(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   5389968,     333551]*)
(*NotebookOutlinePosition[   5396286,     333693]*)
(*  CellTagsIndexPosition[   5394732,     333659]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Divergence and Curl and Their Geometric Interpretations", "Title"],

Cell[CellGroupData[{

Cell["\<\
Setting up the combined potential due to three point potentials as \
an example to visualize gradients, divergences, and curls\
\>", "Section"],

Cell[BoxData[
    \(Simple\ \((2  D)\)\ \ 1\/r\ \(potential : \ \ \((\ gravity, \ 
          electrostatic\ potential\ have\ this\ dependency)\)\)\)], "Text",
  FontFamily->"Helvetica",
  CellTags->"mmtag:13:1/r_potentials"],

Cell[BoxData[
    \(potential[x_\ , \ y_, \ xo_\ , \ yo_] := \ \(-1\)/
        Sqrt[\((x - xo)\)^2\  + \ \((y - yo)\)^2]\)], "Input"],

Cell["A field source located a distance 1 south of the origin", "Text"],

Cell[BoxData[
    \(HoleSouth[x_, \ y_]\  := \ 
      potential[x, y, \ Cos[3  Pi/2], \ Sin[3\ Pi/2]]\)], "Input"],

Cell["Sources located distance 1 at 30\[Degree] and 150\[Degree]:", "Text"],

Cell[BoxData[
    \(HoleNorthWest[x_\ , \ y_]\  := \ 
      potential[x, y, \ Cos[Pi/6], \ Sin[\ Pi/6]]\)], "Input"],

Cell[BoxData[
    \(HoleNorthEast[x_\ , \ y_]\  := \ 
      potential[x, y, \ Cos[\ 5\ Pi/6], \ Sin[5\ Pi/6]]\)], "Input"],

Cell["\<\
Function that returns the two dimensional (x,y) gradient field of \
any function declared a function of two arguments:\
\>", "Text"],

Cell[BoxData[
    \(gradfield[
        scalarfunction_]\  := \ {D[scalarfunction[x, y], x] // Simplify, \ 
        D[scalarfunction[x, y], y] // Simplify}\)], "Input",
  CellTags->"mmtag:13:gradient__example_function"],

Cell["Generalizing the function to any arguments:", "Text"],

Cell[BoxData[
    \(gradfield[scalarfunction_, \ x_\ , \ 
        y_]\  := \ {D[scalarfunction[x, y], x] // Simplify, \ 
        D[scalarfunction[x, y], y] // Simplify}\)], "Input"],

Cell["The sum of three potentials:", "Text"],

Cell[BoxData[
    \(ThreeHolePotential[x_, \ y_]\  := \ 
      HoleSouth[x, y]\  + \ HoleNorthWest[x, y]\  + \ 
        HoleNorthEast[x, y]\)], "Input"],

Cell["f(x,y) visualization of the scalar potential:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[
      ThreeHolePotential[x, y], {x, \(-2\), 2}, {y, \(-2\), 2}]\)], "Input",
  CellTags->"mmtag:13:Plot3D[]__example_1/r_potentials"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -26.9375 -19.3395 ]
[.02757 .24618 0 .66054 ]
[.17646 .18758 -26.486 -20 ]
[.17646 .18758 .45147 0 ]
[.3345 .12542 -13.0356 -20 ]
[.3345 .12542 .96436 0 ]
[.50253 .05935 -12.3059 -20 ]
[.50253 .05935 1.69409 0 ]
[.68156 -0.01098 -11.5762 -20 ]
[.68156 -0.01098 2.42381 0 ]
[.70096 -0.00478 0 -13.9157 ]
[.70096 -0.00478 26.9375 6.08431 ]
[.78313 .12104 0 -13.6413 ]
[.78313 .12104 26.9375 6.35872 ]
[.8565 .23339 0 -13.4028 ]
[.8565 .23339 14 6.59718 ]
[.9224 .33431 0 -13.1937 ]
[.9224 .33431 14 6.80633 ]
[.98191 .42546 0 -13.0087 ]
[.98191 .42546 14 6.99126 ]
[.02069 .28654 -26.9375 -6.13427 ]
[.02069 .28654 0 13.8657 ]
[.01289 .33548 -26.9375 -6.22633 ]
[.01289 .33548 0 13.7737 ]
[.00483 .38599 -26.9375 -6.32165 ]
[.00483 .38599 0 13.6784 ]
[-0.00349 .43814 -26.9375 -6.4204 ]
[-0.00349 .43814 0 13.5796 ]
[-0.01209 .49202 -26.9375 -6.52276 ]
[-0.01209 .49202 0 13.4772 ]
[ -0.005 -0.005 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -87.9375 -23.3395 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -87.486 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -74.0356 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -73.3059 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -72.5762 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.01 w
.68874 0 m
.96935 .42924 L
s
.25 Mabswid
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -17.9157 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -17.6413 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -17.4028 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -17.1937 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -17.0087 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.01 w
.03716 .25514 m
0 .48963 L
s
.25 Mabswid
.03293 .28181 m
.03905 .27945 L
s
gsave
.02069 .28654 -87.9375 -10.1343 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.02516 .33085 m
.0313 .32853 L
s
gsave
.01289 .33548 -87.9375 -10.2263 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.01714 .38146 m
.0233 .37919 L
s
gsave
.00483 .38599 -87.9375 -10.3216 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.00886 .43372 m
.01504 .43151 L
s
gsave
-0.00349 .43814 -87.9375 -10.4204 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.0003 .48771 m
.0065 .48556 L
s
gsave
-0.01209 .49202 -87.9375 -10.5228 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.0314 .2915 m
.03507 .29008 L
s
.02985 .30124 m
.03353 .29983 L
s
.0283 .31105 m
.03198 .30965 L
s
.02674 .32092 m
.03042 .31952 L
s
.02358 .34084 m
.02726 .33946 L
s
.02198 .3509 m
.02567 .34952 L
s
.02038 .36102 m
.02407 .35965 L
s
.01877 .37121 m
.02246 .36984 L
s
.01551 .39177 m
.0192 .39042 L
s
.01386 .40216 m
.01756 .40081 L
s
.01221 .41261 m
.01591 .41127 L
s
.01054 .42313 m
.01424 .4218 L
s
.00717 .44438 m
.01088 .44306 L
s
.00547 .4551 m
.00918 .45379 L
s
.00376 .4659 m
.00747 .46459 L
s
.00204 .47677 m
.00575 .47547 L
s
.03446 .27219 m
.03813 .27076 L
s
.03597 .26262 m
.03964 .26119 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.692 .73 .879 r
.38467 .78978 .39813 .80363 .42081 .79522 .40748 .7808 Metetra
.693 .724 .874 r
.40748 .7808 .42081 .79522 .44366 .78673 .43045 .77169 Metetra
.691 .717 .869 r
.43045 .77169 .44366 .78673 .46666 .77822 .45357 .76253 Metetra
.689 .71 .864 r
.45357 .76253 .46666 .77822 .48982 .76976 .47685 .75342 Metetra
.685 .702 .86 r
.47685 .75342 .48982 .76976 .51316 .76144 .50029 .74449 Metetra
.68 .695 .857 r
.50029 .74449 .51316 .76144 .53666 .75334 .5239 .73589 Metetra
.674 .688 .856 r
.5239 .73589 .53666 .75334 .56035 .74552 .54768 .72768 Metetra
.667 .683 .856 r
.54768 .72768 .56035 .74552 .58422 .73799 .57166 .71991 Metetra
.662 .68 .857 r
.57166 .71991 .58422 .73799 .6083 .73074 .59583 .71253 Metetra
.657 .678 .858 r
.59583 .71253 .6083 .73074 .63258 .72373 .62022 .70544 Metetra
.654 .677 .86 r
.62022 .70544 .63258 .72373 .65708 .71691 .64482 .69855 Metetra
.652 .677 .861 r
.64482 .69855 .65708 .71691 .68179 .71023 .66964 .69177 Metetra
.65 .677 .862 r
.66964 .69177 .68179 .71023 .70674 .70368 .69469 .68507 Metetra
.648 .675 .862 r
.69469 .68507 .70674 .70368 .73191 .69727 .71997 .67848 Metetra
.645 .673 .863 r
.71997 .67848 .73191 .69727 .75733 .69105 .7455 .67209 Metetra
.641 .671 .863 r
.7455 .67209 .75733 .69105 .78301 .68508 .77129 .666 Metetra
.635 .669 .865 r
.77129 .666 .78301 .68508 .80896 .67939 .79736 .66032 Metetra
.628 .667 .868 r
.79736 .66032 .80896 .67939 .8352 .67402 .82373 .65509 Metetra
.622 .667 .873 r
.82373 .65509 .8352 .67402 .86173 .66894 .85042 .65029 Metetra
.616 .669 .878 r
.85042 .65029 .86173 .66894 .88856 .66411 .87743 .64583 Metetra
.612 .673 .884 r
.87743 .64583 .88856 .66411 .9157 .65943 .90476 .64158 Metetra
.609 .679 .891 r
.90476 .64158 .9157 .65943 .94313 .65482 .9324 .63741 Metetra
.608 .685 .897 r
.9324 .63741 .94313 .65482 .97087 .65021 .96036 .6332 Metetra
.608 .692 .903 r
.96036 .6332 .97087 .65021 .99891 .64552 .98862 .62887 Metetra
.699 .729 .873 r
.37103 .77552 .38467 .78978 .40748 .7808 .39398 .76587 Metetra
.7 .721 .866 r
.39398 .76587 .40748 .7808 .43045 .77169 .41707 .75599 Metetra
.699 .713 .86 r
.41707 .75599 .43045 .77169 .45357 .76253 .44032 .74597 Metetra
.696 .704 .853 r
.44032 .74597 .45357 .76253 .47685 .75342 .46372 .736 Metetra
.691 .694 .848 r
.46372 .736 .47685 .75342 .50029 .74449 .48727 .72626 Metetra
.684 .684 .845 r
.48727 .72626 .50029 .74449 .5239 .73589 .51098 .71698 Metetra
.675 .676 .843 r
.51098 .71698 .5239 .73589 .54768 .72768 .53486 .70833 Metetra
.666 .669 .843 r
.53486 .70833 .54768 .72768 .57166 .71991 .55892 .70035 Metetra
.659 .666 .845 r
.55892 .70035 .57166 .71991 .59583 .71253 .58319 .69294 Metetra
.654 .665 .848 r
.58319 .69294 .59583 .71253 .62022 .70544 .60767 .6859 Metetra
.652 .665 .85 r
.60767 .6859 .62022 .70544 .64482 .69855 .63237 .67903 Metetra
.651 .667 .852 r
.63237 .67903 .64482 .69855 .66964 .69177 .6573 .67218 Metetra
.651 .667 .853 r
.6573 .67218 .66964 .69177 .69469 .68507 .68244 .6653 Metetra
.65 .666 .853 r
.68244 .6653 .69469 .68507 .71997 .67848 .70782 .65842 Metetra
.647 .663 .852 r
.70782 .65842 .71997 .67848 .7455 .67209 .73344 .65172 Metetra
.641 .659 .852 r
.73344 .65172 .7455 .67209 .77129 .666 .75932 .6454 Metetra
.634 .655 .853 r
.75932 .6454 .77129 .666 .79736 .66032 .7855 .63967 Metetra
.624 .651 .856 r
.7855 .63967 .79736 .66032 .82373 .65509 .81201 .63463 Metetra
.615 .651 .862 r
.81201 .63463 .82373 .65509 .85042 .65029 .83886 .63026 Metetra
.608 .653 .869 r
.83886 .63026 .85042 .65029 .87743 .64583 .86605 .62638 Metetra
.602 .658 .877 r
.86605 .62638 .87743 .64583 .90476 .64158 .89359 .62279 Metetra
.599 .666 .886 r
.89359 .62279 .90476 .64158 .9324 .63741 .92146 .61925 Metetra
.599 .675 .894 r
.92146 .61925 .9324 .63741 .96036 .6332 .94964 .61561 Metetra
.6 .684 .901 r
.94964 .61561 .96036 .6332 .98862 .62887 .97814 .61175 Metetra
.707 .728 .867 r
.35721 .76089 .37103 .77552 .39398 .76587 .3803 .75041 Metetra
.709 .72 .858 r
.3803 .75041 .39398 .76587 .41707 .75599 .40354 .73954 Metetra
.708 .71 .849 r
.40354 .73954 .41707 .75599 .44032 .74597 .42692 .7284 Metetra
.705 .698 .841 r
.42692 .7284 .44032 .74597 .46372 .736 .45045 .71721 Metetra
.699 .685 .833 r
.45045 .71721 .46372 .736 .48727 .72626 .47411 .7063 Metetra
.688 .671 .828 r
.47411 .7063 .48727 .72626 .51098 .71698 .49792 .69608 Metetra
.676 .659 .826 r
.49792 .69608 .51098 .71698 .53486 .70833 .52188 .68689 Metetra
.663 .651 .828 r
.52188 .68689 .53486 .70833 .55892 .70035 .54602 .6788 Metetra
.653 .647 .831 r
.54602 .6788 .55892 .70035 .58319 .69294 .57038 .6716 Metetra
.647 .647 .836 r
.57038 .6716 .58319 .69294 .60767 .6859 .59495 .66487 Metetra
.646 .651 .84 r
.59495 .66487 .60767 .6859 .63237 .67903 .61975 .65822 Metetra
.648 .655 .843 r
.61975 .65822 .63237 .67903 .6573 .67218 .64476 .65137 Metetra
.651 .658 .843 r
.64476 .65137 .6573 .67218 .68244 .6653 .67 .64421 Metetra
.653 .657 .842 r
.67 .64421 .68244 .6653 .70782 .65842 .69545 .63685 Metetra
.651 .653 .839 r
.69545 .63685 .70782 .65842 .73344 .65172 .72114 .62956 Metetra
.644 .646 .837 r
.72114 .62956 .73344 .65172 .75932 .6454 .74709 .62276 Metetra
.633 .638 .837 r
.74709 .62276 .75932 .6454 .7855 .63967 .77336 .61685 Metetra
.619 .631 .84 r
.77336 .61685 .7855 .63967 .81201 .63463 .79999 .6121 Metetra
.606 .628 .847 r
.79999 .6121 .81201 .63463 .83886 .63026 .827 .60842 Metetra
.595 .631 .857 r
.827 .60842 .83886 .63026 .86605 .62638 .8544 .60548 Metetra
.589 .639 .868 r
.8544 .60548 .86605 .62638 .89359 .62279 .88217 .60289 Metetra
.586 .65 .88 r
.88217 .60289 .89359 .62279 .92146 .61925 .91029 .60027 Metetra
.587 .662 .89 r
.91029 .60027 .92146 .61925 .94964 .61561 .93872 .5974 Metetra
.589 .675 .899 r
.93872 .5974 .94964 .61561 .97814 .61175 .96747 .59416 Metetra
.716 .728 .86 r
.3432 .74594 .35721 .76089 .3803 .75041 .36644 .73446 Metetra
.719 .719 .849 r
.36644 .73446 .3803 .75041 .40354 .73954 .38984 .72234 Metetra
.72 .707 .837 r
.38984 .72234 .40354 .73954 .42692 .7284 .41338 .70964 Metetra
.717 .692 .825 r
.41338 .70964 .42692 .7284 .45045 .71721 .43705 .69666 Metetra
.709 .674 .814 r
.43705 .69666 .45045 .71721 .47411 .7063 .46084 .68392 Metetra
.695 .655 .807 r
.46084 .68392 .47411 .7063 .49792 .69608 .48474 .67222 Metetra
.675 .637 .804 r
.48474 .67222 .49792 .69608 .52188 .68689 .50877 .66232 Metetra
.655 .624 .807 r
.50877 .66232 .52188 .68689 .54602 .6788 .53298 .6544 Metetra
.64 .62 .814 r
.53298 .6544 .54602 .6788 .57038 .6716 .5574 .64795 Metetra
.634 .624 .822 r
.5574 .64795 .57038 .6716 .59495 .66487 .58205 .64208 Metetra
.637 .633 .83 r
.58205 .64208 .59495 .66487 .61975 .65822 .60694 .63601 Metetra
.644 .643 .834 r
.60694 .63601 .61975 .65822 .64476 .65137 .63205 .62928 Metetra
.653 .649 .834 r
.63205 .62928 .64476 .65137 .67 .64421 .65736 .62173 Metetra
.659 .649 .829 r
.65736 .62173 .67 .64421 .69545 .63685 .68287 .61349 Metetra
.659 .643 .823 r
.68287 .61349 .69545 .63685 .72114 .62956 .70859 .60505 Metetra
.651 .631 .817 r
.70859 .60505 .72114 .62956 .74709 .62276 .73456 .59718 Metetra
.634 .617 .815 r
.73456 .59718 .74709 .62276 .77336 .61685 .76088 .59081 Metetra
.612 .603 .818 r
.76088 .59081 .77336 .61685 .79999 .6121 .78761 .58649 Metetra
.591 .597 .826 r
.78761 .58649 .79999 .6121 .827 .60842 .81481 .58404 Metetra
.576 .6 .84 r
.81481 .58404 .827 .60842 .8544 .60548 .84246 .58272 Metetra
.569 .612 .857 r
.84246 .58272 .8544 .60548 .88217 .60289 .8705 .58171 Metetra
.568 .629 .873 r
.8705 .58171 .88217 .60289 .91029 .60027 .89889 .58044 Metetra
.571 .648 .887 r
.89889 .58044 .91029 .60027 .93872 .5974 .9276 .57863 Metetra
.576 .665 .898 r
.9276 .57863 .93872 .5974 .96747 .59416 .95661 .57617 Metetra
.726 .73 .854 r
.32899 .73075 .3432 .74594 .36644 .73446 .3524 .71812 Metetra
.732 .72 .839 r
.3524 .71812 .36644 .73446 .38984 .72234 .37598 .70441 Metetra
.736 .706 .823 r
.37598 .70441 .38984 .72234 .41338 .70964 .39971 .68958 Metetra
.734 .687 .805 r
.39971 .68958 .41338 .70964 .43705 .69666 .42357 .67383 Metetra
.725 .664 .789 r
.42357 .67383 .43705 .69666 .46084 .68392 .4475 .65795 Metetra
.705 .636 .778 r
.4475 .65795 .46084 .68392 .48474 .67222 .4715 .64356 Metetra
.673 .607 .773 r
.4715 .64356 .48474 .67222 .50877 .66232 .49558 .63257 Metetra
.638 .584 .778 r
.49558 .63257 .50877 .66232 .53298 .6544 .51981 .62556 Metetra
.614 .578 .79 r
.51981 .62556 .53298 .6544 .5574 .64795 .54427 .62114 Metetra
.609 .59 .806 r
.54427 .62114 .5574 .64795 .58205 .64208 .569 .61725 Metetra
.62 .611 .82 r
.569 .61725 .58205 .64208 .60694 .63601 .59397 .61244 Metetra
.638 .63 .826 r
.59397 .61244 .60694 .63601 .63205 .62928 .61917 .60604 Metetra
.656 .643 .825 r
.61917 .60604 .63205 .62928 .65736 .62173 .64454 .59787 Metetra
.671 .645 .816 r
.64454 .59787 .65736 .62173 .68287 .61349 .67007 .58807 Metetra
.675 .637 .803 r
.67007 .58807 .68287 .61349 .70859 .60505 .69575 .57732 Metetra
.666 .618 .791 r
.69575 .57732 .70859 .60505 .73456 .59718 .72166 .56707 Metetra
.639 .591 .784 r
.72166 .56707 .73456 .59718 .76088 .59081 .74793 .55945 Metetra
.602 .565 .785 r
.74793 .55945 .76088 .59081 .78761 .58649 .77476 .55592 Metetra
.566 .551 .797 r
.77476 .55592 .78761 .58649 .81481 .58404 .8022 .55592 Metetra
.544 .556 .817 r
.8022 .55592 .81481 .58404 .84246 .58272 .83017 .55755 Metetra
.537 .577 .842 r
.83017 .55755 .84246 .58272 .8705 .58171 .85856 .55912 Metetra
.541 .604 .866 r
.85856 .55912 .8705 .58171 .89889 .58044 .88728 .55981 Metetra
.55 .631 .885 r
.88728 .55981 .89889 .58044 .9276 .57863 .91629 .55939 Metetra
.56 .654 .899 r
.91629 .55939 .9276 .57863 .95661 .57617 .94558 .55789 Metetra
.738 .734 .848 r
.31457 .71551 .32899 .73075 .3524 .71812 .33817 .7016 Metetra
.747 .723 .83 r
.33817 .7016 .3524 .71812 .37598 .70441 .36196 .68601 Metetra
.754 .708 .808 r
.36196 .68601 .37598 .70441 .39971 .68958 .38592 .66831 Metetra
.758 .686 .783 r
.38592 .66831 .39971 .68958 .42357 .67383 .41002 .64824 Metetra
.75 .657 .758 r
.41002 .64824 .42357 .67383 .4475 .65795 .43419 .62647 Metetra
.723 .617 .739 r
.43419 .62647 .4475 .65795 .4715 .64356 .45834 .60614 Metetra
.669 .567 .731 r
.45834 .60614 .4715 .64356 .49558 .63257 .48243 .59294 Metetra
.601 .521 .737 r
.48243 .59294 .49558 .63257 .51981 .62556 .50659 .58912 Metetra
.56 .511 .757 r
.50659 .58912 .51981 .62556 .54427 .62114 .53103 .58998 Metetra
.562 .539 .787 r
.53103 .58998 .54427 .62114 .569 .61725 .55579 .5903 Metetra
.591 .583 .812 r
.55579 .5903 .569 .61725 .59397 .61244 .58085 .58783 Metetra
.628 .62 .823 r
.58085 .58783 .59397 .61244 .61917 .60604 .60613 .58207 Metetra
.663 .642 .818 r
.60613 .58207 .61917 .60604 .64454 .59787 .63156 .57296 Metetra
.691 .648 .802 r
.63156 .57296 .64454 .59787 .67007 .58807 .65707 .5605 Metetra
.705 .638 .779 r
.65707 .5605 .67007 .58807 .69575 .57732 .68261 .54517 Metetra
.696 .61 .756 r
.68261 .54517 .69575 .57732 .72166 .56707 .70824 .52921 Metetra
.653 .563 .741 r
.70824 .52921 .72166 .56707 .74793 .55945 .73428 .51796 Metetra
.582 .51 .739 r
.73428 .51796 .74793 .55945 .77476 .55592 .76119 .51631 Metetra
.519 .48 .753 r
.76119 .51631 .77476 .55592 .8022 .55592 .78904 .52208 Metetra
.489 .491 .785 r
.78904 .52208 .8022 .55592 .83017 .55755 .81752 .52948 Metetra
.488 .529 .825 r
.81752 .52948 .83017 .55755 .85856 .55912 .84637 .53523 Metetra
.503 .574 .859 r
.84637 .53523 .85856 .55912 .88728 .55981 .87547 .53863 Metetra
.522 .613 .885 r
.87547 .53863 .88728 .55981 .91629 .55939 .90482 .5399 Metetra
.541 .645 .901 r
.90482 .5399 .91629 .55939 .94558 .55789 .9344 .53948 Metetra
.749 .74 .844 r
.29991 .70044 .31457 .71551 .33817 .7016 .32372 .68527 Metetra
.762 .73 .823 r
.32372 .68527 .33817 .7016 .36196 .68601 .34775 .66767 Metetra
.776 .715 .795 r
.34775 .66767 .36196 .68601 .38592 .66831 .37199 .64651 Metetra
.787 .692 .759 r
.37199 .64651 .38592 .66831 .41002 .64824 .39645 .62007 Metetra
.789 .659 .721 r
.39645 .62007 .41002 .64824 .43419 .62647 .42106 .58672 Metetra
.763 .611 .689 r
.42106 .58672 .43419 .62647 .45834 .60614 .44559 .54996 Metetra
.67 .523 .676 r
.44559 .54996 .45834 .60614 .48243 .59294 .46965 .52983 Metetra
.517 .412 .674 r
.46965 .52983 .48243 .59294 .50659 .58912 .49347 .53834 Metetra
.443 .389 .703 r
.49347 .53834 .50659 .58912 .53103 .58998 .51771 .55342 Metetra
.473 .46 .763 r
.51771 .55342 .53103 .58998 .55579 .5903 .54247 .56189 Metetra
.545 .55 .81 r
.54247 .56189 .55579 .5903 .58085 .58783 .5676 .56306 Metetra
.616 .615 .826 r
.5676 .56306 .58085 .58783 .60613 .58207 .59296 .55823 Metetra
.675 .65 .818 r
.59296 .55823 .60613 .58207 .63156 .57296 .61845 .54788 Metetra
.721 .661 .79 r
.61845 .54788 .63156 .57296 .65707 .5605 .64392 .53144 Metetra
.752 .651 .75 r
.64392 .53144 .65707 .5605 .68261 .54517 .66916 .50753 Metetra
.754 .617 .708 r
.66916 .50753 .68261 .54517 .70824 .52921 .69405 .47674 Metetra
.691 .546 .684 r
.69405 .47674 .70824 .52921 .73428 .51796 .71919 .45247 Metetra
.543 .43 .675 r
.71919 .45247 .73428 .51796 .76119 .51631 .7463 .45745 Metetra
.423 .365 .688 r
.7463 .45745 .76119 .51631 .78904 .52208 .77517 .47968 Metetra
.391 .392 .74 r
.77517 .47968 .78904 .52208 .81752 .52948 .80454 .49869 Metetra
.411 .466 .806 r
.80454 .49869 .81752 .52948 .84637 .53523 .834 .51074 Metetra
.45 .541 .858 r
.834 .51074 .84637 .53523 .87547 .53863 .86353 .51747 Metetra
.488 .598 .89 r
.86353 .51747 .87547 .53863 .90482 .5399 .89321 .52057 Metetra
.518 .638 .908 r
.89321 .52057 .90482 .5399 .9344 .53948 .92309 .52119 Metetra
.759 .749 .844 r
.28499 .68582 .29991 .70044 .32372 .68527 .30901 .66963 Metetra
.777 .742 .821 r
.30901 .66963 .32372 .68527 .34775 .66767 .33328 .65031 Metetra
.798 .729 .787 r
.33328 .65031 .34775 .66767 .37199 .64651 .35784 .62586 Metetra
.82 .708 .741 r
.35784 .62586 .37199 .64651 .39645 .62007 .38276 .59206 Metetra
.838 .677 .683 r
.38276 .59206 .39645 .62007 .42106 .58672 .40819 .53896 Metetra
.832 .632 .633 r
.40819 .53896 .42106 .58672 .44559 .54996 .43407 .45413 Metetra
.591 .429 .63 r
.43407 .45413 .44559 .54996 .46965 .52983 .45747 .4465 Metetra
.49 .366 .639 r
.45747 .4465 .46965 .52983 .49347 .53834 .48077 .4619 Metetra
.19 .165 .598 r
.48077 .4619 .49347 .53834 .51771 .55342 .50438 .5139 Metetra
.308 .343 .736 r
.50438 .5139 .51771 .55342 .54247 .56189 .52904 .53449 Metetra
.478 .523 .825 r
.52904 .53449 .54247 .56189 .5676 .56306 .55422 .53972 Metetra
.603 .623 .844 r
.55422 .53972 .5676 .56306 .59296 .55823 .57967 .53579 Metetra
.689 .67 .826 r
.57967 .53579 .59296 .55823 .61845 .54788 .60524 .52424 Metetra
.756 .687 .785 r
.60524 .52424 .61845 .54788 .64392 .53144 .63069 .5034 Metetra
.81 .681 .721 r
.63069 .5034 .64392 .53144 .66916 .50753 .65556 .46689 Metetra
.843 .652 .644 r
.65556 .46689 .66916 .50753 .69405 .47674 .67868 .39821 Metetra
.677 .502 .641 r
.67868 .39821 .69405 .47674 .71919 .45247 .70311 .36641 Metetra
.596 .441 .642 r
.70311 .36641 .71919 .45247 .7463 .45745 .72891 .358 Metetra
.242 .189 .596 r
.72891 .358 .7463 .45745 .77517 .47968 .7607 .42903 Metetra
.217 .25 .682 r
.7607 .42903 .77517 .47968 .80454 .49869 .7915 .46804 Metetra
.29 .393 .796 r
.7915 .46804 .80454 .49869 .834 .51074 .82161 .48742 Metetra
.379 .514 .867 r
.82161 .48742 .834 .51074 .86353 .51747 .85155 .49727 Metetra
.448 .591 .902 r
.85155 .49727 .86353 .51747 .89321 .52057 .88153 .50189 Metetra
.495 .638 .919 r
.88153 .50189 .89321 .52057 .92309 .52119 .91167 .50331 Metetra
.766 .761 .848 r
.26979 .67187 .28499 .68582 .30901 .66963 .29399 .6551 Metetra
.788 .757 .825 r
.29399 .6551 .30901 .66963 .33328 .65031 .31848 .6349 Metetra
.815 .75 .791 r
.31848 .6349 .33328 .65031 .35784 .62586 .34331 .60882 Metetra
.848 .736 .74 r
.34331 .60882 .35784 .62586 .38276 .59206 .36863 .57108 Metetra
.882 .712 .667 r
.36863 .57108 .38276 .59206 .40819 .53896 .39489 .50377 Metetra
.836 .656 .659 r
.39489 .50377 .40819 .53896 .43407 .45413 .42041 .43999 Metetra
.664 .741 .907 r
.42041 .43999 .43407 .45413 .45747 .4465 .44394 .43224 Metetra
.664 .741 .907 r
.44394 .43224 .45747 .4465 .48077 .4619 .46767 .42442 Metetra
0 0 .312 r
.46767 .42442 .48077 .4619 .50438 .5139 .49092 .48489 Metetra
0 .181 .706 r
.49092 .48489 .50438 .5139 .52904 .53449 .51548 .51263 Metetra
.396 .533 .877 r
.51548 .51263 .52904 .53449 .55422 .53972 .54071 .51964 Metetra
.594 .655 .879 r
.54071 .51964 .55422 .53972 .57967 .53579 .56626 .516 Metetra
.701 .702 .848 r
.56626 .516 .57967 .53579 .60524 .52424 .59195 .50387 Metetra
.783 .723 .797 r
.59195 .50387 .60524 .52424 .63069 .5034 .61751 .48094 Metetra
.859 .726 .715 r
.61751 .48094 .63069 .5034 .65556 .46689 .64232 .43689 Metetra
.89 .698 .636 r
.64232 .43689 .65556 .46689 .67868 .39821 .66531 .3593 Metetra
.63 .545 .74 r
.66531 .3593 .67868 .39821 .70311 .36641 .69103 .35082 Metetra
.664 .741 .907 r
.69103 .35082 .70311 .36641 .72891 .358 .71698 .34227 Metetra
.695 .247 0 r
.71698 .34227 .72891 .358 .7607 .42903 .74717 .39133 Metetra
0 .025 .59 r
.74717 .39133 .7607 .42903 .7915 .46804 .77892 .44465 Metetra
.079 .321 .8 r
.77892 .44465 .7915 .46804 .82161 .48742 .80941 .46781 Metetra
.289 .507 .893 r
.80941 .46781 .82161 .48742 .85155 .49727 .8396 .47907 Metetra
.407 .598 .924 r
.8396 .47907 .85155 .49727 .88153 .50189 .86981 .48433 Metetra
.474 .647 .934 r
.86981 .48433 .88153 .50189 .91167 .50331 .90017 .48607 Metetra
.769 .773 .856 r
.25426 .6587 .26979 .67187 .29399 .6551 .27863 .64191 Metetra
.792 .775 .837 r
.27863 .64191 .29399 .6551 .31848 .6349 .30328 .62192 Metetra
.824 .778 .809 r
.30328 .62192 .31848 .6349 .34331 .60882 .32827 .5967 Metetra
.864 .781 .767 r
.32827 .5967 .34331 .60882 .36863 .57108 .35371 .562 Metetra
.914 .784 .704 r
.35371 .562 .36863 .57108 .39489 .50377 .37983 .50782 Metetra
.972 .819 .634 r
.37983 .50782 .39489 .50377 .42041 .43999 .40653 .42562 Metetra
.664 .741 .907 r
.40653 .42562 .42041 .43999 .44394 .43224 .43018 .41775 Metetra
.114 .469 .892 r
.43018 .41775 .44394 .43224 .46767 .42442 .45366 .42778 Metetra
.862 .457 .266 r
.45366 .42778 .46767 .42442 .49092 .48489 .47701 .47911 Metetra
.604 .038 0 r
.47701 .47911 .49092 .48489 .51548 .51263 .50169 .49898 Metetra
.325 .617 .955 r
.50169 .49898 .51548 .51263 .54071 .51964 .52701 .50359 Metetra
.594 .709 .923 r
.52701 .50359 .54071 .51964 .56626 .516 .55269 .49925 Metetra
.703 .74 .88 r
.55269 .49925 .56626 .516 .59195 .50387 .57855 .48753 Metetra
.789 .768 .834 r
.57855 .48753 .59195 .50387 .61751 .48094 .60437 .46675 Metetra
.879 .797 .765 r
.60437 .46675 .61751 .48094 .64232 .43689 .62974 .43041 Metetra
.967 .821 .646 r
.62974 .43041 .64232 .43689 .66531 .3593 .6536 .36185 Metetra
.838 .999 .798 r
.6536 .36185 .66531 .3593 .69103 .35082 .67874 .33497 Metetra
.664 .741 .907 r
.67874 .33497 .69103 .35082 .71698 .34227 .70486 .32628 Metetra
.819 .393 0 r
.70486 .32628 .71698 .34227 .74717 .39133 .73625 .39401 Metetra
.791 .3 .038 r
.73625 .39401 .74717 .39133 .77892 .44465 .76712 .43355 Metetra
0 .248 .716 r
.76712 .43355 .77892 .44465 .80941 .46781 .79746 .45329 Metetra
.198 .529 .922 r
.79746 .45329 .80941 .46781 .8396 .47907 .82771 .46337 Metetra
.376 .622 .948 r
.82771 .46337 .8396 .47907 .86981 .48433 .85805 .46812 Metetra
.46 .663 .95 r
.85805 .46812 .86981 .48433 .90017 .48607 .88857 .46959 Metetra
.767 .785 .868 r
.23839 .64624 .25426 .6587 .27863 .64191 .2629 .6299 Metetra
.79 .793 .854 r
.2629 .6299 .27863 .64191 .30328 .62192 .28767 .61097 Metetra
.82 .806 .838 r
.28767 .61097 .30328 .62192 .32827 .5967 .31273 .5883 Metetra
.861 .831 .816 r
.31273 .5883 .32827 .5967 .35371 .562 .3381 .56013 Metetra
.916 .889 .79 r
.3381 .56013 .35371 .562 .37983 .50782 .36374 .52482 Metetra
.82 .952 .607 r
.36374 .52482 .37983 .50782 .40653 .42562 .38935 .48594 Metetra
.349 .059 .323 r
.38935 .48594 .40653 .42562 .43018 .41775 .41416 .46377 Metetra
.558 .226 .363 r
.41416 .46377 .43018 .41775 .45366 .42778 .43822 .47042 Metetra
.599 .259 .365 r
.43822 .47042 .45366 .42778 .47701 .47911 .4626 .48372 Metetra
.443 0 0 r
.4626 .48372 .47701 .47911 .50169 .49898 .4876 .49049 Metetra
.374 .739 .99 r
.4876 .49049 .50169 .49898 .52701 .50359 .51308 .49029 Metetra
.607 .759 .951 r
.51308 .49029 .52701 .50359 .55269 .49925 .53891 .48458 Metetra
.691 .768 .91 r
.53891 .48458 .55269 .49925 .57855 .48753 .56496 .47396 Metetra
.76 .801 .886 r
.56496 .47396 .57855 .48753 .60437 .46675 .59111 .45776 Metetra
.84 .875 .867 r
.59111 .45776 .60437 .46675 .62974 .43041 .61718 .43442 Metetra
.853 .997 .771 r
.61718 .43442 .62974 .43041 .6536 .36185 .64301 .40432 Metetra
.269 0 .24 r
.64301 .40432 .6536 .36185 .67874 .33497 .66903 .38081 Metetra
.547 .208 .345 r
.66903 .38081 .67874 .33497 .70486 .32628 .69663 .38673 Metetra
.622 .299 .402 r
.69663 .38673 .70486 .32628 .73625 .39401 .72583 .41 Metetra
.652 .191 .144 r
.72583 .41 .73625 .39401 .76712 .43355 .75562 .42988 Metetra
.321 0 0 r
.75562 .42988 .76712 .43355 .79746 .45329 .78562 .44257 Metetra
.168 .58 .936 r
.78562 .44257 .79746 .45329 .82771 .46337 .81581 .44973 Metetra
.368 .656 .968 r
.81581 .44973 .82771 .46337 .85805 .46812 .84621 .45307 Metetra
.457 .685 .964 r
.84621 .45307 .85805 .46812 .88857 .46959 .87687 .45378 Metetra
.762 .795 .88 r
.22219 .6343 .23839 .64624 .2629 .6299 .24681 .61866 Metetra
.781 .806 .873 r
.24681 .61866 .2629 .6299 .28767 .61097 .27168 .60112 Metetra
.806 .826 .866 r
.27168 .60112 .28767 .61097 .31273 .5883 .29678 .58121 Metetra
.836 .862 .864 r
.29678 .58121 .31273 .5883 .3381 .56013 .32208 .55864 Metetra
.864 .936 .867 r
.32208 .55864 .3381 .56013 .36374 .52482 .3475 .53407 Metetra
.707 .971 .744 r
.3475 .53407 .36374 .52482 .38935 .48594 .37285 .51069 Metetra
.108 0 0 r
.37285 .51069 .38935 .48594 .41416 .46377 .39793 .4943 Metetra
.381 .001 .187 r
.39793 .4943 .41416 .46377 .43822 .47042 .42282 .48721 Metetra
.359 0 .004 r
.42282 .48721 .43822 .47042 .4626 .48372 .44785 .48482 Metetra
.098 .654 .731 r
.44785 .48482 .4626 .48372 .4876 .49049 .4732 .48211 Metetra
.538 .819 .998 r
.4732 .48211 .4876 .49049 .51308 .49029 .4989 .47722 Metetra
.632 .775 .949 r
.4989 .47722 .51308 .49029 .53891 .48458 .52489 .47001 Metetra
.671 .767 .922 r
.52489 .47001 .53891 .48458 .56496 .47396 .55113 .46061 Metetra
.705 .796 .922 r
.55113 .46061 .56496 .47396 .59111 .45776 .57756 .44886 Metetra
.735 .875 .946 r
.57756 .44886 .59111 .45776 .61718 .43442 .60415 .43487 Metetra
.608 .954 .895 r
.60415 .43487 .61718 .43442 .64301 .40432 .63089 .42051 Metetra
.18 0 0 r
.63089 .42051 .64301 .40432 .66903 .38081 .65799 .41088 Metetra
.473 .084 .22 r
.65799 .41088 .66903 .38081 .69663 .38673 .68582 .41079 Metetra
.535 .113 .186 r
.68582 .41079 .69663 .38673 .72583 .41 .7145 .41797 Metetra
.477 0 0 r
.7145 .41797 .72583 .41 .75562 .42988 .74384 .42655 Metetra
0 .46 .726 r
.74384 .42655 .75562 .42988 .78562 .44257 .77363 .43318 Metetra
.228 .648 .957 r
.77363 .43318 .78562 .44257 .81581 .44973 .80378 .43717 Metetra
.388 .691 .98 r
.80378 .43717 .81581 .44973 .84621 .45307 .83424 .43877 Metetra
.465 .706 .973 r
.83424 .43877 .84621 .45307 .87687 .45378 .86502 .43845 Metetra
.754 .801 .89 r
.20565 .62264 .22219 .6343 .24681 .61866 .23038 .60774 Metetra
.77 .814 .888 r
.23038 .60774 .24681 .61866 .27168 .60112 .25534 .59149 Metetra
.788 .834 .888 r
.25534 .59149 .27168 .60112 .29678 .58121 .2805 .57378 Metetra
.806 .867 .893 r
.2805 .57378 .29678 .58121 .32208 .55864 .30582 .55476 Metetra
.816 .921 .907 r
.30582 .55476 .32208 .55864 .3475 .53407 .33124 .53519 Metetra
.769 .983 .907 r
.33124 .53519 .3475 .53407 .37285 .51069 .35666 .51666 Metetra
.548 .924 .787 r
.35666 .51666 .37285 .51069 .39793 .4943 .38204 .50108 Metetra
.337 .798 .678 r
.38204 .50108 .39793 .4943 .42282 .48721 .4074 .48909 Metetra
.435 .875 .857 r
.4074 .48909 .42282 .48721 .44785 .48482 .43288 .47945 Metetra
.61 .892 .989 r
.43288 .47945 .44785 .48482 .4732 .48211 .45856 .47055 Metetra
.658 .808 .955 r
.45856 .47055 .4732 .48211 .4989 .47722 .48447 .46169 Metetra
.659 .751 .918 r
.48447 .46169 .4989 .47722 .52489 .47001 .51062 .45304 Metetra
.652 .731 .907 r
.51062 .45304 .52489 .47001 .55113 .46061 .53702 .44479 Metetra
.647 .747 .922 r
.53702 .44479 .55113 .46061 .57756 .44886 .56368 .43674 Metetra
.635 .801 .962 r
.56368 .43674 .57756 .44886 .60415 .43487 .59061 .42875 Metetra
.546 .869 .994 r
.59061 .42875 .60415 .43487 .63089 .42051 .61785 .4215 Metetra
.182 .716 .766 r
.61785 .4215 .63089 .42051 .65799 .41088 .64546 .41667 Metetra
.174 0 0 r
.64546 .41667 .65799 .41088 .68582 .41079 .67359 .41554 Metetra
.249 0 0 r
.67359 .41554 .68582 .41079 .7145 .41797 .70231 .41752 Metetra
.111 0 0 r
.70231 .41752 .7145 .41797 .74384 .42655 .73159 .42068 Metetra
.139 .644 .904 r
.73159 .42068 .74384 .42655 .77363 .43318 .76135 .42336 Metetra
.323 .704 .981 r
.76135 .42336 .77363 .43318 .80378 .43717 .79153 .42477 Metetra
.423 .718 .986 r
.79153 .42477 .80378 .43717 .83424 .43877 .82208 .42473 Metetra
.481 .724 .978 r
.82208 .42473 .83424 .43877 .86502 .43845 .85299 .42333 Metetra
.746 .805 .899 r
.18879 .61104 .20565 .62264 .23038 .60774 .21363 .5968 Metetra
.758 .817 .899 r
.21363 .5968 .23038 .60774 .25534 .59149 .23868 .58156 Metetra
.771 .834 .9 r
.23868 .58156 .25534 .59149 .2805 .57378 .26393 .56534 Metetra
.782 .857 .906 r
.26393 .56534 .2805 .57378 .30582 .55476 .28935 .54832 Metetra
.789 .89 .917 r
.28935 .54832 .30582 .55476 .33124 .53519 .31488 .53093 Metetra
.781 .925 .931 r
.31488 .53093 .33124 .53519 .35666 .51666 .34049 .51386 Metetra
.757 .947 .941 r
.34049 .51386 .35666 .51666 .38204 .50108 .36615 .49771 Metetra
.739 .942 .95 r
.36615 .49771 .38204 .50108 .4074 .48909 .39189 .4826 Metetra
.744 .901 .949 r
.39189 .4826 .4074 .48909 .43288 .47945 .41774 .4681 Metetra
.74 .829 .919 r
.41774 .4681 .43288 .47945 .45856 .47055 .44374 .45396 Metetra
.716 .755 .883 r
.44374 .45396 .45856 .47055 .48447 .46169 .46987 .44091 Metetra
.675 .696 .862 r
.46987 .44091 .48447 .46169 .51062 .45304 .49616 .43052 Metetra
.627 .661 .864 r
.49616 .43052 .51062 .45304 .53702 .44479 .52266 .42368 Metetra
.587 .66 .889 r
.52266 .42368 .53702 .44479 .56368 .43674 .54948 .41954 Metetra
.554 .697 .935 r
.54948 .41954 .56368 .43674 .59061 .42875 .57666 .41654 Metetra
.5 .752 .985 r
.57666 .41654 .59061 .42875 .61785 .4215 .60422 .41395 Metetra
.382 .773 .988 r
.60422 .41395 .61785 .4215 .64546 .41667 .63218 .41205 Metetra
.233 .724 .922 r
.63218 .41205 .64546 .41667 .67359 .41554 .66059 .41125 Metetra
.173 .687 .894 r
.66059 .41125 .67359 .41554 .70231 .41752 .68949 .41147 Metetra
.224 .702 .936 r
.68949 .41147 .70231 .41752 .73159 .42068 .71888 .4121 Metetra
.318 .724 .979 r
.71888 .4121 .73159 .42068 .76135 .42336 .74873 .41243 Metetra
.4 .734 .991 r
.74873 .41243 .76135 .42336 .79153 .42477 .779 .412 Metetra
.459 .736 .987 r
.779 .412 .79153 .42477 .82208 .42473 .80968 .41059 Metetra
.499 .736 .979 r
.80968 .41059 .82208 .42473 .85299 .42333 .84073 .40818 Metetra
.738 .806 .906 r
.17159 .59935 .18879 .61104 .21363 .5968 .19655 .58563 Metetra
.748 .816 .906 r
.19655 .58563 .21363 .5968 .23868 .58156 .22173 .57113 Metetra
.758 .829 .907 r
.22173 .57113 .23868 .58156 .26393 .56534 .2471 .55584 Metetra
.767 .845 .91 r
.2471 .55584 .26393 .56534 .28935 .54832 .27264 .53986 Metetra
.775 .863 .915 r
.27264 .53986 .28935 .54832 .31488 .53093 .29834 .52333 Metetra
.779 .879 .919 r
.29834 .52333 .31488 .53093 .34049 .51386 .32418 .50642 Metetra
.784 .884 .918 r
.32418 .50642 .34049 .51386 .36615 .49771 .35014 .48908 Metetra
.79 .869 .906 r
.35014 .48908 .36615 .49771 .39189 .4826 .37624 .47098 Metetra
.795 .829 .878 r
.37624 .47098 .39189 .4826 .41774 .4681 .40249 .45152 Metetra
.786 .769 .838 r
.40249 .45152 .41774 .4681 .44374 .45396 .42885 .43068 Metetra
.752 .701 .803 r
.42885 .43068 .44374 .45396 .46987 .44091 .45525 .41069 Metetra
.682 .626 .786 r
.45525 .41069 .46987 .44091 .49616 .43052 .48164 .39695 Metetra
.584 .558 .791 r
.48164 .39695 .49616 .43052 .52266 .42368 .50815 .39309 Metetra
.501 .533 .822 r
.50815 .39309 .52266 .42368 .54948 .41954 .53502 .39558 Metetra
.457 .57 .88 r
.53502 .39558 .54948 .41954 .57666 .41654 .56236 .39901 Metetra
.431 .639 .943 r
.56236 .39901 .57666 .41654 .60422 .41395 .59016 .40115 Metetra
.398 .697 .981 r
.59016 .40115 .60422 .41395 .63218 .41205 .61839 .402 Metetra
.361 .725 .988 r
.61839 .402 .63218 .41205 .66059 .41125 .64706 .40214 Metetra
.348 .734 .986 r
.64706 .40214 .66059 .41125 .68949 .41147 .67618 .40193 Metetra
.369 .74 .989 r
.67618 .40193 .68949 .41147 .71888 .4121 .70575 .40138 Metetra
.409 .745 .993 r
.70575 .40138 .71888 .4121 .74873 .41243 .73575 .40033 Metetra
.451 .746 .992 r
.73575 .40033 .74873 .41243 .779 .412 .76617 .39862 Metetra
.487 .745 .986 r
.76617 .39862 .779 .412 .80968 .41059 .79701 .39613 Metetra
.516 .745 .978 r
.79701 .39613 .80968 .41059 .84073 .40818 .82823 .39286 Metetra
.732 .806 .911 r
.15407 .58748 .17159 .59935 .19655 .58563 .17915 .57417 Metetra
.74 .815 .91 r
.17915 .57417 .19655 .58563 .22173 .57113 .20446 .56017 Metetra
.749 .825 .911 r
.20446 .56017 .22173 .57113 .2471 .55584 .22997 .54546 Metetra
.758 .836 .911 r
.22997 .54546 .2471 .55584 .27264 .53986 .25568 .53 Metetra
.767 .846 .91 r
.25568 .53 .27264 .53986 .29834 .52333 .28157 .51374 Metetra
.778 .852 .906 r
.28157 .51374 .29834 .52333 .32418 .50642 .30765 .49648 Metetra
.792 .85 .894 r
.30765 .49648 .32418 .50642 .35014 .48908 .33393 .47773 Metetra
.809 .832 .868 r
.33393 .47773 .35014 .48908 .37624 .47098 .36042 .45644 Metetra
.824 .794 .824 r
.36042 .45644 .37624 .47098 .40249 .45152 .38714 .43088 Metetra
.826 .739 .768 r
.38714 .43088 .40249 .45152 .42885 .43068 .41405 .39896 Metetra
.799 .668 .719 r
.41405 .39896 .42885 .43068 .45525 .41069 .44098 .36217 Metetra
.699 .563 .697 r
.44098 .36217 .45525 .41069 .48164 .39695 .46748 .33762 Metetra
.496 .41 .689 r
.46748 .33762 .48164 .39695 .50815 .39309 .49367 .34411 Metetra
.342 .342 .714 r
.49367 .34411 .50815 .39309 .53502 .39558 .52037 .36308 Metetra
.303 .406 .802 r
.52037 .36308 .53502 .39558 .56236 .39901 .54777 .37736 Metetra
.322 .527 .899 r
.54777 .37736 .56236 .39901 .59016 .40115 .57576 .38536 Metetra
.352 .628 .957 r
.57576 .38536 .59016 .40115 .61839 .402 .60423 .38914 Metetra
.375 .69 .981 r
.60423 .38914 .61839 .402 .64706 .40214 .63314 .39043 Metetra
.398 .723 .989 r
.63314 .39043 .64706 .40214 .67618 .40193 .66248 .39027 Metetra
.424 .74 .992 r
.66248 .39027 .67618 .40193 .70575 .40138 .69224 .38914 Metetra
.454 .748 .992 r
.69224 .38914 .70575 .40138 .73575 .40033 .72243 .38723 Metetra
.483 .75 .988 r
.72243 .38723 .73575 .40033 .76617 .39862 .75304 .38461 Metetra
.508 .751 .983 r
.75304 .38461 .76617 .39862 .79701 .39613 .78406 .38128 Metetra
.53 .75 .977 r
.78406 .38128 .79701 .39613 .82823 .39286 .81547 .37725 Metetra
.726 .806 .915 r
.1362 .57539 .15407 .58748 .17915 .57417 .16143 .56239 Metetra
.733 .813 .914 r
.16143 .56239 .17915 .57417 .20446 .56017 .18687 .54876 Metetra
.742 .821 .913 r
.18687 .54876 .20446 .56017 .22997 .54546 .21254 .53441 Metetra
.751 .829 .912 r
.21254 .53441 .22997 .54546 .25568 .53 .23842 .51926 Metetra
.763 .836 .908 r
.23842 .51926 .25568 .53 .28157 .51374 .26452 .50308 Metetra
.778 .84 .899 r
.26452 .50308 .28157 .51374 .30765 .49648 .29084 .48544 Metetra
.799 .837 .88 r
.29084 .48544 .30765 .49648 .33393 .47773 .31743 .46547 Metetra
.824 .822 .846 r
.31743 .46547 .33393 .47773 .36042 .45644 .34431 .44138 Metetra
.851 .789 .79 r
.34431 .44138 .36042 .45644 .38714 .43088 .37157 .40937 Metetra
.87 .737 .712 r
.37157 .40937 .38714 .43088 .41405 .39896 .39938 .36066 Metetra
.871 .673 .632 r
.39938 .36066 .41405 .39896 .44098 .36217 .42793 .27579 Metetra
.593 .434 .635 r
.42793 .27579 .44098 .36217 .46748 .33762 .4538 .26378 Metetra
.576 .437 .654 r
.4538 .26378 .46748 .33762 .49367 .34411 .47979 .25715 Metetra
.042 .049 .538 r
.47979 .25715 .49367 .34411 .52037 .36308 .50563 .32394 Metetra
.038 .19 .694 r
.50563 .32394 .52037 .36308 .54777 .37736 .53296 .35478 Metetra
.153 .415 .857 r
.53296 .35478 .54777 .37736 .57576 .38536 .56107 .36899 Metetra
.274 .579 .942 r
.56107 .36899 .57576 .38536 .60423 .38914 .58974 .37531 Metetra
.356 .668 .974 r
.58974 .37531 .60423 .38914 .63314 .39043 .61886 .37753 Metetra
.409 .714 .986 r
.61886 .37753 .63314 .39043 .66248 .39027 .64842 .37744 Metetra
.447 .737 .989 r
.64842 .37744 .66248 .39027 .69224 .38914 .6784 .37592 Metetra
.478 .748 .989 r
.6784 .37592 .69224 .38914 .72243 .38723 .70879 .37338 Metetra
.503 .753 .985 r
.70879 .37338 .72243 .38723 .75304 .38461 .7396 .37004 Metetra
.524 .754 .98 r
.7396 .37004 .75304 .38461 .78406 .38128 .77081 .366 Metetra
.541 .754 .975 r
.77081 .366 .78406 .38128 .81547 .37725 .80243 .36132 Metetra
.72 .806 .918 r
.118 .56307 .1362 .57539 .16143 .56239 .14336 .55032 Metetra
.727 .812 .917 r
.14336 .55032 .16143 .56239 .18687 .54876 .16894 .53696 Metetra
.736 .819 .916 r
.16894 .53696 .18687 .54876 .21254 .53441 .19477 .52291 Metetra
.746 .826 .913 r
.19477 .52291 .21254 .53441 .23842 .51926 .22082 .50801 Metetra
.759 .832 .908 r
.22082 .50801 .23842 .51926 .26452 .50308 .24712 .49195 Metetra
.777 .837 .898 r
.24712 .49195 .26452 .50308 .29084 .48544 .27368 .47422 Metetra
.801 .837 .879 r
.27368 .47422 .29084 .48544 .31743 .46547 .30053 .45375 Metetra
.834 .83 .844 r
.30053 .45375 .31743 .46547 .34431 .44138 .32775 .42839 Metetra
.873 .808 .783 r
.32775 .42839 .34431 .44138 .37157 .40937 .35549 .39311 Metetra
.909 .766 .691 r
.35549 .39311 .37157 .40937 .39938 .36066 .38415 .33339 Metetra
.895 .711 .646 r
.38415 .33339 .39938 .36066 .42793 .27579 .41288 .25586 Metetra
.661 .707 .881 r
.41288 .25586 .42793 .27579 .4538 .26378 .43882 .24641 Metetra
.664 .741 .907 r
.43882 .24641 .4538 .26378 .47979 .25715 .46502 .23688 Metetra
.829 .403 0 r
.46502 .23688 .47979 .25715 .50563 .32394 .49071 .29592 Metetra
0 0 .478 r
.49071 .29592 .50563 .32394 .53296 .35478 .5179 .33752 Metetra
0 .315 .796 r
.5179 .33752 .53296 .35478 .56107 .36899 .54612 .3547 Metetra
.182 .559 .933 r
.54612 .3547 .56107 .36899 .58974 .37531 .57495 .36199 Metetra
.331 .667 .975 r
.57495 .36199 .58974 .37531 .61886 .37753 .60428 .3644 Metetra
.412 .716 .987 r
.60428 .3644 .61886 .37753 .64842 .37744 .63404 .36408 Metetra
.46 .74 .989 r
.63404 .36408 .64842 .37744 .6784 .37592 .66423 .3621 Metetra
.493 .751 .987 r
.66423 .3621 .6784 .37592 .70879 .37338 .69483 .35897 Metetra
.517 .756 .983 r
.69483 .35897 .70879 .37338 .7396 .37004 .72585 .355 Metetra
.536 .758 .978 r
.72585 .355 .7396 .37004 .77081 .366 .75727 .35032 Metetra
.551 .758 .974 r
.75727 .35032 .77081 .366 .80243 .36132 .78911 .34503 Metetra
.715 .805 .921 r
.09944 .5505 .118 .56307 .14336 .55032 .12493 .53797 Metetra
.722 .811 .92 r
.12493 .53797 .14336 .55032 .16894 .53696 .15067 .52486 Metetra
.73 .817 .919 r
.15067 .52486 .16894 .53696 .19477 .52291 .17664 .51109 Metetra
.74 .824 .917 r
.17664 .51109 .19477 .52291 .22082 .50801 .20286 .49647 Metetra
.753 .831 .912 r
.20286 .49647 .22082 .50801 .24712 .49195 .22934 .48072 Metetra
.771 .839 .903 r
.22934 .48072 .24712 .49195 .27368 .47422 .2561 .46331 Metetra
.797 .845 .887 r
.2561 .46331 .27368 .47422 .30053 .45375 .28317 .44331 Metetra
.832 .85 .859 r
.28317 .44331 .30053 .45375 .32775 .42839 .31061 .4189 Metetra
.879 .85 .811 r
.31061 .4189 .32775 .42839 .35549 .39311 .33854 .38627 Metetra
.932 .843 .732 r
.33854 .38627 .35549 .39311 .38415 .33339 .3672 .33662 Metetra
.982 .834 .622 r
.3672 .33662 .38415 .33339 .41288 .25586 .39698 .25036 Metetra
.827 .928 .9 r
.39698 .25036 .41288 .25586 .43882 .24641 .42358 .22873 Metetra
.403 .627 .944 r
.42358 .22873 .43882 .24641 .46502 .23688 .44964 .23108 Metetra
.893 .472 .164 r
.44964 .23108 .46502 .23688 .49071 .29592 .47512 .29862 Metetra
.745 .239 .015 r
.47512 .29862 .49071 .29592 .5179 .33752 .5025 .32976 Metetra
0 .259 .634 r
.5025 .32976 .5179 .33752 .54612 .3547 .53085 .34395 Metetra
.119 .576 .919 r
.53085 .34395 .54612 .3547 .57495 .36199 .55986 .34994 Metetra
.322 .687 .979 r
.55986 .34994 .57495 .36199 .60428 .3644 .58937 .35154 Metetra
.419 .729 .99 r
.58937 .35154 .60428 .3644 .63404 .36408 .61934 .35055 Metetra
.472 .748 .989 r
.61934 .35055 .63404 .36408 .66423 .3621 .64973 .34792 Metetra
.506 .757 .986 r
.64973 .34792 .66423 .3621 .69483 .35897 .68055 .34415 Metetra
.529 .76 .982 r
.68055 .34415 .69483 .35897 .72585 .355 .71178 .33954 Metetra
.546 .762 .977 r
.71178 .33954 .72585 .355 .75727 .35032 .74343 .33425 Metetra
.559 .761 .973 r
.74343 .33425 .75727 .35032 .78911 .34503 .77549 .32838 Metetra
.71 .805 .924 r
.08051 .53769 .09944 .5505 .12493 .53797 .10614 .52535 Metetra
.716 .81 .923 r
.10614 .52535 .12493 .53797 .15067 .52486 .13202 .51249 Metetra
.724 .816 .922 r
.13202 .51249 .15067 .52486 .17664 .51109 .15814 .49901 Metetra
.733 .824 .921 r
.15814 .49901 .17664 .51109 .20286 .49647 .18452 .48475 Metetra
.745 .832 .918 r
.18452 .48475 .20286 .49647 .22934 .48072 .21116 .46948 Metetra
.762 .842 .912 r
.21116 .46948 .22934 .48072 .2561 .46331 .23808 .45279 Metetra
.785 .854 .902 r
.23808 .45279 .2561 .46331 .28317 .44331 .26531 .43403 Metetra
.816 .87 .887 r
.26531 .43403 .28317 .44331 .31061 .4189 .29286 .41213 Metetra
.858 .896 .862 r
.29286 .41213 .31061 .4189 .33854 .38627 .32078 .38541 Metetra
.905 .943 .821 r
.32078 .38541 .33854 .38627 .3672 .33662 .34906 .35193 Metetra
.809 .965 .646 r
.34906 .35193 .3672 .33662 .39698 .25036 .37743 .31347 Metetra
.259 0 .234 r
.37743 .31347 .39698 .25036 .42358 .22873 .40509 .28777 Metetra
.519 .175 .325 r
.40509 .28777 .42358 .22873 .44964 .23108 .43179 .29413 Metetra
.585 .243 .356 r
.43179 .29413 .44964 .23108 .47512 .29862 .45877 .31348 Metetra
.581 .088 .05 r
.45877 .31348 .47512 .29862 .5025 .32976 .48661 .32803 Metetra
.266 0 0 r
.48661 .32803 .5025 .32976 .53085 .34395 .51521 .33592 Metetra
.144 .633 .916 r
.51521 .33592 .53085 .34395 .55986 .34994 .54442 .33903 Metetra
.344 .72 .985 r
.54442 .33903 .55986 .34994 .58937 .35154 .57413 .33902 Metetra
.437 .749 .994 r
.57413 .33902 .58937 .35154 .61934 .35055 .6043 .33695 Metetra
.488 .76 .991 r
.6043 .33695 .61934 .35055 .64973 .34792 .63491 .33347 Metetra
.519 .764 .986 r
.63491 .33347 .64973 .34792 .68055 .34415 .66595 .32898 Metetra
.54 .766 .981 r
.66595 .32898 .68055 .34415 .71178 .33954 .6974 .3237 Metetra
.555 .766 .976 r
.6974 .3237 .71178 .33954 .74343 .33425 .72928 .3178 Metetra
.567 .765 .971 r
.72928 .3178 .74343 .33425 .77549 .32838 .76157 .31136 Metetra
.705 .804 .926 r
.06121 .52462 .08051 .53769 .10614 .52535 .08697 .51246 Metetra
.71 .809 .926 r
.08697 .51246 .10614 .52535 .13202 .51249 .11299 .49984 Metetra
.717 .816 .926 r
.11299 .49984 .13202 .51249 .15814 .49901 .13926 .48667 Metetra
.725 .823 .926 r
.13926 .48667 .15814 .49901 .18452 .48475 .16578 .47284 Metetra
.735 .832 .924 r
.16578 .47284 .18452 .48475 .21116 .46948 .19257 .45816 Metetra
.749 .843 .922 r
.19257 .45816 .21116 .46948 .23808 .45279 .21963 .4424 Metetra
.766 .859 .919 r
.21963 .4424 .23808 .45279 .26531 .43403 .24697 .4252 Metetra
.788 .882 .915 r
.24697 .4252 .26531 .43403 .29286 .41213 .27459 .40613 Metetra
.812 .919 .91 r
.27459 .40613 .29286 .41213 .32078 .38541 .30248 .38486 Metetra
.814 .977 .895 r
.30248 .38486 .32078 .38541 .34906 .35193 .33055 .3618 Metetra
.596 .928 .717 r
.33055 .3618 .34906 .35193 .37743 .31347 .35861 .33973 Metetra
.095 0 0 r
.35861 .33973 .37743 .31347 .40509 .28777 .38644 .32457 Metetra
.386 0 .159 r
.38644 .32457 .40509 .28777 .43179 .29413 .41408 .3202 Metetra
.443 0 .096 r
.41408 .3202 .43179 .29413 .45877 .31348 .44191 .32285 Metetra
.35 0 0 r
.44191 .32285 .45877 .31348 .48661 .32803 .47025 .32659 Metetra
0 .542 .717 r
.47025 .32659 .48661 .32803 .51521 .33592 .49915 .32864 Metetra
.247 .713 .946 r
.49915 .32864 .51521 .33592 .54442 .33903 .52859 .32853 Metetra
.392 .757 .993 r
.52859 .32853 .54442 .33903 .57413 .33902 .55853 .32658 Metetra
.466 .769 .996 r
.55853 .32658 .57413 .33902 .6043 .33695 .58891 .32321 Metetra
.507 .771 .991 r
.58891 .32321 .6043 .33695 .63491 .33347 .61974 .31875 Metetra
.533 .772 .985 r
.61974 .31875 .63491 .33347 .66595 .32898 .65101 .31345 Metetra
.551 .771 .98 r
.65101 .31345 .66595 .32898 .6974 .3237 .68269 .30749 Metetra
.564 .769 .975 r
.68269 .30749 .6974 .3237 .72928 .3178 .7148 .30096 Metetra
.574 .768 .97 r
.7148 .30096 .72928 .3178 .76157 .31136 .74734 .29395 Metetra
.7 .803 .929 r
.04152 .51126 .06121 .52462 .08697 .51246 .06742 .49928 Metetra
.705 .808 .929 r
.06742 .49928 .08697 .51246 .11299 .49984 .09357 .4869 Metetra
.71 .814 .93 r
.09357 .4869 .11299 .49984 .13926 .48667 .11998 .47405 Metetra
.717 .822 .93 r
.11998 .47405 .13926 .48667 .16578 .47284 .14664 .46065 Metetra
.724 .831 .931 r
.14664 .46065 .16578 .47284 .19257 .45816 .17357 .44661 Metetra
.734 .843 .931 r
.17357 .44661 .19257 .45816 .21963 .4424 .20075 .4318 Metetra
.745 .859 .933 r
.20075 .4318 .21963 .4424 .24697 .4252 .2282 .41608 Metetra
.756 .882 .935 r
.2282 .41608 .24697 .4252 .27459 .40613 .2559 .3994 Metetra
.763 .915 .941 r
.2559 .3994 .27459 .40613 .30248 .38486 .28381 .38192 Metetra
.741 .958 .942 r
.28381 .38192 .30248 .38486 .33055 .3618 .31187 .36436 Metetra
.61 .955 .88 r
.31187 .36436 .33055 .3618 .35861 .33973 .33999 .34835 Metetra
.33999 .34835 .35861 .33973 .38644 .32457 .36811 .33604 Metetra
.024 0 0 r
.36811 .33604 .38644 .32457 .41408 .3202 .39627 .32855 Metetra
.088 0 0 r
.39627 .32855 .41408 .3202 .44191 .32285 .42466 .32482 Metetra
.42466 .32482 .44191 .32285 .47025 .32659 .45343 .32271 Metetra
.223 .73 .894 r
.45343 .32271 .47025 .32659 .49915 .32864 .48266 .32057 Metetra
.367 .778 .981 r
.48266 .32057 .49915 .32864 .52859 .32853 .51237 .31769 Metetra
.45 .786 .998 r
.51237 .31769 .52859 .32853 .55853 .32658 .54254 .31386 Metetra
.498 .785 .996 r
.54254 .31386 .55853 .32658 .58891 .32321 .57316 .30915 Metetra
.528 .781 .99 r
.57316 .30915 .58891 .32321 .61974 .31875 .60422 .30367 Metetra
.548 .778 .984 r
.60422 .30367 .61974 .31875 .65101 .31345 .63572 .29754 Metetra
.562 .775 .978 r
.63572 .29754 .65101 .31345 .68269 .30749 .66764 .29086 Metetra
.573 .773 .973 r
.66764 .29086 .68269 .30749 .7148 .30096 .69999 .2837 Metetra
.582 .771 .969 r
.69999 .2837 .7148 .30096 .74734 .29395 .73277 .27612 Metetra
.695 .802 .931 r
.02144 .49761 .04152 .51126 .06742 .49928 .04747 .48579 Metetra
.699 .807 .932 r
.04747 .48579 .06742 .49928 .09357 .4869 .07376 .47363 Metetra
.703 .813 .933 r
.07376 .47363 .09357 .4869 .11998 .47405 .1003 .46108 Metetra
.708 .82 .934 r
.1003 .46108 .11998 .47405 .14664 .46065 .1271 .4481 Metetra
.713 .828 .936 r
.1271 .4481 .14664 .46065 .17357 .44661 .15415 .43465 Metetra
.719 .839 .938 r
.15415 .43465 .17357 .44661 .20075 .4318 .18147 .42068 Metetra
.725 .854 .942 r
.18147 .42068 .20075 .4318 .2282 .41608 .20903 .4062 Metetra
.729 .873 .948 r
.20903 .4062 .2282 .41608 .2559 .3994 .23682 .39127 Metetra
.726 .898 .957 r
.23682 .39127 .2559 .3994 .28381 .38192 .26482 .37618 Metetra
.704 .926 .966 r
.26482 .37618 .28381 .38192 .31187 .36436 .29298 .36146 Metetra
.639 .941 .96 r
.29298 .36146 .31187 .36436 .33999 .34835 .32127 .34799 Metetra
.513 .91 .918 r
.32127 .34799 .33999 .34835 .36811 .33604 .34968 .33666 Metetra
.378 .842 .865 r
.34968 .33666 .36811 .33604 .39627 .32855 .37824 .32788 Metetra
.319 .805 .871 r
.37824 .32788 .39627 .32855 .42466 .32482 .40705 .32127 Metetra
.346 .809 .929 r
.40705 .32127 .42466 .32482 .45343 .32271 .4362 .31595 Metetra
.407 .815 .978 r
.4362 .31595 .45343 .32271 .48266 .32057 .46575 .31105 Metetra
.462 .812 .998 r
.46575 .31105 .48266 .32057 .51237 .31769 .49574 .30601 Metetra
.501 .803 .999 r
.49574 .30601 .51237 .31769 .54254 .31386 .52616 .30055 Metetra
.529 .795 .994 r
.52616 .30055 .54254 .31386 .57316 .30915 .55703 .29459 Metetra
.548 .788 .988 r
.55703 .29459 .57316 .30915 .60422 .30367 .58833 .28812 Metetra
.563 .783 .982 r
.58833 .28812 .60422 .30367 .63572 .29754 .62007 .28117 Metetra
.573 .779 .976 r
.62007 .28117 .63572 .29754 .66764 .29086 .65223 .27379 Metetra
.582 .776 .972 r
.65223 .27379 .66764 .29086 .69999 .2837 .68483 .266 Metetra
.588 .773 .968 r
.68483 .266 .69999 .2837 .73277 .27612 .71787 .25785 Metetra
.69 .801 .934 r
.00095 .48363 .02144 .49761 .04747 .48579 .02711 .47195 Metetra
.693 .805 .935 r
.02711 .47195 .04747 .48579 .07376 .47363 .05353 .45998 Metetra
.696 .811 .936 r
.05353 .45998 .07376 .47363 .1003 .46108 .08021 .4477 Metetra
.7 .817 .938 r
.08021 .4477 .1003 .46108 .1271 .4481 .10715 .43509 Metetra
.703 .825 .94 r
.10715 .43509 .1271 .4481 .15415 .43465 .13434 .42215 Metetra
.706 .834 .943 r
.13434 .42215 .15415 .43465 .18147 .42068 .16178 .40887 Metetra
.708 .846 .948 r
.16178 .40887 .18147 .42068 .20903 .4062 .18946 .39532 Metetra
.708 .86 .955 r
.18946 .39532 .20903 .4062 .23682 .39127 .21738 .3816 Metetra
.701 .878 .963 r
.21738 .3816 .23682 .39127 .26482 .37618 .24551 .36796 Metetra
.684 .895 .973 r
.24551 .36796 .26482 .37618 .29298 .36146 .27383 .35475 Metetra
.65 .908 .981 r
.27383 .35475 .29298 .36146 .32127 .34799 .30233 .34245 Metetra
.597 .907 .982 r
.30233 .34245 .32127 .34799 .34968 .33666 .33101 .33148 Metetra
.541 .891 .98 r
.33101 .33148 .34968 .33666 .37824 .32788 .3599 .322 Metetra
.505 .871 .983 r
.3599 .322 .37824 .32788 .40705 .32127 .38906 .31386 Metetra
.496 .853 .992 r
.38906 .31386 .40705 .32127 .4362 .31595 .41855 .30664 Metetra
.507 .837 .999 r
.41855 .30664 .4362 .31595 .46575 .31105 .44841 .2999 Metetra
.524 .822 .999 r
.44841 .2999 .46575 .31105 .49574 .30601 .47869 .29326 Metetra
.541 .81 .996 r
.47869 .29326 .49574 .30601 .52616 .30055 .50938 .28647 Metetra
.555 .8 .99 r
.50938 .28647 .52616 .30055 .55703 .29459 .5405 .27941 Metetra
.567 .792 .984 r
.5405 .27941 .55703 .29459 .58833 .28812 .57205 .27202 Metetra
.576 .786 .979 r
.57205 .27202 .58833 .28812 .62007 .28117 .60404 .26429 Metetra
.583 .782 .974 r
.60404 .26429 .62007 .28117 .65223 .27379 .63646 .25622 Metetra
.59 .778 .97 r
.63646 .25622 .65223 .27379 .68483 .266 .66932 .24782 Metetra
.595 .775 .966 r
.66932 .24782 .68483 .266 .71787 .25785 .70262 .2391 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.01 w
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -87.9375 -23.3395 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -87.486 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -74.0356 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -73.3059 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -72.5762 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 467.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001db000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfZ7oookJPWo001o/OoonfX00?oooo]ZQooonfX9
o`00Ok7ooo]Z003ooookJXOooo]Z1?l007nfoookJP00oooonfZ8oookJPCo001o]OoonfX00?oooo]Z
ROoonfX5o`00Ok?ooo]Z003ooookJX_ooo]Z1?l007nboookJP00oooonfZ<oookJP?o001o/_oonfX0
0?oooo]ZSOoonfX3o`00Ok7ooo]Z003ooookJXOooo]Z0ol007l3oookJP?o001o/OoonfX00?oooo]Z
QooonfX3o`00O`?ooo]Z0ol007lIoookJPWo001oSooonfX00?oooo]ZQooonfX4o`00O`;ooo]Z0ol0
07lIoookJPWo001oSooonfX00?oooo]ZR?oonfX7o`00Oa[ooo]Z1?l007nDoookJP00oooonfZ9oook
JPGo001o4?oonfX:o`00O`;ooo]Z1?l007nCoookJP00oooonfZNoookJP[o001o0ooonfX5o`00Oi7o
oo]Z003ooookJZgooo]Z1?l007n@oookJP00oooonfZ^oookJP?o001oT?oonfX00?oooo]Z[ooonfX3
o`00Ohoooo]Z003ooookJY7ooo]Z1_l0000BoookJP?o001o0ooonfX3o`00Ohoooo]Z003ooookJXko
oo]Z2Ol0000BoookJP?o001o0ooonfX3o`00Ohoooo]Z003ooookJXcooo]Z3?l0000AoookJPCo001o
0_oonfX3o`00Ohoooo]Z003ooookJXWooo]Z4?l0000AoookJPOo001oT?oonfX00?oooo]ZQooonfXB
o`0001;ooo]Z1Ol007nAoookJP00oooonfZ4oookJQKo0000YooonfX00?oooo]ZP_oonfX@o`000003
oookJ_l0003o000000Ko0000Y_oonfX00?oooo]ZOooonfXAo`0000Cooo]Z1ol0002VoookJP00oooo
nfYloookJQ7o00001ooonfX8o`000:Gooo]Z003ooookJW[ooo]Z4Ol00009oookJPWo0000Y?oonfX0
0?oooo]ZMooonfXAo`0000cooo]Z00?o0000oookJ_l000001_l0002ToookJP00oooonfYeoookJQ7o
00003ooonfX9o`000:?ooo]Z003ooookJW;ooo]Z4Ol0000BoookJP03o`000?oonf[o000000Oo0000
X_oonfX00?oooo]ZL?oonfX@o`0001Gooo]Z00?o0000oookJ_oonfX01ol0002RoookJP00oooonfY]
oookJQ7o00005ooonfX00ol0003ooo]ZoookJP08o`000:7ooo]Z003ooookJV_ooo]Z4?l0000Joook
JP04o`000?oonf[ooo]ZoookJPOo0000XOoonfX00?oooo]ZJ?oonfXAo`0001cooo]Z00?o0000oook
J_oonfX00_oonfX7o`000:3ooo]Z003ooookJVKooo]Z4?l0000OoookJP03o`000?oonf[ooo]Z00;o
oo]Z2?l0002OoookJP00oooonfYSoookJQ7o00008OoonfX00ol0003ooo]ZoookJP03oookJPOo0000
WooonfX00?oooo]ZHOoonfX@o`0002Cooo]Z00?o0000oookJ_oonfX00ooonfX8o`0009kooo]Z003o
oookJR[ooo]Z0ol007laoookJQ7o00009_oonfX00ol0003ooo]ZoookJP04oookJPSo0000WOoonfX0
0?oooo]Z:_oonfX3o`00Obkooo]Z4Ol0000YoookJP03o`000?oonf[ooo]Z00Gooo]Z1ol0002Moook
JP00oooonfXZoookJP?o001o;?oonfXAo`0002_ooo]Z00?o0000oookJ_oonfX01OoonfX8o`0009co
oo]Z003ooookJR[ooo]Z0ol007lYoookJQ7o0000;_oonfX00ol0003ooo]ZoookJP06oookJPSo0000
VooonfX00?oooo]Z:_oonfX3o`00ObOooo]Z4Ol0000`oookJP03o`000?oonf[ooo]Z00Oooo]Z1ol0
002KoookJP00oooonfXZoookJP?o001o9?oonfXAo`0003?ooo]Z00?o0000oookJ_oonfX01ooonfX8
o`0009[ooo]Z003ooookJR[ooo]Z0ol007lRoookJQ3o0000=_oonfX00ol0003ooo]ZoookJP08oook
JPSo0000VOoonfX00?oooo]Z:_oonfX3o`00Oaoooo]Z4Ol0000hoookJP03o`000?oonf[ooo]Z00Wo
oo]Z1ol0002IoookJP00oooonfXZoookJP?o001o7OoonfX@o`0003cooo]Z00?o0000oookJ_oonfX0
2?oonfX8o`0009Sooo]Z003ooookJROooo]Z1_l007lJoookJQ7o0000?_oonfX00ol0003ooo]Zoook
JP09oookJPSo0000UooonfX00?oooo]Z9ooonfX6o`00OaSooo]Z4?l00011oookJP03o`000?oonf[o
oo]Z00[ooo]Z1ol0002GoookJP00oooonfXYoookJPCo001o5OoonfXAo`0004?ooo]Z00?o0000oook
J_oonfX02_oonfX8o`0009Kooo]Z003ooookJR[ooo]Z0ol007lCoookJQ3o0000A_oonfX00ol0003o
oo]ZoookJP0;oookJPSo0000UOoonfX00?oooo]Z?OoonfXAo`0004Sooo]Z00?o0000oookJ_oonfX0
3?oonfX7o`0009Gooo]Z003ooookJS[ooo]Z4Ol0001;oookJP03o`000?oonf[ooo]Z00cooo]Z2?l0
002DoookJP00oooonfXhoookJQ7o0000COoonfX00ol0003ooo]ZoookJP0=oookJPSo0000TooonfX0
0?oooo]Z=OoonfXAo`00053ooo]Z00?o0000oookJ_oonfX03_oonfX7o`0009?ooo]Z003ooookJS?o
oo]Z4Ol0001BoookJP03o`000?oonf[ooo]Z00kooo]Z2?l0002BoookJP00oooonfX`oookJQ7o0000
EOoonfX00ol0003ooo]ZoookJP0?oookJPSo0000TOoonfX00?oooo]Z;_oonfX@o`0005Sooo]Z00?o
0000oookJ_oonfX04?oonfX7o`00097ooo]Z003ooookJR_ooo]Z4Ol0001JoookJP03o`000?oonf[o
oo]Z013ooo]Z2?l0002@oookJP00oooonfXYoookJQ3o0000GOoonfX00ol0003ooo]ZoookJP0Aoook
JPOo0000T?oonfX00?oooo]Z9_oonfXAo`0005oooo]Z00?o0000oookJ_oonfX04_oonfX7o`0008oo
oo]Z003ooookJRCooo]Z4?l00002oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0
4_oonfX8o`0008kooo]Z003ooookJR7ooo]Z4Ol0001UoookJP03o`000?oonf[ooo]Z01;ooo]Z1ol0
002>oookJP00oooonfXOoookJQ3o0000J?oonfX00ol0003ooo]ZoookJP0BoookJPSo0000SOoonfX0
0?oooo]Z7?oonfXAo`0006[ooo]Z00?o0000oookJ_oonfX04ooonfX8o`0008cooo]Z003ooookJQ[o
oo]Z4?l0001]oookJP03o`000?oonf[ooo]Z01Cooo]Z1ol0002<oookJP00oooonfXGoookJQ7o0000
KooonfX00ol0003ooo]ZoookJP0DoookJPSo0000RooonfX00?oooo]Z5?oonfXAo`0007;ooo]Z00?o
0000oookJ_oonfX05OoonfX8o`0008[ooo]Z003ooookJQ;ooo]Z4Ol0001doookJP03o`000?oonf[o
oo]Z01Kooo]Z1ol0002:oookJP00oooonfX?oookJQ7o0000MooonfX00ol0003ooo]ZoookJP0Foook
JPSo0000ROoonfX00?oooo]Z3OoonfXAo`0007Wooo]Z00?o0000oookJ_oonfX05ooonfX8o`0008So
oo]Z003ooookJP[ooo]Z4Ol0001loookJP03o`000?oonf[ooo]Z01Sooo]Z1ol00028oookJP00oooo
nfX8oookJQ3o0000OooonfX00ol0003ooo]ZoookJP0HoookJPSo0000QooonfX00?oooo]Z1OoonfXA
o`00087ooo]Z00?o0000oookJ_oonfX06OoonfX8o`0008Kooo]Z003<oookJPGo001o<OoonfX@o`00
08Cooo]Z00?o0000oookJ_oonfX06_oonfX7o`0008Kooo]Z003;oookJPOo001o;OoonfXAo`0008Ko
oo]Z00?o0000oookJ_oonfX06_oonfX8o`0008Gooo]Z003;oookJP?o001o00Cooo]Zo`00Ool007oo
001o:ooonfX@o`0008Wooo]Z00?o0000oookJ_oonfX06ooonfX8o`0008Cooo]Z003:oookJP?o001o
0ooonfX3o`00ObOooo]Z4Ol0002;oookJP03o`000?oonf[ooo]Z01cooo]Z1ol00024oookJP00b_oo
nfX3o`00O`?ooo]Z0ol007lUoookJQ3o0000S_oonfX00ol0003ooo]ZoookJP0LoookJPSo00007?oo
nfX3o`00OfCooo]Z003:oookJP?o001o0ooonfX3o`00Ob;ooo]Z4Ol0002AoookJP03o`000?oonf[o
oo]Z01cooo]Z2?l0000KoookJP?o001oI?oonfX00<[ooo]Z0ol007l3oookJP?o001o7ooonfXAo`00
09Cooo]Z00?o0000oookJ_oonfX07OoonfX7o`0001_ooo]Z0ol007mToookJP00b_oonfX3o`00O`?o
oo]Z0ol007lMoookJQ7o0000U_oonfX00ol0003ooo]ZoookJP0MoookJPSo00002_oonfX:o`00O`Ko
oo]Z0ol007mToookJP00b_oonfX3o`00O`?ooo]Z0ol007lJoookJQ7o0000VOoonfX00ol0003ooo]Z
oookJP0NoookJPSo00002OoonfX:o`00O`Kooo]Z0ol007mToookJP00b_oonfX3o`00O`?ooo]Z0ol0
07lHoookJQ7o0000VooonfX00ol0003ooo]ZoookJP0OoookJPOo00006OoonfX3o`00OfCooo]Z003;
oookJP?o001o00Cooo]Zo`00Ool007oo001o5_oonfXAo`0009kooo]Z00?o0000oookJ_oonfX07ooo
nfX8o`0001Sooo]Z0ol007mToookJP00booonfX7o`00OaCooo]Z4?l0002QoookJP03o`000?oonf[o
oo]Z023ooo]Z1ol0000HoookJP?o001oI?oonfX00<cooo]Z1Ol007lBoookJQ7o0000XooonfX00ol0
003ooo]ZoookJP0QoookJPOo00005ooonfX3o`00OfCooo]Z003QoookJQ3o0000Y_oonfX00ol0003o
oo]ZoookJP0QoookJPSo00004ooonfX6o`00OfCooo]Z003NoookJQ7o0000Z?oonfX00ol0003ooo]Z
oookJP0RoookJPOo00004ooonfX6o`00OfCooo]Z003LoookJQ3o0000ZooonfX00ol0003ooo]Zoook
JP0RoookJPSo00005?oonfX4o`00OfCooo]Z003IoookJQ7o0000[OoonfX00ol0003ooo]ZoookJP0S
oookJPSo00005?oonfX3o`00OfCooo]Z003GoookJQ3o0000/?oonfX00ol0003ooo]ZoookJP0Toook
JPOo0000NooonfX00=Cooo]Z4Ol0002boookJP03o`000?oonf[ooo]Z02Cooo]Z2?l0001joookJP00
d_oonfX@o`000;Gooo]Z00?o0000oookJ_oonfX09OoonfX8o`0007Wooo]Z003?oookJQ7o0000]ooo
nfX00ol0003ooo]ZoookJP0VoookJPOo0000NOoonfX00<cooo]Z4Ol0002koookJP03o`000?oonf[o
oo]Z02Gooo]Z2?l0001hoookJP00b_oonfXAo`000003oookJ_l0003ooo]Z0;[ooo]Z00?o0000oook
J_oonfX09_oonfX8o`0007Oooo]Z0037oookJQ7o0000`?oonfX00ol0003ooo]ZoookJP0WoookJPOo
0000MooonfX00<Gooo]Z4Ol00032oookJP03o`000?oonf[ooo]Z02Oooo]Z2?l0001foookJP00`_oo
nfXAo`000<Gooo]Z00?o0000oookJ_oonfX0:?oonfX8o`0007Gooo]Z0030oookJQ3o0000b?oonfX0
0ol0003ooo]ZoookJP0YoookJPOo0000MOoonfX00;gooo]Z4Ol0003:oookJP03o`000?oonf[ooo]Z
02Wooo]Z2?l0001doookJP00^ooonfX@o`000<gooo]Z00?o0000oookJ_oonfX0:_oonfX8o`0007?o
oo]Z002hoookJQ7o0000cooonfX00ol0003ooo]ZoookJP0[oookJPOo0000LooonfX00;Kooo]Z4?l0
003BoookJP03o`000?oonf[ooo]Z02_ooo]Z2?l0001boookJP00/ooonfXAo`000=Cooo]Z00?o0000
oookJ_oonfX0;?oonfX8o`00077ooo]Z002aoookJQ3o0000eooonfX00ol0003ooo]ZoookJP0]oook
JPOo0000LOoonfX007Sooo]Z0ol007lcoookJQ7o0000fOoonfX00ol0003ooo]ZoookJP0]oookJPSo
0000L?oonfX007Sooo]Z0ol007l`oookJQ7o0000g?oonfX00ol0003ooo]ZoookJP0^oookJPSo0000
KooonfX007Sooo]Z0ol007l^oookJQ7o0000g_oonfX00ol0003ooo]ZoookJP0_oookJPOo0000Kooo
nfX006Sooo]Z2_l007l6oookJP?o001o:ooonfXAo`000>7ooo]Z00?o0000oookJ_oonfX0;ooonfX8
o`0006kooo]Z001XoookJP[o001o1_oonfX3o`00ObWooo]Z4Ol0003SoookJP03o`000?oonf[ooo]Z
033ooo]Z1ol0001^oookJP00N?oonfX3o`00ObKooo]Z4Ol0003WoookJP03o`000?oonf[ooo]Z033o
oo]Z1ol0001]oookJP00N?oonfX3o`00ObCooo]Z4?l0003ZoookJP03o`000?oonf[ooo]Z033ooo]Z
2?l0001/oookJP00N?oonfX3o`00Ob7ooo]Z4Ol0003/oookJP03o`000?oonf[ooo]Z037ooo]Z1ol0
001/oookJP00N?oonfX3o`00Oaoooo]Z4?l0003_oookJP03o`000?oonf[ooo]Z037ooo]Z2?l0001[
oookJP00MOoonfX6o`00Oacooo]Z4Ol0003aoookJP03o`000?oonf[ooo]Z03;ooo]Z2?l0001Zoook
JP00MOoonfX6o`00Oa[ooo]Z4?l0003doookJP03o`000?oonf[ooo]Z03?ooo]Z1ol0001ZoookJP00
MooonfX4o`00OaOooo]Z4Ol0003foookJP03o`000?oonf[ooo]Z03?ooo]Z2?l0001YoookJP00N?oo
nfX3o`00OaGooo]Z4?l0003ioookJP03o`000?oonf[ooo]Z03Cooo]Z2?l0001XoookJP00SOoonfXA
o`000?_ooo]Z00?o0000oookJ_oonfX0=OoonfX7o`0006Sooo]Z002:oookJQ7o0000o_oonfX00ol0
003ooo]ZoookJP0eoookJPSo0000IooonfX008Sooo]Z4Ol0003ooookJP7ooo]Z00?o0000oookJ_oo
nfX0=_oonfX8o`0006Kooo]Z0025oookJQ7o0000oooonfX4oookJP03o`000?oonf[ooo]Z03Oooo]Z
1ol0001VoookJP00PooonfXAo`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0goookJPSo0000IOoo
nfX0083ooo]Z4Ol0003ooookJPWooo]Z00?o0000oookJ_oonfX0>?oonfX8o`0006Cooo]Z001noook
JQ3o0000oooonfX<oookJP03o`000?oonf[ooo]Z03Wooo]Z1ol0001ToookJP00NooonfXAo`000?oo
oo]Z3_oonfX00ol0003ooo]ZoookJP0ioookJPSo0000HooonfX007Wooo]Z4?l0003ooookJQ;ooo]Z
00?o0000oookJ_oonfX0>OoonfX8o`0006;ooo]Z001foookJQ;o0000oooonfXCoookJP03o`000?oo
nf[ooo]Z03[ooo]Z1ol0001RoookJP00M?oonfX@o`000?oooo]Z5ooonfX00ol0003ooo]ZoookJP0j
oookJPSo0000HOoonfX0077ooo]Z4Ol0003ooookJQWooo]Z00?o0000oookJ_oonfX0>ooonfX8o`00
063ooo]Z001_oookJQ3o0000oooonfXLoookJP03o`000?oonf[ooo]Z03cooo]Z1ol0001PoookJP00
K?oonfXAo`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP0loookJPSo0000GooonfX006[ooo]Z4?l0
003ooookJR7ooo]Z00?o0000oookJ_oonfX0?OoonfX8o`0005kooo]Z001WoookJQ7o0000oooonfXS
oookJP03o`000?oonf[ooo]Z03kooo]Z1ol0001NoookJP00I?oonfXAo`000?oooo]Z9_oonfX00ol0
003ooo]ZoookJP0noookJPSo0000GOoonfX006;ooo]Z4Ol0003ooookJRSooo]Z00?o0000oookJ_oo
nfX0?ooonfX7o`0005gooo]Z001OoookJQ7o0000oooonfX[oookJP03o`000?oonf[ooo]Z043ooo]Z
1ol0000=oookJPGo001oB_oonfX002Cooo]Z2Ol007l`oookJQ7o0000oooonfX]oookJP03o`000?oo
nf[ooo]Z043ooo]Z2?l0000;oookJPOo001oBOoonfX002Cooo]Z2Ol007l]oookJQ7o0000oooonfX`
oookJP03o`000?oonf[ooo]Z047ooo]Z1ol0000;oookJP?o001o00Cooo]Zo`00Ool007oo001oBOoo
nfX002Cooo]Z1?l007l`oookJQ3o0000oooonfXcoookJP03o`000?oonf[ooo]Z047ooo]Z2?l00009
oookJP?o001o0ooonfX3o`00OdSooo]Z000HoookJP[o001o0ooonfX4o`00Obcooo]Z4Ol0003ooook
JSGooo]Z00?o0000oookJ_oonfX0@_oonfX8o`0000Sooo]Z0ol007l3oookJP?o001oB?oonfX001So
oo]Z2_l007l4oookJPGo001o:?oonfX@o`000:7ooo]Z1_l0002@oookJP03o`000?oonf[ooo]Z04?o
oo]Z1ol00008oookJP?o001o0ooonfX3o`00OdSooo]Z000XoookJPCo001o9?oonfXAo`000:;ooo]Z
00?o0000od80>ol000001?n4;5<7o`0008Wooo]Z00?o0000oookJ_oonfX0@ooonfX8o`0000Oooo]Z
0ol007l3oookJP?o001oB?oonfX002Wooo]Z0ol007lRoookJQ3o0000Y?oonfX01?l0003o@P0kod80
>ol0000;oh@/D`Co0000Q_oonfX00ol0003ooo]ZoookJP13oookJPSo00001_oonfX3o`00O`?ooo]Z
0ol007m8oookJP00:_oonfX3o`00Oakooo]Z4Ol0002UoookJP04o`000?m203_o@P0ko`0000koQ2aC
00?o0000onAh:Ol000000_l00023oookJP03o`000?oonf[ooo]Z04Cooo]Z1ol00006oookJP?o001o
0ooonfX3o`00OdSooo]Z000ToookJP?o001o0ooonfX3o`00Oacooo]Z4?l0002VoookJP;o00000om2
03/00ol0003oQ2aCoh@/D`0<oh@/D`;o00000ooTN2T3o`00083ooo]Z00?o0000oookJ_oonfX0A?oo
nfX8o`0000Gooo]Z0ol007l3oookJP?o001oB?oonfX002Cooo]Z0ol007l3oookJP?o001o6OoonfXA
o`000:Oooo]Z00?o0000od80>om203/00om203/00ol0003oQ2aCoh@/D`0;oh@/D`03o`000?nE?U_o
000000Koi7PY00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP15oookJPSo00001OoonfX3
o`00O`04oookJ_l007oo001oo`00OdWooo]Z000ToookJPCo001o0_oonfX3o`00OaKooo]Z4Ol0002Y
oookJP03o`000?m203_o@P0k00?o@P0k00?o0000oh@/Don4;5<03?n4;5<00ol0003oUCiKo`000006
onAh:@03o`000?oonf[ooo]Z07[ooo]Z1?l00017oookJPSo00001OoonfX7o`00OdWooo]Z000Uoook
JPOo001o5OoonfXAo`000:[ooo]Z00?o0000od80>om203/01?m203/00ol0003oQ2aCoh@/D`0<oh@/
D`04o`000?nE?U_oUCiKo`0000Koi7PY00?o0000oookJ_oonfX0M_oonfX3o`0000;oV<Kg0_l00018
oookJPSo00001OoonfX5o`00Od[ooo]Z000VoookJPGo001o4ooonfXAo`000:_ooo]Z0_l00007od80
>`03o`000?n4;5?oQ2aC00_oQ2aC00Go0000oiDnFonE?U_oUCiKo`000006onAh:@;o0000LooonfX4
o`0000KoV<Kg00?o0000oookJ_oonfX0AooonfX8o`0005?ooo]Z000loookJQ7o0000[?oonfX00ol0
003o@P0kod80>`06od80>`03o`000?n4;5?oQ2aC00coQ2aC00Go0000oiDnFonE?U_oUCiKo`000007
onAh:@;o0000KooonfX3o`0000WoV<Kg0ol00019oookJPOo0000DooonfX003Wooo]Z4Ol0002^oook
JP03o`000?m203_o@P0k00Oo@P0k00?o0000oh@/Don4;5<03?n4;5<00ol0003oUCiKoiDnF`02oiDn
F`03o`000?oTN2Woi7PY00Coi7PY0_l0001/oookJP?o00002OnHa_L3o`000004oiS6mol0003oV<Kg
o`0004Sooo]Z2?l0001BoookJP00=ooonfX@o`000;3ooo]Z00?o0000od80>om203/02?m203/00ol0
003oQ2aCoh@/D`0;oh@/D`03o`000?nE?U_oUCiK00?oUCiK00?o0000onAh:OoTN2T01?oTN2T00ol0
003oe6L0o`00001WoookJPCo00002OnHa_L3o`0000GoV<Kg00?o0000oiS6mol00000B?oonfX8o`00
057ooo]Z000doookJQ7o0000/OoonfX00ol0003o@P0kod80>`08od80>`03o`000?n4;5?oQ2aC00co
Q2aC00?o0000oiDnFonE?U/00onE?U/00ol0003oi7PYonAh:@05onAh:@03o`000?oDI`3o0000067o
oo]Z1Ol00002oiO7n003o`000?nHa_OoV<Kg00GoV<Kg0ol00009oiS6m`03o`000?nHa_Oo000004So
oo]Z1ol0001AoookJP00<ooonfX?o`000;Cooo]Z00?o0000od80>om203/02?m203/00ol0003oQ2aC
oh@/D`0<oh@/D`03o`000?nE?U_oUCiK00CoUCiK00?o0000onAh:OoTN2T01?oTN2T00ol0003oe6L0
o`00001MoookJPCo00002?nGaoP01?l0003oV<KgoiS6monHa_L3o`0000goV<Kg00?o0000oiS6mol0
0000AooonfX8o`00053ooo]Z000coookJPgo0000]OoonfX2o`0000[o@P0k00?o0000oh@/Don4;5<0
3?n4;5<00ol0003oUCiKoiDnF`04oiDnF`03o`000?oTN2Woi7PY00Goi7PY00?o0000omAW0?l00000
EooonfX5o`0000goUlOh0ol0000@oiS6m`04o`000?nHa_OoV<Kgo`0004Oooo]Z2?l0001?oookJP00
<ooonfX:o`000;Sooo]Z00?o0000od80>om203/02?m203/00ol0003oQ2aCoh@/D`0<oh@/D`03o`00
0?nE?U_oUCiK00KoUCiK00?o0000onAh:OoTN2T01?oTN2T01?l0003oe6L0omAW0?l0001BoookJPCo
00003onGaoP3o`000003oiO7n?l0003oV<Kg017oV<Kg00Co0000oiS6monHa_Oo0000AooonfX7o`00
04oooo]Z000coookJPSo0000^_oonfX00ol0003o@P0kod80>`08od80>`03o`000?n4;5?oQ2aC00co
Q2aC00?o0000oiDnFonE?U/01_nE?U/00ol0003oi7PYonAh:@05onAh:@04o`000?oDI`3oe6L0o`00
04cooo]Z1Ol00002oiG8n@03o`000?nGaoSoUlOh00coUlOh0_l00005oiO7n003o`000?nHa_OoV<Kg
013oV<Kg1?l00016oookJPSo0000C_oonfX003;ooo]Z1ol0002koookJP;o00002_m203/00ol0003o
Q2aCoh@/D`0<oh@/D`03o`000?nE?U_oUCiK00KoUCiK00?o0000onAh:OoTN2T01OoTN2T01?l0003o
e6L0omAW0?l00018oookJPCo00002?nEb?T00ol0003oUlOhoiO7n008oiO7n0?o00002?nGaoP00ol0
003oV<KgoiS6m`0;oiS6m`Go00000_nFaOL00ol0003ooo]ZoookJP15oookJPOo0000C_oonfX003;o
oo]Z1_l000000ooonf[o0000oookJP2ioookJP03o`000?m203_o@P0k00Wo@P0k00?o0000oh@/Don4
;5<02on4;5<00ol0003oUCiKoiDnF`08oiDnF`03o`000?oTN2Woi7PY00Goi7PY00Co0000omAW0?oD
I`3o0000@_oonfX5o`0000goULSi00?o0000oiO7n?nGaoP01?nGaoP3o`0000coUlOh00?o0000oiS6
monHa_L01_nHa_L4o`0000GoU/Gg00Co0000oiK5monFaOOo0000AooonfX7o`0004gooo]Z000boook
JPKo00000_oonfX00ol0003ooo]ZoookJP2goookJP03o`000?m203_o@P0k00So@P0k00?o0000oh@/
Don4;5<03?n4;5<00ol0003oUCiKoiDnF`08oiDnF`03o`000?oTN2Woi7PY00Goi7PY00Co0000omAW
0?oDI`3o0000?_oonfX4o`0001?oULSi00?o0000oiO7n?nGaoP00ol0000@oiO7n003o`000?nHa_Oo
V<Kg00Go00002_nFaOL01?l0003oU/GgoiK5mol00016oookJPSo0000C?oonfX003;ooo]Z1_l00003
oookJP03o`000?oonf[ooo]Z0;Gooo]Z0_l0000:od80>`03o`000?n4;5?oQ2aC00coQ2aC00?o0000
oiDnFonE?U/02?nE?U/00ol0003oi7PYonAh:@06onAh:@03o`000?oDI`3o000003_ooo]Z0ol00002
oi?9nP03o`000?nEb?WoULSi01;oULSi0ol0000BoiO7n0Co00004?nFaOL01?l0003oU/GgoiK5mol0
0016oookJPOo0000C?oonfX003;ooo]Z1Ol00005oookJP03o`000?oonf[ooo]Z0;Cooo]Z00?o0000
od80>om203/02Om203/00ol0003oQ2aCoh@/D`0;oh@/D`03o`000?nE?U_oUCiK00[oUCiK00?o0000
onAh:OoTN2T01OoTN2T01?l0003oe6L0omAW0?l0000foookJPCo00001_nCbOX00ol0003oULSioiG8
n@0>oiG8n@?o000000?oULSio`000?nGaoP03onGaoP3o`0000;oU<Kh00?o0000oiK5monFaOL03onF
aOL01Ol0003oU/GgoiK5monFaOOo000004Gooo]Z2?l0001;oookJP00<_oonfX5o`0000Kooo]Z00?o
0000oookJ_oonfX0/ooonfX00ol0003o@P0kod80>`08od80>`03o`000?n4;5?oQ2aC00coQ2aC00?o
0000oiDnFonE?U/02_nE?U/00ol0003oi7PYonAh:@05onAh:@04o`000?oDI`3oe6L0o`0003?ooo]Z
0ol0000;oi?9nP03o`000?nEb?WoULSi00[oULSi0ol00005oiG8n@03o`000?nGaoSoUlOh00WoUlOh
1?l00006oiC6n003o`000?nFaOOoU/Gg00ooU/Gg00Co0000oiK5monFaOOo0000A_oonfX8o`0004[o
oo]Z000aoookJPKo00001ooonfX00ol0003ooo]ZoookJP2aoookJP;o00002_m203/00ol0003oQ2aC
oh@/D`0<oh@/D`03o`000?nE?U_oUCiK00[oUCiK00?o0000onAh:OoTN2T01_oTN2T01?l0003oe6L0
omAW0?l0000_oookJP?o00003onCbOX00ol0003oULSioiG8n@06oiG8n@?o00002OnEb?T00ol0003o
UlOhoiO7n004oiO7n0Co00002onDa_P00ol0003oU/GgoiK5m`0?oiK5m`04o`000?nFaOOoU/Ggo`00
04Kooo]Z1ol0001:oookJP00<OoonfX6o`0000Sooo]Z00?o0000oookJ_oonfX0/?oonfX2o`0000[o
@P0k00?o0000oh@/Don4;5<02on4;5<00ol0003oUCiKoiDnF`0<oiDnF`03o`000?oTN2Woi7PY00Go
i7PY00Co0000omAW0?oDI`3o0000:ooonfX4o`0001?oTlWj00?o0000oiG8nOnEb?T00onEb?T2o`00
00goULSi00?o0000oiO7n?nGaoP00ol0000@oiC6n003o`000?nFaOOoU/Gg00koU/Gg00Go0000oiK5
monFaOOoU/Ggo`000015oookJPSo0000BOoonfX0037ooo]Z1_l00009oookJP03o`000?oonf[ooo]Z
0:oooo]Z00?o0000od80>om203/02?m203/00ol0003oQ2aCoh@/D`0<oh@/D`03o`000?nE?U_oUCiK
00coUCiK00?o0000onAh:OoTN2T01_oTN2T00ol0003oe6L0o`00000WoookJPCo00001?nAb_/00ol0
003oTlWjoi?9nP0Aoi?9nP03o`000?nEb?Wo000000;o00003_nEb?T4o`0001CoU<Kh00?o0000oiK5
monFaOL03_nFaOL01Ol0003oU/GgoiK5monFaOOo000004Gooo]Z2?l00018oookJP00<OoonfX6o`00
00[ooo]Z00?o0000oookJ_oonfX0[OoonfX2o`0000[o@P0k00?o0000oh@/Don4;5<03?n4;5<00ol0
003oUCiKoiDnF`0<oiDnF`03o`000?oTN2Woi7PY00Koi7PY00Co0000omAW0?oDI`3o00008OoonfX5
o`0000WoTL[k00?o0000oi?9n_nCbOX03onCbOX3o`0000goULSi1?l00003oi;7n@03o`000?nDa_So
U<Kh01;oU<Kh00?o0000oiK5monFaOL03onFaOL00ol0003oU/Ggo`000002o`0004Gooo]Z1ol00018
oookJP00<OoonfX5o`0000cooo]Z00?o0000oookJ_oonfX0[?oonfX2o`0000[o@P0k00?o0000oh@/
Don4;5<03?n4;5<00ol0003oUCiKoiDnF`0=oiDnF`03o`000?oTN2Woi7PY00Koi7PY00?o0000omAW
0?l000007OoonfX4o`0000ooTL[k00?o0000oi?9n_nCbOX02onCbOX3o`0000?oTlWj00?o0000oiG8
nOnEb?T01OnEb?T5o`0000SoT/Oi00?o0000oiC6n?nDa_P04_nDa_P00ol0003oU/GgoiK5m`0;oiK5
m`Go00000_nDaOP00ol0003ooo]ZoookJP13oookJPSo0000AooonfX0037ooo]Z1_l0000<oookJP;o
0000[?oonfX00ol0003o@P0kod80>`08od80>`03o`000?n4;5?oQ2aC00coQ2aC00?o0000oiDnFonE
?U/03_nE?U/00ol0003oi7PYonAh:@06onAh:@04o`000?oDI`3oe6L0o`0001Oooo]Z1Ol0000Doi7:
n`03o`000?nCbO[oTlWj00OoTlWj0ol00007oi?9nP03o`000?nEb?WoULSi00Co00003_nBaoT00ol0
003oU<KhoiC6n00BoiC6n003o`000?nFaOOoU/Gg00KoU/Gg1?l00004oiC5n005o`000?nDaOSoU<Gh
oiC5n?l00000AOoonfX8o`0004Kooo]Z000aoookJPGo00003ooonfX00ol0003ooo]ZoookJP2Xoook
JP;o00002_m203/00ol0003oQ2aCoh@/D`0<oh@/D`03o`000?nE?U_oUCiK00ooUCiK00?o0000onAh
:OoTN2T01_oTN2T00ol0003oe6L0o`00000BoookJPGo00001On>c?d00ol0003oTL[koi7:n`0Boi7:
n`03o`000?nCbO[oTlWj00?oTlWj0ol00008oi?9nPGo00004onBaoT00ol0003oU<KhoiC6n00BoiC6
n003o`000?nFaOOoU/Gg00Go00002OnDaOP01Ol0003oU<GhoiC5n?nDaOSo000004Gooo]Z1ol00016
oookJP00<?oonfX6o`00013ooo]Z00?o0000oookJ_oonfX0YooonfX2o`0000[o@P0k00?o0000oh@/
Don4;5<03?n4;5<00ol0003oUCiKoiDnF`0?oiDnF`03o`000?oTN2Woi7PY00Koi7PY00?o0000omAW
0?l000003OoonfX5o`0000_oS/cm00?o0000oi7:nonAb_/04_nAb_/00ol0003oTlWjo`000002o`00
00GoTlWj1_l00004oi38n`03o`000?nBaoWoT/Oi01;oT/Oi00?o0000oiC6n?nDa_P04?nDa_P4o`00
00ooU<Gh00Go0000oiC5n?nDaOSoU<Gho`000014oookJPSo0000AOoonfX002;ooo]Z1Ol007l9oook
JPKo00004OoonfX00ol0003ooo]ZoookJP2VoookJP;o00002Om203/00ol0003oQ2aCoh@/D`0<oh@/
D`03o`000?nE?U_oUCiK013oUCiK00?o0000onAh:OoTN2T01ooTN2T00ol0003oe6L0o`000007oook
JPGo00004On>c?d00ol0003oTL[koi7:n`0Aoi7:n`;o00000onCbOX5o`0000_oT<Sk00?o0000oi;7
nOnBaoT04_nBaoT00ol0003oU<KhoiC6n00;oiC6n0Co00000_nBaOT00ol0003oU<GhoiC5n00?oiC5
n005o`000?nDaOSoU<GhoiC5n?l00000A?oonfX8o`0004Cooo]Z000QoookJPOo001o2?oonfX6o`00
01;ooo]Z00?o0000oookJ_oonfX0Y?oonfX2o`0000Wo@P0k1?l0000<oh@/D`03o`000?nE?U_oUCiK
017oUCiK00?o0000onAh:OoTN2T01_oTN2T00ol0003oe6L0o`000003oookJPCo00001?n:coh00ol0
003oS/cmohk<o@0@ohk<o@03o`000?nAb__oTL[k00goTL[k2?l0000Aoi38n`03o`000?nBaoWoT/Oi
01;oT/Oi00?o0000oiC6n?nDa_P01OnDa_P5o`0000OoT/Gi00?o0000oiC5n?nDaOP03_nDaOP01Ol0
003oU<GhoiC5n?nDaOSo000004Gooo]Z1ol00014oookJP008?oonfX4o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z1_l0000CoookJP03o`000?oonf[ooo]Z0:?ooo]Z0_l00008od80>`03o`000?lH003o
000000;oHP0X1Ol00007oh@/D`03o`000?nE?U_oUCiK017oUCiK00?o0000onAh:OoTN2T01_oTN2T6
o`0000WoR/on00?o0000ohk<oOn>c?d04?n>c?d00ol0003oTL[koi7:n`09oi7:n`Ko00000on<bO`0
0ol0003oT<Skoi38n`0Aoi38n`03o`000?nBaoWoT/Oi01;oT/Oi00?o0000oiC6n?nDa_P01?l0000=
oi;5n@03o`000?nDaOSoU<Gh00koU<Gh00Go0000oiC5n?nDaOSoU<Gho`000014oookJPSo0000@ooo
nfX001Cooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000EoookJP03o`000?oonf[o
oo]Z0:;ooo]Z0_l00007od80>`03o`000?lH003o000000SoHP0X1Ol000000on4;5?o0000oiDnF`0C
oiDnF`03o`000?oTN2Woi7PY00?oi7PY1?l0000?oh[?oP03o`000?n>c?goS/cm013oS/cm00?o0000
oi7:nonAb_/01OnAb_/5o`0000SoS<Wl00?o0000oi38non@b?/04On@b?/00ol0003oT/Oioi;7n@0?
oi;7n@Go00004_nBaOT00ol0003oU<GhoiC5n00>oiC5n005o`000?nDaOSoU<GhoiC5n?l00000A?oo
nfX8o`0004;ooo]Z000DoookJP[o001o2?oonfX3o`00O`Oooo]Z1Ol0000FoookJP03o`000?oonf[o
oo]Z0:3ooo]Z0_l00007od80>`04o`000?lH003o6000o`0000goHP0X0ol0000DoiDnF`Go00005?n:
coh00ol0003oS/cmohk<o@0@ohk<o@03o`000?nAb__oTL[k00Co00003_n<bO`00ol0003oT<Skoi38
n`0Aoi38n`03o`000?nBaoWoT/Oi00SoT/Oi1_l00003oho6nP03o`000?nBaOWoT/Gi01;oT/Gi00?o
0000oiC5n?nDaOP03OnDaOP00ol0003oU<GhoiC5n003o`0004Cooo]Z1ol00012oookJP009_oonfX3
o`00O`Kooo]Z1_l0000GoookJP03o`000?oonf[ooo]Z09oooo]Z0_l00006od80>`04o`000?lH003o
6000o`0000ooHP0X00?o0000og406?l000004?nE?U/4o`0000CoQ];o00?o0000oh[?o_n:coh04_n:
coh00ol0003oS/cmohk<o@0=ohk<o@Ko00004_n<bO`00ol0003oT<Skoi38n`0Aoi38n`04o`000?nB
aoWoT/Oioi;7n@Ko00002_n?a_X00ol0003oT/Gioi;5n@0Boi;5n@03o`000?nDaOSoU<Gh00_oU<Gh
1?l00002oi;4n003o`000?oonf[ooo]Z04;ooo]Z2?l00011oookJP008OoonfX2o`00O`;ooo]Z1?l0
07l6oookJPKo00006?oonfX00ol0003ooo]ZoookJP2MoookJP03o`000?o?mjGo000000Go@P0k00Go
0000oaP00?lH003o6000o`00000>of80:005o`000?ma01SoL@0Hog406?l000002onE?U/4o`0000Wo
Q];o00?o0000oh[?o_n:coh04_n:coh00ol0003oS/cmohk<o@07ohk<o@So00000_n7boh00ol0003o
S<Wlohc9o00Aohc9o003o`000?n@b?_oT<Sk00ooT<Sk1Ol0000Aoho6nP03o`000?nBaOWoT/Gi01;o
T/Gi00?o0000oiC5n?nDaOP01OnDaOP5o`0000?oT/Ch00Go0000oi;4n?nBa?SoT/Cho`000014oook
JPSo0000@?oonfX0027ooo]Z1ol007l7oookJPKo00006OoonfX00ol0003ooo]ZoookJP2LoookJP;o
00001Om203/01Ol0003o6000oaP00?lH003o000000koHP0X00?o0000og406?ma01P00oma01P00ol0
003oUCiKoiDnF`04oiDnF`Co00003_n6d_l2o`0001?oR/on00Co0000ohk<oOn>c?goS/cm1Ol00003
ohO;oP;o00001_n7boh00ol0003oS<Wlohc9o00Aohc9o003o`000?n@b?_oT<Sk00[oT<Sk1?l00003
ohc7n`03o`000?n?a_[oSlKj017oSlKj00?o0000oi;5nOnBaOT04_nBaOT00ol0003oU<GhoiC5n004
o`0000WoT/Ch00Go0000oi;4n?nBa?SoT/Cho`000014oookJPOo0000@?oonfX0027ooo]Z1_l007l8
oookJPKo00006_oonfX00ol0003ooo]ZoookJP2KoookJP;o00001?m203/00ol0003o6000oaP00002
oaP00003o`000?mR02SoHP0X00_oHP0X00?o0000og406?ma01P01Oma01P6o`0001CoQ];o00?o0000
oh[?o_n:coh03_n:coh6o`0000GoQl_n0ol00009ohO;oP03o`000?n<bOcoS<Wl017oS<Wl00?o0000
oi38non@b?/01On@b?/4o`0000SoS<Ok00?o0000oho6n_n?a_X04On?a_X00ol0003oT/Gioi;5n@0@
oi;5n@Co00003OnBa?P00ol0003oT/Choi;4n002oi;4n003o`000?oonf[ooo]Z047ooo]Z2?l0000o
oookJP008OoonfX2o`00O`cooo]Z1Ol0000LoookJP03o`000?oonf[ooo]Z09Wooo]Z00?o0000olog
YOl000000om203/00ol0003o6000oaP00002oaP00003o`000?mR02SoHP0X00coHP0X00Co0000og40
6?ma01SoL@0H1Ol00005oh7Fo`03o`000?n6d_ooQ];o01;oQ];o00?o0000oh[?o_n:coh01on:coh6
o`0000GoP<go00?o0000ohO;o_n7boh00ol0000=ohO;oP03o`000?n<bOcoS<Wl017oS<Wl00?o0000
oi38non@b?/01?l0000=ohc7n`03o`000?n?a_[oSlKj017oSlKj00?o0000oi;5nOnBaOT02onBaOT4
o`0000;oT<Ci00?o0000oi;4n?nBa?P03OnBa?P00ol0003oT/Choi;4n002oi;4n003o`000?oonf[o
oo]Z047ooo]Z2?l0000noookJP008OoonfX2o`00O`cooo]Z1Ol0000MoookJP;o0000VOoonfX00ol0
003ocoNUo`000002od80>`03o`000?lH003o600000?o600000?o0000of80:?mR02P02omR02P5o`00
00_oPMKo0_l0000CohKBo`04o`000?n:cokoR/onoh[?oPGo00002on0cOl3o`00017oQl_n00?o0000
ohc9o?n<bO`03_n<bO`5o`0001;oS<Ok00?o0000oho6n_n?a_X04On?a_X00ol0003oT/Gioi;5n@05
oi;5n@Go00001on@a?T00ol0003oT/Choi;4n00=oi;4n005o`000?nBa?SoT/Choi;4n?l00000A?oo
nfX7o`0003kooo]Z000RoookJPOo001o1OoonfX6o`0001oooo]Z00?o0000oookJ_oonfX0U_oonfX2
o`0000;o@P0k00?o0000oaP00?lH00000olH00000ol0003oHP0Xof80:007of80:0Go00004_n1e_l0
0ol0003oQ];oohKBo`0>ohKBo`Ko00003On0cOl3o`0000;oP<go00?o0000ohO;o_n7boh04?n7boh0
0ol0003oS<Wlohc9o007ohc9o0Ko00001?n7aod00ol0003oS<Okohc7n`0Aohc7n`03o`000?n?a_[o
SlKj017oSlKj00?o0000oi;5nOnBaOT01?l0000=oi34n@03o`000?nBa?SoT/Ch00coT/Ch00?o0000
oi;4n?nBa?P00_nBa?P00ol0003ooo]ZoookJP11oookJPSo0000?OoonfX002;ooo]Z1ol007l5oook
JPKo00008?oonfX00ol0003ooo]ZoookJP2DoookJP05o`000?o?mjGo0000od80>ol000001_lH0000
0ol0003oHP0Xof80:003of80:0Co00001?mnf_d2o`0001;oPMKo0_l00009ohKBo`Go00001Omfcol0
0ol0003oP<gooh3=o`08oh3=o`?o00001_n0cOl00ol0003oQl_nohO;oP0@ohO;oP04o`000?n<bOco
S<Wlohc9o0Go00002on7aod00ol0003oS<Okohc7n`0Aohc7n`03o`000?n?a_[oSlKj00koSlKj1Ol0
000Boi34n@03o`000?nBa?SoT/Ch00coT/Ch00?o0000oi;4n?nBa?P00_nBa?P00ol0003ooo]Zoook
JP11oookJPOo0000?OoonfX002kooo]Z1_l0000QoookJP03o`000?oonf[ooo]Z09?ooo]Z00Co0000
ologYOl0003o00001_lH00000ol0003oHP0Xof80:004o`0000[oO][m0_l0000Boh7Fo`04o`000?n6
d_ooQ];oohKBo`Go00002omfcol2o`0000GoP<go0ol0000:oh3=o`03o`000?n7bokoQl_n00coQl_n
1ol0000AohO7o@03o`000?n<ao_oS<Ok017oS<Ok00?o0000oho6n_n?a_X01on?a_X6o`0000CoSLGj
00?o0000oi34nOn@a?T04On@a?T00ol0003oT/Choi;4n00<oi;4n003o`000?nBa?SoT/Ch00;oT/Ch
00?o0000oookJ_oonfX0@OoonfX7o`0003cooo]Z000^oookJPKo00008_oonfX00ol0003ooo]Zoook
JP2BoookJP?o00001_lH0004o`00013oO][m00?o0000oh7Foon1e_l03?n1e_l7o`0001;oM/oo00?o
0000oh3=ool000000_l0000>oh3=o`03o`000?n7bokoQl_n00;oQl_n2Ol00006ogo8oP03o`000?n7
aogoQlOm013oQlOm00?o0000ohc7non<ao/04On<ao/01?l0003oSlKjoho6n_n?a_X5o`0000_oSLGj
00?o0000oi34nOn@a?T04On@a?T00ol0003oT/Choi;4n00<oi;4n003o`000?nBa?So000000?o0000
@_oonfX8o`0003_ooo]Z000^oookJPGo00009?oonfX00ol0003ooo]ZoookJP2@oookJP03o`000?o?
mjGo000000?o60001?l0000EogkJo@;o00001?n1e_l8o`0000KoJ=3j0_l0000AogK?o`?o00003On0
cOl8o`00013oOlSn00?o0000ohO7oOn7aod04?n7aod00ol0003oS<Okohc7n`0>ohc7n`Ko00004On=
aOX00ol0003oT<Cioi34n@0Aoi34n@03o`000?nBa?SoT/Ch00OoT/Ch1_l00003oi73n003o`000?oo
nf[ooo]Z047ooo]Z1ol0000koookJP00;_oonfX5o`0002Gooo]Z00?o0000oookJ_oonfX0SooonfX0
0ol0003ocoNUo`000003o`0000CoPMkk0ol0000BogkJo@Ko00004?mXd?X2o`0000coM/oo0ol00003
ogK?o`03o`000?n0cOooP<go00;oP<go2?l00006og?9o`03o`000?mob?koOlSn013oOlSn00?o0000
ohO7oOn7aod04?n7aod00ol0003oS<Okohc7n`07ohc7n`Ko00001?n8aO`00ol0003oSLGjohg5nP0A
ohg5nP03o`000?n@a?WoT<Ci017oT<Ci00Co0000oi;4n?nBa?SoT/Ch1Ol00005oi73n003o`000?nA
`oSoTL?h00;oTL?h00?o0000oookJ_oonfX0@?oonfX8o`0003[ooo]Z000^oookJPGo00009_oonfX0
0ol0003ooo]ZoookJP2<oookJPCo00002on1g_/2o`0000_oO][m1Ol00004oeS?k@?o00004OmXd?X0
0ol0003oM/ooogK?o`06ogK?o`?o00000omfcol8o`0000ooLlWo00?o0000ogo8o_mob?h04?mob?h0
0ol0003oQlOmohO7o@0@ohO7o@04o`000?n<ao_oS<Okohc7n`Go00002on8aO`00ol0003oSLGjohg5
nP0Aohg5nP03o`000?n@a?WoT<Ci00koT<Ci1_l0000;oi73n003o`000?nA`oSoTL?h00;oTL?h00?o
0000oookJ_oonfX0@?oonfX8o`0003Wooo]Z000]oookJPKo00009ooonfX00ol0003ooo]ZoookJP27
oookJPCo00004On1g_/3o`0000?oO][m1Ol0000<oeS?k@;o00004?mXd?X2o`0000?oM/oo2Ol00006
oeg7n`03o`000?mcbOooLlWo00ooLlWo0_l0000Aogo8oP03o`000?n7aogoQlOm00coQlOm1ol0000A
ohS5o003o`000?n=aO[oSLGj017oSLGj00?o0000oi34nOn@a?T01on@a?T6o`0000?oS/Ci00?o0000
oi73n?nA`oP03?nA`oP00ol0003oTL?hoi73n002oi73n003o`000?oonf[ooo]Z043ooo]Z1ol0000i
oookJP00;OoonfX6o`0002Sooo]Z00?o0000oookJ_oonfX0PooonfX3o`0001KoPMkk1Ol0000CoeS?
k@?o00002?mXd?X;o`0000ooGLOk0_l0000Aog?9o`03o`000?mob?koOlSn00ooOlSn00?o0000ohO7
oOn7aod00_n7aod9o`0000GoPLGm00?o0000ohS5o?n8aO`04On8aO`00ol0003oSLGjohg5nP0Aohg5
nP04o`000?n@a?WoT<Cioi34n@Go00002_n>a?T00ol0003oTL?hoi73n00;oi73n003o`000?nA`oSo
TL?h00?oTL?h00?o0000oookJ_oonfX0?ooonfX8o`0000oooo]Z0ol007lVoookJP00;OoonfX6o`00
02Wooo]Z00?o0000oookJ_oonfX0OooonfX3o`0000?oR^Cj0ol0000?oh7Nn`Co00001OmAc]h5o`00
00WoF<o]4?l00004ocVji0?o00000_li^^@2o`00017oGLOk00?o0000og?9oomcbOl03omcbOl00ol0
003oOlSnogo8oP0;ogo8oPSo00003on1aOd00ol0003oR<GlohS5o00AohS5o003o`000?n=aO[oSLGj
00koSLGj1_l0000@ohk4n@03o`000?nA`oSoTL?h00_oTL?h00?o0000oi73n?nA`oP00onA`oP00ol0
003ooo]ZoookJP0ooookJPSo00003_oonfX3o`00ObKooo]Z000]oookJPKo0000:_oonfX00ol0003o
oo]ZoookJP1loookJP;o00002On:i?X2o`0000WoPMkk1?l0000;oe7>gPco00001_nGKj8:o`000004
ocVji?l0003o0000o`0000Oo>K[T0ol0000?oeg7n`;o00004?mcbOl00ol0003oOlSnogo8oP02ogo8
oPSo00001_mga?h00ol0003oPLGmoh75o@0?oh75o@03o`000?n8aOcoR<Gl017oR<Gl00?o0000ohg5
n_n=aOX01on=aOX6o`0000?oR/Ck00?o0000ohk4nOn>a?T04On>a?T00ol0003oTL?hoi73n00;oi73
n003o`000?nA`oSoTL?h00?oTL?h00?o0000oookJ_oonfX0?ooonfX7o`0000kooo]Z0ol007lVoook
JP00;OoonfX5o`0002cooo]Z00?o0000oookJ_oonfX0N?oonfX3o`0000goR^Cj0ol00002oh7Nn`Co
00002?mAc]h7o`0000[ogZbQ00?o0000oiM_X_nGKj803OnGKj8<o`0000Co>K[T0_l0000?oeg7n`03
o`000?mcbOooLlWo00KoLlWo3?l0000?ogO4oP03o`000?n1aOgoPLGm00ooPLGm00?o0000ohS5o?n8
aO`04On8aO`01?l0003oSLGjohg5n_n=aOX5o`0000[oR/Ck00?o0000ohk4nOn>a?T04On>a?T00ol0
003oTL?hoi73n00:oi73n003o`000?nA`oSoTL?h00CoTL?h00?o0000oookJ_oonfX0?_oonfX8o`00
00gooo]Z0ol007lVoookJP00;OoonfX6o`0002cooo]Z0_l0001foookJP;o00004On:i?X@o`0000Co
iKJU00?o0000omj/XOoN[:402_oN[:400ol0003oUfnRoiM_XP0;oiM_XP?o00001onCKjLRo`0000[o
I<7n00?o0000ogO4o_mga?h03omga?h2o`00013oPLGm00?o0000ohS5o?n8aO`03_n8aO`6o`00013o
R/Ck00?o0000ohk4nOn>a?T04?n>a?T00ol0003oTL?hoi73n00;oi73n004o`000?nA`oSoTL?hoi73
n0Co0000@?oonfX8o`0000cooo]Z0ol007lVoookJP00;?oonfX6o`0002oooo]Z00?o0000oookJ_oo
nfX0L?oonfX3o`0000ooR^Cj1?l00006of3Gg@Co00002OoU]ZD00ol0003ogZbQomj/X@0;omj/X@03
o`000?nGKj;oUfnR00SoUfnR0ol00002oiM_XP03o`000?nCKjOoTfnW00_oTfnW1?l00002o`2:]`;o
00003_lo]_800ol0003oI<7nofC1oP0>ofC1oP03o`000?mga?koMlCn013oMlCn00?o0000oh75oOn1
aOd03_n1aOd00ol0003oR<GlohS5o007ohS5o0Ko00001?n4`o`00ol0003oR/Ckoh[4n`0@oh[4n`03
o`000?n>a?WoS/Ci013oS/Ci00?o0000oi73n?nA`oP02?nA`oP6o`0000?oSl;i00?o0000oookJ_oo
nfX0?ooonfX7o`0000cooo]Z0ol007lVoookJP00;?oonfX6o`00033ooo]Z00?o0000oookJ_oonfX0
K?oonfX6o`0000coR^Cj0ol00007of3Gg@Co00003?oU]ZD00ol0003ogZbQomj/X@0;omj/X@03o`00
0?nGKj;oUfnR00GoUfnR0ol00005oiM_XP03o`000?nCKjOoTfnW00_oTfnW00Co0000o`X<ROl:38Wo
2Pb91ol0000<ocnflP03o`000?mT`OkoI<7n00koI<7n00?o0000ogO4o_mga?h04?mga?h00ol0003o
PLGmoh75o@0>oh75o@04o`000?n8aOcoR<GlohS5o0Go00002on4`o`00ol0003oR/Ckoh[4n`0@oh[4
n`03o`000?n>a?WoS/Ci013oS/Ci00Co0000oi73n?nA`oSoTL?h1_l00004oho2n@03o`000?n?`_Wo
Sl;i00?oSl;i00?o0000oookJ_oonfX0?_oonfX8o`0000_ooo]Z0ol007lVoookJP008OoonfX3o`00
O`Sooo]Z1_l0000aoookJP03o`000?oonf[ooo]Z06Sooo]Z0ol00006oiSXn`Go00000on:i?X4o`00
00KoH=OM1ol0000=onFfY@03o`000?oN[:7ogZbQ00cogZbQ00Co0000oiM_X_nGKj;oUfnR0ol00009
oiM_XP03o`000?nCKjOoTfnW00[oTfnW00?o0000o`X<ROl:38T01Ol:38T5o`0000_o?kKb0_l0000?
ofC1oP03o`000?mga?koMlCn013oMlCn00?o0000oh75oOn1aOd01_n1aOd;o`00017oQ<?l00?o0000
oh[4non:a?/03on:a?/00ol0003oS/Ciohk4n@0>ohk4n@Ko00002_n?`_T00ol0003oSl;ioho2n@04
oho2n@03o`000?oonf[ooo]Z03kooo]Z2?l0000:oookJP?o001o9_oonfX0027ooo]Z0ol007l8oook
JPKo0000<_oonfX00ol0003ooo]ZoookJP1ToookJP?o00003_nHj?/?o`0000Cok]Nk00?o0000onFf
YOoU]ZD02_oU]ZD00ol0003ogZbQomj/X@0=omj/X@Co00003?nGKj800ol0003oTfnWoi=_Y`0:oi=_
Y`03o`000?l:38Wo2Pb900Oo2Pb900?o0000o`T`/Ol000001Ol00008ocnflP03o`000?mT`OkoI<7n
00goI<7n00?o0000ogO4o_mga?h03?mga?h<o`0000[oO<;m00?o0000ohC3o?n4`o`04?n4`o`00ol0
003oR/Ckoh[4n`0?oh[4n`03o`000?n>a?WoS/Ci00OoS/Ci1_l00003oh_3nP03o`000?n?`_WoSl;i
00_oSl;i00?o0000oho2nOn?`_T01?n?`_T00ol0003ooo]ZoookJP0noookJPOo00002_oonfX3o`00
ObKooo]Z000QoookJP?o001o2?oonfX5o`0003Cooo]Z00?o0000oookJ_oonfX0H?oonfX3o`0000ko
V>Sk0ol00008oh?Xj`?o00001oo^ek/00ol0003oj<B`o`00000;onFfY@03o`000?oN[:7ogZbQ00_o
gZbQ0ol0000>oiM_XPCo00002_nCKjL00ol0003o2Pb9o`X<R@08o`X<R@03o`000?l9<;7o2C2a00?o
000000?o9:;Zo`000?l000001Ol00002ocnflP03o`000?mT`OkoI<7n00goI<7n00?o0000ogO4o_mg
a?h00_mga?h9o`0000GoKkon00?o0000ogc2oOml`_d03oml`_d00ol0003oQ<?lohC3o00@ohC3o003
o`000?n:a?_oR/Ck00ooR/Ck00Co0000ohk4nOn>a?WoS/Ci1Ol0000:oh_3nP03o`000?n?`_WoSl;i
00_oSl;i00?o0000oho2nOn?`_T01?n?`_T00ol0003ooo]ZoookJP0moookJPSo00001_oonfX6o`00
ObKooo]Z000@oookJP[o001o0_oonfX9o`00O`Oooo]Z1Ol0000eoookJP03o`000?oonf[ooo]Z05co
oo]Z0ol0000?oiSXn`;o00002On3j>/2o`000003onOad_l0003ok]Nk00Ook]Nk00Co0000onS4/?oX
a;3o00002_oU]ZD00ol0003ogZbQomj/X@09omj/X@;o00000_oN[:400ol0003oUfnRoiM_XP0;oiM_
XP03o`000?nbT;;o000000;oOVR`1Ol00006oi=_Y`03o`000?l:38Wo2Pb900Oo2Pb900Go0000o`T`
/Ol9<;7o0000o`1@b`03o`0000Ko9:;Z5ol0000?ofnooP03o`000?ml`_goO<;m00ooO<;m00?o0000
ohC3o?n4`o`04?n4`o`00ol0003oR/Ckoh[4n`0;oh[4n`Oo00004?n;`oX00ol0003oSl;ioho2n@0:
oho2n@03o`000?n?`_WoSl;i00CoSl;i00?o0000oookJ_oonfX0?OoonfX9o`0000Gooo]Z1_l007lV
oookJP004?oonfX:o`00O`;ooo]Z2Ol007l6oookJPKo0000=_oonfX00ol0003ooo]ZoookJP1Hoook
JPCo00003_nHj?/3o`0000SoPnS[1?l00002onOadP03o`000?o^ek_ok]Nk00Gok]Nk00Go0000onS4
/?oXa;3oj<B`o`000009onFfY@03o`000?oN[:7ogZbQ00OogZbQ0ol00004omj/X@03o`000?nGKj;o
UfnR00[oUfnR00Co0000ok:@/_nbT;;o00001omnJ;05o`000003oi=_Yol0003o2Pb900So2Pb900Go
0000o`T`/Ol9<;7o2C2ao`000002o`1@b`?o00002OlTX^X2o`0000koF;Sl00?o0000ofnoo_m__oh0
3om__oh00ol0003oO<;mogc2o@0?ogc2o@03o`000?n4`ocoQ<?l013oQ<?l00?o0000oh[4non:a?/0
0_n:a?/8o`0000GoQl;k00?o0000oh_3n_n;`oX04?n;`oX00ol0003oSl;ioho2n@0:oho2n@03o`00
0?n?`_WoSl;i00CoSl;i00?o0000oookJ_oonfX0?_oonfX7o`0000Oooo]Z1?l007lVoookJP007?oo
nfX2o`00O`?ooo]Z0ol007l7oookJPKo0000=ooonfX00ol0003ooo]ZoookJP1EoookJP;o00001?nV
j?/4o`0000SoV>Sk0_l00009oh?Xj`Go00000_oWlM800ol0003ok]NkonkG^`06onkG^`03o`000?oX
a;3oj<B`00;oj<B`00?o0000onFfYOoU]ZD01_oU]ZD00ol0003ogZbQomj/X@04omj/X@?o00001ooN
[:400ol0003oUfnRoiM_XP09oiM_XP03o`000?nbT;;o/Y2b00;o/Y2b00?o0000ogiX/?mnJ;002Omn
J;03o`0000Wo2Pb900Go0000o`T`/Ol9<;7o2C2ao`000002o`1@b`Ko00001olTX^X2o`0000goF;Sl
0_l0000@ofnooP03o`000?ml`_goO<;m00ooO<;m00?o0000ohC3o?n4`o`03?n4`o`8o`0000koQl;k
00?o0000oh_3n_n;`oX04?n;`oX00ol0003oSl;ioho2n@0:oho2n@03o`000?n?`_WoSl;i00CoSl;i
00?o0000oookJ_oonfX0?OoonfX8o`0000Oooo]Z0ol007lVoookJP007OoonfX2o`00O`;ooo]Z0ol0
07l7oookJPKo0000>?oonfX00ol0003ooo]ZoookJP1BoookJP;o00002_nVj?/3o`0000;oV>Sk0ol0
0009oh?Xj`;o000000CoW?CQo`000?l0003o00000_oWlM800ol0003ok]NkonkG^`06onkG^`03o`00
0?oXa;3oj<B`00Coj<B`00?o0000onFfYOoU]ZD01OoU]ZD01?l0003ogZbQomj/XOoN[:43o`0000_o
gZbQ00?o0000oiM_X_nGKj801onGKj800ol0003o/Y2bok:@/P03ok:@/P03o`000?mnJ;3oOVR`00[o
OVR`00?o0000oeMG]_l000002?l:38T00ol0003o2C2ao`T`/@02o`T`/@04o`000?l0D<_o053;o`1@
b`?o000000?o7Y?[o`000?l000000ol00004obBRjP03o`000?mH^?coF;Sl00coF;Sl00?o0000ofno
o_m__oh03_m__oh00ol0003oO<;mogc2o@0?ogc2o@03o`000?n4`ocoQ<?l00;oQ<?l2Ol00004oh71
o003o`000?n7`__oQl;k013oQl;k00?o0000oh_3n_n;`oX04?n;`oX00ol0003oSl;ioho2n@0:oho2
n@04o`000?n?`_WoSl;ioho2n@Co0000?ooonfX8o`0002oooo]Z000MoookJP?o001o00Cooo]Zo`00
Ool007oo001o1ooonfX6o`0003Wooo]Z00?o0000oookJ_oonfX0C_oonfX3o`0000ooY^Sk1ol00005
oh?Xj`;o000000GoW?CQo`000?l0003oV>fgo`000003onOadP03o`000?o^ek_ok]Nk00Kok]Nk00?o
0000onS4/?oXa;001?oXa;000ol0003oiKJUonFfY@04onFfY@03o`000?oN[:7o000000;o00003_oN
[:400ol0003oUfnRoiM_XP06oiM_XP03o`000?nbT;;o/Y2b00Co/Y2b00?o0000ogiX/?mnJ;002_mn
J;001?l0003oEeNfoeMG]_l00008o`X<R@03o`000?l9<;7o2C2a00;o2C2a00?o0000o`1@bol0D</0
0_l0D</2o`0000Go7Y?[1ol0000=oeRho0;o00003om__oh00ol0003oO<;mogc2o@0;ogc2o@So0000
3_n1`O`00ol0003oQl;kohO2n`0@ohO2n`03o`000?n;`o[oRl?j013oRl?j00?o0000oho2nOn?`_T0
1on?`_T6o`0000?oSL;i00?o0000oookJ_oonfX0?_oonfX7o`0002oooo]Z000NoookJP;o001o00Co
oo]Zo`00Ool007oo001o1ooonfX5o`0003_ooo]Z00?o0000oookJ_oonfX0BooonfX2o`00013oY^Sk
0_l00007oj?`m@Go00000_nLm>401?l0003oV>fgoiS]]ol00003onOadP03o`000?o^ek_ok]Nk00Ko
k]Nk00?o0000onS4/?oXa;001_oXa;000ol0003oiKJUonFfY@02onFfY@?o00004OoN[:400ol0003o
UfnRoiM_XP05oiM_XP03o`000?nbT;;o/Y2b00Go/Y2b00?o0000ogiX/?mnJ;002omnJ;000ol0003o
EeNfoeMG]P02o`0000Ko2Pb900?o0000o`T`/Ol9<;400ol9<;400ol0003o053;o`1@b`02o`1@b`?o
00002?lNTn/;o`0000KoF;Sl00?o0000ofnoo_m__oh03Om__oh00ol0003oO<;mogc2o@02ogc2o@So
00001Omh_od00ol0003oPL7loh71o00?oh71o003o`000?n7`__oQl;k013oQl;k00?o0000oh_3n_n;
`oX04?n;`oX01?l0003oSl;ioho2nOn?`_T5o`0000?oSL;i00?o0000ohg2nOn=`_T01?n=`_T00ol0
003ooo]ZoookJP0moookJPSo0000;_oonfX001oooo]Z1Ol007l7oookJPGo0000??oonfX00ol0003o
oo]ZoookJP18oookJP;o00004?nVj?/2o`0000[oXo3e0_l00003oicdh@04o`000?nHkKOoV>fgo`00
00Coio7B00?o0000onkG^oo^ek/01_o^ek/00ol0003oj<B`onS4/006onS4/003o`000?oU]ZGo0000
00;o000000?oiKJUo`000?oN[:404OoN[:400ol0003oUfnRoiM_XP04oiM_XP03o`000?nbT;;o/Y2b
00Oo/Y2b00?o0000ogiX/?mnJ;002_mnJ;000ol0003oEeNfoeMG]P02oeMG]P03o`000?l:38Wo2Pb9
00?o2Pb900?o0000o`T`/Ol9<;401?l9<;400ol0003o053;o`1@b`03o`1@b`;o00002olNTn/00ol0
003oDZojoe:_nP04oe:_nQ_o00003_mh_od00ol0003oPL7loh71o00?oh71o003o`000?n7`__oQl;k
013oQl;k00?o0000oh_3n_n;`oX03?n;`oX7o`0000WoSL;i00?o0000ohg2nOn=`_T01?n=`_T00ol0
003ooo]ZoookJP0moookJPSo0000;OoonfX001oooo]Z1Ol007l7oookJPGo0000?OoonfX00ol0003o
oo]ZoookJP15oookJP;o00004?nVj?/2o`0000[oXo3e0_l00004oicdh@04o`000?nHkKOo0000o`00
00Coio7B00?o0000onkG^oo^ek/01oo^ek/00ol0003oj<B`onS4/005onS4/0?o00000ooU]ZD00ol0
003ogZbQomj/X@0Aomj/X@03o`000?nGKj;oUfnR00?oUfnR00?o0000ok:@/_nbT;802?nbT;800ol0
003oOVR`ogiX/00:ogiX/003o`000?mGEkKoEeNf00?oEeNf0_l00004o`X<R@03o`000?l9<;7o2C2a
00Co2C2a00?o0000o`1@bol0D</01?l0D</00ol0003o7Y?[oajCj`09oajCj`03o`000?mB[o[oDZoj
00coDZoj00?o0000of^joOm[^_d03Om[^_d00ol0003oN;omogRoo@0>ogRoo@03o`000?n1`OcoPL7l
00ooPL7l00?o0000ohO2non7`_/04?n7`_/00ol0003oRl?joh_3nP02oh_3nPWo00001?n9`_X00ol0
003oSL;iohg2n@0:ohg2n@03o`000?n=`_WoSL;i00CoSL;i00?o0000oookJ_oonfX0?OoonfX7o`00
02gooo]Z000PoookJPCo001o1_oonfX6o`0003kooo]Z0_l00013oookJP?o00003onVj?/2o`0000[o
Xo3e0_l00004oicdh@Co000000?od?[Uo`000?oWlM800ooWlM800ol0003ok]NkonkG^`06onkG^`03
o`000?oXa;3oj<B`00Coj<B`0_l00003onS4/004o`000?oU]ZGoiKJUo`0001?ogZbQ00?o0000oiM_
X_nGKj800_nGKj800ol0003o/Y2bok:@/P09ok:@/P03o`000?mnJ;3oOVR`00_oOVR`00?o0000oeMG
]_mGEkH01?mGEkH01Ol0003o2Pb9o`X<ROl:38Wo000000Oo2C2a0_l00005o`1@b`?o00002OlNTn/0
0ol0003oDZojoe:_nP0<oe:_nP03o`000?m[^_goJk[m00goJk[m00?o0000ogRooOmh_od03_mh_od0
0ol0003oPL7loh71o00?oh71o003o`000?n7`__oQl;k00coQl;k2?l0000>ohW2nP03o`000?n=`_Wo
SL;i00WoSL;i00?o0000ohg2nOn=`_T01On=`_T00ol0003ooo]ZoookJP0loookJPSo0000;?oonfX0
027ooo]Z0ol007l6oookJPKo0000@?oonfX00ol0003ooo]ZoookJP0noookJP;o00000on_iOT3o`00
00[oY^Sk0_l0000:oj?`m@;o00001OnLm>43o`0000;od?[U00?o0000onOad_oWlM800_oWlM800ol0
003ok]NkonkG^`07onkG^`04o`000?oXa;3oj<B`onS4/0?o00001OoXa;001?l0003oiKJUonFfYOl0
000Comj/X@05o`000?nGKj;oUfnRoiM_X_l000003?nbT;800ol0003oOVR`ogiX/00;ogiX/003o`00
0?mGEkKoEeNf00GoEeNf00Co0000o`X<ROl:38Wo00001ol9<;401?l0003o9f[Ko`000?l00004o`1@
b`03o`000?l^Snko000000?o00001_lNTn/00ol0003oDZojoe:_nP0<oe:_nP03o`000?m[^_goJk[m
00goJk[m00?o0000ogRooOmh_od03_mh_od00ol0003oPL7loh71o00?oh71o003o`000?n7`__oQl;k
00;oQl;k2Ol00004ohC1n`03o`000?n9`_[oRL;j013oRL;j00?o0000ohg2nOn=`_T02On=`_T00ol0
003oSL;iohg2n@04ohg2n@03o`000?oonf[ooo]Z03gooo]Z1ol0000/oookJP00:_oonfX6o`00047o
oo]Z00?o0000oookJ_oonfX0>ooonfX2o`0000So[nGi0_l00006ojKXn`;o00002_nSl?D2o`0000Ko
W?CQ0_l00003om3ji@03o`000?oWlM;oio7B00?oio7B00?o0000onkG^oo^ek/01_o^ek/00ol0003o
j<B`o`000002o`0000Woj<B`0_l0000Eomj/X@03o`000?nGKj;o000000ko/Y2b00?o0000ogiX/?mn
J;002_mnJ;000ol0003oEeNfoeMG]P06oeMG]P;o000000?o2Pb9o`000?l9<;401_l9<;400ol0003o
9f[KobMZf`02o`0000?o053;00?o0000obj?k_l^Snh00_l^Snh4o`0000?o7Y?[00?o0000oe:_n_mB
[oX03?mB[oX00ol0003oJk[mof^jo@0=of^jo@03o`000?mh_ogoN;om00koN;om00?o0000oh71o?n1
`O`02on1`O`8o`0000koQ<7k00?o0000ohW2n_n9`_X04?n9`_X00ol0003oSL;iohg2n@09ohg2n@03
o`000?n=`_WoSL;i00CoSL;i00?o0000oookJ_oonfX0?OoonfX7o`0002_ooo]Z000ZoookJPKo0000
@_oonfX00ol0003ooo]ZoookJP0goookJP?o00003?n_iOT3o`000003ojKXnol0003o000000[oXo3e
0_l00007oicdh@;o00000oo@n^D00ol0003oio7BonOadP03onOadP03o`000?o^ek_ok]Nk00Kok]Nk
0ol0000=onS4/003o`000?oN[:7ogZbQ01?ogZbQ0_l0000?ok:@/P03o`000?mnJ;3oOVR`00_oOVR`
00?o0000oeMG]_mGEkH01omGEkH2o`0000So2C2a00Co0000obMZfolWJ]_o9f[K0_l00002o`1@b`03
o`000?l^Snko;Xo^00Go;Xo^1Ol0000>oe:_nP03o`000?m[^_goJk[m00goJk[m00?o0000ogRooOmh
_od03_mh_od00ol0003oPL7loh71o002oh71o0So00001Omn`?`00ol0003oQ<7kohC1n`0?ohC1n`03
o`000?n9`_[oRL;j013oRL;j00?o0000ohg2nOn=`_T02?n=`_T00ol0003oSL;iohg2n@05ohg2n@03
o`000?oonf[ooo]Z03cooo]Z2?l0000ZoookJP00:_oonfX5o`0004Cooo]Z00?o0000oookJ_oonfX0
=?oonfX2o`00017o[nGi1ol00005oj?`m@;o00000onLm>46o`0000Cod?[U00?o0000onOad_oWlM80
0ooWlM800ol0003ok]NkonkG^`04onkG^`Co00003ooXa;000ol0003ogZbQomj/X@0Comj/X@03o`00
0?nbT;;o/Y2b00ko/Y2b00?o0000ogiX/?mnJ;002omnJ;000ol0003oEeNfoeMG]P08oeMG]P03o`00
0?l9<;7o2C2a00Ko2C2a00?o0000obMZfolWJ]/00olWJ]/01?l0003o053;o`1@bol0000:obj?kP[o
00001_mB[oX00ol0003oJk[mof^jo@0=of^jo@03o`000?mh_ogoN;om00KoN;om3?l0000>ogk0o003
o`000?n4`O_oQ<7k00ooQ<7k00?o0000ohW2n_n9`_X04?n9`_X00ol0003oSL;iohg2n@08ohg2n@04
o`000?n=`_WoSL;iohg2n@Go0000?_oonfX7o`0002[ooo]Z000ZoookJPGo0000AOoonfX00ol0003o
oo]ZoookJP0aoookJP;o00004On_iOT2o`0000Oo]>gg2_l00003okgel@03o`000?o@n^God?[U00?o
d?[U00?o0000onOad_oWlM801?oWlM801?l0003ok]NkonkG^oo^ek/3o`0000?ok]Nk00?o0000onS4
/?oXa;003?oXa;000ol0003og[bfo`00000Domj/X@03o`000?nbT;;o/Y2b00ko/Y2b00?o0000ogiX
/?mnJ;002omnJ;000ol0003oEeNfoeMG]P09oeMG]P;o00001ol9<;400ol0003o9f[KobMZf`03obMZ
f`;o000000?o053;o`000?l^Snh02ol^Snh00ol0003oE:[ioeBZn@04oeBZnAoo00002Ome_Od00ol0
003oO/3logk0o00?ogk0o003o`000?n4`O_oQ<7k00ooQ<7k00?o0000ohW2n_n9`_X04?n9`_X00ol0
003oSL;iohg2n@02ohg2n@Wo00001?n:`OT00ol0003ooo]ZoookJP0loookJPSo0000:OoonfX002Wo
oo]Z1_l00016oookJP03o`000?oonf[ooo]Z02kooo]Z0_l0000AojoUn@;o00002ondkOL00ol0003o
_OGaokgel@07okgel@03o`000?o@n^God?[U00Cod?[U00?o0000onOad_oWlM800ooWlM800ol0003o
k]Nko`000002o`0000Gok]Nk00?o0000onS4/?oXa;003OoXa;000ol0003og[bfo`00000Comj/X@;o
00004OnbT;800ol0003oOVR`ogiX/00:ogiX/003o`000?mGEkKoEeNf00WoEeNf00Co0000odeWcOl0
003o00001_l9<;400ol0003o9f[KobMZf`04obMZf`?o00003?l^Snh00ol0003oE:[ioeBZn@0;oeBZ
n@03o`000?mY]ocoJKOl00goJKOl00?o0000ogFmoOme_Od03_me_Od00ol0003oO/3logk0o00?ogk0
o003o`000?n4`O_oQ<7k00ooQ<7k00?o0000ohW2n_n9`_X03?n9`_X8o`0000OoR/7i00?o0000oh[1
nOn:`OT01?n:`OT00ol0003ooo]ZoookJP0loookJPSo0000:?oonfX002Wooo]Z1_l00017oookJP03
o`000?oonf[ooo]Z02_ooo]Z0ol0000@ojoUn@;o00002ondkOL2o`0000So_OGa0_l00006om3ji@03
o`000?oWlM;oio7B00Coio7B0_l00008onkG^`03o`000?oXa;3oj<B`00coj<B`00Co0000omjl]_oN
_;Ko00004_oN[:401?l0003oc:^holb[^?l0000@ok:@/P03o`000?mnJ;3oOVR`00_oOVR`00?o0000
oeMG]_mGEkH02OmGEkH00ol0003oCFO=odeWc@02o`0000Co2C2a00?o0000obMZfolWJ]/01_lWJ]/2
o`0000co;Xo^00?o0000oeBZnOmDZ_T02omDZ_T00ol0003oJKOlofVgo00=ofVgo003o`000?me_Ogo
MKgm00koMKgm00?o0000ogk0o?mn`?`03omn`?`00ol0003oQ<7kohC1n`0?ohC1n`03o`000?n9`_[o
RL;j00;oRL;j2Ol00004ohK1nP03o`000?n:`OWoR/7i00SoR/7i00?o0000oh[1nOn:`OT01On:`OT0
0ol0003ooo]ZoookJP0loookJPOo0000:?oonfX002Wooo]Z1_l00018oookJP03o`000?oonf[ooo]Z
02Sooo]Z0_l00003ok?PmP;o00003On_iOT00ol0003o]>ggokC]m`0:okC]m`03o`000?nmmO7o_OGa
00Oo_OGa00?o0000om3jiOo@n^D01Oo@n^D00ol0003oio7BonOadP02onOadP?o00002Oo^ek/00ol0
003oj<B`onS4/00<onS4/003o`000?oN_;Kog[bf00;og[bf00?o0000omj/XOoN[:403_oN[:401Ol0
003oc:^holb[^?o<ZkSo0000013o/Y2b00?o0000ogiX/?mnJ;002omnJ;000ol0003oEeNfoeMG]P09
oeMG]P03o`000?m=IlgoCFO=00;oCFO=0_l00003o`T`/@03o`000?lWJ]_o9f[K00Oo9f[K1?l00009
obj?kP03o`000?mDZ_WoE:[i00_oE:[i00?o0000ofVgo?mY]o`03OmY]o`00ol0003oMKgmogFmo@0>
ogFmo@03o`000?mn`?coO/3l00ooO/3l00?o0000ohC1non4`O/02on4`O/8o`0000koQ/7j00?o0000
oh[1nOn:`OT02?n:`OT00ol0003oR/7ioh[1n@05oh[1n@03o`000?oonf[ooo]Z03_ooo]Z2?l0000W
oookJP00:OoonfX6o`0004Wooo]Z00?o0000oookJ_oonfX09OoonfX2o`0000Oo/n3f0_l00009ojoU
n@;o00002ondkOL2o`0000Wo_OGa00?o0000om3jiOo@n^D01Oo@n^D00ol0003oio7BonOadP03o`00
00;oio7B00?o0000onkG^oo^ek/01oo^ek/00ol0003oj<B`onS4/00<onS4/003o`000?oN_;Kog[bf
00;og[bf00?o0000omj/XOoN[:403_oN[:401Ol0003oc:^holb[^?o<ZkSo0000013o/Y2b00?o0000
ogiX/?mnJ;002omnJ;000ol0003oEeNfoeMG]P09oeMG]P03o`000?m=IlgoCFO=00CoCFO=0_l00002
o`T`/@03o`000?lWJ]_o9f[K00Oo9f[K00?o0000odJDlOm6U?401Ol00005obj?kP03o`000?mDZ_Wo
E:[i00_oE:[i00?o0000ofVgo?mY]o`03OmY]o`00ol0003oMKgmogFmo@0>ogFmo@03o`000?mn`?co
O/3l00ooO/3l00?o0000ohC1non4`O/00_n4`O/8o`0000GoP<3l00?o0000ohK1n_n6`OX03on6`OX0
0ol0003oR/7ioh[1n@08oh[1n@03o`000?n:`OWoR/7i00GoR/7i00?o0000oookJ_oonfX0>ooonfX8
o`0002Kooo]Z000YoookJPGo0000BooonfX00ol0003ooo]ZoookJP0QoookJP?o00002onch?H2o`00
00Go[nGi0_l0000<okC]m`03o`000?nmmO7o_OGa00Oo_OGa0_l00007om3ji@Co00001?oWlM800ol0
003ok]NkonkG^`07onkG^`03o`000?oXa;3oj<B`00coj<B`00?o0000omjl]_oN_;H00ooN_;H00ol0
003ogZbQomj/X@0=omj/X@03o`000?o<ZkSoc:^h00?oc:^h00?o0000ok:@/_nbT;803_nbT;800ol0
003oOVR`ogiX/00;ogiX/003o`000?mGEkKoEeNf00WoEeNf00?o0000odeWcOm=Ild01Om=Ild3o`00
00[o9f[K00?o0000odJDlOm6U?401?m6U?45o`000003obj?k_l0003oE:[i00coE:[i00?o0000ofVg
o?mY]o`03OmY]o`00ol0003oMKgmogFmo@0>ogFmo@03o`000?mn`?coO/3l00OoO/3l3?l0000>oh30
o003o`000?n6`O[oQ/7j00ooQ/7j00?o0000oh[1nOn:`OT02?n:`OT00ol0003oR/7ioh[1n@05oh[1
n@03o`000?oonf[ooo]Z03_ooo]Z1ol0000VoookJP00:OoonfX5o`0004cooo]Z00?o0000oookJ_oo
nfX07_oonfX2o`00013o/n3f0_l000000on_iOWo0000o`00000<okC]m`;o00002OnmmO400ol0003o
d?[Uom3ji@05om3ji@?o00001ooWlM800ol0003ok]NkonkG^`07onkG^`03o`000?oXa;3oj<B`00co
j<B`00?o0000omjl]_oN_;H01?oN_;H00ol0003ogZbQomj/X@0;omj/X@03o`000?o<ZkSoc:^h00Co
c:^h00?o0000ok:@/_nbT;803_nbT;800ol0003oOVR`ogiX/00;ogiX/003o`000?mGEkKoEeNf00Wo
EeNf00?o0000odeWcOm=Ild01om=Ild2o`0000[o9f[K00?o0000odJDlOm6U?402?m6U?4;o`0000Go
E:[i00?o0000ofVgo?mY]o`03OmY]o`00ol0003oMKgmogFmo@06ogFmoA7o00002?mj_od00ol0003o
P<3loh30o00@oh30o003o`000?n6`O[oQ/7j00ooQ/7j00?o0000oh[1nOn:`OT01on:`OT00ol0003o
R/7ioh[1n@06oh[1n@03o`000?oonf[ooo]Z03[ooo]Z2?l0000UoookJP00:?oonfX6o`0004gooo]Z
00?o0000oookJ_oonfX06ooonfX2o`0001?o/n3f1?l0000;okC]m`03o`000?nmmO7o_OGa00So_OGa
00?o0000om3jiOo@n^D00oo@n^D3o`000003om3jiOl0003oio7B00Koio7B00?o0000onkG^oo^ek/0
1oo^ek/00ol0003oj<B`onS4/00<onS4/003o`000?oN_;Kog[bf00Gog[bf00?o0000omj/XOoN[:40
2_oN[:400ol0003oc:^holb[^005olb[^003o`000?nbT;;o/Y2b00ko/Y2b00?o0000ogiX/?mnJ;00
2omnJ;000ol0003oEeNfoeMG]P0:oeMG]P03o`000?m=IlgoCFO=00SoCFO=0ol00008obMZf`03o`00
0?m6U?7oAYCa00[oAYCa00?o0000oe^[nOmKZoT01OmKZoTNo`0000WoL[cm00?o0000ogZooOmj_od0
3_mj_od00ol0003oP<3loh30o00@oh30o003o`000?n6`O[oQ/7j00ooQ/7j00?o0000oh[1nOn:`OT0
1on:`OT00ol0003oR/7ioh[1n@02oh[1n@Go0000??oonfX8o`0002Cooo]Z000XoookJPKo0000C_oo
nfX2o`0001Wooo]Z0_l0000Cok?PmP;o00001?niiO@3o`0000Ko]>gg0_l00009okgel@;o00000oo@
n^D3o`0000?od?[U00?o0000onOad_oWlM801OoWlM800ol0003ok]NkonkG^`08onkG^`03o`000?oX
a;3oj<B`00coj<B`00?o0000omjl]_oN_;H01OoN_;H00ol0003ogZbQomj/X@0:omj/X@03o`000?o<
ZkSoc:^h00Koc:^h00?o0000ok:@/_nbT;803OnbT;800ol0003oOVR`ogiX/00;ogiX/003o`000?mG
EkKoEeNf00[oEeNf00?o0000odeWcOm=Ild02?m=Ild00ol0003oDXKVoe:6iP04o`0000Go9f[K00?o
0000odJDlOm6U?402_m6U?400ol0003oFj_ioe^[n@0<oe^[n@03o`000?mX]_coJ;Kl00goJ;Kl00?o
0000og:loOmb_?d03Omb_?d00ol0003oN[omogZoo@0>ogZoo@03o`000?n0`?coP<3l013oP<3l00?o
0000ohK1n_n6`OX03on6`OX00ol0003oR/7ioh[1n@02oh[1n@Wo00001?n7_oX00ol0003ooo]Zoook
JP0koookJPOo00009?oonfX002Sooo]Z1_l0001@oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000B
ok?PmP;o00002OniiO@3o`0000;o]>gg00?o0000okgelOnmmO402?nmmO401?l0003od?[Uom3jiOo@
n^D2o`0000God?[U00?o0000onOad_oWlM801_oWlM800ol0003ok]NkonkG^`08onkG^`03o`000?oX
a;3oj<B`00_oj<B`00?o0000omjl]_oN_;H01ooN_;H00ol0003ogZbQomj/X@08omj/X@03o`000?o<
ZkSoc:^h00Ooc:^h00?o0000ok:@/_nbT;803_nbT;800ol0003oOVR`ogiX/00;ogiX/003o`000?mG
EkKoEeNf00[oEeNf00?o0000odeWcOm=Ild02?m=Ild00ol0003oDXKVoe:6iP03oe:6iP?o00000olW
J]/00ol0003oAYCaodJDl@0:odJDl@03o`000?mKZoWoFj_i00coFj_i00?o0000ofRfo?mX]_`03OmX
]_`00ol0003oL[cmog:lo@0=og:lo@03o`000?mj_ogoN[om00koN[om00?o0000oh30o?n0`?`04?n0
`?`00ol0003oQ/7johK1nP0;ohK1nPSo00001On7_oX00ol0003oQkojohNonP06ohNonP03o`000?oo
nf[ooo]Z03[ooo]Z2?l0000SoookJP00:?oonfX6o`00057ooo]Z00?o0000oookJ_oonfX04OoonfX2
o`0000?o]Mcd0_l0000>ok?PmP;o00003_niiO@7o`0000Go_OGa00?o0000om3jiOl000000_l00006
om3ji@03o`000?oWlM;oio7B00Koio7B00?o0000onkG^oo^ek/02?o^ek/00ol0003oj<B`onS4/00;
onS4/003o`000?oN_;Kog[bf00Sog[bf00?o0000omj/XOoN[:401ooN[:400ol0003oc:^holb[^008
olb[^003o`000?nbT;;o/Y2b00ko/Y2b00?o0000ogiX/?mnJ;002omnJ;000ol0003oEeNfoeMG]P0:
oeMG]P03o`000?m=IlgoCFO=00WoCFO=00?o0000oe:6i_mBQ^H01OmBQ^H5o`0000coAYCa00?o0000
oe^[nOmKZoT03?mKZoT00ol0003oJ;KlofRfo00=ofRfo003o`000?mb_?goL[cm00goL[cm00?o0000
ogZooOmj_od03_mj_od00ol0003oP<3loh30o00@oh30o003o`000?n6`O[oQ/7j00;oQ/7j2?l00004
oh;0n`03o`000?n7_o[oQkoj00OoQkoj00?o0000ohNon_n7_oX01_n7_oX00ol0003ooo]ZoookJP0j
oookJPSo00008_oonfX002Sooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z00kooo]Z0_l00007okGL
m003o`000?nch?Ko/n3f00[o/n3f00?o0000okWUm?niiO@03?niiO@2o`0000Oo`n[`2_l00005om3j
i@03o`000?oWlM;oio7B00Ooio7B00?o0000onkG^oo^ek/02?o^ek/00ol0003oj<B`onS4/00;onS4
/003o`000?oN_;Kog[bf00Sog[bf00?o0000omj/XOoN[:401_oN[:400ol0003oc:^holb[^00:olb[
^003o`000?nbT;;o/Y2b00go/Y2b00?o0000ogiX/?mnJ;002omnJ;000ol0003oEeNfoeMG]P0:oeMG
]P03o`000?m=IlgoCFO=00WoCFO=00?o0000oe:6i_mBQ^H02OmBQ^H5o`0000WoAYCa00?o0000oe^[
nOmKZoT03?mKZoT00ol0003oJ;KlofRfo00=ofRfo003o`000?mb_?goL[cm00goL[cm00?o0000ogZo
oOmj_od03_mj_od00ol0003oP<3loh30o00<oh30o0So00003On2`?/00ol0003oQkojohNonP07ohNo
nP03o`000?n7_o[oQkoj00KoQkoj00?o0000oookJ_oonfX0>_oonfX7o`0002;ooo]Z000JoookJPGo
001o2OoonfX5o`0005Cooo]Z00?o0000oookJ_oonfX02ooonfX2o`0000[o]Mcd0_l00008ok?PmP;o
00003_niiO@00ol0003o`n[`ol?Zl008ol?Zl0?o00001_o?jnP@o`0000Wok]Nk00?o0000onS4/?oX
a;002ooXa;000ol0003og[bfomjl]P0:omjl]P03o`000?oN[:7ogZbQ00GogZbQ00?o0000olb[^?o<
ZkP02_o<ZkP00ol0003o/Y2bok:@/P0=ok:@/P03o`000?mnJ;3oOVR`00coOVR`00?o0000oeMG]_mG
EkH02_mGEkH00ol0003oCFO=odeWc@09odeWc@03o`000?mBQ^KoDXKV00WoDXKV00Co0000oeZPm?mJ
X?CoFZ3d1Ol00005odJDl@03o`000?mKZoWoFj_i00coFj_i00?o0000ofRfo?mX]_`03OmX]_`00ol0
003oL[cmog:lo@0=og:lo@03o`000?mj_ogoN[om00koN[om00?o0000oh30o?n0`?`00_n0`?`9o`00
00CoNkol00?o0000oh;0non2`?/03on2`?/00ol0003oQkojohNonP07ohNonP03o`000?n7_o[oQkoj
00KoQkoj00?o0000oookJ_oonfX0>OoonfX8o`00027ooo]Z000IoookJPOo001o1ooonfX6o`0005Go
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o]McdokGLm00<okGLm0;o00001?nch?H2o`0000ko
^NGd0_l00008ol?Zl0Co00002_o?jnP00ol0003ofnGLom_Ug009om_Ug004o`000?oQfLoo0000o`00
00Ook]Nk00?o0000onS4/?oXa;002ooXa;000ol0003og[bfomjl]P0:omjl]P03o`000?oN[:7ogZbQ
00CogZbQ00?o0000olb[^?o<ZkP02oo<ZkP00ol0003o/Y2bok:@/P0>ok:@/P03o`000?mnJ;3oOVR`
00_oOVR`00?o0000oeMG]_mGEkH02_mGEkH00ol0003oCFO=odeWc@0:odeWc@03o`000?mBQ^KoDXKV
00WoDXKV00?o0000oeZPm?mJX?@01OmJX?@5o`000003odJDlOl0003oFj_i00goFj_i00?o0000ofRf
o?mX]_`03OmX]_`00ol0003oL[cmog:lo@0=og:lo@03o`000?mj_ogoN[om00KoN[om3?l0000>og^o
o003o`000?n2`?_oP/3k00ooP/3k00?o0000ohNon_n7_oX01_n7_oX00ol0003oQkojohNonP06ohNo
nP03o`000?oonf[ooo]Z03[ooo]Z2?l0000PoookJP006?oonfX3o`00O`?ooo]Z0ol007l6oookJPKo
0000E_oonfX00ol0003ooo]ZoookJP06oookJP;o00004Oneg?@01?l0003o/n3fo`000?l0000>okWU
m0;o00001oo3j_03o`0000;o`n[`00?o0000olo[j?o?jnP02?o?jnP00ol0003ofnGLom_Ug009om_U
g003o`000?oQfLoohMW?00;ohMW?0ol00003onkG^`03o`000?oXa;3oj<B`00_oj<B`00?o0000omjl
]_oN_;H02ooN_;H00ol0003ogZbQomj/X@03omj/X@03o`000?o<ZkSoc:^h00coc:^h00?o0000ok:@
/_nbT;803_nbT;800ol0003oOVR`ogiX/00;ogiX/003o`000?mGEkKoEeNf00_oEeNf00?o0000odeW
cOm=Ild02Om=Ild00ol0003oDXKVoe:6iP0:oe:6iP03o`000?mJX?CoFZ3d00WoFZ3d>Ol00009ogBo
o@03o`000?mk_ocoNkol00ooNkol00?o0000oh;0non2`?/03on2`?/00ol0003oQkojohNonP06ohNo
nP03o`000?n7_o[oQkoj00KoQkoj00?o0000oookJ_oonfX0>_oonfX7o`00023ooo]Z000<oookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJPKo0000EooonfX00ol0003ooo]ZoookJP03oookJP;o
00004oneg?@3o`0000ko^NGd00?o0000ol?Zl?o3j_001?o3j_03o`0000?o`n[`0_l0000:olo[j003
o`000?oKiMcofnGL00WofnGL00?o0000on7IcooQfLl01_oQfLl2o`000003onkG^ol0003oj<B`00_o
j<B`00?o0000omjl]_oN_;H03OoN_;H01Ol0003ogZbQomj/XOoN[:7o0000013oc:^h00?o0000ok:@
/_nbT;803OnbT;800ol0003oOVR`ogiX/00<ogiX/003o`000?mGEkKoEeNf00[oEeNf00?o0000odeW
cOm=Ild02_m=Ild00ol0003oDXKVoe:6iP0:oe:6iP03o`000?mJX?CoFZ3d00coFZ3d00?o0000oen`
nomO/?/03?mO/?/00ol0003oIKWmofFio@0=ofFio@03o`000?m/_OgoK;gm00goK;gm00?o0000ogBo
oOmd_od03Omd_od00ol0003oNkolog^oo00?og^oo003o`000?n2`?_oP/3k00ooP/3k00?o0000ohNo
n_n7_oX01_n7_oX00ol0003oQkojohNonP06ohNonP03o`000?oonf[ooo]Z03Wooo]Z2?l0000Ooook
JP003?oonfX:o`00O`Sooo]Z0ol007l6oookJPKo0000F?oonfX00ol0003ooo]ZoookJP02o`0001?o
]Mcd0_l00003ok[OlP?o00002OniiO@2o`0000Co`n[`0ol00005ol?Zl003o`000?o?jnSocn_X00Wo
cn_X00?o0000om_Ug?oKiM`02OoKiM`00ol0003ohMW?on7Ic`09on7Ic`;o00003?oXa;000ol0003o
g[bfomjl]P0=omjl]P05o`000?oN[:7ogZbQomj/XOl000004?o<ZkP00ol0003o/Y2bok:@/P0=ok:@
/P03o`000?mnJ;3oOVR`00WoOVR`2ol00005oeMG]P03o`000?m=IlgoCFO=00_oCFO=00?o0000oe:6
i_mBQ^H02_mBQ^H00ol0003oFZ3doeZPm00<oeZPm003o`000?mO/?_oGk3k00coGk3k00?o0000ofFi
oOmU^Od03OmU^Od00ol0003oK;gmofbmo@0=ofbmo@03o`000?md_ogoM;om00goM;om00?o0000og^o
o?mk_o`03omk_o`00ol0003oP/3koh;0n`0?oh;0n`03o`000?n7_o[oQkoj00GoQkoj00?o0000ohNo
n_l000002?l0000koookJPSo00007_oonfX001kooo]Z0ol007l6oookJPGo0000F_oonfX3o`0001;o
]Mcd0_l00008ok[OlP;o00001OniiO@2o`0000Co`n[`0_l00007ol?Zl003o`000?o?jnSocn_X00Wo
cn_X00?o0000om_Ug?oKiM`02OoKiM`00ol0003ohMW?on7Ic`0:on7Ic`03o`000?oOc/So000000[o
j<B`00?o0000omjl]_oN_;H03_oN_;H01?l0003ogZbQomj/XOl0000Aolb[^003o`000?nbT;;o/Y2b
00ko/Y2b00Co0000ogiX/?mnJ;3oOVR`1ol00003oiF>bP03o`000?n0R=;oP8SB00GoP8SB2ol00008
odeWc@03o`000?mBQ^KoDXKV00_oDXKV00?o0000oeZPm?mJX?@03?mJX?@00ol0003oGk3koen`n`0<
oen`n`03o`000?mU^OgoIKWm00goIKWm00?o0000ofbmoOm/_Od03Om/_Od00ol0003oM;omogBoo@0=
ogBoo@03o`000?mk_ocoNkol00ooNkol00?o0000oh;0non2`?/02on2`?/=o`0000SoQ;kj00?o0000
oookJ_oonfX0>_oonfX7o`0001kooo]Z000LoookJPCo001o1ooonfX5o`0005Sooo]Z0_l00003okGH
lP;o00003_neg?@2o`0000co^]ob0ol000000oniiOCo0000ol?Zl002ol?Zl0?o00002?o3j_000ol0
003ocn_Xolo[j009olo[j003o`000?oKiMcofnGL00WofnGL00?o0000on7IcooQfLl02_oQfLl01Ol0
003oglk8omo>b?oOc/So000000Woj<B`00?o0000omjl]_oN_;H03ooN_;H2o`0001?oc:^h00?o0000
ok:@/_nbT;803?nbT;85o`0000_oUHk:00?o0000oh28d_n0R=802_n0R=800ol0003oM97QogBAh@02
ogBAh@Oo00000_m=Ild00ol0003oDXKVoe:6iP0;oe:6iP03o`000?mJX?CoFZ3d00coFZ3d00?o0000
oen`nomO/?/03?mO/?/00ol0003oIKWmofFio@0=ofFio@03o`000?m/_OgoK;gm00goK;gm00?o0000
ogBooOmd_od03Omd_od00ol0003oNkolog^oo00?og^oo003o`000?n2`?_oP/3k00;oP/3k2?l00004
ogbno003o`000?n4__[oQ;kj00KoQ;kj00?o0000ohBnn_n4__X01_n4__X00ol0003ooo]ZoookJP0i
oookJPSo00007OoonfX001cooo]Z0ol007l8oookJPGo0000E_oonfX2o`0000Oo]MSb00?o0000okGL
m?neg?@02_neg?@00ol0003o^]obok[OlP0>ok[OlPKo00002Oo3j_02o`0000_ocn_X00?o0000om_U
g?oKiM`02_oKiM`00ol0003ohMW?on7Ic`09on7Ic`03o`000?oOc/Soglk800?oglk800?o0000onS4
/?oXa;001OoXa;000ol0003og[bfomjl]P0@omjl]P03o`000?o<ZkSoc:^h01;oc:^h00?o0000ok:@
/_nbT;802_nbT;82o`000003ojjPbOl0003oUHk:00goUHk:00?o0000oh28d_n0R=802on0R=800ol0
003oM97QogBAh@08ogBAh@co00001OmBQ^H00ol0003oFZ3doeZPm00<oeZPm003o`000?mO/?_oGk3k
00coGk3k00?o0000ofFioOmU^Od03OmU^Od00ol0003oK;gmofbmo@0=ofbmo@03o`000?md_ogoM;om
00goM;om00?o0000og^oo?mk_o`01omk_o`<o`0000goO;kl00?o0000ohBnn_n4__X01_n4__X00ol0
003oQ;kjohBnnP06ohBnnP03o`000?oonf[ooo]Z03Wooo]Z2?l0000LoookJP007_oonfX2o`00O`Ko
oo]Z1_l0001CoookJP?o00002_nef?82o`0000So]Mcd0_l0000@ok[OlPOo00002?o3j_000ol0003o
cn_Xolo[j00:olo[j003o`000?oKiMcofnGL00[ofnGL00?o0000on7IcooQfLl02OoQfLl00ol0003o
glk8omo>b005omo>b003o`000?oXa;3oj<B`00Coj<B`00?o0000omjl]_oN_;H04?oN_;H00ol0003o
c:^holb[^00Bolb[^003o`000?nbT;;o/Y2b00So/Y2b0_l00004ojjPb@03o`000?nES/[oUHk:00co
UHk:00?o0000oh28d_n0R=802on0R=800ol0003oM97QogBAh@0:ogBAh@03o`000?m^Xo7oKZ?a00Ko
KZ?a7_l00006oen`n`03o`000?mU^OgoIKWm00KoIKWm<?l00008og>no@03o`000?ml__coO;kl00oo
O;kl00?o0000ohBnn_n4__X01On4__X00ol0003oQ;kjohBnnP07ohBnnP03o`000?oonf[ooo]Z03Wo
oo]Z1ol0000LoookJP006?oonfX3o`00O`?ooo]Z0ol007l5oookJPKo0000DOoonfX2o`0000oo]MSb
0_l00004okGLm0;o00004?njgo83o`0000Ko`N7_0_l00005ol?Zl003o`000?o?jnSocn_X00[ocn_X
00?o0000om_Ug?oKiM`02_oKiM`00ol0003ohMW?on7Ic`09on7Ic`03o`000?oOc/Soglk800Ooglk8
00?o0000onS4/?oXa;000_oXa;000ol0003og[bfomjl]P0@omjl]P03o`000?oC_LCo000001Coc:^h
00?o0000ok:@/_nbT;801OnbT;82o`0000Ko[Z3900?o0000oiF>b_nES/X03?nES/X00ol0003oP8SB
oh28dP0;oh28dP03o`000?mdTN7oM97Q00_oM97Q00?o0000ofjSlOm^Xo403Om^Xo400ol0003oIK;k
ofFbn`0<ofFbn`03o`000?mL^OcoG;Wl00CoG;Wl3ol00009oeVko003o`000?mN_OgoG[gm00goG[gm
00?o0000ofRno_mX__h03OmX__h00ol0003oLkkmog>no@0=og>no@03o`000?ml__coO;kl00ooO;kl
00?o0000ohBnn_n4__X01On4__X00ol0003oQ;kjohBnnP07ohBnnP03o`000?oonf[ooo]Z03Sooo]Z
2?l0000KoookJP006?oonfX3o`00O`?ooo]Z0ol007l5oookJPKo0000CooonfX2o`0001?o]MSb00Co
0000okGLm?l0003o00003onjgo83o`0000_o`N7_0ol000000oo3j_3o0000olo[j00;olo[j003o`00
0?oKiMcofnGL00[ofnGL00?o0000on7IcooQfLl02_oQfLl00ol0003oglk8omo>b008omo>b004o`00
0?oXa;3oj<B`o`0001;og[bf00Co0000om>ma?oC_LCo00005?o<ZkP00ol0003o/Y2bok:@/P03ok:@
/P;o00002On^X<T00ol0003oUHk:oiF>bP0<oiF>bP03o`000?n0R=;oP8SB00_oP8SB00?o0000ogBA
hOmdTN402omdTN400ol0003oKZ?aofjSl@0=ofjSl@03o`000?mU/__oIK;k00coIK;k00?o0000oebi
o?mL^O`03?mL^O`2o`0000koFK_l00?o0000oejmoOmN_Od03OmN_Od00ol0003oJ;knofRnoP0=ofRn
oP03o`000?mc__goLkkm00goLkkm00?o0000ogbno?ml__`03oml__`00ol0003oQ;kjohBnnP05ohBn
nP03o`000?n4__[oQ;kj00OoQ;kj00?o0000oookJ_oonfX0>?oonfX7o`0001_ooo]Z000IoookJPOo
001o1_oonfX6o`0004gooo]Z0_l0000EokGHlP?o00003Onjgo85o`0000ko`N7_1?l0000:olo[j003
o`000?oKiMcofnGL00[ofnGL00?o0000on7IcooQfLl02_oQfLl00ol0003oglk8omo>b00:omo>b003
o`000?oXa;3o0000017og[bf00?o0000om>ma?oC_L@00_oC_L@00ol0003oc:^holb[^00Aolb[^004
o`000?nbT;;o/Y2bok:@/P;o00002on^X<T00ol0003oUHk:oiF>bP0<oiF>bP03o`000?n0R=;oP8SB
00_oP8SB00?o0000ogBAhOmdTN403?mdTN400ol0003oKZ?aofjSl@0=ofjSl@03o`000?mU/__oIK;k
00coIK;k0_l0000>oebio003o`000?mI^ocoFK_l00coFK_l00?o0000oejmoOmN_Od03OmN_Od00ol0
003oJ;knofRnoP0=ofRnoP03o`000?mc__goLkkm00goLkkm00?o0000ogbno?ml__`03oml__`00ol0
003oQ;kjohBnnP05ohBnnP03o`000?n4__[oQ;kj00OoQ;kj00?o0000oookJ_oonfX0>?oonfX7o`00
01[ooo]Z000JoookJPGo001o1ooonfX5o`0004cooo]Z0ol0000DokGHlP;o00000onif_42o`0000Wo
^]ob0_l000000onjgo;o0000o`00000?ol7Qk`03o`000?o9hN[obN7Z00;obN7Z0ol00006olo[j003
o`000?oKiMcofnGL00[ofnGL00?o0000on7IcooQfLl02_oQfLl00ol0003oglk8omo>b00<omo>b003
o`000?oN_;Kog[bf00oog[bf00?o0000om>ma?oC_L@00ooC_L@00ol0003oc:^holb[^00Bolb[^0?o
00003On^X<T00ol0003oUHk:oiF>bP0=oiF>bP03o`000?n0R=;oP8SB00_oP8SB00?o0000ogBAhOmd
TN403?mdTN400ol0003oKZ?aofjSl@0=ofjSl@03o`000?mU/__oIK;k00goIK;k00?o0000oebio?mL
^O`03?mL^O`2o`0000goFK_l00?o0000oejmoOmN_Od03OmN_Od00ol0003oJ;knofRnoP0=ofRnoP03
o`000?mc__goLkkm00goLkkm00?o0000ogbno?ml__`03oml__`00ol0003oQ;kjohBnnP04ohBnnP03
o`000?n4__[oQ;kj00Wo0000>OoonfX8o`0001Wooo]Z000VoookJPGo0000B_oonfX2o`0000?o]=Ga
0_l0000@okGHlP;o00001onif_43o`0000?o^]ob0ol00002ok[OlP03o`000?o1hNoo`N7_00go`N7_
0_l00008olWQjP?o00000_o?jnP00ol0003ofnGLom_Ug00;om_Ug003o`000?oQfLoohMW?00WohMW?
00?o0000omo>b?oOc/P03OoOc/P00ol0003og[bfomjl]P0>omjl]P03o`000?oC_LCodkg400Godkg4
00?o0000olb[^?o<ZkP04?o<ZkP2o`00013o[Z3900?o0000oiF>b_nES/X03?nES/X00ol0003oP8SB
oh28dP0<oh28dP03o`000?mdTN7oM97Q00coM97Q00?o0000ofjSlOm^Xo403Om^Xo400ol0003oIK;k
ofFbn`0=ofFbn`03o`000?mL^OcoG;Wl00KoG;Wl4?l00005oeVko003o`000?mN_OgoG[gm00goG[gm
00?o0000ofRno_mX__h03OmX__h00ol0003oLkkmog>no@0=og>no@03o`000?ml__coO;kl00OoO;kl
4Ol00008ognlnP03o`000?oonf[ooo]Z03Sooo]Z1ol0000IoookJP009OoonfX6o`0004Sooo]Z0_l0
0007okCEl@03o`000?nef?;o]MSb00[o]MSb0ol0000<okWJl@?o00000onjgo82o`0000oo`N7_00?o
0000olWQj_o9hNX02oo9hNX3o`0000cofnGL00?o0000on7IcooQfLl02OoQfLl00ol0003oglk8omo>
b00=omo>b003o`000?oIbL[o000000oog[bf00?o0000om>ma?oC_L@01OoC_L@00ol0003oc:^holb[
^00?olb[^003o`000?o0/lgo0000013o[Z3900?o0000oiF>b_nES/X03OnES/X00ol0003oP8SBoh28
dP0;oh28dP03o`000?mdTN7oM97Q00goM97Q00?o0000ofjSlOm^Xo403Om^Xo400ol0003oIK;kofFb
n`06ofFbn`oo00002Olk^N`3o`0000Co;:oT?ol00008ogFlo003o`000?mo_?[oOkcj00GoOkcj00?o
0000ognln_mo_?X01omo_?X00ol0003ooo]ZoookJP0goookJPSo00002_oonfX9o`00O`Gooo]Z000U
oookJPKo0000AOoonfX3o`0000[o]=Ga0_l00008okGHlP;o00003?nif_43o`0000;o^M[a0_l00000
0onjgo;o0000ol7Qk`0?ol7Qk`03o`000?o9hN[obN7Z00_obN7Z00Co0000om3Nhoo@g^?od=kS0ol0
0008om_Ug003o`000?oQfLoohMW?00[ohMW?00?o0000omo>b?oOc/P03?oOc/P01Ol0003ofLW:omW9
b_oIbL[o000000gog[bf00?o0000om>ma?oC_L@01ooC_L@00ol0003oc:^holb[^00=olb[^005o`00
0?o0/lgo`;?=ol2ccOl000004?n^X<T00ol0003oUHk:oiF>bP0<oiF>bP03o`000?n0R=;oP8SB00co
P8SB00?o0000ogBAhOmdTN403OmdTN400ol0003oKZ?aofjSl@06ofjSl@oo00002_mQaO`3o`0000ko
>kW/0_l0000:obb_i0?o00003Oli/nl2o`0000koDKWj00?o0000ofJkoOmV^od03?mV^od00ol0003o
MKclogFlo00>ogFlo003o`000?mo_?[oOkcj00CoOkcj00?o0000ognln_mo_?X02?mo_?X00ol0003o
oo]ZoookJP0goookJPSo00002OoonfX9o`00O`Gooo]Z000UoookJPKo0000@ooonfX2o`0000oo]=Ga
0_l00004okGHlP;o00002onif_43o`0000Ko^M[a0ol0000>ol7Qk`;o00003Oo9hNX00ol0003od=kS
om3Nh`05om3Nh`;o00001OoKiM`00ol0003ohMW?on7Ic`0:on7Ic`03o`000?oOc/Soglk800coglk8
00?o0000omW9b_oIbLX00_oIbLX00ol0003og[bfomjl]P0:omjl]P03o`000?oC_LCodkg400Sodkg4
00?o0000olb[^?o<ZkP02oo<ZkP2o`0000Co`;?=00?o0000ojjPbOn^X<T03_n^X<T00ol0003oUHk:
oiF>bP0=oiF>bP03o`000?n0R=;oP8SB00_oP8SB00?o0000ogBAhOmdTN402_mdTN4<o`0000WoOl3l
0_l0000@of75o1[o00001?l/[n@2o`0000go>K?_00?o0000oe6in_mA^OX03?mA^OX00ol0003oI[_m
ofJko@0<ofJko@03o`000?me_?coMKcl00koMKcl00?o0000ognln_mo_?X01?mo_?X00ol0003oOkcj
ognlnP08ognlnP03o`000?oonf[ooo]Z03Oooo]Z1ol00009oookJPCo001o2_oonfX002Gooo]Z1_l0
0011oookJP;o00004ondeO401?l0003o]MSbo`000?l0000:okWJl@?o00001onif_42o`0000?o_]_^
0_l0000;ol7Qk`03o`000?o9hN[obN7Z00cobN7Z00?o0000om3Nhoo@g^<02?o@g^<3o`000003om_U
g?l0003ohMW?00_ohMW?00?o0000omo>b?oOc/P03?oOc/P00ol0003ofLW:omW9bP04omW9bP03o`00
0?oN_;Kog[bf00Sog[bf00?o0000om>ma?oC_L@02OoC_L@00ol0003oc:^holb[^00:olb[^003o`00
0?o0/lgo`;?=00Go`;?=00?o0000ojjPbOn^X<T03_n^X<T00ol0003oUHk:oiF>bP0<oiF>bP03o`00
0?n0R=;oP8SB00coP8SB00?o0000ogBAhOmdTN400_mdTN47o`0000GoSK;_00?o0000ogo0o?mo`?`0
3omo`?`00ol0003oHLGlof75o008of75o0Go00000oogdZD00ol0003ohk:Ron>bXP0:on>bXP03o`00
0?oGYZCoejJT00?oejJT00Co0000ojf0Y?n]P:Co[H2T3ol00005ocVck`;o00003OmA^OX00ol0003o
I[_mofJko@0<ofJko@03o`000?me_?coMKcl00koMKcl00?o0000ognln_mo_?X01?mo_?X00ol0003o
OkcjognlnP07ognlnP03o`000?oonf[ooo]Z03Oooo]Z2?l00009oookJPCo001o2OoonfX002Gooo]Z
1Ol00010oookJP;o00005OndeO43o`0000So^M[a0ol00008okWJl@;o00001onnfnh2o`0000Oo`N7_
0_l0000=olWQjP;o00003Oo@g^<3o`0000_ohMW?00?o0000omo>b?oOc/P03?oOc/P00ol0003ofLW:
omW9bP06omW9bP03o`000?oN_;Kog[bf00Kog[bf00?o0000om>ma?oC_L@02ooC_L@00ol0003oc:^h
olb[^007olb[^0;o00002?o0/ld00ol0003o[Z39ojjPb@0>ojjPb@03o`000?nES/[oUHk:00goUHk:
00?o0000oh28d_n0R=802On0R=87o`0000goSK;_00?o0000ogo0o?mo`?`03omo`?`2o`0000?oHLGl
1_l00007ooOBY@03o`000?oS/Z;ohk:R00[ohk:R00?o0000omNVY?oGYZ@00ooGYZ@00ol0003o[H2T
ojf0Y00=ojf0Y003o`000?nHL:CoV72T00co00002OmA^OX00ol0003oI[_mofJko@0<ofJko@03o`00
0?me_?coMKcl00koMKcl00?o0000ognln_mo_?X01?mo_?X00ol0003oOkcjognlnP07ognlnP03o`00
0?oonf[ooo]Z03Oooo]Z2?l00009oookJPGo001o1ooonfX002Gooo]Z1Ol0000noookJP?o00005?nd
eO42o`0000?o^=K`0_l00004okWJl@;o00002Onif_42o`0000_o_]_^0_l00004ol7Qk`03o`000?o9
hN[obN7Z00cobN7Z00?o0000om3Nhoo@g^<03?o@g^<01?l0003oe=WKomCIfooDfM/2o`0000WohMW?
00?o0000omo>b?oOc/P03?oOc/P00ol0003ofLW:omW9bP06omW9bP03o`000?oN_;Kog[bf00Kog[bf
00?o0000om>ma?oC_L@02ooC_L@00ol0003oc:^holb[^006olb[^003o`000?o0/lgo`;?=00So`;?=
00?o0000ojjPbOn^X<T03on^X<T00ol0003oUHk:oiF>bP0<oiF>bP03o`000?n0R=;oP8SB00;oP8SB
1ol00003oiJXh`03o`000?n=/^ooSK;_00ooSK;_00?o0000ogo0o?mo`?`03_mo`?`9o`000003om[o
aOl0003omm:U00Gomm:U00?o0000on>bX_oS/Z802ooS/Z800ol0003oejJTomNVY003omNVY003o`00
0?n]P:Co[H2T00go[H2T00?o0000oiQ`Y?nHL:@01?nHL:@3o`0000;o70000_l000000olSY>Oo0000
o`000006o`0000;oDKWj00?o0000ofJkoOmV^od03?mV^od00ol0003oMKclogFlo00>ogFlo003o`00
0?mo_?[oOkcj00?oOkcj00?o0000ognln_mo_?X02?mo_?X00ol0003ooo]ZoookJP0goookJPOo0000
2ooonfX4o`00O`Kooo]Z000ToookJPKo0000??oonfX2o`0000?o/m?`00?o0000okCElOndeO404?nd
eO400ol0003o^=K`okSFl005okSFl0Co00002_nif_400ol0003o_]_^okkKkP0=okkKkP;o000000?o
`N7_o`000?o9hNX03Oo9hNX00ol0003od=kSom3Nh`0<om3Nh`03o`000?oDfM_oe=WK00Coe=WK0_l0
0006on7Ic`03o`000?oOc/Soglk800coglk800?o0000omW9b_oIbLX02?oIbLX00ol0003og[bfomjl
]P04omjl]P03o`000?oC_LCodkg400godkg400?o0000olb[^?o<ZkP01?o<ZkP00ol0003o`;?=ol2c
c@0:ol2cc@03o`000?n^X<Wo[Z3900ko[Z3900?o0000oiF>b_nES/X02onES/X6o`0000_oUZSS00?o
0000ohfbkon=/^l03on=/^l00ol0003oOl3logo0o009ogo0o0Co00001On;g_h00ol0003oVoCUo`00
0002om[oa@03o`000?ogdZGomm:U00Comm:U00?o0000on>bX_oS/Z802_oS/Z800ol0003oejJTomNV
Y005omNVY003o`000?n]P:Co[H2T00co[H2T00?o0000oiQ`Y?nHL:@01onHL:@3o`000003oa`00?l0
003o8jCW00Oo8jCW3?l00006ofJko@03o`000?me_?coMKcl00koMKcl00?o0000ognln_mo_?X00omo
_?X00ol0003oOkcjognlnP09o`0003Sooo]Z2?l0000;oookJP?o001o1_oonfX002Cooo]Z1_l0000j
oookJP;o00001_ncdo02o`0000ko]=Ga0_l00006okSFl0?o000000?o^=K`o`000?nif_402?nif_42
o`00017o_]_^0ol0000=olWQjP03o`000?o@g^?od=kS00cod=kS00?o0000omCIfooDfM/01ooDfM/0
0ol0003ohMW?on7Ic`02on7Ic`03o`000?oOc/Soglk800coglk800?o0000omW9b_oIbLX02_oIbLX0
0ol0003og[bfomjl]P02omjl]P03o`000?oC_LCodkg400kodkg400?o0000olb[^?o<ZkP00_o<ZkP2
o`0000go`;?=00?o0000ojjPbOn^X<T03_n^X<T00ol0003oUHk:oiF>bP08oiF>bP?o00000_nPZMd0
0ol0003oUZSSoiJXh`0=oiJXh`03o`000?n=/^ooSK;_00ooSK;_00?o0000ogo0o?mo`?`01Omo`?`3
o`0000OoRmkn0_l000001OnKm>Go0000om[oaOoJolGo000000Oomm:U00?o0000on>bX_oS/Z802_oS
/Z800ol0003oejJTomNVY005omNVY003o`000?n]P:Co[H2T00co[H2T00?o0000oiQ`Y?nHL:@02_nH
L:@4o`0000_o8jCW00?o0000oe:dnomB]?/01?mB]?/Po`0000SoNkWj00?o0000oookJ_oonfX0=ooo
nfX8o`0000_ooo]Z0ol007l5oookJP009?oonfX6o`0003Sooo]Z0_l0000:ok?Cl0;o00002_ndeO42
o`0000Go^=K`0ol00005okSFl0;o00001Onif_42o`00017o_]_^0_l00003olCKj`;o00002Oo9hNX2
o`0000kod=kS00?o0000omCIfooDfM/02OoDfM/2o`000003on7Icol0003oglk800goglk800?o0000
omW9b_oIbLX02ooIbLX01Ol0003og[bfomjl]_oN_;Ko000001;odkg400Co0000olb[^?o<ZkSo0000
4?o0/ld00ol0003o[Z39ojjPb@0>ojjPb@03o`000?nES/[oUHk:00?oUHk:1?l00006oj2Yg@03o`00
0?nFZ>?oUZSS00goUZSS00?o0000ohfbkon=/^l03on=/^l00ol0003oOl3logo0o004o`0000SoRmkn
0_l00003oi_di@04o`000?oJolGof_o5o`0000Oomm:U00?o0000on>bX_oS/Z802_oS/Z800ol0003o
ejJTomNVY005omNVY003o`000?n]P:Co[H2T00go[H2T00?o0000oiQ`Y?nHL:@02onHL:@6o`0000So
8jCW0_l0000=oe:dn`03o`000?m/]ocoK;Ol00coK;Ol00?o0000og^in_mk^OX00omk^OX00ol0003o
NkWjog^inP08og^inP03o`000?oonf[ooo]Z03Oooo]Z1ol00005oookJP?o001o0ooonfX3o`00O`Go
oo]Z000ToookJPKo0000=_oonfX2o`0000ko/m?`00?o0000okCElOndeO401OndeO42o`0000Co^=K`
0ol0000:okSFl0;o000000?o^M[ao`000?l000004_nnfnh00ol0003oa=_[olCKj`05olCKj`;o0000
1_o9hNX00ol0003od=kSom3Nh`0=om3Nh`03o`000?oDfM_oe=WK00_oe=WK0ol0000=omo>b003o`00
0?oIbL[ofLW:00gofLW:00?o0000omjl]_l000004ooC_L@00ol0003oc:^ho`00000Aol2cc@03o`00
0?n^X<Wo[Z3900ko[Z3900?o0000oiF>b_nES/X00ol0000;oj2Yg@03o`000?nFZ>?oUZSS00goUZSS
00?o0000ohfbkon=/^l03On=/^l4o`0000[oRmkn0_l00004oi_di@05o`000?oJolGof_o5om[oaOl0
00001_ogdZD00ol0003ohk:Ron>bXP0:on>bXP03o`000?oGYZCoejJT00KoejJT00?o0000ojf0Y?n]
P:@03On]P:@00ol0003oV72ToiQ`Y00;oiQ`Y003o`000?lm<9So?C2H00?o?C2H1Ol00005ob>Ti`03
o`000?mB]?_oD[Ck00_oD[Ck00?o0000ofbgo?m/]o`03?m/]o`00ol0003oNkWjog^inP03og^inP03
o`000?mk^O[oNkWj00SoNkWj00?o0000oookJ_oonfX0=_oonfX7o`0000Gooo]Z0ol007l3oookJP?o
001o1OoonfX002Cooo]Z1_l0000doookJP;o00004Oncdo02o`0000Co]=Ga00Co0000okSFl?nhe_3o
^=K`0ol0000>okSFl0?o00004Onnfnh2o`0000[oa=_[00?o0000olWQj_o9hNX00_o9hNX00ol0003o
d=kSom3Nh`0<om3Nh`;o00003OoDfM/01Ol0003oeMCHomGDf?oEe=So000000_oglk800?o0000omW9
b_oIbLX03ooIbLX00ol0003odkg4om>ma00Bom>ma0;o00004oo0/ld00ol0003o[Z39ojjPb@0=ojjP
b@?o00003_nPZMd00ol0003oUZSSoiJXh`0>oiJXh`03o`000?n=/^ooSK;_00WoSK;_0ol00004oj;=
mP?o00001_n;g_h00ol0003oVoCUoi_di@03oi_di@03o`000?oJolGof_o500?o00001_ogdZD00ol0
003ohk:Ron>bXP0:on>bXP03o`000?oGYZCoejJT00KoejJT00?o0000ojf0Y?n]P:@03On]P:@00ol0
003oV72ToiQ`Y00<oiQ`Y003o`000?lm<9So?C2H00Ko?C2H1_l000000olSY>Oo0000oe:dn`0<oe:d
n`03o`000?m/]ocoK;Ol00coK;Ol00?o0000og^in_mk^OX00omk^OX00ol0003oNkWjog^inP08og^i
nP03o`000?oonf[ooo]Z03Cooo]Z2?l00005oookJPCo001o0_oonfX3o`00O`Gooo]Z000ToookJPGo
0000<ooonfX2o`0001Go/m?`00Go0000okCElOl0003o0000okSFl003o`0000oo^=K`0_l00003ok_G
kP;o00003Onnfnh2o`0000goa=_[0_l000000oo9hN[o0000om3Nh`0=om3Nh`03o`000?oDfM_oe=WK
00coe=WK00?o0000omGDf?oEe=P00ooEe=P00ol0003oglk8omo>b008omo>b003o`000?oIbL[ofLW:
00kofLW:0_l0000Com>ma003o`000?o9a=Ko000001?o`;?=00?o0000ojjPbOn^X<T02_n^X<T3o`00
0003ojbbg?l0003oX:WM00ooX:WM00?o0000oiJXhonFZ><03_nFZ><00ol0003oSK;_ohfbk`04ohfb
k`Co00002_nRcOH3o`000003oh_No_l0003o000000GoVoCU1?l000000ooGgmgo0000on7<``03o`00
00?omm:U00?o0000on>bX_oS/Z802OoS/Z800ol0003oejJTomNVY007omNVY003o`000?n]P:Co[H2T
00go[H2T00?o0000oiQ`Y?nHL:@03?nHL:@00ol0003o?C2Hocd`V007ocd`V0Co000000?o07Fio`00
0?l000001Ol00009oe:dn`03o`000?m/]ocoK;Ol00coK;Ol00?o0000og^in_mk^OX00omk^OX00ol0
003oNkWjog^inP08og^inP03o`000?oonf[ooo]Z033ooo]Z0ol00003oookJPGo00001_oonfX7o`00
O`Kooo]Z000ToookJPGo0000<OoonfX3o`0001Ko/m?`1Ol0000@okSFl0;o00001onkenh00ol0003o
_]_^okkKkP09okkKkP03o`000?o4fn_oa=_[00koa=_[0ol0000=om3Nh`03o`000?oDfM_oe=WK00co
e=WK00?o0000omGDf?oEe=P01OoEe=P2o`0000Ooglk800?o0000omW9b_oIbLX03_oIbLX01?l0003o
d/_Bom;;d_l0000Aom>ma005o`000?o9a=KobLCFolW4e_l000004_o0/ld00ol0003o[Z39ojjPb@07
ojjPb@?o00001On//]`00ol0003oX:WMoj2Yg@0>oj2Yg@03o`000?nFZ>?oUZSS00koUZSS00?o0000
ohfbkon=/^l00ol0000@oj;=mP[o00000ooGgmd00ol0003ohLc3on7<``03on7<``?o00003?oS/Z80
0ol0003oejJTomNVY008omNVY003o`000?n]P:Co[H2T00co[H2T00?o0000oiQ`Y?nHL:@03?nHL:@0
0ol0003o?C2Hocd`V008ocd`V0;o000000?o00JGo`000?l000000ol0MKT00ol0003o>ZGdocZUm008
o`0000;oD[Ck00?o0000ofbgo?m/]o`03?m/]o`00ol0003oNkWjog^inP02og^inP03o`000?mk^O[o
NkWj00WoNkWj00?o0000oookJ_oonfX0:ooonfX4o`0000Sooo]Z00?o0000oookJ_oonfX01ooonfX5
o`00O`Oooo]Z000CoookJPWo001o1ooonfX6o`0002oooo]Z0_l00003ok?Al003o`000?ncdo3o/m?`
017o/m?`1?l000000onfdnoo0000o`00000>okSFl0;o00002_nkenh2o`0000Oo_]_^0_l0000@olCK
j`04o`000?o8f^Kob=[VolSJiP;o00002_o@g^<00ol0003oe=WKomCIf`0<omCIf`03o`000?oEe=So
eMCH00SoeMCH00?o0000omo>b?oOc/P00ooOc/P00ol0003ofLW:omW9bP0>omW9bP03o`000?oBbm;o
d/_B00;od/_B00?o0000om>ma?oC_L@03OoC_L@00ol0003obLCFolW4eP03olW4eP03o`000?o0/lgo
`;?=013o`;?=00?o0000ojjPbOn^X<T00on^X<T3o`0000So[;;L00?o0000oj2YgOnPZMd03_nPZMd0
0ol0003oUZSSoiJXh`0=oiJXh`Co00004OnRcOH2o`0000Ko_=ob00?o0000omOOgOoGgmd00ooGgmd0
0ol0003ohLc3on7<``06on7<``03o`000?oS/Z;ohk:R00[ohk:R00?o0000omNVY?oGYZ@02?oGYZ@0
0ol0003o[H2Tojf0Y00<ojf0Y003o`000?nHL:CoV72T00coV72T00?o0000ocd`V?lm<9P02?lm<9P0
1?l0003o=cn^o`000?l01YL3o`0000;o07Fi00?o0000ocZUm?ljYO@01oljYO@<o`0000KoK;Ol00?o
0000og^in_mk^OX00_mk^OX00ol0003oNkWjog^inP09og^inP03o`000?oonf[ooo]Z02Oooo]Z0ol0
000<oookJP03o`000?oonf[ooo]Z01?ooo]Z000CoookJPWo001o1ooonfX6o`0002gooo]Z0_l00006
ok?Al0;o00003oncdo04o`0000Go]]?_00?o0000okSFl?nhe_002_nhe_000ol0003o^mO^ok_GkP0<
ok_GkP;o00000onnfnh2o`00013oa=_[0_l00006olSJiP;o00001oo@g^<00ol0003oe=WKomCIf`0<
omCIf`03o`000?oEe=SoeMCH00[oeMCH00Go0000omo>b?oOc/Soglk8o`00000@omW9bP03o`000?oB
bm;od/_B00Cod/_B00?o0000om>ma?oC_L@02_oC_L@2o`0000KobLCF00?o0000ol2ccOo0/ld04?o0
/ld00ol0003o[Z39ojjPb@03o`0000co[;;L00?o0000oj2YgOnPZMd03_nPZMd00ol0003oUZSSoiJX
h`08oiJXh`Co00000onU_n`00ol0003oX/gfoj;=mP0=oj;=mP;o00001onlgo800ol0003oemoMomOO
g@04omOOg@03o`000?oQc<?ohLc300KohLc300?o0000on>bX_oS/Z802OoS/Z800ol0003oejJTomNV
Y009omNVY003o`000?n]P:Co[H2T00go[H2T00?o0000oiQ`Y?nHL:@02onHL:@00ol0003o?C2Hocd`
V008ocd`V003o`000?lg?jko000000;o00JG00?o0000o`0o]ol000000ol0000;ocZUm003o`000?mS
/?[oHk3j00KoHk3j6Ol0000UoookJP?o00004?oonfX00ol0003ooo]ZoookJP0BoookJP004ooonfX4
o`00O`cooo]Z1_l0000ZoookJP?o00002_ncdO000ol0003o/m?`ok?Cl009ok?Cl0Co00002Onfdnl2
o`0000So^=K`0_l0000Aok_GkP03o`000?nnfnko0000017oa=_[00?o0000olSJi_o8f^H02?o8f^H2
o`0000Cod=kS00?o0000omCIfooDfM/02ooDfM/2o`0000koeMCH00?o0000omo>b?l000004?oIbLX0
0ol0003od/_Bom;;dP05om;;dP03o`000?oC_LCodkg400Wodkg400?o0000olW4e_o9a=H01oo9a=H0
0ol0003o`;?=ol2cc@0?ol2cc@?o00004?n//]`00ol0003oX:WMoj2Yg@0=oj2Yg@03o`000?nFZ>?o
UZSS00GoUZSS0ol00008ojFok003o`000?nRcOKoX/gf00[oX/gf0_l00008okcOlP03o`000?oGgmgo
emoM00CoemoM00?o0000on7<`ooQc<<01_oQc<<00ol0003ofkVgo`00000:on>bXP03o`000?oGYZCo
ejJT00WoejJT00?o0000ojf0Y?n]P:@03On]P:@00ol0003oV72ToiQ`Y00;oiQ`Y003o`000?lm<9So
?C2H00So?C2H00Co0000ocLo[_lg?jko00000_l01YL00ol0003o03ngo`000003o`0000_o>ZGd00?o
0000of>`n_mS/?X03?mS/?X00ol0003oMkCiogNdn@03ogNdn@03o`000?mg]?WoMkCi00SoMkCi00?o
0000oookJ_oonfX07ooonfX4o`0001?ooo]Z00?o0000oookJ_oonfX04_oonfX000Oooo]Z2_l007l3
oookJPCo001o2ooonfX6o`0002Sooo]Z0_l0000>ok?Al003o`000?ncdo3o/m?`00Ko/m?`0ol0000>
okKCk`;o00001?nhe_02o`0001?o^mO^0ol0000@olCKj`03o`000?o8f^Kob=[V00_ob=[V0_l00000
0oo@g^?o0000omCIf`0<omCIf`03o`000?oEe=SoeMCH00koeMCH0ol0000?omW9bP03o`000?oBbm;o
d/_B00Ood/_B00?o0000om>ma?oC_L@01ooC_L@00ol0003obLCFolW4eP09olW4eP03o`000?o0/lgo
`;?=00co`;?=0_l000000ong`N;o0000ojbbg00@ojbbg003o`000?nPZMgoX:WM00koX:WM00?o0000
oiJXhonFZ><01?l0000<ojFok003o`000?nRcOKoX/gf00SoX/gf00?o0000okcOl_nlgo801onlgo80
0ol0003oemoMomOOg@04omOOg@03o`000?oQc<?ohLc300OohLc300?o0000om^i]ol000002_oS/Z80
0ol0003oejJTomNVY009omNVY003o`000?n]P:Co[H2T00go[H2T00?o0000oiQ`Y?nHL:@03?nHL:@0
0ol0003o?C2Hocd`V008ocd`V004o`000?lg?jko=cn^o`0000;o00JG00Go0000o`0o]ol0?kOo0000
oe800003o`0000Wo>ZGd00?o0000of>`n_mS/?X03?mS/?X00ol0003oMkCiogNdn@02ogNdn@03o`00
0?mg]?WoMkCi00WoMkCi00?o0000oookJ_oonfX06ooonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0
4_oonfX000Oooo]Z2_l007l4oookJPGo001o2OoonfX5o`0002Oooo]Z0_l0000Aok?Al0;o00000onc
do03o`0001?o]]?_00Co0000okSFl?l0003o00004onkenh2o`0000?o_mO/0_l0000<olCKj`;o0000
3oo8f^H3o`0000coe=WK00?o0000omGDf?oEe=P03_oEe=P01Ol0003od];Hom;Bf?oBd]So000000go
fLW:00?o0000om;;d_oBbm802OoBbm800ol0003odkg4om>ma004om>ma0;o00003?o9a=H00ol0003o
`;?=ol2cc@0:ol2cc@;o00001?ng`N800ol0003o[;;Lojbbg00?ojbbg003o`000?nPZMgoX:WM00go
X:WM0ol0000AojFok003o`000?nRcOKoX/gf00GoX/gf0_l00009okcOlP03o`000?oGgmgoemoM00Go
emoM00?o0000on7<`ooQc<<01_oQc<<01Ol0003ofkVgom^i]ooK^KOo000000Sohk:R00?o0000omNV
Y?oGYZ@02ooGYZ@00ol0003o[H2Tojf0Y00<ojf0Y003o`000?nHL:CoV72T00coV72T00?o0000ocd`
V?lm<9P02?lm<9P01Ol0003o=cn^ocLo[_lg?jko000000;o00JG0_l000001Ol0?kOo0000oe800?l0
003o:iC_00Co00001_ljYO@00ol0003oHk3jof>`nP0<of>`nP03o`000?mg]?WoMkCi00;oMkCi00?o
0000ogNdnOmg]?T02Omg]?T00ol0003ooo]ZoookJP0GoookJP?o00006_oonfX00ol0003ooo]Zoook
JP0BoookJP005ooonfX4o`00O`Sooo]Z1Ol0000UoookJP;o00005OncdO04o`0001Go]]?_0ol0000C
ok_GkP03o`000?noenco_mO/00Go_mO/00?o0000olCKjoo4fn/02?o4fn/00ol0003ob=[VolSJiP0>
olSJiP04o`000?o<f>?oc=SSolcHh`;o00002OoDfM/00ol0003oeMCHomGDf00>omGDf003o`000?oB
d]Sod];H00?od];H00?o0000omW9b_oIbLX02OoIbLX00ol0003od/_Bom;;dP0:om;;dP03o`000?oC
_LCodkg400?odkg400?o0000olW4e_o9a=H03Oo9a=H00ol0003o`;?=ol2cc@07ol2cc@;o00001ong
`N800ol0003o[;;Lojbbg00>ojbbg003o`000?nPZMgoX:WM00[oX:WM0ol000000onV^nSo0000ojFo
k00BojFok003o`000?nRcOKoX/gf00;oX/gf0_l00009okcOlP;o00001ooGgmd00ol0003ohLc3on7<
``07on7<``05o`000?oK^KOofkVgom^i]ol000002?oS/Z800ol0003oejJTomNVY00;omNVY003o`00
0?n]P:Co[H2T00co[H2T00?o0000oiQ`Y?nHL:@03?nHL:@00ol0003o?C2Hocd`V008ocd`V005o`00
0?lg?jko=cn^ocLo[_l000000_l01YL01?l0003o55;<o`000?l0?kL3o`0000Co:iC_1?l00003ocZU
m003o`000?mS/?[oHk3j00coHk3j00?o0000ogNdnOmg]?T00_mg]?T00ol0003oMkCiogNdn@09ogNd
n@03o`000?oonf[ooo]Z01;ooo]Z1?l0000MoookJP03o`000?oonf[ooo]Z01;ooo]Z000HoookJP?o
001o1ooonfX6o`0002?ooo]Z0ol0000Cok?Al0Ko00005?nfdnl2o`0000?o^MC^00?o0000ok_Gk_nk
enh03_nkenh2o`0000Wo_mO/0_l00006olCKj`;o00003oo8f^H2o`0000Koc=SS0_l00006omCIf`03
o`000?oEe=SoeMCH00koeMCH00?o0000om;Bf?oBd]P01OoBd]P00ol0003ofLW:omW9bP07omW9bP03
o`000?oBbm;od/_B00cod/_B00Go0000om>ma?oC_LCodkg4o`00000AolW4eP03o`000?o0/lgo`;?=
00Co`;?=0_l00009okO1hP03o`000?n//]co[;;L00oo[;;L00?o0000oj2YgOnPZMd01_nPZMd3o`00
00GoY[_X00?o0000ojFok?nU_n`04OnU_n`01?l0003oX/gfo`000?l0000:okcOlP03o`000?oGgmgo
emoM00KoemoM00?o0000on7<`ooQc<<01ooQc<<00ol0003ofkVgom^i]`02om^i]`03o`000?oS/Z;o
hk:R00Kohk:R00?o0000omNVY?oGYZ@02ooGYZ@00ol0003o[H2Tojf0Y00<ojf0Y003o`000?nHL:Co
V72T00coV72T00?o0000ocd`V?lm<9P02?lm<9P00ol0003o=cn^ocLo[P02ocLo[P06o`000?l01YOo
00JGo`000?lDD/co00000_l0?kL2o`0000Oo:iC_1Ol0000>of>`nP05o`000?mg]?WoMkCiogNdnOl0
00002omg]?T00ol0003ooo]ZoookJP0?oookJP?o00008OoonfX00ol0003ooo]ZoookJP0BoookJP00
6OoonfX3o`00O`Kooo]Z1_l0000QoookJP;o00000onbcnl00ol0003o/m7`ok?Al00>ok?Al0;o0000
00?o/m7`o`000?l000000onedNl00ol0003o]]?_okKCk`0@okKCk`03o`000?nie>ko^MC^00Co^MC^
0_l0000<ok_GkP;o00003Onoen`2o`0000?oa=_[00?o0000olSJi_o8f^H03_o8f^H00ol0003oc=SS
olcHh`08olcHh`03o`000?oDfM_oe=WK00;oe=WK00?o0000omGDf?oEe=P03_oEe=P00ol0003od];H
om;Bf007om;Bf003o`000?oIbL[ofLW:00GofLW:00?o0000om;;d_oBbm803_oBbm800ol0003odkg4
o`00000BolW4eP03o`000?o0/lgo`;?=00;o`;?=0_l0000<okO1hP03o`000?n//]co[;;L00oo[;;L
00?o0000oj2YgOnPZMd00_nPZMd3o`0000WoY[_X00?o0000ojFok?nU_n`04?nU_n`3o`0000[o_=ob
00?o0000omOOgOoGgmd01_oGgmd00ol0003ohLc3on7<``07on7<``03o`000?oK^KOofkVg00CofkVg
00?o0000on>bX_oS/Z801?oS/Z800ol0003oejJTomNVY00<omNVY003o`000?n]P:Co[H2T00go[H2T
00?o0000oiQ`Y?nHL:@02onHL:@00ol0003o?C2Hocd`V009ocd`V003o`000?lg?jko=cn^00;o=cn^
00?o0000o`06Uol000000_lDD/`2o`000003o`0o]ol0003o000000[o:iC_1_l0000:of>`nP05o`00
0?mg]?WoMkCiogNdnOl000002omg]?T00ol0003ooo]ZoookJP0;oookJP?o00009?oonfX00ol0003o
oo]ZoookJP0BoookJP004ooonfX3o`00O`?ooo]Z0ol007l6oookJPKo00007ooonfX2o`0000Ko//o_
0_l0000;ok?Al0?o000000?o/m7`o`000?l000001_nedNl2o`0000ko]]?_0_l00009okWDkP03o`00
0?nkenko^mO^00So^mO^00?o0000okoGk?noen`03onoen`00ol0003oa=_[o`00000@olSJiP03o`00
0?o<f>?oc=SS00[oc=SS0_l000000ooDfM_o0000omGDf00?omGDf003o`000?oBd]Sod];H00Wod];H
00?o0000omW9b_oIbLX00ooIbLX00ol0003od/_Bom;;dP0?om;;dP;o00005?o9a=H01?l0003o`;?=
o`000?l0000?okO1hP03o`000?n//]co[;;L00ko[;;L00?o0000oj2YgOl000000_l0000=ojJkj003
o`000?nU_ncoYKo/00coYKo/0ol00003okC;k0;o00001onlgo800ol0003oemoMomOOg@07omOOg@03
o`000?oQc<?ohLc300OohLc300?o0000om^i]ooK^KL01?oK^KL00ol0003ohk:Ron>bXP04on>bXP03
o`000?oGYZCoejJT00coejJT00?o0000ojf0Y?n]P:@03On]P:@00ol0003oV72ToiQ`Y00;oiQ`Y003
o`000?lm<9So?C2H00Wo?C2H00?o0000ocLo[_lg?jh00olg?jh00ol0003o00JGo`000003oaABc004
o`000?l0?kOo03ngo`0000_o:iC_00Co0000oejWmomNYoOoGZOg2Ol00002of>`nP05o`000?mg]?Wo
MkCiogNdnOl000002omg]?T00ol0003ooo]ZoookJP06oookJPCo0000:?oonfX00ol0003ooo]Zoook
JP0AoookJP004ooonfX3o`00O`?ooo]Z0ol007l6oookJPKo00007OoonfX2o`0000[o//o_0_l00006
ok?Al0?o00000_ncdO02o`0000[o]M7_0_l0000:okKCk`;o00003?nie>h00ol0003o^mO^ok_GkP05
ok_GkP;o00004_noen`3o`0000kob=[V0_l0000>olcHh`?o00003_oEe=P2o`0000god];H00Go0000
omW9b_oIbL[ofLW:o`00000Aom;;dP03o`000?o;e>3o000001CobLCF0_l0000AokO1hP03o`000?n/
/]co[;;L00ko[;;L0_l0000AojJkj003o`000?nU_ncoYKo/00WoYKo/0_l00008okC;k0;o00001?nl
go800ol0003oemoMomOOg@07omOOg@03o`000?oQc<?ohLc300OohLc300?o0000om^i]ooK^KL01_oK
^KL00ol0003ohk:Ron>bXP03on>bXP03o`000?oGYZCoejJT00coejJT00?o0000ojf0Y?n]P:@03On]
P:@5o`0000[oV72T00?o0000ocd`V?lm<9P02?lm<9P00ol0003o=cn^ocLo[P04ocLo[P;o00001?lD
D/`00ol0003o03ngo`0o]`03o`0000Wo:iC_00?o0000oejWmomNYoL02OmNYoLDo`0000Cooo]Z0ol0
000/oookJP03o`000?oonf[ooo]Z017ooo]Z000CoookJPCo001o0_oonfX3o`00O`Kooo]Z1Ol0000L
oookJP;o00003_nbcnl00ol0003o/m7`ok?Al003o`0000?o/m7`0_l0000>okGAk`03o`000?nfdnoo
]]?_00Go]]?_0_l0000?okWDkP;o00000onkenh2o`0001;o_mO/0_l00003ol?Gj@;o00002oo8f^H0
0ol0003oc=SSolcHh`0=olcHh`05o`000?o=e^7ocMKQolgFhOl000003?oEe=P00ol0003od];Hom;B
f00>om;Bf003o`000?oIbL[o0000013od/_B0_l00003ol_Dh003o`000?o9a=KobLCF00oobLCF0_l0
00000onme>_o0000okO1hP0AokO1hP03o`000?n//]co[;;L00[o[;;L0ol000000onX`>_o0000ojJk
j00AojJkj003o`000?nU_ncoYKo/00KoYKo/0_l0000<okC;k0;o000000?o_=obo`000?oGgmd02?oG
gmd00ol0003ohLc3on7<``08on7<``03o`000?oK^KOofkVg00KofkVg00?o0000on>bX_oS/Z800_oS
/Z800ol0003oejJTomNVY00>omNVY003o`000?n]P:Co[H2T00_o[H2T0_l00004oh]^[0Oo00000onH
L:@00ol0003o?C2Hocd`V009ocd`V003o`000?lg?jko=cn^00?o=cn^00?o0000o`06Uol000001?lD
D/`3o`0000;o<XO/0ol00007ob^Dk`03o`000?mNYoOoGZOg00_oGZOg00Go0000ogB_m_md[oKoM:of
o`00000;ogB_mP03o`000?oonf[o000000;o0000;ooonfX00ol0003ooo]ZoookJP0AoookJP005?oo
nfX7o`00O`Oooo]Z1Ol0000JoookJP;o00004?nbcnl3o`0000Co/m7`0_l0000AokGAk`;o00001?nf
dnl00ol0003o^MC^okWDkP0AokWDkP03o`000?nkenko000001?o_mO/00?o0000ol?GjOo3enT01Oo3
enT2o`0000Oob=[V0_l0000?olcHh`03o`000?o=e^7ocMKQ00?ocMKQ00?o0000omGDf?oEe=P02?oE
e=P00ol0003od];Hom;Bf00?om;Bf0?o00003ooBbm800ol0003obmCPol_Dh004ol_Dh003o`000?o9
a=KobLCF00gobLCF00?o0000okgDjonme>/00_nme>/00ol0003o]l7RokO1hP0@okO1hP03o`000?n/
/]co[;;L00Ko[;;L0ol00005ojS0j`03o`000?nV^nSoY[_X013oY[_X00?o0000ojFok?nU_n`00_nU
_n`3o`0000oo]<_/0ol00009omOOg@03o`000?oQc<?ohLc300OohLc300?o0000om^i]ooK^KL02?oK
^KL01Ol0003ohk:Ron>bX_oS/Z;o0000013oejJT00?o0000ojf0Y?n]P:@02_n]P:@00ol0003o/8^_
o`00000;oh]^[0Go00002_lm<9P00ol0003o=cn^ocLo[P04ocLo[P03o`000?l01YOo000000Go55;<
0_l00004oc:7k0Co00001?l[U>l00ol0003oGZOgoejWm`0;oejWm`05o`000?md[oKoM:ofogB_m_l0
00002omd[oH00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z017ooo]Z000EoookJPGo001o
1ooonfX6o`0001Sooo]Z0_l0000?ok;?k`?o00000onbcnl01?l0003o/m7`o`000?l0000EokGAk`04
o`000?nfdnoo0000o`0001Co^MC^0ol0000AokoGk0;o00002_o3enT2o`0000Cob=[V00?o0000olcH
hoo<f><03_o<f><00ol0003ocMKQolgFh@05olgFh@;o00001ooEe=P00ol0003od];Hom;Bf00?om;B
f005o`000?o?e=kocmCNoloDg_l000003OoBbm800ol0003obmCPol_Dh006ol_Dh003o`000?o9a=Ko
bLCF00[obLCF0_l00006okgDj`03o`000?ng`N;o]l7R00oo]l7R00?o0000ojbbg?n//]`00on//]`3
o`0000WoZ<3[00?o0000ojJkj?nV^nP04?nV^nP01?l0003oYKo/o`000?l0000@okC;k0;o00000oo2
cN800ol0003oemoMomOOg@05omOOg@03o`000?oQc<?ohLc300SohLc300?o0000om^i]ooK^KL02?oK
^KL01Ol0003ohk:Ron>bX_oS/Z;o0000013oejJT00?o0000ojf0Y?n]P:@02On]P:@01Ol0003o/8^_
ok2;[on`Rjoo000000goRfj/00?o0000ofaM/?l000002Olm<9P00ol0003o=cn^ocLo[P05ocLo[P;o
00001_lDD/`2o`0000Oo<XO/0ol00002ob^Dk`03o`000?mNYoOoGZOg00_oGZOg00Go0000ogB_m_md
[oKoM:ofo`00000;ogB_mP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX04OoonfX0027o
oo]Z1_l0000FoookJP?o00003Onbcnl3o`0000Ko//o_0ol0000FokGAk`?o00004onie>h2o`0000?o
_=C/0_l0000=okoGk0;o00003_o3enT2o`000003olSJi_l0003oc=SS00koc=SS0_l0000:olgFh@03
o`000?oEe=SoeMCH00?oeMCH00?o0000om;Bf?oBd]P03ooBd]P00ol0003ocmCNoloDgP03oloDgP03
o`000?oBbm;od/_B00Sod/_B0_l0000:ol_Dh003o`000?o9a=KobLCF00OobLCF0_l00009okgDj`03
o`000?ng`N;o]l7R00oo]l7R00?o0000ojbbg?l000000_l0000=ojS0j`03o`000?nV^nSoY[_X00oo
Y[_X0_l0000AokC;k003o`000?o2cN;o`/gR00Co`/gR0_l00004omOOg@03o`000?oQc<?ohLc300So
hLc300?o0000om^i]ooK^KL02OoK^KL01?l0003ohk:Ron>bX_l0000AomNVY003o`000?n]P:Co[H2T
00So[H2T00?o0000ok2;[on`Rjl00_n`Rjl00ol0003oRfj/oh]^[00;oh]^[004o`000?m/GK3oK5f`
o`0000So?C2H00?o0000ocLo[_lg?jh01_lg?jh2o`0000Ko55;<0_l00009oc:7k0Co00003OmNYoL0
1?l0003oM:ofogB_m_l0000;ogB_mP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX04Ooo
nfX0027ooo]Z1_l0000CoookJP?o00000onac^l00ol0003o//o_ok;?k`08ok;?k`;o00001onbcnl2
o`0000?o/m3^00?o0000okGAkonedNl04OnedNl2o`0000?o]m;^0_l0000?okWDkP;o00001onle>`0
0ol0003o_mO/okoGk009okoGk003o`000?o3enWo`mOY00oo`mOY0ol0000>olcHh`03o`000?o=e^7o
cMKQ00_ocMKQ00Go0000omGDf?oEe=SoeMCHo`00000@om;Bf0;o00001oo?e=h00ol0003od/_Bom;;
dP06om;;dP03o`000?o;e>3obmCP00_obmCP00?o0000olW4e_o9a=H01?o9a=H2o`0000co_MC[00?o
0000okO1h_ng`N803Ong`N83o`00017oZ<3[00?o0000ojJkj?nV^nP02onV^nP3o`0000;oZlC/00?o
0000okC;k?ndbn`03?ndbn`2o`0000Wo`/gR00Go0000omOOgOoGgmgoemoMo`00000:on7<``03o`00
0?oK^KOofkVg00[ofkVg00?o0000on>bX_l000004OoGYZ@00ol0003o[H2Tojf0Y007ojf0Y003o`00
0?n`Rjoo/8^_00?o/8^_00?o0000oh]^[?n;KZ`03?n;KZ`01?l0003oK5f`ofaM/?l00008ocd`V003
o`000?lg?jko=cn^00Go=cn^0_l00007oaABc0;o00002olbQn`5o`0000WoGZOg00Go0000ogB_m_md
[oKoM:ofo`00000;ogB_mP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX04OoonfX0027o
oo]Z1_l0000AoookJP;o00001onac^l2o`0000Go//o_0ol00007ok;?k`;o00001_ncd>h2o`0000oo
]M7_0_l00007okOBkP03o`000?nie>ko^MC^00[o^MC^0_l0000:okcDk0;o00001onoen`2o`00017o
`mOY00Go0000olGFioo5e^OoaMKWo`00000<olcHh`03o`000?o=e^7ocMKQ00gocMKQ00?o0000omGD
f?l000004?oBd]P00ol0003ocmCNoloDgP08oloDgP03o`000?oBbm;od/_B00?od/_B0_l0000?ol_D
h003o`000?o9a=KobLCF00;obLCF00?o0000okgDjonme>/03Onme>/00ol0003o]l7RokO1hP09okO1
hP?o00000onXc_@00ol0003oZ<3[ojS0j`0?ojS0j`03o`000?nV^nSoY[_X00OoY[_X0ol00006oj_4
k003o`000?ndbnco]<_/00Wo]<_/0_l0000<ol;=hP03o`000?oGgmgo000000[ohLc300?o0000om^i
]ooK^KL02ooK^KL00ol0003ohk:Ro`00000BomNVY003o`000?n]P:Co[H2T00Go[H2T00?o0000ok2;
[on`Rjl01?n`Rjl00ol0003oRfj/oh]^[00<oh]^[004o`000?m/GK3oK5f`ofaM/0;o00001_lm<9P0
0ol0003o=cn^ocLo[P06ocLo[P;o00002?lDD/`00ol0003o<XO/oc:7k009oc:7k004o`000?mPWo;o
H9obof2OlPGo00001OmNYoL01Ol0003oM:ofogB_m_md[oKo000000_oM:of00?o0000oookJ_oonfX0
;OoonfX00ol0003ooo]ZoookJP0AoookJP008OoonfX5o`00013ooo]Z0_l0000;ok7>k`Go00002?nb
cnl2o`0000[o/m3^00?o0000okGAkonedNl02OnedNl3o`0000[o]m;^0_l00008okWDkP;o00003_nl
e>`2o`0000?o_mO/0_l0000Aol?Gj@;o00001Oo5e^L2o`0000Soc=SS0_l0000@olgFh@?o00003_oB
d]P2o`0000cocmCN00Go0000om;;d_oBbm;od/_Bo`00000Bol_Dh004o`000?o9a=Ko0000o`00017o
_MC[00?o0000okO1h_ng`N801?ng`N84o`0000OoZ<kd00?o0000ojS0jonX`>/03onX`>/00ol0003o
Y[_XojJkj003ojJkj0?o00002_n[a>`00ol0003o]<_/okC;k007okC;k003o`000?o2cN;o`/gR00co
`/gR0_l0000;on7<``03o`000?oK^KOofkVg00cofkVg00?o0000omNVY?oGYZ@04OoGYZ@00ol0003o
[H2Tojf0Y004ojf0Y003o`000?n`Rjoo/8^_00Go/8^_00?o0000oh]^[?n;KZ`03?n;KZ`00ol0003o
K5f`ofaM/003ofaM/003o`000?lm<9So?C2H00?o?C2H00?o0000ocLo[_lg?jh01olg?jh00ol0003o
55;<oaABc007oaABc003o`000?lbQnco<XO/00Wo<XO/00?o0000of2Ol_mPWo801OmPWo85o`000003
oejWmol0003oM:of00;oM:of00?o0000ogB_m_md[oH02?md[oH00ol0003ooo]ZoookJP0^oookJP03
o`000?oonf[ooo]Z013ooo]Z000QoookJPGo00003OoonfX3o`0000co/Lk_1?l00008ok;?k`;o0000
3Oncd>h00ol0003o]M7_okGAk`06okGAk`;o00003ongd^h2o`0000Co^MC^0_l0000BokcDk003o`00
0?noenco000001;o`mOY00?o0000olGFioo5e^L01oo5e^L00ol0003oc=SSolcHh`04olcHh`03o`00
0?o=e^7ocMKQ00oocMKQ00Go0000olcFhOo<e^7oc=KQo`00000<om;Bf003o`000?o?e=kocmCN00go
cmCN00?o0000om;;d_l000004oo;e>03o`0001?o_MC[00?o0000okO1h_ng`N800ol0000<ojS>m003
o`000?nX`>_oZ<3[00ooZ<3[00?o0000ojJkj?l000000_l0000>oj_4k003o`000?ndbnco]<_/00Co
]<_/0_l0000>ol;=hP03o`000?o9a=Go000000[ohLc300?o0000om^i]ooK^KL03OoK^KL00ol0003o
ejJTomNVY00AomNVY003o`000?n]P:Co[H2T00?o[H2T00?o0000ok2;[on`Rjl01on`Rjl00ol0003o
Rfj/oh]^[00;oh]^[003o`000?m/GK3oK5f`00CoK5f`00?o0000ocd`V?lm<9P00_lm<9P00ol0003o
=cn^ocLo[P08ocLo[P;o00002?lDD/`2o`0000[o<XO/00?o0000of2Ol_mPWo802OmPWo8;o`0000Ko
M:of00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0@oookJP008OoonfX5o`0000_ooo]Z
0_l0000<ok7>k`?o00001?nac^l2o`0000Co//o_0_l0000@ok?@kP;o00001?nedNl2o`0001?o]m;^
00Co0000okWDk_l0003o00005?nle>`3o`00013o`mOY0_l0000;olGFi`;o00000oo<f><00ol0003o
cMKQolgFh@0>olgFh@;o00001Oo<e^42o`0000Wod];H00?o0000oloDg_o?e=h03_o?e=h3o`00017o
bmCP0_l00003okkVlP03o`000?nme>_o_MC[013o_MC[0ol0000@ojS>m003o`000?nX`>_oZ<3[00go
Z<3[0ol0000Boj_4k004o`000?ndbnco]<_/okC;k0;o00003oo2cN801Ol0003obLCEolW4eOo9a=Go
000000WohLc300?o0000om^i]ooK^KL03?oK^KL2o`0001?oejJT00?o0000ojf0Y?n]P:@00_n]P:@0
0ol0003o/8^_ok2;[`08ok2;[`03o`000?n;KZcoRfj/00coRfj/00?o0000ofaM/?m/GK001?m/GK00
0ol0003o?C2Hocd`V002ocd`V003o`000?lg?jko=cn^00Oo=cn^00?o0000odYTbol000001olDD/`0
0ol0003oBH7To`000002o`0000Oo<XO/00?o0000of2Ol_mPWo802omPWo801Ol0003oMJWcogFYlome
ZO?o000000CoMJWc2?l0000^oookJP03o`000?oonf[ooo]Z013ooo]Z000PoookJPKo00002OoonfX3
o`0000[o/Lk_0ol00009ok7>k`04o`000?nbcnoo0000o`0001Co/m3^00Co0000okGAkol0003o0000
5Ongd^h3o`0001?o_=C/0_l00003okkDj`;o00003Oo3enT00ol0003oaMKWolGFi`0=olGFi`03o`00
0?o<f>?o0000013ocMKQ00?o0000olcFhOo<e^401oo<e^400ol0003od];Hom;Bf004om;Bf0;o0000
4?o?e=h01Ol0003ob]kWol[Nioo:g^Oo000000oobmCP00?o0000okkVl_nni_801?nni_82o`0000go
_MC[0ol00003oicTo@03o`000?nXc_CoZ<kd00koZ<kd00?o0000ojS0jonX`>/02OnX`>/3o`0000;o
XLKb00?o0000oj_4k?n[a>`04On[a>`00ol0003o]<_/o`00000@ol;=hP03o`000?o9a=GobLCE00?o
bLCE00?o0000on7<`ooQc<<01OoQc<<00ol0003ofkVgom^i]`0<om^i]`04o`000?o?[[Socjjho`00
01;oejJT00Go0000ojf0Y?n]P:Co[H2To`00000;ok2;[`03o`000?n;KZcoRfj/00coRfj/00?o0000
ofaM/?m/GK001Om/GK02o`0000;o?C2H00?o0000ocLo[_lg?jh02?lg?jh01?l0003oBVC;o`000?l0
0006oaABc004o`000?m9PNCoBH7TodV1i0?o00001OlbQn`00ol0003oH9obof2OlP0;of2OlP05o`00
0?meZO?oMJWcogFYlol000002_meZO<00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z013o
oo]Z000PoookJPKo00001_oonfX3o`0000?o/<g_00?o0000ok7>konac^l01?nac^l3o`0000co/Lk_
0ol0000Eok?@kP?o00005?ngd^h2o`0000?o^M;]00?o0000okcDk?nle>`03onle>`00ol0003o_]C[
okkDj`05okkDj`03o`000?o3enWo`mOY00So`mOY0_l0000@olGFi`?o00003oo=e^400ol0003oc=KQ
olcFh@09olcFh@;o00000ooBd]P00ol0003ocmCNoloDgP0>oloDgP;o00001Oo:g^L00ol0003obmCP
ol_Dh00:ol_Dh0;o00002Onni_800ol0003o_MC[okgDj`07okgDj`?o00001onLi?d00ol0003oZ<kd
ojS>m00>ojS>m003o`000?nX`>_oZ<3[00CoZ<3[1?l00006oj76lP03o`000?n[a>coZlC/013oZlC/
0ol0000>ol;=hP;o00001oo9a=D00ol0003ohLc3on7<``03on7<``03o`000?oK^KOofkVg00gofkVg
00Co0000oln^^?o?[[So00004ooGYZ@00ol0003o[H2To`00000<ok2;[`03o`000?n;KZcoRfj/00co
Rfj/00?o0000ofaM/?m/GK001om/GK000ol0003o?C2Ho`00000:ocLo[P04o`000?m:I<_oBVC;odYT
b`;o00001OlDD/`00ol0003oBH7TodV1i003odV1i0;o00001?lbQn`00ol0003oH9obof2OlP0;of2O
lP05o`000?meZO?oMJWcogFYlol000002_meZO<00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z013ooo]Z000PoookJPKo00001?oonfX2o`0000Oo/<g_0_l000001?nac^oo0000o`000?l0000<
ok7>k`?o00000onbc^h00ol0003o/m3^ok?@kP0@ok?@kP;o00000oned>h00ol0003o]m;^okOBkP0@
okOBkP03o`000?nid^go^M;]00Co^M;]0_l0000=okcDk0;o00002Onne>/2o`0000Oo`mOY00?o0000
olGFioo5e^L03oo5e^L01Ol0003oa]KUolKFiOo6e^Go000000cocMKQ0_l0000>olcFh@03o`000?oB
d]So0000013ocmCN00?o0000ol[Nioo:g^L01_o:g^L00ol0003obmCPol_Dh007ol_Dh0;o00003?nn
i_82o`0000Go_MC[0_l0000;oicTo@;o00003onXc_@00ol0003oZ<3[ojS0j`03o`0000_oXLKb00?o
0000oj_4k?n[a>`03?n[a>`3o`0000?o/<CX00?o0000ol;=h_o2cN802_o2cN800ol0003obLCEolW4
e@08olW4e@03o`000?oQc<?ohLc300;ohLc300?o0000om^i]ooK^KL03?oK^KL01Ol0003ocjjholn^
^?o?[[So000001?oejJT0_l0000>ok2;[`03o`000?n;KZcoRfj/00_oRfj/00?o0000ofaM/?m/GK00
2?m/GK02o`0000_o=cn^00?o0000odYTbom:I</00_m:I</00ol0003o55;<oaABc002oaABc003o`00
0?m9PNCoBH7T00GoBH7T0ol000000olbQnco0000of2OlP0<of2OlP05o`000?meZO?oMJWcogFYlol0
00002omeZO<00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z013ooo]Z000PoookJPKo0000
00Cooo]Zo`000?l0003o00002_n`cNl2o`0000go/Lk_0_l00007ok;>kP;o00003_ncd>h2o`0000Ko
]M3^0_l0000>okOBkP;o00002Onid^d00ol0003o_=C/okcDk008okcDk0;o00003Onne>/2o`0000?o
`mOY0_l0000@olGFi`;o00001Oo6e^D2o`0000WocMKQ00?o0000olcFhOo<e^403_o<e^43o`0000oo
cmCN00?o0000ol[Nioo:g^L02?o:g^L00ol0003obmCPol_Dh004ol_Dh0;o00004?nni_800ol0003o
_MC[o`000002o`0000ooW>Cm00?o0000ojS>m?nXc_@02_nXc_@5o`0000ooXLKb00?o0000oj_4k?n[
a>`02On[a>`2o`0000Oo/<CX00?o0000ol;=h_o2cN802?o2cN800ol0003obLCEolW4e@0:olW4e@04
o`000?oQc<?ohLc3o`0000kofkVg00?o0000oln^^?o?[[P00oo?[[P00ol0003oejJTomNVY00@omNV
Y003o`000?n`Rjoo/8^_00go/8^_00?o0000oh]^[?n;KZ`03?n;KZ`00ol0003oK5f`ofaM/008ofaM
/0;o00002_lg?jh00ol0003oBVC;odYTb`03odYTb`;o00000olDD/`00ol0003oBH7TodV1i007odV1
i0?o00003OmPWo801Ol0003oMJWcogFYlomeZO?o000000_oMJWc00?o0000oookJ_oonfX0:OoonfX0
0ol0003ooo]ZoookJP0@oookJP008?oonfX7o`0000[o/<g_0ol00002ok3=k`03o`000?nac^oo/Lk_
00Oo/Lk_0ol0000;ok;>kP03o`000?ncd>ko/m3^00Wo/m3^0_l0000:okG@kP;o00002_ngd^h2o`00
00co^M;]00?o0000okcDk?nle>`01Onle>`2o`00017o_]C[00?o0000ol?GjOl000004Oo5e^L00ol0
003oa]KUolKFi@07olKFi@03o`000?o=e^7ocMKQ00CocMKQ0_l0000@olcFh@05o`000?o:fNCob]WT
ol[Ii?l000003?o?e=h2o`0000cob]kW00?o0000ol_Dh?o;e>000_o;e>000ol0003o_^KbokkVlP0@
okkVlP?o00004_nLi?d00ol0003oZ<kdojS>m002ojS>m0Oo00001On9dOl00ol0003oXLKboj76lP0=
oj76lP03o`000?n[a>coZlC/00KoZlC/0_l0000:ok34j003o`000?o2cN;o`/gR00Go`/gR0_l0000>
olW4e@03o`000?oQc<?o000000kofkVg00?o0000oln^^?o?[[P00oo?[[P00ol0003oejJTomNVY00@
omNVY003o`000?n`Rjoo/8^_00go/8^_00?o0000oh]^[?n;KZ`03?n;KZ`00ol0003oK5f`ofaM/009
ofaM/0;o00002Olg?jh00ol0003oBVC;odYTb`05odYTb`04o`000?lDD/co55;<o`0000coBH7T1?l0
000:of2OlP05o`000?meZO?oMJWcogFYlol000002omeZO<00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z00oooo]Z000PoookJPGo00002On`cNl3o`0000Ko/<g_0_l00005ok7>k`;o00003onb
c^h00ol0003o/m3^ok?@kP06ok?@kP;o00003_ned>h00ol0003o]m;^okOBkP05okOBkP;o00003oni
d^d2o`0000Co_=C/00?o0000okkDjonne>/04Onne>/3o`00013oaMKW00?o0000olKFiOo6e^D02Oo6
e^D2o`0000?ocMKQ00?o0000olcFhOo<e^403_o<e^42o`0000Gob]WT0_l00009oloDgP03o`000?o:
g^Oob]kW00gob]kW00Co0000ol_Dh?l0003o00004?nni_83o`0000?oKmoK0ol0000=oicTo@Oo0000
3On9dOl00ol0003oXLKboj76lP0=oj76lP03o`000?n[a>coZlC/00;oZlC/0ol0000=ok34j003o`00
0?o2cN;o`/gR00?o`/gR00?o0000olW4eOo9a=D03_o9a=D2o`0000kofkVg00?o0000oln^^?o?[[P0
1?o?[[P00ol0003oejJTomNVY00?omNVY0;o00003on`Rjl00ol0003oRfj/oh]^[00<oh]^[003o`00
0?m/GK3oK5f`00WoK5f`00?o0000ofAT_Ol000002Olg?jh00ol0003oBVC;odYTb`05odYTb`;o0000
00?o55;<o`000?m9PN@02_m9PN@01?l0003oJ9W/ofRIk?mXVN`5o`0000GoH9ob00Go0000ogFYlome
ZO?oMJWco`00000;ogFYl`03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX03ooonfX001oo
oo]Z1?l00008ok3=k`?o00002on`cNl00ol0003o/Lk_o`000002o`0001;o//k^0_l00004ok?@kP;o
00004Oned>h2o`0000Co]m;^00?o0000okWBkOnid^d04Onid^d01?l0003o_=C/o`000?l0000BokkD
j`;o00000oo0e>T2o`0000coaMKW0_l0000>olKFi@03o`000?o=e^7o0000013oc=KQ00?o0000ol[I
i?o:fN@01oo:fN@00ol0003ocmCNoloDgP04oloDgP;o00004?o:g^L4o`0000go_^Kb0ol00009ofoO
f`?o00000onLi?d7o`0000Go6JNk00?o0000ohWAoon9dOl03On9dOl00ol0003oXLKboj76lP0=oj76
lP04o`000?n[a>co0000o`00017o/<CX00Go0000ol;=h_o2cN;o`/gRo`00000@olW4e@03o`000?o8
^Lco000000gofkVg00?o0000oln^^?o?[[P01_o?[[P00ol0003oejJTomNVY00=omNVY004o`000?o1
WKGo`Ifeo`0000oo/8^_00?o0000oh]^[?n;KZ`02on;KZ`00ol0003oK5f`ofaM/00:ofaM/004o`00
0?mTI;go0000o`0000Oo=cn^00?o0000odYTbom:I</01om:I</3o`0000_oBH7T00?o0000ofRIk?mX
VN`01OmXVN`5o`000003of2Ol_l0003oMJWc00;oMJWc00?o0000ogFYlomeZO<02OmeZO<00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00oooo]Z000OoookJPGo00001?n`cNl3o`0000ko/<g_
0ol0000Fok;>kP04o`000?ncd>ko0000o`0001Go]M3^00Co0000okOBk_l0003o00005?nid^d3o`00
01;o_]C[00?o0000ol3DjOo0e>T01Oo0e>T00ol0003oaMKWolGFi`08olGFi`03o`000?o6e^Goa]KU
00koa]KU0ol0000?olcFh@03o`000?o:fNCob]WT00Wob]WT0_l00003oloDgP03o`000?o:g^Oob]kW
00oob]kW00?o0000okgalonmlO<00_nmlO<3o`0000Oo_^Kb0ol00008ofoOf`_o00001?nGKJ400ol0
003oOEfSo`000002o`0000?o6JNk0_l0000>ohWAo`03o`000?nQa_;oXLKb00_oXLKb0ol0000Dok34
j003o`000?o2cN;o0000013obLCE00Go0000olRic?o8^Lcob;W<o`00000<om^i]`03o`000?o?[[So
cjjh00Kocjjh00?o0000omNVY?oGYZ@03?oGYZ@01Ol0003o`Ifeol6M]Oo1WKGo000000oo/8^_00?o
0000oh]^[?n;KZ`03?n;KZ`00ol0003oK5f`ofaM/009ofaM/004o`000?mTI;goI6BmofAT_@;o0000
1_lg?jh00ol0003oBVC;odYTb`08odYTb`03o`000?m9PNCoBH7T00[oBH7T00?o0000ofRIk?mXVN`0
2OmXVN`<o`0000KoMJWc00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0?oookJP007ooo
nfX9o`0000oo/<g_0_l00003ok7=kP03o`000?nbc^ko//k^01?o//k^0ol0000FokG@kP?o00004oni
d^d2o`0000?o^m;[0_l0000>okkDj`;o00002Oo0e>T2o`0000KoaMKW0_l0000@olKFi@05o`000?o7
enKoamOVolOGi_l000003?o<e^42o`0000kob]WT00?o0000oloDg_l000004?o:g^L2o`0000So_O7c
0ol000000onni_;o0000o`00000<o`000003omBQX_l0003oUffQ00coUffQ00?o0000ogeMXommGJ<0
0_mmGJ<4o`000003oaVW^ol0003o000000goRM7o00?o0000oj76l_nQa_801OnQa_85o`0000?oVl;c
00?o0000ok34j?n`a>P04On`a>P2o`00013obLCE00?o0000olRic?o8^L`00_o8^L`00ol0003ofkVg
om^i]`09om^i]`03o`000?o?[[Socjjh00Oocjjh00?o0000omNVY?oGYZ@02ooGYZ@00ol0003o`Ife
ol6M]@02ol6M]@03o`000?n`Rjoo/8^_00go/8^_00?o0000oh]^[?n;KZ`03?n;KZ`00ol0003oK5f`
ofaM/009ofaM/003o`000?mTI;goI6Bm00?oI6Bm00?o0000ocLo[_lg?jh00olg?jh00ol0003oBVC;
odYTb`09odYTb`;o00002_m9PN@00ol0003oJ9W/ofRIk00;ofRIk003o`000?miYNooNJG_00;oNJG_
00?o0000ogVUkomiYNl00_miYNl8o`0002Sooo]Z00?o0000oookJ_oonfX03ooonfX001oooo]Z2?l0
000>ok3=k`;o00001_nacNh00ol0003o//k^ok;>kP0@ok;>kP;o00000ondc^d00ol0003o]M3^okG@
kP0AokG@kP;o00000ongd>d00ol0003o^M;]okWBk@0?okWBk@03o`000?nkd^_o^m;[00Go^m;[00?o
0000okkDjonne>/02Onne>/2o`0000go`=CY0_l00003olGFi`03o`000?o6e^Goa]KU00koa]KU0_l0
0005olOGiP;o00002Oo<e^400ol0003ob]WTol[Ii00>ol[Ii0?o00003_o:g^L2o`0000co_O7c1ol0
0002omJWZ003o`000?oDXJ;oe:6R00Goe:6R00?o0000oiM]XOnGKJ402onGKJ400ol0003oOEfSogeM
X`06ogeMX`Co00003On9dOl00ol0003oXLKboj76lP04o`0000WoVl;c00?o0000ok34j?n`a>P03_n`
a>P2o`000003ok>mhOl0003obLCE00kobLCE00?o0000olRic?o8^L`01?o8^L`00ol0003ofkVgom^i
]`08om^i]`03o`000?o?[[Socjjh00Socjjh00?o0000omNVY?oGYZ@02OoGYZ@00ol0003o`Ifeol6M
]@03ol6M]@03o`000?n`Rjoo/8^_00go/8^_00?o0000oh]^[?n;KZ`03?n;KZ`00ol0003oK5f`ofaM
/00:ofaM/003o`000?mTI;goI6Bm00?oI6Bm0_l00004ocLo[P03o`000?m:I<_oBVC;00SoBVC;00?o
0000of63gOl000000_l00008odV1i003o`000?mXVNcoJ9W/00_oJ9W/00Go0000ogVUkomiYNooNJG_
o`00000;ogVUk`03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX03ooonfX001?ooo]Z0ol0
07l9oookJPGo00000ooonfX00ol0003o/<g_ok3=k`09ok3=k`;o00002OnacNh2o`0000ko//k^0_l0
0006okC>k@;o00003oned>h2o`0000Ko]m3]0_l0000=okWBk@;o00002Onkd^/2o`0000Oo_]C[0_l0
000Aol3Dj@03o`000?o5e^Oo0000013oa]KU00?o0000olOGi_o7enH01oo7enH00ol0003oc=KQolcF
h@04olcFh@;o00004?o:fN@01?l0003ob>;[olSRjoo8h^/2o`0000_ob]kW00?o0000okgalonmlO<0
2_nmlO<2o`000004oeK<[Ol0003o0000o`0000GoeZNX00?o0000omBQX_oDXJ801OoDXJ800ol0003o
UffQoiM]X@0;oiM]X@03o`000?mmGJ?oOEfS00SoOEfS4_l0000>oi_2l`03o`000?n`a>So/<CX00_o
/<CX0_l00004ok>mh@03o`000?o9a=GobLCE00_obLCE00?o0000olRic?o8^L`01_o8^L`00ol0003o
fkVgom^i]`06om^i]`03o`000?o?[[Socjjh00Wocjjh00?o0000omNVY?oGYZ@02?oGYZ@00ol0003o
`Ifeol6M]@05ol6M]@03o`000?n`Rjoo/8^_00co/8^_00?o0000oh]^[?n;KZ`03?n;KZ`00ol0003o
K5f`ofaM/00:ofaM/003o`000?mTI;goI6Bm00GoI6Bm00Go0000ocLo[_lg?jko=cn^o`00000;odYT
b`04o`000?mQPmgoHH?Mof63g@?o00001Om9PN@00ol0003oJ9W/ofRIk00<ofRIk005o`000?miYNoo
NJG_ogVUkol000002omiYNl00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z00oooo]Z000C
oookJP?o001o2OoonfX5o`0000Cooo]Z0_l00007ok3=k`;o00003OnacNh00ol0003o//k^ok;>kP09
ok;>kP;o00002_ndc^d2o`0000_o]M3^0_l0000:okO@k@03o`000?nid^go^M;]00So^M;]0_l0000=
ok_Bj`;o00001?nne>/00ol0003o`=CYol3Dj@0Aol3Dj@?o00003oo6e^D00ol0003oamOVolOGiP09
olOGiP;o00000oo<e^400ol0003ob]WTol[Ii00>ol[Ii0;o00001_o8h^/2o`0000Oob]kW0_l0000;
okgal`Go00002?oFYjP00ol0003oe:6RomBQXP05omBQXP03o`000?nGKJ7oUffQ00_oUffQ00?o0000
ogeMXommGJ<02OmmGJ<01?l0003o<2ZIoc0ZVOl0000<oenmo@03o`000?nK`_?oVl;c00goVl;c00?o
0000ok34j?n`a>P02?n`a>P2o`0000Oo/kgQ00?o0000olW4eOo9a=D02?o9a=D2o`0000Wob;W<00?o
0000om^i]ooK^KL01OoK^KL00ol0003ocjjholn^^00:oln^^003o`000?oGYZCoejJT00OoejJT00?o
0000ol6M]Oo1WKD01_o1WKD00ol0003o/8^_ok2;[`0=ok2;[`03o`000?n;KZcoRfj/00coRfj/00?o
0000ofaM/?m/GK002Om/GK000ol0003oI6BmofAT_@06ofAT_@;o000000?o=cn^o`000?m:I</02_m:
I</00ol0003oHH?Mof63g@04of63g@;o00001?m9PN@00ol0003oJ9W/ofRIk00<ofRIk005o`000?mi
YNooNJG_ogVUkol000002omiYNl00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z00oooo]Z
000CoookJP?o001o2OoonfX6o`0000Gooo]Z00?o0000ok3=kon`cNl00_n`cNl2o`00013o/Lg^0_l0
0007ok;>kP;o00003_ndc^d00ol0003o]M3^okG@kP06okG@kP;o00003Ongd>d00ol0003o^M;]okWB
k@05okWBk@;o00004Onkd^/01?l0003o_]C[o`000?l0000Bol3Dj@;o00000oo2e>P00ol0003oa]KU
olKFi@0:olKFi@;o00003_o7enH00ol0003oc=KQo`00000@ol[Ii003o`000?o8h^_ob>;[00Sob>;[
00?o0000ol[Nioo:g^L00_o:g^L2o`0000_o_O7c1?l0000:omJWZ003o`000?oDXJ;oe:6R00Koe:6R
00?o0000oiM]XOnGKJ402onGKJ400ol0003oOEfSogeMX`09ogeMX`04o`000?l`:YWo<2ZIoc0ZV@;o
00002omO_Od00ol0003oVl;coi_2l`0=oi_2l`03o`000?n`a>So/<CX00Go/<CX0_l0000:ok>mh@03
o`000?o9a=GobLCE00KobLCE00?o0000olRic?o8^L`02_o8^L`00ol0003ofkVgom^i]`04om^i]`03
o`000?o?[[Socjjh00_ocjjh00?o0000omNVY?oGYZ@01_oGYZ@00ol0003o`Ifeol6M]@06ol6M]@03
o`000?n`Rjoo/8^_00go/8^_00?o0000oh]^[?n;KZ`03?n;KZ`00ol0003oK5f`ofaM/00:ofaM/003
o`000?mTI;goI6Bm00OoI6Bm0ol0000;odYTb`03o`000?mQPmgoHH?M00GoHH?M0ol00002odV1i003
o`000?mXVNcoJ9W/00coJ9W/00Co0000ogVUkomiYNoo00002omiYNl00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z00kooo]Z0003oookJP[o001o1_oonfX3o`00O`oooo]Z00?o0000oookJ_oo
nfX00ooonfX01?l0003o/<g_o`000?l0000Dok7=kP03o`000?nbc^ko//k^00;o//k^0_l0000AokC>
k@;o00001?ned>h2o`00013o]m3]0_l00004okWBk@03o`000?nkd^_o^m;[017o^m;[0ol0000Bol3D
j@03o`000?o2e>So`]CX00Co`]CX0_l00009olKFi@03o`000?o7enKoamOV00koamOV0ol0000?ol[I
i003o`000?o8h^_ob>;[00[ob>;[0_l000000oo:g^Oo0000okgal`0:okgal`?o000000?on=6Ro`00
0?oFYjP02_oFYjP00ol0003oe:6RomBQXP07omBQXP03o`000?nGKJ7oUffQ00_oUffQ00?o0000ogeM
XommGJ<02?mmGJ<00ol0003o<2ZIoc0ZV@02oc0ZV@;o00002omO_Od00ol0003oVl;coi_2l`0=oi_2
l`03o`000?n`a>So/<CX00;o/<CX0_l0000=ok>mh@03o`000?o9a=GobLCE00CobLCE00?o0000olRi
c?o8^L`02oo8^L`00ol0003ofkVgom^i]`03om^i]`03o`000?o?[[Socjjh00cocjjh00?o0000omNV
Y?oGYZ@01OoGYZ@00ol0003o`Ifeol6M]@07ol6M]@03o`000?n`Rjoo/8^_00go/8^_00?o0000oh]^
[?n;KZ`03?n;KZ`00ol0003oK5f`ofaM/00:ofaM/003o`000?mTI;goI6Bm00WoI6Bm00?o0000odYT
bom:I</02Om:I</00ol0003oHH?Mof63g@08of63g@?o00003_mXVN`01Ol0003oNJG_ogVUkomiYNoo
000000_oNJG_00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0>oookJP000ooonfX:o`00
O`Kooo]Z0ol007l@oookJP;o00001?oonfX2o`0001Ko/Lg^00Co0000ok;>k_l0003o00005Ondc^d0
1?l0003o]M3^o`000?l0000DokO@k@04o`000?nid^go0000o`0001;o^m;[0_l00003okgBjP;o0000
3_o0e>T2o`0000Wo`]CX00?o0000olKFiOo6e^D01?o6e^D2o`00013oamOV00Go0000olOJioo7f^Oo
am[Wo`00000<ol[Ii0;o00003_o8h^/4o`0000So_O7c1?l000000oohdJ;o0000omJWZ00;omJWZ003
o`000?oDXJ;oe:6R00Ooe:6R00?o0000oiM]XOnGKJ402onGKJ400ol0003oOEfSogeMX`08ogeMX`03
o`000?l`:YWo<2ZI00?o<2ZI0_l0000;oenmo@03o`000?nK`_?oVl;c00goVl;c00Co0000ok34j?l0
003o00003onc_N400ol0003obLCEolW4e@03olW4e@03o`000?o8^Lcob;W<00gob;W<00Go0000om^i
]ooK^KOofkVgo`00000?oln^^003o`000?oGYZCoejJT00CoejJT00?o0000ol6M]Oo1WKD02Oo1WKD0
0ol0003o/8^_ok2;[`0<ok2;[`03o`000?n;KZcoRfj/00coRfj/00?o0000ofaM/?m/GK002_m/GK00
0ol0003oI6BmofAT_@0:ofAT_@;o00002_m:I</00ol0003oHH?Mof63g@0:of63g@Go00002_mXVN`0
1Ol0003oNJG_ogVUkomiYNoo000000_oNJG_00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Zoook
JP0>oookJP004ooonfX3o`00Oa;ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o/Lg^ok7=kP0C
ok7=kP?o00005_ndc^d3o`0001Go]m3]0ol0000Bok_Bj`03o`000?nmd^[o_M;Z00Go_M;Z00?o0000
ol3DjOo0e>T02Oo0e>T2o`0000co`]CX0_l00003olKFi@03o`000?o7enKoamOV00koamOV0_l00005
olOJi`;o00002Oo:fN@00ol0003ob>;[olSRj`0=olSRj`03o`000?o1l_3o`O;`00;o`O;`1?l00002
okgal`;o000000?oS>c9o`000?ohdJ800_ohdJ800ol0003oeZNXomJWZ00:omJWZ003o`000?oDXJ;o
e:6R00Ooe:6R00?o0000oiM]XOnGKJ402onGKJ400ol0003oOEfSogeMX`08ogeMX`03o`000?l`:YWo
<2ZI00?o<2ZI00?o0000o`0^]?l000001?l00007oenmo@03o`000?nK`_?oVl;c00[oVl;c1?l0000B
ok>mh@05o`000?o9a=GobLCEolW4eOl000004Oo8^L`01?l0003ofkVgom^i]ol0000@oln^^003o`00
0?oGYZCoejJT00;oejJT00?o0000ol6M]Oo1WKD02_o1WKD00ol0003o/8^_ok2;[`0=ok2;[`03o`00
0?n;KZcoRfj/00coRfj/00?o0000ofaM/?m/GK002_m/GK000ol0003oI6BmofAT_@09ofAT_@04o`00
0?mYMlko0000o`0000WoBVC;00?o0000of63gOmQPmd02OmQPmd00ol0003oLYOVog:GiP02og:GiPWo
00000_mXVN`01Ol0003oNJG_ogVUkomiYNoo000000[oNJG_00?o0000oookJ_oonfX08ooonfX00ol0
003ooo]ZoookJP0>oookJP004ooonfX3o`00Oa?ooo]Z00?o0000oookJ_oonfX00ooonfX2o`00013o
/Lg^0ol00003ok?=k@03o`000?ndc^go]<k]017o]<k]0_l00003okG?k@03o`000?ngd>go]m3]013o
]m3]0_l00003okW@k0;o00003_nkd^/2o`0000Wo_M;Z0_l00007ol3Dj@;o00004?o2e>P00ol0003o
a]KUo`00000@olOGiP03o`000?o7f^Ooam[W00Ooam[W00?o0000ol[Ii?o:fN@01?o:fN@2o`0000ko
b>;[0_l00009ol7bl0;o000000?oS>c9o`000?l000001?ohdJ800ol0003oeZNXomJWZ009omJWZ003
o`000?oDXJ;oe:6R00Soe:6R00?o0000oiM]XOnGKJ402onGKJ400ol0003oOEfSogeMX`09ogeMX`03
o`000?l`:YWo<2ZI00?o<2ZI00Co0000o`0^]?l0;[Co00000_mCWO@7o`000003oenmoOl0003oVl;c
00?oVl;c1ol00003oiRek003o`000?nc_N7o/kgQ017o/kgQ00?o0000olW4eOl000004_o8^L`00ol0
003ofkVgo`00000Aoln^^005o`000?oGYZCoejJTomNVY?l000003Oo1WKD00ol0003o/8^_ok2;[`0=
ok2;[`03o`000?n;KZcoRfj/00coRfj/00?o0000ofaM/?m/GK002_m/GK000ol0003oI6BmofAT_@0:
ofAT_@03o`000?mYMlkoJGO>00?o00001_m:I</00ol0003oHH?Mof63g@0:of63g@03o`000?mbUnKo
LYOV00[oLYOV3?l00006ogVUk`03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX03_oonfX0
01?ooo]Z0ol007lDoookJP03o`000?oonf[ooo]Z00Cooo]Z0_l0000<ok7=kP;o00001onccNd2o`00
00oo]<k]0_l00006okG?k@;o00003_ngd>d2o`0000Oo^M3/00?o0000ok_Bjonkd^/02Onkd^/2o`00
00go_M;Z0_l00004ol3Dj@03o`000?o2e>So`]CX013o`]CX0ol0000>olOGiP;o00002oo7f^L2o`00
00?ob]WT00?o0000olSRjoo8h^/03Oo8h^/00ol0003o`O;`ol7bl008ol7bl004o`000?n<k<Wo0000
o`0000?on=6R0ol0000<omJWZ003o`000?oDXJ;oe:6R00Soe:6R00?o0000oiM]XOnGKJ402onGKJ40
0ol0003oOEfSogeMX`09ogeMX`03o`000?l`:YWo<2ZI00?o<2ZI00Go0000o`0^]?l0;[Co02jdo`00
0008oe>Mm0Ko00002onH]N`00ol0003o/kgQok>mh@0@ok>mh@;o00004oo8^L`2o`0001;ocjjh00Co
0000omNVY?oGYZCo00003_o1WKD00ol0003o/8^_ok2;[`0=ok2;[`03o`000?n;KZcoRfj/00coRfj/
00?o0000ofaM/?m/GK002_m/GK000ol0003oI6BmofAT_@0:ofAT_@03o`000?mYMlkoJGO>00?oJGO>
0_l00005odYTb`03o`000?mQPmgoHH?M00[oHH?M00?o0000og:Gi_mbUnH03?mbUnH01Ol0003oOZ?[
ogjSjomnXn_o000000CoOZ?[2?l0000SoookJP03o`000?oonf[ooo]Z00kooo]Z000CoookJP?o001o
5OoonfX2o`0000Kooo]Z00?o0000ok7=k_nacNh01onacNh2o`0000_o/lg]0_l0000;okC>k@;o0000
2_necnd00ol0003o]m3]okO@k@09okO@k@;o00002_nid>`2o`0000Oo^m;[0_l0000AokgBjP04o`00
0?o0e>Wo0000o`00017o`]CX0_l00003ol?Fj0;o00002_o7enH2o`0000ooam[W00?o0000ol[Ii?l0
00003_o8h^/2o`0000Wo`O;`0_l000000on<k<Wo0000ooSAXP04o`0000;ojLRd00?o0000omJWZ?oF
YjP02_oFYjP00ol0003oe:6RomBQXP08omBQXP03o`000?nGKJ7oUffQ00_oUffQ00?o0000ogeMXomm
GJ<02OmmGJ<00ol0003o<2ZIoc0ZV@03oc0ZV@;o00000ol0;[@00ol0003oDigdoe>Mm007oe>Mm003
o`000?nH]NcoV;G/00goV;G/00?o0000ok>mhOnc_N403Onc_N42o`000003ok>cfOl0003ob;W<017o
b;W<00?o0000ol6_b?l000004oo?[[P2o`00013o`Ife00?o0000ok2;[on`Rjl03?n`Rjl00ol0003o
Rfj/oh]^[00<oh]^[003o`000?m/GK3oK5f`00_oK5f`00?o0000ofAT_OmTI;d02OmTI;d00ol0003o
JGO>ofUgcP05ofUgcP;o00000om:I</00ol0003oHH?Mof63g@0:of63g@03o`000?mbUnKoLYOV00go
LYOV00Go0000ogjSjomnXn_oOZ?[o`00000:ogjSj`03o`000?oonf[ooo]Z027ooo]Z00?o0000oook
J_oonfX03_oonfX0013ooo]Z1_l007lGoookJP03o`000?oonf[ooo]Z00Cooo]Z0_l00004ok7=kP?o
00003onccNd00ol0003o]<k]okC>k@06okC>k@;o00003Onecnd00ol0003o]m3]okO@k@06okO@k@;o
00003_nid>`2o`0000Co^m;[00?o0000okgBj_nmd^X04Onmd^X3o`00017o`]CX00?o0000ol?Fj?o3
e^P01Oo3e^P2o`0000OoamOV00?o0000olOJioo7f^L03oo7f^L3o`0000cob>;[0_l00009ol7bl0;o
000000?oS>c9o`000?l000000_l00005onW8]003o`000?oQ]Z[o000000[oeZNX00?o0000omBQX_oD
XJ802OoDXJ800ol0003oUffQoiM]X@0;oiM]X@03o`000?mmGJ?oOEfS00WoOEfS00?o0000oc0ZVOl`
:YT01?l`:YT00ol0003o02jdo`0^]002o`0^]003o`000?mCWOCoDigd00OoDigd00?o0000oiRek?nH
]N`03OnH]N`00ol0003o/kgQok>mh@0:ok>mh@;o00001?nc/mT00ol0003ob;W<olRic00>olRic005
o`000?o1[lSo`Jo8ol6_b?l000004_o?[[P00ol0003o`Ifeol6M]@0?ol6M]@03o`000?n`Rjoo/8^_
00go/8^_00?o0000oh]^[?n;KZ`03?n;KZ`00ol0003oK5f`ofaM/00:ofaM/003o`000?mTI;goI6Bm
00[oI6Bm00?o0000ofUgc_mYMlh01_mYMlh3o`000003odYTbol0003oHH?M00_oHH?M00?o0000og:G
i_mbUnH03OmbUnH01Ol0003oOZ?[ogjSjomnXn_o000000[oOZ?[00?o0000oookJ_oonfX08?oonfX0
0ol0003ooo]ZoookJP0>oookJP004?oonfX6o`00OaSooo]Z00?o0000oookJ_oonfX01OoonfX01?l0
003o/Lg^o`000?l0000Cok?=k@;o00001?ndc^d2o`00013o]Lo]0_l00004okO@k@;o00004_nid>`0
1?l0003o^m;[o`000?l0000BokgBjP;o00000onndnT00ol0003o`]CXol;Dj00<ol;Dj0;o00002_o3
e^P00ol0003oamOVolOGiP02olOGiP;o00004Oo7f^L01?l0003oan7[olOQjoo7hN/2o`0000Wob>;[
00?o0000ol7bl?o1l_002?o1l_001Ol0003oS>c9ohc/bOl0003odO>K00;o00001_oYb;@00ol0003o
hKJZo`00000:omJWZ003o`000?oDXJ;oe:6R00Woe:6R00?o0000oiM]XOnGKJ402onGKJ400ol0003o
OEfSogeMX`09ogeMX`03o`000?l`:YWo<2ZI00Co<2ZI00?o0000o`0^]?l0;[@00ol0;[@00ol0003o
Digdoe>Mm007oe>Mm003o`000?nH]NcoV;G/00goV;G/00?o0000ok>mhOnc_N401onc_N42o`0000Oo
/k?I00?o0000olRic?o8^L`03?o8^L`00ol0003o`Jo8ol6_b002ol6_b003o`000?o?[[Socjjh00oo
cjjh0_l0000Aol6M]@03o`000?n`Rjoo/8^_00go/8^_00?o0000oh]^[?n;KZ`03?n;KZ`00ol0003o
K5f`ofaM/00:ofaM/003o`000?mTI;goI6Bm00[oI6Bm00?o0000ofUgc_mYMlh02OmYMlh2o`0000go
HH?M00?o0000og:Gi_mbUnH03?mbUnH01Ol0003oOZ?[ogjSjomnXn_o000000_oOZ?[00?o0000oook
J_oonfX08?oonfX00ol0003ooo]ZoookJP0=oookJP004_oonfX4o`00OaWooo]Z00?o0000oookJ_oo
nfX01OoonfX2o`0001Ko/lg]00Co0000okC>kOl0003o00005?necnd01?l0003o]m3]o`000?l0000D
okW@k0?o00004_nmd^X00ol0003o_]?YokkCj@04okkCj@;o00002_o2e>P2o`0000go`mKX0_l00000
0oo7enKo0000olOJi`0@olOJi`;o00001_o7hN/3o`0000Cob>;[0_l00009ol7bl0;o000000CoS>c9
o`000?l0003odO>K0_l00007onW8]003o`000?oQ]Z[o000000[oeZNX00?o0000omBQX_oDXJ802_oD
XJ800ol0003oUffQoiM]X@0;oiM]X@03o`000?mmGJ?oOEfS00SoOEfS00?o0000oc0ZVOl`:YT01Ol`
:YT00ol0003o02jdo`0^]003o`0^]003o`000?mCWOCoDigd00OoDigd00?o0000oiRek?nH]N`03?nH
]N`00ol0003o/kgQok>mh@05ok>mh@;o00002Onc/mT00ol0003ob;W<olRic00:olRic0;o00001_o1
[lP00ol0003ocjjholn^^00=oln^^004o`000?o0Y[oo`:Joo`00013o`Ife00?o0000ok2;[on`Rjl0
3On`Rjl00ol0003oRfj/oh]^[00<oh]^[003o`000?m/GK3oK5f`00_oK5f`00?o0000ofAT_OmTI;d0
2_mTI;d00ol0003oJGO>ofUgcP0:ofUgcPCo00002_mQPmd00ol0003oLYOVog:GiP0<og:GiP05o`00
0?mnXn_oOZ?[ogjSjol000002_mnXn/00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z00go
oo]Z000CoookJP?o001o6_oonfX2o`0000Oooo]Z00?o0000ok?=kOnccNd04onccNd3o`0001Go]Lo]
0ol0000CokW@k0;o00000onjdN/2o`0000ko_M;Z0_l00009okkCj@03o`000?o2e>So`]CX00Go`]CX
0_l0000@ol?Fj0?o00004?o7f^L00ol0003oan7[olOQj`09olOQj`;o000000?ob>;[o`000?o1l_00
2?o1l_05o`000005okCh__l0003o0000on[Sb_l000001_oYb;@01Ol0003ohKJZon6fZ_oQ]Z[o0000
00SoeZNX00?o0000omBQX_oDXJ802ooDXJ800ol0003oUffQoiM]X@0;oiM]X@03o`000?mmGJ?oOEfS
00WoOEfS00?o0000oc0ZVOl`:YT01?l`:YT00ol0003o02jdo`0^]004o`0^]0?o00001omCWO@00ol0
003oV;G/oiRek00<oiRek003o`000?nc_N7o/kgQ00;o/kgQ0_l0000<ok>cf@03o`000?o8^Lcob;W<
00Sob;W<00?o0000ol6_b?o1[lP01_o1[lP00ol0003ocjjholn^^00<oln^^005o`000?o0Y[oo`:Jo
ol2V_ol000004Oo1WKD00ol0003o/8^_ok2;[`0<ok2;[`03o`000?n;KZcoRfj/00coRfj/00?o0000
ofaM/?m/GK002om/GK000ol0003oI6BmofAT_@0:ofAT_@03o`000?mYMlkoJGO>00[oJGO>00Co0000
og>:fomcR]_oLh[K1Ol00005of63g@03o`000?mbUnKoLYOV00coLYOV00?o0000ogjSjomnXn/00_mn
Xn/00ol0003oOZ?[ogjSj`08ogjSj`03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX03Ooo
nfX003;ooo]Z00?o0000oookJ_oonfX01OoonfX2o`00013o/lg]0ol00003okC=k@03o`000?necngo
]Lo]013o]Lo]0_l00003okO?k0;o00003onid>`2o`0000Oo^]7[00?o0000okgBj_nmd^X02Onmd^X2
o`0000co_]?Y0_l00004ol;Dj003o`000?o3e^So`mKX00oo`mKX00Go0000olCHj?o4f>Soa=SXo`00
000=olOJi`;o00003Oo7hN/7o`0000Co`O;`0ol000000oo4nnSo0000okCh_P02o`000003on[Sb_l0
003ojLRd00KojLRd00Go0000on6fZ_oQ]Z[ohKJZo`000008omJWZ003o`000?oDXJ;oe:6R00_oe:6R
00?o0000oiM]XOnGKJ402onGKJ400ol0003oOEfSogeMX`09ogeMX`03o`000?l`:YWo<2ZI00Go<2ZI
0_l00004o`0^]003o`000?mUR>3oIHSP00?o00001?mCWO@00ol0003oV;G/oiRek00=oiRek004o`00
0?nc_N7o0000o`0000oo/k?I00?o0000olRic?o8^L`01_o8^L`00ol0003o`Jo8ol6_b008ol6_b003
o`000?o?[[Socjjh00[ocjjh00?o0000ol2V_oo0Y[l00_o0Y[l00ol0003o`Ifeol6M]@0?ol6M]@03
o`000?n`Rjoo/8^_00co/8^_00?o0000oh]^[?n;KZ`03On;KZ`00ol0003oK5f`ofaM/00:ofaM/003
o`000?mTI;goI6Bm00_oI6Bm00?o0000ofUgc_mYMlh02_mYMlh00ol0003oLh[Kog>:f`05og>:f`Go
000000?oHH?Mo`000?mbUnH03OmbUnH01Ol0003oOZ?[ogjSjomnXn_o000000_oOZ?[00?o0000oook
J_oonfX07_oonfX00ol0003ooo]ZoookJP0=oookJP00<ooonfX00ol0003ooo]ZoookJP06oookJP;o
00003?nccNd2o`0000Oo]<g]0_l0000>okG?k@;o00001ongcn`00ol0003o^M3/okW@k00:okW@k0;o
00002_njdN/2o`0000Oo_M;Z0_l0000@okkCj@04o`000?o2e>So0000o`00013o`mKX0_l00005olCH
j0;o00002Oo7f^L2o`0000koan7[00?o0000olO/k_o7k>h01Oo7k>h4o`0000?oa?_X00Co0000okCh
__l0003o00000_oZhlX00ol0003ojLRdonW8]004onW8]003o`000?oQ]Z[ohKJZ00;ohKJZ00?o0000
omJWZ?oFYjP01_oFYjP00ol0003oe:6RomBQXP0;omBQXP03o`000?nGKJ7oUffQ00_oUffQ00?o0000
ogeMXommGJ<02OmmGJ<00ol0003o<2ZIoc0ZV@05oc0ZV@03o`000?m>Ekco000000Co02jd00?o0000
ofF8h?mUR>000_mUR>03o`0000;oDigd00?o0000oiRek?nH]N`02_nH]N`4o`00017o/k?I00?o0000
olRic?o8^L`01?o8^L`2o`0000_o`Jo800?o0000oln^^?o?[[P02Oo?[[P00ol0003o`:Jool2V_`04
ol2V_`03o`000?o1WKGo`Ife00ko`Ife00?o0000ok2;[on`Rjl03On`Rjl00ol0003oRfj/oh]^[005
oh]^[0_o00002_m/GK000ol0003oI6BmofAT_@0:ofAT_@03o`000?mYMlkoJGO>00[oJGO>00?o0000
og>:fomcR]/02_mcR]/7o`0000[oLYOV00Go0000ogjSjomnXn_oOZ?[o`00000:ogjSj`03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX03OoonfX003Cooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003o/lg]ok?=k@07ok?=k@;o00002ondcNd00ol0003o]Lo]okG?k@09okG?k@;o00002_ngcn`2
o`0000So^M3/0_l0000>ok[Aj`;o00001?nmd^X00ol0003o_]?YokkCj@0@okkCj@?o00004?o3e^P0
0ol0003oa=SXolCHj007olCHj003o`000?o7f^Ooam[W00Goam[W00?o0000olOQjoo7hN/03?o7hN/2
o`0000Woanc^00?o0000olCkj?o4nnP00_o4nnP01?l0003o]?Rno`000?l00002on[SbP03o`000?oY
b;CojLRd00GojLRd00?o0000on6fZ_oQ]ZX00ooQ]ZX00ol0003oeZNXomJWZ004omJWZ003o`000?oD
XJ;oe:6R00coe:6R00?o0000oiM]XOnGKJ402onGKJ400ol0003oOEfSogeMX`09ogeMX`03o`000?l`
:YWo<2ZI00Ko<2ZI00?o0000odiG_?l000000ol0;[@00ol0003oIHSPofF8h005ofF8h0Co00001?nH
]N`7o`0000?oV:OQ00?o0000ok>cfOnc/mT04?nc/mT00ol0003ob;W<olRic002olRic003o`000?o1
[lSo`Jo800co`Jo800?o0000oln^^?o?[[P01oo?[[P00ol0003o`:Jool2V_`05ol2V_`03o`000?o1
WKGo`Ife00ko`Ife00?o0000ok2;[on`Rjl03?n`Rjl9o`0000OoU8:m00Co0000ohAj`?n4N/3oQ7[0
1Ol00005ofaM/003o`000?mTI;goI6Bm00[oI6Bm00?o0000ofUgc_mYMlh02omYMlh00ol0003oLh[K
og>:f`0;og>:f`03o`000?mlVN?oO9WS00;oO9WS2?l00002og:GiP03o`000?mnXn_oOZ?[00;oOZ?[
00?o0000ogjSjomnXn/02?mnXn/00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00gooo]Z
000eoookJP;o00002?oonfX2o`0000Co/lg]0ol0000>okC=k@03o`000?necngo]Lo]00Ko]Lo]0_l0
000>okO?k0;o00001?nid>`2o`0001;o^]7[00Co0000okgBj_l0003o00004_nndnT01Ol0003o`=CY
ol3DjOo0e>Wo000000go`mKX0_l0000;olCHj0;o00000oo7f^L2o`0000koan7[00?o0000olO/k_o7
k>h01oo7k>h2o`0000Coa?_X00Co0000okCh__ndn;ko00000ooZhlX00ol0003ojLRdonW8]005onW8
]003o`000?oQ]Z[ohKJZ00?ohKJZ00?o0000omJWZ?oFYjP01?oFYjP00ol0003oe:6RomBQXP0<omBQ
XP03o`000?nGKJ7oUffQ00_oUffQ00?o0000ogeMXommGJ<02OmmGJ<00ol0003o<2ZIoc0ZV@06oc0Z
V@04o`000?m>EkcoCUNlo`0000?o02jd00?o0000ofF8h?mUR>001omUR>05o`0000_oV:OQ00?o0000
ok>cfOnc/mT03onc/mT01Ol0003ob;W<olRic?o8^Lco000000oo`Jo800?o0000oln^^?o?[[P01_o?
[[P00ol0003o`:Jool2V_`07ol2V_`03o`000?o1WKGo`Ife00ko`Ife00?o0000ok2;[on`Rjl02?n`
Rjl3o`000003ojN@_Ol0003oU8:m00koU8:m00?o0000ohAj`?n4N/001On4N/06o`0000goI6Bm00?o
0000ofUgc_mYMlh02_mYMlh00ol0003oLh[Kog>:f`0<og>:f`03o`000?mlVN?oO9WS00WoO9WS5?l0
000NoookJP03o`000?oonf[ooo]Z00gooo]Z000goookJP03o`000?oonf[ooo]Z00Oooo]Z00Co0000
ok?=kOl0003o00004_ndcNd2o`0000Co]Lo]0_l0000BokO?k004o`000?nid>co0000o`0001Co^]7[
0ol0000AokkCj@;o00001Oo0e>T2o`0000Wo`mKX0_l0000?olCHj003o`000?o7f^Oo000000koan7[
0_l00009olO/kP03o`000?o4nnSoa?_X00?oa?_X00Co0000okCh__ndn;ko00000ooZhlX00ol0003o
jLRdonW8]005onW8]003o`000?oQ]Z[ohKJZ00GohKJZ00?o0000omJWZ?oFYjP00ooFYjP00ol0003o
e:6RomBQXP0<omBQXP03o`000?nGKJ7oUffQ00_oUffQ00?o0000ogeMXommGJ<02OmmGJ<00ol0003o
<2ZIoc0ZV@06oc0ZV@05o`000?m>EkcoCUNlodiG_?l000000ol0;[@00ol0003oIHSPofF8h007ofF8
h003o`000?nHYn7oV:OQ00goV:OQ00?o0000ok>cfOnc/mT03onc/mT00ol0003ob;W<o`00000@ol6_
b003o`000?o?[[Socjjh00Gocjjh00?o0000ol2V_oo0Y[l02?o0Y[l00ol0003o`Ifeol6M]@0>ol6M
]@03o`000?n`Rjoo/8^_00Ko/8^_0_l00005ojN@_@03o`000?nDP[goU8:m00coU8:m00?o0000ohAj
`?n4N/002_n4N/04o`0000[oI6Bm00?o0000ofUgc_mYMlh02omYMlh00ol0003oLh[Kog>:f`0;og>:
f`03o`000?mlVN?oO9WS00coO9WS00?o0000ohBSj?n4XnP00_n4XnP00ol0003oQ:?XohBSj008ohBS
j003o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX03?oonfX003Sooo]Z00?o0000oookJ_oo
nfX01ooonfX2o`0001Go]<g]00Co0000okG?kOl0003o00005?ngcn`3o`0001?o^]7[0_l00003okcA
jP03o`000?nndnWo_]?Y00go_]?Y00?o0000ol3DjOo0e>T01oo0e>T00ol0003o`mKXol?Fj005ol?F
j003o`000?o4f>Soa=SX00ooa=SX0ol0000<olOQj`;o00002_o7k>h00ol0003oa?_XolCkj003olCk
j004o`000?ndn;ko0000o`0000Coj^?:00?o0000onW8]?oYb;@01OoYb;@00ol0003ohKJZon6fZP05
on6fZP03o`000?oFYjSoeZNX00?oeZNX00?o0000omBQX_oDXJ803?oDXJ800ol0003oUffQoiM]X@0<
oiM]X@03o`000?mmGJ?oOEfS00WoOEfS00?o0000oc0ZVOl`:YT01_l`:YT01?l0003oCUNlodiG_?m>
Ek`2o`000003o`0^]?l0003oIHSP00WoIHSP00?o0000oiRWhOnHYn403?nHYn400ol0003o/k?Iok>c
f@0?ok>cf@;o00004_o1[lP00ol0003ocjjholn^^003oln^^003o`000?o0Y[oo`:Jo00Wo`:Jo00?o
0000ol6M]Oo1WKD03_o1WKD00ol0003o/8^_ok2;[`04ok2;[`;o00001onWT;d00ol0003oU8:moiB2
_@0<oiB2_@03o`000?n4N/3oQ7[000_oQ7[000?o0000ogemb?mmOLP01?l00007ofAT_@03o`000?mY
MlkoJGO>00_oJGO>00?o0000og>:fomcR]/02omcR]/00ol0003oO9WSogbIh`0<ogbIh`03o`000?n4
XnSoQ:?X00;oQ:?X00?o0000ohBSj?n4XnP02?n4XnP00ol0003ooo]ZoookJP0LoookJP03o`000?oo
nf[ooo]Z00cooo]Z000ioookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000okC=kOndcNd04_ndcNd3
o`0001?o]lo/0_l00003okS?j`03o`000?njdN_o^]7[00oo^]7[00?o0000okcAj_nldNX01?nldNX0
0ol0003o_]?YokkCj@0:okkCj@;o00002oo0e>T2o`0000?o`mKX0_l0000AolCHj004o`000?o6g>[o
a]cZolKLjP;o00002Oo7hN/00ol0003oanc^olO/kP08olO/kP;o00001Oo4nnP01Ol0003o]?Rno`00
0?oMkmgo000000?oj^?:00?o0000onW8]?oYb;@01_oYb;@00ol0003ohKJZon6fZP05on6fZP03o`00
0?oFYjSoeZNX00;oeZNX00?o0000omBQX_oDXJ803OoDXJ800ol0003oUffQoiM]X@0<oiM]X@03o`00
0?mmGJ?oOEfS00WoOEfS00?o0000oc0ZVOl`:YT01_l`:YT00ol0003oCUNlodiG_003odiG_003o`00
0?l0;[Co000000[oIHSP00?o0000oiRWhOnHYn403?nHYn400ol0003o/k?Iok>cf@0;ok>cf@?o0000
00?o/:_Co`000?o1[lP04Oo1[lP00ol0003ocjjholn^^002oln^^003o`000?o0Y[oo`:Jo00_o`:Jo
00?o0000ol6M]Oo1WKD03Oo1WKD01?l0003o/8^_ok2;[on`Rjl3o`0000WoYi2m00?o0000oiB2_OnD
P[d03OnDP[d00ol0003oQ7[0ohAj`00;ohAj`003o`000?mmOLSoOGg800?oOGg80ol00004ofAT_@03
o`000?mYMlkoJGO>00_oJGO>00?o0000og>:fomcR]/02omcR]/00ol0003oO9WSogbIh`0<ogbIh`03
o`000?n4XnSoQ:?X00?oQ:?X00?o0000ohBSj?n4XnP02?n4XnP00ol0003ooo]ZoookJP0KoookJP03
o`000?oonf[ooo]Z00cooo]Z000joookJP;o00002OoonfX2o`0000oo]<g]0ol00003okG>k0;o0000
3ongcn`2o`0000Ko^<o[0_l0000=ok[Aj`;o00002?nldNX2o`0000So_]?Y0_l0000?ol3Dj@03o`00
0?o3e^So0000017oa=SX0_l00006olKLjP?o00001?o7hN/2o`0000[oanc^00?o0000olCkj?o4nnP0
1?o4nnP3o`000003omg_gOl0003oj^?:00?oj^?:00?o0000onW8]?oYb;@01OoYb;@00ol0003ohKJZ
on6fZP07on6fZP05o`000?oFYjSoeZNXomJWZ?l000004?oDXJ800ol0003oUffQoiM]X@0;oiM]X@03
o`000?mmGJ?oOEfS00WoOEfS00?o0000oc0ZVOl`:YT01_l`:YT00ol0003oCUNlodiG_004odiG_0;o
00002omUR>000ol0003oV:OQoiRWh@0<oiRWh@03o`000?nc/mWo/k?I00So/k?I0_l00005ok2[d`03
o`000?o1[lSo`Jo8013o`Jo800Co0000oln^^?o?[[So00003_o0Y[l00ol0003o`Ifeol6M]@0>ol6M
]@?o00003OnWT;d00ol0003oU8:moiB2_@0<oiB2_@03o`000?n4N/3oQ7[000_oQ7[000?o0000ogem
b?mmOLP01_mmOLP5o`0000koJGO>00?o0000og>:fomcR]/02omcR]/00ol0003oO9WSogbIh`0<ogbI
h`03o`000?n4XnSoQ:?X00;oQ:?X00?o0000ohBSj?n4XnP02?n4XnP00ol0003ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z00cooo]Z000loookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000okC=kOnd
cNd02_ndcNd2o`0000So]Lk/00?o0000okO?k?ngcn`02_ngcn`2o`0000[o^<o[00?o0000ok[Ajonj
dN/02?njdN/2o`0000co_=7Z00?o0000okkCjOnndnT01?nndnT00ol0003o`=CYol3Dj@0?ol3Dj@?o
00004?o4f>P00ol0003oa]cZolKLjP09olKLjP;o000000?oan7[o`000?o7k>h02Oo7k>h2o`0000Ko
a?_X0_l00002omg_g@03o`000?oZhl[oj^?:00;oj^?:00?o0000onW8]?oYb;@01_oYb;@00ol0003o
hKJZon6fZP07on6fZP05o`000?oFYjSoeZNXomJWZ?l000004?oDXJ800ol0003oUffQoiM]X@0:oiM]
X@?o00002_mmGJ<00ol0003o<2ZIoc0ZV@07oc0ZV@03o`000?m>EkcoCUNl00CoCUNl0_l0000;ofF8
h003o`000?nHYn7oV:OQ00coV:OQ00?o0000ok>cfOnc/mT01Onc/mT2o`0000Oo/:_C00?o0000ol6_
b?o1[lP04?o1[lP00ol0003ocjjho`00000@ol2V_`03o`000?o1WKGo`Ife00co`Ife0_l0000?ojN@
_@03o`000?nDP[goU8:m00coU8:m00?o0000ohAj`?n4N/002on4N/000ol0003oOGg8ogemb00:ogem
b0Go00002_mYMlh00ol0003oLh[Kog>:f`0;og>:f`03o`000?mlVN?oO9WS00coO9WS00?o0000ohBS
j?n4XnP00on4XnP00ol0003oQ:?XohBSj008ohBSj003o`000?oonf[ooo]Z01[ooo]Z00?o0000oook
J_oonfX03?oonfX003gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o]<g]okC=k@07okC=k@;o
00002onec^`2o`0000So]lo/0_l0000=okS?j`03o`000?njdN_o^]7[00Go^]7[0_l0000?okcAjP04
o`000?nndnWo_]?YokkCj@;o00004Oo0e>T01Ol0003o`]KYol;FjOo2e^Wo000000goa=SX0_l0000=
olKLjPCo00002?o7k>h00ol0003oa?_XolCkj005olCkj003o`000?oMkmgogNoM00;ogNoM00?o0000
on[Sb_oZhlX00_oZhlX00ol0003ojLRdonW8]005onW8]003o`000?oQ]Z[ohKJZ00SohKJZ00Co0000
omJWZ?oFYjSo00004OoDXJ800ol0003oUffQoiM]X@09oiM]X@04o`000?n[QJgo0000ohAY[0?o0000
1ommGJ<00ol0003o<2ZIoc0ZV@07oc0ZV@03o`000?m>EkcoCUNl00GoCUNl0_l0000:ofF8h003o`00
0?nHYn7oV:OQ00coV:OQ00?o0000ok>cfOnc/mT00_nc/mT3o`0000[o/:_C00?o0000ol6_b?o1[lP0
3oo1[lP2o`00017o`:Jo00?o0000ol6M]Oo1WKD02oo1WKD00ol0003o/Yc1o`00000?ojN@_@03o`00
0?nDP[goU8:m00goU8:m00?o0000ohAj`?n4N/002on4N/000ol0003oOGg8ogemb00:ogemb004o`00
0?mlQm?oO8OCogb7d`Go00001_mYMlh00ol0003oLh[Kog>:f`0;og>:f`03o`000?mlVN?oO9WS00co
O9WS00?o0000ohBSj?n4XnP00on4XnP00ol0003oQ:?XohBSj007ohBSj003o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX03?oonfX003kooo]Z00?o0000oookJ_oonfX02?oonfX2o`0000Co]<g]
0ol0000?okG>k0;o00001?ngcn`2o`00013o^<o[0_l00004ok[Aj`03o`000?nldN[o_=7Z013o_=7Z
00?o0000okkCjOl000004Oo0e>T2o`0000Go`]KY0_l00009olCHj0;o00003_o6g>X00ol0003obN?Z
olWSjP02olWSjPGo00000_o7k>h01?l0003oa?_XolCkj?o4nnP5o`0000CogNoM00?o0000on[Sb_oZ
hlX00_oZhlX00ol0003ojLRdonW8]006onW8]003o`000?oQ]Z[ohKJZ00WohKJZ00?o0000omJWZ?l0
00004OoDXJ800ol0003oUffQoiM]X@08oiM]X@04o`000?n[QJgoZhF]o`0000CoQ6V/0ol00004ogeM
X`03o`000?l`:YWo<2ZI00Oo<2ZI00?o0000odiG_?m>Ek`01_m>Ek`00ol0003oIHSPofF8h009ofF8
h003o`000?nHYn7oV:OQ00coV:OQ00Co0000ok>cfOl0003o00003On`Zm<00ol0003o`Jo8ol6_b00>
ol6_b003o`000?nhZL[o0000017o`:Jo00?o0000ol6M]Oo1WKD02Oo1WKD2o`0000?o/Yc100?o0000
ojN@_OnWT;d03OnWT;d00ol0003oU8:moiB2_@0<oiB2_@03o`000?n4N/3oQ7[000_oQ7[000?o0000
ogemb?mmOLP02ommOLP00ol0003oO8OCogb7d`05ogb7d`Go000000?oJGO>o`000?mcR]/03?mcR]/0
0ol0003oO9WSogbIh`0=ogbIh`03o`000?n4XnSoQ:?X00?oQ:?X00?o0000ohBSj?n4XnP01on4XnP0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00cooo]Z000ooookJP03o`000?oonf[ooo]Z
00Wooo]Z00Co0000okC=kOl0003o00005?nec^`01?l0003o]lo/o`000?l0000DokS?j`04o`000?nj
dN_o0000o`0001?o_=7Z0ol0000@ol3Dj@03o`000?o2e^Wo`]KY00Oo`]KY00?o0000olCHj?o4f>P0
1Oo4f>P00ol0003oa]cZolKLjP0<olKLjP;o00002_o9hnX6o`0000?od>_X00?o0000omg_gOoMkmd0
0_oMkmd00ol0003oj^?:on[SbP03on[SbP03o`000?oYb;CojLRd00KojLRd00?o0000on6fZ_oQ]ZX0
2OoQ]ZX00ol0003oeZNXo`00000AomBQXP03o`000?nGKJ7oUffQ00OoUffQ00?o0000oj^5[On[QJd0
0_n[QJd00ol0003oQ6V/ohAY[004ohAY[0;o00000ommGJ<00ol0003o<2ZIoc0ZV@07oc0ZV@03o`00
0?m>EkcoCUNl00KoCUNl1Ol00007ofF8h003o`000?nHYn7oV:OQ00WoV:OQ1?l0000@ok2[d`03o`00
0?o1[lSo`Jo800_o`Jo80_l00003okRYbP03o`000?o0Y[oo`:Jo00oo`:Jo00?o0000ol6M]Oo1WKD0
1_o1WKD2o`0000Go/Yc100?o0000ojN@_OnWT;d03OnWT;d00ol0003oU8:moiB2_@0<oiB2_@03o`00
0?n4N/3oQ7[000coQ7[000?o0000ogemb?mmOLP02_mmOLP00ol0003oO8OCogb7d`0:ogb7d`Oo0000
2OmcR]/00ol0003oO9WSogbIh`0<ogbIh`03o`000?n4XnSoQ:?X00?oQ:?X00?o0000ohBSj?n4XnP0
2?n4XnP00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00cooo]Z0010oookJP;o00002_oo
nfX2o`0001Go]Lk/0ol0000EokS?j`?o00004_nldNX2o`0000?o_M;Y00?o0000ol3DjOo0e>T02oo0
e>T2o`0000_o`]KY0_l00003olCHj0;o00003_o6g>X00ol0003obN?ZolWSjP09olWSjP03o`000?o@
jnSod>_X00Kod>_X00?o0000omg_gOoMkmd00ooMkmd00ol0003oj^?:on[SbP03on[SbP03o`000?oY
b;CojLRd00GojLRd00?o0000on6fZ_oQ]ZX02_oQ]ZX2o`0001;oe:6R00?o0000oiM]XOnGKJ401_nG
KJ400ol0003oZhF]oj^5[@03oj^5[@03o`000?n4JJcoQ6V/00KoQ6V/1?l00009oc0ZV@03o`000?m>
EkcoCUNl00KoCUNl00?o0000ogZ5domjQM<00_mjQM<7o`000003ofF8h?l0003oV:OQ00;oV:OQ1ol0
0003oiZOf003o`000?n`Zm?o/:_C00oo/:_C00?o0000ol6_b?o1[lP02Oo1[lP00ol0003o^:W:okRY
bP03okRYbP03o`000?o0Y[oo`:Jo00oo`:Jo00?o0000ol6M]Oo1WKD01Oo1WKD00ol0003o/Yc1ok:L
`@05ok:L`@03o`000?nWT;goYi2m00goYi2m00?o0000oiB2_OnDP[d03OnDP[d00ol0003oQ7[0ohAj
`00;ohAj`003o`000?mmOLSoOGg800_oOGg800?o0000ogb7domlQm<02omlQm<00ol0003oP9;Koh2B
f`02oh2Bf`Oo00000_mcR]/00ol0003oO9WSogbIh`0=ogbIh`03o`000?n4XnSoQ:?X00?oQ:?X00?o
0000ohBSj?n4XnP01on4XnP00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00_ooo]Z0012
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000okG>k?nec^`04?nec^`2o`0000?o]lk[00?o0000
okS?jonhcn/04?nhcn/2o`0000?o^/oZ00?o0000okcAj_nldNX03OnldNX2o`0000Ko_M;Y0_l00009
ol3Dj@;o00003oo2e^T00ol0003oa=SXo`00000>olKLjP;o00002oo9hnX00ol0003od>_Xom3[j006
om3[j003o`000?oMkmgogNoM00?ogNoM00?o0000on[Sb_oZhlX00ooZhlX00ol0003ojLRdonW8]006
onW8]003o`000?oQ]Z[ohKJZ00_ohKJZ00?o0000omBQX_oDXJ804?oDXJ800ol0003oUffQoiM]X@04
oiM]X@;o00001_n[QJd00ol0003oQ6V/ohAY[009ohAY[0;o00002?l`:YT00ol0003oCUNlodiG_007
odiG_003o`000?mjQM?oNXGC00SoNXGC1Ol0000;oiZOf003o`000?n`Zm?o/:_C00ko/:_C00?o0000
ol6_b?o1[lP01oo1[lP2o`0000Oo^:W:00?o0000ol2V_oo0Y[l03oo0Y[l00ol0003o`Ifeol6M]@02
ol6M]@;o00002OnbW<400ol0003oYi2mojN@_@0=ojN@_@03o`000?nDP[goU8:m00coU8:m00?o0000
ohAj`?n4N/002on4N/000ol0003oOGg8ogemb00;ogemb003o`000?mlQm?oO8OC00coO8OC00?o0000
oh2Bfon0T]/02?n0T]/<o`0000KoO9WS00?o0000ohBSj?n4XnP01?n4XnP00ol0003oQ:?Xo`000008
o`0001[ooo]Z00?o0000oookJ_oonfX02ooonfX004?ooo]Z00?o0000oookJ_oonfX02OoonfX2o`00
00ko]Lk/0_l00006okO>j`;o00003_nhcn/2o`0000Ko^/oZ0_l0000;okcAjP;o00002_nmd^T00ol0
003o`=CYol3Dj@05ol3Dj@03o`000?o2e^Wo`]KY00oo`]KY0ol0000<olKLjP;o00003?o9hnX00ol0
003od>_Xom3[j006om3[j003o`000?oMkmgogNoM00?ogNoM00?o0000on[Sb_oZhlX01?oZhlX00ol0
003ojLRdonW8]005onW8]003o`000?oQ]Z[ohKJZ00cohKJZ00?o0000omBQX_oDXJ804?oDXJ800ol0
003oUffQoiM]X@03oiM]X@03o`000?n[QJgoZhF]00KoZhF]00?o0000ohAY[?n4JJ`02On4JJ`00ol0
003oLF>co`000008oc0ZV@03o`000?m>EkcoCUNl00KoCUNl00?o0000ogZ5domjQM<02_mjQM<00ol0
003oVYoHoiZOf00<oiZOf003o`000?n`Zm?o/:_C00ko/:_C00?o0000ol6_b?o1[lP01?o1[lP2o`00
00Wo^:W:00?o0000ol2V_oo0Y[l03oo0Y[l00ol0003o`Ifeol6M]@02o`0000_o/Yc100?o0000ojN@
_OnWT;d03OnWT;d00ol0003oU8:moiB2_@0<oiB2_@03o`000?n4N/3oQ7[000coQ7[000?o0000ogem
b?mmOLP02ommOLP00ol0003oO8OCogb7d`0;ogb7d`03o`000?n0T]_oP9;K00_oP9;K00?o0000ohFL
h_n5W>801_n5W>8?o`0000SoRZGV00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0;oook
JP00A?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?nec^co]Lk/00Wo]Lk/0_l0000:okO>j`03
o`000?nhcn_o^<o[00Wo^<o[0_l0000:ok[?jP03o`000?nldN[o_=7Z00Ko_=7Z0_l0000=okgBj@;o
00000oo0e>T2o`00017o`]KY00Co0000olCHj?o4f>Soa=SX0_l00009olKLjP03o`000?o9hn[obN?Z
00[obN?Z0_l00008om3[j003o`000?oMkmgogNoM00?ogNoM00?o0000on[Sb_oZhlX01?oZhlX00ol0
003ojLRdonW8]006onW8]003o`000?oQ]Z[ohKJZ00_ohKJZ0_l0000BomBQXP03o`000?nGKJ7oUffQ
00;oUffQ00?o0000oj^5[On[QJd01on[QJd00ol0003oQ6V/ohAY[009ohAY[003o`000?maHk?oLF>c
00;o00001_l`:YT00ol0003oCUNlodiG_007odiG_003o`000?mjQM?oNXGC00[oNXGC00?o0000oiZO
f?nJWmP02onJWmP00ol0003o/:_Cok2[d`0>ok2[d`03o`000?o1[lSo`Jo800?o`Jo800?o0000okRY
b_nhZLX02OnhZLX00ol0003o`:Jool2V_`0?ol2V_`03o`000?o1WKGo000000ko/Yc100?o0000ojN@
_OnWT;d03OnWT;d00ol0003oU8:moiB2_@0<oiB2_@03o`000?n4N/3oQ7[000_oQ7[000?o0000ogem
b?mmOLP02ommOLP00ol0003oO8OCogb7d`0<ogb7d`03o`000?n0T]_oP9;K00_oP9;K00?o0000ohFL
h_n5W>803?n5W>800ol0003oRZGVohZUiP04ohZUiP03o`000?n:YNKoRZGV00OoRZGV00?o0000oook
J_oonfX05ooonfX00ol0003ooo]ZoookJP0;oookJP00AOoonfX2o`0000_ooo]Z00?o0000okG>k?ne
c^`01_nec^`2o`0000go]lk[00?o0000okS?jonhcn/01_nhcn/2o`0000go^/oZ0_l00004okcAjP;o
00004Onmd^T00ol0003o`=CYo`00000Aol;Fj@;o00001_o4f>P3o`0000Coa]cZ0_l0000<olWSjP03
o`000?o@jnSod>_X00Ood>_X00?o0000omg_gOoMkmd01?oMkmd00ol0003oj^?:on[SbP04on[SbP03
o`000?oYb;CojLRd00KojLRd00?o0000on6fZ_oQ]ZX02ooQ]ZX00ol0003oeZf^o`00000BomBQXP04
o`000?nGKJ7oUffQo`0000_oZhF]00?o0000ohAY[?n4JJ`02On4JJ`01?l0003oLF>cog5S/omaHk<2
o`0000Co<2ZI00?o0000odiG_?m>Ek`01om>Ek`00ol0003oNXGCogZ5d`0:ogZ5d`03o`000?nJWmSo
VYoH00coVYoH00?o0000ok2[don`Zm<03_n`Zm<00ol0003o`Jo8ol6_b002o`0000go^:W:00?o0000
ol2V_oo0Y[l03_o0Y[l2o`0000oo/Yc100?o0000ojN@_OnWT;d03OnWT;d00ol0003oU8:moiB2_@0<
oiB2_@03o`000?n4N/3oQ7[000_oQ7[000?o0000ogemb?mmOLP03?mmOLP00ol0003oO8OCogb7d`0;
ogb7d`03o`000?n0T]_oP9;K00coP9;K00?o0000ohFLh_n5W>803?n5W>800ol0003oRZGVohZUiP04
ohZUiP03o`000?n:YNKoRZGV00OoRZGV00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0;
oookJP00AooonfX00ol0003ooo]ZoookJP09oookJP;o00001?nec^`2o`00013o]lk[0_l00004okS?
j`;o00004OnjcnX01?l0003o_=7Zo`000?l0000CokgBj@?o00003oo2e^T2o`0000_oa=SX0_l00000
0oo6g>[o0000olWSjP0<olWSjP03o`000?o@jnSod>_X00Ood>_X00?o0000omg_gOoMkmd01?oMkmd0
0ol0003oj^?:on[SbP04on[SbP03o`000?oYb;CojLRd00KojLRd00?o0000on6fZ_oQ]ZX02ooQ]ZX0
1?l0003oeZf^omJ][_l0000BomBQXP03o`000?nGKJ7o000000coZhF]00?o0000ohAY[?n4JJ`02On4
JJ`00ol0003oLF>cog5S/`03og5S/`03o`000?l`:YWo<2ZI00;o<2ZI00?o0000odiG_?m>Ek`01om>
Ek`00ol0003oNXGCogZ5d`0:ogZ5d`03o`000?nJWmSoVYoH00coVYoH00?o0000ok2[don`Zm<03On`
Zm<00ol0003o`Jo8o`00000?okRYbP03o`000?o0Y[oo`:Jo00go`:Jo00?o0000okBSaol000003onb
W<400ol0003oYi2mojN@_@0=ojN@_@03o`000?nDP[goU8:m00coU8:m00?o0000ohAj`?n4N/003?n4
N/000ol0003oOGg8ogemb00;ogemb003o`000?mlQm?oO8OC00coO8OC00?o0000oh2Bfon0T]/02on0
T]/00ol0003oQIcRohFLhP0=ohFLhP03o`000?n:YNKoRZGV00CoRZGV00?o0000ohZUi_n:YNH01_n:
YNH00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00_ooo]Z0018oookJP03o`000?oonf[o
oo]Z00[ooo]Z00Co0000okG>k?l0003o00005?ngc^/01?l0003o^<o[o`000?l0000Cok[?jP?o0000
4_nmd^T2o`0000?o_m?Y0_l0000<ol;Fj@03o`000?o4f>Soa=SX00coa=SX0ol0000;olWSjP;o0000
2Oo@jnP00ol0003ogNoMomg_g@04omg_g@03o`000?oZhl[oj^?:00Goj^?:00?o0000onW8]?oYb;@0
1_oYb;@00ol0003ohKJZon6fZP0;on6fZP04o`000?oF[JkoeZf^o`0001;oe:6R0_l0000=oj^5[@03
o`000?n4JJcoQ6V/00WoQ6V/00?o0000og5S/omaHk<01?maHk<2o`0000;o<2ZI00?o0000odiG_?m>
Ek`01om>Ek`00ol0003oNXGCogZ5d`0:ogZ5d`03o`000?nJWmSoVYoH00coVYoH00?o0000ok2[don`
Zm<03On`Zm<2o`00017o^:W:00?o0000ol2V_oo0Y[l02_o0Y[l2o`0000?o]:?700?o0000ok:L`Onb
W<403OnbW<400ol0003oYi2mojN@_@0=ojN@_@03o`000?nDP[goU8:m00coU8:m00?o0000ohAj`?n4
N/002on4N/000ol0003oOGg8ogemb00;ogemb003o`000?mlQm?oO8OC00coO8OC00?o0000oh2Bfon0
T]/03?n0T]/00ol0003oQIcRohFLhP0<ohFLhP03o`000?n:YNKoRZGV00CoRZGV00?o0000ohZUi_n:
YNH01on:YNH00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00_ooo]Z0019oookJP03o`00
0?oonf[ooo]Z00[ooo]Z0_l0000EokO>j`?o00004onjcnX01?l0003o^m3Yok_@jOnkd>T2o`0000ko
_M;Y0_l00007okoCj@;o00002?o2e^T2o`0000koa=SX00Co0000olSKioo8fnOob=_W0_l00008olWS
jP03o`000?o@jnSod>_X00Sod>_X00?o0000omg_gOoMkmd01OoMkmd00ol0003oj^?:on[SbP04on[S
bP03o`000?oYb;CojLRd00KojLRd00?o0000on6fZ_oQ]ZX03?oQ]ZX01?l0003oeZf^omJ][_l0000B
omBQXP03o`000?n[QJgoZhF]00coZhF]00?o0000ohAY[?n4JJ`02On4JJ`00ol0003oLF>cog5S/`06
og5S/`?o00002_m>Ek`00ol0003oNXGCogZ5d`0:ogZ5d`03o`000?nJWmSoVYoH00coVYoH00?o0000
ok2[don`Zm<02On`Zm<3o`000003ojbVdOl0003o^:W:013o^:W:00?o0000ol2V_oo0Y[l02Oo0Y[l0
0ol0003o]:?7okBSa`03okBSa`03o`000?nbW<7o/Yc100go/Yc100?o0000ojN@_OnWT;d03OnWT;d0
0ol0003oU8:moiB2_@0<oiB2_@03o`000?n4N/3oQ7[000coQ7[000?o0000ogemb?mmOLP02ommOLP0
0ol0003oO8OCogb7d`0;ogb7d`03o`000?n0T]_oP9;K00goP9;K00?o0000ohFLh_n5W>803?n5W>80
0ol0003oRZGVohZUiP04ohZUiP03o`000?n:YNKoRZGV00KoRZGV00?o0000oookJ_oonfX05_oonfX0
0ol0003ooo]ZoookJP0:oookJP00B_oonfX2o`0000cooo]Z00?o0000okO>jongc^/04?ngc^/2o`00
00?o^<k[00?o0000ok[?j_njcnX03_njcnX2o`0000Ko^m3Y00?o0000okgBjOnmd^T02Onmd^T2o`00
00_o_m?Y0_l00004ol;Fj@;o00003_o4f>P2o`0000Kob=_W0ol00004olWSjP03o`000?o@jnSod>_X
00Sod>_X00?o0000omg_gOoMkmd01OoMkmd00ol0003oj^?:on[SbP05on[SbP03o`000?oYb;CojLRd
00KojLRd00?o0000on6fZ_oQ]ZX02ooQ]ZX00ol0003oeZf^omJ][P02omJ][P03o`000?oDXJ;oe:6R
00ooe:6R00?o0000oj^5[On[QJd03?n[QJd00ol0003oQ6V/ohAY[00:ohAY[003o`000?maHk?oLF>c
00OoLF>c0_l00009odiG_003o`000?mjQM?oNXGC00_oNXGC00?o0000oiZOf?nJWmP03?nJWmP00ol0
003o/:_Cok2[d`05ok2[d`?o00001On/Y]400ol0003o^:W:okRYbP0?okRYbP03o`000?o0Y[oo`:Jo
00Ko`:Jo0_l00006okBSa`03o`000?nbW<7o/Yc100ko/Yc100?o0000ojN@_OnWT;d03?nWT;d00ol0
003oU8:moiB2_@0<oiB2_@03o`000?n4N/3oQ7[000coQ7[000?o0000ogemb?mmOLP02ommOLP00ol0
003oO8OCogb7d`0<ogb7d`03o`000?n0T]_oP9;K00coP9;K00?o0000ohFLh_n5W>803?n5W>800ol0
003oRZGVohZUiP05ohZUiP03o`000?n:YNKoRZGV00KoRZGV00?o0000oookJ_oonfX05OoonfX00ol0
003ooo]ZoookJP0:oookJP00C?oonfX00ol0003ooo]ZoookJP0:oookJP;o00003_ngc^/2o`0000Ko
^<k[0_l0000<ok[?jP;o00002Onkd>T2o`0000So_M;Y00?o0000okoCjOnodnT03OnodnT2o`000003
ol;FjOl0003oa=SX00koa=SX00?o0000olSKioo8fnL02Oo8fnL2o`000003olWSj_l0003od>_X00Wo
d>_X00?o0000omg_gOoMkmd01OoMkmd00ol0003oj^?:on[SbP05on[SbP03o`000?oYb;CojLRd00Oo
jLRd00?o0000on6fZ_oQ]ZX02ooQ]ZX00ol0003oeZf^omJ][P02omJ][P03o`000?oDXJ;oe:6R00ko
e:6R0_l0000?oj^5[@03o`000?n4JJcoQ6V/00WoQ6V/00?o0000og5S/omaHk<02?maHk<3o`0000So
CUNl00?o0000ogZ5domjQM<02_mjQM<00ol0003oVYoHoiZOf00<oiZOf003o`000?n`Zm?o/:_C00?o
/:_C0_l00008ojbVd@03o`000?nhZL[o^:W:00oo^:W:00?o0000ol2V_oo0Y[l01?o0Y[l2o`0000Wo
]:?700?o0000ok:L`OnbW<403OnbW<400ol0003oYi2mojN@_@0=ojN@_@03o`000?nDP[goU8:m00co
U8:m00?o0000ohAj`?n4N/002on4N/000ol0003oOGg8ogemb00<ogemb003o`000?mlQm?oO8OC00_o
O8OC00?o0000oh2Bfon0T]/03On0T]/00ol0003oQIcRohFLhP0<ohFLhP03o`000?n:YNKoRZGV00Go
RZGV00?o0000ohZUi_n:YNH01_n:YNH00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00[o
oo]Z001=oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000okO>jongc^/02Ongc^/2o`0000[o^<k[
00?o0000ok[?j_njcnX02?njcnX00ol0003o^m3Yok_@j@0;ok_@j@;o00001?nmd^T2o`00017o_m?Y
0ol0000=olCHj0;o00003Oo8fnL4o`0000Sod>_X00?o0000omg_gOoMkmd01_oMkmd00ol0003oj^?:
on[SbP05on[SbP03o`000?oYb;CojLRd00KojLRd00?o0000on6fZ_oQ]ZX02ooQ]ZX00ol0003oeZf^
omJ][P03omJ][P03o`000?oDXJ;oe:6R00goe:6R00Co0000ol>L/?o3W;3o00003_n[QJd00ol0003o
Q6V/ohAY[009ohAY[003o`000?maHk?oLF>c00SoLF>c00?o0000ogUe`omiML<00ol00005odiG_003
o`000?mjQM?oNXGC00_oNXGC00?o0000oiZOf?nJWmP03?nJWmP00ol0003o/:_Co`000002o`0000_o
[:KA00?o0000okRYb_nhZLX03_nhZLX00ol0003o`:Jool2V_`03ol2V_`03o`000?ndXlOo]:?700Wo
]:?700?o0000ok:L`OnbW<403OnbW<400ol0003oYi2mojN@_@0=ojN@_@03o`000?nDP[goU8:m00Wo
U8:m6ol00005ogemb003o`000?mlQm?oO8OC00coO8OC00?o0000oh2Bfon0T]/03?n0T]/00ol0003o
QIcRohFLhP0=ohFLhP03o`000?n:YNKoRZGV00CoRZGV00?o0000ohZUi_n:YNH01_n:YNH00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00[ooo]Z001>oookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000okO>jongc^/01_ngc^/2o`0000go^<k[00?o0000ok[?j_njcnX01OnjcnX2o`00013o^m3Y
00Co0000okgBjOl0003o00004OnodnT2o`0000?o`]CX0_l0000:olCHj003o`000?o8fnOob=_W00co
b=_W00?o0000olkMi?o>gN@00_o>gN@5o`0000;od>_X00?o0000omg_gOoMkmd01_oMkmd00ol0003o
j^?:on[SbP05on[SbP03o`000?oYb;CojLRd00OojLRd00?o0000on6fZ_oQ]ZX02ooQ]ZX00ol0003o
eZf^omJ][P04omJ][P03o`000?oDXJ;oe:6R00coe:6R00Co0000ol>L/?o3W;3o00003_n[QJd00ol0
003oQ6V/ohAY[009ohAY[003o`000?maHk?oLF>c00WoLF>c00?o0000ogUe`omiML<00_miML<3o`00
00?oCUNl00?o0000ogZ5domjQM<02_mjQM<00ol0003oVYoHoiZOf00;oiZOf0?o00003_n/Y]400ol0
003o^:W:okRYbP0?okRYbP03o`000?o0Y[oo`:Jo00;o00003OndXlL00ol0003o/Yc1ok:L`@0=ok:L
`@03o`000?nWT;goYi2m00coYi2m00?o0000oiB2_OnDP[d00_nDP[d7o`0000?oVY3800?o0000oi2=
c?n@SL`03?n@SL`00ol0003oRhkAoh^>d@06oh^>d@oo00001OmlQm<00ol0003oP9;Koh2Bf`0=oh2B
f`03o`000?n5W>;oQIcR00coQIcR00?o0000ohZUi_n:YNH01On:YNH:o`0001Gooo]Z00?o0000oook
J_oonfX02_oonfX004oooo]Z0_l0000<oookJP;o00001?ngc^/2o`00013o^<k[0_l00003ok[?jP;o
00004_nkd>T3o`00017o_m?Y00?o0000ol;Dj?o2e>P01Oo2e>P2o`0000Ooa=SX00?o0000olSKioo8
fnL03?o8fnL00ol0003oc]gTolkMi008olkMi0oo00001?oZhlX00ol0003ojLRdonW8]007onW8]003
o`000?oQ]Z[ohKJZ00[ohKJZ00?o0000omJ][_oF[Jh01OoF[Jh00ol0003oe:6RomBQXP0;omBQXP05
o`000?o3W;3o`ib`ol>L/?l000003_n[QJd00ol0003oQ6V/ohAY[00:ohAY[003o`000?maHk?oLF>c
00SoLF>c00?o0000ogUe`omiML<01OmiML<4o`0000goNXGC00?o0000oiZOf?nJWmP01OnJWmP5o`00
00;oWIgC00?o0000ojbVdOn/Y]403On/Y]400ol0003o^:W:okRYbP0>okRYbP03o`000?o0Y[oo0000
00oo]:?700?o0000ok:L`OnbW<403OnbW<400ol0003oYi2mojN@_@0;ojN@_@Ko00002onJT<P00ol0
003oT8g<oi2=c00<oi2=c003o`000?n;S]7oRhkA00_oRhkA00?o0000ohVCeon9TmL01_n9TmL^o`00
00OoSjOV00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0:oookJP00DOoonfX00ol0003o
oo]ZoookJP0;oookJP04o`000?ngc^_o0000o`0001Co^<k[00?o0000ok[?j_l000004_nkd>T2o`00
00?o_M3X00?o0000okoCjOnodnT03?nodnT2o`0000[o`]CX00?o0000olCHj?o4f>P00_o4f>P2o`00
00gob=_W0_l0000:olkMi003o`000?oFg=goe]cM00Soe]cM00?o0000omcDd?oLe=000_oLe=05o`00
00SojLRd00?o0000on6fZ_oQ]ZX02ooQ]ZX00ol0003oeZf^omJ][P05omJ][P03o`000?oDXJ;oe:6R
00[oe:6R00?o0000ol>L/?o3W;000_o3W;000ol0003oZhF]oj^5[@0<oj^5[@03o`000?n4JJcoQ6V/
00[oQ6V/00?o0000og5S/omaHk<02?maHk<00ol0003oNGG3ogUe``08ogUe``Wo00001OmjQM<00ol0
003oVYoHoiZOf005o`0000SoWIgC00?o0000ojbVdOn/Y]403On/Y]400ol0003o^:W:okRYbP0=okRY
bP;o00004?ndXlL00ol0003o/Yc1ok:L`@0>ok:L`@03o`000?nWT;goYi2m00OoYi2m0ol00002oj>G
b003o`000?nJT<SoVY3800coVY3800?o0000oi2=c?n@SL`03?n@SL`00ol0003oRhkAoh^>d@0<oh^>
d@03o`000?n9TmOoRI?G00_oRI?G00?o0000ohZJgOn:V]d03On:V]d00ol0003oS:7RohbQhP0<ohbQ
hP03o`000?n?YnKoSjOV00KoSjOV00?o0000ohnWi_n?YnH01On?YnH00ol0003ooo]ZoookJP0Boook
JP03o`000?oonf[ooo]Z00[ooo]Z001BoookJP03o`000?oonf[ooo]Z00_ooo]Z0_l0000EokS>j`?o
00004Onkd>T00ol0003o_M3Xokg@j004okg@j0;o00002_nodnT2o`0000go`]CX0_l000000oo4f>So
0000olSKi`0=olSKi`03o`000?o>gNCoc]gT00Woc]gT00?o0000omKLgOoFg=d02?oFg=d00ol0003o
g=C@omcDd006omcDd003o`000?oMalCo000000OojLRd00?o0000on6fZ_oQ]ZX02_oQ]ZX00ol0003o
eZf^omJ][P06omJ][P03o`000?oDXJ;oe:6R00[oe:6R00?o0000ol>L/?o3W;000oo3W;000ol0003o
ZhF]oj^5[@0<oj^5[@03o`000?n4JJcoQ6V/00WoQ6V/00?o0000og5S/omaHk<02OmaHk<00ol0003o
NGG3ogUe``08ogUe``03o`000?n;S<ooRhc?00GoRhc?2?l0000=oifMd`03o`000?n/Y]7o[:KA00go
[:KA00?o0000okRYb_nhZLX02_nhZLX3o`000003ok2UcOl0003o]:?7013o]:?700?o0000ok:L`Onb
W<403OnbW<400ol0003oYi2mojN@_@03ojN@_@Co00001_nSUlP00ol0003oVY38oiZ@b00;oiZ@b003
o`000?n@SLcoT8g<00goT8g<00?o0000oh^>dOn;S]402on;S]400ol0003oRI?GohVCe`0<ohVCe`03
o`000?n:V]goRY[M00goRY[M00?o0000ohbQh_n<XN803?n<XN800ol0003oSjOVohnWiP05ohnWiP03
o`000?n?YnKoSjOV00KoSjOV00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0:oookJP00
DooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?nhc^_o^<k[013o^<k[0_l00003okW>jP03o`00
0?nkd>Wo^m3Y00co^m3Y0_l00009okg@j003o`000?nodnWo_m?Y00Go_m?Y0_l0000@ol;Dj0?o0000
3Oo8fnL00ol0003oc]gTolkMi009olkMi003o`000?oFg=goe]cM00Soe]cM00?o0000omcDd?oLe=00
1_oLe=001?l0003ogLO4omg7a?oMal@2o`0000CojLRd00?o0000on6fZ_oQ]ZX02ooQ]ZX00ol0003o
eZf^omJ][P07omJ][P03o`000?oDXJ;oe:6R00Soe:6R00?o0000ol>L/?o3W;001?o3W;000ol0003o
ZhF]oj^5[@0<oj^5[@03o`000?n4JJcoQ6V/00[oQ6V/00?o0000og5S/omaHk<02?maHk<00ol0003o
NGG3ogUe``09ogUe``03o`000?n;S<ooRhc?00[oRhc?00?o0000oifMdonMWM<03OnMWM<00ol0003o
[:KAojbVd@0=ojbVd@03o`000?nhZL[o^:W:00Oo^:W:0_l00005ok2Uc@03o`000?ndXlOo]:?700ko
]:?700?o0000ok:L`OnbW<403OnbW<400ol0003oYi2mojN@_@03o`0000[oXiO800?o0000oiZ@b?nJ
T<P03?nJT<P00ol0003oT8g<oi2=c00<oi2=c003o`000?n;S]7oRhkA00coRhkA00?o0000ohVCeon9
TmL02on9TmL00ol0003oRY[MohZJg@0=ohZJg@03o`000?n<XN;oS:7R00goS:7R00?o0000ohnWi_n?
YnH01On?YnH00ol0003oSjOVohnWiP05ohnWiP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oo
nfX02OoonfX005Cooo]Z0_l0000=oookJP;o00003_nhc^/2o`0000Ko^LkZ0_l0000:ok_@j@;o0000
3?nmd>P2o`0000Co_m?Y00?o0000ol;Dj?o2e>P03oo2e>P01?l0003oaMGVolGEi_o5eNH2o`0000[o
b=_W00?o0000olkMi?o>gN@02Oo>gN@00ol0003oe]cMomKLg@08omKLg@03o`000?oLe=3og=C@00Ko
g=C@00?o0000omg7a?oMal@01?oMal@2o`0000;ojLRd00?o0000on6fZ_oQ]ZX02_oQ]ZX00ol0003o
eZf^omJ][P08omJ][P03o`000?oDXJ;oe:6R00Ooe:6R00?o0000ol>L/?o3W;001Oo3W;000ol0003o
ZhF]oj^5[@0<oj^5[@03o`000?n4JJcoQ6V/00[oQ6V/00?o0000og5S/omaHk<02?maHk<00ol0003o
NGG3ogUe``09ogUe``03o`000?n;S<ooRhc?00_oRhc?00?o0000oifMdonMWM<03?nMWM<00ol0003o
[:KAojbVd@0=ojbVd@03o`000?nhZL[o^:W:00Go^:W:0_l00007ok2Uc@03o`000?ndXlOo]:?700ko
]:?700?o0000ok:L`OnbW<403OnbW<43o`0000goXiO800?o0000oiZ@b?nJT<P03?nJT<P00ol0003o
T8g<oi2=c00=oi2=c003o`000?n;S]7oRhkA00_oRhkA00?o0000ohVCeon9TmL03?n9TmL00ol0003o
RY[MohZJg@0=ohZJg@03o`000?n<XN;oS:7R00coS:7R00?o0000ohnWi_n?YnH01_n?YnH00ol0003o
SjOVohnWiP05ohnWiP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX02OoonfX005Kooo]Z
00?o0000oookJ_oonfX03?oonfX00ol0003o^<k[okS>j`09okS>j`;o00002_nic^X00ol0003o^m3Y
ok_@j@05ok_@j@;o00004?nmd>P01?l0003o_m?Yo`000?l0000@ol;Dj0;o00001_o5eNH2o`0000Ko
b=_W0_l0000;olkMi003o`000?oFg=goe]cM00Soe]cM00?o0000omcDd?oLe=001_oLe=000ol0003o
gLO4omg7a007omg7a003o`000?oYb;Co000000cohKJZ00?o0000omJ][_oF[Jh02?oF[Jh00ol0003o
e:6RomBQXP07omBQXP03o`000?o3W;3o`ib`00Go`ib`00?o0000oj^5[On[QJd03?n[QJd00ol0003o
Q6V/ohAY[00:ohAY[003o`000?maHk?oLF>c00WoLF>c00?o0000ogUe`omiML<02OmiML<00ol0003o
Rhc?oh^<c`0:oh^<c`03o`000?nMWM?oWIgC00goWIgC00?o0000ojbVdOn/Y]403On/Y]401?l0003o
^:W:okRYb_nhZLX3o`0000[o/:G=00?o0000okBSaondXlL03_ndXlL00ol0003o/Yc1ok:L`@09ok:L
`@?o000000?oZYk:o`000?nSUlP03_nSUlP00ol0003oVY38oiZ@b00<oiZ@b003o`000?n@SLcoT8g<
00coT8g<00?o0000oh^>dOn;S]403?n;S]400ol0003oRI?GohVCe`0<ohVCe`03o`000?n:V]goRY[M
00coRY[M00?o0000ohbQh_n<XN803On<XN800ol0003oSjOVohnWiP05ohnWiP03o`000?n?YnKoSjOV
00GoSjOV00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP09oookJP00EooonfX00ol0003o
oo]ZoookJP0<oookJP03o`000?nhc^_o^<k[00Ko^<k[0_l0000=okW>jP;o00001?nkd>T00ol0003o
_M3Xokg@j00@okg@j0?o00004?o2e>P00ol0003oaMGVolGEiP08olGEiP03o`000?o8fnOob=_W00;o
b=_W00?o0000olkMi?o>gN@02Oo>gN@2o`0000[oe]cM00?o0000omcDd?oLe=001ooLe=000ol0003o
gLO4omg7a008omg7a003o`000?oQ]Z[ohKJZ00_ohKJZ00?o0000omJ][_oF[Jh02?oF[Jh00ol0003o
e:6RomBQXP06omBQXP03o`000?o3W;3o`ib`00Ko`ib`00?o0000oj^5[On[QJd03?n[QJd00ol0003o
Q6V/ohAY[00:ohAY[003o`000?maHk?oLF>c00WoLF>c00?o0000ogUe`omiML<02OmiML<00ol0003o
Rhc?oh^<c`0;oh^<c`03o`000?nMWM?oWIgC00goWIgC00?o0000ojbVdOn/Y]403?n/Y]401?l0003o
^:W:o`000?l0000=ok2Uc@03o`000?ndXlOo]:?700ko]:?700?o0000ok:L`OnbW<401onbW<42o`00
00GoZYk:00?o0000oj>Gb?nSUlP03?nSUlP00ol0003oVY38oiZ@b00<oiZ@b003o`000?n@SLcoT8g<
00goT8g<00?o0000oh^>dOn;S]402on;S]400ol0003oRI?GohVCe`0<ohVCe`03o`000?n:V]goRY[M
00goRY[M00?o0000ohbQh_n<XN803?n<XN800ol0003oSjOVohnWiP06ohnWiP03o`000?n?YnKoSjOV
00GoSjOV00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP09oookJP00F?oonfX00ol0003o
oo]ZoookJP0<oookJP;o00001?nhc^/2o`00017o^LkZ00Co0000ok_@jOl0003o00004_nmd>P01Ol0
003o_m3Woko@ionod>Oo000000go`]CX0_l0000<olGEiP;o000000?ob=_Wo`000?o>gN@02_o>gN@0
0ol0003oe]cMomKLg@09omKLg@03o`000?oLe=3og=C@00Oog=C@00?o0000omg7a?oMal@02OoMal@0
0ol0003ohKJZon6fZP0:on6fZP03o`000?oF[JkoeZf^00[oeZf^00?o0000omBQX_oDXJ801OoDXJ80
0ol0003o`ib`ol>L/007ol>L/003o`000?n[QJgoZhF]00coZhF]00?o0000ohAY[?n4JJ`02_n4JJ`0
0ol0003oLF>cog5S/`09og5S/`03o`000?miML?oNGG300WoNGG300?o0000oh^<con;S<l02_n;S<l0
0ol0003oWIgCoifMd`0=oifMd`03o`000?n/Y]7o[:KA00co[:KA0_l0000@ok2Uc@03o`000?ndXlOo
]:?700ko]:?700?o0000ok:L`OnbW<401?nbW<42o`0000OoZYk:00?o0000oj>Gb?nSUlP03OnSUlP0
0ol0003oVY38oiZ@b00<oiZ@b003o`000?n@SLcoT8g<00coT8g<00?o0000oh^>dOn;S]403?n;S]40
0ol0003oRI?GohVCe`0<ohVCe`03o`000?n:V]goRY[M00goRY[M00?o0000ohbQh_n<XN803?n<XN80
0ol0003oSjOVohnWiP06ohnWiP03o`000?n?YnKoSjOV00GoSjOV00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP09oookJP00FOoonfX2o`0000kooo]Z00Co0000okS>jol0003o00004onic^X3
o`00017o_M3X0_l00005oko@i`;o00002Oo2e>P2o`0000ooaMGV0ol0000:olkMi003o`000?oFg=go
e]cM00Woe]cM00?o0000omcDd?oLe=001ooLe=000ol0003ogLO4omg7a009omg7a003o`000?oI_;go
000000_ohKJZ00?o0000omJ][_oF[Jh02_oF[Jh00ol0003oe:6RomBQXP04omBQXP03o`000?o3W;3o
`ib`00So`ib`00?o0000oj^5[On[QJd03?n[QJd00ol0003oQ6V/ohAY[00:ohAY[003o`000?maHk?o
LF>c00WoLF>c00?o0000ogUe`omiML<02OmiML<00ol0003oRhc?oh^<c`0;oh^<c`03o`000?nMWM?o
WIgC00goWIgC00?o0000ojbVdOn/Y]402?n/Y]43o`000003ojVTdOl0003o/:G=00oo/:G=00?o0000
okBSaondXlL03_ndXlL01?l0003o/Yc1ok:L`OnbW<43o`0000[oZYk:00?o0000oj>Gb?nSUlP03?nS
UlP00ol0003oVY38oiZ@b00<oiZ@b003o`000?n@SLcoT8g<00coT8g<00?o0000oh^>dOn;S]403?n;
S]400ol0003oRI?GohVCe`0<ohVCe`03o`000?n:V]goRY[M00goRY[M00?o0000ohbQh_n<XN803On<
XN800ol0003oSjOVohnWiP06ohnWiP03o`000?n?YnKoSjOV00CoSjOV00?o0000oookJ_oonfX03ooo
nfX00ol0003ooo]ZoookJP09oookJP00FooonfX00ol0003ooo]ZoookJP0<oookJP;o00004_nic^X2
o`0000?o^lkY0_l0000=okg@j0;o00002Onod>L00ol0003o`]CXol;Dj005ol;Dj003o`000?o5eNKo
aMGV00koaMGV00Co0000olWEhoo9eN?obMGS0_l00007olkMi003o`000?oFg=goe]cM00[oe]cM00?o
0000omcDd?oLe=001_oLe=000ol0003ogLO4omg7a009omg7a005o`000?oI_;gofKbmomVl_Ol00000
2OoQ]ZX00ol0003oeZf^omJ][P0;omJ][P03o`000?oDXJ;oe:6R00?oe:6R00?o0000ol>L/?o3W;00
2Oo3W;000ol0003oZhF]oj^5[@0<oj^5[@03o`000?n4JJcoQ6V/00[oQ6V/00?o0000og5S/omaHk<0
2OmaHk<00ol0003oNGG3ogUe``0:ogUe``03o`000?n;S<ooRhc?00_oRhc?00?o0000oifMdonMWM<0
3?nMWM<00ol0003o[:KAojbVd@05ojbVd@?o00001OnYY=400ol0003o/:G=ok2Uc@0>ok2Uc@03o`00
0?ndXlOo]:?700go]:?700Co0000ok:L`Ol0003o00003OnZW/X00ol0003oXiO8oj>Gb00=oj>Gb003
o`000?nJT<SoVY3800_oVY3800?o0000oi2=c?n@SL`03On@SL`00ol0003oRhkAoh^>d@0<oh^>d@03
o`000?n9TmOoRI?G00coRI?G00?o0000ohZJgOn:V]d03On:V]d00ol0003oS:7RohbQhP0<ohbQhP03
o`000?n?YnKoSjOV00KoSjOV2Ol0000@oookJP03o`000?oonf[ooo]Z00Wooo]Z001LoookJP03o`00
0?oonf[ooo]Z00gooo]Z0_l0000>okW>jP;o00001onkc^T00ol0003o_M3Xokg@j009okg@j003o`00
0?nod>Oo_m3W00[o_m3W0_l00003ol;Dj0;o00003oo5eNH2o`0000KobMGS0_l00004olkMi003o`00
0?oFg=goe]cM00[oe]cM00?o0000omcDd?oLe=001ooLe=000ol0003ogLO4omg7a009omg7a005o`00
0?oI_;gofKbmomVl_Ol000002OoQ]ZX00ol0003oeZf^omJ][P0<omJ][P03o`000?oDXJ;oe:6R00;o
e:6R00?o0000ol>L/?o3W;002Oo3W;000ol0003oZhF]oj^5[@0<oj^5[@03o`000?n4JJcoQ6V/00[o
Q6V/00?o0000og5S/omaHk<02_maHk<00ol0003oNGG3ogUe``09ogUe``03o`000?n;S<ooRhc?00_o
Rhc?00?o0000oifMdonMWM<03OnMWM<00ol0003o[:KAojbVd@02ojbVd@;o00002?nYY=400ol0003o
/:G=ok2Uc@0>ok2Uc@03o`000?ndXlOo]:?700go]:?70_l0000?ojZNbP03o`000?nSUlSoXiO800go
XiO800?o0000oiZ@b?nJT<P03?nJT<P00ol0003oT8g<oi2=c00<oi2=c003o`000?n;S]7oRhkA00co
RhkA00?o0000ohVCeon9TmL03On9TmL00ol0003oRY[MohZJg@0<ohZJg@03o`000?n<XN;oS:7R00Ko
S:7R3ol000000onCZ^Go0000oi>Zi@05oi>Zi@03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo
nfX02?oonfX005gooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003o^LkZokW>jP09okW>jP;o0000
2_nkc^T2o`0000Oo_M3X0_l0000?oko@i`03o`000?o2e>So0000013oaMGV00?o0000olWEhoo9eN<0
2?o9eN<2o`000003olkMi?l0003oe]cM00_oe]cM00?o0000omcDd?oLe=001ooLe=000ol0003ogLO4
omg7a009omg7a003o`000?oI_;gofKbm00?ofKbm00?o0000on6fZ_oQ]ZX01OoQ]ZX00ol0003oeZf^
omJ][P0=omJ][P05o`000?oDXJ;oe:6RomBQX_l000003Oo3W;000ol0003oZhF]oj^5[@0;oj^5[@03
o`000?n4JJcoQ6V/00_oQ6V/00?o0000og5S/omaHk<02OmaHk<00ol0003oNGG3ogUe``0:ogUe``03
o`000?n;S<ooRhc?00_oRhc?00?o0000oifMdonMWM<03?nMWM<00ol0003o[:KAo`000002o`0000_o
ZJCA00?o0000ok2UcOn`YLd03_n`YLd00ol0003o]:?7okBSa`09okBSa`?o000000?o[:?=o`000?nZ
W/X03onZW/X00ol0003oXiO8oj>Gb00<oj>Gb003o`000?nJT<SoVY3800coVY3800?o0000oi2=c?n@
SL`03On@SL`00ol0003oRhkAoh^>d@0<oh^>d@03o`000?n9TmOoRI?G00coRI?G00?o0000ohZJgOn:
V]d01_n:V]d?o`0000OoTZGS00?o0000oi>ZiOnCZ^D01onCZ^D00ol0003oTj[Uoi>Zi@04oi>Zi@03
o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX02?oonfX005kooo]Z0_l0000?oookJP;o0000
2?nic^X00ol0003o^lkYok_>j@0<ok_>j@;o00000onmd>P2o`00017o_m3W0ol0000>olGEiP;o0000
3?o9eN<3o`0000_oe]cM00?o0000omcDd?oLe=001ooLe=000ol0003ogLO4omg7a009omg7a003o`00
0?oI_;gofKbm00GofKbm00?o0000on6fZ_oQ]ZX01?oQ]ZX00ol0003oeZf^omJ][P0=omJ][P04o`00
0?oDXJ;oe:6Ro`0000ko`ib`00?o0000oj^5[On[QJd03?n[QJd00ol0003oQ6V/ohAY[00:ohAY[003
o`000?maHk?oLF>c00WoLF>c00?o0000ogUe`omiML<02_miML<00ol0003oRhc?oh^<c`0;oh^<c`03
o`000?nMWM?oWIgC00_oWIgC0ol0000>ojVTd@03o`000?n`YLgo/:G=00ko/:G=00?o0000okBSaond
XlL01_ndXlL3o`0000Go[:?=00?o0000ojZNb_nZW/X03OnZW/X00ol0003oXiO8oj>Gb00=oj>Gb003
o`000?nJT<SoVY3800coVY3800?o0000oi2=c?n@SL`03?n@SL`00ol0003oRhkAoh^>d@0<oh^>d@03
o`000?n9TmOoRI?G00KoRI?G3ol00007oi6Qg`03o`000?nBYN?oTZGS00goTZGS00?o0000oi>ZiOnC
Z^D01_nCZ^D00ol0003oTj[Uoi>Zi@05oi>Zi@03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oo
nfX02?oonfX0063ooo]Z00?o0000oookJ_oonfX03_oonfX2o`0000Co^LkZ0_l0000Aok_>j@03o`00
0?nmd>So000001;o_m3W00Co0000ol;Ai_o2dNKo`]7V0_l0000:olGEiP;o00003Oo9eN<01?l0003o
c]?MolkCgOo>dmd2o`0000Soe]cM00?o0000omcDd?oLe=002?oLe=000ol0003ogLO4omg7a009omg7
a003o`000?oI_;gofKbm00GofKbm00?o0000on6fZ_oQ]ZX00ooQ]ZX00ol0003oeZf^omJ][P0>omJ]
[P04o`000?oDXJ;oe:6Ro`0000ko`ib`00?o0000oj^5[On[QJd03?n[QJd00ol0003oQ6V/ohAY[00:
ohAY[003o`000?maHk?oLF>c00[oLF>c00?o0000ogUe`omiML<02_miML<00ol0003oRhc?oh^<c`0;
oh^<c`03o`000?nMWM?oWIgC00GoWIgC1Ol00002oj2NdP03o`000?nYY=7oZJCA00goZJCA00?o0000
ok2UcOn`YLd03_n`YLd00ol0003o]:?7okBSa`02okBSa`?o00002?n/Xld00ol0003oZYk:ojZNbP0>
ojZNbP03o`000?nSUlSoXiO800coXiO800?o0000oiZ@b?nJT<P03?nJT<P00ol0003oT8g<oi2=c009
oi2=c1_o00001onAW=/00ol0003oTJ7Ooi6Qg`0=oi6Qg`03o`000?nBYN?oTZGS00goTZGS00?o0000
oi>ZiOnCZ^D01_nCZ^D00ol0003oTj[Uoi>Zi@04oi>Zi@03o`000?oonf[ooo]Z00gooo]Z00?o0000
oookJ_oonfX02?oonfX0067ooo]Z00?o0000oookJ_oonfX03ooonfX01?l0003o^LkZo`000?l0000C
ok_>j@?o00004?nod>L2o`0000Ko`]7V0_l00007olGEiP03o`000?o9eN?obMGS00cobMGS00?o0000
olkCgOo>dmd01?o>dmd3o`0000Coe]cM00?o0000omcDd?oLe=002?oLe=000ol0003ogLO4omg7a009
omg7a003o`000?oI_;gofKbm00OofKbm00?o0000on6fZ_oQ]ZX00_oQ]ZX00ol0003oeZf^omJ][P0?
omJ][P;o00003oo3W;000ol0003oZhF]oj^5[@0<oj^5[@03o`000?n4JJcoQ6V/00[oQ6V/00?o0000
og5S/omaHk<02_maHk<00ol0003oNGG3ogUe``0:ogUe``03o`000?n;S<ooRhc?00_oRhc?00?o0000
oifMdonMWM<01Ol00008oj2NdP03o`000?nYY=7oZJCA00coZJCA00?o0000ok2UcOn`YLd03_n`YLd0
0ol0003o]:?7o`000002o`0000co[:?=00?o0000ojZNb_nZW/X03OnZW/X00ol0003oXiO8oj>Gb00=
oj>Gb003o`000?nJT<SoVY3800_oVY3800?o0000oi2=c?n@SL`00_n@SL`7o`0000CoUiSC00?o0000
oi>IeonCVML03?nCVML00ol0003oTIcKoi6Lf`0=oi6Lf`03o`000?nAXMooTJ7O00coTJ7O00?o0000
oi:UhonBYN<03OnBYN<00ol0003oTj[Uoi>Zi@07oi>Zi@03o`000?nCZ^GoTj[U00CoTj[U00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP08oookJP00H_oonfX00ol0003ooo]ZoookJP0?oook
JP;o00004_nkc^T2o`0000?o_<kW00?o0000oko@ionod>L02onod>L2o`0000[o`]7V00?o0000olGE
i_o5eNH00_o5eNH2o`0000gobMGS0_l0000:olkCg@;o000000?oe]cMo`000?oLe=002OoLe=000ol0
003ogLO4omg7a009omg7a003o`000?oI_;gofKbm00WofKbm00Go0000on6fZ_oQ]Z[ohKJZo`00000A
omJ][P03o`000?o3W;3o`ib`00oo`ib`00?o0000oj^5[On[QJd02on[QJd00ol0003oQ6V/ohAY[00;
ohAY[003o`000?maHk?oLF>c00WoLF>c00?o0000ogUe`omiML<02omiML<00ol0003oRhc?oh^<c`08
oh^<c`Go00003OnPW]800ol0003oZJCAojVTd@0=ojVTd@03o`000?n`YLgo/:G=00go/:G=0_l0000?
ojbSc@03o`000?nZW/[oZYk:00koZYk:00?o0000oj>Gb?nSUlP03?nSUlP00ol0003oVY38oiZ@b009
oiZ@b0Oo00003?nGV=<00ol0003oTiWGoi>Ie`0<oi>Ie`03o`000?nAW=_oTIcK00coTIcK00?o0000
oi6QgonAXMl03OnAXMl00ol0003oTZGSoi:Uh`0=oi:Uh`03o`000?nCZ^GoTj[U00OoTj[U00?o0000
oi>ZiOnCZ^D00onCZ^D00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00Sooo]Z001Soook
JP;o00004OoonfX00ol0003o^lkYok_>j@0=ok_>j@;o00001_nlc^L2o`0000[o_m3W00?o0000ol;A
i_o2dNH02oo2dNH2o`000003olGEi_l0003obMGS00gobMGS00?o0000olkCgOo>dmd02oo>dmd3o`00
00Wog=C@00?o0000omg7a?oMal@02_oMal@00ol0003ofKbmomVl_@09omVl_@04o`000?oQ]Z[ohKJZ
o`0001;oeZf^00?o0000ol>L/?o3W;003oo3W;000ol0003oZhF]oj^5[@0;oj^5[@03o`000?n4JJco
Q6V/00SoQ6V/6?l00005ogUe``04o`000?n;S<ooRhc?oh^<c`Oo00000onGULl00ol0003oX9kBoj2N
dP0=oj2NdP03o`000?nYY=7oZJCA00coZJCA00?o0000ok2UcOn`YLd02_n`YLd3o`000003oj^Ud?l0
003o[:?=00oo[:?=00?o0000ojZNb_nZW/X03OnZW/X00ol0003oXiO8oj>Gb00<oj>Gb003o`000?nJ
T<SoVY3800;oVY381ol00003oibJd@03o`000?nGV=?oUiSC00goUiSC00?o0000oi>IeonCVML03?nC
VML00ol0003oTIcKoi6Lf`0=oi6Lf`03o`000?nAXMooTJ7O00coTJ7O00?o0000oi:UhonBYN<03OnB
YN<00ol0003oTj[Uoi>Zi@07oi>Zi@03o`000?nCZ^GoTj[U00CoTj[U00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP08oookJP00IOoonfX00ol0003ooo]ZoookJP0?oookJP;o00002onkc^T2
o`0000[o_<kW00?o0000oko@ionod>L01Onod>L2o`0000oo`]7V0ol0000=olWEh`03o`000?o>dmgo
c]?M00_oc]?M00Co0000om7>e_oAc]KodLkF0_l00007omcDd003o`000?oMalCogLO400WogLO400?o
0000omVl_OoI_;d02ooI_;d00ol0003ohKJZo`00000AomJ][P03o`000?o9Z;So0000013o`ib`00?o
0000oj^5[On[QJd03?n[QJd00ol0003oQ6V/ohAY[007o`0000?oVHFl00?o0000ohn2`On?P/402_n?
P/400ol0003oShW9ohn9b@05ohn9b@Wo00002onGULl00ol0003oX9kBoj2NdP0<oj2NdP03o`000?nY
Y=7oZJCA00goZJCA00?o0000ok2UcOn`YLd01on`YLd2o`0000GoZjG@00?o0000ojbScOn/Xld03On/
Xld00ol0003oZYk:ojZNbP0=ojZNbP03o`000?nSUlSoXiO800_oXiO81_l0000;oibJd@03o`000?nG
V=?oUiSC00goUiSC00?o0000oi>IeonCVML03?nCVML00ol0003oTIcKoi6Lf`0<oi6Lf`03o`000?nA
XMooTJ7O00goTJ7O00?o0000oi:UhonBYN<03OnBYN<00ol0003oTj[Uoi>Zi@07oi>Zi@03o`000?nC
Z^GoTj[U00CoTj[U00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP08oookJP00I_oonfX0
0ol0003ooo]ZoookJP0@oookJP03o`000?nkc^Wo^lkY00Ko^lkY0_l0000=okc>i`;o00000onod>L2
o`00013o`]7V00Co0000olG@hoo5d>?oaM3S0_l0000:olWEh`03o`000?o>dmgoc]?M00_oc]?M00?o
0000om7>e_oAc]H01?oAc]H2o`0000Cog=C@00?o0000omg7a?oMal@02OoMal@00ol0003ofKbmomVl
_@0=omVl_@03o`000?oF[JkoeZf^00ooeZf^00Co0000olVX^?o9Z;So00004?o3W;000ol0003oZhF]
oj^5[@0;oj^5[@Co00002onIQK`00ol0003oSh;1ohn2`@0:ohn2`@03o`000?n?RLWoShW900[oShW9
00?o0000oiNEconGULl02onGULl00ol0003oX9kBoj2NdP0=oj2NdP03o`000?nYY=7oZJCA00coZJCA
00?o0000ok2UcOn`YLd01On`YLd2o`0000OoZjG@00?o0000ojbScOn/Xld03_n/Xld00ol0003oZYk:
ojZNbP0=ojZNbP03o`000?nSUlSoXiO800GoXiO81Ol00002oj:Md003o`000?nLV]7oW9[A00coW9[A
00?o0000oiNHdonGV=<03OnGV=<00ol0003oTiWGoi>Ie`0<oi>Ie`03o`000?nAW=_oTIcK00goTIcK
00?o0000oi6QgonAXMl03OnAXMl00ol0003oTZGSoi:Uh`0=oi:Uh`03o`000?nCZ^GoTj[U00OoTj[U
00?o0000oi>ZiOnCZ^D00onCZ^D00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00Oooo]Z
001WoookJP03o`000?oonf[ooo]Z013ooo]Z0_l00004ok_>j@;o00004Onlc^L00ol0003o_m3Wo`00
000@ol;AiP;o00001_o5d><2o`0000KobMGS0_l0000=olkCg@03o`000?oAc]KodLkF00OodLkF0_l0
00000ooLe=3o0000omg7a00;omg7a003o`000?oI_;gofKbm00gofKbm00?o0000omJ][_oF[Jh03_oF
[Jh01Ol0003obJRholVX^?o9Z;So0000013o`ib`00?o0000oj^5[On[QJd02On[QJd2o`000003oj^A
^ol0003oVHFl00coVHFl00?o0000ohn2`On?P/402_n?P/400ol0003oShW9ohn9b@0;ohn9b@03o`00
0?nGULooUiG?00_oUiG?00?o0000oj2Nd_nPW]803OnPW]800ol0003oZJCAojVTd@0<ojVTd@04o`00
0?n`YLgo/:G=ok2Uc@?o00002_n[YM000ol0003o[:?=ojbSc@0=ojbSc@03o`000?nZW/[oZYk:00go
ZYk:00?o0000oj>Gb?nSUlP01Ol00008oj:Md003o`000?nLV]7oW9[A00coW9[A00?o0000oiNHdonG
V=<03OnGV=<00ol0003oTiWGoi>Ie`0<oi>Ie`03o`000?nAW=_oTIcK00goTIcK00?o0000oi6QgonA
XMl03?nAXMl00ol0003oTZGSoi:Uh`0=oi:Uh`03o`000?nCZ^GoTj[U00KoTj[U2Ol0000<oookJP03
o`000?oonf[ooo]Z00Oooo]Z001XoookJP;o00004_oonfX01?l0003o^lkYo`000?l0000Cokc>i`?o
00003oo2dNH00ol0003oaM3SolG@h`08olG@h`03o`000?o9eN?obMGS00;obMGS00?o0000olkCgOo>
dmd03?o>dmd00ol0003odLkFom7>eP0:om7>eP;o00002ooMal@00ol0003ofKbmomVl_@0=omVl_@03
o`000?oA]Kgo000000ooeZf^00?o0000olVX^?o9Z;P00_o9Z;P00ol0003o`ib`ol>L/00>ol>L/003
o`000?n[QJgoZhF]00KoZhF]0_l00004oj^A^`03o`000?nIQKcoVHFl00[oVHFl00?o0000ohn2`On?
P/402_n?P/400ol0003oShW9ohn9b@0;ohn9b@03o`000?nGULooUiG?00_oUiG?00?o0000oj2Nd_nP
W]803OnPW]800ol0003oZJCAojVTd@0<ojVTd@04o`000?n`YLgo0000o`0000goZjG@00?o0000ojbS
cOn/Xld03On/Xld00ol0003oZYk:ojZNbP0=ojZNbP?o00003OnRWM000ol0003oW9[AoibJd@0<oibJ
d@03o`000?nGV=?oUiSC00goUiSC00?o0000oi>IeonCVML03?nCVML00ol0003oTIcKoi6Lf`0=oi6L
f`03o`000?nAXMooTJ7O00goTJ7O00?o0000oi:UhonBYN<02OnBYN<<o`0000;oUZcV00?o0000oiJ/
i_nF[>H00onF[>H00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Oooo]Z001ZoookJP03
o`000?oonf[ooo]Z013ooo]Z0_l0000Bokc>i`;o00000onnc^H00ol0003o`]7Vol;AiP0:ol;AiP;o
00003?o5d><2o`000003olWEhol0003oc]?M00goc]?M00?o0000om7>e_oAc]H02ooAc]H00ol0003o
d/O?o`000009omg7a003o`000?oI_;gofKbm00gofKbm00Co0000om6e_OoA]Kgo00003_oF[Jh00ol0
003obJRholVX^003olVX^003o`000?o3W;3o`ib`00ko`ib`00?o0000oj^5[On[QJd01?n[QJd2o`00
00KoZi6k00?o0000oiV5_?nIQK`02onIQK`00ol0003oSh;1ohn2`@0:ohn2`@03o`000?n?RLWoShW9
00_oShW900?o0000oiNEconGULl02onGULl00ol0003oX9kBoj2NdP0=oj2NdP03o`000?nYY=7oZJCA
00[oZJCA0ol0000@oj^Ud003o`000?n/Xlgo[:?=00go[:?=00?o0000ojZNb_nZW/X02OnZW/X3o`00
0003ojJQdOl0003oXYg@00koXYg@00?o0000oibJdOnLV]403?nLV]400ol0003oUiSCoiNHd`0<oiNH
d`03o`000?nCVMOoTiWG00goTiWG00?o0000oi6LfonAW=/03OnAW=/00ol0003oTJ7Ooi6Qg`0<oi6Q
g`03o`000?nBYN?oTZGS00;oTZGS1ol00004oiJYh`03o`000?nF[>KoUZcV00SoUZcV00?o0000oiJ/
i_nF[>H00onF[>H00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Oooo]Z001[oookJP03
o`000?oonf[ooo]Z017ooo]Z00?o0000okc>ionlc^L03_nlc^L00ol0003o_/kVokk>iP04okk>iP;o
00002Oo2dNH00ol0003oaM3SolG@h`0=olG@h`?o00003?o>dmd2o`0000godLkF00Go0000om;7cooB
alood/O?o`000008omg7a003o`000?oI_;gofKbm00cofKbm00?o0000om6e_OoA]Kd00_oA]Kd00ol0
003oeZf^omJ][P0:omJ][P03o`000?o9Z;SobJRh00CobJRh00?o0000ol>L/?o3W;003_o3W;000ol0
003oZhF]oj^5[@03oj^5[@03o`000?n[TK_oZi6k00KoZi6k00?o0000oiV5_?nIQK`02onIQK`00ol0
003oSh;1ohn2`@0:ohn2`@03o`000?n?RLWoShW900_oShW900?o0000oiNEconGULl02onGULl00ol0
003oX9kBoj2NdP0=oj2NdP03o`000?nYY=7oZJCA00OoZJCA0ol00002ojNTd`03o`000?n[YM3oZjG@
00koZjG@00?o0000ojbScOn/Xld03On/Xld00ol0003oZYk:ojZNbP06ojZNbP?o00001OnVXM400ol0
003oXYg@oj:Md00<oj:Md003o`000?nLV]7oW9[A00goW9[A00?o0000oiNHdonGV=<03?nGV=<00ol0
003oTiWGoi>Ie`0<oi>Ie`03o`000?nAW=_oTIcK00goTIcK00?o0000oi6QgonAXMl01_nAXMl;o`00
00coUZWS00?o0000oiJ/i_nF[>H02?nF[>H00ol0003oUZcVoiJ/iP02oiJ/iP03o`000?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX01ooonfX006cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o
_<kWokc>i`0;okc>i`;o00002Onnc^H00ol0003o`]7Vol;AiP05ol;AiP03o`000?o5d>?oaM3S00go
aM3S00Go0000olO>goo7c]ooalkOo`00000:olkCg@03o`000?oAc]KodLkF00codLkF00?o0000om;7
cooBall00ooBall00ol0003ogLO4omg7a004omg7a003o`000?oI_;gofKbm00cofKbm00?o0000om6e
_OoA]Kd00ooA]Kd00ol0003oeZf^omJ][P0:omJ][P03o`000?o9Z;SobJRh00GobJRh00?o0000ol>L
/?o3W;003Oo3W;001?l0003oZhF]oj^5[On[QJd2o`0000[oZi6k00?o0000oiV5_?nIQK`02_nIQK`0
0ol0003oSh;1ohn2`@0;ohn2`@03o`000?n?RLWoShW900_oShW900?o0000oiNEconGULl02onGULl0
0ol0003oX9kBoj2NdP0=oj2NdP03o`000?nYY=7oZJCA00?oZJCA0ol00006ojNTd`03o`000?n[YM3o
ZjG@00koZjG@00?o0000ojbScOn/Xld03On/Xld00ol0003oZYk:ojZNbP02ojZNbP?o00002?nVXM40
0ol0003oXYg@oj:Md00<oj:Md003o`000?nLV]7oW9[A00goW9[A00?o0000oiNHdonGV=<03?nGV=<0
0ol0003oTiWGoi>Ie`0=oi>Ie`03o`000?nAW=_oTIcK00WoTIcK3?l00007oiJVh@03o`000?nFZN?o
UZWS00koUZWS00?o0000oiJ/i_nF[>H01onF[>H00ol0003oUZcVoiJ/iP03oiJ/iP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX01ooonfX006gooo]Z0_l0000BoookJP;o00002Onlc^L2o`00
00co_/kV0_l00003ol;AiP;o00003oo5d><00ol0003oalkOolO>g`03olO>g`03o`000?o>dmgoc]?M
00Koc]?M00?o0000om7>e_oAc]H03?oAc]H00ol0003od/O?om;7c`05om;7c`03o`000?oMalCogLO4
00;ogLO400?o0000omVl_OoI_;d03OoI_;d00ol0003odKFmom6e_@04om6e_@03o`000?oF[JkoeZf^
00SoeZf^00?o0000olVX^?o9Z;P01_o9Z;P00ol0003o`ib`ol>L/00>ol>L/0?o00003?n[TK/00ol0
003oVHFloiV5_00;oiV5_003o`000?n?P/7oSh;100[oSh;100?o0000ohn9bOn?RLT02on?RLT00ol0
003oUiG?oiNEc`0;oiNEc`03o`000?nPW];oX9kB00goX9kB00?o0000ojVTdOnYY=400ol00009ojNT
d`03o`000?n[YM3oZjG@00koZjG@00?o0000ojbScOn/Xld03On/Xld00ol0003oZYk:o`000002o`00
00coYZ7A00?o0000oj:Md?nRWM003?nRWM000ol0003oW9[AoibJd@0=oibJd@03o`000?nGV=?oUiSC
00coUiSC00?o0000oi>IeonCVML03?nCVML00ol0003oTIcKoi6Lf`02oi6Lf`Oo00001?nFXmh00ol0
003oUZKQoiJVh@0=oiJVh@03o`000?nFZN?oUZWS00goUZWS00?o0000oiJ/i_nF[>H02?nF[>H00ol0
003oUZcVoiJ/iP03oiJ/iP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01ooonfX006oo
oo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o_<kWokc>i`04okc>i`;o00004?nnc^H00ol0003o
`]7Vo`00000?olG@h`;o00001oo7c]l2o`0000Goc]?M00?o0000om7>e_oAc]H03?oAc]H00ol0003o
d/O?om;7c`07om;7c`05o`000?oMalCogLO4omg7a?l000003_oI_;d00ol0003odKFmom6e_@05om6e
_@03o`000?oF[JkoeZf^00OoeZf^00?o0000olVX^?o9Z;P01oo9Z;P00ol0003o`ib`ol>L/00=ol>L
/0;o00003_n[TK/00ol0003oVHFloiV5_00;oiV5_003o`000?n?P/7oSh;100_oSh;100?o0000ohn9
bOn?RLT02on?RLT00ol0003oUiG?oiNEc`0;oiNEc`03o`000?nPW];oX9kB00_oX9kB1?l0000=ojNT
d`03o`000?n[YM3oZjG@00koZjG@00?o0000ojbScOn/Xld02on/Xld3o`0000ooYZ7A00?o0000oj:M
d?nRWM003?nRWM000ol0003oW9[AoibJd@0=oibJd@03o`000?nGV=?oUiSC00coUiSC00?o0000oi>I
eonCVML01_nCVML;o`0000coUZ?N00?o0000oiJVhOnFY^403OnFY^400ol0003oUZWSoiJYh`0=oiJY
h`03o`000?nF[>KoUZcV00SoUZcV00?o0000oiJ/i_nF[>H00_nF[>H00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z00Oooo]Z001`oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000okc>ionl
c^L00_nlc^L00ol0003o_/kVokk>iP0@okk>iP?o00003_o5d><00ol0003oalkOolO>g`09olO>g`05
o`000?o>dmgoc]?MolkCgOl000003_oAc]H00ol0003od/O?om;7c`09om;7c`03o`000?oMalCo0000
00kofKbm00?o0000om6e_OoA]Kd01ooA]Kd00ol0003oeZf^omJ][P05omJ][P03o`000?o9Z;SobJRh
00WobJRh00?o0000ol>L/?o3W;002oo3W;000ol0003o^Ifmo`00000?oj^A^`03o`000?nIQKcoVHFl
00[oVHFl00?o0000ohn2`On?P/402on?P/400ol0003oShW9ohn9b@0;ohn9b@03o`000?nGULooUiG?
00_oUiG?00?o0000oj2Nd_nPW]802?nPW]83o`0000;oXj7C00?o0000ojNTdonWY=<03OnWY=<00ol0
003oZjG@oj^Ud00=oj^Ud003o`000?n/Xlgo[:?=00So[:?=0ol00002ojRTdP03o`000?nVXM7oYZ7A
00goYZ7A00?o0000oj:Md?nRWM003OnRWM000ol0003oW9[AoibJd@0=oibJd@03o`000?nGV=?oUiSC
00WoUiSC2ol00007oiRQf`03o`000?nFXmkoUZ?N00goUZ?N00?o0000oiJVhOnFY^403OnFY^400ol0
003oUZWSoiJYh`0=oiJYh`03o`000?nF[>KoUZcV00WoUZcV00?o0000oiJ/i_nF[>H00_nF[>H00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Kooo]Z001aoookJP03o`000?oonf[ooo]Z017o
oo]Z00Co0000okc>iol0003o00004Onnc^H2o`0000?o`LgS00?o0000olG@hoo5d><02_o5d><00ol0
003oalkOolO>g`0;olO>g`03o`000?o>dmgo000000kodLkF00?o0000om;7cooBall02ooBall00ol0
003ofKbmomVl_@0<omVl_@03o`000?oA]KgodKFm00SodKFm00?o0000omJ][_oF[Jh01OoF[Jh00ol0
003obJRholVX^009olVX^003o`000?o3W;3o`ib`00[o`ib`00Go0000okVM_OniWKgo^Ifmo`00000>
oj^A^`03o`000?nIQKcoVHFl00_oVHFl00?o0000ohn2`On?P/402_n?P/400ol0003oShW9ohn9b@0<
ohn9b@03o`000?nGULooUiG?00_oUiG?00?o0000oj2Nd_nPW]800onPW]84o`0000KoXj7C00?o0000
ojNTdonWY=<03?nWY=<00ol0003oZjG@oj^Ud00>oj^Ud003o`000?n/Xlgo[:?=00?o[:?=1?l00006
ojRTdP03o`000?nVXM7oYZ7A00goYZ7A00?o0000oj:Md?nRWM003?nRWM000ol0003oW9[AoibJd@0=
oibJd@03o`000?nGV=?oUiSC00;oUiSC1ol00003oi^Pf003o`000?nHXM_oV:7K00goV:7K00?o0000
oiJSg_nFXmh03OnFXmh00ol0003oUZKQoiJVh@0=oiJVh@03o`000?nFZN?oUZWS00goUZWS00?o0000
oiJ/i_nF[>H02?nF[>H00ol0003oUZcVoiJ/iP02oiJ/iP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX01_oonfX007;ooo]Z00?o0000oookJ_oonfX04OoonfX2o`00017o_/kV00?o0000ol7=
hoo1cN<01?o1cN<2o`0000WoaM3S00?o0000olO>goo7c]l03?o7c]l3o`0000godLkF00?o0000om;7
cooBall03?oBall00ol0003ofKbmomVl_@0<omVl_@03o`000?oA]KgodKFm00SodKFm00?o0000omJ]
[_oF[Jh01?oF[Jh00ol0003obJRholVX^00:olVX^003o`000?o3W;3o`ib`00Wo`ib`00?o0000okVM
_OniWKd00_niWKd00ol0003oZi6koj^A^`0<oj^A^`03o`000?nIQKcoVHFl00_oVHFl00?o0000ohn2
`On?P/402on?P/400ol0003oShW9ohn9b@0;ohn9b@03o`000?nGULooUiG?00_oUiG?00?o0000oj2N
d_nPW]800ol0000:oj>Qd`03o`000?nWY=?oYjCC00goYjCC00?o0000oj^Ud?n[YM003On[YM000ol0
003o[:?=ojbSc@03o`0000[oZ:CB00?o0000ojJQdOnVXM403OnVXM400ol0003oXYg@oj:Md00=oj:M
d003o`000?nLV]7oW9[A00_oW9[A1_l0000;oi^Pf003o`000?nHXM_oV:7K00coV:7K00?o0000oiJS
g_nFXmh03OnFXmh00ol0003oUZKQoiJVh@0=oiJVh@03o`000?nFZN?oUZWS00koUZWS00?o0000oiJ/
i_nF[>H02?nF[>H6o`0000Sooo]Z00?o0000oookJ_oonfX01_oonfX007?ooo]Z0_l0000CoookJP03
o`000?nnc^Ko_/kV00co_/kV0_l00009ol7=h`03o`000?o5d>?oaM3S00CoaM3S0_l0000>olO>g`05
o`000?o:bm[ob/_Jol[;f_l000002ooAc]H00ol0003od/O?om;7c`0<om;7c`03o`000?o@_l[o0000
00cofKbm00?o0000om6e_OoA]Kd02_oA]Kd00ol0003oeZf^omJ][P02omJ][P03o`000?o9Z;SobJRh
00cobJRh00?o0000ol>L/?o3W;001oo3W;000ol0003o^IfmokVM_@03okVM_@03o`000?n[TK_oZi6k
00goZi6k00?o0000oiV5_?nIQK`02_nIQK`00ol0003oSh;1ohn2`@0;ohn2`@03o`000?n?RLWoShW9
00coShW900?o0000oiNEconGULl02?nGULl5o`0000koXj7C00?o0000ojNTdonWY=<03?nWY=<00ol0
003oZjG@oj^Ud00<oj^Ud0Co00003_nXY=800ol0003oYZ7AojJQd@0=ojJQd@03o`000?nRWM3oXYg@
00coXYg@00?o0000oibJdOnLV]401_nLV]45o`0000;oWZ7G00?o0000oi^Pf?nKX=P03?nKX=P00ol0
003oV:7KoiRQf`0=oiRQf`03o`000?nFXmkoUZ?N00goUZ?N00?o0000oiJVhOnFY^403OnFY^400ol0
003oUZWSoiJYh`0=oiJYh`03o`000?nF[>KoUZcV00;oUZcV2?l00003oiV_iP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX01_oonfX007Gooo]Z00?o0000oookJ_oonfX04OoonfX2o`0000[o
_/kV0_l0000<ol7=h`;o00000oo5d><00ol0003oalkOolO>g`0=olO>g`03o`000?o:bm[ob/_J00?o
b/_J0_l00008om7>eP03o`000?oBalood/O?00cod/O?00Go0000om2ob_o@_l[od;o:o`00000:omVl
_@03o`000?oA]KgodKFm00_odKFm00?o0000omJ][_oF[Jh00_oF[Jh00ol0003obJRholVX^00<olVX
^003o`000?o3W;3o`ib`00Go`ib`0_l00007okVM_@03o`000?n[TK_oZi6k00coZi6k00?o0000oiV5
_?nIQK`02onIQK`00ol0003oSh;1ohn2`@0;ohn2`@03o`000?n?RLWoShW900_oShW900Co0000oiNE
conGULooUiG?1ol00003oijLd@03o`000?nSXM?oXj7C00goXj7C00?o0000ojNTdonWY=<03OnWY=<0
0ol0003oZjG@oj^Ud008oj^Ud0?o00000_nXY]@00ol0003oZ:CBojRTdP0=ojRTdP03o`000?nVXM7o
YZ7A00goYZ7A00?o0000oj:Md?nRWM003?nRWM001?l0003oW9[AoibJdOnLV]45o`0000SoWZ7G00?o
0000oi^Pf?nKX=P03?nKX=P00ol0003oV:7KoiRQf`0<oiRQf`03o`000?nFXmkoUZ?N00koUZ?N00?o
0000oiJVhOnFY^403OnFY^400ol0003oUZWSoiJYh`09oiJYh`So00001onI[nH00ol0003oVJoVoiV_
iP02oiV_iP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX01_oonfX007Kooo]Z00?o0000
oookJ_oonfX04_oonfX00ol0003o_/kVokk>iP05okk>iP;o00004?o1cN<00ol0003oaM3So`00000>
olO>g`;o00002?o:bmX00ol0003odLkFom7>eP04om7>eP03o`000?oBalood/O?00cod/O?00?o0000
om2ob_o@_lX00oo@_lX00ol0003ofKbmomVl_@06omVl_@03o`000?oA]KgodKFm00godKFm00Co0000
omJ][_oF[Jko00003oo9Z;P00ol0003o`ib`ol>L/004ol>L/003o`000?niWKgo^Ifm00Oo^Ifm00?o
0000oj^A^on[TK/03?n[TK/00ol0003oVHFloiV5_00;oiV5_003o`000?n?P/7oSh;100_oSh;100?o
0000ohn9bOn?RLT02On?RLT6o`0000_oWYcA00?o0000oj>QdonSXM<03OnSXM<00ol0003oYjCCojNT
d`0=ojNTd`03o`000?n[YM3oZjG@00?oZjG@1?l00006ojRVe003o`000?nXY=;oZ:CB00goZ:CB00?o
0000ojJQdOnVXM403OnVXM400ol0003oXYg@oj:Md00:oj:Md0Go00003OnNXML00ol0003oVj3Hoi^P
f00=oi^Pf003o`000?nHXM_oV:7K00coV:7K00?o0000oiJSg_nFXmh03OnFXmh00ol0003oUZKQoiJV
h@0=oiJVh@03o`000?nFZN?oUZWS00;oUZWS1ol00004oiV/i003o`000?nI[nKoVJoV00WoVJoV00?o
0000oiV_i_nI[nH00_nI[nH00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Kooo]Z001g
oookJP03o`000?oonf[ooo]Z01;ooo]Z0_l00004okk>iP03o`000?o1cN?o`LgS013o`LgS0ol0000=
olO>g`03o`000?o:bm[ob/_J00Wob/_J0_l00003om7>eP03o`000?oBalood/O?00cod/O?00?o0000
om2ob_o@_lX01Oo@_lX00ol0003ofKbmomVl_@04omVl_@03o`000?oA]KgodKFm00kodKFm00?o0000
omJ][_l000004Oo9Z;P00ol0003o`ib`ol>L/002ol>L/003o`000?niWKgo^Ifm00So^Ifm00?o0000
oj^A^on[TK/03On[TK/00ol0003oVHFloiV5_00:oiV5_003o`000?n?P/7oSh;100_oSh;100?o0000
ohn9bOn?RLT00_n?RLT7o`0000?oViO>00?o0000oijLdOnNW=402onNW=400ol0003oXj7Coj>Qd`0>
oj>Qd`03o`000?nWY=?oYjCC00coYjCC00?o0000oj^Ud?n[YM000ol0000:ojRVe003o`000?nXY=;o
Z:CB00goZ:CB00?o0000ojJQdOnVXM403OnVXM400ol0003oXYg@oj:Md005oj:Md0Go00000_nRXmH0
0ol0003oWZ7GoijQe`0>oijQe`03o`000?nKX=SoVj3H00coVj3H00?o0000oiRQfonHXM/03OnHXM/0
0ol0003oUZ?NoiJSgP0=oiJSgP03o`000?nFY^7oUZKQ00WoUZKQ2?l0000<oiV/i003o`000?nI[nKo
VJoV00WoVJoV00Go0000oiV_i_nI[nKoVJoVo`000006oookJP03o`000?oonf[ooo]Z00Kooo]Z001h
oookJP;o00005?oonfX01?l0003o_/kVo`000?l0000Aol7=h`;o00000oo3bn400ol0003oalkOolO>
g`09olO>g`03o`000?o:bm[ob/_J00cob/_J00?o0000om7>e_l000003_oBall00ol0003od;o:om2o
bP07om2obP03o`000?oI_;gofKbm00?ofKbm00?o0000om6e_OoA]Kd03ooA]Kd00ol0003obJRholVX
^00@olVX^005o`000?o3W;3o`ib`ol>L/?l000003?niWKd00ol0003oZi6koj^A^`0<oj^A^`03o`00
0?nIQKcoVHFl00_oVHFl00?o0000ohn2`On?P/402On?P/46o`0000_oViO>00?o0000oijLdOnNW=40
2onNW=400ol0003oXj7Coj>Qd`0=oj>Qd`03o`000?nWY=?oYjCC00coYjCC0ol0000>ojRVe003o`00
0?nXY=;oZ:CB00coZ:CB00?o0000ojJQdOnVXM403OnVXM400ol0003oXYg@oj:Md005o`0000SoXZ?F
00?o0000oijQeonNXML03OnNXML00ol0003oVj3Hoi^Pf00=oi^Pf003o`000?nHXM_oV:7K00coV:7K
00?o0000oiJSg_nFXmh03OnFXmh00ol0003oUZKQoiJVh@02oiJVh@Oo00001?nIZ^800ol0003oVJcT
oiV/i00>oiV/i003o`000?nI[nKoVJoV00WoVJoV00Go0000oiV_i_nI[nKoVJoVo`000006oookJP03
o`000?oonf[ooo]Z00Gooo]Z001joookJP03o`000?oonf[ooo]Z01;ooo]Z0_l0000Aol7=h`03o`00
0?o3bn7o`l_Q00Co`l_Q00?o0000olO>goo7c]l01oo7c]l00ol0003ob/_Jol[;fP0=ol[;fP?o0000
3OoBall00ol0003od;o:om2obP09om2obP05o`000?oI_;gofKbmomVl_Ol000004_oA]Kd00ol0003o
bJRholVX^00@olVX^004o`000?o3W;3o`ib`o`0000go^Ifm00?o0000oj^A^on[TK/03?n[TK/00ol0
003oVHFloiV5_00;oiV5_003o`000?n?P/7oSh;100CoSh;11Ol00002oifCbP03o`000?nKUlkoViO>
00coViO>00?o0000oijLdOnNW=403?nNW=400ol0003oXj7Coj>Qd`0=oj>Qd`03o`000?nWY=?oYjCC
00SoYjCC0ol000000onWY]Go0000ojRVe00>ojRVe003o`000?nXY=;oZ:CB00goZ:CB00?o0000ojJQ
dOnVXM402onVXM44o`0000goXZ?F00?o0000oijQeonNXML03_nNXML00ol0003oVj3Hoi^Pf00<oi^P
f003o`000?nHXM_oV:7K00goV:7K00?o0000oiJSg_nFXmh02OnFXmh8o`0000coVJ[R00?o0000oiV/
i?nI[>@03OnI[>@00ol0003oVJoVoiV_iP09oiV_iP03o`000?nI[nKoVJoV00;oVJoV00?o0000oook
J_oonfX00ooonfX00ol0003ooo]ZoookJP05oookJP00NooonfX00ol0003ooo]ZoookJP0CoookJP03
o`000?o1cN?o`LgS00co`LgS0_l00008ol?;h@;o00001Oo7c]l2o`0000oob/_J00Go0000ol[6e_o:
a]Kob/KFo`00000;om;7c`03o`000?o@_l[od;o:00_od;o:00?o0000omVl_Ol000004_oA]Kd00ol0
003obK72o`00000BolVX^0;o00003_niWKd00ol0003oZi6koj^A^`0=oj^A^`03o`000?nIQKcoVHFl
00[oVHFl00?o0000ohn2`On?P/401?l00008oifCbP03o`000?nKUlkoViO>00coViO>00?o0000oijL
dOnNW=402onNW=400ol0003oXj7Coj>Qd`0=oj>Qd`03o`000?nWY=?oYjCC00GoYjCC0ol00005ojNV
e@03o`000?nXY]CoZ:KD00goZ:KD00?o0000ojRTd_nXY=803?nXY=800ol0003oYZ7AojJQd@08ojJQ
d@?o00000_nTYMH00ol0003oXZ?Foj:SeP0=oj:SeP03o`000?nNXMOoWZ7G00goWZ7G00?o0000oi^P
f?nKX=P03OnKX=P00ol0003oV:7KoiRQf`0<oiRQf`03o`000?nFXmkoUZ?N00;oUZ?N1ol00004oiZX
h003o`000?nIZ^;oVJ[R00koVJ[R00?o0000oiV/i?nI[>@03OnI[>@00ol0003oVJoVoiV_iP09oiV_
iP05o`000?nI[nKoVJoVoiV_i_l000001OoonfX00ol0003ooo]ZoookJP05oookJP00O?oonfX00ol0
003ooo]ZoookJP0CoookJP;o00002_o1cN<2o`0000co`l_Q00Go0000olO>goo7c]ooalkOo`00000@
ol[;fP03o`000?o:a]Kob/KF00?ob/KF00?o0000om;7cooBall01ooBall00ol0003od;o:om2obP0=
om2obP03o`000?oA]KgodKFm013odKFm00Co0000olVa`_o9/L;o00004Oo9Z;P2o`00013o^Ifm00?o
0000oj^A^on[TK/03?n[TK/00ol0003oVHFloiV5_009oiV5_0Co00003?nMTlX00ol0003oViO>oi^G
cP0<oi^GcP03o`000?nNW=7oWYcA00coWYcA00?o0000oj>QdonSXM<03OnSXM<00ol0003oYjCCojNT
d`02ojNTd`;o00002?nWY]D00ol0003oZ:KDojRVe00>ojRVe003o`000?nXY=;oZ:CB00coZ:CB00?o
0000ojJQdOnVXM400onVXM44o`0000KoY:GF00?o0000oj:Se_nRXmH03OnRXmH00ol0003oWZ7GoijQ
e`0=oijQe`03o`000?nKX=SoVj3H00goVj3H00?o0000oiRQfonHXM/02OnHXM/7o`0000coVZSP00?o
0000oiVZh_nIZ^803OnIZ^800ol0003oVJcToiV/i00=oiV/i003o`000?nI[nKoVJoV00[oVJoV00Go
0000oiV_i_nI[nKoVJoVo`000004oookJP03o`000?oonf[ooo]Z00Gooo]Z001moookJP;o00005Ooo
nfX00ol0003o`LgSol7=h`05ol7=h`;o00003oo3bn400ol0003oalkOo`00000?ol[;fP;o00001oo:
a]H00ol0003od/O?om;7c`05om;7c`03o`000?o@_l[od;o:00god;o:0_l0000Aom6e_@03o`000?o9
/L;obK7200;obK7200?o0000olVX^?o9Z;P03Oo9Z;P00ol0003o_jS2o`00000@okVM_@03o`000?n[
TK_oZi6k00coZi6k00?o0000oiV5_?nIQK`01?nIQK`5o`0000;oXiG700?o0000oifCb_nMTlX03?nM
TlX00ol0003oViO>oi^GcP0<oi^GcP03o`000?nNW=7oWYcA00_oWYcA00?o0000oj>QdonSXM<03OnS
XM<00ol0003oYjCCo`000002o`0000_oYjKE00?o0000ojRVe?nXY]@03OnXY]@00ol0003oZ:CBojRT
dP0<ojRTdP03o`000?nVXM7oYZ7A00?o00002_nTYMH00ol0003oXZ?Foj:SeP0=oj:SeP03o`000?nN
XMOoWZ7G00goWZ7G00?o0000oi^Pf?nKX=P03OnKX=P00ol0003oV:7KoiRQf`02oiRQf`Oo00000onK
Ymh00ol0003oVZSPoiZXh00>oiZXh003o`000?nIZ^;oVJ[R00goVJ[R00?o0000oiV/i?nI[>@03OnI
[>@00ol0003oVJoVoiV_iP0:oiV_iP03o`000?nI[nKo000000;o00000ooonfX00ol0003ooo]Zoook
JP05oookJP00OooonfX00ol0003ooo]ZoookJP0CoookJP;o00001?o1cN<00ol0003o`l_Qol?;h@0?
ol?;h@?o00003_o:bmX00ol0003ob/KFol[6eP08ol[6eP03o`000?oBalood/O?00?od/O?00?o0000
om2ob_o@_lX03Oo@_lX01?l0003oc;[9olbjbOl0000?om6e_@03o`000?o9/L;obK7200?obK7200?o
0000olVX^?o9Z;P03?o9Z;P01Ol0003o_jS2oknX`_noZ<;o000000oo^Ifm00?o0000oj^A^on[TK/0
3On[TK/00ol0003oVHFlo`000003o`0000SoXiG700?o0000oifCb_nMTlX02onMTlX00ol0003oViO>
oi^GcP0=oi^GcP03o`000?nNW=7oWYcA00_oWYcA00?o0000oj>QdonSXM<02onSXM<3o`0000koYjKE
00?o0000ojRVe?nXY]@03_nXY]@00ol0003oZ:CBojRTdP0:ojRTdPCo00003_nTYMH00ol0003oXZ?F
oj:SeP0=oj:SeP03o`000?nNXMOoWZ7G00goWZ7G00?o0000oi^Pf?nKX=P02OnKX=P8o`0000_oVjON
00?o0000oiZXh?nJZ>003OnJZ>000ol0003oVJ[RoiVZhP0=oiVZhP03o`000?nI[>CoVJcT00koVJcT
00?o0000oiV_i_nI[nH01_nI[nH5o`0000;oVk7W00Go0000oookJ_oonf[ooo]Zo`000007oookJP00
P?oonfX00ol0003ooo]ZoookJP0DoookJP04o`000?o1cN?o0000o`00017o`l_Q00Go0000olC8g_o4
b=koa<SNo`00000<ol[;fP03o`000?o:a]Kob/KF00[ob/KF00Go0000om;7cooBalood/O?o`00000?
om2obP03o`000?o<^/Woc;[900;oc;[900?o0000om6e_OoA]Kd02ooA]Kd00ol0003obK72olVa`P05
olVa`P03o`000?o9Z;SobJRh00[obJRh00?o0000oknX`_noZ<800_noZ<800ol0003o^IfmokVM_@0>
okVM_@03o`000?n[TK_oZi6k00_oZi6k0ol0000<oj>Ea`03o`000?nMTl[oWI?:00coWI?:00?o0000
oi^Gc_nKUlh03?nKUlh00ol0003oWYcAoijLd@0<oijLd@03o`000?nSXM?oXj7C00GoXj7C1Ol00002
ojBTe@03o`000?nWY]GoYjKE00goYjKE00?o0000ojRVe?nXY]@03OnXY]@00ol0003oZ:CBojRTdP07
ojRTdP?o00000_nVYmH00ol0003oY:GFojBUeP0>ojBUeP03o`000?nRXmKoXZ?F00coXZ?F00?o0000
oijQeonNXML03OnNXML00ol0003oVj3Hoi^Pf002oi^Pf0Oo00001?nMY]`00ol0003oVjONoi^WgP0=
oi^WgP03o`000?nJZ>3oVZSP00goVZSP00?o0000oiVZh_nIZ^803OnIZ^800ol0003oVJcToiV/i00=
oiV/i004o`000?nI[nKoVJoVoiV_iPGo00001?nK/NL01Ol0003oVk7Woi^aionK/NOo000000;ooo]Z
00?o0000oookJ_oonfX01OoonfX0087ooo]Z00?o0000oookJ_oonfX05?oonfX2o`00013o`l_Q0_l0
0005olC8gP;o00002Oo:bmX00ol0003ob/KFol[6eP0<ol[6eP03o`000?oBaloo000000ood;o:00?o
0000olbjbOo<^/T01?o<^/T00ol0003odKFmom6e_@09om6e_@03o`000?o9/L;obK7200KobK7200?o
0000olVX^?o9Z;P02Oo9Z;P00ol0003o_jS2oknX`P03oknX`P03o`000?niWKgo^Ifm00ko^Ifm00?o
0000oj^A^on[TK/02On[TK/2o`000003ojbKaOl0003oXiG700goXiG700?o0000oifCb_nMTlX02onM
TlX00ol0003oViO>oi^GcP0=oi^GcP03o`000?nNW=7oWYcA00_oWYcA00?o0000oj>QdonSXM<01Ol0
0008ojBTe@03o`000?nWY]GoYjKE00goYjKE00?o0000ojRVe?nXY]@03OnXY]@00ol0003oZ:CBojRT
dP03ojRTdP?o00001_nVYmH00ol0003oY:GFojBUeP0=ojBUeP03o`000?nRXmKoXZ?F00goXZ?F00?o
0000oijQeonNXML02onNXML6o`0000coWJKL00?o0000oi^Wg_nKYmh03?nKYmh00ol0003oVZSPoiZX
h00=oiZXh003o`000?nIZ^;oVJ[R00koVJ[R00?o0000oiV/i?nI[>@02OnI[>@7o`0000[oVk7W00Oo
0000oi^aionK/NOoVk7Wo`000?oonf[o000000Oooo]Z0022oookJP;o00005_oonfX00ol0003o`l_Q
ol?;h@0<ol?;h@03o`000?o4b=koa<SN00Ooa<SN00?o0000ol[;f_o:bmX01?o:bmX2o`0000oob/KF
0_l0000?om2obP03o`000?o<^/Woc;[900Goc;[900?o0000om6e_OoA]Kd02?oA]Kd00ol0003obK72
olVa`P08olVa`P03o`000?o9Z;SobJRh00OobJRh00?o0000oknX`_noZ<801OnoZ<800ol0003o^Ifm
okVM_@0=okVM_@03o`000?n[TK_oZi6k00OoZi6k0_l00004ojbKa@03o`000?nSULOoXiG700_oXiG7
00?o0000oifCb_nMTlX03?nMTlX00ol0003oViO>oi^GcP0<oi^GcP03o`000?nNW=7oWYcA00[oWYcA
1?l0000=ojBTe@03o`000?nWY]GoYjKE00goYjKE00?o0000ojRVe?nXY]@03OnXY]@00ol0003oZ:CB
ojRTdP03o`0000WoYZOF00?o0000ojBUe_nTYMH03_nTYMH00ol0003oXZ?Foj:SeP0=oj:SeP03o`00
0?nNXMOoWZ7G00GoWZ7G1Ol00002oinVf`03o`000?nMY]coWJKL00goWJKL00?o0000oi^Wg_nKYmh0
3OnKYmh00ol0003oVZSPoiZXh00=oiZXh003o`000?nIZ^;oVJ[R00goVJ[R00?o0000oiV/i?nI[>@0
0_nI[>@7o`0000CoVjoU00?o0000oi^aionK/NL02_nK/NL01Ol0003oVk7Woi^aionK/NOo000000;o
oo]Z00?o0000oookJ_oonfX01?oonfX008Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o`l_Q
ol?;h@09ol?;h@;o00002oo4b=h2o`0000?ob/_J00?o0000ol[6e_o:a]H03_o:a]H01?l0003obL7C
olW1dol0000=om2obP03o`000?o<^/Woc;[900Ooc;[900?o0000om6e_OoA]Kd01_oA]Kd00ol0003o
bK72olVa`P09olVa`P03o`000?o9Z;SobJRh00KobJRh00?o0000oknX`_noZ<801_noZ<800ol0003o
^IfmokVM_@0>okVM_@03o`000?n[TK_oZi6k00?oZi6k0ol00006ojbKa@03o`000?nSULOoXiG700co
XiG700?o0000oifCb_nMTlX02onMTlX00ol0003oViO>oi^GcP0=oi^GcP03o`000?nNW=7oWYcA00Co
WYcA1Ol00002oj>Re003o`000?nTY=GoY:CE00goY:CE00?o0000ojNVeOnWY]D03OnWY]D00ol0003o
Z:KDojRVe00;ojRVe0Co00003OnVYmH00ol0003oY:GFojBUeP0=ojBUeP03o`000?nRXmKoXZ?F00go
XZ?F00?o0000oijQeonNXML01Ol00008oinVf`03o`000?nMY]coWJKL00goWJKL00?o0000oi^Wg_nK
Ymh03?nKYmh00ol0003oVZSPoiZXh00>oiZXh003o`000?nIZ^;oVJ[R00WoVJ[R2?l0000<oi^_i@03
o`000?nK/NOoVk7W00[oVk7W00Oo0000oi^aionK/NOoVk7Wo`000?oonf[o000000Kooo]Z0025oook
JP03o`000?oonf[ooo]Z01Cooo]Z0_l00008ol?;h@03o`000?o4b=koa<SN00goa<SN00?o0000ol[;
f_l000004?o:a]H00ol0003obL7ColW1d`02olW1d`03o`000?o@_l[od;o:00Wod;o:00?o0000olbj
bOo<^/T02Oo<^/T00ol0003odKFmom6e_@04om6e_@03o`000?o9/L;obK7200[obK7200?o0000olVX
^?o9Z;P01Oo9Z;P00ol0003o_jS2oknX`P08oknX`P03o`000?niWKgo^Ifm00go^Ifm00Co0000oj^A
^on[TK_oZi6k0_l0000:ojbKa@03o`000?nSULOoXiG700_oXiG700?o0000oifCb_nMTlX02onMTlX0
0ol0003oViO>oi^GcP0=oi^GcP03o`000?nNW=7oWYcA00Co00002?nSX]@00ol0003oY:CEojBTe@0<
ojBTe@03o`000?nWY]GoYjKE00goYjKE00?o0000ojRVe?nXY]@02?nXY]@3o`0000;oYjSG00?o0000
ojJWe_nVYmH03OnVYmH00ol0003oY:GFojBUeP0=ojBUeP03o`000?nRXmKoXZ?F00_oXZ?F1?l0000>
oinVf`03o`000?nMY]coWJKL00coWJKL00?o0000oi^Wg_nKYmh03OnKYmh00ol0003oVZSPoiZXh00=
oiZXh003o`000?nIZ^;oVJ[R00;oVJ[R1ol00004oi^]i003o`000?nK[nGoVjoU00koVjoU00?o0000
oi^aionK/NL02_nK/NL01?l0003oVk7Woi^aionK/NL2o`0000Kooo]Z0026oookJP03o`000?oonf[o
oo]Z01Gooo]Z00?o0000ol?;hOo3bn401?o3bn400ol0003oa<SNolC8gP0>olC8gP?o00003_o:a]H2
o`0000KobL7C00?o0000om2ob_o@_lX01oo@_lX00ol0003oc;[9olbjb@0:olbjb@03o`000?oA]Kgo
dKFm00?odKFm00?o0000olVa`_o9/L803?o9/L800ol0003obJRholVX^003olVX^003o`000?noZ<;o
_jS200Wo_jS200?o0000okVM_OniWKd03OniWKd01?l0003oZi6ko`000?l0000<ojbKa@03o`000?nS
ULOoXiG700coXiG700?o0000oifCb_nMTlX02onMTlX00ol0003oViO>oi^GcP0;oi^GcPCo00003?nS
X]@00ol0003oY:CEojBTe@0=ojBTe@03o`000?nWY]GoYjKE00goYjKE00?o0000ojRVe?nXY]@00onX
Y]@4o`0000KoYjSG00?o0000ojJWe_nVYmH03?nVYmH00ol0003oY:GFojBUeP0>ojBUeP03o`000?nR
XmKoXZ?F00GoXZ?F1Ol00002oj:WfP03o`000?nOY]_oWjKK00goWjKK00?o0000oifVg?nMY]`03OnM
Y]`00ol0003oVjONoi^WgP0=oi^WgP03o`000?nJZ>3oVZSP00WoVZSP2?l0000<oi^]i003o`000?nK
[nGoVjoU00goVjoU00?o0000oi^aionK/NL02onK/NL00ol0003oVk7Woi^ai`02o`0000Kooo]Z0027
oookJP;o00005_oonfX01?l0003o`l_Qol?;hOo3bn42o`00013oa<SN00Go0000olC5foo4aM_oa<GK
o`00000<ol[6eP03o`000?o9`M?obL7C00OobL7C00?o0000om2ob_o@_lX01Oo@_lX00ol0003oc;[9
olbjb@0<olbjb@05o`000?oA]KgodKFmom6e_Ol000003oo9/L800ol0003obJRholVX^002olVX^003
o`000?noZ<;o_jS200_o_jS200?o0000okVM_OniWKd03?niWKd2o`0000ko[9_500?o0000oj>EaonS
ULL03?nSULL00ol0003oWI?:oifCbP0;oifCbP03o`000?nKUlkoViO>00SoViO>0ol00002oj:OdP03
o`000?nSX]CoXj;D00coXj;D00?o0000ojBTeOnTY=D03OnTY=D00ol0003oYjKEojNVe@0<ojNVe@03
o`000?nXY]CoZ:KD00?o00002_nWZ=L00ol0003oYZOFojJWeP0=ojJWeP03o`000?nTYMKoY:GF00go
Y:GF00?o0000oj:Se_nRXmH01Ol00008oj:WfP03o`000?nOY]_oWjKK00goWjKK00?o0000oifVg?nM
Y]`03OnMY]`00ol0003oVjONoi^WgP0<oi^WgP03o`000?nJZ>3oVZSP00;oVZSP1ol00004oib/hP03
o`000?nK[NCoVjgT00koVjgT00?o0000oi^_iOnK[nD03OnK[nD00ol0003oVk7Woi^ai`0:oi^ai`05
o`000?nK/NOoVk7Woi^aiol000001_oonfX008Wooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
`l_Qo`00000@olC8gP;o00001Oo4aM/00ol0003ob/KFol[6eP08ol[6eP03o`000?o9`M?obL7C00Wo
bL7C00?o0000om2ob_o@_lX00oo@_lX00ol0003oc;[9olbjb@0>olbjb@03o`000?oA]Kgo0000017o
bK7200Co0000olVX^?o9Z;So00003_noZ<800ol0003o^IfmokVM_@0;okVM_@03o`000?ndX/Oo0000
00oo[9_500?o0000oj>EaonSULL02onSULL00ol0003oWI?:oifCbP0<oifCbP03o`000?nKUlkoViO>
00?oViO>1?l00006oj:OdP03o`000?nSX]CoXj;D00coXj;D00?o0000ojBTeOnTY=D03?nTY=D00ol0
003oYjKEojNVe@0;ojNVe@Co00003_nWZ=L00ol0003oYZOFojJWeP0<ojJWeP03o`000?nTYMKoY:GF
00coY:GF1?l0000=oj:WfP03o`000?nOY]_oWjKK00koWjKK00?o0000oifVg?nMY]`03?nMY]`00ol0
003oVjONoi^WgP0;oi^WgPKo00003?nL[>800ol0003oVjgToi^]i00=oi^]i003o`000?nK[nGoVjoU
00koVjoU00?o0000oi^aionK/NL02_nK/NL00ol0003oVk7Wo`000002o`0000Gooo]Z002:oookJP03
o`000?oonf[ooo]Z01Cooo]Z0_l0000?olC8gP03o`000?o4aM_oa<GK00Koa<GK00?o0000ol[6e_o:
a]H01_o:a]H00ol0003obL7ColW1d`0;olW1d`05o`000?o@_l[od;o:om2ob_l000004Oo<^/T2o`00
01;obK7200?o0000olVX^?l000003onoZ<800ol0003o^IfmokVM_@09okVM_@;o00000ondX/L00ol0
003o[9_5ojbKa@0<ojbKa@03o`000?nSULOoXiG700coXiG700?o0000oifCb_nMTlX02onMTlX00ol0
003oViO>oi^GcP03o`0000[oXYoB00?o0000oj>Re?nSX]@03?nSX]@00ol0003oY:CEojBTe@0=ojBT
e@03o`000?nWY]GoYjKE00GoYjKE1Ol00002ojJXe`03o`000?nWZ=OoYjSG00goYjSG00?o0000ojJW
e_nVYmH03OnVYmH00ol0003oY:GFojBUeP08ojBUeP?o00000_nTZ=X00ol0003oXZOJoj:WfP0=oj:W
fP03o`000?nOY]_oWjKK00goWjKK00?o0000oifVg?nMY]`03OnMY]`00ol0003oVjONoi^WgP05oi^W
gPGo00000_nMZn000ol0003oW:cRoib/hP0>oib/hP03o`000?nK[NCoVjgT00goVjgT00?o0000oi^_
iOnK[nD03OnK[nD00ol0003oVk7Woi^ai`07oi^ai`Go000000?ooo]Zo`000?oonfX01OoonfX008_o
oo]Z00?o0000oookJ_oonfX05OoonfX00ol0003oa<SNolC8gP0:olC8gP;o00002_o4aM/00ol0003o
b/KFol[6eP03ol[6eP;o00003oo9`M<00ol0003od;o:o`00000Aolbjb@03o`000?o6]l_o000001;o
bK720_l0000AoknX`P03o`000?niWKgo^Ifm00Ko^Ifm0_l00005okBRa`03o`000?n/VlGo[9_500go
[9_500?o0000oj>EaonSULL02onSULL00ol0003oWI?:oifCbP0:oifCbPCo00003_nRWm800ol0003o
Xj;Doj>Re00<oj>Re003o`000?nTY=GoY:CE00coY:CE00?o0000ojNVeOnWY]D01Ol00008ojJXe`03
o`000?nWZ=OoYjSG00goYjSG00?o0000ojJWe_nVYmH03OnVYmH00ol0003oY:GFojBUeP03ojBUePCo
00001_nTZ=X00ol0003oXZOJoj:WfP0<oj:WfP03o`000?nOY]_oWjKK00koWjKK00?o0000oifVg?nM
Y]`03?nMY]`00ol0003oVjONoi^WgP05o`0000SoWJ_P00?o0000oib/h_nL[>803OnL[>800ol0003o
VjgToi^]i00>oi^]i003o`000?nK[nGoVjoU00goVjoU00Co0000oi^aionK/NOoVk7W1Ol00004oook
JP04o`000?oonf[ooo]Zo`0000Gooo]Z002<oookJP;o00005_oonfX2o`0000Woa<SN00?o0000olC5
foo4aM/02oo4aM/01Ol0003ob/KFol[6e_o:a]Ko0000017obL7C0_l0000Aolbjb@05o`000?o6]l_o
a[O;olJgbol000004?o9/L800ol0003o`Zo8o`00000AoknX`P03o`000?niWKgo^Ifm00Go^Ifm00?o
0000okBRaondX/L01_ndX/L00ol0003o[9_5ojbKa@0<ojbKa@03o`000?nSULOoXiG700coXiG700?o
0000oifCb_nMTlX01?nMTlX5o`0000;oXik@00?o0000oj:Od_nRWm803OnRWm800ol0003oXj;Doj>R
e00<oj>Re003o`000?nTY=GoY:CE00_oY:CE1?l0000>ojJXe`03o`000?nWZ=OoYjSG00goYjSG00?o
0000ojJWe_nVYmH03?nVYmH00ol0003oY:GFojBUeP03o`0000[oY:SJ00?o0000oj:Wf_nRYmX03OnR
YmX00ol0003oWjKKoinVf`0=oinVf`03o`000?nMY]coWJKL00[oWJKL1Ol0000>oif[h003o`000?nL
[>;oW:cR00goW:cR00?o0000oi^]i?nK[N@03OnK[N@00ol0003oVjoUoi^_i@0:oi^_i@Oo00002_oo
nfX00ol0003ooo]Zo`000005oookJP00S_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?o4b=ko
a<SN00Goa<SN00?o0000olC5foo4aM/03Oo4aM/00ol0003ob/KFo`00000AolW1d`03o`000?o6_M;o
0000013oc;[900?o0000olJgboo6]l/00_o6]l/00ol0003obK72olVa`P0=olVa`P05o`000?o2[lSo
`Zo8ol:_b?l000004OnoZ<800ol0003o^IfmokVM_@02okVM_@;o00002OndX/L00ol0003o[9_5ojbK
a@0=ojbKa@03o`000?nSULOoXiG700_oXiG700?o0000oifCb_nMTlX01?l00008oj>Nd003o`000?nR
Wm;oXYoB00goXYoB00?o0000oj>Re?nSX]@03?nSX]@00ol0003oY:CEojBTe@07ojBTe@?o00000_nU
YmL00ol0003oYZSGojJXe`0=ojJXe`03o`000?nWZ=OoYjSG00goYjSG00?o0000ojJWe_nVYmH02onV
YmH4o`0000koY:SJ00?o0000oj:Wf_nRYmX03OnRYmX00ol0003oWjKKoinVf`0=oinVf`03o`000?nM
Y]coWJKL00;oWJKL1ol00003oinZg`03o`000?nMZn3oWJ_P00goWJ_P00?o0000oib/h_nL[>803OnL
[>800ol0003oVjgToi^]i00>oi^]i003o`000?nK[nGoVjoU00;oVjoU1ol0000BoookJP;o00001Ooo
nfX008oooo]Z00?o0000oookJ_oonfX05OoonfX2o`0000?oa<SN0_l0000@olC5f`;o00004Oo9`M<0
1Ol0003oa[gBolJmd_o6_M;o000000koc;[900?o0000olJgboo6]l/01?o6]l/00ol0003obK72olVa
`P0;olVa`P03o`000?o2[lSo`Zo800?o`Zo800?o0000oknX`_noZ<803_noZ<800ol0003o^IfmokVM
_@02o`0000_o]:;700?o0000ojbKaOn/VlD03On/VlD00ol0003oXiG7oj>Ea`0:oj>Ea`Co00003?nS
W]000ol0003oXYoBoj:OdP0>oj:OdP03o`000?nSX]CoXj;D00coXj;D00?o0000ojBTeOnTY=D00onT
Y=D3o`0000KoYJOG00?o0000ojJXeonVZ=L03OnVZ=L00ol0003oYjSGojNXe`0=ojNXe`03o`000?nV
YmKoYZOF00GoYZOF1Ol00002ojFYfP03o`000?nTZ=[oY:SJ00goY:SJ00?o0000oj:Wf_nRYmX03OnR
YmX00ol0003oWjKKoinVf`0<oinVf`Ko00002onOZ]l00ol0003oWJ_Poif[h00=oif[h003o`000?nL
[>;oW:cR00goW:cR00?o0000oi^]i?nK[N@03?nK[N@6o`0001Sooo]Z0ol00005oookJP00T?oonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?o4b=ko0000017oa<GK00Co0000olC2fOo4`]Wo00003_o9
`M<2o`0000Goa[gB00?o0000olbjbOo<^/T02Oo<^/T2o`0000Soa[O;00?o0000olVa`_o9/L802Oo9
/L800ol0003o`Zo8ol:_b004ol:_b003o`000?noZ<;o_jS200ko_jS200?o0000okVM_Ol000003_nd
X/L00ol0003o[9_5ojbKa@0<ojbKa@03o`000?nSULOoXiG700OoXiG70ol00002ojNOcP03o`000?nS
W]3oXik@00coXik@00?o0000oj:Od_nRWm803OnRWm800ol0003oXj;Doj>Re00<oj>Re003o`000?nT
Y=GoY:CE00?o00002OnUYmL00ol0003oYZSGojJXe`0>ojJXe`03o`000?nWZ=OoYjSG00coYjSG00?o
0000ojJWe_nVYmH01Ol00008ojFYfP03o`000?nTZ=[oY:SJ00goY:SJ00?o0000oj:Wf_nRYmX03OnR
YmX00ol0003oWjKKoinVf`06oinVf`Go00000_nPZ]h00ol0003oWj[OoinZg`0=oinZg`03o`000?nM
Zn3oWJ_P00coWJ_P00?o0000oib/h_nL[>803_nL[>800ol0003oVjgToi^]i006oi^]i0Go00006_oo
nfX4o`0000Sooo]Z002AoookJP;o00005ooonfX2o`0000ooa<GK0_l00004olC2f@03o`000?o9`M?o
bL7C00[obL7C00?o0000olJmd_o6_M801_o6_M800ol0003oc;[9olbjb@07olbjb@03o`000?o6]l_o
a[O;00Soa[O;00?o0000olVa`_o9/L801oo9/L82o`0000So`Zo800?o0000oknX`_noZ<803OnoZ<82
o`0000oo]:;700?o0000ojbKaOn/VlD03On/VlD00ol0003oXiG7oj>Ea`03oj>Ea`?o00001_nWWlh0
0ol0003oXik@oj>Nd00<oj>Nd003o`000?nRWm;oXYoB00goXYoB00?o0000oj>Re?nSX]@02_nSX]@4
o`0000goYJOG00?o0000ojJXeonVZ=L03OnVZ=L00ol0003oYjSGojNXe`0;ojNXe`Co00003OnUZMX0
0ol0003oY:SJojBXfP0>ojBXfP03o`000?nRYm[oXZOJ00coXZOJ00Co0000oinVfonOY]_oWjKK1Ol0
0008oj2ZgP03o`000?nOZ]ooWj[O00coWj[O00?o0000oif[h?nMZn003OnMZn000ol0003oW:cRoib/
hP0=oib/hP04o`000?nK[NCoVjgToi^]i0Go00006ooonfX4o`0000cooo]Z002CoookJP03o`000?oo
nf[ooo]Z01Kooo]Z00?o0000olC5foo4aM/02oo4aM/00ol0003oa<;IolC2f@05olC2f@03o`000?o9
`M?obL7C00SobL7C00?o0000olJmd_o6_M802?o6_M800ol0003oc;[9olbjb@05olbjb@03o`000?o6
]l_oa[O;00[oa[O;00?o0000olVa`_o9/L801Oo9/L800ol0003o`Zo8ol:_b008ol:_b003o`000?no
Z<;o_jS200co_jS200?o0000okVYbOl000004?ndX/L00ol0003o[9_5ojbKa@0<ojbKa@03o`000?nS
ULOoXiG700?o00002OnWWlh00ol0003oXik@oj>Nd00<oj>Nd003o`000?nRWm;oXYoB00goXYoB00?o
0000oj>Re?nSX]@01onSX]@3o`0000;oYJKG00?o0000ojFWeonUYmL03OnUYmL00ol0003oYZSGojJX
e`0=ojJXe`03o`000?nWZ=OoYjSG00OoYjSG0ol00002ojJZfP03o`000?nUZM[oYJWJ00goYJWJ00?o
0000ojBXf_nTZ=X03OnTZ=X00ol0003oXZOJoj:WfP0;oj:WfPGo00003OnPZ]h00ol0003oWj[OoinZ
g`0=oinZg`03o`000?nMZn3oWJ_P00goWJ_P00?o0000oib/h_nL[>802OnL[>87o`0001gooo]Z0ol0
000@oookJP00U?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?o4aM_oa<GK00Soa<GK0_l00009
olC2f@03o`000?o9`M?obL7C00KobL7C00?o0000olJmd_o6_M802_o6_M800ol0003oc;[9olbjb@03
olbjb@03o`000?o6]l_oa[O;00_oa[O;00?o0000olVa`_o9/L801?o9/L800ol0003o`Zo8ol:_b00:
ol:_b003o`000?noZ<;o_jS200Wo_jS20_l00003okVYb@03o`000?ndX/Oo]:;700go]:;700?o0000
ojbKaOn/VlD03?n/VlD3o`0000goYio>00?o0000oj>Nd?nSW]003?nSW]000ol0003oXYoBoj:OdP0=
oj:OdP03o`000?nSX]CoXj;D00?oXj;D0ol00006ojFVe`03o`000?nUYmOoYJOG00coYJOG00?o0000
ojJXeonVZ=L03OnVZ=L00ol0003oYjSGojNXe`04ojNXe`?o00001_nVZ]X00ol0003oYJWJojFYfP0<
ojFYfP03o`000?nTZ=[oY:SJ00koY:SJ00?o0000oj:Wf_nRYmX01OnRYmX5o`0000;oXZ_M00?o0000
oj2Zg_nPZ]h03_nPZ]h00ol0003oWj[OoinZg`0<oinZg`03o`000?nMZn3oWJ_P00goWJ_P00?o0000
oib/h_nL[>800_nL[>87o`00023ooo]Z1?l0000CoookJP00UOoonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?o4aM_oa<GK00Koa<GK00?o0000olC2fOo4`]T02_o4`]T00ol0003obL7ColW1d`03olW1
d`;o00003_o6_M801Ol0003oc;[9olbjbOo<^/Wo000000ooa[O;00?o0000olVa`_o9/L800_o9/L80
0ol0003o`Zo8ol:_b00<ol:_b003o`000?noZ<;o_jS200Oo_jS200?o0000okVYbOniZLT00oniZLT0
0ol0003o]:;7okBRa`0>okBRa`03o`000?n/VlGo[9_500Wo[9_50_l000000on/Xlgo0000ojNOcP0=
ojNOcP03o`000?nSW]3oXik@00coXik@00?o0000oj:Od_nRWm803OnRWm800ol0003oXj;Doj>Re003
o`0000[oYJKG00?o0000ojFWeonUYmL03?nUYmL00ol0003oYZSGojJXe`0=ojJXe`03o`000?nWZ=Oo
YjSG00?o00002_nVZ]X00ol0003oYJWJojFYfP0<ojFYfP03o`000?nTZ=[oY:SJ00goY:SJ00?o0000
oj:Wf_nRYmX01Ol00008oj:[g@03o`000?nPZ]koX:[N00goX:[N00?o0000oinZgonOZ]l03OnOZ]l0
0ol0003oWJ_Poif[h00;oif[h0Ko00008ooonfX4o`0001Oooo]Z002FoookJP;o00005ooonfX00ol0
003oa<GKolC5f`04olC5f`03o`000?o4`]Woa<;I00coa<;I00Go0000olW1doo9`M?obL7Co`00000A
olJmdP03o`000?o<^/Wo0000017oa[O;00Co0000olVa`_o9/L;o00003oo2[lP00ol0003o_jS2oknX
`P05oknX`P;o00001oniZLT00ol0003o]:;7okBRa`0=okBRa`03o`000?n/VlGo[9_500Oo[9_50_l0
0004ojbSc@03o`000?nWWlkoYio>00coYio>00?o0000oj>Nd?nSW]003?nSW]000ol0003oXYoBoj:O
dP0;oj:OdPCo00003OnUY]L00ol0003oYJOGojFWe`0<ojFWe`03o`000?nVZ=OoYZSG00coYZSG1?l0
000=ojJZfP03o`000?nUZM[oYJWJ00goYJWJ00?o0000ojBXf_nTZ=X02onTZ=X4o`0000koXZ_M00?o
0000oj2Zg_nPZ]h03OnPZ]h00ol0003oWj[OoinZg`0=oinZg`03o`000?nMZn3oWJ_P00GoWJ_P1Ol0
000UoookJPCo00006ooonfX009Sooo]Z00?o0000oookJ_oonfX05OoonfX01?l0003oa<GKolC5foo4
aM/2o`00013oa<;I00?o0000olW1dol000004_o6_M82o`0001;oa[O;00?o0000olVa`_l000004Oo2
[lP00ol0003o_jS2oknX`P03oknX`P03o`000?niZLWo^JW900So^JW900?o0000okBRaondX/L03?nd
X/L00ol0003o[9_5ojbKa@04ojbKa@?o00001_n/Xld00ol0003oYio>ojNOcP0=ojNOcP03o`000?nS
W]3oXik@00coXik@00?o0000oj:Od_nRWm801OnRWm85o`0000;oYJGF00?o0000ojFVeonUY]L03OnU
Y]L00ol0003oYJOGojFWe`0<ojFWe`03o`000?nVZ=OoYZSG00SoYZSG0ol00002ojJZfP03o`000?nV
Z][oYZ[J00goYZ[J00?o0000ojFYf_nUZMX03?nUZMX00ol0003oY:SJojBXfP08ojBXfP?o00000_nT
Zm`00ol0003oXZ_Moj:[g@0=oj:[g@03o`000?nPZ]koX:[N00koX:[N00?o0000oinZgonOZ]l03?nO
Z]l00ol0003oWJ_Poif[h005o`0002Kooo]Z1?l0000OoookJP00VOoonfX00ol0003ooo]ZoookJP0E
oookJP03o`000?o4aM_o000001;oa<;I0_l0000BolJmdP03o`000?o3^];o000001;oa[O;0_l0000B
ol:_b004o`000?noZ<;o_jS2oknX`P;o00002oniZLT00ol0003o]:;7okBRa`0=okBRa`04o`000?n/
VlGo[9_5ojbKa@;o00002_n/Xld00ol0003oYio>ojNOcP0<ojNOcP03o`000?nSW]3oXik@00coXik@
00?o0000oj:Od_nRWm801Ol00008ojFUeP03o`000?nUY]OoYJKG00goYJKG00?o0000ojFWeonUYmL0
3?nUYmL00ol0003oYZSGojJXe`03ojJXe`Co00001_nVZ]X00ol0003oYZ[JojJZfP0=ojJZfP03o`00
0?nUZM[oYJWJ00coYJWJ00?o0000ojBXf_nTZ=X00onTZ=X4o`0000KoY:_L00?o0000oj:[gOnRZmd0
3OnRZmd00ol0003oX:[Noj2ZgP0=oj2ZgP03o`000?nOZ]ooWj[O00_oWj[O1?l0000WoookJPCo0000
8ooonfX009[ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003oa<;IolC2f@0@olC2f@03o`000?o2
_mSo0000017oa[gB00Go0000ol>jd_o3^];o`k[Bo`00000@olJgb`03o`000?o1]Lko000001?o`Zo8
00?o0000oknX`_l000003_niZLT00ol0003o]:;7okBRa`0<okBRa`04o`000?n/VlGo0000o`0000co
[:?=00?o0000ojNOc_nWWlh03OnWWlh00ol0003oXik@oj>Nd00:oj>Nd0Co00003OnUYMH00ol0003o
YJKGojFVe`0=ojFVe`03o`000?nUYmOoYJOG00coYJOG00?o0000ojJXeonVZ=L00ol0000:ojJZfP03
o`000?nVZ][oYZ[J00goYZ[J00?o0000ojFYf_nUZMX03?nUZMX00ol0003oY:SJojBXfP03o`0000_o
Y:_L00?o0000oj:[gOnRZmd03OnRZmd00ol0003oX:[Noj2ZgP0=oj2ZgP03o`000?nOZ]ooWj[O00Go
Wj[O1Ol0000WoookJPCo00009ooonfX009_ooo]Z0_l0000FoookJP03o`000?o4`]Woa<;I00goa<;I
0_l00003ol:of003o`000?o6_M;oa[gB00coa[gB0_l00005ol>jdP03o`000?o6]l_oa[O;00_oa[O;
0_l00003ol6ecP03o`000?o2[lSo`Zo8013o`Zo80_l0000?okVYb@03o`000?ndX/Oo]:;700co]:;7
0_l0000?ojbSc@03o`000?nWWlkoYio>00coYio>00?o0000oj>Nd?nSW]001onSW]03o`0000;oYjGD
00?o0000ojFUe_nUYMH03OnUYMH00ol0003oYJKGojFVe`0=ojFVe`03o`000?nUYmOoYJOG00[oYJOG
1?l0000>ojJZfP03o`000?nVZ][oYZ[J00goYZ[J00?o0000ojFYf_nUZMX02_nUZMX4o`0000koY:_L
00?o0000oj:[gOnRZmd03_nRZmd00ol0003oX:[Noj2ZgP0<oj2ZgP03o`000?nOZ]ooWj[O00Go0000
:OoonfX3o`0002_ooo]Z002MoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000olC2fOo4`]T02oo4
`]T00ol0003o`[oHol:of004ol:of003o`000?o6_M;oa[gB00[oa[gB00?o0000ol>jd_o3^]801Oo3
^]800ol0003oa[O;olJgb`0:olJgb`03o`000?o1]Lko`KG>00Co`KG>00?o0000ol:_b?o2[lP03_o2
[lP00ol0003o^jo>o`00000@okVYb@03o`000?ndX/Oo]:;700Wo]:;70_l000000onaYlko0000ojbS
c@0>ojbSc@03o`000?nWWlkoYio>00goYio>00?o0000oj>Nd?nSW]000onSW]03o`0000KoYjGD00?o
0000ojFUe_nUYMH03?nUYMH00ol0003oYJKGojFVe`0=ojFVe`03o`000?nUYmOoYJOG00GoYJOG1Ol0
0002ojJZfP03o`000?nVZ][oYZ[J00goYZ[J00?o0000ojJZf_nVZ]X03OnVZ]X00ol0003oYJWJojFY
fP05ojFYfPGo00000_nU[=`00ol0003oY:_LojB[g00>ojB[g003o`000?nRZmgoXZ_M00goXZ_M00?o
0000oj2Zg_nPZ]h02_nPZ]h5o`0002[ooo]Z1?l0000^oookJP00W_oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?o4`]Woa<;I00Soa<;I0_l00008ol:of003o`000?o6_M;oa[gB00Soa[gB00?o0000
ol>jd_o3^]801oo3^]800ol0003oa[O;olJgb`07olJgb`;o00002?o1]Lh00ol0003o`Zo8ol:_b00;
ol:_b0;o00000onk[lh00ol0003o^JW9okVYb@0=okVYb@03o`000?ndX/Oo]:;700Oo]:;70_l00004
ok6WcP03o`000?n/Xlgo[:?=00go[:?=00?o0000ojNOc_nWWlh03?nWWlh00ol0003oXik@oj>Nd003
o`0000WoYjGD00?o0000ojFUe_nUYMH03OnUYMH00ol0003oYJKGojFVe`0=ojFVe`03o`000?nUYmOo
YJOG00Co00002?nVZ]X00ol0003oYZ[JojJZfP0=ojJZfP03o`000?nVZ][oYZ[J00goYZ[J00?o0000
ojFYf_nUZMX01?l00008ojF/g003o`000?nTZmcoY:_L00koY:_L00?o0000oj:[gOnRZmd03OnRZmd0
0ol0003oX:[Noj2ZgP02oj2ZgPOo0000:ooonfX4o`0003;ooo]Z002OoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000olC2fOo4`]T01_o4`]T00ol0003o`[oHol:of009ol:of003o`000?o6_M;oa[gB
00Koa[gB00?o0000ol>jd_o3^]802Oo3^]800ol0003oa[O;olJgb`05olJgb`03o`000?o1]Lko`KG>
00So`KG>00?o0000ol:_b?o2[lP02_o2[lP00ol0003o^jo>ok^_cP03ok^_cP03o`000?niZLWo^JW9
00ko^JW900?o0000okBRaondX/L01?ndX/L2o`0000Ko/JO>00?o0000ojbScOn/Xld03On/Xld00ol0
003oYio>ojNOcP0<ojNOcP?o00003OnWYM@00ol0003oYJGFojFUeP0=ojFUeP03o`000?nUY]OoYJKG
00_oYJKG1?l0000=ojJZfP03o`000?nVZ][oYZ[J00goYZ[J00?o0000ojJZf_nVZ]X02onVZ]X4o`00
00goYJcL00?o0000ojB[g?nTZm`03OnTZm`00ol0003oXZ_Moj:[g@0<oj:[g@Ko0000;_oonfX4o`00
03Kooo]Z002PoookJP;o00005OoonfX00ol0003oa<;IolC2f@04olC2f@03o`000?o2_mSo`[oH00_o
`[oH00?o0000olJmd_o6_M800oo6_M82o`0000go`k[B00?o0000olJgboo6]l/00oo6]l/00ol0003o
`KG>ol6ecP0:ol6ecP03o`000?o2[lSo`Zo800Oo`Zo80_l00007ok^_cP03o`000?niZLWo^JW900ko
^JW900Co0000okBRaondX/Oo]:;70_l00009ok6WcP03o`000?n/Xlgo[:?=00go[:?=00?o0000ojNO
c_nWWlh02?nWWlh3o`000003ojVVdol0003oYjGD00koYjGD00?o0000ojFUe_nUYMH03?nUYMH00ol0
003oYJKGojFVe`08ojFVe`?o00000_nVZ]T00ol0003oYZ[JojJZfP0<ojJZfP03o`000?nVZ][oYZ[J
00goYZ[J00?o0000ojJZf_nVZ]X02?nVZ]X3o`0000;oYJcL00?o0000ojF/g?nU[=`03?nU[=`00ol0
003oY:_LojB[g00>ojB[g003o`000?nRZmgoXZ_M00SoXZ_M0ol0000`oookJPCo0000>_oonfX00:;o
oo]Z00?o0000oookJ_oonfX04ooonfX01?l0003oa<;IolC2fOo4`]T2o`0000oo`[oH00Go0000olJm
d_o6_M;oa[gBo`00000?ol>jdP04o`000?o6]l_oa[O;olJgb`;o00003_o1]Lh00ol0003o`Zo8ol:_
b005ol:_b003o`000?nk[lko^jo>00Oo^jo>00?o0000okVYbOniZLT03_niZLT01?l0003o]:;7o`00
0?l0000<ok6WcP03o`000?n/Xlgo[:?=00co[:?=00?o0000ojNOc_nWWlh01OnWWlh3o`0000GoZJKC
00?o0000ojNUe?nWYM@03?nWYM@00ol0003oYJGFojFUeP0=ojFUeP03o`000?nUY]OoYJKG00?oYJKG
1?l00006ojJZf@03o`000?nVZ][oYZ[J00coYZ[J00?o0000ojJZf_nVZ]X03OnVZ]X00ol0003oYZ[J
ojJZfP03ojJZfPCo00001_nU[=`00ol0003oYJcLojF/g00<ojF/g003o`000?nTZmcoY:_L00goY:_L
00?o0000oj:[gOnRZmd01?nRZmd4o`0002oooo]Z1?l0000noookJP00XooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?o4`]Wo000001;o`[oH00?o0000olJmd_l000004Oo3^]800ol0003oa[O;o`00
000@ol6ecP03o`000?o2[lSo`Zo800Co`Zo800?o0000ok^_c_nk[lh02Onk[lh00ol0003o^JW9okVY
b@0=okVYb@;o00003_naYlh00ol0003o[:?=ojbSc@0=ojbSc@03o`000?nWWlkoYio>00;oYio>0_l0
0008ojVVd`03o`000?nWYMCoYjGD00goYjGD00?o0000ojFUe_nUYMH03?nUYMH00ol0003oYJKGojFV
e`03o`0000[oYZ[I00?o0000ojJZf_nVZ]X03OnVZ]X00ol0003oYZ[JojJZfP0<ojJZfP03o`000?nV
Z][oYZ[J00?o00002onU[=`00ol0003oYJcLojF/g00<ojF/g003o`000?nTZmcoY:_L00goY:_L00?o
0000oj:[gOnRZmd00ol0000`oookJP?o0000@_oonfX00:Cooo]Z00?o0000oookJ_oonfX04ooonfX0
0ol0003o`[oHol:of00Aol:of0;o00004_o3^]82o`0001;o`KG>00Co0000ol:_b?o2[lSo`Zo80_l0
000=ok^_cP03o`000?niZLWo^JW900[o^JW90_l000000one[=3o0000ok6WcP0>ok6WcP03o`000?n/
Xlgo[:?=00co[:?=00?o0000ojNOc_l000000_l0000;ojVVd`03o`000?nWYMCoYjGD00coYjGD00?o
0000ojFUe_nUYMH02onUYMH4o`0000koYZ[I00?o0000ojJZf_nVZ]X03OnVZ]X00ol0003oYZ[JojJZ
fP0:ojJZfPCo00003_nU[=`00ol0003oYJcLojF/g00=ojF/g003o`000?nTZmcoY:_L00_oY:_L1?l0
000_oookJPCo0000AOoonfX00:Gooo]Z0_l0000DoookJP03o`000?o2_mSo`[oH00oo`[oH00Co0000
oknmf?no_MSo00004?o3^]800ol0003o_kWDo`00000Col6ecP03o`000?o2[lSo000000oo^jo>00?o
0000okVYbOniZLT02?niZLT2o`0000Co]Jc@00?o0000ok6Wc_naYlh03?naYlh00ol0003o[:?=ojbS
c@0;ojbSc@?o00003onYY]<00ol0003oYjGDojNUe00<ojNUe003o`000?nUYMKoYJGF00OoYJGF0ol0
0002ojNZf@03o`000?nVZ]WoYZ[I00goYZ[I00?o0000ojJZf_nVZ]X03OnVZ]X00ol0003oYZ[JojJZ
fP05ojJZfPGo00000_nV[M`00ol0003oYJcLojF/g00>ojF/g003o`000?nU[=coYJcL00coYJcL00?o
0000ojB[g?nTZm`01_nTZm`5o`0002oooo]Z1?l00019oookJP00YooonfX00ol0003ooo]ZoookJP0B
oookJP03o`000?o2_mSo`[oH00co`[oH0_l00004oknmf003o`000?o3^];o`k[B00_o`k[B0_l00003
oknie003o`000?o1]Lko`KG>013o`KG>0_l0000Aok^_cP03o`000?niZLWo^JW900Go^JW90_l00006
okF/d003o`000?naYlko/JO>00go/JO>00?o0000ojbScOn/Xld01on/Xld3o`0000;o[JSC00?o0000
ojVVdonYY]<03OnYY]<00ol0003oYjGDojNUe00=ojNUe003o`000?nUYMKoYJGF00?oYJGF0ol00006
ojNZf@03o`000?nVZ]WoYZ[I00goYZ[I00?o0000ojJZf_nVZ]X03OnVZ]X00ol0003oYZ[JojJZfP04
o`0000SoYZgL00?o0000ojF/g?nU[=`03OnU[=`00ol0003oYJcLojF/g00=ojF/g003o`000?nTZmco
Y:_L00Go0000<?oonfX4o`0004gooo]Z002XoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000ol:o
f?o2_mP02Oo2_mP2o`0000Oo_kgH00?o0000ol>jd_o3^]802Oo3^]800ol0003o_kWDoknie004okni
e003o`000?o1]Lko`KG>00ko`KG>00?o0000okbdd_l000004Onk[lh00ol0003o^JW9okVYb@04okVY
b@03o`000?ne[=3o]Jc@00Oo]Jc@00?o0000ok6Wc_naYlh03OnaYlh00ol0003o[:?=ojbSc@03ojbS
c@?o00001_n]Z=<00ol0003oZJKCojVVd`0=ojVVd`03o`000?nWYMCoYjGD00coYjGD00?o0000ojFU
e_nUYMH00ol0000:ojNZf@03o`000?nVZ]WoYZ[I00goYZ[I00?o0000ojJZf_nVZ]X02onVZ]X4o`00
00goYZgL00?o0000ojF/g?nU[=`03OnU[=`00ol0003oYJcLojF/g00;ojF/g0Co0000<OoonfX4o`00
057ooo]Z002YoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000ol:of?o2_mP01oo2_mP00ol0003o
_kgHoknmf008oknmf003o`000?o3^];o`k[B00Ko`k[B0_l00008oknie003o`000?o1]Lko`KG>00_o
`KG>0_l00003okbddP03o`000?nk[lko^jo>00oo^jo>00Co0000okVYbOniZLWo^JW90_l0000;okF/
d003o`000?naYlko/JO>00co/JO>00?o0000ojbScOn/Xld00ol0000:ojfXd`03o`000?nYY]?oZJKC
00coZJKC00?o0000ojNUe?nWYM@02onWYM@4o`0000goYj[I00?o0000ojJZfOnVZ]T03OnVZ]T00ol0
003oYZ[JojJZfP08ojJZfP?o00000_nV[M`00ol0003oYZgLojJ]g00<ojJ]g003o`000?nU[=coYJcL
00koYJcL00?o0000ojF/g?nU[=`01OnU[=`5o`00037ooo]Z1?l0001EoookJP00Z_oonfX00ol0003o
oo]ZoookJP0BoookJP03o`000?o2_mSo`[oH00Co`[oH0_l0000<oknmf003o`000?o3^];o`k[B00Co
`k[B00?o0000oknie?no^M@02Ono^M@00ol0003o`KG>ol6ecP08ol6ecP;o00001_nl]=800ol0003o
^jo>ok^_cP0>ok^_cP04o`000?niZLWo0000o`0000go]Jc@00?o0000ok6Wc_naYlh03?naYlh3o`00
00go[JSC00?o0000ojVVdonYY]<03OnYY]<00ol0003oYjGDojNUe007ojNUe0?o00000_nXZ]P00ol0
003oYj[IojNZf@0=ojNZf@03o`000?nVZ]WoYZ[I00goYZ[I00?o0000ojJZf_nVZ]X00onVZ]X4o`00
00KoYZgL00?o0000ojJ]g?nV[M`03?nV[M`00ol0003oYJcLojF/g00=ojF/g003o`000?nU[=coYJcL
00Go0000<_oonfX4o`0005Wooo]Z002[oookJP;o00004ooonfX01?l0003o`[oHol:of?o2_mP2o`00
00oo_kgH00Co0000ol>jd_o3^];o`k[B0_l0000<oknie003o`000?o1]Lko`KG>00Oo`KG>00?o0000
okbdd_nl]=801_nl]=800ol0003o^jo>ok^_cP0>ok^_cP;o00004?ne[=000ol0003o/JO>ok6WcP09
ok6WcP;o000000?o/:_Co`000?n]Z=<03_n]Z=<00ol0003oZJKCojVVd`0=ojVVd`03o`000?nWYMCo
YjGD00?oYjGD0ol00006ojRZf003o`000?nWZ]WoYj[I00goYj[I00?o0000ojJZfOnVZ]T03?nVZ]T0
0ol0003oYZ[JojJZfP03o`0000_oYZgL00?o0000ojJ]g?nV[M`03?nV[M`00ol0003oYJcLojF/g00;
ojF/g0Co0000=?oonfX3o`0005gooo]Z002]oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000ol:o
f?l000004_no_MP00ol0003o`k[Bo`00000?oknie003o`000?o1]Lko`KG>00Co`KG>0_l0000:okbd
dP03o`000?nk[lko^jo>00_o^jo>0_l000000ong/M?o0000okF/d00?okF/d003o`000?naYlko/JO>
00Oo/JO>0_l00004ok2[d`03o`000?n]Z=?o[JSC00go[JSC00?o0000ojVVdonYY]<03?nYY]<00ol0
003oYjGDojNUe003o`0000[oZ:[H00?o0000ojNZfOnWZ]T03OnWZ]T00ol0003oYZ[IojJZf@0:ojJZ
f@Co00003_nV[M`00ol0003oYZgLojJ]g00=ojJ]g003o`000?nU[=coYJcL00OoYJcL0ol0000doook
JPCo0000H?oonfX00:kooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o_kgHoknmf00Aoknmf0;o
00004Ono^M@01?l0003o`KG>ol6ec_o1]Lh2o`0000go_;CB00?o0000ok^_c_nk[lh02?nk[lh2o`00
00Co]k7C00?o0000okF/d?ne[=003_ne[=000ol0003o/JO>ok6WcP04ok6WcP;o00001_n`Zm<00ol0
003o[JSCojfXd`0=ojfXd`03o`000?nYY]?oZJKC00_oZJKC1?l0000=ojRZf003o`000?nWZ]WoYj[I
00goYj[I00?o0000ojJZfOnVZ]T01OnVZ]T5o`0000;oYjgL00?o0000ojJ]g?nV[M`03_nV[M`00ol0
003oYZgLojJ]g00<ojJ]g003o`000?nU[=coYJcL00CoYJcL0ol0000coookJPCo0000I?oonfX00:oo
oo]Z00?o0000oookJ_oonfX04OoonfX00ol0003o_kgHoknmf00?oknmf003o`000?nl^mWo000001;o
_kWD00?o0000ol6ec_l000003onl]=800ol0003o^jo>ok^_cP06ok^_cP;o00001ong/M<00ol0003o
]Jc@okF/d00>okF/d004o`000?naYlko/JO>ok6WcP;o00002On`Zm<00ol0003o[JSCojfXd`0=ojfX
d`03o`000?nYY]?oZJKC00OoZJKC0ol00002ojZ[e`03o`000?nXZ]SoZ:[H00goZ:[H00?o0000ojNZ
fOnWZ]T03OnWZ]T00ol0003oYZ[IojJZf@04o`0000SoYjgL00?o0000ojJ]g?nV[M`03OnV[M`00ol0
003oYZgLojJ]g00=ojJ]g003o`000?nU[=coYJcL00?o0000<_oonfX4o`0006Sooo]Z002`oookJP;o
00004_oonfX00ol0003o_kgHoknmf00<oknmf0;o00000onl^mT00ol0003o_kWDoknie00?oknie0;o
00004Onl]=800ol0003o^jo>ok^_cP04ok^_cP03o`000?ng/M?o]k7C00Oo]k7C00?o0000okF/d?ne
[=003_ne[=001?l0003o/JO>o`000?l0000<ok2[d`03o`000?n]Z=?o[JSC00co[JSC00?o0000ojVV
donYY]<01?nYY]<3o`0000KoZZ_G00?o0000ojRZf?nXZ]P03OnXZ]P00ol0003oYj[IojNZf@0;ojNZ
f@Co00003OnW[M`00ol0003oYZgLojJ]g00=ojJ]g003o`000?nV[McoYZgL00_oYZgL1?l0000aoook
JPCo0000K?oonfX00;;ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003o_kgHoknmf009oknmf0;o
00001_nl^mT00ol0003o_kWDoknie00<oknie0;o000000?o^kSFo`000?nl]=804?nl]=800ol0003o
^jo>ok^_cP02ok^_cP;o00002ong/M<00ol0003o]Jc@okF/d00=okF/d0;o00003_n`Zm<00ol0003o
[JSCojfXd`0=ojfXd`03o`000?nYY]?oZJKC00?o00002_nZZmL00ol0003oZ:[HojRZf00=ojRZf003
o`000?nWZ]WoYj[I00OoYj[I0ol00002ojR]f`03o`000?nW[McoYjgL00coYjgL00?o0000ojJ]g?nV
[M`03_nV[M`00ol0003oYZgLojJ]g005ojJ]g0Go0000<OoonfX4o`00073ooo]Z002coookJP03o`00
0?oonf[ooo]Z013ooo]Z00?o0000oknmf?no_MP01ono_MP00ol0003o_;_Iokbkf@07okbkf@03o`00
0?no^MCo_kWD00Wo_kWD0_l00004ok^heP03o`000?nl]=;o_;CB00oo_;CB00Co0000ok^_c_l0003o
00003_ng/M<00ol0003o]Jc@okF/d00:okF/d0;o000000?o/ZoEo`000?n`Zm<03_n`Zm<00ol0003o
[JSCojfXd`0<ojfXd`?o00003OnZZmL00ol0003oZ:[HojRZf00=ojRZf003o`000?nWZ]WoYj[I00Co
Yj[I0ol00006ojR]f`03o`000?nW[McoYjgL00coYjgL00?o0000ojJ]g?nV[M`03OnV[M`00ol0003o
YZgLojJ]g005o`0003?ooo]Z0ol0001doookJP00]?oonfX00ol0003ooo]ZoookJP0@oookJP03o`00
0?no_MSo_kgH00Co_kgH0_l0000;okbkf@03o`000?no^MCo_kWD00Ko_kWD0_l00007ok^heP03o`00
0?nl]=;o_;CB00ko_;CB0_l0000@okNad`03o`000?ne[=3o]Jc@00So]Jc@0_l00004ok:_e@03o`00
0?n`Zm?o/:_C00co/:_C00?o0000ojfXdon]Z=<02On]Z=<3o`000003ojb]eol0003oZZ_G00koZZ_G
00?o0000ojRZf?nXZ]P03OnXZ]P00ol0003oYj[IojNZf@03o`0000[oZ:gK00?o0000ojN]g?nW[M`0
3?nW[M`00ol0003oYZgLojJ]g00;ojJ]g0Co0000=?oonfX4o`0007Oooo]Z002eoookJP;o00004Ooo
nfX01?l0003o_kgHoknmf?no_MP2o`0000go_;_I00?o0000oknie?no^M@01Ono^M@00ol0003o^kSF
ok^heP07ok^heP03o`000?nl]=;o_;CB00co_;CB0_l000000onh]=Ko0000okNad`0@okNad`03o`00
0?ne[=3o]Jc@00Co]Jc@0ol00007ok:_e@03o`000?n`Zm?o/:_C00co/:_C00?o0000ojfXdon]Z=<0
1On]Z=<3o`0000Go[:gG00?o0000ojZ[eonZZmL03OnZZmL00ol0003oZ:[HojRZf00;ojRZf0Co0000
3OnX[M/00ol0003oYjgLojN]g00=ojN]g003o`000?nV[McoYZgL00OoYZgL0ol0000doookJPCo0000
NooonfX00;Oooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o_kgHo`00000@okbkf@03o`000?no
^MCo_kWD00;o_kWD0_l0000;ok^heP03o`000?nl]=;o_;CB00Wo_;CB0_l00004okRdeP03o`000?ng
/M?o]k7C00ko]k7C00?o0000okF/d?ne[=000_ne[=02o`0000[o/ZoE00?o0000ok2[don`Zm<03On`
Zm<00ol0003o[JSCojfXd`02ojfXd`;o00002On/[ML00ol0003oZZ_GojZ[e`0=ojZ[e`03o`000?nX
Z]SoZ:[H00OoZ:[H0ol00002ojV^f`03o`000?nX[M_oZ:gK00goZ:gK00?o0000ojN]g?nW[M`03?nW
[M`00ol0003oYZgLojJ]g004ojJ]g0?o0000<ooonfX4o`0007oooo]Z002hoookJP03o`000?oonf[o
oo]Z00oooo]Z00?o0000okbkfOnl^mT04?nl^mT01?l0003o_kWDo`000?l0000>ok^heP03o`000?nl
]=;o_;CB00Ko_;CB0_l00007okRdeP03o`000?ng/M?o]k7C00ko]k7C00Co0000okF/d?l0003o0000
3Onb[mD00ol0003o/:_Cok2[d`0<ok2[d`03o`000?n]Z=?o000000;o00002on/[ML00ol0003oZZ_G
ojZ[e`0=ojZ[e`03o`000?nXZ]SoZ:[H00CoZ:[H0ol00006ojV^f`03o`000?nX[M_oZ:gK00goZ:gK
00?o0000ojN]g?nW[M`03?nW[M`00ol0003oYZgLojJ]g003o`0003;ooo]Z1?l00023oookJP00^Ooo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?nl^mWo_;_I00oo_;_I0_l0000Aok^heP03o`000?nl
]=;o_;CB00Co_;CB00?o0000okRde_nh]=H01onh]=H00ol0003o]k7CokNad`0>okNad`;o00004?nb
[mD00ol0003o/:_Cok2[d`0;ok2[d`;o00003on/[ML00ol0003oZZ_GojZ[e`0=ojZ[e`03o`000?nX
Z]SoZ:[H00?o00002_nY[]/00ol0003oZ:gKojR]f`0=ojR]f`03o`000?nW[McoYjgL00[oYjgL1?l0
000aoookJPCo0000QooonfX00;[ooo]Z0_l0000@oookJP03o`000?nl^mWo_;_I00co_;_I0_l00000
0oni^][o0000ok^heP0@ok^heP03o`000?nl]=;o_;CB00;o_;CB0_l0000;okRdeP03o`000?ng/M?o
]k7C00_o]k7C0_l000000ond/]Oo0000ok:_e@0?ok:_e@03o`000?n`Zm?o/:_C00So/:_C0ol00000
0on_[mSo0000ojb]e`0?ojb]e`03o`000?nZZmOoZZ_G00_oZZ_G1?l0000=ojV^f`03o`000?nX[M_o
Z:gK00goZ:gK00?o0000ojN]g?nW[M`01OnW[M`5o`00037ooo]Z1?l0002;oookJP00_?oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?nl^mWo_;_I00[o_;_I00?o0000okVjf_ni^]X00_ni^]X00ol0
003o^kSFok^heP0?ok^heP04o`000?nl]=;o0000o`0000ko^;CF00?o0000okNadong/M<02?ng/M<2
o`0000Co];;G00?o0000ok:_eOnb[mD03_nb[mD00ol0003o/:_Cok2[d`05ok2[d`;o00001On_[mP0
0ol0003o[:gGojb]e`0>ojb]e`03o`000?nZZmOoZZ_G00OoZZ_G0ol00002ojZ^f`03o`000?nY[]_o
ZJkK00goZJkK00?o0000ojR]fonX[M/03OnX[M/00ol0003oYjgLojN]g004o`0003?ooo]Z0ol0002?
oookJP00_OoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?nl^mWo_;_I00Oo_;_I0_l00006okVj
fP03o`000?nk^=Ko^kSF00ko^kSF0_l0000AokRdeP03o`000?ng/M?o]k7C00Co]k7C0ol00007okBb
e`03o`000?nb[mGo/ZoE00go/ZoE00?o0000ok2[don`Zm<00on`Zm<2o`0000So[joH00?o0000ojb]
eon/[ML03On/[ML00ol0003oZZ_GojZ[e`04ojZ[e`?o00001_nZ[]/00ol0003oZJkKojV^f`0=ojV^
f`03o`000?nX[M_oZ:gK00_oZ:gK1?l0000coookJPCo0000T_oonfX00;kooo]Z00?o0000oookJ_oo
nfX03_oonfX00ol0003o_;_Iokbkf@04okbkf@;o00002Oni^]X00ol0003o^kSFok^heP0;ok^heP;o
000000?o^;SIo`000?nh]=H04?nh]=H00ol0003o]k7CokNad`02okNad`;o00002_nd/]L00ol0003o
/ZoEok:_e@0>ok:_e@03o`000?n`Zm?o000000;o00002_n_[mP00ol0003o[:gGojb]e`0>ojb]e`03
o`000?nZZmOoZZ_G00?o00002_nZ[]/00ol0003oZJkKojV^f`0=ojV^f`03o`000?nX[M_oZ:gK00Oo
Z:gK0ol0000coookJPCo0000U_oonfX00;oooo]Z0_l0000?oookJP03o`000?nl^mWo_;_I00;o_;_I
00?o0000okVjf_ni^]X02_ni^]X00ol0003o^kSFok^heP08ok^heP;o00001?nh^=T00ol0003o^;CF
okRdeP0?okRdeP04o`000?ng/M?o0000o`0000go];;G00?o0000ok:_eOnb[mD03Onb[mD2o`0000ko
[joH00?o0000ojb]eon/[ML03On/[ML3o`0000goZZkK00?o0000ojV^fonY[]/03OnY[]/00ol0003o
Z:gKojR]f`04ojR]f`?o0000<_oonfX4o`0009[ooo]Z0031oookJP03o`000?oonf[ooo]Z00gooo]Z
00Co0000okbkfOl0003o00003_ni^]X00ol0003o^kSFok^heP05ok^heP;o00001onh^=T00ol0003o
^;CFokRdeP0>okRdeP;o00004?nd/]L00ol0003o/ZoEok:_e@09ok:_e@?o000000?o/;7Io`000?n_
[mP03_n_[mP00ol0003o[:gGojb]e`09ojb]e`?o000000?o[;3Ko`000?nZ[]/03_nZ[]/00ol0003o
ZJkKojV^f`0=ojV^f`03o`000?nX[M_oZ:gK00?o0000<OoonfX4o`0009kooo]Z0032oookJP03o`00
0?oonf[ooo]Z00gooo]Z00?o0000okVjf_ni^]X03oni^]X00ol0003o^kSFok^heP02ok^heP;o0000
2_nh^=T00ol0003o^;CFokRdeP0;okRdeP;o000000?o]KGIo`000?nd/]L04?nd/]L00ol0003o/ZoE
ok:_e@05ok:_e@?o00001On`/MT00ol0003o[joHojn_f00=ojn_f003o`000?n/[MOo[:gG00Go[:gG
0ol00005ojb`f`03o`000?nZ[]_oZZkK00goZZkK00?o0000ojV^fonY[]/02onY[]/4o`00033ooo]Z
1?l0002RoookJP00`ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?ni^][o^K[J013o^K[J00Co
0000ok^he_l0003o00003Onh^=T00ol0003o^;CFokRdeP08okRdeP;o00001?ne]MT00ol0003o];;G
okBbe`0>okBbe`03o`000?nb[mGo/ZoE00?o/ZoE0_l00009ok2af@03o`000?n_[mSo[joH00co[joH
00?o0000ojb]eon/[ML00on/[ML2o`0000Wo[;3K00?o0000ojZ^fonZ[]/03OnZ[]/00ol0003oZJkK
ojV^f`07ojV^f`?o0000<OoonfX3o`000:Kooo]Z0034oookJP;o00003OoonfX00ol0003o^K[JokVj
fP0?okVjfP;o00004?nh^=T00ol0003o^;CFokRdeP05okRdeP;o00001one]MT00ol0003o];;GokBb
e`0>okBbe`03o`000?nb[mGo000000;o00003?n`/MT00ol0003o[joHojn_f00<ojn_f003o`000?n/
[MOo000000;o00002on//=/00ol0003oZZkKojZ^f`0=ojZ^f`03o`000?nY[]_oZJkK00CoZJkK0ol0
000`oookJPCo0000ZOoonfX00<Kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003o^K[JokVjfP0<
okVjfP;o000000?o]k[Lo`000?nh^=T04?nh^=T00ol0003o^;CFokRdeP02okRdeP;o00002_ne]MT0
0ol0003o];;GokBbe`0=okBbe`;o00004?n`/MT00ol0003o[joHojn_f00;ojn_f0;o00003on//=/0
0ol0003oZZkKojZ^f`0=ojZ^f`03o`000?nY[]_oZJkK00?o0000;ooonfX4o`000:gooo]Z0037oook
JP03o`000?oonf[ooo]Z00_ooo]Z00?o0000okVjf_ni^]X02Oni^]X2o`0000Co]k[L00?o0000okRh
fOnh^=T03onh^=T01?l0003o^;CFo`000?l0000=okFef@03o`000?nd/]Oo];;G00Wo];;G0ol00000
0onb]=[o0000ok2af@0?ok2af@03o`000?n_[mSo[joH00So[joH0ol000000on^/M_o0000ojb`f`0?
ojb`f`03o`000?nZ[]_oZZkK00_oZZkK1?l0000^oookJPCo0000/OoonfX00<Sooo]Z00?o0000oook
J_oonfX02ooonfX00ol0003o^K[JokVjfP05okVjfP?o00001ong^]`00ol0003o^;SIokRhf@0>okRh
f@;o00004?ne]MT00ol0003o];;GokBbe`06okBbe`;o00001Onb]=X00ol0003o/;7Iok2af@0>ok2a
f@03o`000?n_[mSo[joH00Co[joH0ol00005ojjaf`03o`000?n//=_o[;3K00ko[;3K00?o0000ojZ^
fonZ[]/01onZ[]/3o`0002kooo]Z1?l0002eoookJP00bOoonfX2o`0000cooo]Z00?o0000okVjf_ni
^]X00_ni^]X2o`0000_o]k[L00?o0000okRhfOnh^=T02onh^=T2o`000003okFhfol0003o]KGI013o
]KGI00?o0000okBbeond/]L00ond/]L2o`0000So/[CJ00?o0000ok2afOn`/MT03_n`/MT00ol0003o
[joHojn_f003o`0000Wo[[7K00?o0000ojb`fon//=/03On//=/00ol0003oZZkKojZ^f`04ojZ^f`?o
0000;OoonfX4o`000;Wooo]Z003;oookJP03o`000?oonf[ooo]Z00[ooo]Z00Co0000okVjf_l0003o
00003_ng^]`00ol0003o^;SIokRhf@08okRhf@;o00001?ne^=/00ol0003o]KGIokFef@0?okFef@03
o`000?nd/]Oo000000;o00002onb]=X00ol0003o/;7Iok2af@0=ok2af@?o00003On^/M/00ol0003o
[;3Kojb`f`0=ojb`f`03o`000?nZ[]_oZZkK00?o0000;OoonfX3o`000;gooo]Z003<oookJP03o`00
0?oonf[ooo]Z00[ooo]Z00?o0000okNjg?ng^]`03_ng^]`00ol0003o^;SIokRhf@05okRhf@?o0000
1one^=/00ol0003o]KGIokFef@0>okFef@;o00003onb]=X00ol0003o/;7Iok2af@09ok2af@?o0000
00?o[k?Lo`000?n^/M/03_n^/M/00ol0003o[;3Kojb`f`0;ojb`f`Co0000;?oonfX4o`000<3ooo]Z
003=oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000okNjg?ng^]`03_ng^]`00ol0003o^;SIokRh
f@02okRhf@;o00002one^=/00ol0003o]KGIokFef@0;okFef@;o000000?o/[KLo`000?nb]=X03_nb
]=X00ol0003o/;7Iok2af@06ok2af@?o00001On_/m`00ol0003o[[7Kojjaf`0<ojjaf`03o`000?n/
/=_o[;3K00So[;3K0ol0000/oookJPCo0000a?oonfX00<kooo]Z0_l0000;oookJP03o`000?ng^]co
]k[L00ko]k[L00Co0000okRhfOl0003o00003_ne^=/00ol0003o]KGIokFef@08okFef@;o00001?nb
]]`00ol0003o/[CJok:dfP0=ok:dfP03o`000?n`/MWo/;7I00?o/;7I0_l00009ojncg003o`000?n^
/M_o[[7K00co[[7K00?o0000ojb`fon//=/01?n//=/3o`0002_ooo]Z1?l00038oookJP00d?oonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?ng^]co]k[L00go]k[L0_l0000@okFhf`03o`000?ne]MWo
]KGI00Go]KGI0ol00007ok:fg003o`000?nb]=[o/[CJ00go/[CJ00?o0000ok2afOl000000_l0000;
ojncg003o`000?n^/M_o[[7K00go[[7K00?o0000ojb`fon//=/00ol0000ZoookJPCo0000c?oonfX0
0=7ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o]k[LokNjg009okNjg0?o00000_nd^]d00ol0
003o]KSKokFhf`0>okFhf`03o`000?ne]MWo]KGI00;o]KGI0_l0000;ok:fg003o`000?nb]=[o/[CJ
00co/[CJ0_l0000?ojncg003o`000?n^/M_o[[7K00co[[7K0ol0000YoookJPCo0000d?oonfX00=;o
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o]k[LokNjg006okNjg0;o00001_nd^]d00ol0003o
]KSKokFhf`0>okFhf`04o`000?ne]MWo0000o`0000ko/[KL00?o0000ok:df_nb]=X02?nb]=X3o`00
0003ok2egOl0003o[k?L00oo[k?L00?o0000ojjafon^/M/02?n^/M/3o`0002Sooo]Z1?l0003Doook
JP00dooonfX2o`0000[ooo]Z00?o0000okNjg?ng^]`00ong^]`2o`0000Wo];[M00?o0000okFhfone
^=/03One^=/2o`00013o/[KL00?o0000ok:df_nb]=X01_nb]=X2o`0000Go/;GM00?o0000ojncg?n_
/m`03_n_/m`00ol0003o[[7Kojjaf`05ojjaf`;o0000:?oonfX3o`000=Sooo]Z003EoookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000okNjg?l000000_l0000<okBjg@03o`000?ne^=_o]KSK00Wo]KSK
0ol000000onc^=go0000ok:fg00@ok:fg003o`000?nb]=[o/[CJ00?o/[CJ0_l00008ok2eg@03o`00
0?n_/mco[k?L00go[k?L00?o0000ojjafon^/M/00on^/M/2o`0002Kooo]Z1?l0003KoookJP00e_oo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?nd^]go];[M00ko];[M00?o0000okFhfone^=/01_ne
^=/2o`0000Go/kSM00?o0000ok:fg?nb]]`03onb]]`00ol0003o/[CJo`000002o`0000_o/;GM00?o
0000ojncg?n_/m`03On_/m`00ol0003o[[7Ko`000002o`0002Cooo]Z1?l0003OoookJP00eooonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?nd^]go];[M00oo];[M00?o0000okFhfone^=/00one^=/2
o`0000So/kSM00?o0000ok:fg?nb]]`03_nb]]`2o`0000oo/;GM00?o0000ojncg?n_/m`02on_/m`3
o`0002?ooo]Z1?l0003SoookJP00f?oonfX2o`0000Sooo]Z00?o0000okBjgOnd^]d03ond^]d00ol0
003o]KSKo`000002o`0000_o/kSM00?o0000ok:fg?nb]]`02_nb]]`3o`000003ok2gg_l0003o/;GM
00ko/;GM00?o0000ojncg?n_/m`02?n_/m`3o`0002;ooo]Z1?l0003WoookJP00f_oonfX00ol0003o
oo]ZoookJP06oookJP03o`000?nd^]go];[M00ko];[M0_l0000?ok>hg@03o`000?nb]]co/[KL00Ko
/[KL0ol00005ok2ggP03o`000?n`]Mgo/;GM00go/;GM00?o0000ojncg?n_/m`01?n_/m`3o`00027o
oo]Z1?l0003[oookJP00fooonfX00ol0003ooo]ZoookJP06oookJP03o`000?nd^]go];[M00[o];[M
0ol000000onb^]oo0000ok>hg@0?ok>hg@03o`000?nb]]co/[KL00?o/[KL0_l00009ok2ggP03o`00
0?n`]Mgo/;GM00go/;GM00?o0000ojncg?n_/m`00ol0000QoookJP?o0000kooonfX00=cooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003o];[MokBjg@06okBjg@?o00001Onb^]l00ol0003o/kSMok>h
g@0>ok>hg@03o`000?nb]]co000000;o00003?n`]mh00ol0003o/;GMok2eg@0<ok2eg@?o00008?oo
nfX4o`000?;ooo]Z003MoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000okBjgOnd^]d00ond^]d2
o`0000Wo/[[O00?o0000ok>hgOnc^=d03Onc^=d2o`00013o/;ON00?o0000ok2egOn`]Md02?n`]Md3
o`0001oooo]Z1?l0003foookJP00g_oonfX2o`0000Oooo]Z00?o0000okBjgOl000000_l0000<ok:j
g`03o`000?nc^=go/kSM00Wo/kSM0ol000000ona^Moo0000ok2ggP0?ok2ggP03o`000?n`]Mgo/;GM
00Ko/;GM0_l0000NoookJPCo0000n_oonfX00>3ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
/[[Ook:jg`0>ok:jg`03o`000?nc^=go/kSM00Ko/kSM0_l00005ok6ig`03o`000?n`]mko/;ON00ko
/;ON00?o0000ok2egOn`]Md00on`]Md2o`0001cooo]Z1?l0003noookJP00hOoonfX00ol0003ooo]Z
oookJP05oookJP03o`000?nb^]oo/[[O00ko/[[O00?o0000ok>hgOnc^=d00onc^=d2o`0000So/KWO
00?o0000ok2gg_n`]mh03_n`]mh00ol0003o/;GMo`000002o`0001[ooo]Z1?l0003ooookJP?ooo]Z
003RoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000ok:jgonb^]l03_nb^]l00ol0003o/kSMo`00
0002o`0000_o/KWO00?o0000ok2gg_n`]mh03?n`]mh3o`0001Wooo]Z1?l0003ooookJPOooo]Z003S
oookJP;o00001_oonfX00ol0003o/[[Ook:jg`0=ok:jg`;o00003ona^Ml00ol0003o/;ONok2ggP08
ok2ggP?o00006OoonfX3o`000?oooo]Z2ooonfX00>Gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003o/[[Ook:jg`09ok:jg`?o000000?o/K[Qo`000?na^Ml03ona^Ml00ol0003o/;ONok2ggP04ok2g
gP?o00006?oonfX4o`000?oooo]Z3_oonfX00>Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
/[[Ook:jg`06ok:jg`;o00001Ona^^400ol0003o/KWOok6ig`0>ok6ig`03o`000?n`]mko/;ON00?o
00005ooonfX4o`000?oooo]Z4_oonfX00>Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o/[[O
ok:jg`03ok:jg`;o00002?na^^400ol0003o/KWOok6ig`0=ok6ig`?o00005_oonfX4o`000?oooo]Z
5_oonfX00>Sooo]Z0_l00005oookJP03o`000?nb^]oo000000;o00002ona^^400ol0003o/KWOok6i
g`09ok6ig`?o00005OoonfX4o`000?oooo]Z6_oonfX00>[ooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003o/K[Qok6jh@0=ok6jh@03o`000?na^Moo/KWO00Ko/KWO0_l0000DoookJPCo0000oooonfXN
oookJP00jooonfX00ol0003ooo]ZoookJP03oookJP03o`000?na^^7o/K[Q00go/K[Q00?o0000ok6i
gona^Ml00ona^Ml2o`0001?ooo]Z0ol0003ooookJR;ooo]Z003/oookJP03o`000?oonf[ooo]Z00?o
oo]Z00?o0000ok6jhOna^^403Ona^^400ol0003o/KWOo`000002o`00017ooo]Z1?l0003ooookJRGo
oo]Z003]oookJP;o00001?oonfX00ol0003o/K[Qok6jh@0<ok6jh@;o00004?oonfX4o`000?oooo]Z
:OoonfX00>oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o/K[Qok6jh@08ok6jh@?o00003_oo
nfX4o`000?oooo]Z;OoonfX00?3ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o/K[Qok6jh@04
ok6jh@?o00003OoonfX4o`000?oooo]Z<OoonfX00?7ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003o/K[Qok6jh@03o`0000cooo]Z1?l0003ooookJSGooo]Z003boookJP;o00000ooonfX2o`0000_o
oo]Z1?l0003ooookJSWooo]Z003doookJP04o`000?oonf[ooo]Zo`0000Wooo]Z0ol0003ooookJSgo
oo]Z003eoookJP03o`000?oonf[o000000Gooo]Z1?l0003ooookJT3ooo]Z003foookJP;o000000?o
oo]Zo`000?l000000_l0003ooookJTCooo]Z003goookJP;o0000oooonfY8oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {466.188, 0}} -> {-0.0592813, 0.0148478, \
0.00177298, 0.00177298}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Contour visualization of the three-hole potential", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ContourPlot[ThreeHolePotential[x, y], {x, \(-2\), 2}, {y, \(-2\), 2}, 
      PlotPoints \[Rule] 40, 
      ColorFunction \[Rule] \((Hue[1 - #*0.66] &)\)]\)], "Input",
  CellTags->"mmtag:13:ContourPlot[]__example_1/r_potentials"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.5 0.240385 [
[.01923 -0.0125 -13.4688 -20 ]
[.01923 -0.0125 13.4688 0 ]
[.25962 -0.0125 -13.4688 -20 ]
[.25962 -0.0125 13.4688 0 ]
[.5 -0.0125 -7 -20 ]
[.5 -0.0125 7 0 ]
[.74038 -0.0125 -7 -20 ]
[.74038 -0.0125 7 0 ]
[.98077 -0.0125 -7 -20 ]
[.98077 -0.0125 7 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -26.9375 -10 ]
[-0.0125 .01923 0 10 ]
[-0.0125 .25962 -26.9375 -10 ]
[-0.0125 .25962 0 10 ]
[-0.0125 .5 -14 -10 ]
[-0.0125 .5 0 10 ]
[-0.0125 .74038 -14 -10 ]
[-0.0125 .74038 0 10 ]
[-0.0125 .98077 -14 -10 ]
[-0.0125 .98077 0 10 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.25962 0 m
.25962 .00625 L
s
gsave
.25962 -0.0125 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.74038 0 m
.74038 .00625 L
s
gsave
.74038 -0.0125 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .25962 m
.00625 .25962 L
s
gsave
-0.0125 .25962 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .74038 m
.00625 .74038 L
s
gsave
-0.0125 .74038 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 1 .436 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
0 1 .04 r
.01923 .81151 m
.03471 .83284 L
.04389 .84424 L
.05544 .8575 L
.06854 .87126 L
.0798 .88215 L
.0932 .89412 L
.10872 .9068 L
.11785 .91372 L
.1425 .93067 L
.14374 .93146 L
.16716 .94537 L
.18765 .95611 L
.19181 .95815 L
.21647 .96923 L
.24112 .97881 L
.24665 .98077 L
.01923 .98077 L
F
0 g
.01923 .81151 m
.03471 .83284 L
.04389 .84424 L
.05544 .8575 L
.06854 .87126 L
.0798 .88215 L
.0932 .89412 L
.10872 .9068 L
.11785 .91372 L
.1425 .93067 L
.14374 .93146 L
.16716 .94537 L
.18765 .95611 L
.19181 .95815 L
.21647 .96923 L
.24112 .97881 L
.24665 .98077 L
s
0 1 .04 r
.01923 .30011 m
.02405 .29043 L
.03695 .26578 L
.04389 .25316 L
.05072 .24112 L
.0654 .21647 L
.06854 .21139 L
.08105 .19181 L
.0932 .17374 L
.09777 .16716 L
.11573 .1425 L
.11785 .13972 L
.13516 .11785 L
.1425 .10906 L
.15638 .0932 L
.16716 .08153 L
.17981 .06854 L
.19181 .05691 L
.2061 .04389 L
.21647 .03498 L
.23621 .01923 L
.01923 .01923 L
F
0 g
.01923 .30011 m
.02405 .29043 L
.03695 .26578 L
.04389 .25316 L
.05072 .24112 L
.0654 .21647 L
.06854 .21139 L
.08105 .19181 L
.0932 .17374 L
.09777 .16716 L
.11573 .1425 L
.11785 .13972 L
.13516 .11785 L
.1425 .10906 L
.15638 .0932 L
.16716 .08153 L
.17981 .06854 L
.19181 .05691 L
.2061 .04389 L
.21647 .03498 L
.23621 .01923 L
s
0 1 .832 r
.41371 .04295 m
.43836 .03601 L
.46302 .03147 L
.48767 .02922 L
.51233 .02922 L
.53698 .03147 L
.56164 .03601 L
.58629 .04295 L
.5891 .04389 L
.61095 .05242 L
.6356 .06464 L
.64243 .06854 L
.66026 .07992 L
.67821 .0932 L
.68491 .09867 L
.70597 .11785 L
.70957 .12145 L
.72884 .1425 L
.73422 .14893 L
.74842 .16716 L
.75888 .18176 L
.76569 .19181 L
.78138 .21647 L
.78353 .22 L
.79607 .24112 L
.80819 .26213 L
.81027 .26578 L
.82435 .29043 L
.83284 .30521 L
.83855 .31509 L
.85292 .33974 L
.8575 .34758 L
.86727 .3644 L
.88127 .38905 L
.88215 .39064 L
.89452 .41371 L
.90665 .43836 L
.9068 .43869 L
.91737 .46302 L
.92647 .48767 L
.93146 .50362 L
.93384 .51233 L
.93937 .53698 L
.94302 .56164 L
.94474 .58629 L
.94446 .61095 L
.9421 .6356 L
.93754 .66026 L
.93146 .68248 L
.93063 .68491 L
.92112 .70957 L
.90869 .73422 L
.9068 .73748 L
.89281 .75888 L
.88215 .77268 L
.8727 .78353 L
.8575 .79886 L
.84699 .80819 L
.83284 .81936 L
.81298 .83284 L
.80819 .83574 L
.78353 .8489 L
.76383 .8575 L
.75888 .8594 L
.73422 .86766 L
.70957 .87401 L
.68491 .8787 L
.66026 .88198 L
.65897 .88215 L
.6356 .88409 L
.61095 .88527 L
.58629 .88577 L
.56164 .88586 L
.53698 .88576 L
.51233 .88566 L
.48767 .88566 L
.46302 .88576 L
.43836 .88586 L
.41371 .88577 L
.38905 .88527 L
.3644 .88409 L
.34103 .88215 L
.33974 .88198 L
.31509 .8787 L
.29043 .87401 L
.26578 .86766 L
.24112 .8594 L
.23617 .8575 L
.21647 .8489 L
.19181 .83574 L
.18702 .83284 L
.16716 .81936 L
.15301 .80819 L
.1425 .79886 L
.1273 .78353 L
.11785 .77268 L
.10719 .75888 L
.0932 .73748 L
.09131 .73422 L
.07888 .70957 L
.06937 .68491 L
.06854 .68248 L
.06246 .66026 L
.0579 .6356 L
.05554 .61095 L
.05526 .58629 L
.05698 .56164 L
.06063 .53698 L
.06616 .51233 L
.06854 .50362 L
.07353 .48767 L
.08263 .46302 L
.0932 .43869 L
.09335 .43836 L
.10548 .41371 L
.11785 .39064 L
.11873 .38905 L
.13273 .3644 L
.1425 .34758 L
.14708 .33974 L
.16145 .31509 L
.16716 .30521 L
.17565 .29043 L
.18973 .26578 L
.19181 .26213 L
.20393 .24112 L
.21647 .22 L
.21862 .21647 L
.23431 .19181 L
.24112 .18176 L
.25158 .16716 L
.26578 .14893 L
.27116 .1425 L
.29043 .12145 L
.29403 .11785 L
.31509 .09867 L
.32179 .0932 L
.33974 .07992 L
.35757 .06854 L
.3644 .06464 L
.38905 .05242 L
.4109 .04389 L
F
0 g
.41371 .04295 m
.43836 .03601 L
.46302 .03147 L
.48767 .02922 L
.51233 .02922 L
.53698 .03147 L
.56164 .03601 L
.58629 .04295 L
.5891 .04389 L
.61095 .05242 L
.6356 .06464 L
.64243 .06854 L
.66026 .07992 L
.67821 .0932 L
.68491 .09867 L
.70597 .11785 L
.70957 .12145 L
.72884 .1425 L
.73422 .14893 L
.74842 .16716 L
.75888 .18176 L
.76569 .19181 L
.78138 .21647 L
.78353 .22 L
.79607 .24112 L
.80819 .26213 L
.81027 .26578 L
.82435 .29043 L
.83284 .30521 L
.83855 .31509 L
.85292 .33974 L
.8575 .34758 L
.86727 .3644 L
.88127 .38905 L
.88215 .39064 L
.89452 .41371 L
.90665 .43836 L
.9068 .43869 L
.91737 .46302 L
.92647 .48767 L
.93146 .50362 L
.93384 .51233 L
.93937 .53698 L
.94302 .56164 L
.94474 .58629 L
.94446 .61095 L
.9421 .6356 L
.93754 .66026 L
.93146 .68248 L
.93063 .68491 L
Mistroke
.92112 .70957 L
.90869 .73422 L
.9068 .73748 L
.89281 .75888 L
.88215 .77268 L
.8727 .78353 L
.8575 .79886 L
.84699 .80819 L
.83284 .81936 L
.81298 .83284 L
.80819 .83574 L
.78353 .8489 L
.76383 .8575 L
.75888 .8594 L
.73422 .86766 L
.70957 .87401 L
.68491 .8787 L
.66026 .88198 L
.65897 .88215 L
.6356 .88409 L
.61095 .88527 L
.58629 .88577 L
.56164 .88586 L
.53698 .88576 L
.51233 .88566 L
.48767 .88566 L
.46302 .88576 L
.43836 .88586 L
.41371 .88577 L
.38905 .88527 L
.3644 .88409 L
.34103 .88215 L
.33974 .88198 L
.31509 .8787 L
.29043 .87401 L
.26578 .86766 L
.24112 .8594 L
.23617 .8575 L
.21647 .8489 L
.19181 .83574 L
.18702 .83284 L
.16716 .81936 L
.15301 .80819 L
.1425 .79886 L
.1273 .78353 L
.11785 .77268 L
.10719 .75888 L
.0932 .73748 L
.09131 .73422 L
.07888 .70957 L
Mistroke
.06937 .68491 L
.06854 .68248 L
.06246 .66026 L
.0579 .6356 L
.05554 .61095 L
.05526 .58629 L
.05698 .56164 L
.06063 .53698 L
.06616 .51233 L
.06854 .50362 L
.07353 .48767 L
.08263 .46302 L
.0932 .43869 L
.09335 .43836 L
.10548 .41371 L
.11785 .39064 L
.11873 .38905 L
.13273 .3644 L
.1425 .34758 L
.14708 .33974 L
.16145 .31509 L
.16716 .30521 L
.17565 .29043 L
.18973 .26578 L
.19181 .26213 L
.20393 .24112 L
.21647 .22 L
.21862 .21647 L
.23431 .19181 L
.24112 .18176 L
.25158 .16716 L
.26578 .14893 L
.27116 .1425 L
.29043 .12145 L
.29403 .11785 L
.31509 .09867 L
.32179 .0932 L
.33974 .07992 L
.35757 .06854 L
.3644 .06464 L
.38905 .05242 L
.4109 .04389 L
.41371 .04295 L
Mfstroke
0 .772 1 r
.46302 .09046 m
.48767 .08733 L
.51233 .08733 L
.53698 .09046 L
.55032 .0932 L
.56164 .09687 L
.58629 .10686 L
.60619 .11785 L
.61095 .12094 L
.6356 .14006 L
.63828 .1425 L
.66026 .16586 L
.66132 .16716 L
.67902 .19181 L
.68491 .20141 L
.69315 .21647 L
.70481 .24112 L
.70957 .25239 L
.7149 .26578 L
.7243 .29043 L
.73405 .31509 L
.73422 .31549 L
.74536 .33974 L
.75888 .36361 L
.75937 .3644 L
.77663 .38905 L
.78353 .39796 L
.79623 .41371 L
.80819 .4284 L
.81614 .43836 L
.83284 .4607 L
.83446 .46302 L
.85016 .48767 L
.8575 .50114 L
.86288 .51233 L
.87257 .53698 L
.87932 .56164 L
.88215 .57767 L
.88317 .58629 L
.88413 .61095 L
.88215 .63559 L
.88215 .6356 L
.87703 .66026 L
.86848 .68491 L
.8575 .70698 L
.85594 .70957 L
.83838 .73422 L
.83284 .74057 L
.81378 .75888 L
.80819 .7634 L
.78353 .7799 L
.77699 .78353 L
.75888 .79189 L
.73422 .80032 L
.70957 .8058 L
.69117 .80819 L
.68491 .80871 L
.66026 .80939 L
.63572 .80819 L
.6356 .80818 L
.61095 .80547 L
.58629 .80178 L
.56164 .79781 L
.53698 .79441 L
.51233 .79243 L
.48767 .79243 L
.46302 .79441 L
.43836 .79781 L
.41371 .80178 L
.38905 .80547 L
.3644 .80818 L
.36428 .80819 L
.33974 .80939 L
.31509 .80871 L
.30883 .80819 L
.29043 .8058 L
.26578 .80032 L
.24112 .79189 L
.22301 .78353 L
.21647 .7799 L
.19181 .7634 L
.18622 .75888 L
.16716 .74057 L
.16162 .73422 L
.14406 .70957 L
.1425 .70698 L
.13152 .68491 L
.12297 .66026 L
.11785 .6356 L
.11785 .63559 L
.11587 .61095 L
.11683 .58629 L
.11785 .57767 L
.12068 .56164 L
.12743 .53698 L
.13712 .51233 L
.1425 .50114 L
.14984 .48767 L
.16554 .46302 L
.16716 .4607 L
.18386 .43836 L
.19181 .4284 L
.20377 .41371 L
.21647 .39796 L
.22337 .38905 L
.24063 .3644 L
.24112 .36361 L
.25464 .33974 L
.26578 .31549 L
.26595 .31509 L
.2757 .29043 L
.2851 .26578 L
.29043 .25239 L
.29519 .24112 L
.30685 .21647 L
.31509 .20141 L
.32098 .19181 L
.33868 .16716 L
.33974 .16586 L
.36172 .1425 L
.3644 .14006 L
.38905 .12094 L
.39381 .11785 L
.41371 .10686 L
.43836 .09687 L
.44968 .0932 L
F
0 g
.46302 .09046 m
.48767 .08733 L
.51233 .08733 L
.53698 .09046 L
.55032 .0932 L
.56164 .09687 L
.58629 .10686 L
.60619 .11785 L
.61095 .12094 L
.6356 .14006 L
.63828 .1425 L
.66026 .16586 L
.66132 .16716 L
.67902 .19181 L
.68491 .20141 L
.69315 .21647 L
.70481 .24112 L
.70957 .25239 L
.7149 .26578 L
.7243 .29043 L
.73405 .31509 L
.73422 .31549 L
.74536 .33974 L
.75888 .36361 L
.75937 .3644 L
.77663 .38905 L
.78353 .39796 L
.79623 .41371 L
.80819 .4284 L
.81614 .43836 L
.83284 .4607 L
.83446 .46302 L
.85016 .48767 L
.8575 .50114 L
.86288 .51233 L
.87257 .53698 L
.87932 .56164 L
.88215 .57767 L
.88317 .58629 L
.88413 .61095 L
.88215 .63559 L
.88215 .6356 L
.87703 .66026 L
.86848 .68491 L
.8575 .70698 L
.85594 .70957 L
.83838 .73422 L
.83284 .74057 L
.81378 .75888 L
.80819 .7634 L
Mistroke
.78353 .7799 L
.77699 .78353 L
.75888 .79189 L
.73422 .80032 L
.70957 .8058 L
.69117 .80819 L
.68491 .80871 L
.66026 .80939 L
.63572 .80819 L
.6356 .80818 L
.61095 .80547 L
.58629 .80178 L
.56164 .79781 L
.53698 .79441 L
.51233 .79243 L
.48767 .79243 L
.46302 .79441 L
.43836 .79781 L
.41371 .80178 L
.38905 .80547 L
.3644 .80818 L
.36428 .80819 L
.33974 .80939 L
.31509 .80871 L
.30883 .80819 L
.29043 .8058 L
.26578 .80032 L
.24112 .79189 L
.22301 .78353 L
.21647 .7799 L
.19181 .7634 L
.18622 .75888 L
.16716 .74057 L
.16162 .73422 L
.14406 .70957 L
.1425 .70698 L
.13152 .68491 L
.12297 .66026 L
.11785 .6356 L
.11785 .63559 L
.11587 .61095 L
.11683 .58629 L
.11785 .57767 L
.12068 .56164 L
.12743 .53698 L
.13712 .51233 L
.1425 .50114 L
.14984 .48767 L
.16554 .46302 L
.16716 .4607 L
Mistroke
.18386 .43836 L
.19181 .4284 L
.20377 .41371 L
.21647 .39796 L
.22337 .38905 L
.24063 .3644 L
.24112 .36361 L
.25464 .33974 L
.26578 .31549 L
.26595 .31509 L
.2757 .29043 L
.2851 .26578 L
.29043 .25239 L
.29519 .24112 L
.30685 .21647 L
.31509 .20141 L
.32098 .19181 L
.33868 .16716 L
.33974 .16586 L
.36172 .1425 L
.3644 .14006 L
.38905 .12094 L
.39381 .11785 L
.41371 .10686 L
.43836 .09687 L
.44968 .0932 L
.46302 .09046 L
Mfstroke
0 .376 1 r
.43836 .13644 m
.46302 .12788 L
.48767 .12376 L
.51233 .12376 L
.53698 .12788 L
.56164 .13644 L
.57389 .1425 L
.58629 .1503 L
.60687 .16716 L
.61095 .17124 L
.62779 .19181 L
.6356 .20386 L
.64221 .21647 L
.6522 .24112 L
.6589 .26578 L
.66026 .27084 L
.6631 .29043 L
.66565 .31509 L
.66767 .33974 L
.67094 .3644 L
.67868 .38905 L
.68491 .40015 L
.69636 .41371 L
.70957 .42538 L
.72756 .43836 L
.73422 .44302 L
.75888 .46041 L
.76239 .46302 L
.78353 .48066 L
.79093 .48767 L
.80819 .50702 L
.81224 .51233 L
.82762 .53698 L
.83284 .54771 L
.83809 .56164 L
.84425 .58629 L
.84645 .61095 L
.84472 .6356 L
.83887 .66026 L
.83284 .67618 L
.82824 .68491 L
.81151 .70957 L
.80819 .71342 L
.78535 .73422 L
.78353 .73554 L
.75888 .74995 L
.73524 .75888 L
.73422 .75914 L
.70957 .76407 L
.68491 .76538 L
.66026 .7634 L
.6373 .75888 L
.6356 .75832 L
.61095 .75038 L
.58629 .74008 L
.5741 .73422 L
.56164 .72847 L
.53698 .71767 L
.51233 .71087 L
.48767 .71087 L
.46302 .71767 L
.43836 .72847 L
.4259 .73422 L
.41371 .74008 L
.38905 .75038 L
.3644 .75832 L
.3627 .75888 L
.33974 .7634 L
.31509 .76538 L
.29043 .76407 L
.26578 .75914 L
.26476 .75888 L
.24112 .74995 L
.21647 .73554 L
.21465 .73422 L
.19181 .71342 L
.18849 .70957 L
.17176 .68491 L
.16716 .67618 L
.16113 .66026 L
.15528 .6356 L
.15355 .61095 L
.15575 .58629 L
.16191 .56164 L
.16716 .54771 L
.17238 .53698 L
.18776 .51233 L
.19181 .50702 L
.20907 .48767 L
.21647 .48066 L
.23761 .46302 L
.24112 .46041 L
.26578 .44302 L
.27244 .43836 L
.29043 .42538 L
.30364 .41371 L
.31509 .40015 L
.32132 .38905 L
.32906 .3644 L
.33233 .33974 L
.33435 .31509 L
.3369 .29043 L
.33974 .27084 L
.3411 .26578 L
.3478 .24112 L
.35779 .21647 L
.3644 .20386 L
.37221 .19181 L
.38905 .17124 L
.39313 .16716 L
.41371 .1503 L
.42611 .1425 L
F
0 g
.43836 .13644 m
.46302 .12788 L
.48767 .12376 L
.51233 .12376 L
.53698 .12788 L
.56164 .13644 L
.57389 .1425 L
.58629 .1503 L
.60687 .16716 L
.61095 .17124 L
.62779 .19181 L
.6356 .20386 L
.64221 .21647 L
.6522 .24112 L
.6589 .26578 L
.66026 .27084 L
.6631 .29043 L
.66565 .31509 L
.66767 .33974 L
.67094 .3644 L
.67868 .38905 L
.68491 .40015 L
.69636 .41371 L
.70957 .42538 L
.72756 .43836 L
.73422 .44302 L
.75888 .46041 L
.76239 .46302 L
.78353 .48066 L
.79093 .48767 L
.80819 .50702 L
.81224 .51233 L
.82762 .53698 L
.83284 .54771 L
.83809 .56164 L
.84425 .58629 L
.84645 .61095 L
.84472 .6356 L
.83887 .66026 L
.83284 .67618 L
.82824 .68491 L
.81151 .70957 L
.80819 .71342 L
.78535 .73422 L
.78353 .73554 L
.75888 .74995 L
.73524 .75888 L
.73422 .75914 L
.70957 .76407 L
.68491 .76538 L
Mistroke
.66026 .7634 L
.6373 .75888 L
.6356 .75832 L
.61095 .75038 L
.58629 .74008 L
.5741 .73422 L
.56164 .72847 L
.53698 .71767 L
.51233 .71087 L
.48767 .71087 L
.46302 .71767 L
.43836 .72847 L
.4259 .73422 L
.41371 .74008 L
.38905 .75038 L
.3644 .75832 L
.3627 .75888 L
.33974 .7634 L
.31509 .76538 L
.29043 .76407 L
.26578 .75914 L
.26476 .75888 L
.24112 .74995 L
.21647 .73554 L
.21465 .73422 L
.19181 .71342 L
.18849 .70957 L
.17176 .68491 L
.16716 .67618 L
.16113 .66026 L
.15528 .6356 L
.15355 .61095 L
.15575 .58629 L
.16191 .56164 L
.16716 .54771 L
.17238 .53698 L
.18776 .51233 L
.19181 .50702 L
.20907 .48767 L
.21647 .48066 L
.23761 .46302 L
.24112 .46041 L
.26578 .44302 L
.27244 .43836 L
.29043 .42538 L
.30364 .41371 L
.31509 .40015 L
.32132 .38905 L
.32906 .3644 L
.33233 .33974 L
Mistroke
.33435 .31509 L
.3369 .29043 L
.33974 .27084 L
.3411 .26578 L
.3478 .24112 L
.35779 .21647 L
.3644 .20386 L
.37221 .19181 L
.38905 .17124 L
.39313 .16716 L
.41371 .1503 L
.42611 .1425 L
.43836 .13644 L
Mfstroke
.02 0 1 r
.29043 .48256 m
.31509 .47756 L
.33974 .4756 L
.3644 .47675 L
.38905 .48187 L
.40591 .48767 L
.41371 .49237 L
.43627 .51233 L
.43836 .51488 L
.45069 .53698 L
.46104 .56164 L
.46302 .57061 L
.46374 .58629 L
.46302 .59424 L
.45872 .61095 L
.44779 .6356 L
.43836 .6565 L
.43513 .66026 L
.41548 .68491 L
.41371 .68697 L
.38905 .70839 L
.38737 .70957 L
.3644 .72303 L
.33974 .7323 L
.33197 .73422 L
.31509 .7368 L
.29043 .73675 L
.27454 .73422 L
.26578 .73194 L
.24112 .72153 L
.22322 .70957 L
.21647 .70357 L
.2004 .68491 L
.19181 .67109 L
.18717 .66026 L
.18039 .6356 L
.17882 .61095 L
.18221 .58629 L
.19085 .56164 L
.19181 .55958 L
.20596 .53698 L
.21647 .52491 L
.23021 .51233 L
.24112 .5046 L
.26578 .49119 L
.27229 .48767 L
F
0 g
.29043 .48256 m
.31509 .47756 L
.33974 .4756 L
.3644 .47675 L
.38905 .48187 L
.40591 .48767 L
.41371 .49237 L
.43627 .51233 L
.43836 .51488 L
.45069 .53698 L
.46104 .56164 L
.46302 .57061 L
.46374 .58629 L
.46302 .59424 L
.45872 .61095 L
.44779 .6356 L
.43836 .6565 L
.43513 .66026 L
.41548 .68491 L
.41371 .68697 L
.38905 .70839 L
.38737 .70957 L
.3644 .72303 L
.33974 .7323 L
.33197 .73422 L
.31509 .7368 L
.29043 .73675 L
.27454 .73422 L
.26578 .73194 L
.24112 .72153 L
.22322 .70957 L
.21647 .70357 L
.2004 .68491 L
.19181 .67109 L
.18717 .66026 L
.18039 .6356 L
.17882 .61095 L
.18221 .58629 L
.19085 .56164 L
.19181 .55958 L
.20596 .53698 L
.21647 .52491 L
.23021 .51233 L
.24112 .5046 L
.26578 .49119 L
.27229 .48767 L
.29043 .48256 L
s
.416 0 1 r
.29043 .51143 m
.31509 .51034 L
.3304 .51233 L
.33974 .51476 L
.3644 .52612 L
.37857 .53698 L
.38905 .54822 L
.39752 .56164 L
.40695 .58629 L
.40954 .61095 L
.40571 .6356 L
.39554 .66026 L
.38905 .6713 L
.377 .68491 L
.3644 .69596 L
.34063 .70957 L
.33974 .70992 L
.31509 .71671 L
.29043 .71765 L
.26578 .71281 L
.25573 .70957 L
.24112 .70079 L
.22255 .68491 L
.21647 .67777 L
.20616 .66026 L
.19821 .6356 L
.19669 .61095 L
.2013 .58629 L
.2127 .56164 L
.21647 .55603 L
.2341 .53698 L
.24112 .53165 L
.26578 .51824 L
.28539 .51233 L
F
0 g
.29043 .51143 m
.31509 .51034 L
.3304 .51233 L
.33974 .51476 L
.3644 .52612 L
.37857 .53698 L
.38905 .54822 L
.39752 .56164 L
.40695 .58629 L
.40954 .61095 L
.40571 .6356 L
.39554 .66026 L
.38905 .6713 L
.377 .68491 L
.3644 .69596 L
.34063 .70957 L
.33974 .70992 L
.31509 .71671 L
.29043 .71765 L
.26578 .71281 L
.25573 .70957 L
.24112 .70079 L
.22255 .68491 L
.21647 .67777 L
.20616 .66026 L
.19821 .6356 L
.19669 .61095 L
.2013 .58629 L
.2127 .56164 L
.21647 .55603 L
.2341 .53698 L
.24112 .53165 L
.26578 .51824 L
.28539 .51233 L
.29043 .51143 L
s
.812 0 1 r
.26578 .53597 m
.29043 .53006 L
.31509 .53074 L
.33655 .53698 L
.33974 .53855 L
.3644 .55712 L
.36815 .56164 L
.38159 .58629 L
.38645 .61095 L
.38377 .6356 L
.37336 .66026 L
.3644 .67322 L
.35175 .68491 L
.33974 .69275 L
.31509 .70192 L
.29043 .70376 L
.26578 .69851 L
.24134 .68491 L
.24112 .6847 L
.2206 .66026 L
.21647 .65204 L
.21147 .6356 L
.21003 .61095 L
.2156 .58629 L
.21647 .58382 L
.23029 .56164 L
.24112 .55092 L
.2628 .53698 L
F
0 g
.26578 .53597 m
.29043 .53006 L
.31509 .53074 L
.33655 .53698 L
.33974 .53855 L
.3644 .55712 L
.36815 .56164 L
.38159 .58629 L
.38645 .61095 L
.38377 .6356 L
.37336 .66026 L
.3644 .67322 L
.35175 .68491 L
.33974 .69275 L
.31509 .70192 L
.29043 .70376 L
.26578 .69851 L
.24134 .68491 L
.24112 .6847 L
.2206 .66026 L
.21647 .65204 L
.21147 .6356 L
.21003 .61095 L
.2156 .58629 L
.21647 .58382 L
.23029 .56164 L
.24112 .55092 L
.2628 .53698 L
.26578 .53597 L
s
1 0 .792 r
.26578 .54922 m
.29043 .54294 L
.31509 .5449 L
.33974 .55575 L
.34735 .56164 L
.3644 .58387 L
.36532 .58629 L
.37114 .61095 L
.36913 .6356 L
.3644 .64979 L
.35808 .66026 L
.33974 .67907 L
.33395 .68491 L
.31509 .69062 L
.29043 .69307 L
.26578 .68771 L
.25837 .68491 L
.24112 .67132 L
.2323 .66026 L
.22174 .6356 L
.22017 .61095 L
.22714 .58629 L
.24112 .56578 L
.24499 .56164 L
F
0 g
.26578 .54922 m
.29043 .54294 L
.31509 .5449 L
.33974 .55575 L
.34735 .56164 L
.3644 .58387 L
.36532 .58629 L
.37114 .61095 L
.36913 .6356 L
.3644 .64979 L
.35808 .66026 L
.33974 .67907 L
.33395 .68491 L
.31509 .69062 L
.29043 .69307 L
.26578 .68771 L
.25837 .68491 L
.24112 .67132 L
.2323 .66026 L
.22174 .6356 L
.22017 .61095 L
.22714 .58629 L
.24112 .56578 L
.24499 .56164 L
.26578 .54922 L
s
1 0 .396 r
.26578 .55888 m
.29043 .55289 L
.31509 .55552 L
.33294 .56164 L
.33974 .56904 L
.35288 .58629 L
.36077 .61095 L
.35866 .6356 L
.34618 .66026 L
.33974 .66743 L
.31509 .68178 L
.30015 .68491 L
.29043 .68524 L
.2868 .68491 L
.26578 .67887 L
.24176 .66026 L
.24112 .65945 L
.23013 .6356 L
.22861 .61095 L
.23634 .58629 L
.24112 .5785 L
.25928 .56164 L
F
0 g
.26578 .55888 m
.29043 .55289 L
.31509 .55552 L
.33294 .56164 L
.33974 .56904 L
.35288 .58629 L
.36077 .61095 L
.35866 .6356 L
.34618 .66026 L
.33974 .66743 L
.31509 .68178 L
.30015 .68491 L
.29043 .68524 L
.2868 .68491 L
.26578 .67887 L
.24176 .66026 L
.24112 .65945 L
.23013 .6356 L
.22861 .61095 L
.23634 .58629 L
.24112 .5785 L
.25928 .56164 L
.26578 .55888 L
s
1 0 0 r
.29043 .55989 m
.30954 .56164 L
.31509 .56341 L
.33974 .58059 L
.34355 .58629 L
.35196 .61095 L
.35011 .6356 L
.33974 .65711 L
.33709 .66026 L
.31509 .67415 L
.29043 .67559 L
.26578 .67148 L
.24976 .66026 L
.24112 .64816 L
.2366 .6356 L
.23513 .61095 L
.24112 .59083 L
.24389 .58629 L
.26578 .56683 L
.27866 .56164 L
F
0 g
.29043 .55989 m
.30954 .56164 L
.31509 .56341 L
.33974 .58059 L
.34355 .58629 L
.35196 .61095 L
.35011 .6356 L
.33974 .65711 L
.33709 .66026 L
.31509 .67415 L
.29043 .67559 L
.26578 .67148 L
.24976 .66026 L
.24112 .64816 L
.2366 .6356 L
.23513 .61095 L
.24112 .59083 L
.24389 .58629 L
.26578 .56683 L
.27866 .56164 L
.29043 .55989 L
s
.02 0 1 r
.43836 .16453 m
.46302 .15351 L
.48767 .14832 L
.51233 .14832 L
.53698 .15351 L
.56164 .16453 L
.56596 .16716 L
.58629 .1836 L
.5938 .19181 L
.6102 .21647 L
.61095 .21758 L
.6199 .24112 L
.62479 .26578 L
.62561 .29043 L
.62272 .31509 L
.61628 .33974 L
.61095 .35359 L
.60621 .3644 L
.59206 .38905 L
.58629 .39371 L
.5717 .41371 L
.56164 .42197 L
.53698 .43414 L
.52312 .43836 L
.51233 .43988 L
.48767 .43988 L
.47688 .43836 L
.46302 .43414 L
.43836 .42197 L
.4283 .41371 L
.41371 .39371 L
.40794 .38905 L
.39379 .3644 L
.38905 .35359 L
.38372 .33974 L
.37728 .31509 L
.37439 .29043 L
.37521 .26578 L
.3801 .24112 L
.38905 .21758 L
.3898 .21647 L
.4062 .19181 L
.41371 .1836 L
.43404 .16716 L
F
0 g
.43836 .16453 m
.46302 .15351 L
.48767 .14832 L
.51233 .14832 L
.53698 .15351 L
.56164 .16453 L
.56596 .16716 L
.58629 .1836 L
.5938 .19181 L
.6102 .21647 L
.61095 .21758 L
.6199 .24112 L
.62479 .26578 L
.62561 .29043 L
.62272 .31509 L
.61628 .33974 L
.61095 .35359 L
.60621 .3644 L
.59206 .38905 L
.58629 .39371 L
.5717 .41371 L
.56164 .42197 L
.53698 .43414 L
.52312 .43836 L
.51233 .43988 L
.48767 .43988 L
.47688 .43836 L
.46302 .43414 L
.43836 .42197 L
.4283 .41371 L
.41371 .39371 L
.40794 .38905 L
.39379 .3644 L
.38905 .35359 L
.38372 .33974 L
.37728 .31509 L
.37439 .29043 L
.37521 .26578 L
.3801 .24112 L
.38905 .21758 L
.3898 .21647 L
.4062 .19181 L
.41371 .1836 L
.43404 .16716 L
.43836 .16453 L
s
.416 0 1 r
.48767 .16575 m
.51233 .16575 L
.52074 .16716 L
.53698 .1721 L
.56164 .1861 L
.56843 .19181 L
.58629 .21327 L
.58812 .21647 L
.59836 .24112 L
.6024 .26578 L
.60095 .29043 L
.59395 .31509 L
.58629 .33045 L
.58005 .33974 L
.56164 .35867 L
.55471 .3644 L
.53698 .37295 L
.51233 .3795 L
.48767 .3795 L
.46302 .37295 L
.44529 .3644 L
.43836 .35867 L
.41995 .33974 L
.41371 .33045 L
.40605 .31509 L
.39905 .29043 L
.3976 .26578 L
.40164 .24112 L
.41188 .21647 L
.41371 .21327 L
.43157 .19181 L
.43836 .1861 L
.46302 .1721 L
.47926 .16716 L
F
0 g
.48767 .16575 m
.51233 .16575 L
.52074 .16716 L
.53698 .1721 L
.56164 .1861 L
.56843 .19181 L
.58629 .21327 L
.58812 .21647 L
.59836 .24112 L
.6024 .26578 L
.60095 .29043 L
.59395 .31509 L
.58629 .33045 L
.58005 .33974 L
.56164 .35867 L
.55471 .3644 L
.53698 .37295 L
.51233 .3795 L
.48767 .3795 L
.46302 .37295 L
.44529 .3644 L
.43836 .35867 L
.41995 .33974 L
.41371 .33045 L
.40605 .31509 L
.39905 .29043 L
.3976 .26578 L
.40164 .24112 L
.41188 .21647 L
.41371 .21327 L
.43157 .19181 L
.43836 .1861 L
.46302 .1721 L
.47926 .16716 L
.48767 .16575 L
s
.812 0 1 r
.46302 .18635 m
.48767 .17901 L
.51233 .17901 L
.53698 .18635 L
.54731 .19181 L
.56164 .20382 L
.57166 .21647 L
.58317 .24112 L
.58629 .25688 L
.58686 .26578 L
.58629 .27638 L
.58364 .29043 L
.57287 .31509 L
.56164 .32945 L
.55052 .33974 L
.53698 .34712 L
.51233 .35464 L
.48767 .35464 L
.46302 .34712 L
.44948 .33974 L
.43836 .32945 L
.42713 .31509 L
.41636 .29043 L
.41371 .27638 L
.41314 .26578 L
.41371 .25688 L
.41683 .24112 L
.42834 .21647 L
.43836 .20382 L
.45269 .19181 L
F
0 g
.46302 .18635 m
.48767 .17901 L
.51233 .17901 L
.53698 .18635 L
.54731 .19181 L
.56164 .20382 L
.57166 .21647 L
.58317 .24112 L
.58629 .25688 L
.58686 .26578 L
.58629 .27638 L
.58364 .29043 L
.57287 .31509 L
.56164 .32945 L
.55052 .33974 L
.53698 .34712 L
.51233 .35464 L
.48767 .35464 L
.46302 .34712 L
.44948 .33974 L
.43836 .32945 L
.42713 .31509 L
.41636 .29043 L
.41371 .27638 L
.41314 .26578 L
.41371 .25688 L
.41683 .24112 L
.42834 .21647 L
.43836 .20382 L
.45269 .19181 L
.46302 .18635 L
s
1 0 .792 r
.48767 .18892 m
.51233 .18892 L
.5243 .19181 L
.53698 .19766 L
.55893 .21647 L
.56164 .218 L
.57148 .24112 L
.57488 .26578 L
.57045 .29043 L
.56164 .30871 L
.55627 .31509 L
.53698 .33043 L
.51233 .33962 L
.48767 .33962 L
.46302 .33043 L
.44373 .31509 L
.43836 .30871 L
.42955 .29043 L
.42512 .26578 L
.42852 .24112 L
.43836 .218 L
.44107 .21647 L
.46302 .19766 L
.4757 .19181 L
F
0 g
.48767 .18892 m
.51233 .18892 L
.5243 .19181 L
.53698 .19766 L
.55893 .21647 L
.56164 .218 L
.57148 .24112 L
.57488 .26578 L
.57045 .29043 L
.56164 .30871 L
.55627 .31509 L
.53698 .33043 L
.51233 .33962 L
.48767 .33962 L
.46302 .33043 L
.44373 .31509 L
.43836 .30871 L
.42955 .29043 L
.42512 .26578 L
.42852 .24112 L
.43836 .218 L
.44107 .21647 L
.46302 .19766 L
.4757 .19181 L
.48767 .18892 L
s
1 0 .396 r
.46302 .20707 m
.48767 .19708 L
.51233 .19708 L
.53698 .20707 L
.54824 .21647 L
.56164 .23483 L
.5629 .24112 L
.56605 .26578 L
.56164 .28784 L
.56051 .29043 L
.54174 .31509 L
.53698 .31826 L
.51233 .32786 L
.48767 .32786 L
.46302 .31826 L
.45826 .31509 L
.43949 .29043 L
.43836 .28784 L
.43395 .26578 L
.4371 .24112 L
.43836 .23483 L
.45176 .21647 L
F
0 g
.46302 .20707 m
.48767 .19708 L
.51233 .19708 L
.53698 .20707 L
.54824 .21647 L
.56164 .23483 L
.5629 .24112 L
.56605 .26578 L
.56164 .28784 L
.56051 .29043 L
.54174 .31509 L
.53698 .31826 L
.51233 .32786 L
.48767 .32786 L
.46302 .31826 L
.45826 .31509 L
.43949 .29043 L
.43836 .28784 L
.43395 .26578 L
.4371 .24112 L
.43836 .23483 L
.45176 .21647 L
.46302 .20707 L
s
1 0 0 r
.46302 .21486 m
.48767 .20398 L
.51233 .20398 L
.53698 .21486 L
.53898 .21647 L
.55541 .24112 L
.55724 .26578 L
.55195 .29043 L
.53698 .30863 L
.52735 .31509 L
.51233 .31965 L
.48767 .31965 L
.47265 .31509 L
.46302 .30863 L
.44805 .29043 L
.44276 .26578 L
.44459 .24112 L
.46102 .21647 L
F
0 g
.46302 .21486 m
.48767 .20398 L
.51233 .20398 L
.53698 .21486 L
.53898 .21647 L
.55541 .24112 L
.55724 .26578 L
.55195 .29043 L
.53698 .30863 L
.52735 .31509 L
.51233 .31965 L
.48767 .31965 L
.47265 .31509 L
.46302 .30863 L
.44805 .29043 L
.44276 .26578 L
.44459 .24112 L
.46102 .21647 L
.46302 .21486 L
s
.02 0 1 r
.61095 .48187 m
.6356 .47675 L
.66026 .4756 L
.68491 .47756 L
.70957 .48256 L
.72771 .48767 L
.73422 .49119 L
.75888 .5046 L
.76979 .51233 L
.78353 .52491 L
.79404 .53698 L
.80819 .55958 L
.80915 .56164 L
.81779 .58629 L
.82118 .61095 L
.81961 .6356 L
.81283 .66026 L
.80819 .67109 L
.7996 .68491 L
.78353 .70357 L
.77678 .70957 L
.75888 .72153 L
.73422 .73194 L
.72546 .73422 L
.70957 .73675 L
.68491 .7368 L
.66803 .73422 L
.66026 .7323 L
.6356 .72303 L
.61263 .70957 L
.61095 .70839 L
.58629 .68697 L
.58452 .68491 L
.56487 .66026 L
.56164 .6565 L
.55221 .6356 L
.54128 .61095 L
.53698 .59424 L
.53626 .58629 L
.53698 .57061 L
.53896 .56164 L
.54931 .53698 L
.56164 .51488 L
.56373 .51233 L
.58629 .49237 L
.59409 .48767 L
F
0 g
.61095 .48187 m
.6356 .47675 L
.66026 .4756 L
.68491 .47756 L
.70957 .48256 L
.72771 .48767 L
.73422 .49119 L
.75888 .5046 L
.76979 .51233 L
.78353 .52491 L
.79404 .53698 L
.80819 .55958 L
.80915 .56164 L
.81779 .58629 L
.82118 .61095 L
.81961 .6356 L
.81283 .66026 L
.80819 .67109 L
.7996 .68491 L
.78353 .70357 L
.77678 .70957 L
.75888 .72153 L
.73422 .73194 L
.72546 .73422 L
.70957 .73675 L
.68491 .7368 L
.66803 .73422 L
.66026 .7323 L
.6356 .72303 L
.61263 .70957 L
.61095 .70839 L
.58629 .68697 L
.58452 .68491 L
.56487 .66026 L
.56164 .6565 L
.55221 .6356 L
.54128 .61095 L
.53698 .59424 L
.53626 .58629 L
.53698 .57061 L
.53896 .56164 L
.54931 .53698 L
.56164 .51488 L
.56373 .51233 L
.58629 .49237 L
.59409 .48767 L
.61095 .48187 L
s
.416 0 1 r
.68491 .51034 m
.70957 .51143 L
.71461 .51233 L
.73422 .51824 L
.75888 .53165 L
.7659 .53698 L
.78353 .55603 L
.7873 .56164 L
.7987 .58629 L
.80331 .61095 L
.80179 .6356 L
.79384 .66026 L
.78353 .67777 L
.77745 .68491 L
.75888 .70079 L
.74427 .70957 L
.73422 .71281 L
.70957 .71765 L
.68491 .71671 L
.66026 .70992 L
.65937 .70957 L
.6356 .69596 L
.623 .68491 L
.61095 .6713 L
.60446 .66026 L
.59429 .6356 L
.59046 .61095 L
.59305 .58629 L
.60248 .56164 L
.61095 .54822 L
.62143 .53698 L
.6356 .52612 L
.66026 .51476 L
.6696 .51233 L
F
0 g
.68491 .51034 m
.70957 .51143 L
.71461 .51233 L
.73422 .51824 L
.75888 .53165 L
.7659 .53698 L
.78353 .55603 L
.7873 .56164 L
.7987 .58629 L
.80331 .61095 L
.80179 .6356 L
.79384 .66026 L
.78353 .67777 L
.77745 .68491 L
.75888 .70079 L
.74427 .70957 L
.73422 .71281 L
.70957 .71765 L
.68491 .71671 L
.66026 .70992 L
.65937 .70957 L
.6356 .69596 L
.623 .68491 L
.61095 .6713 L
.60446 .66026 L
.59429 .6356 L
.59046 .61095 L
.59305 .58629 L
.60248 .56164 L
.61095 .54822 L
.62143 .53698 L
.6356 .52612 L
.66026 .51476 L
.6696 .51233 L
.68491 .51034 L
s
.812 0 1 r
.68491 .53074 m
.70957 .53006 L
.73422 .53597 L
.7372 .53698 L
.75888 .55092 L
.76971 .56164 L
.78353 .58382 L
.7844 .58629 L
.78997 .61095 L
.78853 .6356 L
.78353 .65204 L
.7794 .66026 L
.75888 .6847 L
.75866 .68491 L
.73422 .69851 L
.70957 .70376 L
.68491 .70192 L
.66026 .69275 L
.64825 .68491 L
.6356 .67322 L
.62664 .66026 L
.61623 .6356 L
.61355 .61095 L
.61841 .58629 L
.63185 .56164 L
.6356 .55712 L
.66026 .53855 L
.66345 .53698 L
F
0 g
.68491 .53074 m
.70957 .53006 L
.73422 .53597 L
.7372 .53698 L
.75888 .55092 L
.76971 .56164 L
.78353 .58382 L
.7844 .58629 L
.78997 .61095 L
.78853 .6356 L
.78353 .65204 L
.7794 .66026 L
.75888 .6847 L
.75866 .68491 L
.73422 .69851 L
.70957 .70376 L
.68491 .70192 L
.66026 .69275 L
.64825 .68491 L
.6356 .67322 L
.62664 .66026 L
.61623 .6356 L
.61355 .61095 L
.61841 .58629 L
.63185 .56164 L
.6356 .55712 L
.66026 .53855 L
.66345 .53698 L
.68491 .53074 L
s
1 0 .792 r
.66026 .55575 m
.68491 .5449 L
.70957 .54294 L
.73422 .54922 L
.75501 .56164 L
.75888 .56578 L
.77286 .58629 L
.77983 .61095 L
.77826 .6356 L
.7677 .66026 L
.75888 .67132 L
.74163 .68491 L
.73422 .68771 L
.70957 .69307 L
.68491 .69062 L
.66605 .68491 L
.66026 .67907 L
.64192 .66026 L
.6356 .64979 L
.63087 .6356 L
.62886 .61095 L
.63468 .58629 L
.6356 .58387 L
.65265 .56164 L
F
0 g
.66026 .55575 m
.68491 .5449 L
.70957 .54294 L
.73422 .54922 L
.75501 .56164 L
.75888 .56578 L
.77286 .58629 L
.77983 .61095 L
.77826 .6356 L
.7677 .66026 L
.75888 .67132 L
.74163 .68491 L
.73422 .68771 L
.70957 .69307 L
.68491 .69062 L
.66605 .68491 L
.66026 .67907 L
.64192 .66026 L
.6356 .64979 L
.63087 .6356 L
.62886 .61095 L
.63468 .58629 L
.6356 .58387 L
.65265 .56164 L
.66026 .55575 L
s
1 0 .396 r
.68491 .55552 m
.70957 .55289 L
.73422 .55888 L
.74072 .56164 L
.75888 .5785 L
.76366 .58629 L
.77139 .61095 L
.76987 .6356 L
.75888 .65945 L
.75824 .66026 L
.73422 .67887 L
.7132 .68491 L
.70957 .68524 L
.69985 .68491 L
.68491 .68178 L
.66026 .66743 L
.65382 .66026 L
.64134 .6356 L
.63923 .61095 L
.64712 .58629 L
.66026 .56904 L
.66706 .56164 L
F
0 g
.68491 .55552 m
.70957 .55289 L
.73422 .55888 L
.74072 .56164 L
.75888 .5785 L
.76366 .58629 L
.77139 .61095 L
.76987 .6356 L
.75888 .65945 L
.75824 .66026 L
.73422 .67887 L
.7132 .68491 L
.70957 .68524 L
.69985 .68491 L
.68491 .68178 L
.66026 .66743 L
.65382 .66026 L
.64134 .6356 L
.63923 .61095 L
.64712 .58629 L
.66026 .56904 L
.66706 .56164 L
.68491 .55552 L
s
1 0 0 r
.70957 .55989 m
.72134 .56164 L
.73422 .56683 L
.75611 .58629 L
.75888 .59083 L
.76487 .61095 L
.7634 .6356 L
.75888 .64816 L
.75024 .66026 L
.73422 .67148 L
.70957 .67559 L
.68491 .67415 L
.66291 .66026 L
.66026 .65711 L
.64989 .6356 L
.64804 .61095 L
.65645 .58629 L
.66026 .58059 L
.68491 .56341 L
.69046 .56164 L
F
0 g
.70957 .55989 m
.72134 .56164 L
.73422 .56683 L
.75611 .58629 L
.75888 .59083 L
.76487 .61095 L
.7634 .6356 L
.75888 .64816 L
.75024 .66026 L
.73422 .67148 L
.70957 .67559 L
.68491 .67415 L
.66291 .66026 L
.66026 .65711 L
.64989 .6356 L
.64804 .61095 L
.65645 .58629 L
.66026 .58059 L
.68491 .56341 L
.69046 .56164 L
.70957 .55989 L
s
0 1 .04 r
.98077 .81151 m
.96529 .83284 L
.95611 .84424 L
.94456 .8575 L
.93146 .87126 L
.9202 .88215 L
.9068 .89412 L
.89128 .9068 L
.88215 .91372 L
.8575 .93067 L
.85626 .93146 L
.83284 .94537 L
.81235 .95611 L
.80819 .95815 L
.78353 .96923 L
.75888 .97881 L
.75335 .98077 L
.98077 .98077 L
F
0 g
.98077 .81151 m
.96529 .83284 L
.95611 .84424 L
.94456 .8575 L
.93146 .87126 L
.9202 .88215 L
.9068 .89412 L
.89128 .9068 L
.88215 .91372 L
.8575 .93067 L
.85626 .93146 L
.83284 .94537 L
.81235 .95611 L
.80819 .95815 L
.78353 .96923 L
.75888 .97881 L
.75335 .98077 L
s
0 1 .04 r
.98077 .30011 m
.97595 .29043 L
.96305 .26578 L
.95611 .25316 L
.94928 .24112 L
.9346 .21647 L
.93146 .21139 L
.91895 .19181 L
.9068 .17374 L
.90223 .16716 L
.88427 .1425 L
.88215 .13972 L
.86484 .11785 L
.8575 .10906 L
.84362 .0932 L
.83284 .08153 L
.82019 .06854 L
.80819 .05691 L
.7939 .04389 L
.78353 .03498 L
.76379 .01923 L
.98077 .01923 L
F
0 g
.98077 .30011 m
.97595 .29043 L
.96305 .26578 L
.95611 .25316 L
.94928 .24112 L
.9346 .21647 L
.93146 .21139 L
.91895 .19181 L
.9068 .17374 L
.90223 .16716 L
.88427 .1425 L
.88215 .13972 L
.86484 .11785 L
.8575 .10906 L
.84362 .0932 L
.83284 .08153 L
.82019 .06854 L
.80819 .05691 L
.7939 .04389 L
.78353 .03498 L
.76379 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 576},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900002@2000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z000]oookJPWo001oOOoonfX3
o`00OgOooo]Z1Ol007mooookJP?o001oNooonfX9o`00O`Sooo]Z000]oookJPWo001oOOoonfX3o`00
OgKooo]Z1ol007mnoookJP?o001oNooonfX9o`00O`Sooo]Z000]oookJPCo001oP_oonfX3o`00OgKo
oo]Z0ol007l01?oonf[o001oo`00Ool007mnoookJP?o001oNooonfX4o`00O`gooo]Z000QoookJP[o
001o0ooonfX4o`00Og7ooo]Z2_l007l6oookJP?o001oMOoonfX3o`00O`?ooo]Z0ol007mmoookJP?o
001oO?oonfX4o`00O`cooo]Z000QoookJP[o001o1?oonfX5o`00Ofoooo]Z2_l007l6oookJP?o001o
MOoonfX3o`00O`?ooo]Z0ol007mmoookJP?o001oOOoonfX5o`00O`[ooo]Z000aoookJPCo001oO_oo
nfX3o`00OgGooo]Z0ol007l3oookJP?o001oOOoonfX3o`00Ogoooo]Z1?l007l9oookJP00<_oonfX3
o`00Ogkooo]Z0ol007meoookJP?o001o0ooonfX3o`00Oggooo]Z0ol007n0oookJP?o001o2OoonfX0
03?ooo]Z0ol007mmoookJP?o001oMOoonfX3o`00O`?ooo]Z0ol007mmoookJP?o001oPOoonfX3o`00
O`Sooo]Z000]oookJP?o001o0ooonfX3o`00Oggooo]Z0ol007meoookJP?o001o0ooonfX3o`00Oggo
oo]Z0ol007mkoookJP?o001o0ooonfX3o`00O`Sooo]Z000]oookJP?o001o0ooonfX3o`00Og[ooo]Z
1_l007meoookJP?o001o0ooonfX3o`00Og[ooo]Z1_l007mkoookJP?o001o0ooonfX3o`00O`Sooo]Z
000]oookJPCo001o0_oonfX3o`00Og[ooo]Z1_l007mfoookJP?o001o00Cooo]Zo`00Ool007oo001o
NooonfX6o`00Og_ooo]Z1?l007l2oookJP?o001o2?oonfX002kooo]Z1ol007mmoookJPCo001oM_oo
nfX7o`00Oggooo]Z1?l007mloookJPOo001o2OoonfX002oooo]Z1Ol007mooookJP?o001oMooonfX5
o`00Ogoooo]Z0ol007mmoookJPGo001o2_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;o
oo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooook
J_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z000QoookJ_oo0000ool0
000Po`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00Oooo]Z0Ol00001oookJP008OoonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP07oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP1ooookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003o
oo]ZoookJP1ooookJP03o`000?oonf[ooo]Z00Oooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP3ooookJ_oooo]Z7?oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z0?oooo]Zoooo
nfXLoookJP7o00000OoonfX000oooo]Z2Ol007l9oookJP03o`000?oonf[ooo]Z0?oooo]ZoooonfXL
oookJP7o00000OoonfX000oooo]Z2Ol007l9oookJP03o`000?oonf[ooo]Z0?oooo]ZoooonfXLoook
JP7o00000OoonfX000oooo]Z1?l007l>oookJP03o`000?oonf[ooo]Z0?oooo]ZoooonfXLoookJP7o
00000OoonfX000?ooo]Z2_l007l3oookJPCo001o3OoonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Z
7?oonfX1o`00007ooo]Z0003oookJP[o001o1?oonfX5o`00O`_ooo]Z1Ol0001joookJP;o0000oooo
nfXNoookJP;o0000N_oonfX4o`00007ooo]Z000CoookJPCo001o2_oonfX00ol0003ooo]ZoookJP08
oookJW?o0?l:00?o0000o`3oKol0ofl0ool0oflPo`3oK`03o`000?l0o`[o0?l:073o0?l:2_oonfX1
o`00007ooo]Z000DoookJP?o001o2_oonfX00ol0003ooo]ZoookJP08oookJW;o0?l:00?o0000o`3o
Kol0ofl0ool0oflRo`3oK`03o`000?l0o`[o0?l:06oo0?l:2_oonfX1o`00007ooo]Z000EoookJP?o
001o2OoonfX00ol0003ooo]ZoookJP08oookJW7o0?l:00?o0000o`3oKol0ofl0ool0oflTo`3oK`03
o`000?l0o`[o0?l:06ko0?l:2_oonfX1o`00007ooo]Z000?oookJP?o001o0ooonfX3o`00O`Wooo]Z
00?o0000oookJ_oonfX02?oonfY_o`3o2P;o0000ool0oflXo`3oK`03o`000?l0o`[o0?l:06go0?l:
2_oonfX1o`00007ooo]Z000?oookJP?o001o0ooonfX3o`00O`Wooo]Z00?o0000oookJ_oonfX02?oo
nfY^o`3o2P03o`000?l0ofoo0?m_0?oo0?m_:Ol0ofl00ol0003o0?l:o`3o2P1/o`3o2P[ooo]Z0Ol0
0001oookJP003ooonfX4o`00O`;ooo]Z0ol007l9oookJP03o`000?oonf[ooo]Z00Sooo]ZKOl0o`X0
0ol0003o0?m_o`3oK`27o`3oKa_o0000R?l0ofl00ol0003o0?l:o`3o2P1[o`3o2P[ooo]Z0Ol00001
oookJP004?oonfX7o`00O`[ooo]Z00?o0000oookJ_oonfX02?oonfY/o`3o2P03o`000?l0ofoo0?m_
07ko0?m_2_l0000Ko`3oe0[o0000Ool0ofl00ol0003o0?l:o`3o2P1Zo`3o2P[ooo]Z0Ol00001oook
JP004OoonfX5o`00O`_ooo]Z00?o0000oookJ_oonfX02?oonfY[o`3o2P03o`000?l0ofoo0?m_07So
0?m_1ol0000_o`3oe0Oo0000NOl0ofl00ol0003o0?l:o`3o2P1Yo`3o2P[ooo]Z0Ol00001oookJP00
8OoonfX00ol0003ooo]ZoookJP08oookJV[o0?l:00?o0000o`3oKol0ofl0Lol0ofl6o`0003go0?oD
1Ol0001eo`3oK`;o0000JOl0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oo
nfYYo`3o2P03o`000?l0ofoo0?m_077o0?m_0ol00018o`3oe0?o0000M?l0ofl00ol0003o0?l:o`3o
2P1Vo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJVSo0?l:00?o0000
o`3oKol0ofl0Kol0ofl3o`0004ko0?oD0ol0001bo`3oK`03o`000?l0o`[o0?l:06Go0?l:2_oonfX1
o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]ZIol0o`X00ol0003o0?m_o`3oK`1]o`3o
K`?o0000E?l0om@3o`00073o0?m_00?o0000o`3o2_l0o`X0I?l0o`X:oookJP7o00000OoonfX0027o
oo]Z00?o0000oookJ_oonfX02?oonfYVo`3o2P03o`000?l0ofoo0?m_06co0?m_0_l0001Jo`3oe0?o
0000K_l0ofl00ol0003o0?l:o`3o2P1So`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJVCo0?l:0_l0001]o`3oK`;o0000Gol0om@3o`0006co0?m_0_l0001So`3o2P[ooo]Z
0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJV?o0?l:00?o0000o`3oKol0ofl0J_l0
ofl3o`0006Co0?oD0ol0001[o`3oK`03o`000?l0o`[o0?l:063o0?l:2_oonfX1o`00007ooo]Z000Q
oookJP03o`000?oonf[ooo]Z00Sooo]ZH_l0o`X00ol0003o0?m_o`3oK`1Xo`3oK`?o0000J_l0om@3
o`0006Wo0?m_00?o0000o`3o2_l0o`X0Gol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oook
J_oonfX02?oonfYQo`3o2P03o`000?l0ofoo0?m_06Ko0?m_0ol0001`o`3oe0?o0000Iol0ofl00ol0
003o0?l:o`3o2P1No`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJV3o
0?l:00?o0000o`3oKol0ofl0I?l0ofl3o`0007Ko0?oD0_l0001Vo`3oK`03o`000?l0o`[o0?l:05go
0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]ZGol0o`X00ol0003o0?m_
o`3oK`1So`3oK`;o0000Nol0om@2o`0006Go0?m_00?o0000o`3o2_l0o`X0G?l0o`X:oookJP7o0000
0OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfYNo`3o2P03o`000?l0ofoo0?m_06;o0?m_0_l0
001oo`3oe0;o0000I?l0ofl00ol0003o0?l:o`3o2P1Ko`3o2P[ooo]Z0Ol00001oookJP008OoonfX0
0ol0003ooo]ZoookJP08oookJUgo0?l:00?o0000o`3oKol0ofl0HOl0ofl2o`0008?o0?oD0_l0001S
o`3oK`03o`000?l0o`[o0?l:05[o0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z
00Sooo]ZG?l0o`X00ol0003o0?m_o`3oK`1Po`3oK`;o0000Qol0om@00ol0003o0?m_o`3oK`1Qo`3o
K`03o`000?l0o`[o0?l:05Wo0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00So
oo]ZFol0o`X00ol0003o0?m_o`3oK`1Oo`3oK`;o0000R_l0om@2o`0006;o0?m_00?o0000o`3o2_l0
o`X0F?l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfYJo`3o2P03o`00
0?l0ofoo0?m_05ko0?m_0_l0002>o`3oe0;o0000HOl0ofl00ol0003o0?l:o`3o2P1Go`3o2P[ooo]Z
0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJUWo0?l:00?o0000o`3oKol0ofl0GOl0
ofl2o`0009;o0?oD0_l0001Po`3oK`03o`000?l0o`[o0?l:05Ko0?l:2_oonfX1o`00007ooo]Z000Q
oookJP?o00002?oonfYHo`3o2P03o`000?l0ofoo0?m_05go0?m_00?o0000o`3oe?l0om@0U?l0om@2
o`0005oo0?m_00?o0000o`3o2_l0o`X0EOl0o`X8oookJP?o00000OoonfX0027ooo]Z00?o0000oook
J_oonfX02?oonfYGo`3o2P03o`000?l0ofoo0?m_05co0?m_0_l0002Io`3oe0;o0000G_l0ofl00ol0
003o0?l:o`3o2P1Do`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJUKo
0?l:00?o0000o`3oKol0ofl0Fol0ofl2o`0009go0?oD0_l0001Mo`3oK`03o`000?l0o`[o0?l:05?o
0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]ZEOl0o`X00ol0003o0?m_
o`3oK`1Ko`3oK`03o`000?l0omCo0?oD09oo0?oD00?o0000o`3oKol0ofl0Fol0ofl00ol0003o0?l:
o`3o2P1Bo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJUCo0?l:00?o
0000o`3oKol0ofl0F_l0ofl2o`000:?o0?oD0_l0001Lo`3oK`03o`000?l0o`[o0?l:057o0?l:2_oo
nfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]ZDol0o`X00ol0003o0?m_o`3oK`1I
o`3oK`;o0000Yol0om@2o`0005_o0?m_00?o0000o`3o2_l0o`X0D?l0o`X:oookJP7o00000OoonfX0
027ooo]Z00?o0000oookJ_oonfX02?oonfYBo`3o2P03o`000?l0ofoo0?m_05Wo0?m_00?o0000o`3o
e?l0om@0ZOl0om@00ol0003o0?m_o`3oK`1Io`3oK`03o`000?l0o`[o0?l:04oo0?l:2_oonfX1o`00
007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]ZDOl0o`X00ol0003o0?m_o`3oK`1Ho`3oK`;o
0000[Ol0om@2o`0005[o0?m_00?o0000o`3o2_l0o`X0C_l0o`X:oookJP7o00000OoonfX0027ooo]Z
00?o0000oookJ_oonfX02?oonfY@o`3o2P03o`000?l0ofoo0?m_05So0?m_00?o0000o`3oe?l0om@0
[ol0om@00ol0003o0?m_o`3oK`1Ho`3oK`03o`000?l0o`[o0?l:04go0?l:2_oonfX1o`00007ooo]Z
000QoookJP03o`000?oonf[ooo]Z00Sooo]ZCol0o`X00ol0003o0?m_o`3oK`1Go`3oK`;o0000/ol0
om@00ol0003o0?m_o`3oK`1Ho`3oK`03o`000?l0o`[o0?l:04co0?l:2_oonfX1o`00007ooo]Z000Q
oookJP03o`000?oonf[ooo]Z00Sooo]ZC_l0o`X00ol0003o0?m_o`3oK`1Go`3oK`03o`000?l0omCo
0?oD0;Co0?oD0_l0001Io`3oK`03o`000?l0o`[o0?l:04_o0?l:2_oonfX1o`00007ooo]Z000Qoook
JP03o`000?oonf[ooo]Z00Sooo]ZCOl0o`X00ol0003o0?m_o`3oK`1Go`3oK`03o`000?l0omCo0?oD
053o0?oD5Ol0001Bo`3oe003o`000?l0ofoo0?m_05Oo0?m_00?o0000o`3o2_l0o`X0B_l0o`X:oook
JP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfY<o`3o2P03o`000?l0ofoo0?m_05Ko
0?m_0_l0001<o`3oe0Oo00005Ol0aOl7o`0004co0?oD00?o0000o`3oKol0ofl0Eol0ofl00ol0003o
0?l:o`3o2P19o`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJT_o0?l:
00?o0000o`3oKol0ofl0E_l0ofl00ol0003o0?oDo`3oe016o`3oe0Ko00008ol0aOl7o`0004Ko0?oD
00?o0000o`3oKol0ofl0Eol0ofl00ol0003o0?l:o`3o2P18o`3o2P[ooo]Z0Ol00001oookJP008Ooo
nfX00ol0003ooo]ZoookJP08oookJT[o0?l:00?o0000o`3oKol0ofl0E_l0ofl00ol0003o0?oDo`3o
e011o`3oe0Ko0000<?l0aOl5o`0004;o0?oD0_l0001Ho`3oK`03o`000?l0o`[o0?l:04Oo0?l:2_oo
nfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]ZB_l0o`X00ol0003o0?m_o`3oK`1E
o`3oK`03o`000?l0omCo0?oD03oo0?oD0ol0000ko`35o`?o0000@Ol0om@00ol0003o0?m_o`3oK`1E
o`3oK`03o`000?l0o`[o0?l:04Oo0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z
00Sooo]ZBOl0o`X00ol0003o0?m_o`3oK`1Eo`3oK`03o`000?l0omCo0?oD03go0?oD0ol00011o`35
o`;o0000@?l0om@00ol0003o0?m_o`3oK`1Eo`3oK`03o`000?l0o`[o0?l:04Ko0?l:2_oonfX1o`00
007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]ZB?l0o`X00ol0003o0?m_o`3oK`1Do`3oK`;o
0000?_l0om@2o`0004Ko0<Go0_l0000oo`3oe003o`000?l0ofoo0?m_05Go0?m_00?o0000o`3o2_l0
o`X0AOl0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfY7o`3o2P03o`00
0?l0ofoo0?m_05Co0?m_00?o0000o`3oe?l0om@0??l0om@2o`0004[o0<Go0_l0000no`3oe003o`00
0?l0ofoo0?m_05Go0?m_00?o0000o`3o2_l0o`X0A?l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o
0000oookJ_oonfX02?oonfY6o`3o2P03o`000?l0ofoo0?m_05Co0?m_00?o0000o`3oe?l0om@0>_l0
om@3o`0004ko0<Go0ol0000lo`3oe003o`000?l0ofoo0?m_05Go0?m_00?o0000o`3o2_l0o`X0@ol0
o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfY5o`3o2P03o`000?l0ofoo
0?m_05Co0?m_00?o0000o`3oe?l0om@0>Ol0om@2o`0005Co0<Go0_l0000ko`3oe003o`000?l0ofoo
0?m_05Co0?m_00?o0000o`3o2_l0o`X0@ol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oook
J_oonfX02?oonfY4o`3o2P03o`000?l0ofoo0?m_05Co0?m_00?o0000o`3oe?l0om@0>?l0om@2o`00
05So0<Go0_l0000jo`3oe003o`000?l0ofoo0?m_05Co0?m_00?o0000o`3o2_l0o`X0@_l0o`X:oook
JP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfY3o`3o2P03o`000?l0ofoo0?m_05Co
0?m_00?o0000o`3oe?l0om@0=ol0om@2o`0005co0<Go0_l0000io`3oe003o`000?l0ofoo0?m_05Co
0?m_00?o0000o`3o2_l0o`X0@Ol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX0
2?oonfY2o`3o2P03o`000?l0ofoo0?m_05Co0?m_00?o0000o`3oe?l0om@0=_l0om@2o`00063o0<Go
0_l0000ho`3oe003o`000?l0ofoo0?m_05Co0?m_00?o0000o`3o2_l0o`X0@?l0o`X:oookJP7o0000
0OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfY2o`3o2P03o`000?l0ofoo0?m_05?o0?m_00?o
0000o`3oe?l0om@0=Ol0om@2o`0006Co0<Go0_l0000go`3oe003o`000?l0ofoo0?m_05?o0?m_00?o
0000o`3o2_l0o`X0@?l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfY1
o`3o2P03o`000?l0ofoo0?m_05?o0?m_00?o0000o`3oe?l0om@0=Ol0om@00ol0003o0<Goo`35o`1V
o`35o`03o`000?l0omCo0?oD03Go0?oD00?o0000o`3oKol0ofl0Dol0ofl00ol0003o0?l:o`3o2P0o
o`3o2P[ooo]Z0Ol00001oookJP008OoonfX3o`0000Sooo]Z@?l0o`X00ol0003o0?m_o`3oK`1Co`3o
K`03o`000?l0omCo0?oD03Co0?oD0_l0001Zo`35o`;o0000=_l0om@00ol0003o0?m_o`3oK`1Co`3o
K`03o`000?l0o`[o0?l:03ko0?l:2?oonfX3o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00So
oo]Z?ol0o`X00ol0003o0?m_o`3oK`1Co`3oK`03o`000?l0omCo0?oD03?o0?oD0_l0001^o`35o`;o
0000=Ol0om@00ol0003o0?m_o`3oK`1Co`3oK`03o`000?l0o`[o0?l:03go0?l:2_oonfX1o`00007o
oo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z?_l0o`X00ol0003o0?m_o`3oK`1Co`3oK`03o`00
0?l0omCo0?oD03;o0?oD0_l0001bo`35o`?o0000<ol0om@00ol0003o0?m_o`3oK`1Co`3oK`03o`00
0?l0o`[o0?l:03co0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z?_l0
o`X00ol0003o0?m_o`3oK`1Bo`3oK`03o`000?l0omCo0?oD037o0?oD0_l0001go`35o`;o0000<_l0
om@00ol0003o0?m_o`3oK`1Bo`3oK`03o`000?l0o`[o0?l:03co0?l:2_oonfX1o`00007ooo]Z000Q
oookJP03o`000?oonf[ooo]Z00Sooo]Z?Ol0o`X00ol0003o0?m_o`3oK`1Bo`3oK`03o`000?l0omCo
0?oD037o0?oD00?o0000o`35ool0aOl0NOl0aOl00ol0003o0?oDo`3oe00`o`3oe003o`000?l0ofoo
0?m_05;o0?m_00?o0000o`3o2_l0o`X0>ol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oook
J_oonfX02?oonfXlo`3o2P03o`000?l0ofoo0?m_05?o0?m_00?o0000o`3oe?l0om@0<?l0om@00ol0
003o0<Goo`35o`0bo`35oaGo0000=?l0aOl00ol0003o0?oDo`3oe00`o`3oe003o`000?l0ofoo0?m_
05;o0?m_00?o0000o`3o2_l0o`X0>_l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oo
nfX02?oonfXko`3o2P03o`000?l0ofoo0?m_05?o0?m_00?o0000o`3oe?l0om@0<?l0om@00ol0003o
0<Goo`35o`0/o`35o`Oo00005Ol0H?l7o`0002ko0<Go00?o0000o`3oe?l0om@0<?l0om@00ol0003o
0?m_o`3oK`1Bo`3oK`03o`000?l0o`[o0?l:03Wo0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`00
0?oonf[ooo]Z00Sooo]Z>_l0o`X00ol0003o0?m_o`3oK`1Co`3oK`03o`000?l0omCo0?oD02oo0?oD
0_l0000[o`35o`Co00008ol0H?l4o`0002_o0<Go00?o0000o`3oe?l0om@0<?l0om@00ol0003o0?m_
o`3oK`1Bo`3oK`03o`000?l0o`[o0?l:03So0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oo
nf[ooo]Z00Sooo]Z>Ol0o`X00ol0003o0?m_o`3oK`1Co`3oK`03o`000?l0omCo0?oD02oo0?oD00?o
0000o`35ool0aOl0:?l0aOl3o`0002_o063o0ol0000Yo`35o`;o0000<Ol0om@00ol0003o0?m_o`3o
K`1Bo`3oK`03o`000?l0o`[o0?l:03Oo0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[o
oo]Z00Sooo]Z>Ol0o`X00ol0003o0?m_o`3oK`1Bo`3oK`03o`000?l0omCo0?oD02oo0?oD00?o0000
o`35ool0aOl09_l0aOl3o`00037o063o0ol0000Xo`35o`03o`000?l0omCo0?oD02oo0?oD00?o0000
o`3oKol0ofl0D_l0ofl00ol0003o0?l:o`3o2P0fo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0
003ooo]ZoookJP08oookJSSo0?l:00?o0000o`3oKol0ofl0D_l0ofl00ol0003o0?oDo`3oe00^o`3o
e0;o00009_l0aOl3o`0003Oo063o0_l0000Wo`35o`03o`000?l0omCo0?oD02oo0?oD00?o0000o`3o
Kol0ofl0D_l0ofl00ol0003o0?l:o`3o2P0eo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003o
oo]ZoookJP08oookJSOo0?l:00?o0000o`3oKol0ofl0D_l0ofl00ol0003o0?oDo`3oe00^o`3oe003
o`000?l0aOoo0<Go02?o0<Go0ol0000lo`1Po`?o00009Ol0aOl00ol0003o0?oDo`3oe00_o`3oe003
o`000?l0ofoo0?m_05;o0?m_00?o0000o`3o2_l0o`X0=?l0o`X:oookJP7o00000OoonfX0027ooo]Z
00?o0000oookJ_oonfX02?oonfXfo`3o2P03o`000?l0ofoo0?m_05;o0?m_00?o0000o`3oe?l0om@0
;_l0om@00ol0003o0<Goo`35o`0Ro`35o`;o0000@_l0H?l2o`0002Co0<Go00?o0000o`3oe?l0om@0
;ol0om@00ol0003o0?m_o`3oK`1Bo`3oK`03o`000?l0o`[o0?l:03?o0?l:2_oonfX1o`00007ooo]Z
000QoookJP03o`000?oonf[ooo]Z00Sooo]Z=Ol0o`X00ol0003o0?m_o`3oK`1Bo`3oK`03o`000?l0
omCo0?oD02ko0?oD00?o0000o`35ool0aOl08Ol0aOl2o`0004Ko063o0ol0000Ro`35o`03o`000?l0
omCo0?oD02oo0?oD00?o0000o`3oKol0ofl0D_l0ofl00ol0003o0?l:o`3o2P0bo`3o2P[ooo]Z0Ol0
0001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJSGo0?l:00?o0000o`3oKol0ofl0DOl0ofl0
0ol0003o0?oDo`3oe00^o`3oe003o`000?l0aOoo0<Go023o0<Go0_l0001;o`1Po`;o00008Ol0aOl2
o`00033o0?oD00?o0000o`3oKol0ofl0DOl0ofl00ol0003o0?l:o`3o2P0bo`3o2P[ooo]Z0Ol00001
oookJP008OoonfX00ol0003ooo]ZoookJP08oookJSCo0?l:00?o0000o`3oKol0ofl0DOl0ofl00ol0
003o0?oDo`3oe00^o`3oe003o`000?l0aOoo0<Go01oo0<Go0_l0001?o`1Po`;o00008Ol0aOl00ol0
003o0?oDo`3oe00^o`3oe003o`000?l0ofoo0?m_057o0?m_00?o0000o`3o2_l0o`X0<Ol0o`X:oook
JP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXdo`3o2P03o`000?l0ofoo0?m_053o
0?m_00?o0000o`3oe?l0om@0;ol0om@00ol0003o0<Goo`35o`0Mo`35o`;o0000Dol0H?l00ol0003o
0<Goo`35o`0No`35o`03o`000?l0omCo0?oD02oo0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o
0?l:o`3o2P0ao`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJS?o0?l:
00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00_o`3oe003o`000?l0aOoo0<Go01go0<Go
00?o0000o`1Pool0H?l0E?l0H?l2o`0001oo0<Go00?o0000o`3oe?l0om@0;ol0om@00ol0003o0?m_
o`3oK`1@o`3oK`03o`000?l0o`[o0?l:033o0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oo
nf[ooo]Z00Sooo]Z<_l0o`X00ol0003o0?m_o`3oK`1@o`3oK`03o`000?l0omCo0?oD02oo0?oD00?o
0000o`35ool0aOl07?l0aOl2o`0002?o063o4_l0000To`1Po`03o`000?l0aOoo0<Go01go0<Go00?o
0000o`3oe?l0om@0;ol0om@00ol0003o0?m_o`3oK`1@o`3oK`03o`000?l0o`[o0?l:02oo0?l:2_oo
nfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z<Ol0o`X00ol0003o0?m_o`3oK`1A
o`3oK`03o`000?l0omCo0?oD02ko0?oD00?o0000o`35ool0aOl06ol0aOl2o`00023o063o1Ol0000B
o`D0o`Go00008?l0H?l2o`0001ko0<Go00?o0000o`3oe?l0om@0;_l0om@00ol0003o0?m_o`3oK`1@
o`3oK`03o`000?l0o`[o0?l:02oo0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z
00Sooo]Z<Ol0o`X00ol0003o0?m_o`3oK`1@o`3oK`03o`000?l0omCo0?oD02ko0?oD00?o0000o`35
ool0aOl06ol0aOl00ol0003o063oo`1Po`0Lo`1Po`Co00007?l50?l5o`0001go063o00?o0000o`35
ool0aOl07?l0aOl00ol0003o0?oDo`3oe00^o`3oe003o`000?l0ofoo0?m_053o0?m_00?o0000o`3o
2_l0o`X0;_l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfX`o`3o2P03
o`000?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0;_l0om@00ol0003o0<Goo`35o`0Ko`35o`03
o`000?l0H?oo063o01[o063o0ol0000Uo`D0o`?o00006ol0H?l00ol0003o0<Goo`35o`0Lo`35o`03
o`000?l0omCo0?oD02ko0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?l:o`3o2P0]o`3o2P[o
oo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJRoo0?l:00?o0000o`3oKol0ofl0
D?l0ofl00ol0003o0?oDo`3oe00^o`3oe003o`000?l0aOoo0<Go01_o0<Go00?o0000o`1Pool0H?l0
6?l0H?l3o`0002_o1@3o0_l0000Jo`1Po`;o00007Ol0aOl00ol0003o0?oDo`3oe00]o`3oe003o`00
0?l0ofoo0?m_057o0?m_00?o0000o`3o2_l0o`X0;?l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o
0000oookJ_oonfX02?oonfX^o`3o2P03o`000?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0;_l0
om@00ol0003o0<Goo`35o`0Jo`35o`;o00006Ol0H?l2o`00033o1@3o0_l0000Jo`1Po`03o`000?l0
aOoo0<Go01_o0<Go00?o0000o`3oe?l0om@0;Ol0om@00ol0003o0?m_o`3oK`1@o`3oK`03o`000?l0
o`[o0?l:02co0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z;Ol0o`X0
0ol0003o0?m_o`3oK`1Ao`3oK`03o`000?l0omCo0?oD02go0?oD00?o0000o`35ool0aOl06_l0aOl0
0ol0003o063oo`1Po`0Go`1Po`;o0000=?l50?l3o`0001So063o00?o0000o`35ool0aOl06ol0aOl0
0ol0003o0?oDo`3oe00]o`3oe003o`000?l0ofoo0?m_053o0?m_00?o0000o`3o2_l0o`X0:ol0o`X:
oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfX]o`3o2P03o`000?l0ofoo0?m_
053o0?m_00?o0000o`3oe?l0om@0;Ol0om@00ol0003o0<Goo`35o`0Jo`35o`03o`000?l0H?oo063o
01Go063o0ol0000io`D0o`;o00005ol0H?l2o`0001co0<Go00?o0000o`3oe?l0om@0;Ol0om@00ol0
003o0?m_o`3oK`1@o`3oK`03o`000?l0o`[o0?l:02[o0?l:2_oonfX1o`00007ooo]Z000QoookJP?o
00002?oonfX/o`3o2P03o`000?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0;Ol0om@00ol0003o
0<Goo`35o`0Jo`35o`03o`000?l0H?oo063o01Co063o0_l0000no`D0o`;o00005ol0H?l00ol0003o
0<Goo`35o`0Jo`35o`03o`000?l0omCo0?oD02co0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o
0?l:o`3o2P0Zo`3o2PSooo]Z0ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJR_o0?l:
00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00]o`3oe003o`000?l0aOoo0<Go01[o0<Go
00?o0000o`1Pool0H?l04ol0H?l2o`0001So1@3o4ol0000Go`D0o`;o00005_l0H?l00ol0003o0<Go
o`35o`0Jo`35o`03o`000?l0omCo0?oD02co0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?l:
o`3o2P0Yo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJR[o0?l:00?o
0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00/o`3oe0;o00007?l0aOl00ol0003o063oo`1P
o`0Bo`1Po`;o00005ol50?l3o`0001?oJP3o1?l0000Eo`D0o`;o00005Ol0H?l00ol0003o0<Goo`35
o`0Jo`35o`03o`000?l0omCo0?oD02co0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?l:o`3o
2P0Xo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJR[o0?l:00?o0000
o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00/o`3oe003o`000?l0aOoo0<Go01[o0<Go00?o0000
o`1Pool0H?l04_l0H?l00ol0003o1@3oo`D0o`0Do`D0o`?o00006_mZ0?l3o`0001Co1@3o00?o0000
o`1Pool0H?l04ol0H?l00ol0003o0<Goo`35o`0Io`35o`03o`000?l0omCo0?oD02co0?oD00?o0000
o`3oKol0ofl0D?l0ofl00ol0003o0?l:o`3o2P0Xo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0
003ooo]ZoookJP08oookJRWo0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00/o`3o
e003o`000?l0aOoo0<Go01[o0<Go00?o0000o`1Pool0H?l04_l0H?l00ol0003o1@3oo`D0o`0Bo`D0
o`?o00008?mZ0?l3o`0001;o1@3o00?o0000o`1Pool0H?l04ol0H?l00ol0003o0<Goo`35o`0Io`35
o`03o`000?l0omCo0?oD02co0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?l:o`3o2P0Wo`3o
2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJRWo0?l:00?o0000o`3oKol0
ofl0Col0ofl00ol0003o0?oDo`3oe00/o`3oe003o`000?l0aOoo0<Go01_o0<Go00?o0000o`1Pool0
H?l04Ol0H?l00ol0003o1@3oo`D0o`0@o`D0o`?o00009_mZ0?l2o`00017o1@3o00?o0000o`1Pool0
H?l04_l0H?l00ol0003o0<Goo`35o`0Jo`35o`03o`000?l0omCo0?oD02co0?oD00?o0000o`3oKol0
ofl0D?l0ofl00ol0003o0?l:o`3o2P0Vo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJRSo0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00/o`3oe003o`00
0?l0aOoo0<Go01[o0<Go00?o0000o`1Pool0H?l04?l0H?l2o`00017o1@3o0_l0000[ofX0o`03o`00
0?l50?oo1@3o00oo1@3o0_l0000Co`1Po`03o`000?l0aOoo0<Go01[o0<Go00?o0000o`3oe?l0om@0
;?l0om@00ol0003o0?m_o`3oK`1@o`3oK`03o`000?l0o`[o0?l:02Go0?l:2_oonfX1o`00007ooo]Z
000QoookJP03o`000?oonf[ooo]Z00Sooo]Z:?l0o`X00ol0003o0?m_o`3oK`1?o`3oK`03o`000?l0
omCo0?oD02co0?oD00?o0000o`35ool0aOl06_l0aOl00ol0003o063oo`1Po`0@o`1Po`03o`000?l5
0?oo1@3o013o1@3o00?o0000ofX0oomZ0?l0;?mZ0?l2o`00017o1@3o00?o0000o`1Pool0H?l04Ol0
H?l00ol0003o0<Goo`35o`0Io`35o`03o`000?l0omCo0?oD02co0?oD00?o0000o`3oKol0ofl0D?l0
ofl00ol0003o0?l:o`3o2P0Uo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08
oookJROo0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00[o`3oe003o`000?l0aOoo
0<Go01[o0<Go00?o0000o`1Pool0H?l04?l0H?l00ol0003o1@3oo`D0o`0?o`D0o`;o0000<OmZ0?l2
o`00013o1@3o00?o0000o`1Pool0H?l04Ol0H?l00ol0003o0<Goo`35o`0Io`35o`03o`000?l0omCo
0?oD02co0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?l:o`3o2P0To`3o2P[ooo]Z0Ol00001
oookJP008OoonfX00ol0003ooo]ZoookJP08oookJRKo0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0
003o0?oDo`3oe00/o`3oe003o`000?l0aOoo0<Go01[o0<Go00?o0000o`1Pool0H?l03ol0H?l00ol0
003o1@3oo`D0o`0>o`D0o`;o00004OmZ0?lBo`0001;oJP3o00?o0000o`D0ool50?l03_l50?l00ol0
003o063oo`1Po`0@o`1Po`03o`000?l0aOoo0<Go01[o0<Go00?o0000o`3oe?l0om@0;?l0om@00ol0
003o0?m_o`3oK`1@o`3oK`03o`000?l0o`[o0?l:02?o0?l:2_oonfX1o`00007ooo]Z000QoookJP03
o`000?oonf[ooo]Z00Sooo]Z9_l0o`X00ol0003o0?m_o`3oK`1?o`3oK`03o`000?l0omCo0?oD02co
0?oD00?o0000o`35ool0aOl06_l0aOl00ol0003o063oo`1Po`0?o`1Po`03o`000?l50?oo1@3o00go
1@3o0_l0000@ofX0o`?o00004_o?0?l3o`00013oJP3o0_l0000?o`D0o`03o`000?l0H?oo063o013o
063o00?o0000o`35ool0aOl06Ol0aOl00ol0003o0?oDo`3oe00]o`3oe003o`000?l0ofoo0?m_04oo
0?m_00?o0000o`3o2_l0o`X08ol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX0
2?oonfXUo`3o2P03o`000?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0;?l0om@00ol0003o0<Go
o`35o`0Io`35o`03o`000?l0H?oo063o00oo063o00?o0000o`D0ool50?l03Ol50?l00ol0003oJP3o
ofX0o`0=ofX0o`?o00006?o?0?l4o`0000koJP3o0_l0000>o`D0o`03o`000?l0H?oo063o013o063o
00?o0000o`35ool0aOl06Ol0aOl00ol0003o0?oDo`3oe00/o`3oe003o`000?l0ofoo0?m_053o0?m_
00?o0000o`3o2_l0o`X08_l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oo
nfXTo`3o2P03o`000?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0;?l0om@00ol0003o0<Goo`35
o`0Io`35o`03o`000?l0H?oo063o013o063o00?o0000o`D0ool50?l02ol50?l2o`0000goJP3o0ol0
000Ooll0o`?o00003OmZ0?l00ol0003o1@3oo`D0o`0<o`D0o`03o`000?l0H?oo063o013o063o00?o
0000o`35ool0aOl06Ol0aOl00ol0003o0?oDo`3oe00/o`3oe003o`000?l0ofoo0?m_053o0?m_00?o
0000o`3o2_l0o`X08Ol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXS
o`3o2P03o`000?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0;?l0om@00ol0003o0<Goo`35o`0J
o`35o`03o`000?l0H?oo063o00oo063o00?o0000o`D0ool50?l02ol50?l00ol0003oJP3oofX0o`0:
ofX0o`?o00009Oo?0?l3o`0000_oJP3o0_l0000=o`D0o`03o`000?l0H?oo063o00oo063o00?o0000
o`35ool0aOl06_l0aOl00ol0003o0?oDo`3oe00/o`3oe003o`000?l0ofoo0?m_053o0?m_00?o0000
o`3o2_l0o`X08?l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXSo`3o
2P03o`000?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0;?l0om@00ol0003o0<Goo`35o`0Io`35
o`03o`000?l0H?oo063o00oo063o00?o0000o`D0ool50?l02ol50?l00ol0003oJP3oofX0o`09ofX0
o`;o00003Oo?0?lAo`0000goc`3o0_l0000;ofX0o`03o`000?l50?oo1@3o00_o1@3o00?o0000o`1P
ool0H?l03ol0H?l00ol0003o0<Goo`35o`0Io`35o`03o`000?l0omCo0?oD02co0?oD00?o0000o`3o
Kol0ofl0D?l0ofl00ol0003o0?l:o`3o2P0Po`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003o
oo]ZoookJP08oookJR;o0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00/o`3oe003
o`000?l0aOoo0<Go01Wo0<Go00?o0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`0;o`D0o`03
o`000?mZ0?ooJP3o00SoJP3o0_l0000<oll0o`?o00004Ooo0<X3o`0000coc`3o00?o0000ofX0oomZ
0?l02OmZ0?l00ol0003o1@3oo`D0o`0;o`D0o`03o`000?l0H?oo063o00oo063o00?o0000o`35ool0
aOl06Ol0aOl00ol0003o0?oDo`3oe00/o`3oe003o`000?l0ofoo0?m_053o0?m_00?o0000o`3o2_l0
o`X07ol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXQo`3o2P03o`00
0?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0;?l0om@00ol0003o0<Goo`35o`0Io`35o`03o`00
0?l0H?oo063o00oo063o00?o0000o`D0ool50?l02ol50?l00ol0003oJP3oofX0o`07ofX0o`;o0000
2oo?0?l3o`0001Ooo`3:0ol0000:oll0o`;o00002_mZ0?l00ol0003o1@3oo`D0o`0;o`D0o`03o`00
0?l0H?oo063o00oo063o00?o0000o`35ool0aOl06Ol0aOl00ol0003o0?oDo`3oe00/o`3oe003o`00
0?l0ofoo0?m_053o0?m_00?o0000o`3o2_l0o`X07_l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o
0000oookJ_oonfX02?oonfXQo`3o2P03o`000?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0;?l0
om@00ol0003o0<Goo`35o`0Io`35o`03o`000?l0H?oo063o00oo063o00?o0000o`D0ool50?l02ol5
0?l00ol0003oJP3oofX0o`06ofX0o`03o`000?o?0?ooc`3o00Soc`3o0ol0000Mool0bP?o00002Oo?
0?l00ol0003oJP3oofX0o`07ofX0o`03o`000?l50?oo1@3o00_o1@3o00?o0000o`1Pool0H?l03ol0
H?l00ol0003o0<Goo`35o`0Io`35o`03o`000?l0omCo0?oD02co0?oD00?o0000o`3oKol0ofl0D?l0
ofl00ol0003o0?l:o`3o2P0No`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08
oookJR3o0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00/o`3oe003o`000?l0aOoo
0<Go01Wo0<Go00?o0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`0;o`D0o`03o`000?mZ0?oo
JP3o00KoJP3o00?o0000oll0ooo?0?l01oo?0?l2o`0000Woo`3:4?l0000:ool0bP;o00002?o?0?l0
0ol0003oJP3oofX0o`07ofX0o`03o`000?l50?oo1@3o00_o1@3o00?o0000o`1Pool0H?l03ol0H?l0
0ol0003o0<Goo`35o`0Io`35o`03o`000?l0omCo0?oD02co0?oD00?o0000o`3oKol0ofl0D?l0ofl0
0ol0003o0?l:o`3o2P0Mo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oook
JQoo0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00/o`3oe003o`000?l0aOoo0<Go
01Wo0<Go00?o0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`0;o`D0o`03o`000?mZ0?ooJP3o
00GoJP3o0_l00008oll0o`;o00002Ooo0<X2o`00013oo`1U0ol00009ool0bP;o00001oo?0?l2o`00
00SoJP3o00?o0000o`D0ool50?l02ol50?l00ol0003o063oo`1Po`0?o`1Po`03o`000?l0aOoo0<Go
01Wo0<Go00?o0000o`3oe?l0om@0;?l0om@00ol0003o0?m_o`3oK`1@o`3oK`03o`000?l0o`[o0?l:
01co0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z7ol0o`X00ol0003o
0?m_o`3oK`1@o`3oK`03o`000?l0omCo0?oD02co0?oD00?o0000o`35ool0aOl06?l0aOl00ol0003o
063oo`1Po`0@o`1Po`03o`000?l50?oo1@3o00[o1@3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003o
c`3ooll0o`07oll0o`03o`000?oo0<[oo`3:00Ooo`3:0_l0000Eool0I@;o00002Ooo0<X00ol0003o
c`3ooll0o`06oll0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000o`D0ool50?l02_l50?l00ol0003o
063oo`1Po`0?o`1Po`03o`000?l0aOoo0<Go01Wo0<Go00?o0000o`3oe?l0om@0;?l0om@00ol0003o
0?m_o`3oK`1@o`3oK`03o`000?l0o`[o0?l:01co0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`00
0?oonf[ooo]Z00Sooo]Z7_l0o`X00ol0003o0?m_o`3oK`1@o`3oK`03o`000?l0omCo0?oD02co0?oD
00?o0000o`35ool0aOl06?l0aOl00ol0003o063oo`1Po`0@o`1Po`03o`000?l50?oo1@3o00[o1@3o
00?o0000ofX0oomZ0?l01OmZ0?l00ol0003oc`3ooll0o`07oll0o`03o`000?oo0<[oo`3:00Goo`3:
0ol0000Iool0I@;o00002?oo0<X00ol0003oc`3ooll0o`06oll0o`03o`000?mZ0?ooJP3o00KoJP3o
00?o0000o`D0ool50?l02_l50?l00ol0003o063oo`1Po`0?o`1Po`03o`000?l0aOoo0<Go01Wo0<Go
00?o0000o`3oe?l0om@0;?l0om@00ol0003o0?m_o`3oK`1@o`3oK`03o`000?l0o`[o0?l:01_o0?l:
2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z7Ol0o`X00ol0003o0?m_o`3o
K`1Ao`3oK`03o`000?l0omCo0?oD02co0?oD00?o0000o`35ool0aOl05ol0aOl00ol0003o063oo`1P
o`0@o`1Po`03o`000?l50?oo1@3o00[o1@3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003oc`3ooll0
o`07oll0o`03o`000?oo0<[oo`3:00Coo`3:0_l00007ool0IA3o00001ooo06D3o`0000Koo`3:00?o
0000oll0ooo?0?l01_o?0?l00ol0003oJP3oofX0o`06ofX0o`03o`000?l50?oo1@3o00Wo1@3o00?o
0000o`1Pool0H?l04?l0H?l00ol0003o0<Goo`35o`0Ho`35o`03o`000?l0omCo0?oD02co0?oD00?o
0000o`3oKol0ofl0D?l0ofl00ol0003o0?l:o`3o2P0Ko`3o2P[ooo]Z0Ol00001oookJP008OoonfX0
0ol0003ooo]ZoookJP08oookJQco0?l:00?o0000o`3oKol0ofl0DOl0ofl00ol0003o0?oDo`3oe00/
o`3oe003o`000?l0aOoo0<Go01So0<Go00?o0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`0:
o`D0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000oll0ooo?0?l01_o?0?l00ol0003oo`3:ool0bP03
ool0bP;o00001ooo06D2o`00013oo`000ol00007ool0I@;o00001Ooo0<X00ol0003oc`3ooll0o`05
oll0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000o`D0ool50?l02_l50?l00ol0003o063oo`1Po`0?
o`1Po`03o`000?l0aOoo0<Go01Wo0<Go00?o0000o`3oe?l0om@0;?l0om@00ol0003o0?m_o`3oK`1@
o`3oK`03o`000?l0o`[o0?l:01[o0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z
00Sooo]Z7?l0o`X00ol0003o0?m_o`3oK`1@o`3oK`03o`000?l0omCo0?oD02co0?oD00?o0000o`35
ool0aOl06?l0aOl00ol0003o063oo`1Po`0@o`1Po`03o`000?l50?oo1@3o00Wo1@3o00?o0000ofX0
oomZ0?l01_mZ0?l00ol0003oc`3ooll0o`05oll0o`;o00001?oo0<X2o`0000Ooo`1U0_l0000Eool0
00;o00001ooo06D2o`0000Coo`3:0_l00006oll0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000o`D0
ool50?l02_l50?l00ol0003o063oo`1Po`0?o`1Po`03o`000?l0aOoo0<Go01So0<Go00?o0000o`3o
e?l0om@0;Ol0om@00ol0003o0?m_o`3oK`1@o`3oK`03o`000?l0o`[o0?l:01Wo0?l:2_oonfX1o`00
007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z6ol0o`X00ol0003o0?m_o`3oK`1Ao`3oK`03
o`000?l0omCo0?oD02co0?oD00?o0000o`35ool0aOl06?l0aOl00ol0003o063oo`1Po`0?o`1Po`03
o`000?l50?oo1@3o00Wo1@3o00?o0000ofX0oomZ0?l01_mZ0?l00ol0003oc`3ooll0o`05oll0o`03
o`000?oo0<[oo`3:00?oo`3:00?o0000ool0IOoo06D01?oo06D3o`0001Woo`000_l00007ool0I@03
o`000?oo0<[oo`3:00?oo`3:00?o0000oll0ooo?0?l01?o?0?l00ol0003oJP3oofX0o`06ofX0o`03
o`000?l50?oo1@3o00Wo1@3o00?o0000o`1Pool0H?l03ol0H?l00ol0003o0<Goo`35o`0Io`35o`03
o`000?l0omCo0?oD02co0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?l:o`3o2P0Io`3o2P[o
oo]Z0Ol00001oookJP008OoonfX3o`0000Sooo]Z6_l0o`X00ol0003o0?m_o`3oK`1Ao`3oK`03o`00
0?l0omCo0?oD02co0?oD00?o0000o`35ool0aOl06?l0aOl00ol0003o063oo`1Po`0?o`1Po`03o`00
0?l50?oo1@3o00Wo1@3o00?o0000ofX0oomZ0?l01_mZ0?l00ol0003oc`3ooll0o`05oll0o`03o`00
0?oo0<[oo`3:00?oo`3:00?o0000ool0IOoo06D00ooo06D2o`0001koo`000ol00005ool0I@03o`00
0?oo0<[oo`3:00?oo`3:00?o0000oll0ooo?0?l01?o?0?l00ol0003oJP3oofX0o`06ofX0o`03o`00
0?l50?oo1@3o00Wo1@3o00?o0000o`1Pool0H?l03ol0H?l00ol0003o0<Goo`35o`0Ho`35o`03o`00
0?l0omCo0?oD02go0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?l:o`3o2P0Ho`3o2PSooo]Z
0ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQ[o0?l:00?o0000o`3oKol0ofl0DOl0
ofl00ol0003o0?oDo`3oe00/o`3oe003o`000?l0aOoo0<Go01So0<Go00?o0000o`1Pool0H?l03ol0
H?l00ol0003o1@3oo`D0o`08o`D0o`03o`000?mZ0?ooJP3o00OoJP3o00?o0000oll0ooo?0?l01?o?
0?l00ol0003oo`3:ool0bP03ool0bP03o`000?oo06Goo`1U00;oo`1U0_l0000Sool000;o00001?oo
06D00ol0003oo`3:ool0bP03ool0bP03o`000?o?0?ooc`3o00Coc`3o00?o0000ofX0oomZ0?l01_mZ
0?l00ol0003o1@3oo`D0o`08o`D0o`03o`000?l0H?oo063o013o063o00?o0000o`35ool0aOl06?l0
aOl00ol0003o0?oDo`3oe00/o`3oe003o`000?l0ofoo0?m_053o0?m_00?o0000o`3o2_l0o`X06?l0
o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXIo`3o2P03o`000?l0ofoo
0?m_057o0?m_00?o0000o`3oe?l0om@0;?l0om@00ol0003o0<Goo`35o`0Io`35o`03o`000?l0H?oo
063o00ko063o00?o0000o`D0ool50?l02Ol50?l00ol0003oJP3oofX0o`06ofX0o`03o`000?o?0?oo
c`3o00Coc`3o00?o0000ool0b_oo0<X00ooo0<X00ol0003oo`1Uool0I@02ool0I@03o`000?oo003o
o`0002Goo`0000?o0000ool0IOoo06D00_oo06D00ol0003oo`3:ool0bP03ool0bP03o`000?o?0?oo
c`3o00Coc`3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?l0H?oo
063o00oo063o00?o0000o`35ool0aOl06?l0aOl00ol0003o0?oDo`3oe00]o`3oe003o`000?l0ofoo
0?m_053o0?m_00?o0000o`3o2_l0o`X05ol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oook
J_oonfX02?oonfXIo`3o2P03o`000?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0;?l0om@00ol0
003o0<Goo`35o`0Io`35o`03o`000?l0H?oo063o00ko063o00?o0000o`D0ool50?l02Ol50?l00ol0
003oJP3oofX0o`06ofX0o`03o`000?o?0?ooc`3o00?oc`3o0_l00005ool0bP03o`000?oo06Goo`1U
00;oo`1U00?o0000ool00?oo00009ooo00000ol0003oo`1Uool0I@02ool0I@03o`000?oo0<[oo`3:
00?oo`3:00?o0000oll0ooo?0?l01?o?0?l00ol0003oJP3oofX0o`05ofX0o`03o`000?l50?oo1@3o
00Wo1@3o00?o0000o`1Pool0H?l03ol0H?l00ol0003o0<Goo`35o`0Ho`35o`03o`000?l0omCo0?oD
02go0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?l:o`3o2P0Fo`3o2P[ooo]Z0Ol00001oook
JP008OoonfX00ol0003ooo]ZoookJP08oookJQWo0?l:00?o0000o`3oKol0ofl0Col0ofl00ol0003o
0?oDo`3oe00]o`3oe003o`000?l0aOoo0<Go01Wo0<Go00?o0000o`1Pool0H?l03_l0H?l00ol0003o
1@3oo`D0o`09o`D0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000oll0ooo?0?l00_o?0?l00ol0003o
o`3:ool0bP05ool0bP03o`000?oo06Goo`1U00;oo`1U00?o0000ool00?oo00009ooo00000ol0003o
o`1Uool0I@02ool0I@03o`000?oo0<[oo`3:00Coo`3:00?o0000oll0ooo?0?l00oo?0?l00ol0003o
JP3oofX0o`05ofX0o`03o`000?l50?oo1@3o00[o1@3o00?o0000o`1Pool0H?l03_l0H?l00ol0003o
0<Goo`35o`0Ho`35o`03o`000?l0omCo0?oD02go0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o
0?l:o`3o2P0Fo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQSo0?l:
00?o0000o`3oKol0ofl0Col0ofl00ol0003o0?oDo`3oe00]o`3oe003o`000?l0aOoo0<Go01Wo0<Go
00?o0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`08o`D0o`03o`000?mZ0?ooJP3o00KoJP3o
00?o0000oll0ooo?0?l00oo?0?l00ol0003oo`3:ool0bP04ool0bP03o`000?oo06Goo`1U00;oo`1U
00?o0000ool00?oo0000:Ooo00000ol0003oo`1Uool0I@02ool0I@03o`000?oo0<[oo`3:00?oo`3:
00?o0000oll0ooo?0?l01?o?0?l00ol0003oJP3oofX0o`05ofX0o`03o`000?l50?oo1@3o00Wo1@3o
00?o0000o`1Pool0H?l03ol0H?l00ol0003o0<Goo`35o`0Ho`35o`03o`000?l0omCo0?oD02go0?oD
00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?l:o`3o2P0Eo`3o2P[ooo]Z0Ol00001oookJP008Ooo
nfX00ol0003ooo]ZoookJP08oookJQOo0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3o
e00]o`3oe003o`000?l0aOoo0<Go01Wo0<Go00?o0000o`1Pool0H?l03_l0H?l00ol0003o1@3oo`D0
o`09o`D0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000oll0ooo?0?l00_o?0?l00ol0003oo`3:ool0
bP04ool0bP03o`000?oo06Goo`1U00;oo`1U00?o0000ool00?oo0000:ooo00000ol0003oo`1Uool0
I@02ool0I@03o`000?oo0<[oo`3:00?oo`3:00?o0000oll0ooo?0?l00oo?0?l00ol0003oJP3oofX0
o`05ofX0o`03o`000?l50?oo1@3o00[o1@3o00?o0000o`1Pool0H?l03_l0H?l00ol0003o0<Goo`35
o`0Ho`35o`03o`000?l0omCo0?oD02go0?oD00?o0000o`3oKol0ofl0DOl0ofl00ol0003o0?l:o`3o
2P0Do`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQOo0?l:00?o0000
o`3oKol0ofl0Col0ofl00ol0003o0?oDo`3oe00]o`3oe003o`000?l0aOoo0<Go01Wo0<Go00?o0000
o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?mZ0?ooJP3o00GoJP3o00?o0000
oll0ooo?0?l00oo?0?l00ol0003oo`3:ool0bP03ool0bP03o`000?oo06Goo`1U00?oo`1U00?o0000
ool00?oo0000:ooo00000ol0003oo`1Uool0I@02ool0I@03o`000?oo0<[oo`3:00?oo`3:00?o0000
oll0ooo?0?l01?o?0?l00ol0003oJP3oofX0o`05ofX0o`03o`000?l50?oo1@3o00Wo1@3o00?o0000
o`1Pool0H?l03_l0H?l00ol0003o0<Goo`35o`0Io`35o`03o`000?l0omCo0?oD02go0?oD00?o0000
o`3oKol0ofl0D?l0ofl00ol0003o0?l:o`3o2P0Do`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0
003ooo]ZoookJP08oookJQKo0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00]o`3o
e003o`000?l0aOoo0<Go01Wo0<Go00?o0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`08o`D0
o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000oll0ooo?0?l00oo?0?l00ol0003oo`3:ool0bP02ool0
bP03o`000?oo06Goo`1U00?oo`1U00?o0000ool00?oo0000;Ooo00000ol0003oo`1Uool0I@02ool0
I@03o`000?oo0<[oo`3:00;oo`3:00?o0000oll0ooo?0?l01?o?0?l00ol0003oJP3oofX0o`05ofX0
o`03o`000?l50?oo1@3o00Wo1@3o00?o0000o`1Pool0H?l03ol0H?l00ol0003o0<Goo`35o`0Ho`35
o`03o`000?l0omCo0?oD02ko0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?l:o`3o2P0Co`3o
2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQKo0?l:00?o0000o`3oKol0
ofl0Col0ofl00ol0003o0?oDo`3oe00]o`3oe003o`000?l0aOoo0<Go01Wo0<Go00?o0000o`1Pool0
H?l03ol0H?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?mZ0?ooJP3o00GoJP3o00?o0000oll0ooo?
0?l00oo?0?l00ol0003oo`3:ool0bP03ool0bP03o`000?oo06Goo`1U00;oo`1U00?o0000ool00?oo
0000;ooo00000ol0003oo`1Uool0I@02ool0I@03o`000?oo0<[oo`3:00;oo`3:00?o0000oll0ooo?
0?l01?o?0?l00ol0003oJP3oofX0o`05ofX0o`03o`000?l50?oo1@3o00Wo1@3o00?o0000o`1Pool0
H?l03_l0H?l00ol0003o0<Goo`35o`0Io`35o`03o`000?l0omCo0?oD02go0?oD00?o0000o`3oKol0
ofl0D?l0ofl00ol0003o0?l:o`3o2P0Co`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJQGo0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00]o`3oe003o`00
0?l0aOoo0<Go01Wo0<Go00?o0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`08o`D0o`03o`00
0?mZ0?ooJP3o00KoJP3o00?o0000oll0ooo?0?l00oo?0?l00ol0003oo`3:ool0bP02ool0bP03o`00
0?oo06Goo`1U00;oo`1U00?o0000ool00?oo0000<Ooo00000ol0003oo`1Uool0I@02ool0I@05o`00
0?oo0<[oo`3:ool0b_l000001_o?0?l00ol0003oJP3oofX0o`05ofX0o`03o`000?l50?oo1@3o00Wo
1@3o00?o0000o`1Pool0H?l03ol0H?l00ol0003o0<Goo`35o`0Io`35o`03o`000?l0omCo0?oD02go
0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?l:o`3o2P0Bo`3o2P[ooo]Z0Ol00001oookJP00
8OoonfX00ol0003ooo]ZoookJP08oookJQCo0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oD
o`3oe00^o`3oe003o`000?l0aOoo0<Go01Wo0<Go00?o0000o`1Pool0H?l03_l0H?l00ol0003o1@3o
o`D0o`09o`D0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000oll0ooo?0?l00_o?0?l00ol0003oo`3:
ool0bP02ool0bP03o`000?oo06Goo`1U00?oo`1U00?o0000ool00?oo0000<Ooo00000ol0003oo`1U
ool0I@02ool0I@03o`000?oo0<[oo`3:00;oo`3:00?o0000oll0ooo?0?l00oo?0?l00ol0003oJP3o
ofX0o`05ofX0o`03o`000?l50?oo1@3o00[o1@3o00?o0000o`1Pool0H?l03_l0H?l00ol0003o0<Go
o`35o`0Io`35o`03o`000?l0omCo0?oD02ko0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?l:
o`3o2P0Ao`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQCo0?l:00?o
0000o`3oKol0ofl0Col0ofl00ol0003o0?oDo`3oe00^o`3oe003o`000?l0aOoo0<Go01Wo0<Go00?o
0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?mZ0?ooJP3o00GoJP3o00?o
0000oll0ooo?0?l00oo?0?l01Ol0003oo`3:ool0b_oo0<[o000000Goo`1U00?o0000ool00?oo0000
<ooo00000ol0003oo`1Uool0I@02ool0I@05o`000?oo0<[oo`3:ool0b_l000001_o?0?l00ol0003o
JP3oofX0o`05ofX0o`03o`000?l50?oo1@3o00Wo1@3o00?o0000o`1Pool0H?l03_l0H?l00ol0003o
0<Goo`35o`0Jo`35o`03o`000?l0omCo0?oD02go0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o
0?l:o`3o2P0Ao`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQ?o0?l:
00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00^o`3oe003o`000?l0aOoo0<Go01Wo0<Go
00?o0000o`1Pool0H?l03_l0H?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?mZ0?ooJP3o00KoJP3o
00?o0000oll0ooo?0?l00_o?0?l01Ol0003oo`3:ool0b_oo0<[o000000Goo`1U00?o0000ool00?oo
0000=Ooo00000ol0003oo`1Uool0I@02ool0I@05o`000?oo0<[oo`3:ool0b_l000001Oo?0?l00ol0
003oJP3oofX0o`05ofX0o`03o`000?l50?oo1@3o00[o1@3o00?o0000o`1Pool0H?l03_l0H?l00ol0
003o0<Goo`35o`0Io`35o`03o`000?l0omCo0?oD02ko0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0
003o0?l:o`3o2P0@o`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQ?o
0?l:00?o0000o`3oKol0ofl0Col0ofl00ol0003o0?oDo`3oe00^o`3oe003o`000?l0aOoo0<Go01Wo
0<Go00?o0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?mZ0?ooJP3o00Go
JP3o00?o0000oll0ooo?0?l00oo?0?l01Ol0003oo`3:ool0b_oo0<[o000000Goo`1U00?o0000ool0
0?oo0000=Ooo00000ol0003oo`1Uool0I@02ool0I@05o`000?oo0<[oo`3:ool0b_l000001_o?0?l0
0ol0003oJP3oofX0o`05ofX0o`03o`000?l50?oo1@3o00Wo1@3o00?o0000o`1Pool0H?l03_l0H?l0
0ol0003o0<Goo`35o`0Jo`35o`03o`000?l0omCo0?oD02go0?oD00?o0000o`3oKol0ofl0D?l0ofl0
0ol0003o0?l:o`3o2P0@o`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oook
JQ;o0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00^o`3oe003o`000?l0aOoo0<Go
01Wo0<Go00?o0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?mZ0?ooJP3o
00GoJP3o00?o0000oll0ooo?0?l00oo?0?l01Ol0003oo`3:ool0b_oo0<[o000000Coo`1U00?o0000
ool00?oo0000=ooo00000ol0003oo`1Uool0I@02ool0I@04o`000?oo0<[oo`3:o`0000Koc`3o00?o
0000ofX0oomZ0?l01OmZ0?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?l0H?oo063o00ko063o00?o
0000o`35ool0aOl06_l0aOl00ol0003o0?oDo`3oe00^o`3oe003o`000?l0ofoo0?m_053o0?m_00?o
0000o`3o2_l0o`X03ol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXA
o`3o2P03o`000?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0;_l0om@00ol0003o0<Goo`35o`0I
o`35o`03o`000?l0H?oo063o00oo063o00?o0000o`D0ool50?l02Ol50?l00ol0003oJP3oofX0o`05
ofX0o`03o`000?o?0?ooc`3o00?oc`3o00?o0000ool0b_oo0<X00_oo0<X01Ol0003oo`1Uool0IOoo
06Go000003_oo`0000Go0000ool0IOoo06Goo`1Uo`000003ool0bP03o`000?o?0?ooc`3o00Coc`3o
00?o0000ofX0oomZ0?l01OmZ0?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?l0H?oo063o00ko063o
00?o0000o`35ool0aOl06_l0aOl00ol0003o0?oDo`3oe00^o`3oe003o`000?l0ofoo0?m_053o0?m_
00?o0000o`3o2_l0o`X03_l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oo
nfXAo`3o2P03o`000?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0;_l0om@00ol0003o0<Goo`35
o`0Io`35o`03o`000?l0H?oo063o00oo063o00?o0000o`D0ool50?l02Ol50?l00ol0003oJP3oofX0
o`05ofX0o`03o`000?o?0?ooc`3o00?oc`3o00?o0000ool0b_oo0<X00_oo0<X01Ol0003oo`1Uool0
IOoo06Go000003_oo`0000Go0000ool0IOoo06Goo`1Uo`000003ool0bP03o`000?o?0?ooc`3o00Co
c`3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?l0H?oo063o00ko
063o00?o0000o`35ool0aOl06_l0aOl00ol0003o0?oDo`3oe00^o`3oe003o`000?l0ofoo0?m_053o
0?m_00?o0000o`3o2_l0o`X03_l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX0
2?oonfX@o`3o2P03o`000?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0;_l0om@00ol0003o0<Go
o`35o`0Jo`35o`03o`000?l0H?oo063o00oo063o00?o0000o`D0ool50?l02Ol50?l00ol0003oJP3o
ofX0o`05ofX0o`03o`000?o?0?ooc`3o00?oc`3o00?o0000ool0b_oo0<X00_oo0<X01Ol0003oo`1U
ool0IOoo06Go000003_oo`0000Go0000ool0IOoo06Goo`1Uo`000003ool0bP03o`000?o?0?ooc`3o
00Coc`3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?l0H?oo063o
00ko063o00?o0000o`35ool0aOl06ol0aOl00ol0003o0?oDo`3oe00^o`3oe003o`000?l0ofoo0?m_
053o0?m_00?o0000o`3o2_l0o`X03Ol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oo
nfX02?oonfX@o`3o2P03o`000?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0;_l0om@00ol0003o
0<Goo`35o`0Io`35o`03o`000?l0H?oo063o00oo063o00?o0000o`D0ool50?l02Ol50?l00ol0003o
JP3oofX0o`05ofX0o`03o`000?o?0?ooc`3o00Coc`3o00?o0000ool0b_oo0<X00_oo0<X01Ol0003o
o`1Uool0IOoo06Go000003_oo`0000Go0000ool0IOoo06Goo`1Uo`000003ool0bP03o`000?o?0?oo
c`3o00Coc`3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?l0H?oo
063o00oo063o00?o0000o`35ool0aOl06_l0aOl00ol0003o0?oDo`3oe00^o`3oe003o`000?l0ofoo
0?m_053o0?m_00?o0000o`3o2_l0o`X03Ol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oook
J_oonfX02?oonfX?o`3o2P03o`000?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0;_l0om@00ol0
003o0<Goo`35o`0Jo`35o`03o`000?l0H?oo063o00oo063o00?o0000o`D0ool50?l02Ol50?l00ol0
003oJP3oofX0o`05ofX0o`03o`000?o?0?ooc`3o00?oc`3o00?o0000ool0b_oo0<X00_oo0<X00ol0
003oo`1Uool0I@02ool0I@03o`000?oo003oo`0003Woo`0000?o0000ool0IOoo06D00_oo06D01Ol0
003oo`3:ool0b_oo0<[o000000Goc`3o00?o0000ofX0oomZ0?l01_mZ0?l00ol0003o1@3oo`D0o`09
o`D0o`03o`000?l0H?oo063o00ko063o00?o0000o`35ool0aOl06_l0aOl00ol0003o0?oDo`3oe00_
o`3oe003o`000?l0ofoo0?m_053o0?m_00?o0000o`3o2_l0o`X03?l0o`X:oookJP7o00000OoonfX0
027ooo]Z00?o0000oookJ_oonfX02?oonfX>o`3o2P03o`000?l0ofoo0?m_053o0?m_00?o0000o`3o
e?l0om@0;ol0om@00ol0003o0<Goo`35o`0Jo`35o`03o`000?l0H?oo063o00oo063o00?o0000o`D0
ool50?l02Ol50?l00ol0003oJP3oofX0o`05ofX0o`03o`000?o?0?ooc`3o00?oc`3o00?o0000ool0
b_oo0<X00_oo0<X00ol0003oo`1Uool0I@02ool0I@03o`000?oo003oo`0003Woo`0000?o0000ool0
IOoo06D00_oo06D01Ol0003oo`3:ool0b_oo0<[o000000Koc`3o00?o0000ofX0oomZ0?l01OmZ0?l0
0ol0003o1@3oo`D0o`09o`D0o`03o`000?l0H?oo063o00ko063o00?o0000o`35ool0aOl06ol0aOl0
0ol0003o0?oDo`3oe00_o`3oe003o`000?l0ofoo0?m_053o0?m_00?o0000o`3o2_l0o`X02ol0o`X:
oookJP7o00000OoonfX001?ooo]Z0ol007l;oookJP03o`000?oonf[ooo]Z00Sooo]Z3_l0o`X00ol0
003o0?m_o`3oK`1@o`3oK`03o`000?l0omCo0?oD02ko0?oD00?o0000o`35ool0aOl06ol0aOl00ol0
003o063oo`1Po`0?o`1Po`03o`000?l50?oo1@3o00Wo1@3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0
003oc`3ooll0o`03oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo06D00ol0
003oo`00ool0000iool00003o`000?oo06Goo`1U00;oo`1U00Go0000ool0b_oo0<[oo`3:o`000006
oll0o`03o`000?mZ0?ooJP3o00GoJP3o00?o0000o`D0ool50?l02Ol50?l00ol0003o063oo`1Po`0?
o`1Po`03o`000?l0aOoo0<Go01[o0<Go00?o0000o`3oe?l0om@0;ol0om@00ol0003o0?m_o`3oK`1@
o`3oK`03o`000?l0o`[o0?l:00_o0?l:2_oonfX1o`00007ooo]Z000CoookJP?o001o2ooonfX00ol0
003ooo]ZoookJP08oookJPgo0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00_o`3o
e003o`000?l0aOoo0<Go01_o0<Go00?o0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`09o`D0
o`03o`000?mZ0?ooJP3o00GoJP3o00?o0000oll0ooo?0?l00oo?0?l00ol0003oo`3:ool0bP02ool0
bP03o`000?oo06Goo`1U00;oo`1U00?o0000ool00?oo0000>Ooo00000ol0003oo`1Uool0I@02ool0
I@05o`000?oo0<[oo`3:ool0b_l000001_o?0?l00ol0003oJP3oofX0o`05ofX0o`03o`000?l50?oo
1@3o00Wo1@3o00?o0000o`1Pool0H?l03ol0H?l00ol0003o0<Goo`35o`0Jo`35o`03o`000?l0omCo
0?oD033o0?oD00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?l:o`3o2P0:o`3o2P[ooo]Z0Ol00001
oookJP004ooonfX3o`00O`_ooo]Z00?o0000oookJ_oonfX02?oonfX=o`3o2P03o`000?l0ofoo0?m_
053o0?m_00?o0000o`3oe?l0om@0;_l0om@00ol0003o0<Goo`35o`0Ko`35o`03o`000?l0H?oo063o
00oo063o00?o0000o`D0ool50?l02Ol50?l00ol0003oJP3oofX0o`05ofX0o`03o`000?o?0?ooc`3o
00Coc`3o00?o0000ool0b_oo0<X00_oo0<X01Ol0003oo`1Uool0IOoo06Go000003goo`0000Go0000
ool0IOoo06Goo`1Uo`000003ool0bP03o`000?o?0?ooc`3o00Coc`3o00?o0000ofX0oomZ0?l01OmZ
0?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?l0H?oo063o00oo063o00?o0000o`35ool0aOl06ol0
aOl00ol0003o0?oDo`3oe00_o`3oe003o`000?l0ofoo0?m_053o0?m_00?o0000o`3o2_l0o`X02_l0
o`X:oookJP7o00000OoonfX000?ooo]Z2_l007l6oookJP?o001o2ooonfX00ol0003ooo]ZoookJP08
oookJPco0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00_o`3oe003o`000?l0aOoo
0<Go01_o0<Go00?o0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?mZ0?oo
JP3o00GoJP3o00?o0000oll0ooo?0?l01?o?0?l00ol0003oo`3:ool0bP02ool0bP05o`000?oo06Go
o`1Uool0IOl00000?Ooo00001Ol0003oo`1Uool0IOoo06Go000000?oo`3:00?o0000oll0ooo?0?l0
1?o?0?l00ol0003oJP3oofX0o`05ofX0o`03o`000?l50?oo1@3o00Wo1@3o00?o0000o`1Pool0H?l0
3ol0H?l00ol0003o0<Goo`35o`0Ko`35o`03o`000?l0omCo0?oD033o0?oD00?o0000o`3oKol0ofl0
D?l0ofl00ol0003o0?l:o`3o2P09o`3o2P[ooo]Z0Ol00001oookJP000ooonfX:o`00O`Kooo]Z0ol0
07l;oookJPGo00001_oonfX<o`3o2P03o`000?l0ofoo0?m_04oo0?m_00?o0000o`3oe?l0om@0<?l0
om@00ol0003o0<Goo`35o`0Ko`35o`03o`000?l0H?oo063o00oo063o00?o0000o`D0ool50?l02Ol5
0?l00ol0003oJP3oofX0o`05ofX0o`03o`000?o?0?ooc`3o00Coc`3o00?o0000ool0b_oo0<X00_oo
0<X01Ol0003oo`1Uool0IOoo06Go000003goo`0000Go0000ool0IOoo06Goo`1Uo`000003ool0bP03
o`000?o?0?ooc`3o00Coc`3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003o1@3oo`D0o`09o`D0o`03
o`000?l0H?oo063o013o063o00?o0000o`35ool0aOl06_l0aOl00ol0003o0?oDo`3oe00ao`3oe003
o`000?l0ofoo0?m_04oo0?m_00?o0000o`3o2_l0o`X02Ol0o`X7oookJPCo00000OoonfX001?ooo]Z
0ol007l;oookJP03o`000?oonf[ooo]Z00Sooo]Z2ol0o`X00ol0003o0?m_o`3oK`1@o`3oK`03o`00
0?l0omCo0?oD02oo0?oD00?o0000o`35ool0aOl07?l0aOl00ol0003o063oo`1Po`0?o`1Po`03o`00
0?l50?oo1@3o00Wo1@3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003oc`3ooll0o`03oll0o`03o`00
0?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo06D00ol0003oo`00ool0000kool00003o`00
0?oo06Goo`1U00;oo`1U00Go0000ool0b_oo0<[oo`3:o`000005oll0o`03o`000?mZ0?ooJP3o00Ko
JP3o00?o0000o`D0ool50?l02Ol50?l00ol0003o063oo`1Po`0?o`1Po`03o`000?l0aOoo0<Go01_o
0<Go00?o0000o`3oe?l0om@0<?l0om@00ol0003o0?m_o`3oK`1@o`3oK`03o`000?l0o`[o0?l:00So
0?l:2_oonfX1o`00007ooo]Z000CoookJP?o001o2ooonfX00ol0003ooo]ZoookJP08oookJP[o0?l:
00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00`o`3oe003o`000?l0aOoo0<Go01co0<Go
00?o0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?mZ0?ooJP3o00GoJP3o
00?o0000oll0ooo?0?l00oo?0?l00ol0003oo`3:ool0bP02ool0bP03o`000?oo06Goo`1U00;oo`1U
00?o0000ool00?oo0000>ooo00000ol0003oo`1Uool0I@02ool0I@05o`000?oo0<[oo`3:ool0b_l0
00001_o?0?l00ol0003oJP3oofX0o`05ofX0o`03o`000?l50?oo1@3o00Wo1@3o00?o0000o`1Pool0
H?l03ol0H?l00ol0003o0<Goo`35o`0Ko`35o`03o`000?l0omCo0?oD037o0?oD00?o0000o`3oKol0
ofl0Col0ofl00ol0003o0?l:o`3o2P08o`3o2P[ooo]Z0Ol00001oookJP004ooonfX3o`00O`_ooo]Z
00?o0000oookJ_oonfX02?oonfX:o`3o2P03o`000?l0ofoo0?m_053o0?m_00?o0000o`3oe?l0om@0
<?l0om@00ol0003o0<Goo`35o`0Ko`35o`03o`000?l0H?oo063o00oo063o00?o0000o`D0ool50?l0
2Ol50?l00ol0003oJP3oofX0o`06ofX0o`03o`000?o?0?ooc`3o00?oc`3o00?o0000ool0b_oo0<X0
0_oo0<X00ol0003oo`1Uool0I@02ool0I@03o`000?oo003oo`0003_oo`0000?o0000ool0IOoo06D0
0_oo06D01Ol0003oo`3:ool0b_oo0<[o000000Koc`3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003o
1@3oo`D0o`09o`D0o`03o`000?l0H?oo063o013o063o00?o0000o`35ool0aOl06_l0aOl00ol0003o
0?oDo`3oe00ao`3oe003o`000?l0ofoo0?m_04oo0?m_00?o0000o`3o2_l0o`X02?l0o`X:oookJP7o
00000OoonfX001?ooo]Z0ol007l;oookJP03o`000?oonf[ooo]Z00Sooo]Z2Ol0o`X00ol0003o0?m_
o`3oK`1@o`3oK`03o`000?l0omCo0?oD033o0?oD00?o0000o`35ool0aOl07?l0aOl00ol0003o063o
o`1Po`0?o`1Po`03o`000?l50?oo1@3o00Wo1@3o00?o0000ofX0oomZ0?l01_mZ0?l00ol0003oc`3o
oll0o`03oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo06D00ol0003oo`00
ool0000kool00003o`000?oo06Goo`1U00;oo`1U00Go0000ool0b_oo0<[oo`3:o`000006oll0o`03
o`000?mZ0?ooJP3o00GoJP3o00?o0000o`D0ool50?l02Ol50?l00ol0003o063oo`1Po`0@o`1Po`03
o`000?l0aOoo0<Go01_o0<Go00?o0000o`3oe?l0om@0<Ol0om@00ol0003o0?m_o`3oK`1?o`3oK`03
o`000?l0o`[o0?l:00Oo0?l:2_oonfX1o`00007ooo]Z000@oookJPKo001o2ooonfX00ol0003ooo]Z
oookJP08oookJPWo0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00`o`3oe003o`00
0?l0aOoo0<Go01co0<Go00?o0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`09o`D0o`03o`00
0?mZ0?ooJP3o00KoJP3o00?o0000oll0ooo?0?l00oo?0?l00ol0003oo`3:ool0bP02ool0bP03o`00
0?oo06Goo`1U00;oo`1U00?o0000ool00?oo0000>ooo00000ol0003oo`1Uool0I@02ool0I@05o`00
0?oo0<[oo`3:ool0b_l000001_o?0?l00ol0003oJP3oofX0o`05ofX0o`03o`000?l50?oo1@3o00Wo
1@3o00?o0000o`1Pool0H?l04?l0H?l00ol0003o0<Goo`35o`0Ko`35o`03o`000?l0omCo0?oD037o
0?oD00?o0000o`3oKol0ofl0Col0ofl00ol0003o0?l:o`3o2P07o`3o2P[ooo]Z0Ol00001oookJP00
4?oonfX6o`00O`_ooo]Z00?o0000oookJ_oonfX02?oonfX8o`3o2P03o`000?l0ofoo0?m_053o0?m_
00?o0000o`3oe?l0om@0<?l0om@00ol0003o0<Goo`35o`0Lo`35o`03o`000?l0H?oo063o013o063o
00?o0000o`D0ool50?l02Ol50?l00ol0003oJP3oofX0o`06ofX0o`03o`000?o?0?ooc`3o00?oc`3o
00?o0000ool0b_oo0<X00_oo0<X00ol0003oo`1Uool0I@02ool0I@03o`000?oo003oo`0003_oo`00
00?o0000ool0IOoo06D00_oo06D01Ol0003oo`3:ool0b_oo0<[o000000Koc`3o00?o0000ofX0oomZ
0?l01OmZ0?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?l0H?oo063o017o063o00?o0000o`35ool0
aOl06ol0aOl00ol0003o0?oDo`3oe00ao`3oe003o`000?l0ofoo0?m_04oo0?m_00?o0000o`3o2_l0
o`X01_l0o`X:oookJP7o00000OoonfX001;ooo]Z1?l007l;oookJP03o`000?oonf[ooo]Z00Sooo]Z
2?l0o`X00ol0003o0?m_o`3oK`1?o`3oK`03o`000?l0omCo0?oD037o0?oD00?o0000o`35ool0aOl0
7?l0aOl00ol0003o063oo`1Po`0@o`1Po`03o`000?l50?oo1@3o00Wo1@3o00?o0000ofX0oomZ0?l0
1_mZ0?l00ol0003oc`3ooll0o`04oll0o`05o`000?oo0<[oo`3:ool0b_l000001Ooo06D00ol0003o
o`00ool0000iool00003o`000?oo06Goo`1U00;oo`1U00?o0000ool0b_oo0<X00_oo0<X00ol0003o
c`3ooll0o`03oll0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000o`D0ool50?l02Ol50?l00ol0003o
063oo`1Po`0Ao`1Po`03o`000?l0aOoo0<Go01_o0<Go00?o0000o`3oe?l0om@0<Ol0om@00ol0003o
0?m_o`3oK`1?o`3oK`03o`000?l0o`[o0?l:00Ko0?l:2_oonfX1o`00007ooo]Z000CoookJP?o001o
2ooonfX00ol0003ooo]ZoookJP08oookJPOo0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oD
o`3oe00ao`3oe003o`000?l0aOoo0<Go01co0<Go00?o0000o`1Pool0H?l04?l0H?l00ol0003o1@3o
o`D0o`09o`D0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000oll0ooo?0?l01?o?0?l00ol0003oo`3:
ool0bP02ool0bP03o`000?oo06Goo`1U00;oo`1U00?o0000ool00?oo0000>Ooo00000ol0003oo`1U
ool0I@02ool0I@05o`000?oo0<[oo`3:ool0b_l000001_o?0?l00ol0003oJP3oofX0o`06ofX0o`03
o`000?l50?oo1@3o00Wo1@3o00?o0000o`1Pool0H?l04Ol0H?l00ol0003o0<Goo`35o`0Ko`35o`03
o`000?l0omCo0?oD03;o0?oD00?o0000o`3oKol0ofl0Col0ofl00ol0003o0?l:o`3o2P05o`3o2P[o
oo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJPOo0?l:00?o0000o`3oKol0ofl0
Col0ofl00ol0003o0?oDo`3oe00ao`3oe003o`000?l0aOoo0<Go01go0<Go00?o0000o`1Pool0H?l0
4?l0H?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000oll0ooo?0?l0
1?o?0?l00ol0003oo`3:ool0bP02ool0bP03o`000?oo06Goo`1U00;oo`1U00?o0000ool00?oo0000
>Ooo00000ol0003oo`1Uool0I@02ool0I@05o`000?oo0<[oo`3:ool0b_l000001_o?0?l00ol0003o
JP3oofX0o`06ofX0o`03o`000?l50?oo1@3o00Wo1@3o00?o0000o`1Pool0H?l04Ol0H?l00ol0003o
0<Goo`35o`0Lo`35o`03o`000?l0omCo0?oD037o0?oD00?o0000o`3oKol0ofl0Col0ofl00ol0003o
0?l:o`3o2P05o`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJPKo0?l:
00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00ao`3oe003o`000?l0aOoo0<Go01go0<Go
00?o0000o`1Pool0H?l04?l0H?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?mZ0?ooJP3o00KoJP3o
00?o0000oll0ooo?0?l01?o?0?l00ol0003oo`3:ool0bP02ool0bP03o`000?oo06Goo`1U00;oo`1U
00?o0000ool00?oo0000>Ooo00000ol0003oo`1Uool0I@02ool0I@05o`000?oo0<[oo`3:ool0b_l0
00001_o?0?l00ol0003oJP3oofX0o`06ofX0o`03o`000?l50?oo1@3o00Wo1@3o00?o0000o`1Pool0
H?l04Ol0H?l00ol0003o0<Goo`35o`0Lo`35o`03o`000?l0omCo0?oD03;o0?oD00?o0000o`3oKol0
ofl0Col0ofl00ol0003o0?l:o`3o2P04o`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJPGo0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3oe00ao`3oe003o`00
0?l0aOoo0<Go01ko0<Go00?o0000o`1Pool0H?l04?l0H?l00ol0003o1@3oo`D0o`0:o`D0o`03o`00
0?mZ0?ooJP3o00GoJP3o00?o0000oll0ooo?0?l01Oo?0?l01Ol0003oo`3:ool0b_oo0<[o000000Go
o`1U00?o0000ool00?oo0000=ooo00000ol0003oo`1Uool0I@02ool0I@03o`000?oo0<[oo`3:00;o
o`3:00?o0000oll0ooo?0?l01?o?0?l00ol0003oJP3oofX0o`05ofX0o`03o`000?l50?oo1@3o00_o
1@3o00?o0000o`1Pool0H?l04?l0H?l00ol0003o0<Goo`35o`0Mo`35o`03o`000?l0omCo0?oD03;o
0?oD00?o0000o`3oKol0ofl0Col0ofl00ol0003o0?l:o`3o2P03o`3o2P[ooo]Z0Ol00001oookJP00
8OoonfX00ol0003ooo]ZoookJP08oookJPGo0?l:00?o0000o`3oKol0ofl0Col0ofl00ol0003o0?oD
o`3oe00bo`3oe003o`000?l0aOoo0<Go01go0<Go00?o0000o`1Pool0H?l04Ol0H?l00ol0003o1@3o
o`D0o`0:o`D0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000oll0ooo?0?l01?o?0?l01Ol0003oo`3:
ool0b_oo0<[o000000Goo`1U00?o0000ool00?oo0000=ooo00000ol0003oo`1Uool0I@02ool0I@03
o`000?oo0<[oo`3:00;oo`3:00?o0000oll0ooo?0?l01?o?0?l00ol0003oJP3oofX0o`05ofX0o`03
o`000?l50?oo1@3o00_o1@3o00?o0000o`1Pool0H?l04Ol0H?l00ol0003o0<Goo`35o`0Lo`35o`03
o`000?l0omCo0?oD03;o0?oD00?o0000o`3oKol0ofl0Col0ofl00ol0003o0?l:o`3o2P03o`3o2P[o
oo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJPCo0?l:00?o0000o`3oKol0ofl0
D?l0ofl00ol0003o0?oDo`3oe00bo`3oe003o`000?l0aOoo0<Go01go0<Go00?o0000o`1Pool0H?l0
4Ol0H?l00ol0003o1@3oo`D0o`0:o`D0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000oll0ooo?0?l0
1?o?0?l01Ol0003oo`3:ool0b_oo0<[o000000Goo`1U00?o0000ool00?oo0000=ooo00000ol0003o
o`1Uool0I@02ool0I@03o`000?oo0<[oo`3:00;oo`3:00?o0000oll0ooo?0?l01?o?0?l00ol0003o
JP3oofX0o`05ofX0o`03o`000?l50?oo1@3o00_o1@3o00?o0000o`1Pool0H?l04Ol0H?l00ol0003o
0<Goo`35o`0Lo`35o`03o`000?l0omCo0?oD03?o0?oD00?o0000o`3oKol0ofl0Col0ofl00ol0003o
0?l:o`3o2P02o`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJPCo0?l:
00?o0000o`3oKol0ofl0Col0ofl00ol0003o0?oDo`3oe00bo`3oe003o`000?l0aOoo0<Go01ko0<Go
00?o0000o`1Pool0H?l04Ol0H?l00ol0003o1@3oo`D0o`0:o`D0o`03o`000?mZ0?ooJP3o00KoJP3o
00?o0000oll0ooo?0?l01?o?0?l00ol0003oo`3:ool0bP02ool0bP03o`000?oo06Goo`1U00;oo`1U
00?o0000ool00?oo0000=ooo00000ol0003oo`1Uool0I@02ool0I@03o`000?oo0<[oo`3:00;oo`3:
00?o0000oll0ooo?0?l00oo?0?l00ol0003oJP3oofX0o`06ofX0o`03o`000?l50?oo1@3o00_o1@3o
00?o0000o`1Pool0H?l04Ol0H?l00ol0003o0<Goo`35o`0Mo`35o`03o`000?l0omCo0?oD03;o0?oD
00?o0000o`3oKol0ofl0Col0ofl00ol0003o0?l:o`3o2P02o`3o2P[ooo]Z0Ol00001oookJP008Ooo
nfX00ol0003ooo]ZoookJP08oookJP?o0?l:00?o0000o`3oKol0ofl0D?l0ofl00ol0003o0?oDo`3o
e00bo`3oe003o`000?l0aOoo0<Go01ko0<Go00?o0000o`1Pool0H?l04Ol0H?l00ol0003o1@3oo`D0
o`0:o`D0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000oll0ooo?0?l01?o?0?l00ol0003oo`3:ool0
bP02ool0bP03o`000?oo06Goo`1U00;oo`1U00?o0000ool00?oo0000=ooo00001Ol0003oo`1Uool0
IOoo06Go000000Coo`3:00?o0000oll0ooo?0?l01?o?0?l00ol0003oJP3oofX0o`06ofX0o`03o`00
0?l50?oo1@3o00_o1@3o00?o0000o`1Pool0H?l04Ol0H?l00ol0003o0<Goo`35o`0Mo`35o`03o`00
0?l0omCo0?oD03?o0?oD00?o0000o`3oKol0ofl0Col0ofl01?l0003o0?l:o`3o2_l0o`X:oookJP7o
00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfX3o`3o2P03o`000?l0ofoo0?m_04oo0?m_
00?o0000o`3oe?l0om@0<ol0om@00ol0003o0<Goo`35o`0No`35o`03o`000?l0H?oo063o017o063o
00?o0000o`D0ool50?l02_l50?l00ol0003oJP3oofX0o`07ofX0o`03o`000?o?0?ooc`3o00Coc`3o
00Go0000ool0b_oo0<[oo`3:o`000005ool0I@03o`000?oo003oo`0003Goo`0000?o0000ool0IOoo
06D00_oo06D00ol0003oo`3:ool0bP02ool0bP03o`000?o?0?ooc`3o00Coc`3o00?o0000ofX0oomZ
0?l01_mZ0?l00ol0003o1@3oo`D0o`0;o`D0o`03o`000?l0H?oo063o017o063o00?o0000o`35ool0
aOl07Ol0aOl00ol0003o0?oDo`3oe00co`3oe003o`000?l0ofoo0?m_04oo0?m_00Co0000o`3o2_l0
o`[o0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z0_l0o`X00ol0003o
0?m_o`3oK`1?o`3oK`03o`000?l0omCo0?oD03?o0?oD00?o0000o`35ool0aOl07ol0aOl00ol0003o
063oo`1Po`0Ao`1Po`03o`000?l50?oo1@3o00[o1@3o00?o0000ofX0oomZ0?l01omZ0?l00ol0003o
c`3ooll0o`04oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo06D00ol0003o
o`00ool0000eool00003o`000?oo06Goo`1U00;oo`1U00?o0000ool0b_oo0<X00_oo0<X00ol0003o
c`3ooll0o`04oll0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000o`D0ool50?l02ol50?l00ol0003o
063oo`1Po`0Ao`1Po`03o`000?l0aOoo0<Go01ko0<Go00?o0000o`3oe?l0om@0<ol0om@00ol0003o
0?m_o`3oK`1?o`3oK`03o`000?l0o`[o0?l:00[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJP;o0?l:00?o0000o`3oKol0ofl0Col0ofl00ol0003o0?oDo`3oe00co`3oe003o`00
0?l0aOoo0<Go01oo0<Go00?o0000o`1Pool0H?l04Ol0H?l00ol0003o1@3oo`D0o`0:o`D0o`03o`00
0?mZ0?ooJP3o00OoJP3o00?o0000oll0ooo?0?l01?o?0?l00ol0003oo`3:ool0bP02ool0bP03o`00
0?oo06Goo`1U00;oo`1U00?o0000ool00?oo0000=Ooo00000ol0003oo`1Uool0I@02ool0I@03o`00
0?oo0<[oo`3:00;oo`3:00?o0000oll0ooo?0?l01?o?0?l00ol0003oJP3oofX0o`06ofX0o`03o`00
0?l50?oo1@3o00_o1@3o00?o0000o`1Pool0H?l04Ol0H?l00ol0003o0<Goo`35o`0No`35o`03o`00
0?l0omCo0?oD03?o0?oD00?o0000o`3oKol0ofl0Col0ofl00ol0003o0?l:o`3o2P0:oookJP7o0000
0OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0o`[o0000o`3oK`1@o`3oK`03o`000?l0
omCo0?oD03?o0?oD00?o0000o`35ool0aOl08?l0aOl00ol0003o063oo`1Po`0Ao`1Po`03o`000?l5
0?oo1@3o00[o1@3o00?o0000ofX0oomZ0?l02?mZ0?l00ol0003oc`3ooll0o`04oll0o`03o`000?oo
0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo06D00ol0003oo`00ool0000cool00003o`000?oo
06Goo`1U00;oo`1U00?o0000ool0b_oo0<X00_oo0<X00ol0003oc`3ooll0o`04oll0o`03o`000?mZ
0?ooJP3o00OoJP3o00?o0000o`D0ool50?l02ol50?l00ol0003o063oo`1Po`0Ao`1Po`03o`000?l0
aOoo0<Go01oo0<Go00?o0000o`3oe?l0om@0<ol0om@00ol0003o0?m_o`3oK`1?o`3oK`03o`000?l0
o`[ooo]Z00Wooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJP03o`3o2_l0003o
0?m_053o0?m_00?o0000o`3oe?l0om@0<ol0om@00ol0003o0<Goo`35o`0Po`35o`03o`000?l0H?oo
063o017o063o00?o0000o`D0ool50?l02ol50?l00ol0003oJP3oofX0o`07ofX0o`03o`000?o?0?oo
c`3o00Coc`3o00?o0000ool0b_oo0<X00ooo0<X00ol0003oo`1Uool0I@02ool0I@03o`000?oo003o
o`00037oo`0000?o0000ool0IOoo06D00_oo06D00ol0003oo`3:ool0bP03ool0bP03o`000?o?0?oo
c`3o00Coc`3o00?o0000ofX0oomZ0?l01_mZ0?l00ol0003o1@3oo`D0o`0<o`D0o`03o`000?l0H?oo
063o017o063o00?o0000o`35ool0aOl07ol0aOl00ol0003o0?oDo`3oe00do`3oe003o`000?l0ofoo
0?m_04oo0?m_00?o0000oookJ_oonfX02?oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0?l:o`000?l0ofl0Col0ofl00ol0003o0?oDo`3oe00do`3oe003o`000?l0aOoo0<Go
01oo0<Go00?o0000o`1Pool0H?l04_l0H?l00ol0003o1@3oo`D0o`0;o`D0o`03o`000?mZ0?ooJP3o
00OoJP3o00?o0000oll0ooo?0?l01?o?0?l00ol0003oo`3:ool0bP04ool0bP03o`000?oo06Goo`1U
00;oo`1U00?o0000ool00?oo0000;ooo00000ol0003oo`1Uool0I@02ool0I@03o`000?oo0<[oo`3:
00?oo`3:00?o0000oll0ooo?0?l01?o?0?l00ol0003oJP3oofX0o`07ofX0o`03o`000?l50?oo1@3o
00_o1@3o00?o0000o`1Pool0H?l04_l0H?l00ol0003o0<Goo`35o`0Oo`35o`03o`000?l0omCo0?oD
03Co0?oD00?o0000o`3oKol0ofl0Col0ofl00ol0003ooo]ZoookJP08oookJP7o00000OoonfX0027o
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003o0?m_o`3oK`1?o`3oK`03o`000?l0omCo0?oD03?o
0?oD00?o0000o`35ool0aOl08?l0aOl00ol0003o063oo`1Po`0Bo`1Po`03o`000?l50?oo1@3o00_o
1@3o00?o0000ofX0oomZ0?l02?mZ0?l00ol0003oc`3ooll0o`04oll0o`03o`000?oo0<[oo`3:00?o
o`3:00?o0000ool0IOoo06D00ooo06D00ol0003oo`00ool0000]ool00003o`000?oo06Goo`1U00;o
o`1U00?o0000ool0b_oo0<X01?oo0<X00ol0003oc`3ooll0o`04oll0o`03o`000?mZ0?ooJP3o00Oo
JP3o00?o0000o`D0ool50?l02ol50?l00ol0003o063oo`1Po`0Bo`1Po`03o`000?l0aOoo0<Go023o
0<Go00?o0000o`3oe?l0om@0=?l0om@00ol0003o0?m_o`3oK`1?o`3oK`03o`000?oonf[ooo]Z00Oo
oo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJU7o0?m_00?o0000o`3oe?l0om@0
=?l0om@00ol0003o0<Goo`35o`0Po`35o`03o`000?l0H?oo063o01;o063o00?o0000o`D0ool50?l0
3?l50?l00ol0003oJP3oofX0o`07ofX0o`03o`000?o?0?ooc`3o00Coc`3o00?o0000ool0b_oo0<X0
1?oo0<X00ol0003oo`1Uool0I@02ool0I@03o`000?oo003oo`0002goo`0000Go0000ool0IOoo06Go
o`1Uo`000006ool0bP03o`000?o?0?ooc`3o00Coc`3o00?o0000ofX0oomZ0?l02?mZ0?l00ol0003o
1@3oo`D0o`0;o`D0o`03o`000?l0H?oo063o01;o063o00?o0000o`35ool0aOl08?l0aOl00ol0003o
0?oDo`3oe00do`3oe003o`000?l0ofoo0?m_04oo0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`00
0?oonf[ooo]Z00Sooo]ZDOl0ofl00ol0003o0?oDo`3oe00co`3oe003o`000?l0aOoo0<Go027o0<Go
00?o0000o`1Pool0H?l04ol0H?l00ol0003o1@3oo`D0o`0;o`D0o`03o`000?mZ0?ooJP3o00SoJP3o
00?o0000oll0ooo?0?l01?o?0?l00ol0003oo`3:ool0bP04ool0bP03o`000?oo06Goo`1U00;oo`1U
00?o0000ool00?oo0000:ooo00001Ol0003oo`1Uool0IOoo06Go000000Ooo`3:00?o0000oll0ooo?
0?l01?o?0?l00ol0003oJP3oofX0o`07ofX0o`03o`000?l50?oo1@3o00co1@3o00?o0000o`1Pool0
H?l04ol0H?l00ol0003o0<Goo`35o`0Po`35o`03o`000?l0omCo0?oD03Co0?oD00?o0000o`3oKol0
ofl0C_l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfY@o`3oK`03o`00
0?l0omCo0?oD03Co0?oD00?o0000o`35ool0aOl08Ol0aOl00ol0003o063oo`1Po`0Co`1Po`03o`00
0?l50?oo1@3o00_o1@3o00?o0000ofX0oomZ0?l02?mZ0?l00ol0003oc`3ooll0o`04oll0o`03o`00
0?oo0<[oo`3:00Goo`3:00?o0000ool0IOoo06D00_oo06D00ol0003oo`00ool0000Yool00003o`00
0?oo06Goo`1U00;oo`1U00?o0000ool0b_oo0<X01?oo0<X00ol0003oc`3ooll0o`05oll0o`03o`00
0?mZ0?ooJP3o00OoJP3o00?o0000o`D0ool50?l03?l50?l00ol0003o063oo`1Po`0Co`1Po`03o`00
0?l0aOoo0<Go023o0<Go00?o0000o`3oe?l0om@0=Ol0om@00ol0003o0?m_o`3oK`1=o`3oK`[ooo]Z
0Ol00001oookJP008OoonfX3o`0000Sooo]ZD?l0ofl00ol0003o0?oDo`3oe00do`3oe003o`000?l0
aOoo0<Go027o0<Go00?o0000o`1Pool0H?l04ol0H?l00ol0003o1@3oo`D0o`0<o`D0o`03o`000?mZ
0?ooJP3o00OoJP3o00?o0000oll0ooo?0?l01?o?0?l00ol0003oo`3:ool0bP06ool0bP03o`000?oo
06Goo`1U00;oo`1U00?o0000ool00?oo00009ooo00000ol0003oo`1Uool0I@02ool0I@03o`000?oo
0<[oo`3:00Goo`3:00?o0000oll0ooo?0?l01?o?0?l00ol0003oJP3oofX0o`08ofX0o`03o`000?l5
0?oo1@3o00co1@3o00?o0000o`1Pool0H?l04ol0H?l00ol0003o0<Goo`35o`0Po`35o`03o`000?l0
omCo0?oD03Go0?oD00?o0000o`3oKol0ofl0COl0ofl8oookJP?o00000OoonfX0027ooo]Z00?o0000
oookJ_oonfX02?oonfY?o`3oK`03o`000?l0omCo0?oD03Co0?oD00?o0000o`35ool0aOl08_l0aOl0
0ol0003o063oo`1Po`0Co`1Po`03o`000?l50?oo1@3o00co1@3o00?o0000ofX0oomZ0?l02?mZ0?l0
0ol0003oc`3ooll0o`04oll0o`03o`000?oo0<[oo`3:00Goo`3:00?o0000ool0IOoo06D00ooo06D2
o`0002Goo`000_l00004ool0I@03o`000?oo0<[oo`3:00Goo`3:00?o0000oll0ooo?0?l01Oo?0?l0
0ol0003oJP3oofX0o`08ofX0o`03o`000?l50?oo1@3o00co1@3o00?o0000o`1Pool0H?l04ol0H?l0
0ol0003o0<Goo`35o`0Qo`35o`03o`000?l0omCo0?oD03Go0?oD00?o0000o`3oKol0ofl0C?l0ofl:
oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfY>o`3oK`03o`000?l0omCo0?oD
03Go0?oD00?o0000o`35ool0aOl08Ol0aOl00ol0003o063oo`1Po`0Do`1Po`03o`000?l50?oo1@3o
00co1@3o00?o0000ofX0oomZ0?l02?mZ0?l00ol0003oc`3ooll0o`05oll0o`03o`000?oo0<[oo`3:
00Goo`3:00?o0000ool0IOoo06D01?oo06D2o`00027oo`000_l00005ool0I@03o`000?oo0<[oo`3:
00Goo`3:00?o0000oll0ooo?0?l01Oo?0?l00ol0003oJP3oofX0o`09ofX0o`03o`000?l50?oo1@3o
00_o1@3o00?o0000o`1Pool0H?l05?l0H?l00ol0003o0<Goo`35o`0Qo`35o`03o`000?l0omCo0?oD
03Ko0?oD00?o0000o`3oKol0ofl0Bol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oo
nfX02?oonfY>o`3oK`03o`000?l0omCo0?oD03Go0?oD00?o0000o`35ool0aOl08Ol0aOl00ol0003o
063oo`1Po`0Do`1Po`03o`000?l50?oo1@3o00go1@3o00?o0000ofX0oomZ0?l01omZ0?l00ol0003o
c`3ooll0o`06oll0o`03o`000?oo0<[oo`3:00Goo`3:00?o0000ool0IOoo06D01Ooo06D00ol0003o
o`00ool0000Mool00003o`000?oo06Goo`1U00Coo`1U00?o0000ool0b_oo0<X01Ooo0<X00ol0003o
c`3ooll0o`06oll0o`03o`000?mZ0?ooJP3o00SoJP3o00?o0000o`D0ool50?l03?l50?l00ol0003o
063oo`1Po`0Do`1Po`03o`000?l0aOoo0<Go027o0<Go00?o0000o`3oe?l0om@0=_l0om@00ol0003o
0?m_o`3oK`1;o`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJTgo0?m_
00?o0000o`3oe?l0om@0=Ol0om@00ol0003o0<Goo`35o`0Ro`35o`03o`000?l0H?oo063o01Co063o
00?o0000o`D0ool50?l03Ol50?l00ol0003oJP3oofX0o`08ofX0o`03o`000?o?0?ooc`3o00Koc`3o
0_l00006ool0bP;o00001_oo06D2o`0001_oo`000_l00006ool0I@03o`000?oo0<[oo`3:00Coo`3:
0_l00008oll0o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000o`D0ool50?l03?l50?l00ol0003o063o
o`1Po`0Do`1Po`03o`000?l0aOoo0<Go02;o0<Go00?o0000o`3oe?l0om@0=_l0om@00ol0003o0?m_
o`3oK`1:o`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJTgo0?m_00?o
0000o`3oe?l0om@0=Ol0om@00ol0003o0<Goo`35o`0Ro`35o`03o`000?l0H?oo063o01Co063o00?o
0000o`D0ool50?l03Ol50?l00ol0003oJP3oofX0o`08ofX0o`03o`000?o?0?ooc`3o00Soc`3o00?o
0000ool0b_oo0<X01Ooo0<X00ol0003oo`1Uool0I@05ool0I@?o00005Ooo0003o`0000Ooo`1U00?o
0000ool0b_oo0<X01?oo0<X00ol0003oc`3ooll0o`08oll0o`03o`000?mZ0?ooJP3o00WoJP3o00?o
0000o`D0ool50?l03?l50?l00ol0003o063oo`1Po`0Do`1Po`03o`000?l0aOoo0<Go02?o0<Go00?o
0000o`3oe?l0om@0=Ol0om@00ol0003o0?m_o`3oK`1:o`3oK`[ooo]Z0Ol00001oookJP008OoonfX0
0ol0003ooo]ZoookJP08oookJTco0?m_00?o0000o`3oe?l0om@0=_l0om@00ol0003o0<Goo`35o`0R
o`35o`03o`000?l0H?oo063o01Co063o00?o0000o`D0ool50?l03_l50?l00ol0003oJP3oofX0o`08
ofX0o`03o`000?o?0?ooc`3o00Soc`3o00?o0000ool0b_oo0<X01Ooo0<X2o`0000Soo`1U0ol0000?
ool000?o00002?oo06D2o`0000Koo`3:00?o0000oll0ooo?0?l02?o?0?l00ol0003oJP3oofX0o`09
ofX0o`03o`000?l50?oo1@3o00go1@3o00?o0000o`1Pool0H?l05?l0H?l00ol0003o0<Goo`35o`0S
o`35o`03o`000?l0omCo0?oD03Ko0?oD00?o0000o`3oKol0ofl0BOl0ofl:oookJP7o00000OoonfX0
027ooo]Z00?o0000oookJ_oonfX02?oonfY<o`3oK`03o`000?l0omCo0?oD03Go0?oD00?o0000o`35
ool0aOl08ol0aOl00ol0003o063oo`1Po`0Eo`1Po`03o`000?l50?oo1@3o00go1@3o00?o0000ofX0
oomZ0?l02OmZ0?l00ol0003oc`3ooll0o`08oll0o`03o`000?oo0<[oo`3:00Koo`3:0ol00008ool0
I@oo00002?oo06D3o`0000Ooo`3:00?o0000oll0ooo?0?l02?o?0?l00ol0003oJP3oofX0o`0:ofX0
o`03o`000?l50?oo1@3o00co1@3o00?o0000o`1Pool0H?l05Ol0H?l00ol0003o0<Goo`35o`0To`35
o`03o`000?l0omCo0?oD03Go0?oD00?o0000o`3oKol0ofl0BOl0ofl:oookJP7o00000OoonfX0027o
oo]Z00?o0000oookJ_oonfX02?oonfY;o`3oK`03o`000?l0omCo0?oD03Ko0?oD00?o0000o`35ool0
aOl08ol0aOl00ol0003o063oo`1Po`0Eo`1Po`03o`000?l50?oo1@3o00ko1@3o00?o0000ofX0oomZ
0?l02OmZ0?l00ol0003oc`3ooll0o`08oll0o`;o00002Ooo0<X3o`0001Woo`1U0ol00009ool0bP03
o`000?o?0?ooc`3o00Soc`3o00?o0000ofX0oomZ0?l02_mZ0?l00ol0003o1@3oo`D0o`0=o`D0o`03
o`000?l0H?oo063o01Ko063o00?o0000o`35ool0aOl08ol0aOl00ol0003o0?oDo`3oe00fo`3oe003
o`000?l0ofoo0?m_04So0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z
B_l0ofl00ol0003o0?oDo`3oe00fo`3oe003o`000?l0aOoo0<Go02Co0<Go00?o0000o`1Pool0H?l0
5Ol0H?l00ol0003o1@3oo`D0o`0>o`D0o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000oll0ooo?0?l0
2_o?0?l00ol0003oo`3:ool0bP09ool0bP;o00005?oo06D3o`0000_oo`3:00?o0000oll0ooo?0?l0
2Oo?0?l00ol0003oJP3oofX0o`09ofX0o`03o`000?l50?oo1@3o00ko1@3o00?o0000o`1Pool0H?l0
5_l0H?l00ol0003o0<Goo`35o`0To`35o`03o`000?l0omCo0?oD03Ko0?oD00?o0000o`3oKol0ofl0
Aol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfY:o`3oK`03o`000?l0
omCo0?oD03Ko0?oD00?o0000o`35ool0aOl09?l0aOl00ol0003o063oo`1Po`0Fo`1Po`03o`000?l5
0?oo1@3o00go1@3o00?o0000ofX0oomZ0?l02_mZ0?l00ol0003oc`3ooll0o`0:oll0o`03o`000?oo
0<[oo`3:00[oo`3:0ol0000>ool0I@?o00003Ooo0<X00ol0003oc`3ooll0o`09oll0o`03o`000?mZ
0?ooJP3o00[oJP3o00?o0000o`D0ool50?l03_l50?l00ol0003o063oo`1Po`0Fo`1Po`03o`000?l0
aOoo0<Go02Co0<Go00?o0000o`3oe?l0om@0=_l0om@00ol0003o0?m_o`3oK`17o`3oK`[ooo]Z0Ol0
0001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJTWo0?m_00?o0000o`3oe?l0om@0=_l0om@0
0ol0003o0<Goo`35o`0Uo`35o`03o`000?l0H?oo063o01Ko063o00?o0000o`D0ool50?l03_l50?l0
0ol0003oJP3oofX0o`0:ofX0o`03o`000?o?0?ooc`3o00[oc`3o00?o0000ool0b_oo0<X03?oo0<X>
o`0000ooo`3:00?o0000oll0ooo?0?l02Oo?0?l00ol0003oJP3oofX0o`0:ofX0o`03o`000?l50?oo
1@3o00oo1@3o00?o0000o`1Pool0H?l05_l0H?l00ol0003o0<Goo`35o`0Uo`35o`03o`000?l0omCo
0?oD03Ko0?oD00?o0000o`3oKol0ofl0A_l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oook
J_oonfX02?oonfY9o`3oK`03o`000?l0omCo0?oD03Ko0?oD00?o0000o`35ool0aOl09?l0aOl00ol0
003o063oo`1Po`0Go`1Po`03o`000?l50?oo1@3o00ko1@3o00?o0000ofX0oomZ0?l02omZ0?l00ol0
003oc`3ooll0o`0:oll0o`03o`000?oo0<[oo`3:02Ooo`3:00?o0000oll0ooo?0?l02Oo?0?l00ol0
003oJP3oofX0o`0;ofX0o`03o`000?l50?oo1@3o00ko1@3o00?o0000o`1Pool0H?l05ol0H?l00ol0
003o0<Goo`35o`0Uo`35o`03o`000?l0omCo0?oD03Ko0?oD00?o0000o`3oKol0ofl0A_l0ofl:oook
JP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfY8o`3oK`03o`000?l0omCo0?oD03Oo
0?oD00?o0000o`35ool0aOl09?l0aOl00ol0003o063oo`1Po`0Go`1Po`03o`000?l50?oo1@3o00oo
1@3o00?o0000ofX0oomZ0?l02omZ0?l00ol0003oc`3ooll0o`0:oll0o`;o00009Ooo0<X2o`0000_o
c`3o00?o0000ofX0oomZ0?l02omZ0?l00ol0003o1@3oo`D0o`0?o`D0o`03o`000?l0H?oo063o01Oo
063o00?o0000o`35ool0aOl09Ol0aOl00ol0003o0?oDo`3oe00go`3oe003o`000?l0ofoo0?m_04Go
0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]ZB?l0ofl00ol0003o0?oD
o`3oe00fo`3oe003o`000?l0aOoo0<Go02Go0<Go00?o0000o`1Pool0H?l06?l0H?l00ol0003o1@3o
o`D0o`0>o`D0o`03o`000?mZ0?ooJP3o00coJP3o00?o0000oll0ooo?0?l02oo?0?l3o`0001ooo`3:
0ol0000<oll0o`03o`000?mZ0?ooJP3o00coJP3o00?o0000o`D0ool50?l03ol50?l00ol0003o063o
o`1Po`0Go`1Po`03o`000?l0aOoo0<Go02Ko0<Go00?o0000o`3oe?l0om@0=_l0om@00ol0003o0?m_
o`3oK`15o`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJTOo0?m_00?o
0000o`3oe?l0om@0=ol0om@00ol0003o0<Goo`35o`0Uo`35o`03o`000?l0H?oo063o01So063o00?o
0000o`D0ool50?l03ol50?l00ol0003oJP3oofX0o`0<ofX0o`03o`000?o?0?ooc`3o00goc`3o0ol0
000Iool0bP?o00003_o?0?l00ol0003oJP3oofX0o`0<ofX0o`03o`000?l50?oo1@3o013o1@3o00?o
0000o`1Pool0H?l06?l0H?l00ol0003o0<Goo`35o`0Uo`35o`03o`000?l0omCo0?oD03Oo0?oD00?o
0000o`3oKol0ofl0A?l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfY6
o`3oK`03o`000?l0omCo0?oD03Oo0?oD00?o0000o`35ool0aOl09_l0aOl00ol0003o063oo`1Po`0H
o`1Po`03o`000?l50?oo1@3o013o1@3o00?o0000ofX0oomZ0?l03?mZ0?l00ol0003oc`3ooll0o`0?
oll0o`;o00005?oo0<X3o`00013oc`3o00?o0000ofX0oomZ0?l03?mZ0?l00ol0003o1@3oo`D0o`0A
o`D0o`03o`000?l0H?oo063o01So063o00?o0000o`35ool0aOl09_l0aOl00ol0003o0?oDo`3oe00g
o`3oe003o`000?l0ofoo0?m_04?o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z
00Sooo]ZA_l0ofl00ol0003o0?oDo`3oe00go`3oe003o`000?l0aOoo0<Go02Ko0<Go00?o0000o`1P
ool0H?l06Ol0H?l00ol0003o1@3oo`D0o`0?o`D0o`03o`000?mZ0?ooJP3o00goJP3o00?o0000oll0
ooo?0?l04?o?0?l3o`0000koo`3:0ol0000Boll0o`03o`000?mZ0?ooJP3o00goJP3o00?o0000o`D0
ool50?l04?l50?l00ol0003o063oo`1Po`0Io`1Po`03o`000?l0aOoo0<Go02Ko0<Go00?o0000o`3o
e?l0om@0=ol0om@00ol0003o0?m_o`3oK`13o`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003o
oo]ZoookJP08oookJTGo0?m_00?o0000o`3oe?l0om@0=ol0om@00ol0003o0<Goo`35o`0Wo`35o`03
o`000?l0H?oo063o01Wo063o00?o0000o`D0ool50?l04?l50?l00ol0003oJP3oofX0o`0=ofX0o`;o
00004oo?0?l>o`0001?oc`3o0_l0000?ofX0o`03o`000?l50?oo1@3o017o1@3o00?o0000o`1Pool0
H?l06Ol0H?l00ol0003o0<Goo`35o`0Wo`35o`03o`000?l0omCo0?oD03Oo0?oD00?o0000o`3oKol0
ofl0@_l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfY5o`3oK`03o`00
0?l0omCo0?oD03Oo0?oD00?o0000o`35ool0aOl09ol0aOl00ol0003o063oo`1Po`0Io`1Po`03o`00
0?l50?oo1@3o017o1@3o00?o0000ofX0oomZ0?l03_mZ0?l2o`00033oc`3o0_l0000@ofX0o`03o`00
0?l50?oo1@3o01;o1@3o00?o0000o`1Pool0H?l06Ol0H?l00ol0003o0<Goo`35o`0Wo`35o`03o`00
0?l0omCo0?oD03Oo0?oD00?o0000o`3oKol0ofl0@_l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o
0000oookJ_oonfX02?oonfY4o`3oK`03o`000?l0omCo0?oD03Oo0?oD00?o0000o`35ool0aOl0:?l0
aOl00ol0003o063oo`1Po`0Jo`1Po`03o`000?l50?oo1@3o017o1@3o00?o0000ofX0oomZ0?l03omZ
0?l2o`0002goc`3o00?o0000ofX0oomZ0?l03omZ0?l00ol0003o1@3oo`D0o`0Bo`D0o`03o`000?l0
H?oo063o01[o063o00?o0000o`35ool0aOl0:?l0aOl00ol0003o0?oDo`3oe00go`3oe003o`000?l0
ofoo0?m_047o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z@ol0ofl0
0ol0003o0?oDo`3oe00ho`3oe003o`000?l0aOoo0<Go02So0<Go00?o0000o`1Pool0H?l06_l0H?l0
0ol0003o1@3oo`D0o`0Bo`D0o`03o`000?mZ0?ooJP3o013oJP3o0_l0000Yoll0o`;o00004OmZ0?l0
0ol0003o1@3oo`D0o`0Co`D0o`03o`000?l0H?oo063o01[o063o00?o0000o`35ool0aOl0:?l0aOl0
0ol0003o0?oDo`3oe00go`3oe003o`000?l0ofoo0?m_047o0?m_2_oonfX1o`00007ooo]Z000Qoook
JP03o`000?oonf[ooo]Z00Sooo]Z@_l0ofl00ol0003o0?oDo`3oe00ho`3oe003o`000?l0aOoo0<Go
02So0<Go00?o0000o`1Pool0H?l07?l0H?l00ol0003o1@3oo`D0o`0Bo`D0o`03o`000?mZ0?ooJP3o
017oJP3o0ol0000Soll0o`?o00004_mZ0?l00ol0003o1@3oo`D0o`0Co`D0o`03o`000?l0H?oo063o
01_o063o00?o0000o`35ool0aOl0:Ol0aOl00ol0003o0?oDo`3oe00go`3oe003o`000?l0ofoo0?m_
043o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z@_l0ofl00ol0003o
0?oDo`3oe00ho`3oe003o`000?l0aOoo0<Go02So0<Go00?o0000o`1Pool0H?l07?l0H?l00ol0003o
1@3oo`D0o`0Co`D0o`03o`000?mZ0?ooJP3o01?oJP3o0ol0000Moll0o`?o00005?mZ0?l00ol0003o
1@3oo`D0o`0Do`D0o`03o`000?l0H?oo063o01_o063o00?o0000o`35ool0aOl0:Ol0aOl00ol0003o
0?oDo`3oe00go`3oe003o`000?l0ofoo0?m_043o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`00
0?oonf[ooo]Z00Sooo]Z@Ol0ofl00ol0003o0?oDo`3oe00ho`3oe003o`000?l0aOoo0<Go02Wo0<Go
00?o0000o`1Pool0H?l07?l0H?l00ol0003o1@3oo`D0o`0Do`D0o`03o`000?mZ0?ooJP3o01GoJP3o
0ol0000Foll0o`Co00005_mZ0?l00ol0003o1@3oo`D0o`0Eo`D0o`03o`000?l0H?oo063o01_o063o
00?o0000o`35ool0aOl0:_l0aOl00ol0003o0?oDo`3oe00go`3oe003o`000?l0ofoo0?m_03oo0?m_
2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z@Ol0ofl00ol0003o0?oDo`3o
e00go`3oe003o`000?l0aOoo0<Go02[o0<Go00?o0000o`1Pool0H?l07Ol0H?l00ol0003o1@3oo`D0
o`0Do`D0o`03o`000?mZ0?ooJP3o01OoJP3o0ol0000@oll0o`?o00006OmZ0?l00ol0003o1@3oo`D0
o`0Eo`D0o`03o`000?l0H?oo063o01go063o00?o0000o`35ool0aOl0:_l0aOl00ol0003o0?oDo`3o
e00go`3oe003o`000?l0ofoo0?m_03ko0?m_2_oonfX1o`00007ooo]Z000QoookJP?o00002?oonfY0
o`3oK`03o`000?l0omCo0?oD03So0?oD00?o0000o`35ool0aOl0:_l0aOl00ol0003o063oo`1Po`0M
o`1Po`03o`000?l50?oo1@3o01Go1@3o00?o0000ofX0oomZ0?l06OmZ0?l@o`0001_oJP3o00?o0000
o`D0ool50?l05_l50?l00ol0003o063oo`1Po`0Mo`1Po`03o`000?l0aOoo0<Go02[o0<Go00?o0000
o`3oe?l0om@0=ol0om@00ol0003o0?m_o`3oK`0no`3oK`Sooo]Z0ol00001oookJP008OoonfX00ol0
003ooo]ZoookJP08oookJSoo0?m_00?o0000o`3oe?l0om@0>?l0om@00ol0003o0<Goo`35o`0[o`35
o`03o`000?l0H?oo063o01ko063o00?o0000o`D0ool50?l05Ol50?l00ol0003oJP3oofX0o`12ofX0
o`03o`000?l50?oo1@3o01Ko1@3o00?o0000o`1Pool0H?l07_l0H?l00ol0003o0<Goo`35o`0[o`35
o`03o`000?l0omCo0?oD03Oo0?oD00?o0000o`3oKol0ofl0?Ol0ofl:oookJP7o00000OoonfX0027o
oo]Z00?o0000oookJ_oonfX02?oonfXoo`3oK`03o`000?l0omCo0?oD03So0?oD00?o0000o`35ool0
aOl0:ol0aOl00ol0003o063oo`1Po`0No`1Po`03o`000?l50?oo1@3o01Ko1@3o0_l00010ofX0o`;o
00006Ol50?l00ol0003o063oo`1Po`0No`1Po`03o`000?l0aOoo0<Go02_o0<Go00?o0000o`3oe?l0
om@0>?l0om@00ol0003o0?m_o`3oK`0lo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJSko0?m_00?o0000o`3oe?l0om@0>?l0om@00ol0003o0<Goo`35o`0[o`35o`03o`00
0?l0H?oo063o01oo063o00?o0000o`D0ool50?l06?l50?l00ol0003oJP3oofX0o`0lofX0o`03o`00
0?l50?oo1@3o01So1@3o00?o0000o`1Pool0H?l07ol0H?l00ol0003o0<Goo`35o`0/o`35o`03o`00
0?l0omCo0?oD03Oo0?oD00?o0000o`3oKol0ofl0??l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o
0000oookJ_oonfX02?oonfXno`3oK`03o`000?l0omCo0?oD03So0?oD00?o0000o`35ool0aOl0:ol0
aOl00ol0003o063oo`1Po`0Po`1Po`03o`000?l50?oo1@3o01So1@3o00?o0000ofX0oomZ0?l0>_mZ
0?l00ol0003o1@3oo`D0o`0Io`D0o`03o`000?l0H?oo063o01oo063o00?o0000o`35ool0aOl0;?l0
aOl00ol0003o0?oDo`3oe00ho`3oe003o`000?l0ofoo0?m_03_o0?m_2_oonfX1o`00007ooo]Z000Q
oookJP03o`000?oonf[ooo]Z00Sooo]Z?Ol0ofl00ol0003o0?oDo`3oe00go`3oe0;o0000;_l0aOl0
0ol0003o063oo`1Po`0Po`1Po`03o`000?l50?oo1@3o01Wo1@3o0_l0000hofX0o`;o00006ol50?l0
0ol0003o063oo`1Po`0Po`1Po`03o`000?l0aOoo0<Go02go0<Go00?o0000o`3oe?l0om@0>?l0om@0
0ol0003o0?m_o`3oK`0jo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oook
JSgo0?m_00?o0000o`3oe?l0om@0=ol0om@00ol0003o0<Goo`35o`0]o`35o`03o`000?l0H?oo063o
023o063o00?o0000o`D0ool50?l06ol50?l2o`0003CoJP3o0_l0000Mo`D0o`03o`000?l0H?oo063o
023o063o00?o0000o`35ool0aOl0;Ol0aOl00ol0003o0?oDo`3oe00ho`3oe003o`000?l0ofoo0?m_
03[o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z??l0ofl00ol0003o
0?oDo`3oe00go`3oe003o`000?l0aOoo0<Go02ko0<Go00?o0000o`1Pool0H?l08Ol0H?l00ol0003o
1@3oo`D0o`0Lo`D0o`;o0000<?mZ0?l2o`0001ko1@3o00?o0000o`1Pool0H?l08Ol0H?l00ol0003o
0<Goo`35o`0^o`35o`03o`000?l0omCo0?oD03So0?oD00?o0000o`3oKol0ofl0>Ol0ofl:oookJP7o
00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXko`3oK`03o`000?l0omCo0?oD03Oo0?oD
00?o0000o`35ool0aOl0;_l0aOl00ol0003o063oo`1Po`0So`1Po`03o`000?l50?oo1@3o01go1@3o
0_l0000]ofX0o`03o`000?l50?oo1@3o01ko1@3o00?o0000o`1Pool0H?l08_l0H?l00ol0003o0<Go
o`35o`0^o`35o`03o`000?l0omCo0?oD03Oo0?oD00?o0000o`3oKol0ofl0>Ol0ofl:oookJP7o0000
0OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXko`3oK`03o`000?l0omCo0?oD03Oo0?oD00?o
0000o`35ool0aOl0;_l0aOl00ol0003o063oo`1Po`0So`1Po`03o`000?l50?oo1@3o01oo1@3o0_l0
000YofX0o`;o00008?l50?l00ol0003o063oo`1Po`0So`1Po`03o`000?l0aOoo0<Go02ko0<Go00?o
0000o`3oe?l0om@0>?l0om@00ol0003o0?m_o`3oK`0ho`3oK`[ooo]Z0Ol00001oookJP008OoonfX0
0ol0003ooo]ZoookJP08oookJS[o0?m_00?o0000o`3oe?l0om@0=ol0om@00ol0003o0<Goo`35o`0_
o`35o`03o`000?l0H?oo063o02Co063o00?o0000o`D0ool50?l08?l50?l3o`0002?oJP3o0ol0000R
o`D0o`03o`000?l0H?oo063o02?o063o00?o0000o`35ool0aOl0;ol0aOl00ol0003o0?oDo`3oe00g
o`3oe003o`000?l0ofoo0?m_03So0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z
00Sooo]Z>_l0ofl00ol0003o0?oDo`3oe00fo`3oe003o`000?l0aOoo0<Go02oo0<Go00?o0000o`1P
ool0H?l09Ol0H?l00ol0003o1@3oo`D0o`0So`D0o`Go00006OmZ0?l5o`0002Co1@3o00?o0000o`1P
ool0H?l09Ol0H?l00ol0003o0<Goo`35o`0_o`35o`03o`000?l0omCo0?oD03Oo0?oD00?o0000o`3o
Kol0ofl0=ol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXio`3oK`03
o`000?l0omCo0?oD03Ko0?oD00?o0000o`35ool0aOl0<?l0aOl00ol0003o063oo`1Po`0Vo`1Po`03
o`000?l50?oo1@3o02Oo1@3o1?l0000@ofX0o`Go0000:?l50?l00ol0003o063oo`1Po`0Vo`1Po`03
o`000?l0aOoo0<Go033o0<Go00?o0000o`3oe?l0om@0=ol0om@00ol0003o0?m_o`3oK`0fo`3oK`[o
oo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJSSo0?m_00?o0000o`3oe?l0om@0
=ol0om@00ol0003o0<Goo`35o`0`o`35o`03o`000?l0H?oo063o02Oo063o00?o0000o`D0ool50?l0
:_l50?l@o`0002go1@3o00?o0000o`1Pool0H?l09_l0H?l00ol0003o0<Goo`35o`0`o`35o`03o`00
0?l0omCo0?oD03Oo0?oD00?o0000o`3oKol0ofl0=_l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o
0000oookJ_oonfX02?oonfXho`3oK`03o`000?l0omCo0?oD03Ko0?oD00?o0000o`35ool0aOl0<?l0
aOl00ol0003o063oo`1Po`0Xo`1Po`03o`000?l50?oo1@3o06Ko1@3o00?o0000o`1Pool0H?l0:?l0
H?l00ol0003o0<Goo`35o`0`o`35o`03o`000?l0omCo0?oD03Oo0?oD00?o0000o`3oKol0ofl0=Ol0
ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXgo`3oK`03o`000?l0omCo
0?oD03Ko0?oD00?o0000o`35ool0aOl0<Ol0aOl00ol0003o063oo`1Po`0Yo`1Po`03o`000?l50?oo
1@3o06Go1@3o00?o0000o`1Pool0H?l0:?l0H?l00ol0003o0<Goo`35o`0ao`35o`03o`000?l0omCo
0?oD03Ko0?oD00?o0000o`3oKol0ofl0=Ol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oook
J_oonfX02?oonfXgo`3oK`03o`000?l0omCo0?oD03Ko0?oD00?o0000o`35ool0aOl0<Ol0aOl00ol0
003o063oo`1Po`0Yo`1Po`03o`000?l50?oo1@3o06Co1@3o00?o0000o`1Pool0H?l0:Ol0H?l00ol0
003o0<Goo`35o`0ao`35o`03o`000?l0omCo0?oD03Oo0?oD00?o0000o`3oKol0ofl0=?l0ofl:oook
JP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXfo`3oK`03o`000?l0omCo0?oD03Ko
0?oD00?o0000o`35ool0aOl0<Ol0aOl00ol0003o063oo`1Po`0[o`1Po`03o`000?l50?oo1@3o06?o
1@3o00?o0000o`1Pool0H?l0:_l0H?l00ol0003o0<Goo`35o`0ao`35o`03o`000?l0omCo0?oD03Ko
0?oD00?o0000o`3oKol0ofl0=?l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX0
2?oonfXeo`3oK`03o`000?l0omCo0?oD03Ko0?oD00?o0000o`35ool0aOl0<_l0aOl00ol0003o063o
o`1Po`0/o`1Po`03o`000?l50?oo1@3o063o1@3o0_l0000]o`1Po`03o`000?l0aOoo0<Go03;o0<Go
00?o0000o`3oe?l0om@0=_l0om@00ol0003o0?m_o`3oK`0co`3oK`[ooo]Z0Ol00001oookJP008Ooo
nfX00ol0003ooo]ZoookJP08oookJSGo0?m_00?o0000o`3oe?l0om@0=_l0om@00ol0003o0<Goo`35
o`0bo`35o`03o`000?l0H?oo063o02go063o00?o0000o`D0ool50?l0G_l50?l00ol0003o063oo`1P
o`0]o`1Po`03o`000?l0aOoo0<Go03;o0<Go00?o0000o`3oe?l0om@0=ol0om@00ol0003o0?m_o`3o
K`0bo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJSGo0?m_00?o0000
o`3oe?l0om@0=Ol0om@00ol0003o0<Goo`35o`0bo`35o`03o`000?l0H?oo063o02oo063o00?o0000
o`D0ool50?l0G?l50?l00ol0003o063oo`1Po`0_o`1Po`03o`000?l0aOoo0<Go03;o0<Go00?o0000
o`3oe?l0om@0=_l0om@00ol0003o0?m_o`3oK`0bo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0
003ooo]ZoookJP08oookJSCo0?m_00?o0000o`3oe?l0om@0=Ol0om@00ol0003o0<Goo`35o`0co`35
o`03o`000?l0H?oo063o033o063o00?o0000o`D0ool50?l0F_l50?l00ol0003o063oo`1Po`0ao`1P
o`03o`000?l0aOoo0<Go03;o0<Go00?o0000o`3oe?l0om@0=_l0om@00ol0003o0?m_o`3oK`0ao`3o
K`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJSCo0?m_00?o0000o`3oe?l0
om@0=?l0om@00ol0003o0<Goo`35o`0co`35o`03o`000?l0H?oo063o037o063o00?o0000o`D0ool5
0?l0F_l50?l00ol0003o063oo`1Po`0ao`1Po`03o`000?l0aOoo0<Go03?o0<Go00?o0000o`3oe?l0
om@0=Ol0om@00ol0003o0?m_o`3oK`0ao`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJS?o0?m_00?o0000o`3oe?l0om@0=?l0om@00ol0003o0<Goo`35o`0do`35o`03o`00
0?l0H?oo063o03;o063o00?o0000o`D0ool50?l0F?l50?l00ol0003o063oo`1Po`0co`1Po`03o`00
0?l0aOoo0<Go03?o0<Go00?o0000o`3oe?l0om@0=Ol0om@00ol0003o0?m_o`3oK`0`o`3oK`[ooo]Z
0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJS?o0?m_00?o0000o`3oe?l0om@0=?l0
om@00ol0003o0<Goo`35o`0co`35o`03o`000?l0H?oo063o03Co063o00?o0000o`D0ool50?l0E_l5
0?l00ol0003o063oo`1Po`0eo`1Po`03o`000?l0aOoo0<Go03;o0<Go00?o0000o`3oe?l0om@0=Ol0
om@00ol0003o0?m_o`3oK`0`o`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08
oookJS;o0?m_00?o0000o`3oe?l0om@0=?l0om@00ol0003o0<Goo`35o`0do`35o`03o`000?l0H?oo
063o03Go063o00?o0000o`D0ool50?l0EOl50?l00ol0003o063oo`1Po`0eo`1Po`03o`000?l0aOoo
0<Go03?o0<Go00?o0000o`3oe?l0om@0=Ol0om@00ol0003o0?m_o`3oK`0_o`3oK`[ooo]Z0Ol00001
oookJP008OoonfX3o`0000Sooo]Z<Ol0ofl00ol0003o0?oDo`3oe00do`3oe003o`000?l0aOoo0<Go
03Co0<Go00?o0000o`1Pool0H?l0=_l0H?l00ol0003o1@3oo`D0o`1Do`D0o`03o`000?l0H?oo063o
03Oo063o00?o0000o`35ool0aOl0<ol0aOl00ol0003o0?oDo`3oe00do`3oe003o`000?l0ofoo0?m_
02oo0?m_2?oonfX3o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z<Ol0ofl00ol0003o
0?oDo`3oe00co`3oe003o`000?l0aOoo0<Go03Co0<Go00?o0000o`1Pool0H?l0>?l0H?l00ol0003o
1@3oo`D0o`1Bo`D0o`03o`000?l0H?oo063o03Wo063o00?o0000o`35ool0aOl0<ol0aOl00ol0003o
0?oDo`3oe00co`3oe003o`000?l0ofoo0?m_02oo0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`00
0?oonf[ooo]Z00Sooo]Z<?l0ofl00ol0003o0?oDo`3oe00co`3oe003o`000?l0aOoo0<Go03Co0<Go
00?o0000o`1Pool0H?l0>_l0H?l00ol0003o1@3oo`D0o`1Ao`D0o`03o`000?l0H?oo063o03[o063o
00?o0000o`35ool0aOl0<ol0aOl00ol0003o0?oDo`3oe00co`3oe003o`000?l0ofoo0?m_02ko0?m_
2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z<?l0ofl00ol0003o0?oDo`3o
e00co`3oe003o`000?l0aOoo0<Go03Co0<Go00?o0000o`1Pool0H?l0>_l0H?l00ol0003o1@3oo`D0
o`1@o`D0o`03o`000?l0H?oo063o03_o063o00?o0000o`35ool0aOl0<ol0aOl00ol0003o0?oDo`3o
e00co`3oe003o`000?l0ofoo0?m_02ko0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[o
oo]Z00Sooo]Z;ol0ofl00ol0003o0?oDo`3oe00co`3oe003o`000?l0aOoo0<Go03Co0<Go00?o0000
o`1Pool0H?l0??l0H?l00ol0003o1@3oo`D0o`1?o`D0o`03o`000?l0H?oo063o03co063o00?o0000
o`35ool0aOl0<ol0aOl00ol0003o0?oDo`3oe00co`3oe003o`000?l0ofoo0?m_02go0?m_2_oonfX1
o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z;ol0ofl00ol0003o0?oDo`3oe00bo`3o
e003o`000?l0aOoo0<Go03Co0<Go00?o0000o`1Pool0H?l0?_l0H?l00ol0003o1@3oo`D0o`1=o`D0
o`03o`000?l0H?oo063o03ko063o00?o0000o`35ool0aOl0<ol0aOl00ol0003o0?oDo`3oe00bo`3o
e003o`000?l0ofoo0?m_02go0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00So
oo]Z;_l0ofl00ol0003o0?oDo`3oe00bo`3oe003o`000?l0aOoo0<Go03?o0<Go0_l00012o`1Po`;o
0000Bol50?l2o`0004;o063o0_l0000do`35o`03o`000?l0omCo0?oD03;o0?oD00?o0000o`3oKol0
ofl0;?l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfX^o`3oK`03o`00
0?l0omCo0?oD03;o0?oD00?o0000o`35ool0aOl0<_l0aOl00ol0003o063oo`1Po`14o`1Po`03o`00
0?l50?oo1@3o04Oo1@3o00?o0000o`1Pool0H?l0A?l0H?l00ol0003o0<Goo`35o`0ao`35o`03o`00
0?l0omCo0?oD03;o0?oD00?o0000o`3oKol0ofl0;?l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o
0000oookJ_oonfX02?oonfX]o`3oK`03o`000?l0omCo0?oD03;o0?oD00?o0000o`35ool0aOl0<_l0
aOl00ol0003o063oo`1Po`16o`1Po`03o`000?l50?oo1@3o04Co1@3o0_l00018o`1Po`03o`000?l0
aOoo0<Go037o0<Go00?o0000o`3oe?l0om@0<_l0om@00ol0003o0?m_o`3oK`0[o`3oK`[ooo]Z0Ol0
0001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJRgo0?m_00?o0000o`3oe?l0om@0<Ol0om@0
0ol0003o0<Goo`35o`0ao`35o`;o0000B_l0H?l00ol0003o1@3oo`D0o`12o`D0o`03o`000?l0H?oo
063o04Wo063o00?o0000o`35ool0aOl0<Ol0aOl00ol0003o0?oDo`3oe00ao`3oe003o`000?l0ofoo
0?m_02_o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z;?l0ofl00ol0
003o0?oDo`3oe00ao`3oe003o`000?l0aOoo0<Go037o0<Go00?o0000o`1Pool0H?l0Bol0H?l2o`00
043o1@3o0_l0001=o`1Po`03o`000?l0aOoo0<Go037o0<Go00?o0000o`3oe?l0om@0<Ol0om@00ol0
003o0?m_o`3oK`0Zo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJRco
0?m_00?o0000o`3oe?l0om@0<Ol0om@00ol0003o0<Goo`35o`0`o`35o`03o`000?l0H?oo063o04ko
063o0_l0000lo`D0o`;o0000D?l0H?l00ol0003o0<Goo`35o`0ao`35o`03o`000?l0omCo0?oD033o
0?oD00?o0000o`3oKol0ofl0:_l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX0
2?oonfX[o`3oK`03o`000?l0omCo0?oD037o0?oD00?o0000o`35ool0aOl0;ol0aOl2o`0005?o063o
0_l0000ho`D0o`;o0000Dol0H?l2o`0003;o0<Go00?o0000o`3oe?l0om@0<?l0om@00ol0003o0?m_
o`3oK`0Yo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJR_o0?m_00?o
0000o`3oe?l0om@0<?l0om@00ol0003o0<Goo`35o`0_o`35o`03o`000?l0H?oo063o05Go063o0_l0
000do`D0o`;o0000Eol0H?l00ol0003o0<Goo`35o`0`o`35o`03o`000?l0omCo0?oD033o0?oD00?o
0000o`3oKol0ofl0:?l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfX[
o`3oK`03o`000?l0omCo0?oD02oo0?oD00?o0000o`35ool0aOl0;ol0aOl00ol0003o063oo`1Po`1H
o`1Po`;o0000<Ol50?l00ol0003o063oo`1Po`1Ho`1Po`;o0000<Ol0aOl00ol0003o0?oDo`3oe00_
o`3oe003o`000?l0ofoo0?m_02So0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z
00Sooo]Z:_l0ofl00ol0003o0?oDo`3oe00`o`3oe003o`000?l0aOoo0<Go02go0<Go0_l0001Mo`1P
o`;o0000;Ol50?l2o`0005go063o00?o0000o`35ool0aOl0;_l0aOl00ol0003o0?oDo`3oe00`o`3o
e003o`000?l0ofoo0?m_02Oo0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00So
oo]Z:_l0ofl00ol0003o0?oDo`3oe00_o`3oe003o`000?l0aOoo0<Go02go0<Go00?o0000o`1Pool0
H?l0Gol0H?l2o`0002Wo1@3o0_l0001Po`1Po`03o`000?l0aOoo0<Go02ko0<Go00?o0000o`3oe?l0
om@0;ol0om@00ol0003o0?m_o`3oK`0Wo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJRWo0?m_00?o0000o`3oe?l0om@0;ol0om@00ol0003o0<Goo`35o`0]o`35o`03o`00
0?l0H?oo063o06;o063o0ol0000So`D0o`?o0000Hol0H?l2o`0002oo0<Go00?o0000o`3oe?l0om@0
;ol0om@00ol0003o0?m_o`3oK`0Vo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Zoook
JP08oookJRWo0?m_00?o0000o`3oe?l0om@0;_l0om@00ol0003o0<Goo`35o`0]o`35o`03o`000?l0
H?oo063o06Ko063o0ol0000Lo`D0o`Co0000J?l0H?l00ol0003o0<Goo`35o`0]o`35o`03o`000?l0
omCo0?oD02ko0?oD00?o0000o`3oKol0ofl09_l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000
oookJ_oonfX02?oonfXXo`3oK`03o`000?l0omCo0?oD02ko0?oD00?o0000o`35ool0aOl0;?l0aOl2
o`0006co063o1Ol0000Bo`D0o`Go0000KOl0H?l2o`0002ko0<Go00?o0000o`3oe?l0om@0;_l0om@0
0ol0003o0?m_o`3oK`0Uo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oook
JRSo0?m_00?o0000o`3oe?l0om@0;_l0om@00ol0003o0<Goo`35o`0[o`35o`03o`000?l0H?oo063o
077o063o4_l0001do`1Po`03o`000?l0aOoo0<Go02_o0<Go00?o0000o`3oe?l0om@0;_l0om@00ol0
003o0?m_o`3oK`0Uo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJROo
0?m_00?o0000o`3oe?l0om@0;_l0om@00ol0003o0<Goo`35o`0[o`35o`03o`000?l0H?oo063o0?Wo
063o00?o0000o`35ool0aOl0:ol0aOl00ol0003o0?oDo`3oe00^o`3oe003o`000?l0ofoo0?m_02Co
0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z9ol0ofl00ol0003o0?oD
o`3oe00]o`3oe003o`000?l0aOoo0<Go02[o0<Go0_l0003mo`1Po`;o0000;?l0aOl00ol0003o0?oD
o`3oe00]o`3oe003o`000?l0ofoo0?m_02Co0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oo
nf[ooo]Z00Sooo]Z9_l0ofl00ol0003o0?oDo`3oe00]o`3oe003o`000?l0aOoo0<Go02[o0<Go00?o
0000o`1Pool0H?l0ool0H?l00ol0003o0<Goo`35o`0Zo`35o`03o`000?l0omCo0?oD02go0?oD00?o
0000o`3oKol0ofl08ol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXV
o`3oK`03o`000?l0omCo0?oD02go0?oD00?o0000o`35ool0aOl0:?l0aOl2o`000?oo063o1?l0H?l2
o`0002[o0<Go00?o0000o`3oe?l0om@0;Ol0om@00ol0003o0?m_o`3oK`0So`3oK`[ooo]Z0Ol00001
oookJP008OoonfX00ol0003ooo]ZoookJP08oookJRGo0?m_00?o0000o`3oe?l0om@0;Ol0om@00ol0
003o0<Goo`35o`0Xo`35o`03o`000?l0H?oo063o0?oo063o1_l0H?l00ol0003o0<Goo`35o`0Xo`35
o`03o`000?l0omCo0?oD02go0?oD00?o0000o`3oKol0ofl08_l0ofl:oookJP7o00000OoonfX0027o
oo]Z0ol00008oookJRGo0?m_00?o0000o`3oe?l0om@0;?l0om@00ol0003o0<Goo`35o`0Wo`35o`;o
0000ool0H?l:o`1Po`;o0000:Ol0aOl00ol0003o0?oDo`3oe00/o`3oe003o`000?l0ofoo0?m_02;o
0?m_2?oonfX3o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z9Ol0ofl00ol0003o0?oD
o`3oe00[o`3oe003o`000?l0aOoo0<Go02Oo0<Go00?o0000o`1Pool0H?l0ool0H?l<o`1Po`03o`00
0?l0aOoo0<Go02Oo0<Go00?o0000o`3oe?l0om@0:ol0om@00ol0003o0?m_o`3oK`0Ro`3oK`[ooo]Z
0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJRCo0?m_00?o0000o`3oe?l0om@0;?l0
om@00ol0003o0<Goo`35o`0Vo`35o`03o`000?l0H?oo063o0?oo063o3_l0H?l00ol0003o0<Goo`35
o`0Vo`35o`03o`000?l0omCo0?oD02co0?oD00?o0000o`3oKol0ofl08Ol0ofl:oookJP7o00000Ooo
nfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXTo`3oK`03o`000?l0omCo0?oD02_o0?oD00?o0000
o`35ool0aOl09Ol0aOl2o`000?oo063o4_l0H?l2o`0002Oo0<Go00?o0000o`3oe?l0om@0:ol0om@0
0ol0003o0?m_o`3oK`0Qo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oook
JR?o0?m_00?o0000o`3oe?l0om@0:ol0om@00ol0003o0<Goo`35o`0Uo`35o`03o`000?l0H?oo063o
0?oo063o5?l0H?l00ol0003o0<Goo`35o`0Uo`35o`03o`000?l0omCo0?oD02_o0?oD00?o0000o`3o
Kol0ofl08?l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXSo`3oK`03
o`000?l0omCo0?oD02[o0?oD00?o0000o`35ool0aOl09?l0aOl2o`000?oo063o6?l0H?l2o`0002Ko
0<Go00?o0000o`3oe?l0om@0:_l0om@00ol0003o0?m_o`3oK`0Po`3oK`[ooo]Z0Ol00001oookJP00
8OoonfX00ol0003ooo]ZoookJP08oookJR;o0?m_00?o0000o`3oe?l0om@0:_l0om@00ol0003o0<Go
o`35o`0So`35o`;o0000ool0H?lLo`1Po`;o00009Ol0aOl00ol0003o0?oDo`3oe00Zo`3oe003o`00
0?l0ofoo0?m_01oo0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z8_l0
ofl00ol0003o0?oDo`3oe00Zo`3oe003o`000?l0aOoo0<Go02;o0<Go00?o0000o`1Pool0H?l0ool0
H?lNo`1Po`03o`000?l0aOoo0<Go02;o0<Go00?o0000o`3oe?l0om@0:_l0om@00ol0003o0?m_o`3o
K`0Oo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJR7o0?m_00?o0000
o`3oe?l0om@0:_l0om@00ol0003o0<Goo`35o`0Ro`35o`03o`000?l0H?oo063o0?oo063o8?l0H?l0
0ol0003o0<Goo`35o`0Ro`35o`03o`000?l0omCo0?oD02[o0?oD00?o0000o`3oKol0ofl07_l0ofl:
oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXQo`3oK`03o`000?l0omCo0?oD
02Wo0?oD00?o0000o`35ool0aOl08_l0aOl00ol0003o063oo`1Po`3oo`1Pob;o063o00?o0000o`35
ool0aOl08Ol0aOl00ol0003o0?oDo`3oe00Zo`3oe003o`000?l0ofoo0?m_01ko0?m_2_oonfX1o`00
007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z8Ol0ofl00ol0003o0?oDo`3oe00Yo`3oe003
o`000?l0aOoo0<Go027o0<Go00?o0000o`1Pool0H?l0ool0H?lTo`1Po`03o`000?l0aOoo0<Go027o
0<Go00?o0000o`3oe?l0om@0:Ol0om@00ol0003o0?m_o`3oK`0No`3oK`[ooo]Z0Ol00001oookJP00
8OoonfX00ol0003ooo]ZoookJP08oookJR3o0?m_00?o0000o`3oe?l0om@0:Ol0om@00ol0003o0<Go
o`35o`0Po`35o`;o0000ool0H?lXo`1Po`03o`000?l0aOoo0<Go027o0<Go00?o0000o`3oe?l0om@0
:Ol0om@00ol0003o0?m_o`3oK`0Mo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Zoook
JP08oookJR3o0?m_00?o0000o`3oe?l0om@0:?l0om@00ol0003o0<Goo`35o`0Po`35o`03o`000?l0
H?oo063o0?oo063o:Ol0H?l00ol0003o0<Goo`35o`0Po`35o`03o`000?l0omCo0?oD02Wo0?oD00?o
0000o`3oKol0ofl07Ol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXP
o`3oK`03o`000?l0omCo0?oD02So0?oD00?o0000o`35ool0aOl07ol0aOl00ol0003o063oo`1Po`0g
o`1Po`ko0000Wol0H?l?o`0003Oo063o00?o0000o`35ool0aOl08?l0aOl00ol0003o0?oDo`3oe00X
o`3oe003o`000?l0ofoo0?m_01go0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z
00Sooo]Z7ol0ofl00ol0003o0?oDo`3oe00Xo`3oe003o`000?l0aOoo0<Go01oo0<Go00?o0000o`1P
ool0H?l0;ol0H?l9o`0000ko1@3o2?l0002>o`1Po`Wo00003ol50?l8o`00033o063o00?o0000o`35
ool0aOl07ol0aOl00ol0003o0?oDo`3oe00Yo`3oe003o`000?l0ofoo0?m_01co0?m_2_oonfX1o`00
007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z7ol0ofl00ol0003o0?oDo`3oe00Xo`3oe003
o`000?l0aOoo0<Go01ko0<Go00?o0000o`1Pool0H?l0:ol0H?l5o`0001oo1@3o1Ol00024o`1Po`Go
00008?l50?l5o`0002co063o00?o0000o`35ool0aOl07ol0aOl00ol0003o0?oDo`3oe00Xo`3oe003
o`000?l0ofoo0?m_01co0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z
7ol0ofl00ol0003o0?oDo`3oe00Wo`3oe003o`000?l0aOoo0<Go01ko0<Go00?o0000o`1Pool0H?l0
9ol0H?l5o`0002Wo1@3o1Ol0001ko`1Po`Co0000:_l50?l4o`0002Wo063o00?o0000o`35ool0aOl0
7_l0aOl00ol0003o0?oDo`3oe00Xo`3oe003o`000?l0ofoo0?m_01co0?m_2_oonfX1o`00007ooo]Z
000QoookJP03o`000?oonf[ooo]Z00Sooo]Z7_l0ofl00ol0003o0?oDo`3oe00Wo`3oe003o`000?l0
aOoo0<Go01ko0<Go00?o0000o`1Pool0H?l09Ol0H?l3o`0003?o1@3o1?l0001do`1Po`?o0000<_l5
0?l4o`0002Ko063o00?o0000o`35ool0aOl07_l0aOl00ol0003o0?oDo`3oe00Xo`3oe003o`000?l0
ofoo0?m_01_o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z7_l0ofl0
0ol0003o0?oDo`3oe00Wo`3oe003o`000?l0aOoo0<Go01go0<Go00?o0000o`1Pool0H?l08ol0H?l3
o`0003[o1@3o0ol0001^o`1Po`?o0000>Ol50?l3o`0002Co063o00?o0000o`35ool0aOl07_l0aOl0
0ol0003o0?oDo`3oe00Wo`3oe003o`000?l0ofoo0?m_01_o0?m_2_oonfX1o`00007ooo]Z000Qoook
JP03o`000?oonf[ooo]Z00Sooo]Z7_l0ofl00ol0003o0?oDo`3oe00Vo`3oe003o`000?l0aOoo0<Go
01go0<Go00?o0000o`1Pool0H?l08Ol0H?l3o`00043o1@3o0ol0001Xo`1Po`?o0000?ol50?l3o`00
02;o063o00?o0000o`35ool0aOl07Ol0aOl00ol0003o0?oDo`3oe00Wo`3oe003o`000?l0ofoo0?m_
01_o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z7Ol0ofl00ol0003o
0?oDo`3oe00Vo`3oe003o`000?l0aOoo0<Go01go0<Go00?o0000o`1Pool0H?l07ol0H?l3o`0004Ko
1@3o0_l0001So`1Po`?o0000AOl50?l3o`00023o063o00?o0000o`35ool0aOl07Ol0aOl00ol0003o
0?oDo`3oe00Wo`3oe003o`000?l0ofoo0?m_01[o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`00
0?oonf[ooo]Z00Sooo]Z7Ol0ofl00ol0003o0?oDo`3oe00Vo`3oe003o`000?l0aOoo0<Go01go0<Go
00?o0000o`1Pool0H?l07Ol0H?l2o`0004_o1@3o0_l0001No`1Po`?o0000Bol50?l2o`0001oo063o
00?o0000o`35ool0aOl07?l0aOl00ol0003o0?oDo`3oe00Wo`3oe003o`000?l0ofoo0?m_01[o0?m_
2_oonfX1o`00007ooo]Z000AoookJPGo001o2ooonfX00ol0003ooo]ZoookJP08oookJQco0?m_00?o
0000o`3oe?l0om@09_l0om@00ol0003o0<Goo`35o`0Mo`35o`03o`000?l0H?oo063o01co063o0_l0
001?o`D0o`;o0000F_l0H?l2o`00053o1@3o0_l0000No`1Po`03o`000?l0aOoo0<Go01co0<Go00?o
0000o`3oe?l0om@09_l0om@00ol0003o0?m_o`3oK`0Jo`3oK`[ooo]Z0Ol00001oookJP004?oonfX7
o`00O`[ooo]Z00?o0000oookJ_oonfX02?oonfXLo`3oK`03o`000?l0omCo0?oD02Ko0?oD00?o0000
o`35ool0aOl07?l0aOl00ol0003o063oo`1Po`0Ko`1Po`;o0000Dol50?l00ol0003o063oo`1Po`1F
o`1Po`03o`000?l50?oo1@3o05;o1@3o0_l0000Mo`1Po`03o`000?l0aOoo0<Go01_o0<Go00?o0000
o`3oe?l0om@09ol0om@00ol0003o0?m_o`3oK`0Io`3oK`[ooo]Z0Ol00001oookJP004?oonfX3o`00
O`04oookJ_l007oo001oo`00O`[ooo]Z00?o0000oookJ_oonfX02?oonfXLo`3oK`03o`000?l0omCo
0?oD02Go0?oD00?o0000o`35ool0aOl07?l0aOl00ol0003o063oo`1Po`0Jo`1Po`;o0000E_l50?l0
0ol0003o063oo`1Po`1Do`1Po`03o`000?l50?oo1@3o05Go1@3o0_l0000Lo`1Po`03o`000?l0aOoo
0<Go01_o0<Go00?o0000o`3oe?l0om@09_l0om@00ol0003o0?m_o`3oK`0Io`3oK`[ooo]Z0Ol00001
oookJP003ooonfX3o`00O`?ooo]Z0ol007l9oookJP03o`000?oonf[ooo]Z00Sooo]Z6ol0ofl00ol0
003o0?oDo`3oe00Uo`3oe003o`000?l0aOoo0<Go01co0<Go00?o0000o`1Pool0H?l06Ol0H?l2o`00
05Wo1@3o00?o0000o`1Pool0H?l0D_l0H?l00ol0003o1@3oo`D0o`1Ho`D0o`;o00006ol0H?l00ol0
003o0<Goo`35o`0Ko`35o`03o`000?l0omCo0?oD02Go0?oD00?o0000o`3oKol0ofl06Ol0ofl:oook
JP7o00000OoonfX000oooo]Z0ol007l3oookJP?o001o2OoonfX5o`0000Kooo]Z6ol0ofl00ol0003o
0?oDo`3oe00Uo`3oe003o`000?l0aOoo0<Go01_o0<Go00?o0000o`1Pool0H?l06Ol0H?l00ol0003o
1@3oo`D0o`1Jo`D0o`03o`000?l0H?oo063o053o063o00?o0000o`D0ool50?l0Fol50?l00ol0003o
063oo`1Po`0Io`1Po`03o`000?l0aOoo0<Go01[o0<Go00?o0000o`3oe?l0om@09Ol0om@00ol0003o
0?m_o`3oK`0Io`3oK`Oooo]Z1?l00001oookJP003ooonfX3o`00O`?ooo]Z0ol007l9oookJP03o`00
0?oonf[ooo]Z00Sooo]Z6ol0ofl00ol0003o0?oDo`3oe00To`3oe003o`000?l0aOoo0<Go01_o0<Go
00?o0000o`1Pool0H?l06?l0H?l2o`0005ko1@3o00?o0000o`1Pool0H?l0C_l0H?l00ol0003o1@3o
o`D0o`1Mo`D0o`;o00006_l0H?l00ol0003o0<Goo`35o`0Jo`35o`03o`000?l0omCo0?oD02Go0?oD
00?o0000o`3oKol0ofl06?l0ofl:oookJP7o00000OoonfX000oooo]Z0ol007l3oookJP?o001o2Ooo
nfX00ol0003ooo]ZoookJP08oookJQ[o0?m_00?o0000o`3oe?l0om@09Ol0om@00ol0003o0<Goo`35
o`0Jo`35o`03o`000?l0H?oo063o01Oo063o0_l0001Qo`D0o`03o`000?l0H?oo063o04co063o00?o
0000o`D0ool50?l0H?l50?l2o`0001Wo063o00?o0000o`35ool0aOl06Ol0aOl00ol0003o0?oDo`3o
e00Uo`3oe003o`000?l0ofoo0?m_01So0?m_2_oonfX1o`00007ooo]Z000?oookJP?o001o0ooonfX3
o`00O`Wooo]Z00?o0000oookJ_oonfX02?oonfXJo`3oK`03o`000?l0omCo0?oD02Co0?oD00?o0000
o`35ool0aOl06_l0aOl00ol0003o063oo`1Po`0Fo`1Po`;o0000I?l50?l00ol0003o063oo`1Po`1:
o`1Po`03o`000?l50?oo1@3o06?o1@3o0_l0000Ho`1Po`03o`000?l0aOoo0<Go01Wo0<Go00?o0000
o`3oe?l0om@09?l0om@00ol0003o0?m_o`3oK`0Ho`3oK`[ooo]Z0Ol00001oookJP003ooonfX3o`00
O`?ooo]Z0ol007l9oookJP03o`000?oonf[ooo]Z00Sooo]Z6_l0ofl00ol0003o0?oDo`3oe00To`3o
e003o`000?l0aOoo0<Go01Wo0<Go00?o0000o`1Pool0H?l05_l0H?l00ol0003o1@3oo`D0o`1Uo`D0
o`03o`000?l0H?oo063o04So063o00?o0000o`D0ool50?l0I_l50?l00ol0003o063oo`1Po`0Fo`1P
o`03o`000?l0aOoo0<Go01So0<Go00?o0000o`3oe?l0om@09Ol0om@00ol0003o0?m_o`3oK`0Go`3o
K`[ooo]Z0Ol00001oookJP003ooonfX3o`00O`?ooo]Z0ol007l9oookJP03o`000?oonf[ooo]Z00So
oo]Z6Ol0ofl00ol0003o0?oDo`3oe00To`3oe003o`000?l0aOoo0<Go01[o0<Go00?o0000o`1Pool0
H?l05?l0H?l2o`0006Wo1@3o00?o0000o`1Pool0H?l0A_l0H?l00ol0003o1@3oo`D0o`1Xo`D0o`;o
00005_l0H?l00ol0003o0<Goo`35o`0Io`35o`03o`000?l0omCo0?oD02Co0?oD00?o0000o`3oKol0
ofl05ol0ofl:oookJP7o00000OoonfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l:oookJP03
o`000?oonf[ooo]Z00Sooo]Z6Ol0ofl00ol0003o0?oDo`3oe00To`3oe003o`000?l0aOoo0<Go01Wo
0<Go00?o0000o`1Pool0H?l05?l0H?l00ol0003o1@3oo`D0o`0So`D0o`co0000>ol50?l00ol0003o
063oo`1Po`14o`1Po`03o`000?l50?oo1@3o03[o1@3o3?l0000Uo`D0o`03o`000?l0H?oo063o01Co
063o00?o0000o`35ool0aOl06?l0aOl00ol0003o0?oDo`3oe00To`3oe003o`000?l0ofoo0?m_01Oo
0?m_2_oonfX1o`00007ooo]Z000@oookJPOo001o2_oonfX00ol0003ooo]ZoookJP08oookJQWo0?m_
00?o0000o`3oe?l0om@08ol0om@00ol0003o0<Goo`35o`0Io`35o`03o`000?l0H?oo063o01?o063o
0_l0000Ko`D0o`_o00003?mZ0?l7o`0003Go1@3o00?o0000o`1Pool0H?l0@_l0H?l00ol0003o1@3o
o`D0o`0eo`D0o`Ko00003?mZ0?l;o`0001_o1@3o00?o0000o`1Pool0H?l05?l0H?l00ol0003o0<Go
o`35o`0Ho`35o`03o`000?l0omCo0?oD02Co0?oD00?o0000o`3oKol0ofl05_l0ofl:oookJP7o0000
0OoonfX0017ooo]Z1Ol007l;oookJP03o`000?oonf[ooo]Z00Sooo]Z6Ol0ofl00ol0003o0?oDo`3o
e00So`3oe003o`000?l0aOoo0<Go01Wo0<Go00?o0000o`1Pool0H?l04_l0H?l00ol0003o1@3oo`D0
o`0Go`D0o`Co00007_mZ0?l3o`0003?o1@3o00?o0000o`1Pool0H?l0@?l0H?l00ol0003o1@3oo`D0
o`0bo`D0o`Co00007OmZ0?l4o`0001So1@3o00?o0000o`1Pool0H?l04ol0H?l00ol0003o0<Goo`35
o`0Ho`35o`03o`000?l0omCo0?oD02Co0?oD00?o0000o`3oKol0ofl05_l0ofl:oookJP7o00000Ooo
nfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXIo`3oK`03o`000?l0omCo0?oD02;o0?oD00?o0000
o`35ool0aOl06Ol0aOl00ol0003o063oo`1Po`0Bo`1Po`03o`000?l50?oo1@3o01Go1@3o0ol0000U
ofX0o`;o0000<Ol50?l00ol0003o063oo`1Po`10o`1Po`03o`000?l50?oo1@3o033o1@3o0_l0000U
ofX0o`?o00005_l50?l00ol0003o063oo`1Po`0Co`1Po`03o`000?l0aOoo0<Go01So0<Go00?o0000
o`3oe?l0om@08ol0om@00ol0003o0?m_o`3oK`0Fo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0
003ooo]ZoookJP08oookJQSo0?m_00?o0000o`3oe?l0om@08ol0om@00ol0003o0<Goo`35o`0Ho`35
o`03o`000?l0H?oo063o01;o063o00?o0000o`D0ool50?l04ol50?l3o`0002[oJP3o0_l0000`o`D0
o`03o`000?l0H?oo063o03ko063o00?o0000o`D0ool50?l0;ol50?l2o`0002[oJP3o0ol0000Do`D0
o`03o`000?l0H?oo063o01?o063o00?o0000o`35ool0aOl05ol0aOl00ol0003o0?oDo`3oe00To`3o
e003o`000?l0ofoo0?m_01Go0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00So
oo]Z6?l0ofl00ol0003o0?oDo`3oe00So`3oe003o`000?l0aOoo0<Go01So0<Go00?o0000o`1Pool0
H?l04Ol0H?l00ol0003o1@3oo`D0o`0Co`D0o`03o`000?mZ0?ooJP3o02goJP3o0_l0000^o`D0o`03
o`000?l0H?oo063o03ko063o00?o0000o`D0ool50?l0;Ol50?l2o`0002ooJP3o00?o0000o`D0ool5
0?l04_l50?l00ol0003o063oo`1Po`0Bo`1Po`03o`000?l0aOoo0<Go01Oo0<Go00?o0000o`3oe?l0
om@09?l0om@00ol0003o0?m_o`3oK`0Eo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJQSo0?m_00?o0000o`3oe?l0om@08_l0om@00ol0003o0<Goo`35o`0Ho`35o`03o`00
0?l0H?oo063o017o063o00?o0000o`D0ool50?l04_l50?l2o`0003;oJP3o00?o0000o`D0ool50?l0
;?l50?l00ol0003o063oo`1Po`0lo`1Po`03o`000?l50?oo1@3o02co1@3o0_l0000bofX0o`;o0000
4ol50?l00ol0003o063oo`1Po`0Bo`1Po`03o`000?l0aOoo0<Go01Oo0<Go00?o0000o`3oe?l0om@0
8ol0om@00ol0003o0?m_o`3oK`0Eo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Zoook
JP08oookJQSo0?m_00?o0000o`3oe?l0om@08_l0om@00ol0003o0<Goo`35o`0Go`35o`03o`000?l0
H?oo063o017o063o00?o0000o`D0ool50?l04Ol50?l2o`0003GoJP3o0_l0000]o`D0o`03o`000?l0
H?oo063o03[o063o00?o0000o`D0ool50?l0:ol50?l2o`0003KoJP3o0_l0000Bo`D0o`03o`000?l0
H?oo063o017o063o00?o0000o`35ool0aOl05ol0aOl00ol0003o0?oDo`3oe00So`3oe003o`000?l0
ofoo0?m_01Go0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z5ol0ofl0
0ol0003o0?oDo`3oe00Ro`3oe003o`000?l0aOoo0<Go01Oo0<Go00?o0000o`1Pool0H?l04Ol0H?l0
0ol0003o1@3oo`D0o`0Ao`D0o`03o`000?mZ0?ooJP3o03OoJP3o0_l0000[o`D0o`03o`000?l0H?oo
063o03[o063o00?o0000o`D0ool50?l0:Ol50?l2o`0003[oJP3o00?o0000o`D0ool50?l04?l50?l0
0ol0003o063oo`1Po`0Ao`1Po`03o`000?l0aOoo0<Go01Oo0<Go00?o0000o`3oe?l0om@08ol0om@0
0ol0003o0?m_o`3oK`0Do`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oook
JQOo0?m_00?o0000o`3oe?l0om@08_l0om@00ol0003o0<Goo`35o`0Go`35o`03o`000?l0H?oo063o
017o063o00?o0000o`D0ool50?l03ol50?l2o`0003coJP3o0_l0000Zo`D0o`03o`000?l0H?oo063o
03So063o00?o0000o`D0ool50?l0:?l50?l2o`0003goJP3o0_l0000Ao`D0o`03o`000?l0H?oo063o
017o063o00?o0000o`35ool0aOl05_l0aOl00ol0003o0?oDo`3oe00So`3oe003o`000?l0ofoo0?m_
01Co0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z5ol0ofl00ol0003o
0?oDo`3oe00Ro`3oe003o`000?l0aOoo0<Go01Ko0<Go00?o0000o`1Pool0H?l04Ol0H?l00ol0003o
1@3oo`D0o`0>o`D0o`;o0000@?mZ0?l00ol0003o1@3oo`D0o`0Wo`D0o`03o`000?l0H?oo063o03So
063o00?o0000o`D0ool50?l09ol50?l00ol0003oJP3oofX0o`0oofX0o`;o00004?l50?l00ol0003o
063oo`1Po`0@o`1Po`03o`000?l0aOoo0<Go01Ko0<Go00?o0000o`3oe?l0om@08ol0om@00ol0003o
0?m_o`3oK`0Do`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQOo0?m_
00?o0000o`3oe?l0om@08Ol0om@00ol0003o0<Goo`35o`0Fo`35o`03o`000?l0H?oo063o017o063o
00?o0000o`D0ool50?l03_l50?l00ol0003oJP3oofX0o`0DofX0oa?o00006_mZ0?l2o`0002So1@3o
00?o0000o`1Pool0H?l0=_l0H?l00ol0003o1@3oo`D0o`0Vo`D0o`;o00006omZ0?lBo`0001OoJP3o
00?o0000o`D0ool50?l03_l50?l00ol0003o063oo`1Po`0@o`1Po`03o`000?l0aOoo0<Go01Ko0<Go
00?o0000o`3oe?l0om@08_l0om@00ol0003o0?m_o`3oK`0Do`3oK`[ooo]Z0Ol00001oookJP008Ooo
nfX00ol0003ooo]ZoookJP08oookJQOo0?m_00?o0000o`3oe?l0om@08Ol0om@00ol0003o0<Goo`35
o`0Fo`35o`03o`000?l0H?oo063o013o063o00?o0000o`D0ool50?l03Ol50?l2o`0001;oJP3o1Ol0
000Coll0o`Co00006?mZ0?l2o`0002Oo1@3o00?o0000o`1Pool0H?l0=?l0H?l00ol0003o1@3oo`D0
o`0Vo`D0o`03o`000?mZ0?ooJP3o01OoJP3o1?l0000Boll0o`Go00004omZ0?l2o`0000oo1@3o00?o
0000o`1Pool0H?l03ol0H?l00ol0003o0<Goo`35o`0Fo`35o`03o`000?l0omCo0?oD02;o0?oD00?o
0000o`3oKol0ofl05?l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXF
o`3oK`03o`000?l0omCo0?oD02;o0?oD00?o0000o`35ool0aOl05Ol0aOl00ol0003o063oo`1Po`0@
o`1Po`03o`000?l50?oo1@3o00co1@3o0_l0000@ofX0o`Co00007?o?0?l3o`0001OoJP3o00?o0000
o`D0ool50?l09?l50?l00ol0003o063oo`1Po`0do`1Po`03o`000?l50?oo1@3o02Go1@3o00?o0000
ofX0oomZ0?l05?mZ0?l4o`0001_oc`3o1Ol0000@ofX0o`;o00003_l50?l00ol0003o063oo`1Po`0?
o`1Po`03o`000?l0aOoo0<Go01Go0<Go00?o0000o`3oe?l0om@08ol0om@00ol0003o0?m_o`3oK`0C
o`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQKo0?m_00?o0000o`3o
e?l0om@08Ol0om@00ol0003o0<Goo`35o`0Eo`35o`03o`000?l0H?oo063o013o063o00?o0000o`D0
ool50?l03?l50?l00ol0003oJP3oofX0o`0;ofX0o`Go00008oo?0?l3o`0001GoJP3o00?o0000o`D0
ool50?l09?l50?l00ol0003o063oo`1Po`0bo`1Po`03o`000?l50?oo1@3o02Go1@3o00?o0000ofX0
oomZ0?l04omZ0?l2o`0002Coc`3o1?l0000>ofX0o`03o`000?l50?oo1@3o00co1@3o00?o0000o`1P
ool0H?l03ol0H?l00ol0003o0<Goo`35o`0Eo`35o`03o`000?l0omCo0?oD02;o0?oD00?o0000o`3o
Kol0ofl04ol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXFo`3oK`03
o`000?l0omCo0?oD027o0?oD00?o0000o`35ool0aOl05Ol0aOl00ol0003o063oo`1Po`0@o`1Po`03
o`000?l50?oo1@3o00co1@3o00?o0000ofX0oomZ0?l02_mZ0?l00ol0003oc`3ooll0o`0Yoll0o`;o
00005?mZ0?l00ol0003o1@3oo`D0o`0So`D0o`03o`000?l0H?oo063o03;o063o00?o0000o`D0ool5
0?l09?l50?l00ol0003oJP3oofX0o`0BofX0o`;o0000:_o?0?l00ol0003oJP3oofX0o`0;ofX0o`03
o`000?l50?oo1@3o00co1@3o00?o0000o`1Pool0H?l03ol0H?l00ol0003o0<Goo`35o`0Eo`35o`03
o`000?l0omCo0?oD02;o0?oD00?o0000o`3oKol0ofl04ol0ofl:oookJP7o00000OoonfX0027ooo]Z
00?o0000oookJ_oonfX02?oonfXFo`3oK`03o`000?l0omCo0?oD027o0?oD00?o0000o`35ool0aOl0
5?l0aOl00ol0003o063oo`1Po`0@o`1Po`03o`000?l50?oo1@3o00co1@3o00?o0000ofX0oomZ0?l0
2_mZ0?l00ol0003oc`3ooll0o`0/oll0o`03o`000?mZ0?ooJP3o01;oJP3o00?o0000o`D0ool50?l0
8ol50?l00ol0003o063oo`1Po`0`o`1Po`03o`000?l50?oo1@3o02Co1@3o00?o0000ofX0oomZ0?l0
4_mZ0?l00ol0003oc`3ooll0o`0[oll0o`;o00003?mZ0?l00ol0003o1@3oo`D0o`0<o`D0o`03o`00
0?l0H?oo063o00oo063o00?o0000o`35ool0aOl05?l0aOl00ol0003o0?oDo`3oe00Ro`3oe003o`00
0?l0ofoo0?m_01?o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z5_l0
ofl00ol0003o0?oDo`3oe00Po`3oe003o`000?l0aOoo0<Go01Go0<Go00?o0000o`1Pool0H?l03ol0
H?l00ol0003o1@3oo`D0o`0<o`D0o`03o`000?mZ0?ooJP3o00WoJP3o0_l0000`oll0o`03o`000?mZ
0?ooJP3o01;oJP3o00?o0000o`D0ool50?l08_l50?l00ol0003o063oo`1Po`0`o`1Po`03o`000?l5
0?oo1@3o02?o1@3o00?o0000ofX0oomZ0?l04OmZ0?l2o`00033oc`3o00?o0000ofX0oomZ0?l02_mZ
0?l00ol0003o1@3oo`D0o`0<o`D0o`03o`000?l0H?oo063o00ko063o00?o0000o`35ool0aOl05Ol0
aOl00ol0003o0?oDo`3oe00Qo`3oe003o`000?l0ofoo0?m_01?o0?m_2_oonfX1o`00007ooo]Z000Q
oookJP03o`000?oonf[ooo]Z00Sooo]Z5Ol0ofl00ol0003o0?oDo`3oe00Qo`3oe003o`000?l0aOoo
0<Go01Go0<Go00?o0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`0;o`D0o`03o`000?mZ0?oo
JP3o00WoJP3o00?o0000oll0ooo?0?l04?o?0?l:o`0001Ooc`3o0_l0000CofX0o`03o`000?l50?oo
1@3o02;o1@3o00?o0000o`1Pool0H?l0;ol0H?l00ol0003o1@3oo`D0o`0Ro`D0o`03o`000?mZ0?oo
JP3o017oJP3o00?o0000oll0ooo?0?l05_o?0?l9o`0001;oc`3o0_l0000;ofX0o`03o`000?l50?oo
1@3o00_o1@3o00?o0000o`1Pool0H?l03ol0H?l00ol0003o0<Goo`35o`0Do`35o`03o`000?l0omCo
0?oD02;o0?oD00?o0000o`3oKol0ofl04_l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oook
J_oonfX02?oonfXEo`3oK`03o`000?l0omCo0?oD027o0?oD00?o0000o`35ool0aOl05?l0aOl00ol0
003o063oo`1Po`0?o`1Po`03o`000?l50?oo1@3o00_o1@3o00?o0000ofX0oomZ0?l02?mZ0?l2o`00
00koc`3o1Ol0000:ool0bPSo00004Oo?0?l00ol0003oJP3oofX0o`0AofX0o`03o`000?l50?oo1@3o
027o1@3o00?o0000o`1Pool0H?l0;_l0H?l00ol0003o1@3oo`D0o`0Ro`D0o`03o`000?mZ0?ooJP3o
017oJP3o00?o0000oll0ooo?0?l03oo?0?l8o`0000Woo`3:1Ol0000?oll0o`03o`000?mZ0?ooJP3o
00WoJP3o00?o0000o`D0ool50?l02ol50?l00ol0003o063oo`1Po`0>o`1Po`03o`000?l0aOoo0<Go
01Co0<Go00?o0000o`3oe?l0om@08_l0om@00ol0003o0?m_o`3oK`0Bo`3oK`[ooo]Z0Ol00001oook
JP008OoonfX3o`0000Sooo]Z5Ol0ofl00ol0003o0?oDo`3oe00Qo`3oe003o`000?l0aOoo0<Go01Co
0<Go00?o0000o`1Pool0H?l03ol0H?l00ol0003o1@3oo`D0o`0:o`D0o`03o`000?mZ0?ooJP3o00So
JP3o00?o0000oll0ooo?0?l02_o?0?l4o`0001Ooo`3:0_l0000@oll0o`03o`000?mZ0?ooJP3o017o
JP3o00?o0000o`D0ool50?l08?l50?l00ol0003o063oo`1Po`0^o`1Po`03o`000?l50?oo1@3o027o
1@3o00?o0000ofX0oomZ0?l04?mZ0?l2o`00013oc`3o0_l0000Fool0bPGo00002oo?0?l2o`0000[o
JP3o00?o0000o`D0ool50?l02_l50?l00ol0003o063oo`1Po`0?o`1Po`03o`000?l0aOoo0<Go01Co
0<Go00?o0000o`3oe?l0om@08Ol0om@00ol0003o0?m_o`3oK`0Bo`3oK`Sooo]Z0ol00001oookJP00
8OoonfX00ol0003ooo]ZoookJP08oookJQGo0?m_00?o0000o`3oe?l0om@08Ol0om@00ol0003o0<Go
o`35o`0Do`35o`03o`000?l0H?oo063o00ko063o00?o0000o`D0ool50?l02_l50?l00ol0003oJP3o
ofX0o`08ofX0o`03o`000?o?0?ooc`3o00Soc`3o0ol0000Mool0bP;o00003oo?0?l00ol0003oJP3o
ofX0o`0@ofX0o`03o`000?l50?oo1@3o027o1@3o00?o0000o`1Pool0H?l0;Ol0H?l00ol0003o1@3o
o`D0o`0Qo`D0o`03o`000?mZ0?ooJP3o00ooJP3o00?o0000oll0ooo?0?l03_o?0?l2o`0001goo`3:
0ol0000:oll0o`03o`000?mZ0?ooJP3o00OoJP3o00?o0000o`D0ool50?l02ol50?l00ol0003o063o
o`1Po`0>o`1Po`03o`000?l0aOoo0<Go01Co0<Go00?o0000o`3oe?l0om@08Ol0om@00ol0003o0?m_
o`3oK`0Bo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQGo0?m_00?o
0000o`3oe?l0om@08?l0om@00ol0003o0<Goo`35o`0Do`35o`03o`000?l0H?oo063o00ko063o00?o
0000o`D0ool50?l02_l50?l00ol0003oJP3oofX0o`08ofX0o`03o`000?o?0?ooc`3o00Soc`3o00?o
0000ool0b_oo0<X08?oo0<X3o`0000goc`3o0_l0000AofX0o`03o`000?l50?oo1@3o023o1@3o00?o
0000o`1Pool0H?l0;?l0H?l00ol0003o1@3oo`D0o`0Qo`D0o`03o`000?mZ0?ooJP3o00koJP3o0_l0
000>oll0o`?o00008_oo0<X00ol0003oc`3ooll0o`08oll0o`03o`000?mZ0?ooJP3o00OoJP3o00?o
0000o`D0ool50?l02ol50?l00ol0003o063oo`1Po`0>o`1Po`03o`000?l0aOoo0<Go01?o0<Go00?o
0000o`3oe?l0om@08Ol0om@00ol0003o0?m_o`3oK`0Bo`3oK`[ooo]Z0Ol00001oookJP008OoonfX0
0ol0003ooo]ZoookJP08oookJQGo0?m_00?o0000o`3oe?l0om@08?l0om@00ol0003o0<Goo`35o`0D
o`35o`03o`000?l0H?oo063o00ko063o00?o0000o`D0ool50?l02Ol50?l00ol0003oJP3oofX0o`08
ofX0o`03o`000?o?0?ooc`3o00Ooc`3o0_l0000=ool0bP[o00003ooo0<X2o`0000goc`3o00?o0000
ofX0oomZ0?l03_mZ0?l00ol0003o1@3oo`D0o`0Qo`D0o`03o`000?l0H?oo063o02_o063o00?o0000
o`D0ool50?l08?l50?l00ol0003oJP3oofX0o`0>ofX0o`03o`000?o?0?ooc`3o00coc`3o0_l0000?
ool0bPWo00003_oo0<X2o`0000Woc`3o00?o0000ofX0oomZ0?l01omZ0?l00ol0003o1@3oo`D0o`0:
o`D0o`03o`000?l0H?oo063o00ko063o00?o0000o`35ool0aOl04ol0aOl00ol0003o0?oDo`3oe00Q
o`3oe003o`000?l0ofoo0?m_01;o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z
00Sooo]Z5Ol0ofl00ol0003o0?oDo`3oe00Po`3oe003o`000?l0aOoo0<Go01Co0<Go00?o0000o`1P
ool0H?l03Ol0H?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?mZ0?ooJP3o00SoJP3o00?o0000oll0
ooo?0?l01_o?0?l2o`0000[oo`3:1Ol0000:ool0I@So00002Ooo0<X2o`0000coc`3o00?o0000ofX0
oomZ0?l03_mZ0?l00ol0003o1@3oo`D0o`0Po`D0o`03o`000?l0H?oo063o02_o063o00?o0000o`D0
ool50?l08?l50?l00ol0003oJP3oofX0o`0=ofX0o`03o`000?o?0?ooc`3o00_oc`3o0_l00009ool0
bPSo00002Ooo06D5o`0000_oo`3:0_l00008oll0o`03o`000?mZ0?ooJP3o00OoJP3o00?o0000o`D0
ool50?l02_l50?l00ol0003o063oo`1Po`0=o`1Po`03o`000?l0aOoo0<Go01Co0<Go00?o0000o`3o
e?l0om@08?l0om@00ol0003o0?m_o`3oK`0Bo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003o
oo]ZoookJP08oookJQCo0?m_00?o0000o`3oe?l0om@08Ol0om@00ol0003o0<Goo`35o`0Co`35o`03
o`000?l0H?oo063o00ko063o00?o0000o`D0ool50?l02?l50?l00ol0003oJP3oofX0o`08ofX0o`03
o`000?o?0?ooc`3o00Koc`3o00?o0000ool0b_oo0<X01_oo0<X4o`0001Ooo`1U0_l00009ool0bP;o
00002oo?0?l00ol0003oJP3oofX0o`0=ofX0o`03o`000?l50?oo1@3o027o1@3o00?o0000o`1Pool0
H?l0:Ol0H?l00ol0003o1@3oo`D0o`0Po`D0o`03o`000?mZ0?ooJP3o00goJP3o00?o0000oll0ooo?
0?l02_o?0?l2o`0000Soo`3:0ol0000Fool0I@Go00002?oo0<X00ol0003oc`3ooll0o`06oll0o`03
o`000?mZ0?ooJP3o00OoJP3o00?o0000o`D0ool50?l02Ol50?l00ol0003o063oo`1Po`0>o`1Po`03
o`000?l0aOoo0<Go01?o0<Go00?o0000o`3oe?l0om@08Ol0om@00ol0003o0?m_o`3oK`0Ao`3oK`[o
oo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQCo0?m_00?o0000o`3oe?l0om@0
8Ol0om@00ol0003o0<Goo`35o`0Co`35o`03o`000?l0H?oo063o00go063o00?o0000o`D0ool50?l0
2Ol50?l00ol0003oJP3oofX0o`07ofX0o`03o`000?o?0?ooc`3o00Goc`3o0_l00006ool0bP?o0000
7Ooo06D3o`0000Soo`3:00?o0000oll0ooo?0?l02?o?0?l00ol0003oJP3oofX0o`0>ofX0o`03o`00
0?l50?oo1@3o023o1@3o00?o0000o`1Pool0H?l0:Ol0H?l00ol0003o1@3oo`D0o`0Po`D0o`03o`00
0?mZ0?ooJP3o00goJP3o00?o0000oll0ooo?0?l02?o?0?l2o`0000Soo`3:0_l0000Nool0I@?o0000
1_oo0<X2o`0000Ooc`3o00?o0000ofX0oomZ0?l01_mZ0?l00ol0003o1@3oo`D0o`0:o`D0o`03o`00
0?l0H?oo063o00go063o00?o0000o`35ool0aOl04ol0aOl00ol0003o0?oDo`3oe00Qo`3oe003o`00
0?l0ofoo0?m_017o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z5?l0
ofl00ol0003o0?oDo`3oe00Po`3oe003o`000?l0aOoo0<Go01Co0<Go00?o0000o`1Pool0H?l03?l0
H?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?mZ0?ooJP3o00OoJP3o00?o0000oll0ooo?0?l01Oo?
0?l00ol0003oo`3:ool0bP05ool0bP03o`000?oo06Goo`1U00Woo`1U2_l0000>ool0I@;o00001ooo
0<X00ol0003oc`3ooll0o`08oll0o`03o`000?mZ0?ooJP3o00goJP3o00?o0000o`D0ool50?l08?l5
0?l00ol0003o063oo`1Po`0Yo`1Po`03o`000?l50?oo1@3o01oo1@3o00?o0000ofX0oomZ0?l03OmZ
0?l00ol0003oc`3ooll0o`08oll0o`03o`000?oo0<[oo`3:00Goo`3:0ol0000>ool0I@[o00002ooo
06D00ol0003oo`3:ool0bP05ool0bP03o`000?o?0?ooc`3o00Goc`3o00?o0000ofX0oomZ0?l01_mZ
0?l00ol0003o1@3oo`D0o`0:o`D0o`03o`000?l0H?oo063o00co063o00?o0000o`35ool0aOl05?l0
aOl00ol0003o0?oDo`3oe00Po`3oe003o`000?l0ofoo0?m_017o0?m_2_oonfX1o`00007ooo]Z000Q
oookJP03o`000?oonf[ooo]Z00Sooo]Z5?l0ofl00ol0003o0?oDo`3oe00Po`3oe003o`000?l0aOoo
0<Go01?o0<Go00?o0000o`1Pool0H?l03?l0H?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?mZ0?oo
JP3o00OoJP3o00?o0000oll0ooo?0?l01Oo?0?l00ol0003oo`3:ool0bP04ool0bP;o00002?oo06D4
o`0000[oo`001ol00009ool0I@03o`000?oo0<[oo`3:00Goo`3:00?o0000oll0ooo?0?l02?o?0?l0
0ol0003oJP3oofX0o`0=ofX0o`03o`000?l50?oo1@3o023o1@3o00?o0000o`1Pool0H?l09ol0H?l0
0ol0003o1@3oo`D0o`0Oo`D0o`03o`000?mZ0?ooJP3o00goJP3o00?o0000oll0ooo?0?l02?o?0?l0
0ol0003oo`3:ool0bP05ool0bP03o`000?oo06Goo`1U00Woo`1U1_l0000:ool000Co00002?oo06D2
o`0000Koo`3:00?o0000oll0ooo?0?l01Oo?0?l00ol0003oJP3oofX0o`06ofX0o`03o`000?l50?oo
1@3o00Wo1@3o00?o0000o`1Pool0H?l03Ol0H?l00ol0003o0<Goo`35o`0Co`35o`03o`000?l0omCo
0?oD023o0?oD00?o0000o`3oKol0ofl04Ol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oook
J_oonfX02?oonfXDo`3oK`03o`000?l0omCo0?oD023o0?oD00?o0000o`35ool0aOl04ol0aOl00ol0
003o063oo`1Po`0<o`1Po`03o`000?l50?oo1@3o00Wo1@3o00?o0000ofX0oomZ0?l01omZ0?l00ol0
003oc`3ooll0o`04oll0o`03o`000?oo0<[oo`3:00Coo`3:00?o0000ool0IOoo06D01Ooo06D3o`00
01Goo`000_l00008ool0I@03o`000?oo0<[oo`3:00Coo`3:00?o0000oll0ooo?0?l02?o?0?l00ol0
003oJP3oofX0o`0=ofX0o`03o`000?l50?oo1@3o023o1@3o00?o0000o`1Pool0H?l09ol0H?l00ol0
003o1@3oo`D0o`0Oo`D0o`03o`000?mZ0?ooJP3o00goJP3o00?o0000oll0ooo?0?l02?o?0?l00ol0
003oo`3:ool0bP05ool0bP03o`000?oo06Goo`1U00Koo`1U0ol0000Dool000?o00001ooo06D00ol0
003oo`3:ool0bP04ool0bP03o`000?o?0?ooc`3o00Coc`3o00?o0000ofX0oomZ0?l01_mZ0?l00ol0
003o1@3oo`D0o`09o`D0o`03o`000?l0H?oo063o00go063o00?o0000o`35ool0aOl04ol0aOl00ol0
003o0?oDo`3oe00Po`3oe003o`000?l0ofoo0?m_017o0?m_2_oonfX1o`00007ooo]Z000QoookJP03
o`000?oonf[ooo]Z00Sooo]Z5?l0ofl00ol0003o0?oDo`3oe00Po`3oe003o`000?l0aOoo0<Go01?o
0<Go00?o0000o`1Pool0H?l03?l0H?l00ol0003o1@3oo`D0o`08o`D0o`03o`000?mZ0?ooJP3o00Oo
JP3o00?o0000oll0ooo?0?l01?o?0?l00ol0003oo`3:ool0bP04ool0bP03o`000?oo06Goo`1U00Co
o`1U0_l0000Jool00003o`000?oo06Goo`1U00Koo`1U00?o0000ool0b_oo0<X01?oo0<X00ol0003o
c`3ooll0o`08oll0o`03o`000?mZ0?ooJP3o00goJP3o00?o0000o`D0ool50?l07ol50?l00ol0003o
063oo`1Po`0Wo`1Po`03o`000?l50?oo1@3o01ko1@3o00?o0000ofX0oomZ0?l03OmZ0?l00ol0003o
c`3ooll0o`08oll0o`03o`000?oo0<[oo`3:00Goo`3:00?o0000ool0IOoo06D01_oo06D00ol0003o
o`00ool0000Hool000;o00001_oo06D00ol0003oo`3:ool0bP04ool0bP03o`000?o?0?ooc`3o00Co
c`3o00?o0000ofX0oomZ0?l01_mZ0?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?l0H?oo063o00co
063o00?o0000o`35ool0aOl04ol0aOl00ol0003o0?oDo`3oe00Po`3oe003o`000?l0ofoo0?m_017o
0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z5?l0ofl00ol0003o0?oD
o`3oe00Oo`3oe003o`000?l0aOoo0<Go01?o0<Go00?o0000o`1Pool0H?l03?l0H?l00ol0003o1@3o
o`D0o`09o`D0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000oll0ooo?0?l01Oo?0?l00ol0003oo`3:
ool0bP03ool0bP03o`000?oo06Goo`1U00?oo`1U0_l0000Mool000;o00001ooo06D00ol0003oo`3:
ool0bP04ool0bP03o`000?o?0?ooc`3o00Soc`3o00?o0000ofX0oomZ0?l03?mZ0?l00ol0003o1@3o
o`D0o`0Po`D0o`03o`000?l0H?oo063o02Go063o00?o0000o`D0ool50?l07ol50?l00ol0003oJP3o
ofX0o`0=ofX0o`03o`000?o?0?ooc`3o00Ooc`3o00?o0000ool0b_oo0<X01Ooo0<X00ol0003oo`1U
ool0I@05ool0I@;o00007Ooo0002o`0000Goo`1U00?o0000ool0b_oo0<X00ooo0<X00ol0003oc`3o
oll0o`04oll0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000o`D0ool50?l02Ol50?l00ol0003o063o
o`1Po`0=o`1Po`03o`000?l0aOoo0<Go01?o0<Go00?o0000o`3oe?l0om@07ol0om@00ol0003o0?m_
o`3oK`0Ao`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQCo0?m_00?o
0000o`3oe?l0om@07ol0om@00ol0003o0<Goo`35o`0Co`35o`03o`000?l0H?oo063o00co063o00?o
0000o`D0ool50?l02?l50?l00ol0003oJP3oofX0o`07ofX0o`03o`000?o?0?ooc`3o00Coc`3o00?o
0000ool0b_oo0<X00ooo0<X00ol0003oo`1Uool0I@03ool0I@03o`000?oo003oo`0001ooo`0000?o
0000ool0IOoo06D01Ooo06D00ol0003oo`3:ool0bP04ool0bP03o`000?o?0?ooc`3o00Ooc`3o00?o
0000ofX0oomZ0?l03?mZ0?l00ol0003o1@3oo`D0o`0Po`D0o`03o`000?l0H?oo063o02Go063o00?o
0000o`D0ool50?l07ol50?l00ol0003oJP3oofX0o`0<ofX0o`03o`000?o?0?ooc`3o00Ooc`3o00?o
0000ool0b_oo0<X01Ooo0<X00ol0003oo`1Uool0I@05ool0I@03o`000?oo003oo`0001ooo`0000?o
0000ool0IOoo06D00ooo06D00ol0003oo`3:ool0bP03ool0bP03o`000?o?0?ooc`3o00Coc`3o00?o
0000ofX0oomZ0?l01_mZ0?l00ol0003o1@3oo`D0o`08o`D0o`03o`000?l0H?oo063o00go063o00?o
0000o`35ool0aOl04ol0aOl00ol0003o0?oDo`3oe00Oo`3oe003o`000?l0ofoo0?m_017o0?m_2_oo
nfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z5?l0ofl00ol0003o0?oDo`3oe00O
o`3oe003o`000?l0aOoo0<Go01?o0<Go00?o0000o`1Pool0H?l03?l0H?l00ol0003o1@3oo`D0o`08
o`D0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000oll0ooo?0?l01?o?0?l00ol0003oo`3:ool0bP03
ool0bP03o`000?oo06Goo`1U00?oo`1U00?o0000ool00?oo00008Ooo0002o`0000Goo`1U00?o0000
ool0b_oo0<X01?oo0<X00ol0003oc`3ooll0o`08oll0o`03o`000?mZ0?ooJP3o00coJP3o00?o0000
o`D0ool50?l07ol50?l00ol0003o063oo`1Po`0Uo`1Po`03o`000?l50?oo1@3o01ko1@3o00?o0000
ofX0oomZ0?l03OmZ0?l00ol0003oc`3ooll0o`07oll0o`03o`000?oo0<[oo`3:00Goo`3:00?o0000
ool0IOoo06D00ooo06D2o`0002?oo`0000?o0000ool0IOoo06D00ooo06D00ol0003oo`3:ool0bP03
ool0bP03o`000?o?0?ooc`3o00Coc`3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003o1@3oo`D0o`09
o`D0o`03o`000?l0H?oo063o00co063o00?o0000o`35ool0aOl04ol0aOl00ol0003o0?oDo`3oe00O
o`3oe003o`000?l0ofoo0?m_017o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z
00Sooo]Z5?l0ofl00ol0003o0?oDo`3oe00Oo`3oe003o`000?l0aOoo0<Go01;o0<Go00?o0000o`1P
ool0H?l03?l0H?l00ol0003o1@3oo`D0o`08o`D0o`03o`000?mZ0?ooJP3o00KoJP3o00?o0000oll0
ooo?0?l01?o?0?l00ol0003oo`3:ool0bP03ool0bP03o`000?oo06Goo`1U00?oo`1U00?o0000ool0
0?oo00009?oo00000ol0003oo`1Uool0I@03ool0I@03o`000?oo0<[oo`3:00Coo`3:00?o0000oll0
ooo?0?l01oo?0?l00ol0003oJP3oofX0o`0<ofX0o`03o`000?l50?oo1@3o01oo1@3o00?o0000o`1P
ool0H?l09Ol0H?l00ol0003o1@3oo`D0o`0No`D0o`03o`000?mZ0?ooJP3o00coJP3o00?o0000oll0
ooo?0?l01oo?0?l00ol0003oo`3:ool0bP05ool0bP03o`000?oo06Goo`1U00?oo`1U00?o0000ool0
0?oo00009?oo00000ol0003oo`1Uool0I@03ool0I@03o`000?oo0<[oo`3:00;oo`3:00?o0000oll0
ooo?0?l01?o?0?l00ol0003oJP3oofX0o`06ofX0o`03o`000?l50?oo1@3o00So1@3o00?o0000o`1P
ool0H?l03?l0H?l00ol0003o0<Goo`35o`0Co`35o`03o`000?l0omCo0?oD01oo0?oD00?o0000o`3o
Kol0ofl04Ol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXCo`3oK`03
o`000?l0omCo0?oD01oo0?oD00?o0000o`35ool0aOl04ol0aOl00ol0003o063oo`1Po`0<o`1Po`03
o`000?l50?oo1@3o00So1@3o00?o0000ofX0oomZ0?l01_mZ0?l00ol0003oc`3ooll0o`04oll0o`03
o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00ooo06D00ol0003oo`00ool0000Vool00003
o`000?oo06Goo`1U00?oo`1U00?o0000ool0b_oo0<X01?oo0<X00ol0003oc`3ooll0o`07oll0o`03
o`000?mZ0?ooJP3o00coJP3o00?o0000o`D0ool50?l07_l50?l00ol0003o063oo`1Po`0Uo`1Po`03
o`000?l50?oo1@3o01go1@3o00?o0000ofX0oomZ0?l03?mZ0?l00ol0003oc`3ooll0o`07oll0o`03
o`000?oo0<[oo`3:00Goo`3:00?o0000ool0IOoo06D00ooo06D00ol0003oo`00ool0000Vool00003
o`000?oo06Goo`1U00?oo`1U00?o0000ool0b_oo0<X00_oo0<X00ol0003oc`3ooll0o`04oll0o`03
o`000?mZ0?ooJP3o00GoJP3o00?o0000o`D0ool50?l02Ol50?l00ol0003o063oo`1Po`0<o`1Po`03
o`000?l0aOoo0<Go01?o0<Go00?o0000o`3oe?l0om@07_l0om@00ol0003o0?m_o`3oK`0Ao`3oK`[o
oo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQ?o0?m_00?o0000o`3oe?l0om@0
7ol0om@00ol0003o0<Goo`35o`0Co`35o`03o`000?l0H?oo063o00co063o00?o0000o`D0ool50?l0
2?l50?l00ol0003oJP3oofX0o`05ofX0o`03o`000?o?0?ooc`3o00Coc`3o00?o0000ool0b_oo0<X0
0_oo0<X00ol0003oo`1Uool0I@02ool0I@;o0000:_oo0002o`0000Coo`1U00?o0000ool0b_oo0<X0
1?oo0<X00ol0003oc`3ooll0o`07oll0o`03o`000?mZ0?ooJP3o00_oJP3o00?o0000o`D0ool50?l0
7_l50?l00ol0003o063oo`1Po`0Uo`1Po`03o`000?l50?oo1@3o01go1@3o00?o0000ofX0oomZ0?l0
3?mZ0?l00ol0003oc`3ooll0o`06oll0o`03o`000?oo0<[oo`3:00Goo`3:00?o0000ool0IOoo06D0
0_oo06D2o`0002[oo`0000?o0000ool0IOoo06D00ooo06D00ol0003oo`3:ool0bP02ool0bP03o`00
0?o?0?ooc`3o00?oc`3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003o1@3oo`D0o`09o`D0o`03o`00
0?l0H?oo063o00co063o00?o0000o`35ool0aOl04ol0aOl00ol0003o0?oDo`3oe00No`3oe003o`00
0?l0ofoo0?m_017o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z4ol0
ofl00ol0003o0?oDo`3oe00Oo`3oe003o`000?l0aOoo0<Go01;o0<Go00?o0000o`1Pool0H?l03?l0
H?l00ol0003o1@3oo`D0o`08o`D0o`03o`000?mZ0?ooJP3o00GoJP3o00?o0000oll0ooo?0?l01?o?
0?l00ol0003oo`3:ool0bP02ool0bP03o`000?oo06Goo`1U00;oo`1U00?o0000ool00?oo0000;?oo
00000ol0003oo`1Uool0I@02ool0I@03o`000?oo0<[oo`3:00?oo`3:00?o0000oll0ooo?0?l01oo?
0?l00ol0003oJP3oofX0o`0;ofX0o`03o`000?l50?oo1@3o01ko1@3o00?o0000o`1Pool0H?l09Ol0
H?l00ol0003o1@3oo`D0o`0Mo`D0o`03o`000?mZ0?ooJP3o00_oJP3o00?o0000oll0ooo?0?l01oo?
0?l00ol0003oo`3:ool0bP04ool0bP03o`000?oo06Goo`1U00;oo`1U00?o0000ool00?oo0000:ooo
00000ol0003oo`1Uool0I@03ool0I@05o`000?oo0<[oo`3:ool0b_l000001_o?0?l00ol0003oJP3o
ofX0o`05ofX0o`03o`000?l50?oo1@3o00So1@3o00?o0000o`1Pool0H?l03?l0H?l00ol0003o0<Go
o`35o`0Co`35o`03o`000?l0omCo0?oD01ko0?oD00?o0000o`3oKol0ofl04Ol0ofl:oookJP7o0000
0OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXCo`3oK`03o`000?l0omCo0?oD01oo0?oD00?o
0000o`35ool0aOl04_l0aOl00ol0003o063oo`1Po`0<o`1Po`03o`000?l50?oo1@3o00So1@3o00?o
0000ofX0oomZ0?l01OmZ0?l00ol0003oc`3ooll0o`04oll0o`03o`000?oo0<[oo`3:00;oo`3:00Go
0000ool0IOoo06Goo`1Uo`00000`ool00005o`000?oo06Goo`1Uool0IOl000001_oo0<X00ol0003o
c`3ooll0o`07oll0o`03o`000?mZ0?ooJP3o00_oJP3o00?o0000o`D0ool50?l07Ol50?l00ol0003o
063oo`1Po`0To`1Po`03o`000?l50?oo1@3o01go1@3o00?o0000ofX0oomZ0?l03?mZ0?l00ol0003o
c`3ooll0o`06oll0o`03o`000?oo0<[oo`3:00Coo`3:00?o0000ool0IOoo06D00_oo06D00ol0003o
o`00ool0000]ool00003o`000?oo06Goo`1U00;oo`1U00?o0000ool0b_oo0<X00_oo0<X00ol0003o
c`3ooll0o`04oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l02Ol50?l00ol0003o
063oo`1Po`0;o`1Po`03o`000?l0aOoo0<Go01?o0<Go00?o0000o`3oe?l0om@07_l0om@00ol0003o
0?m_o`3oK`0Ao`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQ?o0?m_
00?o0000o`3oe?l0om@07_l0om@00ol0003o0<Goo`35o`0Co`35o`03o`000?l0H?oo063o00co063o
00?o0000o`D0ool50?l01ol50?l00ol0003oJP3oofX0o`05ofX0o`03o`000?o?0?ooc`3o00Coc`3o
00?o0000ool0b_oo0<X00_oo0<X01Ol0003oo`1Uool0IOoo06Go0000037oo`0000?o0000ool0IOoo
06D00_oo06D00ol0003oo`3:ool0bP04ool0bP03o`000?o?0?ooc`3o00Koc`3o00?o0000ofX0oomZ
0?l02omZ0?l00ol0003o1@3oo`D0o`0Mo`D0o`03o`000?l0H?oo063o02Co063o00?o0000o`D0ool5
0?l07Ol50?l00ol0003oJP3oofX0o`0;ofX0o`03o`000?o?0?ooc`3o00Koc`3o00?o0000ool0b_oo
0<X01?oo0<X00ol0003oo`1Uool0I@02ool0I@03o`000?oo003oo`0002ooo`0000?o0000ool0IOoo
06D00_oo06D01Ol0003oo`3:ool0b_oo0<[o000000Koc`3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0
003o1@3oo`D0o`08o`D0o`03o`000?l0H?oo063o00_o063o00?o0000o`35ool0aOl04ol0aOl00ol0
003o0?oDo`3oe00No`3oe003o`000?l0ofoo0?m_017o0?m_2_oonfX1o`00007ooo]Z000QoookJP03
o`000?oonf[ooo]Z00Sooo]Z4ol0ofl00ol0003o0?oDo`3oe00No`3oe003o`000?l0aOoo0<Go01;o
0<Go00?o0000o`1Pool0H?l03?l0H?l00ol0003o1@3oo`D0o`08o`D0o`03o`000?mZ0?ooJP3o00Co
JP3o00?o0000oll0ooo?0?l01?o?0?l00ol0003oo`3:ool0bP02ool0bP05o`000?oo06Goo`1Uool0
IOl00000<ooo00000ol0003oo`1Uool0I@02ool0I@03o`000?oo0<[oo`3:00Coo`3:00?o0000oll0
ooo?0?l01_o?0?l00ol0003oJP3oofX0o`0:ofX0o`03o`000?l50?oo1@3o01go1@3o00?o0000o`1P
ool0H?l09?l0H?l00ol0003o1@3oo`D0o`0Mo`D0o`03o`000?mZ0?ooJP3o00_oJP3o00?o0000oll0
ooo?0?l01Oo?0?l00ol0003oo`3:ool0bP04ool0bP03o`000?oo06Goo`1U00;oo`1U00?o0000ool0
0?oo0000<Ooo00001Ol0003oo`1Uool0IOoo06Go000000Coo`3:00?o0000oll0ooo?0?l01?o?0?l0
0ol0003oJP3oofX0o`04ofX0o`03o`000?l50?oo1@3o00So1@3o00?o0000o`1Pool0H?l03?l0H?l0
0ol0003o0<Goo`35o`0Bo`35o`03o`000?l0omCo0?oD01ko0?oD00?o0000o`3oKol0ofl04Ol0ofl:
oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXCo`3oK`03o`000?l0omCo0?oD
01ko0?oD00?o0000o`35ool0aOl04_l0aOl00ol0003o063oo`1Po`0<o`1Po`03o`000?l50?oo1@3o
00Oo1@3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003oc`3ooll0o`03oll0o`03o`000?oo0<[oo`3:
00;oo`3:00Go0000ool0IOoo06Goo`1Uo`00000eool00003o`000?oo06Goo`1U00;oo`1U00?o0000
ool0b_oo0<X01?oo0<X00ol0003oc`3ooll0o`06oll0o`03o`000?mZ0?ooJP3o00[oJP3o00?o0000
o`D0ool50?l07?l50?l00ol0003o063oo`1Po`0To`1Po`03o`000?l50?oo1@3o01co1@3o00?o0000
ofX0oomZ0?l02omZ0?l00ol0003oc`3ooll0o`06oll0o`03o`000?oo0<[oo`3:00?oo`3:00?o0000
ool0IOoo06D00_oo06D00ol0003oo`00ool0000cool00005o`000?oo06Goo`1Uool0IOl000001?oo
0<X00ol0003oc`3ooll0o`04oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l02?l5
0?l00ol0003o063oo`1Po`0;o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07_l0
om@00ol0003o0?m_o`3oK`0Ao`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08
oookJQ?o0?m_00?o0000o`3oe?l0om@07_l0om@00ol0003o0<Goo`35o`0Bo`35o`03o`000?l0H?oo
063o00co063o00?o0000o`D0ool50?l01ol50?l00ol0003oJP3oofX0o`05ofX0o`03o`000?o?0?oo
c`3o00?oc`3o00?o0000ool0b_oo0<X00_oo0<X01Ol0003oo`1Uool0IOoo06Go000003Goo`0000?o
0000ool0IOoo06D00_oo06D00ol0003oo`3:ool0bP04ool0bP03o`000?o?0?ooc`3o00Koc`3o00?o
0000ofX0oomZ0?l02_mZ0?l00ol0003o1@3oo`D0o`0Lo`D0o`03o`000?l0H?oo063o02Co063o00?o
0000o`D0ool50?l07?l50?l00ol0003oJP3oofX0o`0;ofX0o`03o`000?o?0?ooc`3o00Koc`3o00?o
0000ool0b_oo0<X00ooo0<X00ol0003oo`1Uool0I@02ool0I@03o`000?oo003oo`0003?oo`0000Go
0000ool0IOoo06Goo`1Uo`000004ool0bP03o`000?o?0?ooc`3o00Coc`3o00?o0000ofX0oomZ0?l0
1?mZ0?l00ol0003o1@3oo`D0o`08o`D0o`03o`000?l0H?oo063o00_o063o00?o0000o`35ool0aOl0
4_l0aOl00ol0003o0?oDo`3oe00No`3oe003o`000?l0ofoo0?m_017o0?m_2_oonfX1o`00007ooo]Z
000QoookJP03o`000?oonf[ooo]Z00Sooo]Z4ol0ofl00ol0003o0?oDo`3oe00No`3oe003o`000?l0
aOoo0<Go01;o0<Go00?o0000o`1Pool0H?l03?l0H?l00ol0003o1@3oo`D0o`07o`D0o`03o`000?mZ
0?ooJP3o00GoJP3o00?o0000oll0ooo?0?l00oo?0?l00ol0003oo`3:ool0bP02ool0bP04o`000?oo
06Goo`1Uo`0003Ooo`0000Go0000ool0IOoo06Goo`1Uo`000006ool0bP03o`000?o?0?ooc`3o00Ko
c`3o00?o0000ofX0oomZ0?l02_mZ0?l00ol0003o1@3oo`D0o`0Lo`D0o`03o`000?l0H?oo063o02Co
063o00?o0000o`D0ool50?l07?l50?l00ol0003oJP3oofX0o`0;ofX0o`03o`000?o?0?ooc`3o00Ko
c`3o00?o0000ool0b_oo0<X00ooo0<X00ol0003oo`1Uool0I@02ool0I@03o`000?oo003oo`0003Co
o`0000Go0000ool0IOoo06Goo`1Uo`000003ool0bP03o`000?o?0?ooc`3o00Coc`3o00?o0000ofX0
oomZ0?l01?mZ0?l00ol0003o1@3oo`D0o`08o`D0o`03o`000?l0H?oo063o00_o063o00?o0000o`35
ool0aOl04_l0aOl00ol0003o0?oDo`3oe00No`3oe003o`000?l0ofoo0?m_017o0?m_2_oonfX1o`00
007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z4ol0ofl00ol0003o0?oDo`3oe00No`3oe003
o`000?l0aOoo0<Go01;o0<Go00?o0000o`1Pool0H?l03?l0H?l00ol0003o1@3oo`D0o`07o`D0o`03
o`000?mZ0?ooJP3o00CoJP3o00?o0000oll0ooo?0?l00oo?0?l00ol0003oo`3:ool0bP02ool0bP05
o`000?oo06Goo`1Uool0IOl00000=ooo00000ol0003oo`1Uool0I@02ool0I@03o`000?oo0<[oo`3:
00Coo`3:00?o0000oll0ooo?0?l01Oo?0?l00ol0003oJP3oofX0o`0:ofX0o`03o`000?l50?oo1@3o
01co1@3o00?o0000o`1Pool0H?l09Ol0H?l00ol0003o1@3oo`D0o`0Ko`D0o`03o`000?mZ0?ooJP3o
00[oJP3o00?o0000oll0ooo?0?l01_o?0?l00ol0003oo`3:ool0bP03ool0bP03o`000?oo06Goo`1U
00;oo`1U00?o0000ool00?oo0000=_oo00001?l0003oo`1Uool0IOl00004ool0bP03o`000?o?0?oo
c`3o00Coc`3o00?o0000ofX0oomZ0?l01?mZ0?l00ol0003o1@3oo`D0o`07o`D0o`03o`000?l0H?oo
063o00_o063o00?o0000o`35ool0aOl04_l0aOl00ol0003o0?oDo`3oe00No`3oe003o`000?l0ofoo
0?m_017o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z4ol0ofl00ol0
003o0?oDo`3oe00No`3oe003o`000?l0aOoo0<Go01;o0<Go00?o0000o`1Pool0H?l02ol0H?l00ol0
003o1@3oo`D0o`07o`D0o`03o`000?mZ0?ooJP3o00GoJP3o00?o0000oll0ooo?0?l00oo?0?l00ol0
003oo`3:ool0bP02ool0bP05o`000?oo06Goo`1Uool0IOl00000=ooo00000ol0003oo`1Uool0I@02
ool0I@03o`000?oo0<[oo`3:00Coo`3:00?o0000oll0ooo?0?l01_o?0?l00ol0003oJP3oofX0o`0:
ofX0o`03o`000?l50?oo1@3o01_o1@3o00?o0000o`1Pool0H?l09Ol0H?l00ol0003o1@3oo`D0o`0K
o`D0o`03o`000?mZ0?ooJP3o00[oJP3o00?o0000oll0ooo?0?l01_o?0?l00ol0003oo`3:ool0bP03
ool0bP03o`000?oo06Goo`1U00;oo`1U00?o0000ool00?oo0000=_oo00001?l0003oo`1Uool0IOl0
0004ool0bP03o`000?o?0?ooc`3o00Coc`3o00?o0000ofX0oomZ0?l01?mZ0?l00ol0003o1@3oo`D0
o`08o`D0o`03o`000?l0H?oo063o00[o063o00?o0000o`35ool0aOl04_l0aOl00ol0003o0?oDo`3o
e00No`3oe003o`000?l0ofoo0?m_017o0?m_2_oonfX1o`00007ooo]Z000QoookJP?o00002?oonfXC
o`3oK`03o`000?l0omCo0?oD01ko0?oD00?o0000o`35ool0aOl04_l0aOl00ol0003o063oo`1Po`0;
o`1Po`03o`000?l50?oo1@3o00Oo1@3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003oc`3ooll0o`03
oll0o`03o`000?oo0<[oo`3:00;oo`3:00Co0000ool0IOoo06Go0000>Ooo00001Ol0003oo`1Uool0
IOoo06Go000000Koo`3:00?o0000oll0ooo?0?l01_o?0?l00ol0003oJP3oofX0o`0:ofX0o`03o`00
0?l50?oo1@3o01_o1@3o00?o0000o`1Pool0H?l09Ol0H?l00ol0003o1@3oo`D0o`0Ko`D0o`03o`00
0?mZ0?ooJP3o00[oJP3o00?o0000oll0ooo?0?l01_o?0?l00ol0003oo`3:ool0bP03ool0bP03o`00
0?oo06Goo`1U00;oo`1U00?o0000ool00?oo0000=_oo00001Ol0003oo`1Uool0IOoo06Go000000?o
o`3:00?o0000oll0ooo?0?l01?o?0?l00ol0003oJP3oofX0o`04ofX0o`03o`000?l50?oo1@3o00So
1@3o00?o0000o`1Pool0H?l02_l0H?l00ol0003o0<Goo`35o`0Bo`35o`03o`000?l0omCo0?oD01ko
0?oD00?o0000o`3oKol0ofl04Ol0ofl8oookJP?o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX0
2?oonfXCo`3oK`03o`000?l0omCo0?oD01ko0?oD00?o0000o`35ool0aOl04_l0aOl00ol0003o063o
o`1Po`0;o`1Po`03o`000?l50?oo1@3o00Oo1@3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003oc`3o
oll0o`02oll0o`03o`000?oo0<[oo`3:00;oo`3:00Go0000ool0IOoo06Goo`1Uo`00000iool00003
o`000?oo06Goo`1U00;oo`1U00?o0000ool0b_oo0<X00ooo0<X00ol0003oc`3ooll0o`06oll0o`03
o`000?mZ0?ooJP3o00[oJP3o00?o0000o`D0ool50?l06_l50?l00ol0003o063oo`1Po`0Vo`1Po`03
o`000?l50?oo1@3o01_o1@3o00?o0000ofX0oomZ0?l02_mZ0?l00ol0003oc`3ooll0o`06oll0o`03
o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo06D00ol0003oo`00ool0000hool00004
o`000?oo06Goo`1Uo`0000Coo`3:00?o0000oll0ooo?0?l00oo?0?l00ol0003oJP3oofX0o`04ofX0
o`03o`000?l50?oo1@3o00So1@3o00?o0000o`1Pool0H?l02_l0H?l00ol0003o0<Goo`35o`0Bo`35
o`03o`000?l0omCo0?oD01ko0?oD00?o0000o`3oKol0ofl04Ol0ofl:oookJP7o00000OoonfX0027o
oo]Z00?o0000oookJ_oonfX02?oonfXCo`3oK`03o`000?l0omCo0?oD01ko0?oD00?o0000o`35ool0
aOl04Ol0aOl00ol0003o063oo`1Po`0<o`1Po`03o`000?l50?oo1@3o00Oo1@3o00?o0000ofX0oomZ
0?l01?mZ0?l00ol0003oc`3ooll0o`03oll0o`03o`000?oo0<[oo`3:00;oo`3:00Go0000ool0IOoo
06Goo`1Uo`00000jool00005o`000?oo06Goo`1Uool0IOl000001_oo0<X00ol0003oc`3ooll0o`05
oll0o`03o`000?mZ0?ooJP3o00[oJP3o00?o0000o`D0ool50?l06_l50?l00ol0003o063oo`1Po`0W
o`1Po`03o`000?l50?oo1@3o01Wo1@3o00?o0000ofX0oomZ0?l02_mZ0?l00ol0003oc`3ooll0o`06
oll0o`03o`000?oo0<[oo`3:00?oo`3:00?o0000ool0IOoo06D00_oo06D00ol0003oo`00ool0000h
ool00005o`000?oo06Goo`1Uool0IOl000000ooo0<X00ol0003oc`3ooll0o`04oll0o`03o`000?mZ
0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0003o063oo`1Po`0;o`1Po`03o`000?l0
aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0om@00ol0003o0?m_o`3oK`0Ao`3oK`[ooo]Z0Ol0
0001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQ?o0?m_00?o0000o`3oe?l0om@07_l0om@0
0ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00co063o00?o0000o`D0ool50?l01ol50?l0
0ol0003oJP3oofX0o`04ofX0o`03o`000?o?0?ooc`3o00?oc`3o00?o0000ool0b_oo0<X00_oo0<X0
1?l0003oo`1Uool0IOl0000kool00005o`000?oo06Goo`1Uool0IOl000001_oo0<X00ol0003oc`3o
oll0o`05oll0o`03o`000?mZ0?ooJP3o00[oJP3o00?o0000o`D0ool50?l06_l50?l00ol0003o063o
o`1Po`0Wo`1Po`03o`000?l50?oo1@3o01Wo1@3o00?o0000ofX0oomZ0?l02_mZ0?l00ol0003oc`3o
oll0o`06oll0o`03o`000?oo0<[oo`3:00?oo`3:00?o0000ool0IOoo06D00_oo06D00ol0003oo`00
ool0000hool00005o`000?oo06Goo`1Uool0IOl000000ooo0<X00ol0003oc`3ooll0o`04oll0o`03
o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0003o063oo`1Po`0;o`1Po`03
o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0om@00ol0003o0?m_o`3oK`0Ao`3oK`[o
oo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQ?o0?m_00?o0000o`3oe?l0om@0
7_l0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00co063o00?o0000o`D0ool50?l0
1ol50?l00ol0003oJP3oofX0o`04ofX0o`03o`000?o?0?ooc`3o00;oc`3o00?o0000ool0b_oo0<X0
0_oo0<X01Ol0003oo`1Uool0IOoo06Go000003_oo`0000?o0000ool0IOoo06D00_oo06D00ol0003o
o`3:ool0bP03ool0bP03o`000?o?0?ooc`3o00Goc`3o00?o0000ofX0oomZ0?l02_mZ0?l00ol0003o
1@3oo`D0o`0Io`D0o`03o`000?l0H?oo063o02So063o00?o0000o`D0ool50?l06Ol50?l00ol0003o
JP3oofX0o`0:ofX0o`03o`000?o?0?ooc`3o00Koc`3o00?o0000ool0b_oo0<X00_oo0<X00ol0003o
o`1Uool0I@02ool0I@03o`000?oo003oo`0003[oo`0000Co0000ool0IOoo06Go00001?oo0<X00ol0
003oc`3ooll0o`03oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0
003o063oo`1Po`0;o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0om@00ol0
003o0?m_o`3oK`0Ao`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQ?o
0?m_00?o0000o`3oe?l0om@07_l0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00co
063o00?o0000o`D0ool50?l01ol50?l00ol0003oJP3oofX0o`04ofX0o`03o`000?o?0?ooc`3o00;o
c`3o00?o0000ool0b_oo0<X00_oo0<X01?l0003oo`1Uool0IOl0000mool00005o`000?oo06Goo`1U
ool0IOl000001Ooo0<X00ol0003oc`3ooll0o`05oll0o`03o`000?mZ0?ooJP3o00[oJP3o00?o0000
o`D0ool50?l06Ol50?l00ol0003o063oo`1Po`0Xo`1Po`03o`000?l50?oo1@3o01Wo1@3o00?o0000
ofX0oomZ0?l02_mZ0?l00ol0003oc`3ooll0o`06oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000
ool0IOoo06D00_oo06D00ol0003oo`00ool0000jool00005o`000?oo06Goo`1Uool0IOl000000ooo
0<X00ol0003oc`3ooll0o`03oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol5
0?l00ol0003o063oo`1Po`0;o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0
om@00ol0003o0?m_o`3oK`0Ao`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08
oookJQ?o0?m_00?o0000o`3oe?l0om@07_l0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo
063o00_o063o00?o0000o`D0ool50?l01ol50?l00ol0003oJP3oofX0o`05ofX0o`03o`000?o?0?oo
c`3o00;oc`3o00?o0000ool0b_oo0<X00_oo0<X01?l0003oo`1Uool0IOl0000mool00005o`000?oo
06Goo`1Uool0IOl000001Ooo0<X00ol0003oc`3ooll0o`06oll0o`03o`000?mZ0?ooJP3o00[oJP3o
00?o0000o`D0ool50?l06?l50?l00ol0003o063oo`1Po`0Xo`1Po`03o`000?l50?oo1@3o01Wo1@3o
00?o0000ofX0oomZ0?l02_mZ0?l00ol0003oc`3ooll0o`06oll0o`03o`000?oo0<[oo`3:00;oo`3:
00?o0000ool0IOoo06D00_oo06D00ol0003oo`00ool0000jool00005o`000?oo06Goo`1Uool0IOl0
00000ooo0<X00ol0003oc`3ooll0o`03oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool5
0?l02?l50?l00ol0003o063oo`1Po`0:o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0
om@07Ol0om@00ol0003o0?m_o`3oK`0Ao`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJQ?o0?m_00?o0000o`3oe?l0om@07_l0om@00ol0003o0<Goo`35o`0Ao`35o`03o`00
0?l0H?oo063o00_o063o00?o0000o`D0ool50?l01ol50?l00ol0003oJP3oofX0o`04ofX0o`03o`00
0?o?0?ooc`3o00;oc`3o00?o0000ool0b_oo0<X00_oo0<X01Ol0003oo`1Uool0IOoo06Go000003go
o`0000?o0000ool0IOoo06D00_oo06D00ol0003oo`3:ool0bP03ool0bP03o`000?o?0?ooc`3o00Go
c`3o00?o0000ofX0oomZ0?l02_mZ0?l00ol0003o1@3oo`D0o`0Go`D0o`03o`000?l0H?oo063o02[o
063o00?o0000o`D0ool50?l06?l50?l00ol0003oJP3oofX0o`09ofX0o`03o`000?o?0?ooc`3o00Ko
c`3o00?o0000ool0b_oo0<X00_oo0<X00ol0003oo`1Uool0I@02ool0I@03o`000?oo003oo`0003co
o`0000Co0000ool0IOoo06Go00001?oo0<X00ol0003oc`3ooll0o`03oll0o`03o`000?mZ0?ooJP3o
00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0003o063oo`1Po`0:o`1Po`03o`000?l0aOoo0<Go
01;o0<Go00?o0000o`3oe?l0om@07Ol0om@00ol0003o0?m_o`3oK`0Ao`3oK`[ooo]Z0Ol00001oook
JP008OoonfX00ol0003ooo]ZoookJP08oookJQ?o0?m_00?o0000o`3oe?l0om@07_l0om@00ol0003o
0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00_o063o00?o0000o`D0ool50?l01ol50?l00ol0003o
JP3oofX0o`04ofX0o`03o`000?o?0?ooc`3o00;oc`3o00?o0000ool0b_oo0<X00_oo0<X01?l0003o
o`1Uool0IOl0000oool00005o`000?oo06Goo`1Uool0IOl000001Ooo0<X00ol0003oc`3ooll0o`05
oll0o`03o`000?mZ0?ooJP3o00[oJP3o00?o0000o`D0ool50?l05ol50?l00ol0003o063oo`1Po`0Z
o`1Po`03o`000?l50?oo1@3o01So1@3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0003oc`3ooll0o`06
oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo06D00ol0003oo`00ool0000l
ool00005o`000?oo06Goo`1Uool0IOl000000ooo0<X00ol0003oc`3ooll0o`03oll0o`03o`000?mZ
0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0003o063oo`1Po`0:o`1Po`03o`000?l0
aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0om@00ol0003o0?m_o`3oK`0Ao`3oK`[ooo]Z0Ol0
0001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQ?o0?m_00?o0000o`3oe?l0om@07_l0om@0
0ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00_o063o00?o0000o`D0ool50?l01ol50?l0
0ol0003oJP3oofX0o`04ofX0o`03o`000?o?0?ooc`3o00;oc`3o00?o0000ool0b_oo0<X00_oo0<X0
1?l0003oo`1Uool0IOl0000oool00005o`000?oo06Goo`1Uool0IOl000001Ooo0<X00ol0003oc`3o
oll0o`05oll0o`03o`000?mZ0?ooJP3o00[oJP3o00?o0000o`D0ool50?l05ol50?l00ol0003o063o
o`1Po`0Zo`1Po`03o`000?l50?oo1@3o01So1@3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0003oc`3o
oll0o`06oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo06D00ol0003oo`00
ool0000lool00005o`000?oo06Goo`1Uool0IOl000000ooo0<X00ol0003oc`3ooll0o`03oll0o`03
o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0003o063oo`1Po`0:o`1Po`03
o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0om@00ol0003o0?m_o`3oK`0Ao`3oK`[o
oo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQ?o0?m_00?o0000o`3oe?l0om@0
7_l0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00_o063o00?o0000o`D0ool50?l0
1ol50?l00ol0003oJP3oofX0o`04ofX0o`03o`000?o?0?ooc`3o00;oc`3o00?o0000ool0b_oo0<X0
0_oo0<X01?l0003oo`1Uool0IOl0000oool00005o`000?oo06Goo`1Uool0IOl000001Ooo0<X00ol0
003oc`3ooll0o`05oll0o`03o`000?mZ0?ooJP3o00[oJP3o00?o0000o`D0ool50?l05_l50?l00ol0
003o063oo`1Po`0/o`1Po`03o`000?l50?oo1@3o01Oo1@3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0
003oc`3ooll0o`06oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo06D00ol0
003oo`00ool0000lool00005o`000?oo06Goo`1Uool0IOl000000ooo0<X00ol0003oc`3ooll0o`03
oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0003o063oo`1Po`0:
o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0om@00ol0003o0?m_o`3oK`0A
o`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQ?o0?m_00?o0000o`3o
e?l0om@07_l0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00_o063o00?o0000o`D0
ool50?l01ol50?l00ol0003oJP3oofX0o`04ofX0o`03o`000?o?0?ooc`3o00;oc`3o00?o0000ool0
b_oo0<X00_oo0<X01?l0003oo`1Uool0IOl0000oool00005o`000?oo06Goo`1Uool0IOl000001Ooo
0<X00ol0003oc`3ooll0o`05oll0o`03o`000?mZ0?ooJP3o00[oJP3o00?o0000o`D0ool50?l05_l5
0?l00ol0003o063oo`1Po`0/o`1Po`03o`000?l50?oo1@3o01Oo1@3o00?o0000ofX0oomZ0?l02OmZ
0?l00ol0003oc`3ooll0o`06oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo
06D00ol0003oo`00ool0000lool00005o`000?oo06Goo`1Uool0IOl000000ooo0<X00ol0003oc`3o
oll0o`03oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0003o063o
o`1Po`0:o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0om@00ol0003o0?m_
o`3oK`0Ao`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQCo0?m_00?o
0000o`3oe?l0om@07Ol0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00_o063o00?o
0000o`D0ool50?l01ol50?l00ol0003oJP3oofX0o`04ofX0o`03o`000?o?0?ooc`3o00;oc`3o00?o
0000ool0b_oo0<X00_oo0<X01?l0003oo`1Uool0IOl0000oool00005o`000?oo06Goo`1Uool0IOl0
00001Ooo0<X00ol0003oc`3ooll0o`05oll0o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000o`D0ool5
0?l05ol50?l00ol0003o063oo`1Po`0]o`1Po`03o`000?l50?oo1@3o01Oo1@3o00?o0000ofX0oomZ
0?l02OmZ0?l00ol0003oc`3ooll0o`05oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo
06D00_oo06D00ol0003oo`00ool0000lool00005o`000?oo06Goo`1Uool0IOl000000ooo0<X00ol0
003oc`3ooll0o`03oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0
003o063oo`1Po`0:o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0om@00ol0
003o0?m_o`3oK`0Ao`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQCo
0?m_00?o0000o`3oe?l0om@07Ol0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00_o
063o00?o0000o`D0ool50?l01ol50?l00ol0003oJP3oofX0o`04ofX0o`03o`000?o?0?ooc`3o00;o
c`3o00?o0000ool0b_oo0<X00_oo0<X01?l0003oo`1Uool0IOl0000oool00005o`000?oo06Goo`1U
ool0IOl000001Ooo0<X00ol0003oc`3ooll0o`05oll0o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000
o`D0ool50?l05_l50?l00ol0003o063oo`1Po`0^o`1Po`03o`000?l50?oo1@3o01Oo1@3o00?o0000
ofX0oomZ0?l02OmZ0?l00ol0003oc`3ooll0o`05oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000
ool0IOoo06D00_oo06D00ol0003oo`00ool0000lool00005o`000?oo06Goo`1Uool0IOl000000ooo
0<X00ol0003oc`3ooll0o`03oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol5
0?l00ol0003o063oo`1Po`0:o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0
om@00ol0003o0?m_o`3oK`0Ao`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08
oookJQCo0?m_00?o0000o`3oe?l0om@07Ol0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo
063o00_o063o00?o0000o`D0ool50?l01ol50?l00ol0003oJP3oofX0o`04ofX0o`03o`000?o?0?oo
c`3o00;oc`3o00?o0000ool0b_oo0<X00_oo0<X01?l0003oo`1Uool0IOl0000oool00005o`000?oo
06Goo`1Uool0IOl000001Ooo0<X00ol0003oc`3ooll0o`05oll0o`03o`000?mZ0?ooJP3o00WoJP3o
00?o0000o`D0ool50?l05_l50?l00ol0003o063oo`1Po`0^o`1Po`03o`000?l50?oo1@3o01Oo1@3o
00?o0000ofX0oomZ0?l02OmZ0?l00ol0003oc`3ooll0o`05oll0o`03o`000?oo0<[oo`3:00;oo`3:
00?o0000ool0IOoo06D00_oo06D00ol0003oo`00ool0000lool00005o`000?oo06Goo`1Uool0IOl0
00000ooo0<X00ol0003oc`3ooll0o`03oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool5
0?l01ol50?l00ol0003o063oo`1Po`0:o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0
om@07Ol0om@00ol0003o0?m_o`3oK`0Ao`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJQCo0?m_00?o0000o`3oe?l0om@07Ol0om@00ol0003o0<Goo`35o`0Ao`35o`03o`00
0?l0H?oo063o00_o063o00?o0000o`D0ool50?l01ol50?l00ol0003oJP3oofX0o`04ofX0o`03o`00
0?o?0?ooc`3o00;oc`3o00?o0000ool0b_oo0<X00_oo0<X01?l0003oo`1Uool0IOl0000oool00005
o`000?oo06Goo`1Uool0IOl000001Ooo0<X00ol0003oc`3ooll0o`05oll0o`03o`000?mZ0?ooJP3o
00WoJP3o00?o0000o`D0ool50?l05_l50?l00ol0003o063oo`1Po`0_o`1Po`03o`000?l50?oo1@3o
01Ko1@3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0003oc`3ooll0o`05oll0o`03o`000?oo0<[oo`3:
00;oo`3:00?o0000ool0IOoo06D00_oo06D00ol0003oo`00ool0000lool00005o`000?oo06Goo`1U
ool0IOl000000ooo0<X00ol0003oc`3ooll0o`03oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000
o`D0ool50?l01ol50?l00ol0003o063oo`1Po`0:o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000
o`3oe?l0om@07Ol0om@00ol0003o0?m_o`3oK`0Ao`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0
003ooo]ZoookJP08oookJQCo0?m_00?o0000o`3oe?l0om@07_l0om@00ol0003o0<Goo`35o`0Ao`35
o`03o`000?l0H?oo063o00_o063o00?o0000o`D0ool50?l01_l50?l00ol0003oJP3oofX0o`05ofX0
o`03o`000?o?0?ooc`3o00;oc`3o00?o0000ool0b_oo0<X00_oo0<X01?l0003oo`1Uool0IOl0000m
ool00005o`000?oo06Goo`1Uool0IOl000001Ooo0<X00ol0003oc`3ooll0o`05oll0o`03o`000?mZ
0?ooJP3o00[oJP3o00?o0000o`D0ool50?l05Ol50?l00ol0003o063oo`1Po`0`o`1Po`03o`000?l5
0?oo1@3o01Ko1@3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0003oc`3ooll0o`06oll0o`03o`000?oo
0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo06D00ol0003oo`00ool0000jool00005o`000?oo
06Goo`1Uool0IOl000000ooo0<X00ol0003oc`3ooll0o`03oll0o`03o`000?mZ0?ooJP3o00CoJP3o
00?o0000o`D0ool50?l01ol50?l00ol0003o063oo`1Po`0:o`1Po`03o`000?l0aOoo0<Go01;o0<Go
00?o0000o`3oe?l0om@07Ol0om@00ol0003o0?m_o`3oK`0Bo`3oK`[ooo]Z0Ol00001oookJP008Ooo
nfX00ol0003ooo]ZoookJP08oookJQCo0?m_00?o0000o`3oe?l0om@07_l0om@00ol0003o0<Goo`35
o`0Ao`35o`03o`000?l0H?oo063o00_o063o00?o0000o`D0ool50?l01_l50?l00ol0003oJP3oofX0
o`05ofX0o`03o`000?o?0?ooc`3o00;oc`3o00?o0000ool0b_oo0<X00_oo0<X01?l0003oo`1Uool0
IOl0000mool00005o`000?oo06Goo`1Uool0IOl000001Ooo0<X00ol0003oc`3ooll0o`05oll0o`03
o`000?mZ0?ooJP3o00[oJP3o00?o0000o`D0ool50?l05Ol50?l00ol0003o063oo`1Po`0ao`1Po`03
o`000?l50?oo1@3o01Go1@3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0003oc`3ooll0o`06oll0o`03
o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo06D00ol0003oo`00ool0000jool00005
o`000?oo06Goo`1Uool0IOl000000ooo0<X00ol0003oc`3ooll0o`03oll0o`03o`000?mZ0?ooJP3o
00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0003o063oo`1Po`0:o`1Po`03o`000?l0aOoo0<Go
01;o0<Go00?o0000o`3oe?l0om@07Ol0om@00ol0003o0?m_o`3oK`0Bo`3oK`[ooo]Z0Ol00001oook
JP008OoonfX00ol0003ooo]ZoookJP08oookJQCo0?m_00?o0000o`3oe?l0om@07_l0om@00ol0003o
0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00_o063o00?o0000o`D0ool50?l01_l50?l00ol0003o
JP3oofX0o`05ofX0o`03o`000?o?0?ooc`3o00;oc`3o00?o0000ool0b_oo0<X00_oo0<X01?l0003o
o`1Uool0IOl0000mool00005o`000?oo06Goo`1Uool0IOl000001Ooo0<X00ol0003oc`3ooll0o`05
oll0o`03o`000?mZ0?ooJP3o00[oJP3o00?o0000o`D0ool50?l05Ol50?l00ol0003o063oo`1Po`0a
o`1Po`03o`000?l50?oo1@3o01Go1@3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0003oc`3ooll0o`06
oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo06D00ol0003oo`00ool0000j
ool00005o`000?oo06Goo`1Uool0IOl000000ooo0<X00ol0003oc`3ooll0o`03oll0o`03o`000?mZ
0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0003o063oo`1Po`0:o`1Po`03o`000?l0
aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0om@00ol0003o0?m_o`3oK`0Bo`3oK`[ooo]Z0Ol0
0001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQGo0?m_00?o0000o`3oe?l0om@07Ol0om@0
0ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00_o063o00?o0000o`D0ool50?l01_l50?l0
0ol0003oJP3oofX0o`05ofX0o`03o`000?o?0?ooc`3o00;oc`3o00?o0000ool0b_oo0<X00_oo0<X0
1?l0003oo`1Uool0IOl0000mool00005o`000?oo06Goo`1Uool0IOl000001Ooo0<X00ol0003oc`3o
oll0o`05oll0o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000o`D0ool50?l05Ol50?l00ol0003o063o
o`1Po`0co`1Po`03o`000?l50?oo1@3o01Go1@3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0003oc`3o
oll0o`05oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo06D00ol0003oo`00
ool0000jool00005o`000?oo06Goo`1Uool0IOl000000ooo0<X00ol0003oc`3ooll0o`03oll0o`03
o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0003o063oo`1Po`0:o`1Po`03
o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0om@00ol0003o0?m_o`3oK`0Bo`3oK`[o
oo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQGo0?m_00?o0000o`3oe?l0om@0
7Ol0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00_o063o00?o0000o`D0ool50?l0
1_l50?l00ol0003oJP3oofX0o`05ofX0o`03o`000?o?0?ooc`3o00;oc`3o00?o0000ool0b_oo0<X0
0_oo0<X01?l0003oo`1Uool0IOl0000mool00005o`000?oo06Goo`1Uool0IOl000001Ooo0<X00ol0
003oc`3ooll0o`05oll0o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000o`D0ool50?l05Ol50?l00ol0
003o063oo`1Po`0co`1Po`03o`000?l50?oo1@3o01Go1@3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0
003oc`3ooll0o`05oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo06D00ol0
003oo`00ool0000jool00005o`000?oo06Goo`1Uool0IOl000000ooo0<X00ol0003oc`3ooll0o`03
oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0003o063oo`1Po`0:
o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0om@00ol0003o0?m_o`3oK`0B
o`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQGo0?m_00?o0000o`3o
e?l0om@07Ol0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00_o063o00?o0000o`D0
ool50?l01_l50?l00ol0003oJP3oofX0o`05ofX0o`03o`000?o?0?ooc`3o00;oc`3o00?o0000ool0
b_oo0<X00_oo0<X01?l0003oo`1Uool0IOl0000mool00005o`000?oo06Goo`1Uool0IOl000001Ooo
0<X00ol0003oc`3ooll0o`05oll0o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000o`D0ool50?l05Ol5
0?l00ol0003o063oo`1Po`0co`1Po`03o`000?l50?oo1@3o01Go1@3o00?o0000ofX0oomZ0?l02OmZ
0?l00ol0003oc`3ooll0o`05oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo06D00_oo
06D00ol0003oo`00ool0000jool00005o`000?oo06Goo`1Uool0IOl000000ooo0<X00ol0003oc`3o
oll0o`03oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0003o063o
o`1Po`0:o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0om@00ol0003o0?m_
o`3oK`0Bo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQGo0?m_00?o
0000o`3oe?l0om@07Ol0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00_o063o00?o
0000o`D0ool50?l01_l50?l00ol0003oJP3oofX0o`05ofX0o`03o`000?o?0?ooc`3o00;oc`3o00?o
0000ool0b_oo0<X00_oo0<X01?l0003oo`1Uool0IOl0000mool00005o`000?oo06Goo`1Uool0IOl0
00001Ooo0<X00ol0003oc`3ooll0o`05oll0o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000o`D0ool5
0?l05?l50?l00ol0003o063oo`1Po`0eo`1Po`03o`000?l50?oo1@3o01Co1@3o00?o0000ofX0oomZ
0?l02OmZ0?l00ol0003oc`3ooll0o`05oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000ool0IOoo
06D00_oo06D00ol0003oo`00ool0000jool00005o`000?oo06Goo`1Uool0IOl000000ooo0<X00ol0
003oc`3ooll0o`03oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0
003o063oo`1Po`0:o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0om@00ol0
003o0?m_o`3oK`0Bo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQGo
0?m_00?o0000o`3oe?l0om@07Ol0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00_o
063o00?o0000o`D0ool50?l01_l50?l00ol0003oJP3oofX0o`05ofX0o`03o`000?o?0?ooc`3o00;o
c`3o00?o0000ool0b_oo0<X00_oo0<X01?l0003oo`1Uool0IOl0000mool00005o`000?oo06Goo`1U
ool0IOl000001Ooo0<X00ol0003oc`3ooll0o`05oll0o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000
o`D0ool50?l05?l50?l00ol0003o063oo`1Po`0eo`1Po`03o`000?l50?oo1@3o01Co1@3o00?o0000
ofX0oomZ0?l02OmZ0?l00ol0003oc`3ooll0o`05oll0o`03o`000?oo0<[oo`3:00;oo`3:00?o0000
ool0IOoo06D00_oo06D00ol0003oo`00ool0000jool00005o`000?oo06Goo`1Uool0IOl000000ooo
0<X00ol0003oc`3ooll0o`03oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol5
0?l00ol0003o063oo`1Po`0:o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0
om@00ol0003o0?m_o`3oK`0Bo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08
oookJQGo0?m_00?o0000o`3oe?l0om@07Ol0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo
063o00_o063o00?o0000o`D0ool50?l01ol50?l00ol0003oJP3oofX0o`04ofX0o`03o`000?o?0?oo
c`3o00?oc`3o00?o0000ool0b_oo0<X00_oo0<X01?l0003oo`1Uool0IOl0000kool00005o`000?oo
06Goo`1Uool0IOl000001Ooo0<X00ol0003oc`3ooll0o`05oll0o`03o`000?mZ0?ooJP3o00WoJP3o
00?o0000o`D0ool50?l05?l50?l00ol0003o063oo`1Po`0go`1Po`03o`000?l50?oo1@3o01Co1@3o
00?o0000ofX0oomZ0?l02OmZ0?l00ol0003oc`3ooll0o`04oll0o`03o`000?oo0<[oo`3:00?oo`3:
00?o0000ool0IOoo06D00_oo06D00ol0003oo`00ool0000iool00004o`000?oo06Goo`1Uo`0000?o
o`3:00?o0000oll0ooo?0?l00oo?0?l00ol0003oJP3oofX0o`05ofX0o`03o`000?l50?oo1@3o00Oo
1@3o00?o0000o`1Pool0H?l02_l0H?l00ol0003o0<Goo`35o`0Bo`35o`03o`000?l0omCo0?oD01go
0?oD00?o0000o`3oKol0ofl04_l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX0
2?oonfXEo`3oK`03o`000?l0omCo0?oD01ko0?oD00?o0000o`35ool0aOl04Ol0aOl00ol0003o063o
o`1Po`0;o`1Po`03o`000?l50?oo1@3o00Ko1@3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003oc`3o
oll0o`02oll0o`03o`000?oo0<[oo`3:00;oo`3:00Co0000ool0IOoo06Go0000>ooo00001Ol0003o
o`1Uool0IOoo06Go000000Goo`3:00?o0000oll0ooo?0?l01Oo?0?l00ol0003oJP3oofX0o`09ofX0
o`03o`000?l50?oo1@3o01Co1@3o00?o0000o`1Pool0H?l0=ol0H?l00ol0003o1@3oo`D0o`0Do`D0
o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000oll0ooo?0?l01Oo?0?l00ol0003oo`3:ool0bP02ool0
bP03o`000?oo06Goo`1U00;oo`1U00?o0000ool00?oo0000>?oo00001Ol0003oo`1Uool0IOoo06Go
000000?oo`3:00?o0000oll0ooo?0?l00oo?0?l00ol0003oJP3oofX0o`04ofX0o`03o`000?l50?oo
1@3o00Oo1@3o00?o0000o`1Pool0H?l02_l0H?l00ol0003o0<Goo`35o`0Bo`35o`03o`000?l0omCo
0?oD01ko0?oD00?o0000o`3oKol0ofl04_l0ofl:oookJP7o00000OoonfX0027ooo]Z0ol00008oook
JQKo0?m_00?o0000o`3oe?l0om@07Ol0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o
00_o063o00?o0000o`D0ool50?l01_l50?l00ol0003oJP3oofX0o`05ofX0o`03o`000?o?0?ooc`3o
00?oc`3o00?o0000ool0b_oo0<X00_oo0<X01?l0003oo`1Uool0IOl0000iool00005o`000?oo06Go
o`1Uool0IOl000001Ooo0<X00ol0003oc`3ooll0o`05oll0o`03o`000?mZ0?ooJP3o00WoJP3o00?o
0000o`D0ool50?l05?l50?l00ol0003o063oo`1Po`0io`1Po`03o`000?l50?oo1@3o01?o1@3o00?o
0000ofX0oomZ0?l02OmZ0?l00ol0003oc`3ooll0o`05oll0o`03o`000?oo0<[oo`3:00?oo`3:00?o
0000ool0IOoo06D00_oo06D00ol0003oo`00ool0000gool00004o`000?oo06Goo`1Uo`0000Coo`3:
00?o0000oll0ooo?0?l00oo?0?l00ol0003oJP3oofX0o`04ofX0o`03o`000?l50?oo1@3o00Oo1@3o
00?o0000o`1Pool0H?l02_l0H?l00ol0003o0<Goo`35o`0Bo`35o`03o`000?l0omCo0?oD01go0?oD
00?o0000o`3oKol0ofl04ol0ofl8oookJP?o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oo
nfXFo`3oK`03o`000?l0omCo0?oD01go0?oD00?o0000o`35ool0aOl04Ol0aOl00ol0003o063oo`1P
o`0;o`1Po`03o`000?l50?oo1@3o00Oo1@3o00?o0000ofX0oomZ0?l01?mZ0?l00ol0003oc`3ooll0
o`03oll0o`03o`000?oo0<[oo`3:00;oo`3:00Co0000ool0IOoo06Go0000>Ooo00001Ol0003oo`1U
ool0IOoo06Go000000Goo`3:00?o0000oll0ooo?0?l01Oo?0?l00ol0003oJP3oofX0o`09ofX0o`03
o`000?l50?oo1@3o01Co1@3o00?o0000o`1Pool0H?l0>Ol0H?l00ol0003o1@3oo`D0o`0Do`D0o`03
o`000?mZ0?ooJP3o00WoJP3o00?o0000oll0ooo?0?l01?o?0?l00ol0003oo`3:ool0bP03ool0bP03
o`000?oo06Goo`1U00;oo`1U00?o0000ool00?oo0000=ooo00001?l0003oo`1Uool0IOl00003ool0
bP03o`000?o?0?ooc`3o00?oc`3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003o1@3oo`D0o`07o`D0
o`03o`000?l0H?oo063o00[o063o00?o0000o`35ool0aOl04_l0aOl00ol0003o0?oDo`3oe00Mo`3o
e003o`000?l0ofoo0?m_01?o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00So
oo]Z5_l0ofl00ol0003o0?oDo`3oe00Mo`3oe003o`000?l0aOoo0<Go017o0<Go00?o0000o`1Pool0
H?l02ol0H?l00ol0003o1@3oo`D0o`07o`D0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000oll0ooo?
0?l01?o?0?l00ol0003oo`3:ool0bP02ool0bP03o`000?oo06Go000003Soo`0000Go0000ool0IOoo
06Goo`1Uo`000006ool0bP03o`000?o?0?ooc`3o00Coc`3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0
003o1@3oo`D0o`0Do`D0o`03o`000?l0H?oo063o03_o063o00?o0000o`D0ool50?l04ol50?l00ol0
003oJP3oofX0o`09ofX0o`03o`000?o?0?ooc`3o00Goc`3o00?o0000ool0b_oo0<X00ooo0<X00ol0
003oo`1Uool0I@02ool0I@03o`000?oo003oo`0003Goo`0000Co0000ool0IOoo06Go00001?oo0<X0
0ol0003oc`3ooll0o`03oll0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol50?l0
0ol0003o063oo`1Po`0;o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07Ol0om@0
0ol0003o0?m_o`3oK`0Co`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oook
JQKo0?m_00?o0000o`3oe?l0om@07_l0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o
00_o063o00?o0000o`D0ool50?l01ol50?l00ol0003oJP3oofX0o`03ofX0o`03o`000?o?0?ooc`3o
00Coc`3o00?o0000ool0b_oo0<X00_oo0<X01?l0003oo`1Uool0IOl0000fool00003o`000?oo06Go
o`1U00;oo`1U00?o0000ool0b_oo0<X00ooo0<X00ol0003oc`3ooll0o`05oll0o`03o`000?mZ0?oo
JP3o00WoJP3o00?o0000o`D0ool50?l04ol50?l00ol0003o063oo`1Po`0lo`1Po`03o`000?l50?oo
1@3o01Co1@3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0003oc`3ooll0o`04oll0o`03o`000?oo0<[o
o`3:00Coo`3:00?o0000ool0IOoo06D00_oo06D00ol0003oo`00ool0000dool00004o`000?oo06Go
o`1Uo`0000?oo`3:00?o0000oll0ooo?0?l01?o?0?l00ol0003oJP3oofX0o`04ofX0o`03o`000?l5
0?oo1@3o00Oo1@3o00?o0000o`1Pool0H?l02_l0H?l00ol0003o0<Goo`35o`0Bo`35o`03o`000?l0
omCo0?oD01ko0?oD00?o0000o`3oKol0ofl04ol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000
oookJ_oonfX02?oonfXFo`3oK`03o`000?l0omCo0?oD01ko0?oD00?o0000o`35ool0aOl04Ol0aOl0
0ol0003o063oo`1Po`0;o`1Po`03o`000?l50?oo1@3o00Oo1@3o00?o0000ofX0oomZ0?l01?mZ0?l0
0ol0003oc`3ooll0o`03oll0o`03o`000?oo0<[oo`3:00;oo`3:00Co0000ool0IOoo06Go0000=_oo
00000ol0003oo`1Uool0I@02ool0I@03o`000?oo0<[oo`3:00?oo`3:00?o0000oll0ooo?0?l01Oo?
0?l00ol0003oJP3oofX0o`09ofX0o`03o`000?l50?oo1@3o01?o1@3o00?o0000o`1Pool0H?l0??l0
H?l00ol0003o1@3oo`D0o`0Do`D0o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000oll0ooo?0?l01?o?
0?l00ol0003oo`3:ool0bP04ool0bP03o`000?oo06Goo`1U00;oo`1U00?o0000ool00?oo0000=?oo
00001?l0003oo`1Uool0IOl00003ool0bP03o`000?o?0?ooc`3o00?oc`3o00?o0000ofX0oomZ0?l0
1OmZ0?l00ol0003o1@3oo`D0o`07o`D0o`03o`000?l0H?oo063o00[o063o00?o0000o`35ool0aOl0
4_l0aOl00ol0003o0?oDo`3oe00No`3oe003o`000?l0ofoo0?m_01?o0?m_2_oonfX1o`00007ooo]Z
000QoookJP03o`000?oonf[ooo]Z00Sooo]Z5_l0ofl00ol0003o0?oDo`3oe00No`3oe003o`000?l0
aOoo0<Go017o0<Go00?o0000o`1Pool0H?l02ol0H?l00ol0003o1@3oo`D0o`07o`D0o`03o`000?mZ
0?ooJP3o00CoJP3o00?o0000oll0ooo?0?l01?o?0?l00ol0003oo`3:ool0bP02ool0bP04o`000?oo
06Goo`1Uo`0003Coo`0000?o0000ool0IOoo06D00_oo06D00ol0003oo`3:ool0bP03ool0bP03o`00
0?o?0?ooc`3o00Goc`3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0003o1@3oo`D0o`0Co`D0o`03o`00
0?l0H?oo063o03ko063o00?o0000o`D0ool50?l04ol50?l00ol0003oJP3oofX0o`09ofX0o`03o`00
0?o?0?ooc`3o00Goc`3o00?o0000ool0b_oo0<X01?oo0<X00ol0003oo`1Uool0I@02ool0I@03o`00
0?oo003oo`0003;oo`0000Co0000ool0IOoo06Go00001?oo0<X00ol0003oc`3ooll0o`03oll0o`03
o`000?mZ0?ooJP3o00CoJP3o00?o0000o`D0ool50?l01ol50?l00ol0003o063oo`1Po`0;o`1Po`03
o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07_l0om@00ol0003o0?m_o`3oK`0Co`3oK`[o
oo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQKo0?m_00?o0000o`3oe?l0om@0
7_l0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00_o063o00?o0000o`D0ool50?l0
2?l50?l00ol0003oJP3oofX0o`03ofX0o`03o`000?o?0?ooc`3o00Coc`3o00?o0000ool0b_oo0<X0
0_oo0<X01Ol0003oo`1Uool0IOoo06Go000003?oo`0000?o0000ool0IOoo06D00_oo06D00ol0003o
o`3:ool0bP03ool0bP03o`000?o?0?ooc`3o00Goc`3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0003o
1@3oo`D0o`0Co`D0o`03o`000?l0H?oo063o03ko063o00?o0000o`D0ool50?l05?l50?l00ol0003o
JP3oofX0o`09ofX0o`03o`000?o?0?ooc`3o00Goc`3o00?o0000ool0b_oo0<X00ooo0<X00ol0003o
o`1Uool0I@02ool0I@03o`000?oo003oo`00037oo`0000Go0000ool0IOoo06Goo`1Uo`000003ool0
bP03o`000?o?0?ooc`3o00Coc`3o00?o0000ofX0oomZ0?l01?mZ0?l00ol0003o1@3oo`D0o`07o`D0
o`03o`000?l0H?oo063o00_o063o00?o0000o`35ool0aOl04_l0aOl00ol0003o0?oDo`3oe00No`3o
e003o`000?l0ofoo0?m_01?o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00So
oo]Z5ol0ofl00ol0003o0?oDo`3oe00Mo`3oe003o`000?l0aOoo0<Go017o0<Go00?o0000o`1Pool0
H?l02ol0H?l00ol0003o1@3oo`D0o`08o`D0o`03o`000?mZ0?ooJP3o00CoJP3o00?o0000oll0ooo?
0?l01?o?0?l00ol0003oo`3:ool0bP02ool0bP04o`000?oo06Goo`1Uo`0003;oo`0000?o0000ool0
IOoo06D00_oo06D00ol0003oo`3:ool0bP03ool0bP03o`000?o?0?ooc`3o00Goc`3o00?o0000ofX0
oomZ0?l02OmZ0?l00ol0003o1@3oo`D0o`0Co`D0o`03o`000?l0H?oo063o043o063o00?o0000o`D0
ool50?l04ol50?l00ol0003oJP3oofX0o`09ofX0o`03o`000?o?0?ooc`3o00Goc`3o00?o0000ool0
b_oo0<X01?oo0<X00ol0003oo`1Uool0I@02ool0I@03o`000?oo003oo`0002ooo`0000Go0000ool0
IOoo06Goo`1Uo`000004ool0bP03o`000?o?0?ooc`3o00?oc`3o00?o0000ofX0oomZ0?l01OmZ0?l0
0ol0003o1@3oo`D0o`07o`D0o`03o`000?l0H?oo063o00_o063o00?o0000o`35ool0aOl04_l0aOl0
0ol0003o0?oDo`3oe00Mo`3oe003o`000?l0ofoo0?m_01Co0?m_2_oonfX1o`00007ooo]Z000Qoook
JP03o`000?oonf[ooo]Z00Sooo]Z5ol0ofl00ol0003o0?oDo`3oe00No`3oe003o`000?l0aOoo0<Go
017o0<Go00?o0000o`1Pool0H?l02ol0H?l00ol0003o1@3oo`D0o`07o`D0o`03o`000?mZ0?ooJP3o
00GoJP3o00?o0000oll0ooo?0?l00oo?0?l00ol0003oo`3:ool0bP02ool0bP05o`000?oo06Goo`1U
ool0IOl00000<Ooo00000ol0003oo`1Uool0I@02ool0I@03o`000?oo0<[oo`3:00?oo`3:00?o0000
oll0ooo?0?l01Oo?0?l00ol0003oJP3oofX0o`09ofX0o`03o`000?l50?oo1@3o01?o1@3o00?o0000
o`1Pool0H?l0@Ol0H?l00ol0003o1@3oo`D0o`0Bo`D0o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000
oll0ooo?0?l01_o?0?l00ol0003oo`3:ool0bP03ool0bP03o`000?oo06Goo`1U00;oo`1U00?o0000
ool00?oo0000;_oo00000ol0003oo`1Uool0I@02ool0I@03o`000?oo0<[oo`3:00;oo`3:00?o0000
oll0ooo?0?l00oo?0?l00ol0003oJP3oofX0o`04ofX0o`03o`000?l50?oo1@3o00Oo1@3o00?o0000
o`1Pool0H?l02ol0H?l00ol0003o0<Goo`35o`0Bo`35o`03o`000?l0omCo0?oD01ko0?oD00?o0000
o`3oKol0ofl05?l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXGo`3o
K`03o`000?l0omCo0?oD01ko0?oD00?o0000o`35ool0aOl04Ol0aOl00ol0003o063oo`1Po`0;o`1P
o`03o`000?l50?oo1@3o00So1@3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0003oc`3ooll0o`03oll0
o`03o`000?oo0<[oo`3:00;oo`3:0_l00002ool0I@;o0000;Ooo0002o`0000Coo`1U00?o0000ool0
b_oo0<X00ooo0<X00ol0003oc`3ooll0o`05oll0o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000o`D0
ool50?l04ol50?l00ol0003o063oo`1Po`13o`1Po`03o`000?l50?oo1@3o01;o1@3o00?o0000ofX0
oomZ0?l02OmZ0?l00ol0003oc`3ooll0o`06oll0o`03o`000?oo0<[oo`3:00?oo`3:00?o0000ool0
IOoo06D00_oo06D2o`0002coo`000_l00003ool0I@;o00001?oo0<X00ol0003oc`3ooll0o`03oll0
o`03o`000?mZ0?ooJP3o00GoJP3o00?o0000o`D0ool50?l01ol50?l00ol0003o063oo`1Po`0;o`1P
o`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0om@07_l0om@00ol0003o0?m_o`3oK`0Do`3o
K`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQOo0?m_00?o0000o`3oe?l0
om@07_l0om@00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0H?oo063o00_o063o00?o0000o`D0ool5
0?l02?l50?l00ol0003oJP3oofX0o`05ofX0o`03o`000?o?0?ooc`3o00?oc`3o00?o0000ool0b_oo
0<X01?oo0<X01Ol0003oo`1Uool0IOoo06Go000002_oo`0000?o0000ool0IOoo06D00ooo06D00ol0
003oo`3:ool0bP03ool0bP03o`000?o?0?ooc`3o00Koc`3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0
003o1@3oo`D0o`0Co`D0o`03o`000?l0H?oo063o04?o063o00?o0000o`D0ool50?l04_l50?l00ol0
003oJP3oofX0o`09ofX0o`03o`000?o?0?ooc`3o00Ooc`3o00?o0000ool0b_oo0<X00ooo0<X00ol0
003oo`1Uool0I@03ool0I@03o`000?oo003oo`0002Soo`0000?o0000ool0IOoo06D00_oo06D00ol0
003oo`3:ool0bP04ool0bP03o`000?o?0?ooc`3o00?oc`3o00?o0000ofX0oomZ0?l01OmZ0?l00ol0
003o1@3oo`D0o`07o`D0o`03o`000?l0H?oo063o00_o063o00?o0000o`35ool0aOl04_l0aOl00ol0
003o0?oDo`3oe00No`3oe003o`000?l0ofoo0?m_01Co0?m_2_oonfX1o`00007ooo]Z000QoookJP03
o`000?oonf[ooo]Z00Sooo]Z5ol0ofl00ol0003o0?oDo`3oe00No`3oe003o`000?l0aOoo0<Go01;o
0<Go00?o0000o`1Pool0H?l02ol0H?l00ol0003o1@3oo`D0o`08o`D0o`03o`000?mZ0?ooJP3o00Go
JP3o00?o0000oll0ooo?0?l00oo?0?l00ol0003oo`3:ool0bP04ool0bP04o`000?oo06Goo`1Uool0
I@;o00009ooo0002o`0000Goo`1U00?o0000ool0b_oo0<X00ooo0<X00ol0003oc`3ooll0o`06oll0
o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000o`D0ool50?l04ol50?l00ol0003o063oo`1Po`15o`1P
o`03o`000?l50?oo1@3o01;o1@3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0003oc`3ooll0o`07oll0
o`03o`000?oo0<[oo`3:00?oo`3:00?o0000ool0IOoo06D00ooo06D2o`0002Ooo`0000?o0000ool0
IOoo06D00_oo06D00ol0003oo`3:ool0bP04ool0bP03o`000?o?0?ooc`3o00?oc`3o00?o0000ofX0
oomZ0?l01OmZ0?l00ol0003o1@3oo`D0o`07o`D0o`03o`000?l0H?oo063o00_o063o00?o0000o`35
ool0aOl04_l0aOl00ol0003o0?oDo`3oe00No`3oe003o`000?l0ofoo0?m_01Go0?m_2_oonfX1o`00
007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z6?l0ofl00ol0003o0?oDo`3oe00No`3oe003
o`000?l0aOoo0<Go017o0<Go00?o0000o`1Pool0H?l02ol0H?l00ol0003o1@3oo`D0o`08o`D0o`03
o`000?mZ0?ooJP3o00KoJP3o00?o0000oll0ooo?0?l00oo?0?l00ol0003oo`3:ool0bP04ool0bP;o
00000ooo06D00ol0003oo`00ool0000Sool00003o`000?oo06Goo`1U00Coo`1U00?o0000ool0b_oo
0<X00ooo0<X00ol0003oc`3ooll0o`06oll0o`03o`000?mZ0?ooJP3o00[oJP3o00?o0000o`D0ool5
0?l04_l50?l00ol0003o063oo`1Po`17o`1Po`03o`000?l50?oo1@3o01;o1@3o00?o0000ofX0oomZ
0?l02OmZ0?l00ol0003oc`3ooll0o`07oll0o`03o`000?oo0<[oo`3:00?oo`3:00?o0000ool0IOoo
06D01?oo06D00ol0003oo`00ool0000Rool000;o00000ooo06D2o`0000Koo`3:00?o0000oll0ooo?
0?l00oo?0?l00ol0003oJP3oofX0o`05ofX0o`03o`000?l50?oo1@3o00So1@3o00?o0000o`1Pool0
H?l02ol0H?l00ol0003o0<Goo`35o`0Bo`35o`03o`000?l0omCo0?oD01ko0?oD00?o0000o`3oKol0
ofl05Ol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXHo`3oK`03o`00
0?l0omCo0?oD01ko0?oD00?o0000o`35ool0aOl04_l0aOl00ol0003o063oo`1Po`0;o`1Po`03o`00
0?l50?oo1@3o00So1@3o00?o0000ofX0oomZ0?l01_mZ0?l00ol0003oc`3ooll0o`03oll0o`03o`00
0?oo0<[oo`3:00Goo`3:00Co0000ool0IOoo06Goo`1U0_l0000Qool000;o00001Ooo06D2o`0000Go
o`3:00?o0000oll0ooo?0?l01_o?0?l00ol0003oJP3oofX0o`0:ofX0o`03o`000?l50?oo1@3o01;o
1@3o00?o0000o`1Pool0H?l0BOl0H?l00ol0003o1@3oo`D0o`0Ao`D0o`03o`000?mZ0?ooJP3o00[o
JP3o00?o0000oll0ooo?0?l01oo?0?l00ol0003oo`3:ool0bP03ool0bP;o00001Ooo06D2o`00027o
o`0000?o0000ool0IOoo06D00_oo06D00ol0003oo`3:ool0bP05ool0bP03o`000?o?0?ooc`3o00?o
c`3o00?o0000ofX0oomZ0?l01_mZ0?l00ol0003o1@3oo`D0o`08o`D0o`03o`000?l0H?oo063o00_o
063o00?o0000o`35ool0aOl04_l0aOl00ol0003o0?oDo`3oe00No`3oe003o`000?l0ofoo0?m_01Go
0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z6?l0ofl00ol0003o0?oD
o`3oe00No`3oe003o`000?l0aOoo0<Go01;o0<Go00?o0000o`1Pool0H?l02ol0H?l00ol0003o1@3o
o`D0o`08o`D0o`03o`000?mZ0?ooJP3o00OoJP3o00?o0000oll0ooo?0?l00oo?0?l00ol0003oo`3:
ool0bP05ool0bP03o`000?oo06Goo`1U00;oo`1U00?o0000ool00?oo00007Ooo00000ol0003oo`1U
ool0I@04ool0I@03o`000?oo0<[oo`3:00Coo`3:00?o0000oll0ooo?0?l01oo?0?l00ol0003oJP3o
ofX0o`0:ofX0o`03o`000?l50?oo1@3o017o1@3o00?o0000o`1Pool0H?l0Bol0H?l00ol0003o1@3o
o`D0o`0Ao`D0o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000oll0ooo?0?l02?o?0?l00ol0003oo`3:
ool0bP04ool0bP03o`000?oo06Goo`1U00Coo`1U00?o0000ool00?oo00007Ooo00000ol0003oo`1U
ool0I@02ool0I@03o`000?oo0<[oo`3:00Goo`3:00?o0000oll0ooo?0?l00oo?0?l00ol0003oJP3o
ofX0o`06ofX0o`03o`000?l50?oo1@3o00So1@3o00?o0000o`1Pool0H?l02ol0H?l00ol0003o0<Go
o`35o`0Bo`35o`03o`000?l0omCo0?oD01ko0?oD00?o0000o`3oKol0ofl05_l0ofl:oookJP7o0000
0OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXHo`3oK`03o`000?l0omCo0?oD01oo0?oD00?o
0000o`35ool0aOl04Ol0aOl00ol0003o063oo`1Po`0<o`1Po`03o`000?l50?oo1@3o00So1@3o00?o
0000ofX0oomZ0?l01omZ0?l00ol0003oc`3ooll0o`03oll0o`;o00001_oo0<X00ol0003oo`1Uool0
I@02ool0I@Co00006Ooo0002o`0000Goo`1U0_l00006ool0bP03o`000?o?0?ooc`3o00Ooc`3o00?o
0000ofX0oomZ0?l02_mZ0?l00ol0003o1@3oo`D0o`0Ao`D0o`03o`000?l0H?oo063o04go063o00?o
0000o`D0ool50?l04Ol50?l00ol0003oJP3oofX0o`09ofX0o`03o`000?o?0?ooc`3o00Soc`3o00?o
0000ool0b_oo0<X01?oo0<X2o`0000Goo`1U0_l0000Iool000Co00001?oo06D00ol0003oo`3:ool0
bP04ool0bP;o00001Oo?0?l00ol0003oJP3oofX0o`07ofX0o`03o`000?l50?oo1@3o00So1@3o00?o
0000o`1Pool0H?l02ol0H?l00ol0003o0<Goo`35o`0Bo`35o`03o`000?l0omCo0?oD01ko0?oD00?o
0000o`3oKol0ofl05_l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXI
o`3oK`03o`000?l0omCo0?oD01ko0?oD00?o0000o`35ool0aOl04_l0aOl00ol0003o063oo`1Po`0;
o`1Po`03o`000?l50?oo1@3o00So1@3o00?o0000ofX0oomZ0?l02?mZ0?l00ol0003oc`3ooll0o`04
oll0o`03o`000?oo0<[oo`3:00Coo`3:0_l00006ool0I@Oo00004Ooo00000ol0003oo`1Uool0I@03
ool0I@;o00001ooo0<X00ol0003oc`3ooll0o`07oll0o`03o`000?mZ0?ooJP3o00[oJP3o00?o0000
o`D0ool50?l04Ol50?l00ol0003o063oo`1Po`1?o`1Po`03o`000?l50?oo1@3o013o1@3o00?o0000
ofX0oomZ0?l02_mZ0?l2o`0000Woc`3o00?o0000ool0b_oo0<X01Ooo0<X2o`0000Goo`1U00?o0000
ool00?oo00003ooo0007o`0000Koo`1U0_l00006ool0bP03o`000?o?0?ooc`3o00Coc`3o00?o0000
ofX0oomZ0?l01omZ0?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?l0H?oo063o00_o063o00?o0000
o`35ool0aOl04Ol0aOl00ol0003o0?oDo`3oe00Oo`3oe003o`000?l0ofoo0?m_01Ko0?m_2_oonfX1
o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z6Ol0ofl00ol0003o0?oDo`3oe00No`3o
e003o`000?l0aOoo0<Go01;o0<Go00?o0000o`1Pool0H?l03?l0H?l00ol0003o1@3oo`D0o`08o`D0
o`03o`000?mZ0?ooJP3o00OoJP3o00?o0000oll0ooo?0?l01Oo?0?l00ol0003oo`3:ool0bP05ool0
bP03o`000?oo06Goo`1U00[oo`1U4Ol00005ool0I@03o`000?oo0<[oo`3:00Koo`3:00?o0000oll0
ooo?0?l01oo?0?l00ol0003oJP3oofX0o`0:ofX0o`03o`000?l50?oo1@3o01;o1@3o00?o0000o`1P
ool0H?l0Col0H?l00ol0003o1@3oo`D0o`0Ao`D0o`03o`000?mZ0?ooJP3o00_oJP3o00?o0000oll0
ooo?0?l01oo?0?l00ol0003oo`3:ool0bP06ool0bP03o`000?oo06Goo`1U00?oo`1U4Ol0000<ool0
I@03o`000?oo0<[oo`3:00Goo`3:00?o0000oll0ooo?0?l01Oo?0?l00ol0003oJP3oofX0o`06ofX0
o`03o`000?l50?oo1@3o00Wo1@3o00?o0000o`1Pool0H?l02ol0H?l00ol0003o0<Goo`35o`0Bo`35
o`03o`000?l0omCo0?oD01ko0?oD00?o0000o`3oKol0ofl05ol0ofl:oookJP7o00000OoonfX0027o
oo]Z00?o0000oookJ_oonfX02?oonfXIo`3oK`03o`000?l0omCo0?oD01oo0?oD00?o0000o`35ool0
aOl04_l0aOl00ol0003o063oo`1Po`0<o`1Po`03o`000?l50?oo1@3o00Oo1@3o00?o0000ofX0oomZ
0?l02?mZ0?l00ol0003oc`3ooll0o`05oll0o`;o00001_oo0<X00ol0003oo`1Uool0I@0Mool0I@;o
00002?oo0<X00ol0003oc`3ooll0o`07oll0o`03o`000?mZ0?ooJP3o00[oJP3o00?o0000o`D0ool5
0?l04_l50?l00ol0003o063oo`1Po`1Ao`1Po`03o`000?l50?oo1@3o017o1@3o00?o0000ofX0oomZ
0?l02omZ0?l00ol0003oc`3ooll0o`07oll0o`03o`000?oo0<[oo`3:00Koo`3:0_l0000Oool0I@03
o`000?oo0<[oo`3:00Coo`3:0_l00007oll0o`03o`000?mZ0?ooJP3o00OoJP3o00?o0000o`D0ool5
0?l02?l50?l00ol0003o063oo`1Po`0<o`1Po`03o`000?l0aOoo0<Go01;o0<Go00?o0000o`3oe?l0
om@07_l0om@00ol0003o0?m_o`3oK`0Go`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJQWo0?m_00?o0000o`3oe?l0om@07ol0om@00ol0003o0<Goo`35o`0Bo`35o`03o`00
0?l0H?oo063o00go063o00?o0000o`D0ool50?l01ol50?l2o`0000WoJP3o00?o0000oll0ooo?0?l0
1_o?0?l00ol0003oo`3:ool0bP04ool0bP?o00006_oo06D2o`0000Woo`3:00?o0000oll0ooo?0?l0
1oo?0?l00ol0003oJP3oofX0o`0:ofX0o`03o`000?l50?oo1@3o01;o1@3o00?o0000o`1Pool0H?l0
Dol0H?l00ol0003o1@3oo`D0o`0Ao`D0o`03o`000?mZ0?ooJP3o00_oJP3o00?o0000oll0ooo?0?l0
1oo?0?l00ol0003oo`3:ool0bP07ool0bP;o00006_oo06D3o`0000Koo`3:00?o0000oll0ooo?0?l0
1_o?0?l00ol0003oJP3oofX0o`07ofX0o`03o`000?l50?oo1@3o00So1@3o00?o0000o`1Pool0H?l0
3Ol0H?l00ol0003o0<Goo`35o`0Ao`35o`03o`000?l0omCo0?oD01oo0?oD00?o0000o`3oKol0ofl0
5ol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXJo`3oK`03o`000?l0
omCo0?oD01ko0?oD00?o0000o`35ool0aOl04ol0aOl00ol0003o063oo`1Po`0<o`1Po`03o`000?l5
0?oo1@3o00Wo1@3o00?o0000ofX0oomZ0?l01omZ0?l00ol0003oc`3ooll0o`06oll0o`03o`000?oo
0<[oo`3:00Koo`3:1?l0000Eool0I@03o`000?oo0<[oo`3:00Soo`3:00?o0000oll0ooo?0?l01oo?
0?l00ol0003oJP3oofX0o`0:ofX0o`03o`000?l50?oo1@3o01;o1@3o00?o0000o`1Pool0H?l0EOl0
H?l00ol0003o1@3oo`D0o`0Ao`D0o`03o`000?mZ0?ooJP3o00_oJP3o00?o0000oll0ooo?0?l01oo?
0?l00ol0003oo`3:ool0bP08ool0bP03o`000?oo06Goo`1U01?oo`1U1?l00008ool0bP03o`000?o?
0?ooc`3o00Koc`3o00?o0000ofX0oomZ0?l01omZ0?l00ol0003o1@3oo`D0o`09o`D0o`03o`000?l0
H?oo063o00co063o00?o0000o`35ool0aOl04_l0aOl00ol0003o0?oDo`3oe00No`3oe003o`000?l0
ofoo0?m_01So0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z6_l0ofl0
0ol0003o0?oDo`3oe00Oo`3oe003o`000?l0aOoo0<Go01;o0<Go00?o0000o`1Pool0H?l03Ol0H?l0
0ol0003o1@3oo`D0o`09o`D0o`03o`000?mZ0?ooJP3o00OoJP3o00?o0000oll0ooo?0?l01_o?0?l0
0ol0003oo`3:ool0bP09ool0bP?o00003Ooo06D5o`0000[oo`3:00?o0000oll0ooo?0?l01oo?0?l0
0ol0003oJP3oofX0o`0:ofX0o`03o`000?l50?oo1@3o01;o1@3o00?o0000o`1Pool0H?l0Eol0H?l0
0ol0003o1@3oo`D0o`0Ao`D0o`03o`000?mZ0?ooJP3o00_oJP3o00?o0000oll0ooo?0?l01oo?0?l0
0ol0003oo`3:ool0bP08ool0bPGo00003?oo06D4o`0000_oo`3:00?o0000oll0ooo?0?l01_o?0?l0
0ol0003oJP3oofX0o`07ofX0o`03o`000?l50?oo1@3o00Wo1@3o00?o0000o`1Pool0H?l03?l0H?l0
0ol0003o0<Goo`35o`0Co`35o`03o`000?l0omCo0?oD01ko0?oD00?o0000o`3oKol0ofl06?l0ofl:
oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXKo`3oK`03o`000?l0omCo0?oD
01ko0?oD00?o0000o`35ool0aOl04ol0aOl00ol0003o063oo`1Po`0=o`1Po`03o`000?l50?oo1@3o
00Wo1@3o0_l00008ofX0o`;o00001oo?0?l2o`0000coo`3:0ol00003ool0I@Oo00003Ooo0<X2o`00
00Soc`3o0_l0000;ofX0o`;o00005?l50?l00ol0003o063oo`1Po`1Io`1Po`03o`000?l50?oo1@3o
017o1@3o0_l0000<ofX0o`;o00002?o?0?l2o`0000goo`3:1ol00002ool0I@?o00003Ooo0<X2o`00
00Ooc`3o0_l00008ofX0o`;o00002ol50?l00ol0003o063oo`1Po`0<o`1Po`03o`000?l0aOoo0<Go
01?o0<Go00?o0000o`3oe?l0om@07ol0om@00ol0003o0?m_o`3oK`0Ho`3oK`[ooo]Z0Ol00001oook
JP008OoonfX00ol0003ooo]ZoookJP08oookJQ_o0?m_00?o0000o`3oe?l0om@07_l0om@00ol0003o
0<Goo`35o`0Co`35o`03o`000?l0H?oo063o00go063o00?o0000o`D0ool50?l02ol50?l00ol0003o
JP3oofX0o`07ofX0o`03o`000?o?0?ooc`3o00Koc`3o0_l0000=ool0bP?o00004Ooo0<X3o`0000Wo
c`3o00?o0000ofX0oomZ0?l02_mZ0?l00ol0003o1@3oo`D0o`0Do`D0o`03o`000?l0H?oo063o05Wo
063o00?o0000o`D0ool50?l04ol50?l00ol0003oJP3oofX0o`0;ofX0o`03o`000?o?0?ooc`3o00Oo
c`3o0ol0000Aool0bP;o00003_oo0<X2o`0000Soc`3o00?o0000ofX0oomZ0?l01omZ0?l00ol0003o
1@3oo`D0o`0;o`D0o`03o`000?l0H?oo063o00co063o00?o0000o`35ool0aOl04ol0aOl00ol0003o
0?oDo`3oe00Oo`3oe003o`000?l0ofoo0?m_01So0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`00
0?oonf[ooo]Z00Sooo]Z7?l0ofl00ol0003o0?oDo`3oe00No`3oe003o`000?l0aOoo0<Go01?o0<Go
00?o0000o`1Pool0H?l03Ol0H?l00ol0003o1@3oo`D0o`0;o`D0o`03o`000?mZ0?ooJP3o00OoJP3o
0_l00008oll0o`?o00007?oo0<X2o`0000[oc`3o0_l0000<ofX0o`03o`000?l50?oo1@3o01?o1@3o
0_l0001Lo`1Po`;o00005Ol50?l00ol0003oJP3oofX0o`0;ofX0o`;o00002_o?0?l2o`0001coo`3:
0ol00008oll0o`;o00002OmZ0?l00ol0003o1@3oo`D0o`0;o`D0o`03o`000?l0H?oo063o00co063o
00?o0000o`35ool0aOl04ol0aOl00ol0003o0?oDo`3oe00Oo`3oe003o`000?l0ofoo0?m_01Wo0?m_
2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z7?l0ofl00ol0003o0?oDo`3o
e00No`3oe003o`000?l0aOoo0<Go01Co0<Go00?o0000o`1Pool0H?l03Ol0H?l00ol0003o1@3oo`D0
o`0;o`D0o`03o`000?mZ0?ooJP3o00SoJP3o0_l00009oll0o`Go00005?oo0<X3o`0000_oc`3o00?o
0000ofX0oomZ0?l02omZ0?l00ol0003o1@3oo`D0o`0Co`D0o`03o`000?l0H?oo063o05ko063o00?o
0000o`D0ool50?l04ol50?l00ol0003oJP3oofX0o`0<ofX0o`03o`000?o?0?ooc`3o00Woc`3o0ol0
000Dool0bPGo00002Oo?0?l2o`0000[oJP3o00?o0000o`D0ool50?l02ol50?l00ol0003o063oo`1P
o`0<o`1Po`03o`000?l0aOoo0<Go01Co0<Go00?o0000o`3oe?l0om@07ol0om@00ol0003o0?m_o`3o
K`0Io`3oK`[ooo]Z0Ol00001oookJP008OoonfX3o`0000Sooo]Z7?l0ofl00ol0003o0?oDo`3oe00O
o`3oe003o`000?l0aOoo0<Go01?o0<Go00?o0000o`1Pool0H?l03_l0H?l00ol0003o1@3oo`D0o`0;
o`D0o`03o`000?mZ0?ooJP3o00WoJP3o00?o0000oll0ooo?0?l02oo?0?l4o`0000Soo`3:2?l0000=
oll0o`03o`000?mZ0?ooJP3o00_oJP3o00?o0000o`D0ool50?l04ol50?l00ol0003o063oo`1Po`1P
o`1Po`03o`000?l50?oo1@3o01?o1@3o00?o0000ofX0oomZ0?l03?mZ0?l00ol0003oc`3ooll0o`0;
oll0o`So00001ooo0<X5o`0000goc`3o00?o0000ofX0oomZ0?l02OmZ0?l00ol0003o1@3oo`D0o`0;
o`D0o`03o`000?l0H?oo063o00go063o00?o0000o`35ool0aOl04ol0aOl00ol0003o0?oDo`3oe00P
o`3oe003o`000?l0ofoo0?m_01Wo0?m_2?oonfX3o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z
00Sooo]Z7Ol0ofl00ol0003o0?oDo`3oe00No`3oe003o`000?l0aOoo0<Go01Co0<Go00?o0000o`1P
ool0H?l03Ol0H?l00ol0003o1@3oo`D0o`0<o`D0o`03o`000?mZ0?ooJP3o00WoJP3o0_l0000?oll0
o`So00004oo?0?l2o`0000goJP3o00?o0000o`D0ool50?l04ol50?l00ol0003o063oo`1Po`1Ro`1P
o`03o`000?l50?oo1@3o01?o1@3o00?o0000ofX0oomZ0?l03?mZ0?l2o`0001?oc`3o1ol0000@oll0
o`;o00002omZ0?l00ol0003o1@3oo`D0o`0;o`D0o`03o`000?l0H?oo063o00go063o00?o0000o`35
ool0aOl05?l0aOl00ol0003o0?oDo`3oe00Oo`3oe003o`000?l0ofoo0?m_01[o0?m_2_oonfX1o`00
007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z7Ol0ofl00ol0003o0?oDo`3oe00Oo`3oe003
o`000?l0aOoo0<Go01Co0<Go00?o0000o`1Pool0H?l03Ol0H?l00ol0003o1@3oo`D0o`0<o`D0o`03
o`000?mZ0?ooJP3o00[oJP3o0_l0000Uoll0o`?o00003OmZ0?l2o`0001Go1@3o00?o0000o`1Pool0
H?l0I?l0H?l2o`0001Co1@3o0_l0000>ofX0o`?o00009Oo?0?l2o`0000coJP3o00?o0000o`D0ool5
0?l02ol50?l00ol0003o063oo`1Po`0=o`1Po`03o`000?l0aOoo0<Go01Co0<Go00?o0000o`3oe?l0
om@08?l0om@00ol0003o0?m_o`3oK`0Jo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJQgo0?m_00?o0000o`3oe?l0om@07ol0om@00ol0003o0<Goo`35o`0Do`35o`03o`00
0?l0H?oo063o00ko063o00?o0000o`D0ool50?l03?l50?l00ol0003oJP3oofX0o`0;ofX0o`03o`00
0?o?0?ooc`3o01ooc`3o0ol0000?ofX0o`03o`000?l50?oo1@3o01?o1@3o0_l0001Yo`1Po`03o`00
0?l50?oo1@3o01?o1@3o00?o0000ofX0oomZ0?l03_mZ0?l3o`00027oc`3o00?o0000ofX0oomZ0?l0
2omZ0?l00ol0003o1@3oo`D0o`0<o`D0o`03o`000?l0H?oo063o00go063o00?o0000o`35ool0aOl0
5?l0aOl00ol0003o0?oDo`3oe00Po`3oe003o`000?l0ofoo0?m_01[o0?m_2_oonfX1o`00007ooo]Z
000QoookJP03o`000?oonf[ooo]Z00Sooo]Z7_l0ofl00ol0003o0?oDo`3oe00Oo`3oe003o`000?l0
aOoo0<Go01Co0<Go00?o0000o`1Pool0H?l03Ol0H?l00ol0003o1@3oo`D0o`0=o`D0o`03o`000?mZ
0?ooJP3o00_oJP3o0ol0000Loll0o`;o00004?mZ0?l2o`0001Go1@3o00?o0000o`1Pool0H?l0J_l0
H?l00ol0003o1@3oo`D0o`0Co`D0o`;o00004OmZ0?l2o`0001coc`3o0ol0000=ofX0o`03o`000?l5
0?oo1@3o00co1@3o00?o0000o`1Pool0H?l03Ol0H?l00ol0003o0<Goo`35o`0Do`35o`03o`000?l0
omCo0?oD023o0?oD00?o0000o`3oKol0ofl06ol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000
oookJ_oonfX02?oonfXNo`3oK`03o`000?l0omCo0?oD01oo0?oD00?o0000o`35ool0aOl05?l0aOl0
0ol0003o063oo`1Po`0>o`1Po`03o`000?l50?oo1@3o00go1@3o0_l0000>ofX0o`Go00005?o?0?l3
o`00017oJP3o00?o0000o`D0ool50?l05?l50?l00ol0003o063oo`1Po`1/o`1Po`;o00005Ol50?l2
o`00017oJP3o0ol0000Doll0o`Go00003_mZ0?l2o`0000ko1@3o00?o0000o`1Pool0H?l03_l0H?l0
0ol0003o0<Goo`35o`0Do`35o`03o`000?l0omCo0?oD023o0?oD00?o0000o`3oKol0ofl06ol0ofl:
oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXNo`3oK`03o`000?l0omCo0?oD
023o0?oD00?o0000o`35ool0aOl05?l0aOl00ol0003o063oo`1Po`0>o`1Po`03o`000?l50?oo1@3o
00ko1@3o00?o0000ofX0oomZ0?l04?mZ0?l4o`0000Soc`3o2?l0000BofX0o`;o00005_l50?l00ol0
003o063oo`1Po`1_o`1Po`03o`000?l50?oo1@3o01Co1@3o00?o0000ofX0oomZ0?l04OmZ0?l8o`00
00Ooc`3o1Ol0000BofX0o`03o`000?l50?oo1@3o00go1@3o00?o0000o`1Pool0H?l03_l0H?l00ol0
003o0<Goo`35o`0Do`35o`03o`000?l0omCo0?oD027o0?oD00?o0000o`3oKol0ofl06ol0ofl:oook
JP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXOo`3oK`03o`000?l0omCo0?oD01oo
0?oD00?o0000o`35ool0aOl05Ol0aOl00ol0003o063oo`1Po`0>o`1Po`;o00003ol50?l2o`0001Co
JP3o2?l0000IofX0o`03o`000?l50?oo1@3o01Go1@3o00?o0000o`1Pool0H?l0LOl0H?l00ol0003o
1@3oo`D0o`0Do`D0o`;o00006OmZ0?l7o`0001GoJP3o0_l0000?o`D0o`03o`000?l0H?oo063o00ko
063o00?o0000o`35ool0aOl05Ol0aOl00ol0003o0?oDo`3oe00Po`3oe003o`000?l0ofoo0?m_01co
0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z7ol0ofl00ol0003o0?oD
o`3oe00Po`3oe003o`000?l0aOoo0<Go01Co0<Go00?o0000o`1Pool0H?l04?l0H?l00ol0003o1@3o
o`D0o`0>o`D0o`;o0000<OmZ0?l2o`0001Oo1@3o00?o0000o`1Pool0H?l0Lol0H?l00ol0003o1@3o
o`D0o`0Eo`D0o`;o0000<OmZ0?l2o`00013o1@3o00?o0000o`1Pool0H?l03ol0H?l00ol0003o0<Go
o`35o`0Do`35o`03o`000?l0omCo0?oD027o0?oD00?o0000o`3oKol0ofl07?l0ofl:oookJP7o0000
0OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXOo`3oK`03o`000?l0omCo0?oD023o0?oD00?o
0000o`35ool0aOl05Ol0aOl00ol0003o063oo`1Po`0@o`1Po`03o`000?l50?oo1@3o00oo1@3o00?o
0000ofX0oomZ0?l0;OmZ0?l00ol0003o1@3oo`D0o`0Fo`D0o`03o`000?l0H?oo063o07Go063o00?o
0000o`D0ool50?l05_l50?l00ol0003oJP3oofX0o`0]ofX0o`03o`000?l50?oo1@3o00oo1@3o00?o
0000o`1Pool0H?l03ol0H?l00ol0003o0<Goo`35o`0Eo`35o`03o`000?l0omCo0?oD027o0?oD00?o
0000o`3oKol0ofl07?l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXP
o`3oK`03o`000?l0omCo0?oD023o0?oD00?o0000o`35ool0aOl05Ol0aOl00ol0003o063oo`1Po`0@
o`1Po`;o00004?l50?l2o`0002WoJP3o1?l0000Go`D0o`;o0000<ol0H?lBo`0003Co063o0_l0000G
o`D0o`Co0000:OmZ0?l2o`00013o1@3o0_l0000Ao`1Po`03o`000?l0aOoo0<Go01Go0<Go00?o0000
o`3oe?l0om@08Ol0om@00ol0003o0?m_o`3oK`0Mo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0
003ooo]ZoookJP08oookJR3o0?m_00?o0000o`3oe?l0om@08?l0om@00ol0003o0<Goo`35o`0Fo`35
o`03o`000?l0H?oo063o017o063o0_l0000@o`D0o`?o00008omZ0?l3o`0001Wo1@3o0_l0000bo`1P
o`?o00004_l0aOl3o`0003?o063o0_l0000Io`D0o`?o00008omZ0?l3o`00013o1@3o0_l0000Co`1P
o`03o`000?l0aOoo0<Go01Go0<Go00?o0000o`3oe?l0om@08Ol0om@00ol0003o0?m_o`3oK`0Mo`3o
K`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJR7o0?m_00?o0000o`3oe?l0
om@08?l0om@00ol0003o0<Goo`35o`0Fo`35o`;o00004ol0H?l00ol0003o1@3oo`D0o`0@o`D0o`Co
00007?mZ0?l3o`0001[o1@3o0_l0000ao`1Po`?o00006?l0aOl4o`00037o063o00?o0000o`D0ool5
0?l06Ol50?l3o`0001coJP3o1?l0000Bo`D0o`03o`000?l0H?oo063o017o063o0_l0000Go`35o`03
o`000?l0omCo0?oD027o0?oD00?o0000o`3oKol0ofl07_l0ofl:oookJP7o00000OoonfX0027ooo]Z
00?o0000oookJ_oonfX02?oonfXQo`3oK`03o`000?l0omCo0?oD027o0?oD00?o0000o`35ool0aOl0
5ol0aOl00ol0003o063oo`1Po`0Ao`1Po`;o00005?l50?l7o`0001;oJP3o0ol0000Ko`D0o`;o0000
<?l0H?l3o`0001oo0<Go0ol0000_o`1Po`;o00007?l50?l3o`0001;oJP3o1ol0000Do`D0o`;o0000
4ol0H?l00ol0003o0<Goo`35o`0Fo`35o`03o`000?l0omCo0?oD02;o0?oD00?o0000o`3oKol0ofl0
7_l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXRo`3oK`03o`000?l0
omCo0?oD027o0?oD00?o0000o`35ool0aOl05ol0aOl00ol0003o063oo`1Po`0Bo`1Po`;o00006Ol5
0?lBo`0001go1@3o00?o0000o`1Pool0H?l0;Ol0H?l3o`0002Go0<Go0ol0000^o`1Po`;o00007Ol5
0?lBo`0001Wo1@3o0_l0000Do`1Po`03o`000?l0aOoo0<Go01Oo0<Go00?o0000o`3oe?l0om@08Ol0
om@00ol0003o0?m_o`3oK`0Oo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08
oookJR;o0?m_00?o0000o`3oe?l0om@08Ol0om@00ol0003o0<Goo`35o`0Ho`35o`03o`000?l0H?oo
063o01?o063o00?o0000o`D0ool50?l0@ol50?l2o`0002go063o0ol0000[o`35o`;o0000;_l0H?l0
0ol0003o1@3oo`D0o`14o`D0o`03o`000?l0H?oo063o01?o063o00?o0000o`35ool0aOl05ol0aOl0
0ol0003o0?oDo`3oe00Ro`3oe003o`000?l0ofoo0?m_01oo0?m_2_oonfX1o`00007ooo]Z000Qoook
JP03o`000?oonf[ooo]Z00Sooo]Z8ol0ofl00ol0003o0?oDo`3oe00Qo`3oe003o`000?l0aOoo0<Go
01So0<Go00?o0000o`1Pool0H?l04ol0H?l2o`00047o1@3o0_l0000]o`1Po`;o0000<?l0aOl2o`00
02go063o0_l00012o`D0o`;o00005Ol0H?l00ol0003o0<Goo`35o`0Go`35o`03o`000?l0omCo0?oD
02;o0?oD00?o0000o`3oKol0ofl08?l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oo
nfX02?oonfXTo`3oK`03o`000?l0omCo0?oD027o0?oD00?o0000o`35ool0aOl06?l0aOl00ol0003o
063oo`1Po`0Do`1Po`;o0000?Ol50?l2o`0002go063o0_l0000do`35o`?o0000;?l0H?l2o`0003ko
1@3o0_l0000Eo`1Po`;o00006Ol0aOl00ol0003o0?oDo`3oe00Ro`3oe003o`000?l0ofoo0?m_027o
0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z9?l0ofl00ol0003o0?oD
o`3oe00Ro`3oe003o`000?l0aOoo0<Go01So0<Go00?o0000o`1Pool0H?l05Ol0H?l2o`0003So1@3o
0ol0000/o`1Po`?o0000>Ol0aOl2o`0002co063o0ol0000io`D0o`;o00005_l0H?l00ol0003o0<Go
o`35o`0Io`35o`03o`000?l0omCo0?oD02;o0?oD00?o0000o`3oKol0ofl08Ol0ofl:oookJP7o0000
0OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXUo`3oK`03o`000?l0omCo0?oD02;o0?oD00?o
0000o`35ool0aOl06?l0aOl00ol0003o063oo`1Po`0Fo`1Po`?o0000<_l50?l3o`0002go063o0_l0
000no`35o`;o0000;Ol0H?l3o`0003?o1@3o0ol0000Go`1Po`03o`000?l0aOoo0<Go01Wo0<Go00?o
0000o`3oe?l0om@08_l0om@00ol0003o0?m_o`3oK`0Ro`3oK`[ooo]Z0Ol00001oookJP008OoonfX0
0ol0003ooo]ZoookJP08oookJRGo0?m_00?o0000o`3oe?l0om@08_l0om@00ol0003o0<Goo`35o`0I
o`35o`03o`000?l0H?oo063o01So063o0_l0000^o`D0o`;o0000;_l0H?l2o`0004;o0<Go0_l0000^
o`1Po`?o0000;_l50?l2o`0001Wo063o00?o0000o`35ool0aOl06Ol0aOl00ol0003o0?oDo`3oe00S
o`3oe003o`000?l0ofoo0?m_02;o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z
00Sooo]Z9_l0ofl00ol0003o0?oDo`3oe00Ro`3oe003o`000?l0aOoo0<Go01Wo0<Go00?o0000o`1P
ool0H?l06Ol0H?l2o`0002Wo1@3o0ol0000^o`1Po`;o0000A_l0aOl3o`0002ko063o0ol0000Yo`D0
o`;o00006_l0H?l00ol0003o0<Goo`35o`0Jo`35o`03o`000?l0omCo0?oD02;o0?oD00?o0000o`3o
Kol0ofl08ol0ofl:oookJP7o00000OoonfX001?ooo]Z0ol007l;oookJP03o`000?oonf[ooo]Z00So
oo]Z9_l0ofl00ol0003o0?oDo`3oe00So`3oe003o`000?l0aOoo0<Go01Wo0<Go00?o0000o`1Pool0
H?l06_l0H?l4o`0002;o1@3o0ol0000_o`1Po`;o0000Bol0aOl2o`0002oo063o0ol0000So`D0o`?o
00006ol0H?l00ol0003o0<Goo`35o`0Jo`35o`03o`000?l0omCo0?oD02?o0?oD00?o0000o`3oKol0
ofl08ol0ofl:oookJP7o00000OoonfX001?ooo]Z0ol007l;oookJP03o`000?oonf[ooo]Z00Sooo]Z
9ol0ofl00ol0003o0?oDo`3oe00So`3oe003o`000?l0aOoo0<Go01Wo0<Go00?o0000o`1Pool0H?l0
7Ol0H?l4o`0001[o1@3o1?l0000`o`1Po`;o0000Col0aOl2o`00033o063o1?l0000Jo`D0o`Go0000
7Ol0H?l00ol0003o0<Goo`35o`0Jo`35o`03o`000?l0omCo0?oD02?o0?oD00?o0000o`3oKol0ofl0
9?l0ofl:oookJP7o00000OoonfX001?ooo]Z0ol007l;oookJP03o`000?oonf[ooo]Z00Sooo]Z9ol0
ofl00ol0003o0?oDo`3oe00So`3oe003o`000?l0aOoo0<Go01[o0<Go0_l0000Qo`1Po`Co00004Ol5
0?l5o`00037o063o0ol0001Co`35o`;o0000<_l0H?l5o`00013o1@3o1Ol0000Po`1Po`;o00007Ol0
aOl00ol0003o0?oDo`3oe00So`3oe003o`000?l0ofoo0?m_02Co0?m_2_oonfX1o`00007ooo]Z000C
oookJP?o001o2ooonfX00ol0003ooo]ZoookJP08oookJRSo0?m_00?o0000o`3oe?l0om@08ol0om@0
0ol0003o0<Goo`35o`0Ko`35o`;o00008ol0H?lAo`0003Co063o0_l0001Ho`35o`;o0000=Ol0H?l@
o`0002Co063o00?o0000o`35ool0aOl07?l0aOl00ol0003o0?oDo`3oe00So`3oe003o`000?l0ofoo
0?m_02Go0?m_2_oonfX1o`00007ooo]Z000CoookJP?o001o2ooonfX5o`0000Kooo]Z:?l0ofl00ol0
003o0?oDo`3oe00To`3oe003o`000?l0aOoo0<Go01co0<Go00?o0000o`1Pool0H?l0Hol0H?l2o`00
05co0<Go0_l0001Uo`1Po`;o00007_l0aOl00ol0003o0?oDo`3oe00To`3oe003o`000?l0ofoo0?m_
02Go0?m_1ooonfX4o`00007ooo]Z000CoookJP?o001o2ooonfX00ol0003ooo]ZoookJP08oookJRWo
0?m_00?o0000o`3oe?l0om@09?l0om@2o`0001go0<Go0_l0001Qo`1Po`;o0000H?l0aOl3o`00063o
063o0_l0000No`35o`;o00009_l0om@00ol0003o0?m_o`3oK`0Vo`3oK`[ooo]Z0Ol00001oookJP00
4ooonfX3o`00O`_ooo]Z00?o0000oookJ_oonfX02?oonfXZo`3oK`03o`000?l0omCo0?oD02Go0?oD
00?o0000o`35ool0aOl07?l0aOl2o`0005go063o0_l0001Uo`35o`;o0000GOl0H?l00ol0003o0<Go
o`35o`0Mo`35o`03o`000?l0omCo0?oD02Go0?oD00?o0000o`3oKol0ofl09ol0ofl:oookJP7o0000
0OoonfX001?ooo]Z0ol007l;oookJP03o`000?oonf[ooo]Z00Sooo]Z:_l0ofl00ol0003o0?oDo`3o
e00Vo`3oe003o`000?l0aOoo0<Go01go0<Go0_l0001Ho`1Po`?o0000JOl0aOl2o`0005Wo063o0_l0
000Oo`35o`03o`000?l0omCo0?oD02Go0?oD00?o0000o`3oKol0ofl0:?l0ofl:oookJP7o00000Ooo
nfX001?ooo]Z0ol007l;oookJP03o`000?oonf[ooo]Z00Sooo]Z:ol0ofl00ol0003o0?oDo`3oe00V
o`3oe003o`000?l0aOoo0<Go01ko0<Go00?o0000o`1Pool0H?l0Dol0H?l2o`0006ko0<Go0ol0001D
o`1Po`;o00008?l0aOl00ol0003o0?oDo`3oe00Vo`3oe003o`000?l0ofoo0?m_02So0?m_2_oonfX1
o`00007ooo]Z000@oookJPKo001o2ooonfX00ol0003ooo]ZoookJP08oookJRco0?m_00?o0000o`3o
e?l0om@09_l0om@00ol0003o0<Goo`35o`0No`35o`;o0000DOl0H?l2o`0007?o0<Go0_l0001Ao`1P
o`03o`000?l0aOoo0<Go01oo0<Go00?o0000o`3oe?l0om@09_l0om@00ol0003o0?m_o`3oK`0Yo`3o
K`[ooo]Z0Ol00001oookJP004?oonfX6o`00O`_ooo]Z00?o0000oookJ_oonfX02?oonfX/o`3oK`03
o`000?l0omCo0?oD02Oo0?oD00?o0000o`35ool0aOl07ol0aOl3o`0004_o063o0ol0001go`35o`?o
0000Bol0H?l3o`00027o0<Go00?o0000o`3oe?l0om@09_l0om@00ol0003o0?m_o`3oK`0Zo`3oK`[o
oo]Z0Ol00001oookJP004_oonfX4o`00O`_ooo]Z00?o0000oookJ_oonfX02?oonfX]o`3oK`03o`00
0?l0omCo0?oD02Oo0?oD00?o0000o`35ool0aOl08Ol0aOl3o`0004Go063o0ol0001mo`35o`?o0000
AOl0H?l3o`0002?o0<Go00?o0000o`3oe?l0om@09ol0om@00ol0003o0?m_o`3oK`0Zo`3oK`[ooo]Z
0Ol00001oookJP004ooonfX3o`00O`_ooo]Z00?o0000oookJ_oonfX02?oonfX]o`3oK`03o`000?l0
omCo0?oD02So0?oD00?o0000o`35ool0aOl08ol0aOl3o`0003ko063o1?l00023o`35o`?o0000?ol0
H?l3o`0002Go0<Go00?o0000o`3oe?l0om@09ol0om@00ol0003o0?m_o`3oK`0[o`3oK`[ooo]Z0Ol0
0001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJRko0?m_00?o0000o`3oe?l0om@0:?l0om@0
0ol0003o0<Goo`35o`0Uo`35o`?o0000>?l0H?l3o`0008[o0<Go0ol0000io`1Po`?o00009ol0aOl0
0ol0003o0?oDo`3oe00Wo`3oe003o`000?l0ofoo0?m_02co0?m_2_oonfX1o`00007ooo]Z000Qoook
JP03o`000?oonf[ooo]Z00Sooo]Z;ol0ofl00ol0003o0?oDo`3oe00Xo`3oe003o`000?l0aOoo0<Go
02Oo0<Go00?o0000o`1Pool0H?l0<?l0H?l5o`00093o0<Go1Ol0000bo`1Po`;o0000:Ol0aOl00ol0
003o0?oDo`3oe00Wo`3oe003o`000?l0ofoo0?m_02go0?m_2_oonfX1o`00007ooo]Z000QoookJP03
o`000?oonf[ooo]Z00Sooo]Z;ol0ofl00ol0003o0?oDo`3oe00Yo`3oe003o`000?l0aOoo0<Go02Oo
0<Go1?l0000Zo`1Po`Co0000V_l0aOl5o`0002[o063o1?l0000Yo`35o`03o`000?l0omCo0?oD02So
0?oD00?o0000o`3oKol0ofl0;Ol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX0
2?oonfX`o`3oK`03o`000?l0omCo0?oD02Wo0?oD00?o0000o`35ool0aOl0:_l0aOl7o`0001oo063o
1?l0002So`35o`Co00007ol0H?l7o`0002co0<Go00?o0000o`3oe?l0om@0:?l0om@00ol0003o0?m_
o`3oK`0^o`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJS7o0?m_00?o
0000o`3oe?l0om@0:Ol0om@2o`00037o0<Go2_l0000=o`1Po`So0000Zol0aOl9o`0000co063o2_l0
000ao`35o`;o0000:_l0om@00ol0003o0?m_o`3oK`0_o`3oK`[ooo]Z0Ol00001oookJP008OoonfX0
0ol0003ooo]ZoookJP08oookJS;o0?m_00?o0000o`3oe?l0om@0:_l0om@00ol0003o0<Goo`35o`0h
o`35o`go0000_?l0aOl<o`0003[o0<Go00?o0000o`3oe?l0om@0:_l0om@00ol0003o0?m_o`3oK`0_
o`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJS;o0?m_00?o0000o`3o
e?l0om@0:ol0om@2o`000?oo0<GoA_l0aOl2o`0002co0?oD00?o0000o`3oKol0ofl0<?l0ofl:oook
JP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXco`3oK`03o`000?l0omCo0?oD02co
0?oD00?o0000o`35ool0aOl0ool0aOm2o`35o`03o`000?l0omCo0?oD02co0?oD00?o0000o`3oKol0
ofl0<?l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXdo`3oK`03o`00
0?l0omCo0?oD02co0?oD0_l0003oo`35od3o0<Go0_l0000^o`3oe003o`000?l0ofoo0?m_037o0?m_
2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z=Ol0ofl00ol0003o0?oDo`3o
e00]o`3oe003o`000?l0aOoo0<Go0?oo0<Go>ol0aOl2o`0002oo0?oD00?o0000o`3oKol0ofl0<_l0
ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXeo`3oK`03o`000?l0omCo
0?oD02ko0?oD00?o0000o`35ool0aOl0ool0aOlio`35o`03o`000?l0omCo0?oD02ko0?oD00?o0000
o`3oKol0ofl0<ol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXfo`3o
K`03o`000?l0omCo0?oD02ko0?oD0_l0003oo`35ocOo0<Go0_l0000`o`3oe003o`000?l0ofoo0?m_
03Co0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z=ol0ofl00ol0003o
0?oDo`3oe00_o`3oe003o`000?l0aOoo0<Go0?oo0<Go<ol0aOl00ol0003o0?oDo`3oe00_o`3oe003
o`000?l0ofoo0?m_03Go0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z
>?l0ofl00ol0003o0?oDo`3oe00_o`3oe0;o0000ool0aOlao`35o`;o0000<Ol0om@00ol0003o0?m_
o`3oK`0fo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJSWo0?m_00?o
0000o`3oe?l0om@0<?l0om@2o`000?oo0<Go;_l0aOl00ol0003o0?oDo`3oe00`o`3oe003o`000?l0
ofoo0?m_03Oo0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z>_l0ofl0
0ol0003o0?oDo`3oe00ao`3oe0;o0000ool0aOlZo`35o`;o0000<_l0om@00ol0003o0?m_o`3oK`0h
o`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJS_o0?m_00?o0000o`3o
e?l0om@0<_l0om@3o`000?oo0<Go9?l0aOl3o`0003?o0?oD00?o0000o`3oKol0ofl0>Ol0ofl:oook
JP7o00000OoonfX0027ooo]Z0ol00008oookJSco0?m_00?o0000o`3oe?l0om@0=?l0om@2o`000?oo
0<Go8?l0aOl2o`0003Go0?oD00?o0000o`3oKol0ofl0>_l0ofl8oookJP?o00000OoonfX0027ooo]Z
00?o0000oookJ_oonfX02?oonfXmo`3oK`03o`000?l0omCo0?oD03Go0?oD0ol0003oo`35oa[o0<Go
0ol0000fo`3oe003o`000?l0ofoo0?m_03_o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oo
nf[ooo]Z00Sooo]Z?_l0ofl00ol0003o0?oDo`3oe00go`3oe0;o0000ool0aOlFo`35o`;o0000>?l0
om@00ol0003o0?m_o`3oK`0lo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08
oookJSoo0?m_00?o0000o`3oe?l0om@0>?l0om@3o`0007[o0<Go6ol0001jo`35o`?o0000>Ol0om@0
0ol0003o0?m_o`3oK`0mo`3oK`[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oook
JT3o0?m_00?o0000o`3oe?l0om@0>_l0om@3o`0006go0<Go2_l0000Ko`3oe0[o0000KOl0aOl3o`00
03_o0?oD00?o0000o`3oKol0ofl0?_l0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oo
nfX02?oonfY1o`3oK`03o`000?l0omCo0?oD03co0?oD0_l0001To`35o`Oo0000;ol0om@7o`0006Co
0<Go0_l0000mo`3oe003o`000?l0ofoo0?m_03oo0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`00
0?oonf[ooo]Z00Sooo]Z@_l0ofl2o`0003ko0?oD0ol0001Jo`35o`Oo0000?Ol0om@6o`0005_o0<Go
0ol0000no`3oe003o`000?l0ofoo0?m_043o0?m_2_oonfX1o`00007ooo]Z000QoookJP03o`000?oo
nf[ooo]Z00Sooo]ZA?l0ofl00ol0003o0?oDo`3oe00no`3oe0?o0000D?l0aOl7o`0004[o0?oD1ol0
001Ao`35o`?o0000@?l0om@00ol0003o0?m_o`3oK`11o`3oK`[ooo]Z0Ol00001oookJP008OoonfX0
0ol0003ooo]ZoookJP08oookJTGo0?m_00?o0000o`3oe?l0om@0@?l0om@5o`0004Go0<Go1_l0001H
o`3oe0Oo0000AOl0aOl5o`0004;o0?oD00?o0000o`3oKol0ofl0@_l0ofl:oookJP7o00000OoonfX0
027ooo]Z00?o0000oookJ_oonfX02?oonfY6o`3oK`03o`000?l0omCo0?oD04Co0?oD1?l0000jo`35
o`Oo0000IOl0om@7o`0003Wo0<Go1Ol00016o`3oe003o`000?l0ofoo0?m_04?o0?m_2_oonfX1o`00
007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]ZAol0ofl00ol0003o0?oDo`3oe017o`3oe0Oo
0000:Ol0aOl:o`0007?o0?oD2_l0000Xo`35o`Oo0000B_l0om@00ol0003o0?m_o`3oK`14o`3oK`[o
oo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJTSo0?m_0_l0001>o`3oe13o0000
3?l0aOl=o`0008Oo0?oD3Ol0000=o`35o`ko0000Col0om@2o`0004Oo0?m_2_oonfX1o`00007ooo]Z
000QoookJP03o`000?oonf[ooo]Z00Sooo]ZB_l0ofl00ol0003o0?oDo`3oe01Ko`3oe0co0000XOl0
om@=o`0005co0?oD00?o0000o`3oKol0ofl0Aol0ofl:oookJP7o00000OoonfX0027ooo]Z00?o0000
oookJ_oonfX02?oonfX00ol0003o0?m_o`3oK`18o`3oK`03o`000?l0omCo0?oD0?oo0?oDL?l0om@0
0ol0003o0?m_o`3oK`18o`3oK`03o`000?oonf[ooo]Z00Oooo]Z0Ol00001oookJP008OoonfX00ol0
003ooo]ZoookJP08oookJP03o`000?l0ofoo0?m_04Wo0?m_0_l0003oo`3oe6ko0?oD0_l0001;o`3o
K`03o`000?oonf[ooo]Z00Oooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJP03
o`3o2_l0003o0?m_04_o0?m_00?o0000o`3oe?l0om@0ool0omAZo`3oe003o`000?l0ofoo0?m_04[o
0?m_00?o0000oookJ_oonfX02?oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z
0_l0o`X00ol0003o0?m_o`3oK`1:o`3oK`03o`000?l0omCo0?oD0?oo0?oDJ?l0om@00ol0003o0?m_
o`3oK`1:o`3oK`03o`000?l0o`[ooo]Z00Wooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Zoook
JP08oookJP;o0?l:00?o0000o`3oKol0ofl0Bol0ofl2o`000?oo0?oDI_l0om@2o`0004go0?m_00?o
0000o`3o2_oonfX02OoonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0o`X0
0ol0003o0?m_o`3oK`1<o`3oK`03o`000?l0omCo0?oD0?oo0?oDH_l0om@00ol0003o0?m_o`3oK`1<
o`3oK`03o`000?l0o`[o0?l:00[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oook
JPCo0?l:00?o0000o`3oKol0ofl0C?l0ofl00ol0003o0?oDo`3oe03oo`3oe63o0?oD00?o0000o`3o
Kol0ofl0C?l0ofl01?l0003o0?l:o`3o2_l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oook
J_oonfX02?oonfX4o`3o2P03o`000?l0ofoo0?m_04go0?m_00?o0000o`3oe?l0om@0ool0omAMo`3o
e0;o0000Col0ofl01?l0003o0?l:o`3o2_l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oook
J_oonfX02?oonfX5o`3o2P03o`000?l0ofoo0?m_04go0?m_0_l0003oo`3oe5co0?oD00?o0000o`3o
Kol0ofl0C_l0ofl00ol0003o0?l:o`3o2P02o`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003o
oo]ZoookJP08oookJPKo0?l:00?o0000o`3oKol0ofl0C_l0ofl00ol0003o0?oDo`3oe03oo`3oe5Oo
0?oD0_l0001@o`3oK`03o`000?l0o`[o0?l:00?o0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`00
0?oonf[ooo]Z00Sooo]Z1_l0o`X00ol0003o0?m_o`3oK`1?o`3oK`03o`000?l0omCo0?oD0?oo0?oD
EOl0om@00ol0003o0?m_o`3oK`1@o`3oK`03o`000?l0o`[o0?l:00?o0?l:2_oonfX1o`00007ooo]Z
000QoookJP03o`000?oonf[ooo]Z00Sooo]Z1ol0o`X00ol0003o0?m_o`3oK`1?o`3oK`03o`000?l0
omCo0?oD0?oo0?oDDol0om@00ol0003o0?m_o`3oK`1@o`3oK`03o`000?l0o`[o0?l:00Co0?l:2_oo
nfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z2?l0o`X00ol0003o0?m_o`3oK`1?
o`3oK`?o0000ool0omA@o`3oe0;o0000D_l0ofl00ol0003o0?l:o`3o2P05o`3o2P[ooo]Z0Ol00001
oookJP008OoonfX00ol0003ooo]ZoookJP08oookJPSo0?l:00?o0000o`3oKol0ofl0D_l0ofl2o`00
0?oo0?oDC?l0om@2o`0005Co0?m_00?o0000o`3o2_l0o`X01Ol0o`X:oookJP7o00000OoonfX0027o
oo]Z0ol00008oookJPWo0?l:00?o0000o`3oKol0ofl0Dol0ofl2o`000?oo0?oDB?l0om@2o`0005Go
0?m_00?o0000o`3o2_l0o`X01_l0o`X8oookJP?o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX0
2?oonfX:o`3o2P03o`000?l0ofoo0?m_05Co0?m_0_l0003oo`3oe4Co0?oD0_l0001Fo`3oK`03o`00
0?l0o`[o0?l:00Oo0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z2ol0
o`X00ol0003o0?m_o`3oK`1Eo`3oK`;o0000ool0omA0o`3oe0;o0000Eol0ofl00ol0003o0?l:o`3o
2P08o`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJPco0?l:00?o0000
o`3oKol0ofl0E_l0ofl00ol0003o0?oDo`3oe03oo`3oe3_o0?oD0_l0001Ho`3oK`03o`000?l0o`[o
0?l:00Wo0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z3Ol0o`X00ol0
003o0?m_o`3oK`1Fo`3oK`;o0000ool0om@io`3oe0;o0000FOl0ofl00ol0003o0?l:o`3o2P0:o`3o
2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJPgo0?l:00?o0000o`3oKol0
ofl0F?l0ofl2o`000?oo0?oD=Ol0om@2o`0005[o0?m_00?o0000o`3o2_l0o`X02ol0o`X:oookJP7o
00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfX>o`3o2P03o`000?l0ofoo0?m_05Wo0?m_
0_l0003oo`3oe37o0?oD0_l0001Ko`3oK`03o`000?l0o`[o0?l:00co0?l:2_oonfX1o`00007ooo]Z
000QoookJP03o`000?oonf[ooo]Z00Sooo]Z3ol0o`X00ol0003o0?m_o`3oK`1Jo`3oK`;o0000ool0
om@]o`3oe0;o0000G?l0ofl00ol0003o0?l:o`3o2P0=o`3o2P[ooo]Z0Ol00001oookJP008OoonfX0
0ol0003ooo]ZoookJP08oookJQ3o0?l:00?o0000o`3oKol0ofl0Fol0ofl3o`000?oo0?oD:?l0om@2
o`0005go0?m_00?o0000o`3o2_l0o`X03_l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oook
J_oonfX02?oonfXAo`3o2P03o`000?l0ofoo0?m_05go0?m_0_l0003oo`3oe2Co0?oD0_l0001No`3o
K`03o`000?l0o`[o0?l:00oo0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00So
oo]Z4_l0o`X00ol0003o0?m_o`3oK`1No`3oK`;o0000ool0om@Po`3oe0;o0000Gol0ofl00ol0003o
0?l:o`3o2P0@o`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQ?o0?l:
00?o0000o`3oKol0ofl0Gol0ofl3o`000?oo0?oD6ol0om@2o`00063o0?m_00?o0000o`3o2_l0o`X0
4Ol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXDo`3o2P03o`000?l0
ofoo0?m_067o0?m_0ol0003oo`3oe1Co0?oD1?l0001Qo`3oK`03o`000?l0o`[o0?l:01;o0?l:2_oo
nfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z5Ol0o`X00ol0003o0?m_o`3oK`1S
o`3oK`?o0000ool0om@>o`3oe0?o0000I?l0ofl00ol0003o0?l:o`3o2P0Co`3o2P[ooo]Z0Ol00001
oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQKo0?l:00?o0000o`3oKol0ofl0IOl0ofl3o`00
0?oo0?oD2?l0om@3o`0006Ko0?m_00?o0000o`3o2_l0o`X05?l0o`X:oookJP7o00000OoonfX0027o
oo]Z00?o0000oookJ_oonfX02?oonfXGo`3o2P03o`000?l0ofoo0?m_06Oo0?m_0ol0003oo`3oe0;o
0?oD0ol0001Xo`3oK`03o`000?l0o`[o0?l:01Go0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`00
0?oonf[ooo]Z00Sooo]Z6?l0o`X00ol0003o0?m_o`3oK`1Yo`3oK`Co0000nOl0om@4o`0006[o0?m_
00?o0000o`3o2_l0o`X05_l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oo
nfXIo`3o2P03o`000?l0ofoo0?m_06co0?m_0ol0003co`3oe0?o0000KOl0ofl00ol0003o0?l:o`3o
2P0Go`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJQ[o0?l:00?o0000
o`3oKol0ofl0K_l0ofl3o`000>co0?oD1?l0001_o`3oK`03o`000?l0o`[o0?l:01So0?l:2_oonfX1
o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z6ol0o`X00ol0003o0?m_o`3oK`1`o`3o
K`?o0000i_l0om@3o`0007;o0?m_00?o0000o`3o2_l0o`X06Ol0o`X:oookJP7o00000OoonfX0027o
oo]Z00?o0000oookJ_oonfX02?oonfXLo`3o2P03o`000?l0ofoo0?m_07;o0?m_1_l0003Ko`3oe0Go
0000M?l0ofl00ol0003o0?l:o`3o2P0Jo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJQgo0?l:00?o0000o`3oKol0ofl0Mol0ofl7o`000<go0?oD1ol0001ho`3oK`03o`00
0?l0o`[o0?l:01_o0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z7_l0
o`X00ol0003o0?m_o`3oK`1mo`3oK`Ko0000`Ol0om@6o`0007ko0?m_00?o0000o`3o2_l0o`X07?l0
o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXOo`3o2P03o`000?l0ofoo
0?m_08;o0?m_1ol0002co`3oe0Oo0000Pol0ofl00ol0003o0?l:o`3o2P0Mo`3o2P[ooo]Z0Ol00001
oookJP008OoonfX00ol0003ooo]ZoookJP08oookJR3o0?l:0_l00029o`3oK`[o0000Wol0om@:o`00
08Wo0?m_00?o0000o`3o2_l0o`X07_l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oo
nfX02?oonfXRo`3o2P03o`000?l0ofoo0?m_093o0?m_3Ol00025o`3oe0go0000T_l0ofl00ol0003o
0?l:o`3o2P0Oo`3o2P[ooo]Z0Ol00001oookJP008OoonfX3o`0000Sooo]Z8ol0o`X00ol0003o0?m_
o`3oK`2Lo`3oKhGo0000W_l0ofl00ol0003o0?l:o`3o2P0Po`3o2PSooo]Z0ol00001oookJP008Ooo
nfX00ol0003ooo]ZoookJP08oookJRCo0?l:00?o0000o`3oKol0ofl0ool0ofnno`3oK`03o`000?l0
o`[o0?l:027o0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z9Ol0o`X0
0ol0003o0?m_o`3oK`3oo`3oKkco0?m_00?o0000o`3o2_l0o`X08_l0o`X:oookJP7o00000OoonfX0
027ooo]Z00?o0000oookJ_oonfX02?oonfXVo`3o2P03o`000?l0ofoo0?m_0?oo0?m_^_l0ofl00ol0
003o0?l:o`3o2P0So`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJROo
0?l:00?o0000o`3oKol0ofl0ool0ofnho`3oK`03o`000?l0o`[o0?l:02Co0?l:2_oonfX1o`00007o
oo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z:?l0o`X2o`000?oo0?m_]_l0ofl2o`0002Oo0?l:
2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z:_l0o`X00ol0003o0?m_o`3o
K`3oo`3oKk;o0?m_00?o0000o`3o2_l0o`X09ol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000
oookJ_oonfX02?oonfX[o`3o2P03o`000?l0ofoo0?m_0?oo0?m_/?l0ofl00ol0003o0?l:o`3o2P0X
o`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJRco0?l:00?o0000o`3o
Kol0ofl0ool0ofn^o`3oK`03o`000?l0o`[o0?l:02Wo0?l:2_oonfX1o`00007ooo]Z000QoookJP03
o`000?oonf[ooo]Z00Sooo]Z;Ol0o`X00ol0003o0?m_o`3oK`3oo`3oKjco0?m_00?o0000o`3o2_l0
o`X0:_l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfX^o`3o2P03o`00
0?l0ofoo0?m_0?oo0?m_Z_l0ofl00ol0003o0?l:o`3o2P0[o`3o2P[ooo]Z0Ol00001oookJP008Ooo
nfX00ol0003ooo]ZoookJP08oookJRoo0?l:00?o0000o`3oKol0ofl0ool0ofnXo`3oK`03o`000?l0
o`[o0?l:02co0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z<?l0o`X2
o`000?oo0?m_Y_l0ofl2o`0002oo0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z
00Sooo]Z<_l0o`X2o`000?oo0?m_X_l0ofl2o`00037o0?l:2_oonfX1o`00007ooo]Z000QoookJP03
o`000?oonf[ooo]Z00Sooo]Z=?l0o`X00ol0003o0?m_o`3oK`3oo`3oKiko0?m_00?o0000o`3o2_l0
o`X0<Ol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfXeo`3o2P;o0000
ool0ofnLo`3oK`;o0000=?l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oo
nfXgo`3o2P03o`000?l0ofoo0?m_0?oo0?m_V?l0ofl00ol0003o0?l:o`3o2P0do`3o2P[ooo]Z0Ol0
0001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJSSo0?l:0_l0003oo`3oKiKo0?m_0_l0000g
o`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJS[o0?l:00?o0000o`3o
Kol0ofl0ool0ofnBo`3oK`03o`000?l0o`[o0?l:03Oo0?l:2_oonfX1o`00007ooo]Z000QoookJP03
o`000?oonf[ooo]Z00Sooo]Z>ol0o`X2o`000?oo0?m_T?l0ofl2o`0003[o0?l:2_oonfX1o`00007o
oo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z?Ol0o`X00ol0003o0?m_o`3oK`3oo`3oKh_o0?m_
0_l0000lo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJSko0?l:00?o
0000o`3oKol0ofl0ool0ofn9o`3oK`03o`000?l0o`[o0?l:03co0?l:2_oonfX1o`00007ooo]Z000Q
oookJP03o`000?oonf[ooo]Z00Sooo]Z?ol0o`X2o`000?oo0?m_Qol0ofl2o`0003oo0?l:2_oonfX1
o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]Z@Ol0o`X00ol0003o0?m_o`3oK`3oo`3o
Kh?o0?m_00?o0000o`3o2_l0o`X0?ol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oo
nfX02?oonfY2o`3o2P03o`000?l0ofoo0?m_0?oo0?m_POl0ofl00ol0003o0?l:o`3o2P10o`3o2P[o
oo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJT?o0?l:0_l0003oo`3oKh3o0?m_
0_l00012o`3o2P[ooo]Z0Ol00001oookJP008OoonfX3o`0000Sooo]ZAOl0o`X2o`000?oo0?m_O?l0
ofl2o`0004Co0?l:2?oonfX3o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z00Sooo]ZAol0o`X2
o`000?oo0?m_N?l0ofl2o`0004Ko0?l:2_oonfX1o`00007ooo]Z000QoookJP03o`000?oonf[ooo]Z
00Sooo]ZBOl0o`X2o`000?oo0?m_M?l0ofl2o`0004So0?l:2_oonfX1o`00007ooo]Z000QoookJP03
o`000?oonf[ooo]Z00Sooo]ZBol0o`X00ol0003o0?m_o`3oK`3oo`3oKg3o0?m_00?o0000o`3o2_l0
o`X0B?l0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfY<o`3o2P;o0000
ool0ofm^o`3oK`;o0000Bol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oo
nfY>o`3o2P;o0000ool0ofmZo`3oK`;o0000COl0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000
oookJ_oonfX02?oonfY@o`3o2P;o0000ool0ofmVo`3oK`;o0000Col0o`X:oookJP7o00000OoonfX0
027ooo]Z00?o0000oookJ_oonfX02?oonfYBo`3o2P;o0000ool0ofmRo`3oK`;o0000DOl0o`X:oook
JP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfYDo`3o2P;o0000ool0ofmNo`3oK`;o
0000Dol0o`X:oookJP7o00000OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfYFo`3o2P03o`00
0?l0ofoo0?m_0?oo0?m_F_l0ofl00ol0003o0?l:o`3o2P1Co`3o2P[ooo]Z0Ol00001oookJP008Ooo
nfX00ol0003ooo]ZoookJP08oookJUOo0?l:0_l0003oo`3oKeSo0?m_0_l0001Fo`3o2P[ooo]Z0Ol0
0001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJUWo0?l:0_l0003oo`3oKeCo0?m_0_l0001H
o`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJU_o0?l:0_l0003oo`3o
Ke3o0?m_0_l0001Jo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJUgo
0?l:0_l0003oo`3oKdco0?m_0_l0001Lo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJUoo0?l:0_l0003oo`3oKdOo0?m_0ol0001No`3o2P[ooo]Z0Ol00001oookJP008Ooo
nfX00ol0003ooo]ZoookJP08oookJV7o0?l:0_l0003oo`3oKd?o0?m_0_l0001Qo`3o2P[ooo]Z0Ol0
0001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJV?o0?l:0ol0003oo`3oKcko0?m_0_l0001S
o`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJVKo0?l:0_l0003oo`3o
KcWo0?m_0ol0001Uo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJVSo
0?l:0_l0003oo`3oKcGo0?m_0_l0001Xo`3o2P[ooo]Z0Ol00001oookJP008OoonfX00ol0003ooo]Z
oookJP08oookJV[o0?l:0_l0003oo`3oKc7o0?m_0_l0001Zo`3o2P[ooo]Z0Ol00001oookJP008Ooo
nfX00ol0003ooo]ZoookJP08oookJVco0?l:0ol0003oo`3oKb_o0?m_0ol0001/o`3o2P[ooo]Z0Ol0
0001oookJP008OoonfX00ol0003ooo]ZoookJP08oookJVoo0?l:0ol0003oo`3oKbGo0?m_0ol0001_
o`3o2P[ooo]Z0Ol00001oookJP003ooonfX9o`00O`Wooo]Z00?o0000oookJ_oonfX02?oonfYbo`3o
2P?o0000ool0oflPo`3oK`;o0000L_l0o`X:oookJP7o00000OoonfX000oooo]Z2Ol007l9oookJP03
o`000?oonf[ooo]Z00Sooo]ZMOl0o`X3o`000?oo0?m_6_l0ofl3o`0007Co0?l:2_oonfX1o`00007o
oo]Z000?oookJPCo001o3_oonfX00ol0003ooo]ZoookJP08oookJWSo0?l:0_l0003oo`3oKaKo0?m_
0_l0001go`3o2P[ooo]Z0Ol00001oookJP004?oonfX4o`00O`gooo]Z00?o0000oookJ_oonfX02?oo
nfYjo`3o2P03o`000?l0ofoo0?m_0?oo0?m_4_l0ofl00ol0003o0?l:o`3o2P1go`3o2P[ooo]Z0Ol0
0001oookJP004OoonfX5o`00O`_ooo]Z1Ol00006oookJW_o0?l:00?o0000o`3oKol0ofl0ool0ofl@
o`3oK`03o`000?l0o`[o0?l:07So0?l:1ooonfX4o`00007ooo]Z000CoookJPCo001o2_oonfX00ol0
003ooo]ZoookJP3ooookJ_oooo]Z7?oonfX1o`00007ooo]Z000DoookJP?o001o2_oonfX00ol0003o
oo]ZoookJP3ooookJ_oooo]Z7?oonfX1o`00007ooo]Z000EoookJP?o001o2OoonfX00ol0003ooo]Z
oookJP3ooookJ_oooo]Z7?oonfX1o`00007ooo]Z000?oookJP?o001o0ooonfX3o`00O`Wooo]Z00?o
0000oookJ_oonfX0oooonf[ooookJQcooo]Z0Ol00001oookJP003ooonfX3o`00O`?ooo]Z0ol007l9
oookJP03o`000?oonf[ooo]Z0?oooo]ZoooonfXLoookJP7o00000OoonfX000oooo]Z1?l007l2oook
JP?o001o2OoonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Z7?oonfX1o`00007ooo]Z000@oookJPOo
001o2_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oo
nfX0OooonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oo
nfX01ooonfX1o`00007ooo]Z000AoookJPGo001o2ooonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP07oookJP7o0000
0OoonfX0027ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX01ooonfX1o`00007ooo]Z000QoookJ_oo0000ool0000P
o`00007ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
0000\
\>"],
  ImageRangeCache->{{{0, 575}, {575, 0}} -> {-2.33909, -2.3129, 0.00768707, \
0.00768707}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  ContourGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Gradient field of three-hole potential", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gradthreehole\  = \ gradfield[ThreeHolePotential]\)], "Input"],

Cell[BoxData[
    \({\(\(-\(\@3\/2\)\) + x\)\/\((1 - \@3\ x + x\^2 - y + y\^2)\)\^\(3/2\) + \
\(\@3\/2 + x\)\/\((1 + \@3\ x + x\^2 - y + y\^2)\)\^\(3/2\) + 
        x\/\((x\^2 + \((1 + y)\)\^2)\)\^\(3/2\), \(\(-\(1\/2\)\) + y\)\/\((1 \
- \@3\ x + x\^2 - y + y\^2)\)\^\(3/2\) + \(\(-\(1\/2\)\) + y\)\/\((1 + \@3\ x \
+ x\^2 - y + y\^2)\)\^\(3/2\) + \(1 + y\)\/\((x\^2 + \((1 + y)\)\^2)\)\^\(3/2\
\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(<< Graphics`PlotField`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlotVectorField[gradthreehole, {x, \(-2\), 2}, {y, \(-2\), 2}, 
      ScaleFactor \[Rule] 0.2, ColorFunction \[Rule] \((Hue[1 - #*0.66] &)\), 
      PlotPoints \[Rule] 21]\)], "Input",
  CellTags->"mmtag:13:PlotVectorField[]__example_gradient_of_1/r_potentials"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/0\\^\\(3/2\\)\\) encountered. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\\\ ComplexInfinity\\) encountered. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/0\\^\\(3/2\\)\\) encountered. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\\\ ComplexInfinity\\) encountered. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], \
"Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99993 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.237744 0.500164 0.237744 [
[ 0 0 0 0 ]
[ 1 .99993 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
1 0 .022 r
.0001 w
[ ] 0 setdash
.02451 .02468 m
.02432 .0245 L
s
% Start of user PostScript
-2. -2. -2.000821 -2.0007347 MAarrowhead1
% End of user PostScript
1 0 .024 r
.02451 .07222 m
.02429 .07204 L
s
% Start of user PostScript
-2. -1.8 -2.0009339 -1.8007549 MAarrowhead1
% End of user PostScript
1 0 .026 r
.02451 .11977 m
.02426 .11959 L
s
% Start of user PostScript
-2. -1.6 -2.0010543 -1.6007676 MAarrowhead1
% End of user PostScript
1 0 .028 r
.02451 .16732 m
.02423 .16714 L
s
% Start of user PostScript
-2. -1.4 -2.0011804 -1.4007735 MAarrowhead1
% End of user PostScript
1 0 .03 r
.02451 .21487 m
.0242 .21469 L
s
% Start of user PostScript
-2. -1.2 -2.0013118 -1.200775 MAarrowhead1
% End of user PostScript
1 0 .033 r
.02451 .26242 m
.02417 .26224 L
s
% Start of user PostScript
-2. -1. -2.0014514 -1.0007754 MAarrowhead1
% End of user PostScript
1 0 .035 r
.02451 .30997 m
.02413 .30978 L
s
% Start of user PostScript
-2. -0.8 -2.0016063 -0.80077652 MAarrowhead1
% End of user PostScript
1 0 .039 r
.02451 .35752 m
.02409 .35733 L
s
% Start of user PostScript
-2. -0.6 -2.0017879 -0.60077519 MAarrowhead1
% End of user PostScript
1 0 .043 r
.02451 .40507 m
.02403 .40489 L
s
% Start of user PostScript
-2. -0.4 -2.0020084 -0.40075813 MAarrowhead1
% End of user PostScript
1 0 .047 r
.02451 .45262 m
.02397 .45245 L
s
% Start of user PostScript
-2. -0.2 -2.0022719 -0.20069807 MAarrowhead1
% End of user PostScript
1 0 .052 r
.02451 .50016 m
.0239 .50003 L
s
% Start of user PostScript
-2. 0. -2.0025597 -0.00055599275 MAarrowhead1
% End of user PostScript
1 0 .056 r
.02451 .54771 m
.02384 .54764 L
s
% Start of user PostScript
-2. 0.2 -2.0028153 0.19970168 MAarrowhead1
% End of user PostScript
1 0 .058 r
.02451 .59526 m
.02381 .59528 L
s
% Start of user PostScript
-2. 0.4 -2.0029522 0.4000695 MAarrowhead1
% End of user PostScript
.02451 .64281 m
.02382 .64292 L
s
% Start of user PostScript
-2. 0.6 -2.0028993 0.60048048 MAarrowhead1
% End of user PostScript
1 0 .055 r
.02451 .69036 m
.02388 .69056 L
s
% Start of user PostScript
-2. 0.8 -2.0026574 0.80083544 MAarrowhead1
% End of user PostScript
1 0 .05 r
.02451 .73791 m
.02396 .73816 L
s
% Start of user PostScript
-2. 1. -2.0022997 1.0010669 MAarrowhead1
% End of user PostScript
1 0 .044 r
.02451 .78546 m
.02406 .78573 L
s
% Start of user PostScript
-2. 1.2 -2.0019157 1.2011685 MAarrowhead1
% End of user PostScript
1 0 .039 r
.02451 .83301 m
.02414 .83328 L
s
% Start of user PostScript
-2. 1.4 -2.0015657 1.4011736 MAarrowhead1
% End of user PostScript
1 0 .034 r
.02451 .88055 m
.02421 .88082 L
s
% Start of user PostScript
-2. 1.6 -2.0012735 1.6011222 MAarrowhead1
% End of user PostScript
1 0 .029 r
.02451 .9281 m
.02426 .92835 L
s
% Start of user PostScript
-2. 1.8 -2.0010397 1.8010447 MAarrowhead1
% End of user PostScript
1 0 .025 r
.02451 .97565 m
.02431 .97588 L
s
% Start of user PostScript
-2. 2. -2.0008558 2.0009593 MAarrowhead1
% End of user PostScript
1 0 .024 r
.07206 .02468 m
.07185 .02447 L
s
% Start of user PostScript
-1.8 -2. -1.8008903 -2.000854 MAarrowhead1
% End of user PostScript
1 0 .027 r
.07206 .07222 m
.07182 .07201 L
s
% Start of user PostScript
-1.8 -1.8 -1.8010274 -1.800884 MAarrowhead1
% End of user PostScript
1 0 .029 r
.07206 .11977 m
.07178 .11956 L
s
% Start of user PostScript
-1.8 -1.6 -1.801174 -1.6009036 MAarrowhead1
% End of user PostScript
1 0 .032 r
.07206 .16732 m
.07175 .1671 L
s
% Start of user PostScript
-1.8 -1.4 -1.8013258 -1.400914 MAarrowhead1
% End of user PostScript
1 0 .035 r
.07206 .21487 m
.07171 .21465 L
s
% Start of user PostScript
-1.8 -1.2 -1.8014804 -1.2009204 MAarrowhead1
% End of user PostScript
1 0 .037 r
.07206 .26242 m
.07167 .2622 L
s
% Start of user PostScript
-1.8 -1. -1.8016405 -1.0009316 MAarrowhead1
% End of user PostScript
1 0 .041 r
.07206 .30997 m
.07163 .30974 L
s
% Start of user PostScript
-1.8 -0.8 -1.8018181 -0.80095692 MAarrowhead1
% End of user PostScript
1 0 .045 r
.07206 .35752 m
.07158 .35728 L
s
% Start of user PostScript
-1.8 -0.6 -1.802037 -0.60100009 MAarrowhead1
% End of user PostScript
1 0 .051 r
.07206 .40507 m
.07151 .40482 L
s
% Start of user PostScript
-1.8 -0.4 -1.8023304 -0.4010486 MAarrowhead1
% End of user PostScript
1 0 .058 r
.07206 .45262 m
.07141 .45236 L
s
% Start of user PostScript
-1.8 -0.2 -1.8027297 -0.20106 MAarrowhead1
% End of user PostScript
1 0 .067 r
.07206 .50016 m
.07129 .49994 L
s
% Start of user PostScript
-1.8 0. -1.8032327 -0.00095101395 MAarrowhead1
% End of user PostScript
1 0 .075 r
.07206 .54771 m
.07117 .54757 L
s
% Start of user PostScript
-1.8 0.2 -1.8037496 0.19938292 MAarrowhead1
% End of user PostScript
1 0 .081 r
.07206 .59526 m
.07109 .59526 L
s
% Start of user PostScript
-1.8 0.4 -1.8040768 0.39997741 MAarrowhead1
% End of user PostScript
.07206 .64281 m
.07111 .64297 L
s
% Start of user PostScript
-1.8 0.6 -1.8040109 0.60069081 MAarrowhead1
% End of user PostScript
1 0 .075 r
.07206 .69036 m
.07122 .69066 L
s
% Start of user PostScript
-1.8 0.8 -1.8035523 0.80127105 MAarrowhead1
% End of user PostScript
1 0 .065 r
.07206 .73791 m
.07137 .73828 L
s
% Start of user PostScript
-1.8 1. -1.8029058 1.001575 MAarrowhead1
% End of user PostScript
1 0 .056 r
.07206 .78546 m
.07152 .78585 L
s
% Start of user PostScript
-1.8 1.2 -1.8022782 1.2016359 MAarrowhead1
% End of user PostScript
1 0 .047 r
.07206 .83301 m
.07164 .83338 L
s
% Start of user PostScript
-1.8 1.4 -1.8017649 1.4015563 MAarrowhead1
% End of user PostScript
1 0 .039 r
.07206 .88055 m
.07173 .88089 L
s
% Start of user PostScript
-1.8 1.6 -1.8013757 1.6014196 MAarrowhead1
% End of user PostScript
1 0 .033 r
.07206 .9281 m
.0718 .92841 L
s
% Start of user PostScript
-1.8 1.8 -1.8010879 1.8012717 MAarrowhead1
% End of user PostScript
1 0 .028 r
.07206 .97565 m
.07185 .97592 L
s
% Start of user PostScript
-1.8 2. -1.8008746 2.0011328 MAarrowhead1
% End of user PostScript
.11961 .02468 m
.11938 .02444 L
s
% Start of user PostScript
-1.6 -2. -1.6009671 -2.0009996 MAarrowhead1
% End of user PostScript
1 0 .031 r
.11961 .07222 m
.11934 .07198 L
s
% Start of user PostScript
-1.6 -1.8 -1.6011375 -1.8010433 MAarrowhead1
% End of user PostScript
1 0 .034 r
.11961 .11977 m
.1193 .11952 L
s
% Start of user PostScript
-1.6 -1.6 -1.6013212 -1.601071 MAarrowhead1
% End of user PostScript
1 0 .037 r
.11961 .16732 m
.11925 .16706 L
s
% Start of user PostScript
-1.6 -1.4 -1.6015089 -1.401083 MAarrowhead1
% End of user PostScript
1 0 .04 r
.11961 .21487 m
.11921 .21461 L
s
% Start of user PostScript
-1.6 -1.2 -1.6016921 -1.201088 MAarrowhead1
% End of user PostScript
1 0 .043 r
.11961 .26242 m
.11916 .26216 L
s
% Start of user PostScript
-1.6 -1. -1.6018695 -1.0011045 MAarrowhead1
% End of user PostScript
1 0 .047 r
.11961 .30997 m
.11912 .30969 L
s
% Start of user PostScript
-1.6 -0.8 -1.6020571 -0.80115776 MAarrowhead1
% End of user PostScript
1 0 .052 r
.11961 .35752 m
.11906 .35722 L
s
% Start of user PostScript
-1.6 -0.6 -1.6022962 -0.60127084 MAarrowhead1
% End of user PostScript
1 0 .06 r
.11961 .40507 m
.11898 .40472 L
s
% Start of user PostScript
-1.6 -0.4 -1.6026589 -0.40144813 MAarrowhead1
% End of user PostScript
1 0 .072 r
.11961 .45262 m
.11884 .45222 L
s
% Start of user PostScript
-1.6 -0.2 -1.6032443 -0.20164519 MAarrowhead1
% End of user PostScript
1 0 .089 r
.11961 .50016 m
.11863 .49976 L
s
% Start of user PostScript
-1.6 0. -1.6041392 -0.0017130846 MAarrowhead1
% End of user PostScript
1 0 .108 r
.11961 .54771 m
.11836 .54739 L
s
% Start of user PostScript
-1.6 0.2 -1.6052662 0.19864595 MAarrowhead1
% End of user PostScript
1 0 .122 r
.11961 .59526 m
.11815 .59519 L
s
% Start of user PostScript
-1.6 0.4 -1.6061369 0.39969265 MAarrowhead1
% End of user PostScript
.11961 .64281 m
.11817 .64308 L
s
% Start of user PostScript
-1.6 0.6 -1.6060554 0.60112261 MAarrowhead1
% End of user PostScript
1 0 .108 r
.11961 .69036 m
.11842 .69087 L
s
% Start of user PostScript
-1.6 0.8 -1.6050207 0.80215515 MAarrowhead1
% End of user PostScript
1 0 .089 r
.11961 .73791 m
.11872 .7385 L
s
% Start of user PostScript
-1.6 1. -1.6037284 1.0024827 MAarrowhead1
% End of user PostScript
1 0 .071 r
.11961 .78546 m
.11897 .78602 L
s
% Start of user PostScript
-1.6 1.2 -1.6026697 1.2023606 MAarrowhead1
% End of user PostScript
1 0 .056 r
.11961 .83301 m
.11915 .8335 L
s
% Start of user PostScript
-1.6 1.4 -1.6019293 1.4020809 MAarrowhead1
% End of user PostScript
1 0 .045 r
.11961 .88055 m
.11927 .88098 L
s
% Start of user PostScript
-1.6 1.6 -1.6014332 1.6017895 MAarrowhead1
% End of user PostScript
1 0 .037 r
.11961 .9281 m
.11935 .92847 L
s
% Start of user PostScript
-1.6 1.8 -1.6010978 1.8015346 MAarrowhead1
% End of user PostScript
1 0 .031 r
.11961 .97565 m
.1194 .97597 L
s
% Start of user PostScript
-1.6 2. -1.6008643 2.0013238 MAarrowhead1
% End of user PostScript
.16716 .02468 m
.16691 .02439 L
s
% Start of user PostScript
-1.4 -2. -1.401051 -2.0011809 MAarrowhead1
% End of user PostScript
1 0 .035 r
.16716 .07222 m
.16686 .07193 L
s
% Start of user PostScript
-1.4 -1.8 -1.4012692 -1.8012464 MAarrowhead1
% End of user PostScript
1 0 .039 r
.16716 .11977 m
.1668 .11947 L
s
% Start of user PostScript
-1.4 -1.6 -1.4015097 -1.6012853 MAarrowhead1
% End of user PostScript
1 0 .043 r
.16716 .16732 m
.16674 .16701 L
s
% Start of user PostScript
-1.4 -1.4 -1.4017542 -1.4012933 MAarrowhead1
% End of user PostScript
1 0 .047 r
.16716 .21487 m
.16669 .21457 L
s
% Start of user PostScript
-1.4 -1.2 -1.4019794 -1.2012811 MAarrowhead1
% End of user PostScript
1 0 .05 r
.16716 .26242 m
.16664 .26211 L
s
% Start of user PostScript
-1.4 -1. -1.4021701 -1.0012823 MAarrowhead1
% End of user PostScript
1 0 .054 r
.16716 .30997 m
.1666 .30965 L
s
% Start of user PostScript
-1.4 -0.8 -1.4023396 -0.8013517 MAarrowhead1
% End of user PostScript
1 0 .059 r
.16716 .35752 m
.16655 .35715 L
s
% Start of user PostScript
-1.4 -0.6 -1.4025493 -0.60155396 MAarrowhead1
% End of user PostScript
1 0 .07 r
.16716 .40507 m
.16646 .4046 L
s
% Start of user PostScript
-1.4 -0.4 -1.4029257 -0.4019466 MAarrowhead1
% End of user PostScript
1 0 .089 r
.16716 .45262 m
.16628 .45201 L
s
% Start of user PostScript
-1.4 -0.2 -1.4036951 -0.20254923 MAarrowhead1
% End of user PostScript
1 0 .122 r
.16716 .50016 m
.16591 .4994 L
s
% Start of user PostScript
-1.4 0. -1.4052293 -0.0032200954 MAarrowhead1
% End of user PostScript
1 0 .169 r
.16716 .54771 m
.16529 .54693 L
s
% Start of user PostScript
-1.4 0.2 -1.407863 0.19672672 MAarrowhead1
% End of user PostScript
1 0 .212 r
.16716 .59526 m
.16463 .59495 L
s
% Start of user PostScript
-1.4 0.4 -1.4106435 0.39870183 MAarrowhead1
% End of user PostScript
1 0 .214 r
.16716 .64281 m
.16465 .64336 L
s
% Start of user PostScript
-1.4 0.6 -1.4105438 0.60229467 MAarrowhead1
% End of user PostScript
1 0 .172 r
.16716 .69036 m
.16536 .69137 L
s
% Start of user PostScript
-1.4 0.8 -1.4075607 0.80425922 MAarrowhead1
% End of user PostScript
1 0 .125 r
.16716 .73791 m
.16604 .7389 L
s
% Start of user PostScript
-1.4 1. -1.4047159 1.0041791 MAarrowhead1
% End of user PostScript
1 0 .09 r
.16716 .78546 m
.16645 .78628 L
s
% Start of user PostScript
-1.4 1.2 -1.4029626 1.2034538 MAarrowhead1
% End of user PostScript
1 0 .067 r
.16716 .83301 m
.16669 .83366 L
s
% Start of user PostScript
-1.4 1.4 -1.4019751 1.4027558 MAarrowhead1
% End of user PostScript
1 0 .052 r
.16716 .88055 m
.16682 .88108 L
s
% Start of user PostScript
-1.4 1.6 -1.4014026 1.6022163 MAarrowhead1
% End of user PostScript
1 0 .042 r
.16716 .9281 m
.16691 .92854 L
s
% Start of user PostScript
-1.4 1.8 -1.4010488 1.801817 MAarrowhead1
% End of user PostScript
1 0 .034 r
.16716 .97565 m
.16696 .97601 L
s
% Start of user PostScript
-1.4 2. -1.4008152 2.0015198 MAarrowhead1
% End of user PostScript
1 0 .036 r
.21471 .02468 m
.21444 .02434 L
s
% Start of user PostScript
-1.2 -2. -1.2011382 -2.0014118 MAarrowhead1
% End of user PostScript
1 0 .041 r
.21471 .07222 m
.21437 .07186 L
s
% Start of user PostScript
-1.2 -1.8 -1.2014264 -1.801516 MAarrowhead1
% End of user PostScript
1 0 .047 r
.21471 .11977 m
.21429 .1194 L
s
% Start of user PostScript
-1.2 -1.6 -1.2017594 -1.6015772 MAarrowhead1
% End of user PostScript
1 0 .052 r
.21471 .16732 m
.21421 .16695 L
s
% Start of user PostScript
-1.2 -1.4 -1.2021053 -1.4015749 MAarrowhead1
% End of user PostScript
1 0 .056 r
.21471 .21487 m
.21413 .21451 L
s
% Start of user PostScript
-1.2 -1.2 -1.202409 -1.2015132 MAarrowhead1
% End of user PostScript
1 0 .059 r
.21471 .26242 m
.21408 .26208 L
s
% Start of user PostScript
-1.2 -1. -1.2026159 -1.0014463 MAarrowhead1
% End of user PostScript
1 0 .061 r
.21471 .30997 m
.21406 .30962 L
s
% Start of user PostScript
-1.2 -0.8 -1.2027195 -0.80148211 MAarrowhead1
% End of user PostScript
1 0 .065 r
.21471 .35752 m
.21404 .3571 L
s
% Start of user PostScript
-1.2 -0.6 -1.2027977 -0.60175868 MAarrowhead1
% End of user PostScript
1 0 .077 r
.21471 .40507 m
.21399 .40449 L
s
% Start of user PostScript
-1.2 -0.4 -1.2030306 -0.40243476 MAarrowhead1
% End of user PostScript
1 0 .105 r
.21471 .45262 m
.21381 .45173 L
s
% Start of user PostScript
-1.2 -0.2 -1.2037774 -0.20373782 MAarrowhead1
% End of user PostScript
1 0 .167 r
.21471 .50016 m
.2133 .49874 L
s
% Start of user PostScript
-1.2 0. -1.2059358 -0.0060032478 MAarrowhead1
% End of user PostScript
1 0 .295 r
.21471 .54771 m
.21186 .54559 L
s
% Start of user PostScript
-1.2 0.2 -1.2119616 0.19108534 MAarrowhead1
% End of user PostScript
1 0 .488 r
.21471 .59526 m
.20903 .59379 L
s
% Start of user PostScript
-1.2 0.4 -1.2238635 0.39382919 MAarrowhead1
% End of user PostScript
1 0 .492 r
.21471 .64281 m
.20906 .64457 L
s
% Start of user PostScript
-1.2 0.6 -1.2237446 0.60738687 MAarrowhead1
% End of user PostScript
1 0 .305 r
.21471 .69036 m
.21195 .69277 L
s
% Start of user PostScript
-1.2 0.8 -1.2115968 0.81013072 MAarrowhead1
% End of user PostScript
1 0 .177 r
.21471 .73791 m
.21345 .73962 L
s
% Start of user PostScript
-1.2 1. -1.2053031 1.0072098 MAarrowhead1
% End of user PostScript
1 0 .112 r
.21471 .78546 m
.21403 .78662 L
s
% Start of user PostScript
-1.2 1.2 -1.2028473 1.2049055 MAarrowhead1
% End of user PostScript
1 0 .078 r
.21471 .83301 m
.21428 .83384 L
s
% Start of user PostScript
-1.2 1.4 -1.2017816 1.4035054 MAarrowhead1
% End of user PostScript
1 0 .058 r
.21471 .88055 m
.21441 .88118 L
s
% Start of user PostScript
-1.2 1.6 -1.2012412 1.6026445 MAarrowhead1
% End of user PostScript
1 0 .045 r
.21471 .9281 m
.21449 .9286 L
s
% Start of user PostScript
-1.2 1.8 -1.2009268 1.8020857 MAarrowhead1
% End of user PostScript
1 0 .037 r
.21471 .97565 m
.21453 .97606 L
s
% Start of user PostScript
-1.2 2. -1.2007232 2.0017018 MAarrowhead1
% End of user PostScript
1 0 .042 r
.26226 .02468 m
.26197 .02427 L
s
% Start of user PostScript
-1. -2. -1.0012168 -2.0017099 MAarrowhead1
% End of user PostScript
1 0 .049 r
.26226 .07222 m
.26187 .07178 L
s
% Start of user PostScript
-1. -1.8 -1.0016056 -1.8018889 MAarrowhead1
% End of user PostScript
1 0 .057 r
.26226 .11977 m
.26176 .1193 L
s
% Start of user PostScript
-1. -1.6 -1.0020944 -1.6020063 MAarrowhead1
% End of user PostScript
1 0 .066 r
.26226 .16732 m
.26163 .16685 L
s
% Start of user PostScript
-1. -1.4 -1.0026389 -1.4019986 MAarrowhead1
% End of user PostScript
1 0 .072 r
.26226 .21487 m
.26151 .21444 L
s
% Start of user PostScript
-1. -1.2 -1.0031195 -1.2018302 MAarrowhead1
% End of user PostScript
1 0 .074 r
.26226 .26242 m
.26145 .26205 L
s
% Start of user PostScript
-1. -1. -1.003376 -1.0015756 MAarrowhead1
% End of user PostScript
1 0 .072 r
.26226 .30997 m
.26146 .30962 L
s
% Start of user PostScript
-1. -0.8 -1.0033368 -0.80144889 MAarrowhead1
% End of user PostScript
1 0 .07 r
.26226 .35752 m
.26152 .35711 L
s
% Start of user PostScript
-1. -0.6 -1.0031096 -0.60171346 MAarrowhead1
% End of user PostScript
1 0 .078 r
.26226 .40507 m
.26156 .40444 L
s
% Start of user PostScript
-1. -0.4 -1.002925 -0.40263587 MAarrowhead1
% End of user PostScript
1 0 .112 r
.26226 .45262 m
.26152 .45149 L
s
% Start of user PostScript
-1. -0.2 -1.0031081 -0.20471449 MAarrowhead1
% End of user PostScript
1 0 .209 r
.26226 .50016 m
.26118 .4979 L
s
% Start of user PostScript
-1. 0. -1.004534 -0.0095394184 MAarrowhead1
% End of user PostScript
1 0 .526 r
.26226 .54771 m
.25931 .54212 L
s
% Start of user PostScript
-1. 0.2 -1.0123992 0.17647789 MAarrowhead1
% End of user PostScript
0 .048 1 r
.26226 .59526 m
.24234 .58082 L
s
% Start of user PostScript
-1. 0.4 -1.0837545 0.33926473 MAarrowhead1
% End of user PostScript
0 .064 1 r
.26226 .64281 m
.24238 .6576 L
s
% Start of user PostScript
-1. 0.6 -1.0836181 0.6622093 MAarrowhead1
% End of user PostScript
1 0 .549 r
.26226 .69036 m
.25941 .69631 L
s
% Start of user PostScript
-1. 0.8 -1.0119745 0.82501884 MAarrowhead1
% End of user PostScript
1 0 .232 r
.26226 .73791 m
.26136 .74054 L
s
% Start of user PostScript
-1. 1. -1.0037753 1.011069 MAarrowhead1
% End of user PostScript
1 0 .13 r
.26226 .78546 m
.26179 .78694 L
s
% Start of user PostScript
-1. 1.2 -1.0019438 1.2062566 MAarrowhead1
% End of user PostScript
1 0 .085 r
.26226 .83301 m
.26195 .83398 L
s
% Start of user PostScript
-1. 1.4 -1.0012772 1.4041149 MAarrowhead1
% End of user PostScript
1 0 .062 r
.26226 .88055 m
.26203 .88126 L
s
% Start of user PostScript
-1. 1.6 -1.0009432 1.6029787 MAarrowhead1
% End of user PostScript
1 0 .048 r
.26226 .9281 m
.26208 .92865 L
s
% Start of user PostScript
-1. 1.8 -1.0007375 1.8022967 MAarrowhead1
% End of user PostScript
1 0 .038 r
.26226 .97565 m
.26211 .97609 L
s
% Start of user PostScript
-1. 2. -1.0005941 2.0018482 MAarrowhead1
% End of user PostScript
1 0 .048 r
.3098 .02468 m
.30951 .02418 L
s
% Start of user PostScript
-0.8 -2. -0.80125864 -2.0020918 MAarrowhead1
% End of user PostScript
1 0 .059 r
.3098 .07222 m
.30938 .07165 L
s
% Start of user PostScript
-0.8 -1.8 -0.80178034 -1.8024178 MAarrowhead1
% End of user PostScript
1 0 .073 r
.3098 .11977 m
.3092 .11913 L
s
% Start of user PostScript
-0.8 -1.6 -0.80252621 -1.6026873 MAarrowhead1
% End of user PostScript
1 0 .088 r
.3098 .16732 m
.30898 .16667 L
s
% Start of user PostScript
-0.8 -1.4 -0.8034808 -1.4027385 MAarrowhead1
% End of user PostScript
1 0 .099 r
.3098 .21487 m
.30875 .21431 L
s
% Start of user PostScript
-0.8 -1.2 -0.80441484 -1.2023785 MAarrowhead1
% End of user PostScript
1 0 .102 r
.3098 .26242 m
.30865 .26203 L
s
% Start of user PostScript
-0.8 -1. -0.80485741 -1.0016555 MAarrowhead1
% End of user PostScript
1 0 .092 r
.3098 .30997 m
.30873 .30972 L
s
% Start of user PostScript
-0.8 -0.8 -0.80451963 -0.80106441 MAarrowhead1
% End of user PostScript
1 0 .076 r
.3098 .35752 m
.30893 .35724 L
s
% Start of user PostScript
-0.8 -0.6 -0.80367156 -0.60115262 MAarrowhead1
% End of user PostScript
1 0 .069 r
.3098 .40507 m
.30915 .40455 L
s
% Start of user PostScript
-0.8 -0.4 -0.80274499 -0.40217529 MAarrowhead1
% End of user PostScript
1 0 .097 r
.3098 .45262 m
.30936 .45154 L
s
% Start of user PostScript
-0.8 -0.2 -0.80185229 -0.20453912 MAarrowhead1
% End of user PostScript
1 0 .2 r
.3098 .50016 m
.30968 .49776 L
s
% Start of user PostScript
-0.8 0. -0.8005251 -0.010101882 MAarrowhead1
% End of user PostScript
1 0 .577 r
.3098 .54771 m
.31094 .54087 L
s
% Start of user PostScript
-0.8 0.2 -0.79520894 0.17123852 MAarrowhead1
% End of user PostScript
0 1 .071 r
.3098 .59526 m
.33564 .55578 L
s
% Start of user PostScript
-0.8 0.4 -0.69134667 0.23394525 MAarrowhead1
% End of user PostScript
0 1 .04 r
.3098 .64281 m
.33567 .68271 L
s
% Start of user PostScript
-0.8 0.6 -0.69119997 0.76781702 MAarrowhead1
% End of user PostScript
1 0 .615 r
.3098 .69036 m
.31105 .69763 L
s
% Start of user PostScript
-0.8 0.8 -0.79474353 0.83058722 MAarrowhead1
% End of user PostScript
1 0 .239 r
.3098 .73791 m
.30989 .74077 L
s
% Start of user PostScript
-0.8 1. -0.79966078 1.0120445 MAarrowhead1
% End of user PostScript
1 0 .131 r
.3098 .78546 m
.3097 .78703 L
s
% Start of user PostScript
-0.8 1.2 -0.80044447 1.2066187 MAarrowhead1
% End of user PostScript
1 0 .086 r
.3098 .83301 m
.30966 .83403 L
s
% Start of user PostScript
-0.8 1.4 -0.80058874 1.4043248 MAarrowhead1
% End of user PostScript
1 0 .063 r
.3098 .88055 m
.30967 .8813 L
s
% Start of user PostScript
-0.8 1.6 -0.80057392 1.6031296 MAarrowhead1
% End of user PostScript
1 0 .049 r
.3098 .9281 m
.30968 .92868 L
s
% Start of user PostScript
-0.8 1.8 -0.80051423 1.8024148 MAarrowhead1
% End of user PostScript
1 0 .039 r
.3098 .97565 m
.3097 .97611 L
s
% Start of user PostScript
-0.8 2. -0.80044555 2.0019435 MAarrowhead1
% End of user PostScript
1 0 .056 r
.35735 .02468 m
.35707 .02407 L
s
% Start of user PostScript
-0.6 -2. -0.60121169 -2.0025583 MAarrowhead1
% End of user PostScript
1 0 .073 r
.35735 .07222 m
.35691 .07147 L
s
% Start of user PostScript
-0.6 -1.8 -0.60186963 -1.8031561 MAarrowhead1
% End of user PostScript
1 0 .096 r
.35735 .11977 m
.35664 .11887 L
s
% Start of user PostScript
-0.6 -1.6 -0.60299142 -1.6038164 MAarrowhead1
% End of user PostScript
1 0 .127 r
.35735 .16732 m
.35621 .16632 L
s
% Start of user PostScript
-0.6 -1.4 -0.60479314 -1.4042323 MAarrowhead1
% End of user PostScript
1 0 .157 r
.35735 .21487 m
.35568 .214 L
s
% Start of user PostScript
-0.6 -1.2 -0.60703557 -1.2036614 MAarrowhead1
% End of user PostScript
1 0 .166 r
.35735 .26242 m
.3554 .26202 L
s
% Start of user PostScript
-0.6 -1. -0.60822007 -1.0016858 MAarrowhead1
% End of user PostScript
1 0 .14 r
.35735 .30997 m
.35568 .31001 L
s
% Start of user PostScript
-0.6 -0.8 -0.60704604 -0.79982375 MAarrowhead1
% End of user PostScript
1 0 .094 r
.35735 .35752 m
.35622 .35761 L
s
% Start of user PostScript
-0.6 -0.6 -0.60475343 -0.59962894 MAarrowhead1
% End of user PostScript
1 0 .056 r
.35735 .40507 m
.35671 .40487 L
s
% Start of user PostScript
-0.6 -0.4 -0.60272406 -0.40081444 MAarrowhead1
% End of user PostScript
1 0 .061 r
.35735 .45262 m
.35714 .45191 L
s
% Start of user PostScript
-0.6 -0.2 -0.60088601 -0.2029595 MAarrowhead1
% End of user PostScript
1 0 .134 r
.35735 .50016 m
.35783 .49862 L
s
% Start of user PostScript
-0.6 0. -0.59801346 -0.006481556 MAarrowhead1
% End of user PostScript
1 0 .311 r
.35735 .54771 m
.3597 .54481 L
s
% Start of user PostScript
-0.6 0.2 -0.59011531 0.18780092 MAarrowhead1
% End of user PostScript
1 0 .663 r
.35735 .59526 m
.36484 .59254 L
s
% Start of user PostScript
-0.6 0.4 -0.56852261 0.3885328 MAarrowhead1
% End of user PostScript
1 0 .681 r
.35735 .64281 m
.36487 .64603 L
s
% Start of user PostScript
-0.6 0.6 -0.56838028 0.6135265 MAarrowhead1
% End of user PostScript
1 0 .351 r
.35735 .69036 m
.35981 .69378 L
s
% Start of user PostScript
-0.6 0.8 -0.58965391 0.81438358 MAarrowhead1
% End of user PostScript
1 0 .186 r
.35735 .73791 m
.35804 .74003 L
s
% Start of user PostScript
-0.6 1. -0.59711601 1.0089239 MAarrowhead1
% End of user PostScript
1 0 .115 r
.35735 .78546 m
.35752 .78683 L
s
% Start of user PostScript
-0.6 1.2 -0.59930773 1.2057907 MAarrowhead1
% End of user PostScript
1 0 .081 r
.35735 .83301 m
.35735 .83398 L
s
% Start of user PostScript
-0.6 1.4 -0.60001662 1.4040911 MAarrowhead1
% End of user PostScript
1 0 .061 r
.35735 .88055 m
.35729 .88129 L
s
% Start of user PostScript
-0.6 1.6 -0.60024751 1.6030865 MAarrowhead1
% End of user PostScript
1 0 .049 r
.35735 .9281 m
.35728 .92868 L
s
% Start of user PostScript
-0.6 1.8 -0.60030617 1.8024374 MAarrowhead1
% End of user PostScript
1 0 .04 r
.35735 .97565 m
.35728 .97612 L
s
% Start of user PostScript
-0.6 2. -0.60030046 2.0019868 MAarrowhead1
% End of user PostScript
1 0 .064 r
.4049 .02468 m
.40466 .02395 L
s
% Start of user PostScript
-0.4 -2. -0.40100362 -2.0030624 MAarrowhead1
% End of user PostScript
1 0 .088 r
.4049 .07222 m
.4045 .07125 L
s
% Start of user PostScript
-0.4 -1.8 -0.40170329 -1.8040882 MAarrowhead1
% End of user PostScript
1 0 .128 r
.4049 .11977 m
.40415 .11844 L
s
% Start of user PostScript
-0.4 -1.6 -0.4031766 -1.6056119 MAarrowhead1
% End of user PostScript
1 0 .197 r
.4049 .16732 m
.40336 .16553 L
s
% Start of user PostScript
-0.4 -1.4 -0.40647467 -1.4075355 MAarrowhead1
% End of user PostScript
1 0 .3 r
.4049 .21487 m
.40182 .21301 L
s
% Start of user PostScript
-0.4 -1.2 -0.41298471 -1.2078281 MAarrowhead1
% End of user PostScript
1 0 .36 r
.4049 .26242 m
.4006 .26202 L
s
% Start of user PostScript
-0.4 -1. -0.41809001 -1.0016817 MAarrowhead1
% End of user PostScript
1 0 .271 r
.4049 .30997 m
.40182 .31101 L
s
% Start of user PostScript
-0.4 -0.8 -0.41294761 -0.79561931 MAarrowhead1
% End of user PostScript
1 0 .146 r
.4049 .35752 m
.4034 .35843 L
s
% Start of user PostScript
-0.4 -0.6 -0.40633363 -0.59617535 MAarrowhead1
% End of user PostScript
1 0 .061 r
.4049 .40507 m
.40425 .4054 L
s
% Start of user PostScript
-0.4 -0.4 -0.40274885 -0.39857672 MAarrowhead1
% End of user PostScript
1 0 .02 r
.4049 .45262 m
.40477 .45242 L
s
% Start of user PostScript
-0.4 -0.2 -0.40055599 -0.2008338 MAarrowhead1
% End of user PostScript
1 0 .066 r
.4049 .50016 m
.40534 .49951 L
s
% Start of user PostScript
-0.4 0. -0.39816927 -0.002768364 MAarrowhead1
% End of user PostScript
1 0 .134 r
.4049 .54771 m
.40624 .54682 L
s
% Start of user PostScript
-0.4 0.2 -0.39435556 0.19624997 MAarrowhead1
% End of user PostScript
1 0 .204 r
.4049 .59526 m
.40733 .59491 L
s
% Start of user PostScript
-0.4 0.4 -0.38978417 0.39850965 MAarrowhead1
% End of user PostScript
1 0 .218 r
.4049 .64281 m
.40736 .64372 L
s
% Start of user PostScript
-0.4 0.6 -0.38966806 0.60381789 MAarrowhead1
% End of user PostScript
1 0 .172 r
.4049 .69036 m
.40634 .69185 L
s
% Start of user PostScript
-0.4 0.8 -0.39397107 0.80627815 MAarrowhead1
% End of user PostScript
1 0 .125 r
.4049 .73791 m
.40552 .73927 L
s
% Start of user PostScript
-0.4 1. -0.39738495 1.0057449 MAarrowhead1
% End of user PostScript
1 0 .093 r
.4049 .78546 m
.40513 .78655 L
s
% Start of user PostScript
-0.4 1.2 -0.39905287 1.2046109 MAarrowhead1
% End of user PostScript
1 0 .072 r
.4049 .83301 m
.40496 .83387 L
s
% Start of user PostScript
-0.4 1.4 -0.39976419 1.403652 MAarrowhead1
% End of user PostScript
1 0 .058 r
.4049 .88055 m
.40489 .88125 L
s
% Start of user PostScript
-0.4 1.6 -0.40004886 1.6029336 MAarrowhead1
% End of user PostScript
1 0 .048 r
.4049 .9281 m
.40487 .92867 L
s
% Start of user PostScript
-0.4 1.8 -0.40015116 1.8023984 MAarrowhead1
% End of user PostScript
1 0 .04 r
.4049 .97565 m
.40486 .97613 L
s
% Start of user PostScript
-0.4 2. -0.4001769 2.0019926 MAarrowhead1
% End of user PostScript
1 0 .07 r
.45245 .02468 m
.45231 .02385 L
s
% Start of user PostScript
-0.2 -2. -0.20058379 -2.0034811 MAarrowhead1
% End of user PostScript
1 0 .101 r
.45245 .07222 m
.4522 .07104 L
s
% Start of user PostScript
-0.2 -1.8 -0.20107323 -1.8049853 MAarrowhead1
% End of user PostScript
1 0 .162 r
.45245 .11977 m
.4519 .11791 L
s
% Start of user PostScript
-0.2 -1.6 -0.20232661 -1.6078393 MAarrowhead1
% End of user PostScript
1 0 .306 r
.45245 .16732 m
.45091 .16398 L
s
% Start of user PostScript
-0.2 -1.4 -0.20648533 -1.4140439 MAarrowhead1
% End of user PostScript
1 0 .732 r
.45245 .21487 m
.4464 .2085 L
s
% Start of user PostScript
-0.2 -1.2 -0.22545627 -1.2267984 MAarrowhead1
% End of user PostScript
.576 0 1 r
.45245 .26242 m
.43536 .26202 L
s
% Start of user PostScript
-0.2 -1. -0.27187685 -1.0016662 MAarrowhead1
% End of user PostScript
1 0 .684 r
.45245 .30997 m
.44641 .31553 L
s
% Start of user PostScript
-0.2 -0.8 -0.22542213 -0.77659267 MAarrowhead1
% End of user PostScript
1 0 .243 r
.45245 .35752 m
.45094 .36001 L
s
% Start of user PostScript
-0.2 -0.6 -0.20637586 -0.58951804 MAarrowhead1
% End of user PostScript
1 0 .089 r
.45245 .40507 m
.45197 .40602 L
s
% Start of user PostScript
-0.2 -0.4 -0.20203566 -0.39598089 MAarrowhead1
% End of user PostScript
1 0 .019 r
.45245 .45262 m
.45236 .45283 L
s
% Start of user PostScript
-0.2 -0.2 -0.20038001 -0.19910028 MAarrowhead1
% End of user PostScript
1 0 .022 r
.45245 .50016 m
.45266 .50001 L
s
% Start of user PostScript
-0.2 0. -0.19910537 -0.00065791544 MAarrowhead1
% End of user PostScript
1 0 .05 r
.45245 .54771 m
.45301 .54749 L
s
% Start of user PostScript
-0.2 0.2 -0.19766512 0.199069 MAarrowhead1
% End of user PostScript
1 0 .071 r
.45245 .59526 m
.4533 .59532 L
s
% Start of user PostScript
-0.2 0.4 -0.19643491 0.40024752 MAarrowhead1
% End of user PostScript
1 0 .085 r
.45245 .64281 m
.45331 .64335 L
s
% Start of user PostScript
-0.2 0.6 -0.19636882 0.60227077 MAarrowhead1
% End of user PostScript
1 0 .089 r
.45245 .69036 m
.45306 .69124 L
s
% Start of user PostScript
-0.2 0.8 -0.19744274 0.8037161 MAarrowhead1
% End of user PostScript
1 0 .085 r
.45245 .73791 m
.45278 .73888 L
s
% Start of user PostScript
-0.2 1. -0.19863441 1.0040741 MAarrowhead1
% End of user PostScript
1 0 .076 r
.45245 .78546 m
.45259 .78636 L
s
% Start of user PostScript
-0.2 1.2 -0.19940869 1.203785 MAarrowhead1
% End of user PostScript
1 0 .065 r
.45245 .83301 m
.4525 .83379 L
s
% Start of user PostScript
-0.2 1.4 -0.1998057 1.4032878 MAarrowhead1
% End of user PostScript
1 0 .055 r
.45245 .88055 m
.45245 .88122 L
s
% Start of user PostScript
-0.2 1.6 -0.19998464 1.6027865 MAarrowhead1
% End of user PostScript
1 0 .047 r
.45245 .9281 m
.45244 .92866 L
s
% Start of user PostScript
-0.2 1.8 -0.20005652 1.8023479 MAarrowhead1
% End of user PostScript
1 0 .039 r
.45245 .97565 m
.45243 .97612 L
s
% Start of user PostScript
-0.2 2. -0.20007976 2.0019833 MAarrowhead1
% End of user PostScript
1 0 .072 r
.5 .02468 m
.5 .02381 L
s
% Start of user PostScript
0. -2. 0. -2.0036483 MAarrowhead1
% End of user PostScript
1 0 .107 r
.5 .07222 m
.5 .07095 L
s
% Start of user PostScript
0. -1.8 0. -1.8053789 MAarrowhead1
% End of user PostScript
1 0 .178 r
.5 .11977 m
.5 .11763 L
s
% Start of user PostScript
0. -1.6 0. -1.6090092 MAarrowhead1
% End of user PostScript
1 0 .379 r
.5 .16732 m
.5 .16277 L
s
% Start of user PostScript
0. -1.4 0. -1.4191536 MAarrowhead1
% End of user PostScript
.55 0 1 r
.5 .21487 m
.5 .19746 L
s
% Start of user PostScript
0. -1.2 0. -1.2732247 MAarrowhead1
% End of user PostScript
.617 0 1 r
.5 .30997 m
.5 .32658 L
s
% Start of user PostScript
0. -0.8 0. -0.73014144 MAarrowhead1
% End of user PostScript
1 0 .31 r
.5 .35752 m
.5 .36124 L
s
% Start of user PostScript
0. -0.6 0. -0.58434865 MAarrowhead1
% End of user PostScript
1 0 .105 r
.5 .40507 m
.5 .40633 L
s
% Start of user PostScript
0. -0.4 0. -0.39467407 MAarrowhead1
% End of user PostScript
1 0 .031 r
.5 .45262 m
.5 .45299 L
s
% Start of user PostScript
0. -0.2 0. -0.19842402 MAarrowhead1
% End of user PostScript
1 0 0 r
.5 .50016 m
.5 .50016 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
1 0 .005 r
.5 .54771 m
.5 .54765 L
s
% Start of user PostScript
0. 0.2 0. 0.19975609 MAarrowhead1
% End of user PostScript
1 0 .012 r
.5 .59526 m
.5 .5954 L
s
% Start of user PostScript
0. 0.4 0. 0.40059851 MAarrowhead1
% End of user PostScript
1 0 .039 r
.5 .64281 m
.5 .64328 L
s
% Start of user PostScript
0. 0.6 0. 0.60198933 MAarrowhead1
% End of user PostScript
1 0 .062 r
.5 .69036 m
.5 .6911 L
s
% Start of user PostScript
0. 0.8 0. 0.80312551 MAarrowhead1
% End of user PostScript
1 0 .071 r
.5 .73791 m
.5 .73876 L
s
% Start of user PostScript
0. 1. 0. 1.0035909 MAarrowhead1
% End of user PostScript
1 0 .069 r
.5 .78546 m
.5 .78629 L
s
% Start of user PostScript
0. 1.2 0. 1.2035062 MAarrowhead1
% End of user PostScript
1 0 .062 r
.5 .83301 m
.5 .83376 L
s
% Start of user PostScript
0. 1.4 0. 1.4031526 MAarrowhead1
% End of user PostScript
1 0 .054 r
.5 .88055 m
.5 .8812 L
s
% Start of user PostScript
0. 1.6 0. 1.6027282 MAarrowhead1
% End of user PostScript
1 0 .046 r
.5 .9281 m
.5 .92866 L
s
% Start of user PostScript
0. 1.8 0. 1.8023261 MAarrowhead1
% End of user PostScript
1 0 .039 r
.5 .97565 m
.5 .97612 L
s
% Start of user PostScript
0. 2. 0. 2.0019778 MAarrowhead1
% End of user PostScript
1 0 .07 r
.54755 .02468 m
.54769 .02385 L
s
% Start of user PostScript
0.2 -2. 0.20058379 -2.0034811 MAarrowhead1
% End of user PostScript
1 0 .101 r
.54755 .07222 m
.5478 .07104 L
s
% Start of user PostScript
0.2 -1.8 0.20107323 -1.8049853 MAarrowhead1
% End of user PostScript
1 0 .162 r
.54755 .11977 m
.5481 .11791 L
s
% Start of user PostScript
0.2 -1.6 0.20232661 -1.6078393 MAarrowhead1
% End of user PostScript
1 0 .306 r
.54755 .16732 m
.54909 .16398 L
s
% Start of user PostScript
0.2 -1.4 0.20648533 -1.4140439 MAarrowhead1
% End of user PostScript
1 0 .732 r
.54755 .21487 m
.5536 .2085 L
s
% Start of user PostScript
0.2 -1.2 0.22545627 -1.2267984 MAarrowhead1
% End of user PostScript
.576 0 1 r
.54755 .26242 m
.56464 .26202 L
s
% Start of user PostScript
0.2 -1. 0.27187685 -1.0016662 MAarrowhead1
% End of user PostScript
1 0 .684 r
.54755 .30997 m
.55359 .31553 L
s
% Start of user PostScript
0.2 -0.8 0.22542213 -0.77659267 MAarrowhead1
% End of user PostScript
1 0 .243 r
.54755 .35752 m
.54906 .36001 L
s
% Start of user PostScript
0.2 -0.6 0.20637586 -0.58951804 MAarrowhead1
% End of user PostScript
1 0 .089 r
.54755 .40507 m
.54803 .40602 L
s
% Start of user PostScript
0.2 -0.4 0.20203566 -0.39598089 MAarrowhead1
% End of user PostScript
1 0 .019 r
.54755 .45262 m
.54764 .45283 L
s
% Start of user PostScript
0.2 -0.2 0.20038001 -0.19910028 MAarrowhead1
% End of user PostScript
1 0 .022 r
.54755 .50016 m
.54734 .50001 L
s
% Start of user PostScript
0.2 0. 0.19910537 -0.00065791544 MAarrowhead1
% End of user PostScript
1 0 .05 r
.54755 .54771 m
.54699 .54749 L
s
% Start of user PostScript
0.2 0.2 0.19766512 0.199069 MAarrowhead1
% End of user PostScript
1 0 .071 r
.54755 .59526 m
.5467 .59532 L
s
% Start of user PostScript
0.2 0.4 0.19643491 0.40024752 MAarrowhead1
% End of user PostScript
1 0 .085 r
.54755 .64281 m
.54669 .64335 L
s
% Start of user PostScript
0.2 0.6 0.19636882 0.60227077 MAarrowhead1
% End of user PostScript
1 0 .089 r
.54755 .69036 m
.54694 .69124 L
s
% Start of user PostScript
0.2 0.8 0.19744274 0.8037161 MAarrowhead1
% End of user PostScript
1 0 .085 r
.54755 .73791 m
.54722 .73888 L
s
% Start of user PostScript
0.2 1. 0.19863441 1.0040741 MAarrowhead1
% End of user PostScript
1 0 .076 r
.54755 .78546 m
.54741 .78636 L
s
% Start of user PostScript
0.2 1.2 0.19940869 1.203785 MAarrowhead1
% End of user PostScript
1 0 .065 r
.54755 .83301 m
.5475 .83379 L
s
% Start of user PostScript
0.2 1.4 0.1998057 1.4032878 MAarrowhead1
% End of user PostScript
1 0 .055 r
.54755 .88055 m
.54755 .88122 L
s
% Start of user PostScript
0.2 1.6 0.19998464 1.6027865 MAarrowhead1
% End of user PostScript
1 0 .047 r
.54755 .9281 m
.54756 .92866 L
s
% Start of user PostScript
0.2 1.8 0.20005652 1.8023479 MAarrowhead1
% End of user PostScript
1 0 .039 r
.54755 .97565 m
.54757 .97612 L
s
% Start of user PostScript
0.2 2. 0.20007976 2.0019833 MAarrowhead1
% End of user PostScript
1 0 .064 r
.5951 .02468 m
.59534 .02395 L
s
% Start of user PostScript
0.4 -2. 0.40100362 -2.0030624 MAarrowhead1
% End of user PostScript
1 0 .088 r
.5951 .07222 m
.5955 .07125 L
s
% Start of user PostScript
0.4 -1.8 0.40170329 -1.8040882 MAarrowhead1
% End of user PostScript
1 0 .128 r
.5951 .11977 m
.59585 .11844 L
s
% Start of user PostScript
0.4 -1.6 0.4031766 -1.6056119 MAarrowhead1
% End of user PostScript
1 0 .197 r
.5951 .16732 m
.59664 .16553 L
s
% Start of user PostScript
0.4 -1.4 0.40647467 -1.4075355 MAarrowhead1
% End of user PostScript
1 0 .3 r
.5951 .21487 m
.59818 .21301 L
s
% Start of user PostScript
0.4 -1.2 0.41298471 -1.2078281 MAarrowhead1
% End of user PostScript
1 0 .36 r
.5951 .26242 m
.5994 .26202 L
s
% Start of user PostScript
0.4 -1. 0.41809001 -1.0016817 MAarrowhead1
% End of user PostScript
1 0 .271 r
.5951 .30997 m
.59818 .31101 L
s
% Start of user PostScript
0.4 -0.8 0.41294761 -0.79561931 MAarrowhead1
% End of user PostScript
1 0 .146 r
.5951 .35752 m
.5966 .35843 L
s
% Start of user PostScript
0.4 -0.6 0.40633363 -0.59617535 MAarrowhead1
% End of user PostScript
1 0 .061 r
.5951 .40507 m
.59575 .4054 L
s
% Start of user PostScript
0.4 -0.4 0.40274885 -0.39857672 MAarrowhead1
% End of user PostScript
1 0 .02 r
.5951 .45262 m
.59523 .45242 L
s
% Start of user PostScript
0.4 -0.2 0.40055599 -0.2008338 MAarrowhead1
% End of user PostScript
1 0 .066 r
.5951 .50016 m
.59466 .49951 L
s
% Start of user PostScript
0.4 0. 0.39816927 -0.002768364 MAarrowhead1
% End of user PostScript
1 0 .134 r
.5951 .54771 m
.59376 .54682 L
s
% Start of user PostScript
0.4 0.2 0.39435556 0.19624997 MAarrowhead1
% End of user PostScript
1 0 .204 r
.5951 .59526 m
.59267 .59491 L
s
% Start of user PostScript
0.4 0.4 0.38978417 0.39850965 MAarrowhead1
% End of user PostScript
1 0 .218 r
.5951 .64281 m
.59264 .64372 L
s
% Start of user PostScript
0.4 0.6 0.38966806 0.60381789 MAarrowhead1
% End of user PostScript
1 0 .172 r
.5951 .69036 m
.59366 .69185 L
s
% Start of user PostScript
0.4 0.8 0.39397107 0.80627815 MAarrowhead1
% End of user PostScript
1 0 .125 r
.5951 .73791 m
.59448 .73927 L
s
% Start of user PostScript
0.4 1. 0.39738495 1.0057449 MAarrowhead1
% End of user PostScript
1 0 .093 r
.5951 .78546 m
.59487 .78655 L
s
% Start of user PostScript
0.4 1.2 0.39905287 1.2046109 MAarrowhead1
% End of user PostScript
1 0 .072 r
.5951 .83301 m
.59504 .83387 L
s
% Start of user PostScript
0.4 1.4 0.39976419 1.403652 MAarrowhead1
% End of user PostScript
1 0 .058 r
.5951 .88055 m
.59511 .88125 L
s
% Start of user PostScript
0.4 1.6 0.40004886 1.6029336 MAarrowhead1
% End of user PostScript
1 0 .048 r
.5951 .9281 m
.59513 .92867 L
s
% Start of user PostScript
0.4 1.8 0.40015116 1.8023984 MAarrowhead1
% End of user PostScript
1 0 .04 r
.5951 .97565 m
.59514 .97613 L
s
% Start of user PostScript
0.4 2. 0.4001769 2.0019926 MAarrowhead1
% End of user PostScript
1 0 .056 r
.64265 .02468 m
.64293 .02407 L
s
% Start of user PostScript
0.6 -2. 0.60121169 -2.0025583 MAarrowhead1
% End of user PostScript
1 0 .073 r
.64265 .07222 m
.64309 .07147 L
s
% Start of user PostScript
0.6 -1.8 0.60186963 -1.8031561 MAarrowhead1
% End of user PostScript
1 0 .096 r
.64265 .11977 m
.64336 .11887 L
s
% Start of user PostScript
0.6 -1.6 0.60299142 -1.6038164 MAarrowhead1
% End of user PostScript
1 0 .127 r
.64265 .16732 m
.64379 .16632 L
s
% Start of user PostScript
0.6 -1.4 0.60479314 -1.4042323 MAarrowhead1
% End of user PostScript
1 0 .157 r
.64265 .21487 m
.64432 .214 L
s
% Start of user PostScript
0.6 -1.2 0.60703557 -1.2036614 MAarrowhead1
% End of user PostScript
1 0 .166 r
.64265 .26242 m
.6446 .26202 L
s
% Start of user PostScript
0.6 -1. 0.60822007 -1.0016858 MAarrowhead1
% End of user PostScript
1 0 .14 r
.64265 .30997 m
.64432 .31001 L
s
% Start of user PostScript
0.6 -0.8 0.60704604 -0.79982375 MAarrowhead1
% End of user PostScript
1 0 .094 r
.64265 .35752 m
.64378 .35761 L
s
% Start of user PostScript
0.6 -0.6 0.60475343 -0.59962894 MAarrowhead1
% End of user PostScript
1 0 .056 r
.64265 .40507 m
.64329 .40487 L
s
% Start of user PostScript
0.6 -0.4 0.60272406 -0.40081444 MAarrowhead1
% End of user PostScript
1 0 .061 r
.64265 .45262 m
.64286 .45191 L
s
% Start of user PostScript
0.6 -0.2 0.60088601 -0.2029595 MAarrowhead1
% End of user PostScript
1 0 .134 r
.64265 .50016 m
.64217 .49862 L
s
% Start of user PostScript
0.6 0. 0.59801346 -0.006481556 MAarrowhead1
% End of user PostScript
1 0 .311 r
.64265 .54771 m
.6403 .54481 L
s
% Start of user PostScript
0.6 0.2 0.59011531 0.18780092 MAarrowhead1
% End of user PostScript
1 0 .663 r
.64265 .59526 m
.63516 .59254 L
s
% Start of user PostScript
0.6 0.4 0.56852261 0.3885328 MAarrowhead1
% End of user PostScript
1 0 .681 r
.64265 .64281 m
.63513 .64603 L
s
% Start of user PostScript
0.6 0.6 0.56838028 0.6135265 MAarrowhead1
% End of user PostScript
1 0 .351 r
.64265 .69036 m
.64019 .69378 L
s
% Start of user PostScript
0.6 0.8 0.58965391 0.81438358 MAarrowhead1
% End of user PostScript
1 0 .186 r
.64265 .73791 m
.64196 .74003 L
s
% Start of user PostScript
0.6 1. 0.59711601 1.0089239 MAarrowhead1
% End of user PostScript
1 0 .115 r
.64265 .78546 m
.64248 .78683 L
s
% Start of user PostScript
0.6 1.2 0.59930773 1.2057907 MAarrowhead1
% End of user PostScript
1 0 .081 r
.64265 .83301 m
.64265 .83398 L
s
% Start of user PostScript
0.6 1.4 0.60001662 1.4040911 MAarrowhead1
% End of user PostScript
1 0 .061 r
.64265 .88055 m
.64271 .88129 L
s
% Start of user PostScript
0.6 1.6 0.60024751 1.6030865 MAarrowhead1
% End of user PostScript
1 0 .049 r
.64265 .9281 m
.64272 .92868 L
s
% Start of user PostScript
0.6 1.8 0.60030617 1.8024374 MAarrowhead1
% End of user PostScript
1 0 .04 r
.64265 .97565 m
.64272 .97612 L
s
% Start of user PostScript
0.6 2. 0.60030046 2.0019868 MAarrowhead1
% End of user PostScript
1 0 .048 r
.6902 .02468 m
.69049 .02418 L
s
% Start of user PostScript
0.8 -2. 0.80125864 -2.0020918 MAarrowhead1
% End of user PostScript
1 0 .059 r
.6902 .07222 m
.69062 .07165 L
s
% Start of user PostScript
0.8 -1.8 0.80178034 -1.8024178 MAarrowhead1
% End of user PostScript
1 0 .073 r
.6902 .11977 m
.6908 .11913 L
s
% Start of user PostScript
0.8 -1.6 0.80252621 -1.6026873 MAarrowhead1
% End of user PostScript
1 0 .088 r
.6902 .16732 m
.69102 .16667 L
s
% Start of user PostScript
0.8 -1.4 0.8034808 -1.4027385 MAarrowhead1
% End of user PostScript
1 0 .099 r
.6902 .21487 m
.69125 .21431 L
s
% Start of user PostScript
0.8 -1.2 0.80441484 -1.2023785 MAarrowhead1
% End of user PostScript
1 0 .102 r
.6902 .26242 m
.69135 .26203 L
s
% Start of user PostScript
0.8 -1. 0.80485741 -1.0016555 MAarrowhead1
% End of user PostScript
1 0 .092 r
.6902 .30997 m
.69127 .30972 L
s
% Start of user PostScript
0.8 -0.8 0.80451963 -0.80106441 MAarrowhead1
% End of user PostScript
1 0 .076 r
.6902 .35752 m
.69107 .35724 L
s
% Start of user PostScript
0.8 -0.6 0.80367156 -0.60115262 MAarrowhead1
% End of user PostScript
1 0 .069 r
.6902 .40507 m
.69085 .40455 L
s
% Start of user PostScript
0.8 -0.4 0.80274499 -0.40217529 MAarrowhead1
% End of user PostScript
1 0 .097 r
.6902 .45262 m
.69064 .45154 L
s
% Start of user PostScript
0.8 -0.2 0.80185229 -0.20453912 MAarrowhead1
% End of user PostScript
1 0 .2 r
.6902 .50016 m
.69032 .49776 L
s
% Start of user PostScript
0.8 0. 0.8005251 -0.010101882 MAarrowhead1
% End of user PostScript
1 0 .577 r
.6902 .54771 m
.68906 .54087 L
s
% Start of user PostScript
0.8 0.2 0.79520894 0.17123852 MAarrowhead1
% End of user PostScript
0 1 .071 r
.6902 .59526 m
.66436 .55578 L
s
% Start of user PostScript
0.8 0.4 0.69134667 0.23394525 MAarrowhead1
% End of user PostScript
0 1 .04 r
.6902 .64281 m
.66433 .68271 L
s
% Start of user PostScript
0.8 0.6 0.69119997 0.76781702 MAarrowhead1
% End of user PostScript
1 0 .615 r
.6902 .69036 m
.68895 .69763 L
s
% Start of user PostScript
0.8 0.8 0.79474353 0.83058722 MAarrowhead1
% End of user PostScript
1 0 .239 r
.6902 .73791 m
.69011 .74077 L
s
% Start of user PostScript
0.8 1. 0.79966078 1.0120445 MAarrowhead1
% End of user PostScript
1 0 .131 r
.6902 .78546 m
.6903 .78703 L
s
% Start of user PostScript
0.8 1.2 0.80044447 1.2066187 MAarrowhead1
% End of user PostScript
1 0 .086 r
.6902 .83301 m
.69034 .83403 L
s
% Start of user PostScript
0.8 1.4 0.80058874 1.4043248 MAarrowhead1
% End of user PostScript
1 0 .063 r
.6902 .88055 m
.69033 .8813 L
s
% Start of user PostScript
0.8 1.6 0.80057392 1.6031296 MAarrowhead1
% End of user PostScript
1 0 .049 r
.6902 .9281 m
.69032 .92868 L
s
% Start of user PostScript
0.8 1.8 0.80051423 1.8024148 MAarrowhead1
% End of user PostScript
1 0 .039 r
.6902 .97565 m
.6903 .97611 L
s
% Start of user PostScript
0.8 2. 0.80044555 2.0019435 MAarrowhead1
% End of user PostScript
1 0 .042 r
.73774 .02468 m
.73803 .02427 L
s
% Start of user PostScript
1. -2. 1.0012168 -2.0017099 MAarrowhead1
% End of user PostScript
1 0 .049 r
.73774 .07222 m
.73813 .07178 L
s
% Start of user PostScript
1. -1.8 1.0016056 -1.8018889 MAarrowhead1
% End of user PostScript
1 0 .057 r
.73774 .11977 m
.73824 .1193 L
s
% Start of user PostScript
1. -1.6 1.0020944 -1.6020063 MAarrowhead1
% End of user PostScript
1 0 .066 r
.73774 .16732 m
.73837 .16685 L
s
% Start of user PostScript
1. -1.4 1.0026389 -1.4019986 MAarrowhead1
% End of user PostScript
1 0 .072 r
.73774 .21487 m
.73849 .21444 L
s
% Start of user PostScript
1. -1.2 1.0031195 -1.2018302 MAarrowhead1
% End of user PostScript
1 0 .074 r
.73774 .26242 m
.73855 .26205 L
s
% Start of user PostScript
1. -1. 1.003376 -1.0015756 MAarrowhead1
% End of user PostScript
1 0 .072 r
.73774 .30997 m
.73854 .30962 L
s
% Start of user PostScript
1. -0.8 1.0033368 -0.80144889 MAarrowhead1
% End of user PostScript
1 0 .07 r
.73774 .35752 m
.73848 .35711 L
s
% Start of user PostScript
1. -0.6 1.0031096 -0.60171346 MAarrowhead1
% End of user PostScript
1 0 .078 r
.73774 .40507 m
.73844 .40444 L
s
% Start of user PostScript
1. -0.4 1.002925 -0.40263587 MAarrowhead1
% End of user PostScript
1 0 .112 r
.73774 .45262 m
.73848 .45149 L
s
% Start of user PostScript
1. -0.2 1.0031081 -0.20471449 MAarrowhead1
% End of user PostScript
1 0 .209 r
.73774 .50016 m
.73882 .4979 L
s
% Start of user PostScript
1. 0. 1.004534 -0.0095394184 MAarrowhead1
% End of user PostScript
1 0 .526 r
.73774 .54771 m
.74069 .54212 L
s
% Start of user PostScript
1. 0.2 1.0123992 0.17647789 MAarrowhead1
% End of user PostScript
0 .048 1 r
.73774 .59526 m
.75766 .58082 L
s
% Start of user PostScript
1. 0.4 1.0837545 0.33926473 MAarrowhead1
% End of user PostScript
0 .064 1 r
.73774 .64281 m
.75762 .6576 L
s
% Start of user PostScript
1. 0.6 1.0836181 0.6622093 MAarrowhead1
% End of user PostScript
1 0 .549 r
.73774 .69036 m
.74059 .69631 L
s
% Start of user PostScript
1. 0.8 1.0119745 0.82501884 MAarrowhead1
% End of user PostScript
1 0 .232 r
.73774 .73791 m
.73864 .74054 L
s
% Start of user PostScript
1. 1. 1.0037753 1.011069 MAarrowhead1
% End of user PostScript
1 0 .13 r
.73774 .78546 m
.73821 .78694 L
s
% Start of user PostScript
1. 1.2 1.0019438 1.2062566 MAarrowhead1
% End of user PostScript
1 0 .085 r
.73774 .83301 m
.73805 .83398 L
s
% Start of user PostScript
1. 1.4 1.0012772 1.4041149 MAarrowhead1
% End of user PostScript
1 0 .062 r
.73774 .88055 m
.73797 .88126 L
s
% Start of user PostScript
1. 1.6 1.0009432 1.6029787 MAarrowhead1
% End of user PostScript
1 0 .048 r
.73774 .9281 m
.73792 .92865 L
s
% Start of user PostScript
1. 1.8 1.0007375 1.8022967 MAarrowhead1
% End of user PostScript
1 0 .038 r
.73774 .97565 m
.73789 .97609 L
s
% Start of user PostScript
1. 2. 1.0005941 2.0018482 MAarrowhead1
% End of user PostScript
1 0 .036 r
.78529 .02468 m
.78556 .02434 L
s
% Start of user PostScript
1.2 -2. 1.2011382 -2.0014118 MAarrowhead1
% End of user PostScript
1 0 .041 r
.78529 .07222 m
.78563 .07186 L
s
% Start of user PostScript
1.2 -1.8 1.2014264 -1.801516 MAarrowhead1
% End of user PostScript
1 0 .047 r
.78529 .11977 m
.78571 .1194 L
s
% Start of user PostScript
1.2 -1.6 1.2017594 -1.6015772 MAarrowhead1
% End of user PostScript
1 0 .052 r
.78529 .16732 m
.78579 .16695 L
s
% Start of user PostScript
1.2 -1.4 1.2021053 -1.4015749 MAarrowhead1
% End of user PostScript
1 0 .056 r
.78529 .21487 m
.78587 .21451 L
s
% Start of user PostScript
1.2 -1.2 1.202409 -1.2015132 MAarrowhead1
% End of user PostScript
1 0 .059 r
.78529 .26242 m
.78592 .26208 L
s
% Start of user PostScript
1.2 -1. 1.2026159 -1.0014463 MAarrowhead1
% End of user PostScript
1 0 .061 r
.78529 .30997 m
.78594 .30962 L
s
% Start of user PostScript
1.2 -0.8 1.2027195 -0.80148211 MAarrowhead1
% End of user PostScript
1 0 .065 r
.78529 .35752 m
.78596 .3571 L
s
% Start of user PostScript
1.2 -0.6 1.2027977 -0.60175868 MAarrowhead1
% End of user PostScript
1 0 .077 r
.78529 .40507 m
.78601 .40449 L
s
% Start of user PostScript
1.2 -0.4 1.2030306 -0.40243476 MAarrowhead1
% End of user PostScript
1 0 .105 r
.78529 .45262 m
.78619 .45173 L
s
% Start of user PostScript
1.2 -0.2 1.2037774 -0.20373782 MAarrowhead1
% End of user PostScript
1 0 .167 r
.78529 .50016 m
.7867 .49874 L
s
% Start of user PostScript
1.2 0. 1.2059358 -0.0060032478 MAarrowhead1
% End of user PostScript
1 0 .295 r
.78529 .54771 m
.78814 .54559 L
s
% Start of user PostScript
1.2 0.2 1.2119616 0.19108534 MAarrowhead1
% End of user PostScript
1 0 .488 r
.78529 .59526 m
.79097 .59379 L
s
% Start of user PostScript
1.2 0.4 1.2238635 0.39382919 MAarrowhead1
% End of user PostScript
1 0 .492 r
.78529 .64281 m
.79094 .64457 L
s
% Start of user PostScript
1.2 0.6 1.2237446 0.60738687 MAarrowhead1
% End of user PostScript
1 0 .305 r
.78529 .69036 m
.78805 .69277 L
s
% Start of user PostScript
1.2 0.8 1.2115968 0.81013072 MAarrowhead1
% End of user PostScript
1 0 .177 r
.78529 .73791 m
.78655 .73962 L
s
% Start of user PostScript
1.2 1. 1.2053031 1.0072098 MAarrowhead1
% End of user PostScript
1 0 .112 r
.78529 .78546 m
.78597 .78662 L
s
% Start of user PostScript
1.2 1.2 1.2028473 1.2049055 MAarrowhead1
% End of user PostScript
1 0 .078 r
.78529 .83301 m
.78572 .83384 L
s
% Start of user PostScript
1.2 1.4 1.2017816 1.4035054 MAarrowhead1
% End of user PostScript
1 0 .058 r
.78529 .88055 m
.78559 .88118 L
s
% Start of user PostScript
1.2 1.6 1.2012412 1.6026445 MAarrowhead1
% End of user PostScript
1 0 .045 r
.78529 .9281 m
.78551 .9286 L
s
% Start of user PostScript
1.2 1.8 1.2009268 1.8020857 MAarrowhead1
% End of user PostScript
1 0 .037 r
.78529 .97565 m
.78547 .97606 L
s
% Start of user PostScript
1.2 2. 1.2007232 2.0017018 MAarrowhead1
% End of user PostScript
1 0 .031 r
.83284 .02468 m
.83309 .02439 L
s
% Start of user PostScript
1.4 -2. 1.401051 -2.0011809 MAarrowhead1
% End of user PostScript
1 0 .035 r
.83284 .07222 m
.83314 .07193 L
s
% Start of user PostScript
1.4 -1.8 1.4012692 -1.8012464 MAarrowhead1
% End of user PostScript
1 0 .039 r
.83284 .11977 m
.8332 .11947 L
s
% Start of user PostScript
1.4 -1.6 1.4015097 -1.6012853 MAarrowhead1
% End of user PostScript
1 0 .043 r
.83284 .16732 m
.83326 .16701 L
s
% Start of user PostScript
1.4 -1.4 1.4017542 -1.4012933 MAarrowhead1
% End of user PostScript
1 0 .047 r
.83284 .21487 m
.83331 .21457 L
s
% Start of user PostScript
1.4 -1.2 1.4019794 -1.2012811 MAarrowhead1
% End of user PostScript
1 0 .05 r
.83284 .26242 m
.83336 .26211 L
s
% Start of user PostScript
1.4 -1. 1.4021701 -1.0012823 MAarrowhead1
% End of user PostScript
1 0 .054 r
.83284 .30997 m
.8334 .30965 L
s
% Start of user PostScript
1.4 -0.8 1.4023396 -0.8013517 MAarrowhead1
% End of user PostScript
1 0 .059 r
.83284 .35752 m
.83345 .35715 L
s
% Start of user PostScript
1.4 -0.6 1.4025493 -0.60155396 MAarrowhead1
% End of user PostScript
1 0 .07 r
.83284 .40507 m
.83354 .4046 L
s
% Start of user PostScript
1.4 -0.4 1.4029257 -0.4019466 MAarrowhead1
% End of user PostScript
1 0 .089 r
.83284 .45262 m
.83372 .45201 L
s
% Start of user PostScript
1.4 -0.2 1.4036951 -0.20254923 MAarrowhead1
% End of user PostScript
1 0 .122 r
.83284 .50016 m
.83409 .4994 L
s
% Start of user PostScript
1.4 0. 1.4052293 -0.0032200954 MAarrowhead1
% End of user PostScript
1 0 .169 r
.83284 .54771 m
.83471 .54693 L
s
% Start of user PostScript
1.4 0.2 1.407863 0.19672672 MAarrowhead1
% End of user PostScript
1 0 .212 r
.83284 .59526 m
.83537 .59495 L
s
% Start of user PostScript
1.4 0.4 1.4106435 0.39870183 MAarrowhead1
% End of user PostScript
1 0 .214 r
.83284 .64281 m
.83535 .64336 L
s
% Start of user PostScript
1.4 0.6 1.4105438 0.60229467 MAarrowhead1
% End of user PostScript
1 0 .172 r
.83284 .69036 m
.83464 .69137 L
s
% Start of user PostScript
1.4 0.8 1.4075607 0.80425922 MAarrowhead1
% End of user PostScript
1 0 .125 r
.83284 .73791 m
.83396 .7389 L
s
% Start of user PostScript
1.4 1. 1.4047159 1.0041791 MAarrowhead1
% End of user PostScript
1 0 .09 r
.83284 .78546 m
.83355 .78628 L
s
% Start of user PostScript
1.4 1.2 1.4029626 1.2034538 MAarrowhead1
% End of user PostScript
1 0 .067 r
.83284 .83301 m
.83331 .83366 L
s
% Start of user PostScript
1.4 1.4 1.4019751 1.4027558 MAarrowhead1
% End of user PostScript
1 0 .052 r
.83284 .88055 m
.83318 .88108 L
s
% Start of user PostScript
1.4 1.6 1.4014026 1.6022163 MAarrowhead1
% End of user PostScript
1 0 .042 r
.83284 .9281 m
.83309 .92854 L
s
% Start of user PostScript
1.4 1.8 1.4010488 1.801817 MAarrowhead1
% End of user PostScript
1 0 .034 r
.83284 .97565 m
.83304 .97601 L
s
% Start of user PostScript
1.4 2. 1.4008152 2.0015198 MAarrowhead1
% End of user PostScript
1 0 .028 r
.88039 .02468 m
.88062 .02444 L
s
% Start of user PostScript
1.6 -2. 1.6009671 -2.0009996 MAarrowhead1
% End of user PostScript
1 0 .031 r
.88039 .07222 m
.88066 .07198 L
s
% Start of user PostScript
1.6 -1.8 1.6011375 -1.8010433 MAarrowhead1
% End of user PostScript
1 0 .034 r
.88039 .11977 m
.8807 .11952 L
s
% Start of user PostScript
1.6 -1.6 1.6013212 -1.601071 MAarrowhead1
% End of user PostScript
1 0 .037 r
.88039 .16732 m
.88075 .16706 L
s
% Start of user PostScript
1.6 -1.4 1.6015089 -1.401083 MAarrowhead1
% End of user PostScript
1 0 .04 r
.88039 .21487 m
.88079 .21461 L
s
% Start of user PostScript
1.6 -1.2 1.6016921 -1.201088 MAarrowhead1
% End of user PostScript
1 0 .043 r
.88039 .26242 m
.88084 .26216 L
s
% Start of user PostScript
1.6 -1. 1.6018695 -1.0011045 MAarrowhead1
% End of user PostScript
1 0 .047 r
.88039 .30997 m
.88088 .30969 L
s
% Start of user PostScript
1.6 -0.8 1.6020571 -0.80115776 MAarrowhead1
% End of user PostScript
1 0 .052 r
.88039 .35752 m
.88094 .35722 L
s
% Start of user PostScript
1.6 -0.6 1.6022962 -0.60127084 MAarrowhead1
% End of user PostScript
1 0 .06 r
.88039 .40507 m
.88102 .40472 L
s
% Start of user PostScript
1.6 -0.4 1.6026589 -0.40144813 MAarrowhead1
% End of user PostScript
1 0 .072 r
.88039 .45262 m
.88116 .45222 L
s
% Start of user PostScript
1.6 -0.2 1.6032443 -0.20164519 MAarrowhead1
% End of user PostScript
1 0 .089 r
.88039 .50016 m
.88137 .49976 L
s
% Start of user PostScript
1.6 0. 1.6041392 -0.0017130846 MAarrowhead1
% End of user PostScript
1 0 .108 r
.88039 .54771 m
.88164 .54739 L
s
% Start of user PostScript
1.6 0.2 1.6052662 0.19864595 MAarrowhead1
% End of user PostScript
1 0 .122 r
.88039 .59526 m
.88185 .59519 L
s
% Start of user PostScript
1.6 0.4 1.6061369 0.39969265 MAarrowhead1
% End of user PostScript
.88039 .64281 m
.88183 .64308 L
s
% Start of user PostScript
1.6 0.6 1.6060554 0.60112261 MAarrowhead1
% End of user PostScript
1 0 .108 r
.88039 .69036 m
.88158 .69087 L
s
% Start of user PostScript
1.6 0.8 1.6050207 0.80215515 MAarrowhead1
% End of user PostScript
1 0 .089 r
.88039 .73791 m
.88128 .7385 L
s
% Start of user PostScript
1.6 1. 1.6037284 1.0024827 MAarrowhead1
% End of user PostScript
1 0 .071 r
.88039 .78546 m
.88103 .78602 L
s
% Start of user PostScript
1.6 1.2 1.6026697 1.2023606 MAarrowhead1
% End of user PostScript
1 0 .056 r
.88039 .83301 m
.88085 .8335 L
s
% Start of user PostScript
1.6 1.4 1.6019293 1.4020809 MAarrowhead1
% End of user PostScript
1 0 .045 r
.88039 .88055 m
.88073 .88098 L
s
% Start of user PostScript
1.6 1.6 1.6014332 1.6017895 MAarrowhead1
% End of user PostScript
1 0 .037 r
.88039 .9281 m
.88065 .92847 L
s
% Start of user PostScript
1.6 1.8 1.6010978 1.8015346 MAarrowhead1
% End of user PostScript
1 0 .031 r
.88039 .97565 m
.8806 .97597 L
s
% Start of user PostScript
1.6 2. 1.6008643 2.0013238 MAarrowhead1
% End of user PostScript
1 0 .024 r
.92794 .02468 m
.92815 .02447 L
s
% Start of user PostScript
1.8 -2. 1.8008903 -2.000854 MAarrowhead1
% End of user PostScript
1 0 .027 r
.92794 .07222 m
.92818 .07201 L
s
% Start of user PostScript
1.8 -1.8 1.8010274 -1.800884 MAarrowhead1
% End of user PostScript
1 0 .029 r
.92794 .11977 m
.92822 .11956 L
s
% Start of user PostScript
1.8 -1.6 1.801174 -1.6009036 MAarrowhead1
% End of user PostScript
1 0 .032 r
.92794 .16732 m
.92825 .1671 L
s
% Start of user PostScript
1.8 -1.4 1.8013258 -1.400914 MAarrowhead1
% End of user PostScript
1 0 .035 r
.92794 .21487 m
.92829 .21465 L
s
% Start of user PostScript
1.8 -1.2 1.8014804 -1.2009204 MAarrowhead1
% End of user PostScript
1 0 .037 r
.92794 .26242 m
.92833 .2622 L
s
% Start of user PostScript
1.8 -1. 1.8016405 -1.0009316 MAarrowhead1
% End of user PostScript
1 0 .041 r
.92794 .30997 m
.92837 .30974 L
s
% Start of user PostScript
1.8 -0.8 1.8018181 -0.80095692 MAarrowhead1
% End of user PostScript
1 0 .045 r
.92794 .35752 m
.92842 .35728 L
s
% Start of user PostScript
1.8 -0.6 1.802037 -0.60100009 MAarrowhead1
% End of user PostScript
1 0 .051 r
.92794 .40507 m
.92849 .40482 L
s
% Start of user PostScript
1.8 -0.4 1.8023304 -0.4010486 MAarrowhead1
% End of user PostScript
1 0 .058 r
.92794 .45262 m
.92859 .45236 L
s
% Start of user PostScript
1.8 -0.2 1.8027297 -0.20106 MAarrowhead1
% End of user PostScript
1 0 .067 r
.92794 .50016 m
.92871 .49994 L
s
% Start of user PostScript
1.8 0. 1.8032327 -0.00095101395 MAarrowhead1
% End of user PostScript
1 0 .075 r
.92794 .54771 m
.92883 .54757 L
s
% Start of user PostScript
1.8 0.2 1.8037496 0.19938292 MAarrowhead1
% End of user PostScript
1 0 .081 r
.92794 .59526 m
.92891 .59526 L
s
% Start of user PostScript
1.8 0.4 1.8040768 0.39997741 MAarrowhead1
% End of user PostScript
.92794 .64281 m
.92889 .64297 L
s
% Start of user PostScript
1.8 0.6 1.8040109 0.60069081 MAarrowhead1
% End of user PostScript
1 0 .075 r
.92794 .69036 m
.92878 .69066 L
s
% Start of user PostScript
1.8 0.8 1.8035523 0.80127105 MAarrowhead1
% End of user PostScript
1 0 .065 r
.92794 .73791 m
.92863 .73828 L
s
% Start of user PostScript
1.8 1. 1.8029058 1.001575 MAarrowhead1
% End of user PostScript
1 0 .056 r
.92794 .78546 m
.92848 .78585 L
s
% Start of user PostScript
1.8 1.2 1.8022782 1.2016359 MAarrowhead1
% End of user PostScript
1 0 .047 r
.92794 .83301 m
.92836 .83338 L
s
% Start of user PostScript
1.8 1.4 1.8017649 1.4015563 MAarrowhead1
% End of user PostScript
1 0 .039 r
.92794 .88055 m
.92827 .88089 L
s
% Start of user PostScript
1.8 1.6 1.8013757 1.6014196 MAarrowhead1
% End of user PostScript
1 0 .033 r
.92794 .9281 m
.9282 .92841 L
s
% Start of user PostScript
1.8 1.8 1.8010879 1.8012717 MAarrowhead1
% End of user PostScript
1 0 .028 r
.92794 .97565 m
.92815 .97592 L
s
% Start of user PostScript
1.8 2. 1.8008746 2.0011328 MAarrowhead1
% End of user PostScript
1 0 .022 r
.97549 .02468 m
.97568 .0245 L
s
% Start of user PostScript
2. -2. 2.000821 -2.0007347 MAarrowhead1
% End of user PostScript
1 0 .024 r
.97549 .07222 m
.97571 .07204 L
s
% Start of user PostScript
2. -1.8 2.0009339 -1.8007549 MAarrowhead1
% End of user PostScript
1 0 .026 r
.97549 .11977 m
.97574 .11959 L
s
% Start of user PostScript
2. -1.6 2.0010543 -1.6007676 MAarrowhead1
% End of user PostScript
1 0 .028 r
.97549 .16732 m
.97577 .16714 L
s
% Start of user PostScript
2. -1.4 2.0011804 -1.4007735 MAarrowhead1
% End of user PostScript
1 0 .03 r
.97549 .21487 m
.9758 .21469 L
s
% Start of user PostScript
2. -1.2 2.0013118 -1.200775 MAarrowhead1
% End of user PostScript
1 0 .033 r
.97549 .26242 m
.97583 .26224 L
s
% Start of user PostScript
2. -1. 2.0014514 -1.0007754 MAarrowhead1
% End of user PostScript
1 0 .035 r
.97549 .30997 m
.97587 .30978 L
s
% Start of user PostScript
2. -0.8 2.0016063 -0.80077652 MAarrowhead1
% End of user PostScript
1 0 .039 r
.97549 .35752 m
.97591 .35733 L
s
% Start of user PostScript
2. -0.6 2.0017879 -0.60077519 MAarrowhead1
% End of user PostScript
1 0 .043 r
.97549 .40507 m
.97597 .40489 L
s
% Start of user PostScript
2. -0.4 2.0020084 -0.40075813 MAarrowhead1
% End of user PostScript
1 0 .047 r
.97549 .45262 m
.97603 .45245 L
s
% Start of user PostScript
2. -0.2 2.0022719 -0.20069807 MAarrowhead1
% End of user PostScript
1 0 .052 r
.97549 .50016 m
.9761 .50003 L
s
% Start of user PostScript
2. 0. 2.0025597 -0.00055599275 MAarrowhead1
% End of user PostScript
1 0 .056 r
.97549 .54771 m
.97616 .54764 L
s
% Start of user PostScript
2. 0.2 2.0028153 0.19970168 MAarrowhead1
% End of user PostScript
1 0 .058 r
.97549 .59526 m
.97619 .59528 L
s
% Start of user PostScript
2. 0.4 2.0029522 0.4000695 MAarrowhead1
% End of user PostScript
.97549 .64281 m
.97618 .64292 L
s
% Start of user PostScript
2. 0.6 2.0028993 0.60048048 MAarrowhead1
% End of user PostScript
1 0 .055 r
.97549 .69036 m
.97612 .69056 L
s
% Start of user PostScript
2. 0.8 2.0026574 0.80083544 MAarrowhead1
% End of user PostScript
1 0 .05 r
.97549 .73791 m
.97604 .73816 L
s
% Start of user PostScript
2. 1. 2.0022997 1.0010669 MAarrowhead1
% End of user PostScript
1 0 .044 r
.97549 .78546 m
.97594 .78573 L
s
% Start of user PostScript
2. 1.2 2.0019157 1.2011685 MAarrowhead1
% End of user PostScript
1 0 .039 r
.97549 .83301 m
.97586 .83328 L
s
% Start of user PostScript
2. 1.4 2.0015657 1.4011736 MAarrowhead1
% End of user PostScript
1 0 .034 r
.97549 .88055 m
.97579 .88082 L
s
% Start of user PostScript
2. 1.6 2.0012735 1.6011222 MAarrowhead1
% End of user PostScript
1 0 .029 r
.97549 .9281 m
.97574 .92835 L
s
% Start of user PostScript
2. 1.8 2.0010397 1.8010447 MAarrowhead1
% End of user PostScript
1 0 .025 r
.97549 .97565 m
.97569 .97588 L
s
% Start of user PostScript
2. 2. 2.0008558 2.0009593 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 .99993 L
0 .99993 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{575.75, 575.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008o0002?b000`400?l00000o`00003ooooonf[o
oookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z
003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oo
oo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX0
0?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJR3ooo]Z00?oo`0BoookJ_oonfX0
oooonfXNoookJP003OoonfX3ool01AWooo]Z0ooo00HHoookJP;oo`076OoonfX2ool01a[ooo]Z0_oo
00TIoookJP;oo`0:6OoonfX2ool031[ooo]Z00?oo`0>oookJ_oonfX06?oonfX00ooo013ooo]Zoook
JP0HoookJP;oo`0A6_oonfX00ooo01;ooo]ZoookJP0HoookJP03ool04Ooonf[ooo]Z01Wooo]Z00?o
o`0@oookJ_oonfX06?oonfX00ooo00kooo]ZoookJP0GoookJP;oo`0<6_oonfX2ool02QWooo]Z0_oo
00TIoookJP;oo`076_oonfX2ool01aSooo]Z0ooo00HHoookJP?oo`053_oonfX000oooo]Z1Ooo00DG
oookJPGoo`065?oonfX4ool01aOooo]Z1?oo00LHoookJP?oo`096?oonfX3ool02QSooo]Z0ooo00`I
oookJP;oo`0>6OoonfX00ooo013ooo]ZoookJP0HoookJP03ool04Ooonf[ooo]Z01Wooo]Z00?oo`0B
oookJ_oonfX06?oonfX00ooo017ooo]ZoookJP0IoookJP03ool04?oonf[ooo]Z01Oooo]Z0_oo00hH
oookJP?oo`0<6OoonfX3ool02QSooo]Z0ooo00TGoookJPCoo`075ooonfX5ool01aCooo]Z1Ooo00HF
oookJPGoo`054?oonfX0013ooo]Z2?oo00DDoookJPOoo`064_oonfX4ool01aOooo]Z1Ooo00LGoook
JP?oo`096?oonfX3ool02QSooo]Z1?oo00`GoookJP?oo`0>6?oonfX2ool041Wooo]Z0_oo014Ioook
JP?oo`0B6?oonfX2ool04A[ooo]Z0_oo010HoookJP?oo`0>5ooonfX3ool031Wooo]Z0ooo00XHoook
JP?oo`095ooonfX4ool01aGooo]Z1ooo00LAoookJPSoo`065?oonfX7ool01A7ooo]Z000AoookJPWo
o`054ooonfX8ool01Q7ooo]Z1Ooo00LFoookJPGoo`075_oonfX4ool02AOooo]Z1?oo00XGoookJPGo
o`0<5ooonfX3ool03QOooo]Z0ooo010HoookJP;oo`0A6OoonfX3ool04QSooo]Z0_oo014IoookJP?o
o`0@5ooonfX3ool03QKooo]Z1Ooo00`HoookJPCoo`0:5ooonfX4ool02AGooo]Z1Ooo00LCoookJPWo
o`074?oonfX9ool01Q?ooo]Z2?oo00DBoookJP004_oonfX8ool01ACooo]Z1ooo00HAoookJPOoo`07
5?oonfX7ool01aCooo]Z1Ooo00TFoookJPGoo`0:5ooonfX5ool031Kooo]Z1?oo00hFoookJP?oo`0@
6?oonfX3ool04ASooo]Z0ooo018HoookJP;oo`0A6OoonfX3ool041Kooo]Z1?oo00hEoookJPKoo`0<
5ooonfX5ool02QKooo]Z1Ooo00TCoookJPOoo`074OoonfX:ool01a7ooo]Z2?oo00HDoookJPOoo`05
4ooonfX001?ooo]Z1_oo00DFoookJPGoo`064ooonfX7ool01aCooo]Z2?oo00LCoookJPGoo`095_oo
nfX5ool02QKooo]Z1ooo00`DoookJPGoo`0>5OoonfX4ool041Oooo]Z0ooo014HoookJP?oo`0B5ooo
nfX3ool04ASooo]Z1?oo010EoookJPGoo`0>5?oonfX6ool031Oooo]Z1Ooo00XFoookJPGoo`094ooo
nfX7ool01a;ooo]Z2Ooo00LCoookJPKoo`065_oonfX5ool01ACooo]Z000DoookJPCoo`056?oonfX4
ool01Q?ooo]Z2?oo00LDoookJPSoo`074_oonfX6ool02AGooo]Z1_oo00XFoookJPOoo`0<5?oonfX5
ool03QGooo]Z0ooo010FoookJPGoo`0A5_oonfX5ool04QKooo]Z1?oo014FoookJPCoo`0@5OoonfX5
ool03QCooo]Z1ooo00`FoookJPKoo`0:5OoonfX6ool02A;ooo]Z2?oo00LCoookJPOoo`075OoonfX4
ool01QOooo]Z1?oo00DEoookJP005OoonfX3ool01AWooo]Z0ooo00HDoookJPKoo`075_oonfX6ool0
1a?ooo]Z1ooo00TDoookJPOoo`0:5OoonfX8ool031?ooo]Z1_oo00hDoookJPCoo`0@5OoonfX5ool0
4AKooo]Z1Ooo018FoookJPCoo`0A5OoonfX5ool041Cooo]Z1_oo00hCoookJPSoo`0<5OoonfX7ool0
2QCooo]Z1ooo00TCoookJPKoo`075OoonfX5ool01aKooo]Z0ooo00HHoookJP?oo`055_oonfX001Ko
oo]Z00?oo`05oookJ_oonfX06OoonfX00ooo00Kooo]ZoookJP0DoookJPCoo`075ooonfX5ool01aGo
oo]Z1ooo00TDoookJPOoo`0:5?oonfX6ool031Gooo]Z1ooo00hCoookJPGoo`0@5?oonfX5ool04AKo
oo]Z1Ooo018EoookJPGoo`0A5OoonfX5ool041?ooo]Z1ooo00hEoookJPGoo`0<5OoonfX7ool02QCo
oo]Z1ooo00TEoookJPCoo`075ooonfX3ool01aSooo]Z00?oo`06oookJ_oonfX06?oonfX00ooo00Go
oo]ZoookJP0EoookJP00BOoonfX3ool01aWooo]Z0ooo00LFoookJPGoo`095_oonfX5ool02QOooo]Z
1?oo00`FoookJPGoo`0>5OoonfX5ool041Cooo]Z1_oo014EoookJPGoo`0B5OoonfX5ool04ACooo]Z
1_oo010EoookJPGoo`0>5_oonfX4ool031Oooo]Z1Ooo00XFoookJPGoo`095_oonfX3ool01aSooo]Z
00?oo`07oookJ_oonfX0B_oonfX004[ooo]Z00?oo`07oookJ_oonfX06OoonfX00ooo00Oooo]Zoook
JP0EoookJP?oo`096?oonfX3ool02QWooo]Z0ooo00`HoookJP;oo`0>5ooonfX6ool041?ooo]Z1_oo
014DoookJPOoo`0B5?oonfX5ool04A?ooo]Z1ooo010GoookJP;oo`0>6?oonfX3ool031Wooo]Z0ooo
00XHoookJP?oo`095ooonfX00ooo00Oooo]ZoookJP1ToookJP00OooonfX00ooo00Wooo]ZoookJP0H
oookJP03ool02_oonf[ooo]Z01Wooo]Z00?oo`0<oookJ_oonfX05ooonfX00ooo00kooo]ZoookJP0F
oookJP?oo`0@5_oonfX7ool04A?ooo]Z1ooo018CoookJPKoo`0A5ooonfX3ool041Sooo]Z00?oo`0>
oookJ_oonfX05ooonfX00ooo00cooo]ZoookJP0IoookJP03ool02_oonf[ooo]Z01Sooo]Z00?oo`09
oookJ_oonfX0OOoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z
@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oo
oo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1
oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooo
nf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX000gooo]Z0_oo00HJoookJP;oo`066OoonfX2ool0
1aWooo]Z0_oo00PJoookJP;oo`0:6OoonfX2ool031Wooo]Z0_oo00lJoookJP03ool04_oonf[ooo]Z
01Sooo]Z00?oo`0FoookJ_oonfX06?oonfX2ool06A[ooo]Z00?oo`0KoookJ_oonfX06?oonfX00ooo
01Wooo]ZoookJP0IoookJP03ool05_oonf[ooo]Z01Sooo]Z00?oo`0BoookJ_oonfX06?oonfX00ooo
00oooo]ZoookJP0HoookJP;oo`0<6OoonfX2ool02QWooo]Z0_oo00PJoookJP;oo`076OoonfX2ool0
1QWooo]Z0_oo00H>oookJP003OoonfX4ool01QSooo]Z1?oo00HGoookJPCoo`075ooonfX4ool021So
oo]Z0ooo00XHoookJP?oo`0<6?oonfX3ool03aWooo]Z0_oo018IoookJP03ool05_oonf[ooo]Z01So
oo]Z00?oo`0IoookJ_oonfX06OoonfX00ooo01_ooo]ZoookJP0HoookJP03ool06Ooonf[ooo]Z01Wo
oo]Z00?oo`0FoookJ_oonfX05ooonfX2ool04QWooo]Z0_oo00lIoookJP?oo`0<6?oonfX3ool02QOo
oo]Z1?oo00PHoookJPCoo`075ooonfX4ool01QOooo]Z1?oo00H>oookJP003_oonfX5ool01QOooo]Z
1?oo00HGoookJPCoo`075ooonfX5ool021Oooo]Z0ooo00XHoookJP?oo`0<6?oonfX3ool03aSooo]Z
0ooo018HoookJP;oo`0F6OoonfX2ool06A[ooo]Z00?oo`0KoookJ_oonfX05ooonfX2ool06A[ooo]Z
0_oo01HHoookJP?oo`0B6?oonfX2ool03aWooo]Z0ooo00`HoookJP?oo`0:5ooonfX4ool021Oooo]Z
1Ooo00LGoookJPCoo`065ooonfX4ool01Poooo]Z000?oookJPGoo`065ooonfX5ool01QKooo]Z1Ooo
00LFoookJPGoo`085_oonfX4ool02QOooo]Z1?oo00`GoookJPCoo`0?6?oonfX3ool04QOooo]Z0ooo
01HHoookJP;oo`0I6OoonfX3ool06aSooo]Z0_oo01TIoookJP?oo`0F5ooonfX3ool04QSooo]Z0ooo
00lHoookJPCoo`0<5ooonfX4ool02QGooo]Z1Ooo00PGoookJPGoo`075_oonfX5ool01QKooo]Z1Ooo
00H@oookJP003ooonfX7ool01QGooo]Z1ooo00HDoookJPOoo`075?oonfX7ool021Cooo]Z1Ooo00XG
oookJPCoo`0<5_oonfX5ool03aOooo]Z1?oo018GoookJP?oo`0F5ooonfX3ool06ASooo]Z0ooo01/G
oookJP?oo`0I6?oonfX3ool05QOooo]Z1?oo018GoookJPCoo`0?5_oonfX5ool031Oooo]Z1?oo00XD
oookJPOoo`085OoonfX7ool01aCooo]Z1ooo00HDoookJPOoo`064?oonfX0013ooo]Z2?oo00HDoook
JPOoo`065?oonfX7ool01aCooo]Z2?oo00PCoookJPGoo`0:5_oonfX5ool031Kooo]Z1Ooo00lFoook
JPGoo`0B5_oonfX4ool05QKooo]Z0ooo01THoookJP?oo`0K5ooonfX3ool06AOooo]Z1?oo01HFoook
JPGoo`0B5_oonfX4ool03aKooo]Z1_oo00`FoookJPGoo`0:4ooonfX7ool021Cooo]Z2?oo00LDoook
JPOoo`065?oonfX7ool01Q7ooo]Z000AoookJPSoo`064ooonfX8ool01Q?ooo]Z2?oo00LCoookJPWo
o`084_oonfX6ool02QKooo]Z1Ooo00`EoookJPKoo`0?5_oonfX5ool04QGooo]Z1?oo01HFoookJPCo
o`0I5_oonfX5ool06aGooo]Z1?oo01TFoookJPGoo`0F5OoonfX5ool04QKooo]Z1Ooo00lEoookJPKo
o`0<5_oonfX5ool02Q?ooo]Z2?oo00PCoookJPWoo`074ooonfX8ool01Q?ooo]Z2?oo00HAoookJP00
4_oonfX6ool01QGooo]Z1_oo00HEoookJPKoo`075OoonfX6ool021Cooo]Z1ooo00XEoookJPKoo`0<
5?oonfX7ool03aGooo]Z1_oo018DoookJPGoo`0F5OoonfX4ool06AKooo]Z1Ooo01/EoookJPGoo`0I
5?oonfX6ool05QCooo]Z1_oo018EoookJPKoo`0?5?oonfX7ool031Gooo]Z1_oo00XDoookJPKoo`08
5_oonfX6ool01aGooo]Z1_oo00HEoookJPKoo`064_oonfX001;ooo]Z1Ooo00HGoookJPCoo`065ooo
nfX4ool01aOooo]Z1?oo00PFoookJPOoo`0:5?oonfX7ool031Cooo]Z1ooo00lDoookJPOoo`0B4ooo
nfX6ool05QCooo]Z1Ooo01TEoookJPGoo`0K5?oonfX6ool06A?ooo]Z1ooo01HCoookJPOoo`0B5?oo
nfX6ool03aCooo]Z2?oo00`DoookJPOoo`0:5OoonfX4ool021Sooo]Z1?oo00LGoookJPCoo`065ooo
nfX4ool01Q?ooo]Z000CoookJP?oo`066?oonfX3ool01QSooo]Z0ooo00LHoookJP?oo`085ooonfX5
ool02QOooo]Z1?oo00`FoookJPGoo`0?5_oonfX5ool04QKooo]Z1_oo01HCoookJPGoo`0I5OoonfX5
ool06aCooo]Z1_oo01TBoookJPOoo`0F5_oonfX5ool04QKooo]Z1?oo00lFoookJPGoo`0<5ooonfX4
ool02QOooo]Z0ooo00PIoookJP?oo`076?oonfX3ool01QSooo]Z0ooo00HCoookJP005?oonfX00ooo
00Kooo]ZoookJP0HoookJP03ool01_oonf[ooo]Z01Sooo]Z00?oo`07oookJ_oonfX06?oonfX00ooo
00Sooo]ZoookJP0FoookJP?oo`0:6OoonfX3ool031Oooo]Z0ooo00lIoookJP;oo`0B6?oonfX4ool0
5QGooo]Z1_oo01TCoookJPOoo`0K4_oonfX7ool06AGooo]Z1?oo01HHoookJP;oo`0B6?oonfX3ool0
3aSooo]Z0ooo00`HoookJP?oo`0:6?oonfX00ooo00Sooo]ZoookJP0IoookJP03ool01ooonf[ooo]Z
01Sooo]Z00?oo`06oookJ_oonfX06?oonfX00ooo00Kooo]ZoookJP0BoookJP00OooonfX00ooo00[o
oo]ZoookJP0IoookJP03ool03?oonf[ooo]Z01Oooo]Z00?oo`0?oookJ_oonfX06?oonfX00ooo01;o
oo]ZoookJP0GoookJP03ool05_oonf[ooo]Z01Kooo]Z1?oo01TEoookJPOoo`0K5OoonfX4ool06ASo
oo]Z00?oo`0FoookJ_oonfX05ooonfX00ooo01;ooo]ZoookJP0GoookJP03ool03ooonf[ooo]Z01So
oo]Z00?oo`0<oookJ_oonfX06?oonfX00ooo00[ooo]ZoookJP1noookJP00oooonfX4oookJP03ool0
6Ooonf[ooo]Z03Gooo]Z00?oo`0IoookJ_oonfX0oooonfX2oookJP00oooonf[ooookJT7ooo]Z003o
oookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z
@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oo
oo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1
oookJP00oooonf[ooookJT7ooo]Z003ooookJR3ooo]Z00?oo`0]oookJ_oonfX0oooonfXNoookJP00
GooonfX2ool02A[ooo]Z0_oo00`IoookJP;oo`0>6OoonfX2ool04QWooo]Z0_oo01PJoookJP03ool0
8?oonf[ooo]Z01Sooo]Z00?oo`0YoookJ_oonfX06OoonfX00ooo02gooo]ZoookJP0IoookJP03ool0
:Ooonf[ooo]Z01Sooo]Z00?oo`0PoookJ_oonfX05ooonfX2ool061[ooo]Z0_oo018IoookJP;oo`0>
6OoonfX2ool031Wooo]Z0_oo00UPoookJP003OoonfX2ool01Q[ooo]Z0_oo00LIoookJP;oo`086Ooo
nfX3ool02AWooo]Z0ooo00`HoookJP?oo`0>6?oonfX4ool04QOooo]Z0ooo01PIoookJP;oo`0P6Ooo
nfX2ool0:A[ooo]Z00?oo`0]oookJ_oonfX06?oonfX2ool0:AWooo]Z0_oo020HoookJP?oo`0H6?oo
nfX4ool04QSooo]Z0ooo00hHoookJP?oo`0<6?oonfX3ool02A[ooo]Z0_oo00PIoookJP;oo`076Ooo
nfX2ool01Pkooo]Z000=oookJPCoo`066?oonfX4ool01aSooo]Z1?oo00PGoookJPCoo`096?oonfX4
ool031Oooo]Z1?oo00hGoookJPCoo`0B5ooonfX4ool061Oooo]Z0ooo020HoookJP;oo`0Y6OoonfX3
ool0;AWooo]Z0_oo02THoookJP?oo`0P5ooonfX3ool061Oooo]Z1Ooo018GoookJPCoo`0>5ooonfX4
ool031Oooo]Z1?oo00THoookJPCoo`086?oonfX4ool01aOooo]Z1?oo00H>oookJP003_oonfX5ool0
1QOooo]Z1?oo00LHoookJPKoo`085?oonfX6ool02AKooo]Z1Ooo00`FoookJPGoo`0>5ooonfX5ool0
4QGooo]Z1Ooo01PGoookJP?oo`0P5ooonfX3ool0:ASooo]Z0ooo02dHoookJP?oo`0Y5ooonfX3ool0
81Kooo]Z1Ooo01PFoookJPGoo`0B5ooonfX5ool03QKooo]Z1Ooo00`FoookJPGoo`095OoonfX6ool0
21Sooo]Z1?oo00LGoookJPCoo`063ooonfX000oooo]Z1Ooo00HGoookJPGoo`075ooonfX8ool021;o
oo]Z1_oo00TFoookJPGoo`0<5_oonfX5ool03QKooo]Z1ooo018DoookJPGoo`0H5_oonfX4ool081Ko
oo]Z0ooo02THoookJP?oo`0]6?oonfX3ool0:AKooo]Z1?oo020EoookJPGoo`0H5OoonfX7ool04QKo
oo]Z1Ooo00hFoookJPGoo`0<5_oonfX5ool02A?ooo]Z2?oo00PGoookJPGoo`075_oonfX5ool01Q3o
oo]Z000?oookJPOoo`065OoonfX7ool01aKooo]Z2?oo00PAoookJPSoo`095?oonfX7ool031Cooo]Z
1ooo00hEoookJPOoo`0B4ooonfX7ool061Cooo]Z1Ooo020EoookJPCoo`0Y5ooonfX3ool0;AOooo]Z
1?oo02TEoookJPGoo`0P5?oonfX6ool061?ooo]Z2?oo018EoookJPOoo`0>5?oonfX7ool031Cooo]Z
1ooo00TAoookJPWoo`085_oonfX7ool01aCooo]Z1ooo00H@oookJP004?oonfX8ool01QCooo]Z1ooo
00LFoookJPOoo`084_oonfX8ool02ACooo]Z1ooo00`DoookJPOoo`0>5?oonfX8ool04Q?ooo]Z1ooo
01PDoookJPGoo`0P5OoonfX3ool0:AKooo]Z1Ooo02dFoookJP?oo`0Y5OoonfX5ool081Cooo]Z1_oo
01PCoookJPSoo`0B5OoonfX7ool03QCooo]Z1ooo00`DoookJPOoo`094ooonfX7ool021Kooo]Z1ooo
00LDoookJPOoo`064OoonfX0017ooo]Z2?oo00HCoookJPSoo`075_oonfX5ool021Cooo]Z2?oo00TD
oookJPOoo`0<5?oonfX7ool03QCooo]Z1_oo018EoookJPOoo`0H4ooonfX6ool081Cooo]Z1?oo02TE
oookJPGoo`0]5OoonfX4ool0:ACooo]Z1_oo020CoookJPOoo`0H5?oonfX6ool04QGooo]Z1ooo00hD
oookJPOoo`0<5?oonfX7ool02AGooo]Z1Ooo00PFoookJPSoo`074ooonfX8ool01Q7ooo]Z000Boook
JPKoo`065OoonfX6ool01aSooo]Z0ooo00PEoookJPKoo`095_oonfX6ool031Gooo]Z1_oo00hFoook
JPCoo`0B5_oonfX6ool061Cooo]Z1ooo020CoookJPGoo`0Y5?oonfX5ool0;ACooo]Z1Ooo02TCoook
JPOoo`0P5?oonfX6ool061Gooo]Z1Ooo018FoookJPKoo`0>5OoonfX6ool031Gooo]Z1_oo00TFoook
JP?oo`086?oonfX6ool01aGooo]Z1_oo00HBoookJP004_oonfX5ool01QOooo]Z1?oo00LJoookJP03
ool02?oonf[ooo]Z01Gooo]Z1?oo00THoookJPCoo`0<5ooonfX4ool03QOooo]Z0ooo018HoookJPCo
o`0H5OoonfX5ool081Gooo]Z1Ooo02TDoookJPGoo`0]5?oonfX5ool0:AGooo]Z1Ooo020EoookJPCo
o`0H5ooonfX3ool04QSooo]Z1?oo00hGoookJPCoo`0<5ooonfX4ool02ASooo]Z00?oo`08oookJ_oo
nfX06?oonfX4ool01aOooo]Z1?oo00HCoookJP004ooonfX3ool01QSooo]Z0ooo00LcoookJP?oo`09
6OoonfX3ool031Sooo]Z0ooo00hIoookJP03ool04_oonf[ooo]Z01Oooo]Z0ooo01PGoookJP;oo`0P
5ooonfX6ool0:A;ooo]Z1ooo02dBoookJPKoo`0Y5ooonfX2ool081Oooo]Z0ooo01PHoookJP03ool0
4_oonf[ooo]Z01Sooo]Z0ooo00hHoookJP?oo`0<6?oonfX3ool02CCooo]Z0ooo00LHoookJP?oo`06
4ooonfX001Cooo]Z00?oo`06oookJ_oonfX06?oonfX00ooo00Oooo]ZoookJP0coookJP03ool02Ooo
nf[ooo]Z01Wooo]Z00?oo`0<oookJ_oonfX06?oonfX00ooo00kooo]ZoookJP0coookJP03ool06?oo
nf[ooo]Z01Kooo]Z00?oo`0PoookJ_oonfX05_oonfX3ool0:AGooo]Z1ooo02dFoookJP;oo`0Y6?oo
nfX00ooo023ooo]ZoookJP0FoookJP03ool06?oonf[ooo]Z03?ooo]Z00?oo`0>oookJ_oonfX06?oo
nfX00ooo00cooo]ZoookJP0HoookJP03ool02Ooonf[ooo]Z03Cooo]Z00?oo`07oookJ_oonfX06?oo
nfX00ooo00Kooo]ZoookJP0BoookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oo
oo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1
oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooo
nf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7o
oo]Z003ooookJR3ooo]Z00?oo`1QoookJ_oonfX0oooonfXNoookJP00oooonfX4oookJP03ool0C_oo
nf[ooo]Z01Wooo]Z00?oo`1QoookJ_oonfX06OoonfX00ooo04kooo]ZoookJP3ooookJP;ooo]Z003<
oookJP;oo`0P6OoonfX2ool0<Q[ooo]Z00?oo`1>oookJ_oonfX06OoonfX00ooo067ooo]ZoookJP0I
oookJP03ool0C_oonf[ooo]Z01Oooo]Z0_oo038JoookJP;oo`0Pc?oonfX000gooo]Z0_oo00LJoook
JP;oo`086OoonfX4ool02AOooo]Z0_oo00/JoookJP;oo`0=6OoonfX2ool041Wooo]Z0_oo01HIoook
JPCoo`0P5ooonfX3ool0<QWooo]Z0_oo04hIoookJP?oo`1Q6OoonfX2ool0CQSooo]Z0ooo038Hoook
JPCoo`0P6OoonfX2ool05QWooo]Z0_oo010HoookJP?oo`0=6OoonfX2ool02aSooo]Z1?oo00TIoook
JP;oo`086OoonfX2ool01`kooo]Z000=oookJPCoo`076?oonfX5ool021Sooo]Z2?oo00TAoookJPGo
o`0;5ooonfX5ool03AKooo]Z1?oo010GoookJPGoo`0F5ooonfX6ool081Gooo]Z1?oo038GoookJP?o
o`1>6?oonfX3ool0HASooo]Z0ooo04hGoookJP?oo`0b5_oonfX6ool081Oooo]Z1Ooo01HGoookJPCo
o`0@5?oonfX6ool03AOooo]Z1Ooo00/BoookJPSoo`096?oonfX5ool021Oooo]Z1?oo00L>oookJP00
3_oonfX5ool01aOooo]Z1ooo00PFoookJP[oo`093ooonfX7ool02aGooo]Z1ooo00dDoookJPKoo`0@
5OoonfX7ool05QGooo]Z1ooo020CoookJPGoo`0b5ooonfX3ool0CQOooo]Z0ooo064GoookJP?oo`1>
5_oonfX5ool0<QCooo]Z1ooo020EoookJPOoo`0F5OoonfX6ool041;ooo]Z2?oo00dEoookJPOoo`0;
4?oonfX:ool02AKooo]Z1ooo00PGoookJPCoo`073ooonfX000oooo]Z1Ooo00LGoookJPWoo`085?oo
nfX9ool02A3ooo]Z2Ooo00/CoookJPWoo`0=4_oonfX7ool041Cooo]Z2Ooo01HBoookJPWoo`0P4_oo
nfX5ool0<QKooo]Z1?oo04hFoookJP?oo`1Q5_oonfX4ool0CQGooo]Z1Ooo038CoookJPSoo`0P4ooo
nfX9ool05QCooo]Z1ooo010AoookJPWoo`0=4ooonfX9ool02a7ooo]Z2Ooo00TDoookJPWoo`085_oo
nfX5ool01a3ooo]Z000?oookJPOoo`075_oonfX9ool021Cooo]Z1ooo00TBoookJPWoo`0;4ooonfX9
ool03A;ooo]Z2?oo010CoookJPWoo`0F4_oonfX9ool0817ooo]Z1ooo038DoookJPCoo`1>5OoonfX5
ool0HAGooo]Z1?oo04hDoookJPKoo`0b4_oonfX8ool081?ooo]Z2Ooo01HCoookJPSoo`0@4_oonfX8
ool03A?ooo]Z2Ooo00/CoookJPOoo`095?oonfX9ool021Gooo]Z1ooo00L@oookJP004?oonfX8ool0
1aGooo]Z2?oo00PEoookJPKoo`094ooonfX8ool02aCooo]Z2?oo00dCoookJPSoo`0@4ooonfX8ool0
5Q?ooo]Z2?oo020BoookJPOoo`0b4ooonfX5ool0CQCooo]Z1Ooo064DoookJPGoo`1>4ooonfX6ool0
<Q?ooo]Z2?oo020CoookJPSoo`0F4ooonfX8ool041Cooo]Z1_oo00dDoookJPSoo`0;5?oonfX6ool0
2AGooo]Z2?oo00PEoookJPOoo`074OoonfX0017ooo]Z2?oo00LEoookJPKoo`085ooonfX4ool02AGo
oo]Z1_oo00/EoookJPOoo`0=5?oonfX7ool041Gooo]Z1_oo01HEoookJPKoo`0P5?oonfX7ool0<Q;o
oo]Z1_oo04hCoookJPGoo`1Q4ooonfX6ool0CQ;ooo]Z1ooo038DoookJPKoo`0P5OoonfX6ool05QGo
oo]Z1ooo010EoookJPCoo`0=5_oonfX7ool02aGooo]Z1?oo00TGoookJPKoo`085OoonfX8ool01a7o
oo]Z000BoookJPKoo`075ooonfX4ool021Wooo]Z0ooo00TFoookJPCoo`0;5ooonfX5ool03AKooo]Z
1Ooo010GoookJPCoo`0F5_oonfX5ool081Gooo]Z1_oo038CoookJPOoo`1>4_oonfX5ool0HA;ooo]Z
1ooo04hCoookJPKoo`0b5OoonfX4ool081Oooo]Z1?oo01HGoookJPGoo`0@5_oonfX3ool03ASooo]Z
1Ooo00/FoookJP?oo`096OoonfX4ool021Oooo]Z1_oo00LBoookJP004_oonfX5ool01aWooo]Z0ooo
00PJoookJP03ool02Ooonf[ooo]Z01Kooo]Z0ooo00/HoookJP?oo`0=6?oonfX3ool041Wooo]Z0ooo
01HGoookJP?oo`0P5ooonfX4ool0<QGooo]Z1?oo04hCoookJPOoo`1Q4ooonfX4ool0CQGooo]Z1?oo
038FoookJP?oo`0P6?oonfX3ool05QWooo]Z0ooo010HoookJP03ool03Ooonf[ooo]Z01Sooo]Z0ooo
00/HoookJP03ool02Ooonf[ooo]Z01Sooo]Z0ooo00PIoookJPCoo`074ooonfX001?ooo]Z0ooo00LK
oookJP03ool02?oonf[ooo]Z03?ooo]Z00?oo`0;oookJ_oonfX06?oonfX00ooo00gooo]ZoookJP0H
oookJP03ool04?oonf[ooo]Z01Wooo]Z00?oo`0FoookJ_oonfX05ooonfX00ooo023ooo]ZoookJP0F
oookJP?oo`0b5_oonfX2ool0CQGooo]Z1ooo064EoookJP;oo`1>5_oonfX3ool0<QOooo]Z00?oo`0P
oookJ_oonfX06?oonfX00ooo01Kooo]ZoookJP0IoookJP03ool04?oonf[ooo]Z03?ooo]Z00?oo`0;
oookJ_oonfX0<ooonfX00ooo00Sooo]ZoookJP0IoookJP?oo`074ooonfX001Cooo]Z00?oo`07oook
J_oonfX0e_oonfX00ooo03;ooo]ZoookJP0EoookJP03ool0C_oonf[ooo]Z037ooo]Z00?oo`1>oook
J_oonfX05OoonfX00ooo03;ooo]ZoookJP3FoookJP03ool01ooonf[ooo]Z01;ooo]Z003ooookJ_oo
oo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX0
0?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJR3ooo]Z00?oS03ooookJ_oonfX0
oooonfXNoookJP00oooonfXPoookJP03oh`0oooonf[ooo]Z0?oooo]Z7_oonfX00?oooo]Z8?oonfX0
0on<0?oooo]ZoookJP3ooookJQkooo]Z003ooookJQoooo]Z0on<0?oooookJQoooo]Z003ooookJQoo
oo]Z0on<0?oooookJQoooo]Z003ooookJQoooo]Z0on<0?oooookJQoooo]Z003ooookJQoooo]Z0on<
0?oooookJQoooo]Z003ooookJP7ooo]Z0_oo0;/KoookJPGoS03o6ooonfX2ool0^ooooo]Z0OoonfX0
0?oooo]Z0OoonfX4ool0^aWooo]Z1On<0?lIoookJPCoo`2koooonfX1oookJP00i_oonfX3ool0C1So
oo]Z1?oo0;/HoookJPGoS03o6?oonfX4ool0^aSooo]Z0_oo04cWoookJP003OoonfX7ool01aGooo]Z
0_oo00PIoookJP?oo`0:6?oonfX3ool031Wooo]Z0_oo00hIoookJP;oo`0B6OoonfX3ool06ASooo]Z
1?oo02PGoookJPGoo`1<5_oonfX5ool0^aKooo]Z1On<0?lFoookJPGoo`2k5_oonfX5ool0C1Oooo]Z
1?oo02PHoookJP?oo`0I6?oonfX3ool04QWooo]Z0_oo00hGoookJPCoo`0<6OoonfX3ool02QWooo]Z
0_oo00PEoookJPKoo`073_oonfX000oooo]Z2ooo00L?oookJPGoo`086?oonfX5ool02QKooo]Z1Ooo
00`EoookJPGoo`0>5_oonfX5ool04QSooo]Z1Ooo01TFoookJPOoo`0X4ooonfX7ool0C1?ooo]Z1ooo
0;/CoookJPOoS03o4ooonfX7ool0^a?ooo]Z1ooo04`BoookJPSoo`0X5_oonfX5ool06AKooo]Z1Ooo
018HoookJPGoo`0>4_oonfX7ool031Oooo]Z1Ooo00XHoookJPGoo`083ooonfX:ool01a3ooo]Z000@
oookJP[oo`074?oonfX7ool021Kooo]Z2?oo00XCoookJPSoo`0<4_oonfX7ool03QCooo]Z1ooo018F
oookJPSoo`0I4ooonfX9ool0:17ooo]Z2Ooo04`AoookJPOoo`2k4_oonfX7oh`0oa;ooo]Z1ooo0;/A
oookJPWoo`1<4?oonfX:ool0:1?ooo]Z2?oo01TDoookJPOoo`0B5_oonfX7ool03Q3ooo]Z2Ooo00`D
oookJPSoo`0:5_oonfX7ool0213ooo]Z2Ooo00LAoookJP004_oonfX7ool01a;ooo]Z2Ooo00PDoook
JPWoo`0:4_oonfX9ool0317ooo]Z2Ooo00hBoookJPWoo`0B5?oonfX9ool06A;ooo]Z2?oo02PBoook
JPWoo`1<4?oonfX8ool0^bWooo]Z2?oo0;/@oookJPWoo`1<4OoonfX9ool0:1;ooo]Z2Ooo01TCoook
JPSoo`0B5?oonfX9ool03Q7ooo]Z2?oo00`CoookJPWoo`0:5?oonfX9ool0217ooo]Z1ooo00LCoook
JP004ooonfX6ool01a?ooo]Z2Ooo00PDoookJPSoo`0:4ooonfX8ool031;ooo]Z2Ooo00hBoookJPWo
o`0B5?oonfX8ool06A?ooo]Z1_oo02PDoookJPSoo`1<4OoonfX6ool0^b_ooo]Z1_oo0;/AoookJPSo
o`1<4ooonfX7ool0:1?ooo]Z2?oo01TDoookJPOoo`0B5?oonfX9ool03Q?ooo]Z1Ooo00`EoookJPSo
o`0:5?oonfX9ool021;ooo]Z1_oo00LDoookJP005?oonfX5ool01aCooo]Z2?oo00PEoookJPKoo`0:
5OoonfX6ool031Cooo]Z2?oo00hCoookJPSoo`0B5OoonfX6ool06AGooo]Z1Ooo02PEoookJPKoo`1<
4ooonfX4ool0^bgooo]Z1?oo0;/CoookJPKoo`1<5?oonfX6ool0:1Gooo]Z1_oo01TFoookJPGoo`0B
5OoonfX8ool03QCooo]Z1?oo00`GoookJPKoo`0:5OoonfX8ool021Cooo]Z1?oo00LEoookJP005_oo
nfX2ool01aKooo]Z1_oo00PGoookJPCoo`0:5ooonfX4ool031Kooo]Z1_oo00hEoookJPKoo`0B5ooo
nfX4ool06AOooo]Z1?oo02PFoookJPCoo`1<5?oonfX3ool0^boooo]Z0ooo0;/DoookJPCoo`1<5_oo
nfX4ool0:1Oooo]Z1?oo01TGoookJPCoo`0B5ooonfX6ool03QGooo]Z0ooo00`IoookJPCoo`0:5ooo
nfX6ool021Gooo]Z0_oo00LGoookJP005ooonfX00ooo00Oooo]ZoookJP0EoookJPCoo`086OoonfX3
ool02QSooo]Z0ooo00`GoookJPCoo`0>5ooonfX4ool04QWooo]Z0ooo01THoookJP;oo`0X6?oonfX3
ool0C1Gooo]Z00?oo`2koookJ_oonfX0;ooonfX00ooo0;_ooo]ZoookJP0CoookJP?oo`1<5ooonfX3
ool0:1Sooo]Z0ooo01THoookJP?oo`0B6OoonfX4ool03QOooo]Z00?oo`0<oookJ_oonfX06?oonfX3
ool02QWooo]Z1?oo00PFoookJP03ool01ooonf[ooo]Z01Kooo]Z000`oookJP?oo`086_oonfX00ooo
00[ooo]ZoookJP0HoookJP03ool03?oonf[ooo]Z01Oooo]Z0ooo00hHoookJP?oo`0B6_oonfX00ooo
01Wooo]ZoookJP0HoookJP03ool0:?oonf[ooo]Z01Oooo]Z00?oo`1<oookJ_oonfX0GOoonfX00ooo
04cooo]ZoookJP0GoookJP03ool0:?oonf[ooo]Z01Sooo]Z00?oo`0IoookJ_oonfX06?oonfX00ooo
01;ooo]ZoookJP0HoookJP?oo`0>=?oonfX00ooo00[ooo]ZoookJP0HoookJP?oo`08<?oonfX0037o
oo]Z00?oo`08oookJ_oonfX0CooonfX00ooo00kooo]ZoookJP0HoookJP03ool04_oonf[ooo]Z0?oo
oo]Z6ooonfX00ooo00kooo]ZoookJP1?oookJP03ool02?oonf[ooo]Z02oooo]Z003ooookJ_oooo]Z
@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oo
oo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1
oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooo
nf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7o
oo]Z003ooookJP?ooo]Z1?nC0?lboookJPCoT`3ooooonfX4oookJP00k?oonfX6ool0G0_ooo]Z2OnC
0?lboookJP[oT`3o2_oonfX7ool0G>cooo]Z0014oookJP;oo`0;6OoonfX3ool031Wooo]Z0_oo00lI
oookJP;oo`0B6OoonfX4ool06QOooo]Z3Ooo02X=oookJPcoo`1L2?oonfX<oi<0oc;ooo]Z3OnC0?l7
oookJPgoo`1L3OoonfX=ool0:QOooo]Z1?oo01XIoookJP;oo`0B6OoonfX2ool03aWooo]Z0_oo00`J
oookJP;oo`0;A?oonfX000gooo]Z0ooo00PIoookJP;oo`096OoonfX4ool02aSooo]Z1Ooo00`Foook
JPGoo`0?5_oonfX5ool04QOooo]Z2Ooo01XBoookJPcoo`0Z3ooonfX:ool0G0[ooo]Z2_nC0?lboook
JP_oT`3o2OoonfX;ool0G0oooo]Z3?oo02XBoookJPWoo`0J5ooonfX5ool04QKooo]Z1Ooo00lFoook
JPGoo`0<5ooonfX4ool02a[ooo]Z0_oo00TIoookJP;oo`083_oonfX000kooo]Z1Ooo00PGoookJPCo
o`095ooonfX6ool02aKooo]Z1ooo00`DoookJPOoo`0?5?oonfX7ool04QKooo]Z2_oo01XBoookJPSo
o`0Z4ooonfX7ool0G0gooo]Z1onC0?lcoookJPOoT`3o3OoonfX7ool0G1;ooo]Z2Ooo02XBoookJP[o
o`0J5_oonfX6ool04QGooo]Z1ooo00lDoookJPOoo`0<5OoonfX6ool02aSooo]Z1?oo00TGoookJPCo
o`083ooonfX000oooo]Z1ooo00PEoookJPKoo`095OoonfX7ool02aGooo]Z2Ooo00`BoookJPWoo`0?
4_oonfX9ool04QGooo]Z2?oo01XCoookJPOoo`0Z5_oonfX4ool0G13ooo]Z1?nC0?lcoookJPCoT`3o
4?oonfX4ool0G1Gooo]Z1ooo02XDoookJPSoo`0J5OoonfX8ool04Q?ooo]Z2Ooo00lBoookJPWoo`0<
4ooonfX8ool02aKooo]Z1_oo00TEoookJPKoo`084?oonfX0013ooo]Z2Ooo00PCoookJPSoo`094_oo
nfX9ool02aCooo]Z2Ooo00`BoookJPWoo`0?4_oonfX9ool04QGooo]Z1_oo01XFoookJPGoo`0Z6Ooo
nfX00ooo05cooo]ZoookJP0AoookJP03oi<0oooonf[ooo]Z037ooo]Z00?oT`3ooookJ_oonfX04Ooo
nfX00ooo05cooo]ZoookJP0GoookJPGoo`0Z5_oonfX6ool06QGooo]Z2?oo018CoookJPWoo`0?4_oo
nfX9ool031;ooo]Z2Ooo00/DoookJPSoo`094ooonfX8ool0217ooo]Z000AoookJPWoo`084ooonfX8
ool02A;ooo]Z2Ooo00/DoookJPSoo`0<4ooonfX8ool03a?ooo]Z2?oo018FoookJPGoo`0J6?oonfX2
ool0:Y3ooo]Z0ooo02XHoookJPGoo`0J5_oonfX7ool04QCooo]Z2?oo00lCoookJPSoo`0<4ooonfX8
ool02aCooo]Z2?oo00TCoookJPSoo`084_oonfX001;ooo]Z1ooo00PEoookJPOoo`094ooonfX8ool0
2aGooo]Z1_oo00`DoookJPOoo`0?5OoonfX6ool04QWooo]Z0ooo01XIoookJP03ool0:_oonf[ooo]Z
08kooo]Z00?oo`0ZoookJ_oonfX06?oonfX3ool06QWooo]Z1Ooo018FoookJPKoo`0?5OoonfX6ool0
31Gooo]Z1_oo00/EoookJPOoo`095?oonfX7ool021?ooo]Z000CoookJPGoo`085ooonfX5ool02AGo
oo]Z1_oo00/GoookJPCoo`0<5_oonfX5ool03aOooo]Z1?oo018KoookJP03ool06_oonf[ooo]Z0<Go
oo]Z00?oo`0JoookJ_oonfX06?oonfX4ool04QSooo]Z1?oo00lGoookJPCoo`0<5ooonfX4ool02aOo
oo]Z1Ooo00TFoookJPGoo`085?oonfX001Cooo]Z0ooo00PIoookJP?oo`095_oonfX5ool02aWooo]Z
0ooo00`GoookJP?oo`0?6OoonfX3ool04_kooo]Z0ooo018IoookJP?oo`0?6?oonfX3ool031Sooo]Z
0ooo00/IoookJP?oo`096?oonfX3ool021Gooo]Z000EoookJP03ool02?oonf[ooo]Z01Wooo]Z00?o
o`09oookJ_oonfX05_oonfX3ool02a_ooo]Z00?oo`0<oookJ_oonfX05ooonfX00ooo00oooo]Zoook
JP0IoookJP03ool04_oonf[ooo]Z0?kooo]Z00?oo`0BoookJ_oonfX06OoonfX00ooo00oooo]Zoook
JP0HoookJP03ool03?oonf[ooo]Z01Sooo]Z00?oo`0;oookJ_oonfX06OoonfX00ooo00Wooo]Zoook
JP0HoookJP03ool02?oonf[ooo]Z01Cooo]Z001;oookJP03ool02ooonf[ooo]Z0?oooo]Zl_oonfX0
0?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]Zoooo
nfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00
oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonfX8oook
JP03ool0[ooonf[ooo]Z02gooo]Z00?oo`2_oookJ_oonfX0oooonfX6oookJP00l?oonfX2ool0AAGo
oo]Z00?oo`2_oookJ_oonfX0;?oonfX2ool0[aGooo]Z0_oo04G`oookJP00kooonfX3ool0AACooo]Z
0ooo0:l/oookJPCoo`2_5?oonfX3ool0ANoooo]Z003]oookJPGoo`154ooonfX5ool0[b[ooo]Z1_oo
0:lBoookJPKoo`15kOoonfX00=Gooo]Z0ooo02<CoookJPOoo`154ooonfX6ool0[bSooo]Z1ooo0:lB
oookJPOoo`154ooonfX3ool08mKooo]Z003AoookJPOoo`0S4_oonfX9ool0AA7ooo]Z1Ooo0:lCoook
JPOoW@3o4_oonfX6ool0[a7ooo]Z2?oo04DBoookJPOoo`0Sd_oonfX00;Oooo]Z1ooo01L@oookJP[o
o`0S4?oonfX;ool0AA3ooo]Z1?oo0:lEoookJPOoW@3o5?oonfX5ool0[`oooo]Z2ooo04D@oookJP_o
o`0S4?oonfX7ool05kOooo]Z000=oookJP?oo`086OoonfX4ool02QOooo]Z0ooo00`HoookJP?oo`0=
6OoonfX4ool03aOooo]Z1?oo018GoookJPgoo`0G3_oonfX<ool08`oooo]Z3?oo04D?oookJPCoo`2_
5_oonfX7oid0oaKooo]Z1?oo0:l>oookJPcoo`153ooonfX=ool08`kooo]Z3Ooo01LGoookJPCoo`0B
5ooonfX4ool03aSooo]Z0ooo00dIoookJP?oo`0<5ooonfX4ool02QWooo]Z0_oo00P>oookJP003Ooo
nfX6ool021Sooo]Z1ooo00XCoookJPKoo`0<5_oonfX5ool03AKooo]Z2?oo00lDoookJPOoo`0B5?oo
nfX;ool05a7ooo]Z2Ooo02<>oookJPKoo`155_oonfX2ool0[aWooo]Z1OnM0?lHoookJP?oo`2_5Ooo
nfX6ool0A@kooo]Z2_oo02<AoookJP_oo`0G4ooonfX8ool04QCooo]Z1ooo00lFoookJPKoo`0=5_oo
nfX5ool031?ooo]Z2?oo00XHoookJPGoo`083_oonfX000kooo]Z2?oo00PFoookJPWoo`0:4OoonfX8
ool031Cooo]Z2?oo00dCoookJP[oo`0?4_oonfX9ool04Q?ooo]Z2Ooo01LEoookJPGoo`0S:OoonfX0
0ooo0:oooo]ZoookJP0IoookJPGoW@3o6_oonfX2ool0[bSooo]Z1_oo02<EoookJPWoo`0G4_oonfX:
ool04Q;ooo]Z2Ooo00lDoookJPSoo`0=4ooonfX8ool0317ooo]Z2_oo00XFoookJPOoo`083ooonfX0
00oooo]Z2_oo00PDoookJPSoo`0:4_oonfX9ool031?ooo]Z2Ooo00dBoookJPWoo`0?4ooonfX8ool0
4QKooo]Z1Ooo01LIoookJP;oo`0S:?oonfX00ooo0:oooo]ZoookJP0JoookJPGoW@3o7?oonfX00ooo
0:oooo]ZoookJP0UoookJP;oo`0S6_oonfX5ool05aGooo]Z2Ooo018CoookJPSoo`0?4ooonfX9ool0
3A;ooo]Z2Ooo00`BoookJPWoo`0:5?oonfX9ool0213ooo]Z000@oookJP[oo`085?oonfX6ool02QCo
oo]Z2?oo00`DoookJPSoo`0=4ooonfX7ool03aKooo]Z1Ooo018IoookJP?oo`0GH?oonfX5oid0of3o
oo]Z0ooo01LHoookJPKoo`0B5_oonfX6ool03aCooo]Z2?oo00dCoookJPSoo`0<5?oonfX7ool02QCo
oo]Z2Ooo00PAoookJP004OoonfX9ool021Gooo]Z1Ooo00XEoookJPKoo`0<5_oonfX6ool03AGooo]Z
1_oo00lGoookJPCoo`0B6ooonfX00ooo01Oooo]ZoookJP1OoookJP?oW@3oHOoonfX00ooo01Oooo]Z
oookJP0IoookJPCoo`0B5ooonfX5ool03aKooo]Z1_oo00dEoookJPKoo`0<5OoonfX6ool02QGooo]Z
2?oo00PBoookJP004_oonfX7ool021Oooo]Z1?oo00XFoookJPCoo`0<6?oonfX4ool03AOooo]Z1?oo
00lIoookJP?oo`0BOOoonfX3oid0oggooo]Z0ooo018HoookJPCoo`0?6?oonfX4ool03AOooo]Z1?oo
00`GoookJPCoo`0:5ooonfX6ool021?ooo]Z000CoookJPGoo`086OoonfX2ool02QSooo]Z0ooo00`I
oookJP?oo`0=6?oonfX3ool03a[ooo]Z00?oo`0BoookJ_oonfX0O?oonfX3oid0ogkooo]Z00?oo`0B
oookJ_oonfX06?oonfX2ool03aWooo]Z0ooo00dHoookJP?oo`0<6?oonfX3ool02QWooo]Z1?oo00PD
oookJP005?oonfX3ool021_ooo]Z00?oo`0:oookJ_oonfX05ooonfX00ooo00cooo]ZoookJP0Ioook
JP03ool03Ooonf[ooo]Z01Sooo]Z00?oo`0?oookJ_oonfX0V?oonfX3oid0oiWooo]Z00?oo`0?oook
J_oonfX06OoonfX00ooo00gooo]ZoookJP0HoookJP03ool03?oonf[ooo]Z01Sooo]Z00?oo`0:oook
J_oonfX06?oonfX3ool021Gooo]Z000EoookJP03ool02?oonf[ooo]Z0?oooo]Z2?oonfX00onM0?oo
oo]ZoookJP3ooookJPOooo]Z00?oo`08oookJ_oonfX05?oonfX00?oooo]Z8?oonfX00onM0?oooo]Z
oookJP3ooookJQkooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooook
JT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003o
oookJPOooo]Z0_oo03h_oookJP;oo`0noooonfX7oookJP00oooonfX7oookJPCoo`0n4_oonfX7ool0
Ca;ooo]Z1?oo03kooookJPOooo]Z003ooookJPOooo]Z1Ooo03hAoookJPOoo`1?4OoonfX5ool0?_oo
oo]Z1ooonfX00>oooo]Z0_oo02DDoookJPOoo`0n4?oonfX7ool0Ca3ooo]Z1ooo03hDoookJP03ool0
9Ooonf[ooo]Z0>kooo]Z003^oookJP?oo`0U5?oonfX7ool0?Q7ooo]Z1Ooo04lAoookJPOoo`0n5?oo
nfX2ool09Noooo]Z003]oookJPGoo`0U4ooonfX6ool0?Q;ooo]Z1Ooo04lBoookJPKoo`0n4ooonfX4
ool09Nkooo]Z003FoookJP;oo`0H5?oonfX7ool09A;ooo]Z1Ooo03hCoookJPGoo`1?4ooonfX5ool0
?Q;ooo]Z1_oo02DDoookJP?oo`0He_oonfX00=?ooo]Z1Ooo01PCoookJPSoo`0U4OoonfX5ool0?QGo
oo]Z0ooo04lEoookJPGoo`0n4OoonfX7ool09A?ooo]Z1_oo01SCoookJP00d?oonfX8ool061;ooo]Z
2_oo02D@oookJPCoo`0n5_oonfX3ool0CaKooo]Z1?oo03h@oookJPWoo`0U4_oonfX9ool06=3ooo]Z
003=oookJP_oo`0H4OoonfX8ool09A?ooo]Z0ooo03hGoookJP?oo`1?5ooonfX3ool0?Q?ooo]Z1ooo
02DAoookJPcoo`0HcOoonfX000gooo]Z0ooo00TIoookJP?oo`0;6?oonfX2ool03AWooo]Z0ooo00lI
oookJP;oo`0@6OoonfX2ool04AWooo]Z3Ooo01<>oookJPgoo`0H3ooonfX5ool09AOooo]Z0_oo03hH
oookJP?oo`1?6?oonfX2ool0?QOooo]Z1Ooo02D?oookJPgoo`0H3_oonfX=ool04aSooo]Z0ooo014I
oookJP;oo`0@6OoonfX3ool03aWooo]Z0_oo00dHoookJP?oo`0;6?oonfX3ool02@kooo]Z000?oook
JPGoo`095ooonfX5ool02aCooo]Z1Ooo00dHoookJPGoo`0?5OoonfX5ool041Kooo]Z1Ooo014Hoook
JP_oo`0C4_oonfX9ool060kooo]Z0_oo02DJoookJP;oo`0n6_oonfX00ooo04oooo]ZoookJP0Hoook
JP;oo`0n6OoonfX2ool09@oooo]Z2Ooo01PBoookJP_oo`0C5_oonfX5ool04ASooo]Z1Ooo010Eoook
JPGoo`0?6?oonfX4ool03AGooo]Z1Ooo00/FoookJPGoo`094?oonfX0013ooo]Z2?oo00TDoookJPOo
o`0;4_oonfX7ool03AKooo]Z2?oo00lBoookJPOoo`0@5?oonfX7ool04AOooo]Z2Ooo01<HoookJP?o
o`0H:_oonfX00ooo03kooo]ZoookJP0IoookJP03ool0Cooonf[ooo]Z01Wooo]Z00?oo`0noookJ_oo
nfX0:?oonfX3ool061Sooo]Z2Ooo01<EoookJPOoo`0A5_oonfX7ool041;ooo]Z2?oo00lFoookJPKo
o`0=4_oonfX8ool02aCooo]Z1ooo00TAoookJP004OoonfX9ool02A?ooo]Z2?oo00/AoookJPWoo`0=
5?oonfX9ool03a7ooo]Z2Ooo010BoookJPWoo`0A5_oonfX7ool04lCooo]Z1Ooo01<FoookJPSoo`0A
5?oonfX9ool0417ooo]Z2Ooo00lDoookJPSoo`0=4OoonfX9ool02a?ooo]Z2?oo00TBoookJP004_oo
nfX8ool02ACooo]Z1ooo00/BoookJPWoo`0=5?oonfX8ool03a;ooo]Z2Ooo010BoookJPWoo`0A5_oo
nfX5ool04lGooo]Z0ooo01<HoookJPOoo`0A5?oonfX9ool041;ooo]Z2?oo00lCoookJPWoo`0=4_oo
nfX8ool02aCooo]Z1ooo00TCoookJP004ooonfX6ool02AKooo]Z1Ooo00/DoookJPSoo`0=5OoonfX6
ool03aCooo]Z2?oo010CoookJPSoo`0A6?oonfX3ool04lGooo]Z00?oo`0CoookJ_oonfX06OoonfX5
ool04AGooo]Z2?oo010DoookJPKoo`0?5?oonfX8ool03ACooo]Z1_oo00/FoookJPGoo`095?oonfX0
01Cooo]Z1?oo00THoookJPCoo`0;5OoonfX6ool03AOooo]Z1?oo00lEoookJPOoo`0@5OoonfX6ool0
4A_ooo]Z00?oo`0CoookJ_oonfX0gooonfX4ool04AOooo]Z1_oo010FoookJPCoo`0?5_oonfX6ool0
3AKooo]Z1?oo00/GoookJPCoo`095OoonfX001Gooo]Z0ooo00TIoookJP?oo`0;5_oonfX4ool03AWo
oo]Z0ooo00lFoookJPGoo`0@5ooonfX4ool04Okooo]Z0ooo014IoookJPCoo`0@5ooonfX3ool03aSo
oo]Z1?oo00dGoookJP?oo`0;6?oonfX3ool02AKooo]Z000FoookJP03ool02Ooonf[ooo]Z01Wooo]Z
00?oo`0;oookJ_oonfX05_oonfX3ool03A[ooo]Z00?oo`0?oookJ_oonfX05_oonfX3ool041Wooo]Z
0ooo017ooookJP03ool04Ooonf[ooo]Z01Sooo]Z0ooo010IoookJP03ool03ooonf[ooo]Z01Oooo]Z
0ooo00dIoookJP03ool02ooonf[ooo]Z01Sooo]Z00?oo`09oookJ_oonfX05OoonfX004cooo]Z00?o
o`0=oookJ_oonfX0<ooonfX00ooo013ooo]ZoookJP0IoookJP03ool04Ooonf[ooo]Z0?oooo]Z6ooo
nfX00ooo013ooo]ZoookJP0coookJP03ool03Ooonf[ooo]Z04_ooo]Z003ooookJ_oooo]Z@OoonfX0
0?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]Zoooo
nfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]Z1_oonfX3ool05QCo
oo]Z1ooo01XDoookJP;oo`0FoooonfX7oookJP00oooonfX6oookJPKoo`0F4OoonfX7ool06Q7ooo]Z
1Ooo01KooookJPOooo]Z003ooookJPKooo]Z1ooo01H@oookJPOoo`0J4?oonfX6ool05_oooo]Z1ooo
nfX00?3ooo]Z0_oo00lCoookJPOoo`0F4OoonfX5ool06Q7ooo]Z1_oo01HDoookJP;oo`0?l?oonfX0
0>oooo]Z0ooo00lBoookJPOoo`0F4_oonfX5ool06Q;ooo]Z1_oo01HCoookJP?oo`0?kooonfX00>ko
oo]Z1Ooo00lAoookJPKoo`0F4ooonfX5ool06Q?ooo]Z1Ooo01HBoookJPGoo`0?k_oonfX00>gooo]Z
1_oo00lAoookJPGoo`0F5OoonfX3ool06QGooo]Z1?oo01HAoookJPOoo`0?kOoonfX00>cooo]Z1ooo
00lAoookJPCoo`0F5_oonfX3ool06QKooo]Z0ooo01HAoookJPSoo`0?k?oonfX00>_ooo]Z2Ooo00l@
oookJP?oo`0F5ooonfX3ool06QKooo]Z0ooo01H@oookJP[oo`0?jooonfX00>[ooo]Z1ooo00lBoook
JP?oo`0F6?oonfX3ool06QOooo]Z0ooo01HBoookJPSoo`0?j_oonfX002Wooo]Z1?oo00dGoookJP?o
o`0?6?oonfX3ool04ASooo]Z0_oo01<JoookJP;oo`0C6OoonfX2ool04B3ooo]Z1_oo00h@oookJPCo
o`0?5_oonfX2ool05Q[ooo]Z00?oo`0JoookJ_oonfX05ooonfX2ool05QKooo]Z1Ooo00l?oookJPOo
o`0>8?oonfX2ool04AWooo]Z0_oo01<IoookJP;oo`0C6_oonfX2ool04ASooo]Z0ooo00lGoookJPCo
o`0=:OoonfX000gooo]Z3Ooo00/?oookJP03ool03Ooonf[oo`0=00Koo`0=4_oonfX00ooo00oooo]Z
ool03`04ool03aGooo]Z1Ooo014EoookJPCoo`0C6?oonfX4ool04aOooo]Z1Ooo014GoookJPcoo`0>
3ooonfX2ool03aWooo]Z0_oo01HJoookJP03ool06_oonf[ooo]Z01Sooo]Z00?oo`0FoookJ_oonfX0
6?oonfX2ool03`kooo]Z3Ooo00hGoookJPGoo`0A5ooonfX4ool04aOooo]Z1?oo01<GoookJPCoo`0A
5OoonfX6ool03a;ooo]Z2?oo00d00ooonf[oo`0=oookJP0>oookJPcoo`0;3_oonfX000oooo]Z2ooo
00/BoookJPWoo`0=4_oonfX7ool03a?ooo]Z1ooo014CoookJPKoo`0C5_oonfX5ool04aKooo]Z1ooo
014FoookJP[oo`0>S?oonfX;ool03QKooo]Z1ooo014EoookJPKoo`0C5OoonfX6ool04aGooo]Z1_oo
014BoookJPSoo`0?4OoonfX:ool03A;ooo]Z2_oo00/@oookJP004OoonfX9ool02a?ooo]Z2?oo00dC
oookJPSoo`0?4_oonfX9ool04A7ooo]Z1ooo01<EoookJPKoo`0C5OoonfX9ool04AKooo]Z1_oo00j>
oookJPOoo`0>5_oonfX9ool04ACooo]Z1ooo01<DoookJPOoo`0C4ooonfX8ool04A7ooo]Z2Ooo00lB
oookJPWoo`0=4ooonfX8ool02a;ooo]Z000DoookJPGoo`0;5_oonfX5ool03AGooo]Z1ooo00lCoook
JPWoo`0A4OoonfX8ool04a?ooo]Z2?oo01<DoookJPWoo`0A5ooonfX4ool03Xkooo]Z1?oo00hGoook
JP[oo`0A4ooonfX9ool04a;ooo]Z2?oo01<BoookJPWoo`0A4_oonfX8ool03aCooo]Z1_oo00dFoook
JPGoo`0;5?oonfX001Kooo]Z0ooo00/GoookJPCoo`0=5_oonfX5ool03aGooo]Z2?oo014BoookJPSo
o`0C4ooonfX8ool04aCooo]Z2?oo014JoookJP03ool03_oonf[ooo]Z08cooo]Z00?oo`0>oookJ_oo
nfX06?oonfX9ool04A?ooo]Z2Ooo01<BoookJPSoo`0C4ooonfX8ool04ACooo]Z1_oo00lFoookJPCo
o`0=5ooonfX3ool02aKooo]Z000HoookJP03ool02ooonf[ooo]Z01Kooo]Z0ooo00dGoookJPCoo`0?
5_oonfX6ool04ACooo]Z1ooo01<DoookJPOoo`0C5OoonfX6ool04LKooo]Z1ooo014DoookJPSoo`0C
5?oonfX7ool04aCooo]Z1_oo014FoookJPCoo`0?5ooonfX3ool03ASooo]Z00?oo`0;oookJ_oonfX0
5_oonfX003;ooo]Z00?oo`0=oookJ_oonfX05ooonfX3ool03aOooo]Z1?oo014FoookJPGoo`0C5_oo
nfX5ool04aOooo]Z1?oo0178oookJPGoo`0A5_oonfX6ool04aKooo]Z1Ooo01<FoookJPCoo`0A5ooo
nfX3ool03aWooo]Z00?oo`0=oookJ_oonfX0<?oonfX004gooo]Z00?oo`0?oookJ_oonfX05ooonfX3
ool04AOooo]Z0ooo01<GoookJPCoo`0C6OoonfX3ool04LWooo]Z0ooo014HoookJPGoo`0C5ooonfX3
ool04aOooo]Z0ooo014IoookJP03ool03ooonf[ooo]Z04_ooo]Z001XoookJP03ool04Ooonf[ooo]Z
01Oooo]Z00?oo`0CoookJ_oonfX05ooonfX3ool04a[ooo]Z00?oo`0AoookJ_oonfX0bOoonfX00ooo
017ooo]ZoookJP0HoookJP?oo`0C6OoonfX00ooo01?ooo]ZoookJP0GoookJP03ool04Ooonf[ooo]Z
06Kooo]Z002MoookJP03ool04ooonf[ooo]Z0?oooo]Z0_oonfX00ooo01?ooo]ZoookJP2KoookJP00
oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooook
JT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonfX7oookJP;oo`045?oo
nfX7ool01aCooo]Z0_oo00CooookJPOooo]Z003ooookJPOooo]Z1Ooo00@AoookJPOoo`074OoonfX5
ool01?oooo]Z1ooonfX00?oooo]Z1ooonfX6ool0113ooo]Z1ooo00L@oookJPKoo`04oooonfX7oook
JP00oooonfX6oookJPOoo`044OoonfX5ool01a7ooo]Z1_oo00CooookJPOooo]Z003ooookJPKooo]Z
1_oo00@BoookJPGoo`074_oonfX6ool01?oooo]Z1_oonfX00?oooo]Z1_oonfX5ool011?ooo]Z1Ooo
00LCoookJPGoo`04oooonfX6oookJP00oooonfX5oookJPGoo`045OoonfX3ool01aGooo]Z1?oo00Co
oookJPKooo]Z003ooookJPGooo]Z1?oo00@FoookJP?oo`075_oonfX3ool01?oooo]Z1_oonfX00?oo
oo]Z1OoonfX3ool011Oooo]Z0ooo00LFoookJP?oo`04oooonfX6oookJP00oooonfX5oookJP;oo`04
6?oonfX3ool01aOooo]Z0ooo00CooookJPGooo]Z001joookJP;oo`0J6_oonfX00ooo01cooo]Zoook
JP0HoookJP03ool06?oonf[ooo]Z04oooo]Z0_oo00@JoookJP03ool01ooonf[ooo]Z01Oooo]Z0_oo
00AAoookJP03ool06?oonf[ooo]Z01Sooo]Z0_oo01`IoookJP;oo`0JNooonfX000gooo]Z1ooo00`E
oookJPCoo`0>5ooonfX3ool04QSooo]Z0_oo01HIoookJP?oo`0J6OoonfX00ooo01cooo]ZoookJP0H
oookJP;oo`0H6_oonfX00ooo00oooo]ZoookJP0HoookJP03ool01Ooonf[ooo]Z01Sooo]Z0_oo00@J
oookJP03ool01ooonf[ooo]Z01Sooo]Z00?oo`04oookJ_oonfX06OoonfX00ooo00Gooo]ZoookJP0H
oookJP03ool03ooonf[ooo]Z01Sooo]Z00?oo`0HoookJ_oonfX05ooonfX3ool071Sooo]Z0ooo01XJ
oookJP;oo`0F5ooonfX4ool04QOooo]Z1?oo00hEoookJPKoo`0<3_oonfX000oooo]Z2ooo00`@oook
JPSoo`0>4ooonfX6ool04QCooo]Z1Ooo01HGoookJPCoo`0J5ooonfX2ool071Wooo]Z0_oo01PJoook
JP03ool03ooonf[ooo]Z01Sooo]Z00?oo`05oookJ_oonfX0JooonfX00ooo00Gooo]ZoookJP0Hoook
JP03ool03ooonf[ooo]Z01Oooo]Z0_oo01PHoookJP?oo`0L6?oonfX3ool06QSooo]Z1Ooo01HAoook
JPSoo`0B5?oonfX7ool03Q7ooo]Z2_oo00`@oookJP004?oonfX:ool0317ooo]Z2_oo00hAoookJPSo
o`0B4_oonfX7ool05QCooo]Z1Ooo01XGoookJP;oo`0L6?oonfX3ool061Wooo]Z0_oo00lIoookJP;o
o`05JooonfX2ool01AWooo]Z0_oo00lHoookJP?oo`0H5ooonfX4ool071Kooo]Z1Ooo01XEoookJPOo
o`0F3ooonfX:ool04Q;ooo]Z2Ooo00hBoookJPWoo`0<4OoonfX001;ooo]Z1ooo00`CoookJPWoo`0>
4_oonfX9ool04Q7ooo]Z2Ooo01HBoookJPGoo`0J5_oonfX3ool071Sooo]Z0_oo01PIoookJP?oo`0?
6OoonfX2ool01FWooo]Z0_oo00DIoookJP?oo`0?5ooonfX3ool061Oooo]Z1Ooo01`EoookJPGoo`0J
4ooonfX9ool05Q3ooo]Z2Ooo018CoookJPSoo`0>5?oonfX7ool031;ooo]Z000CoookJPKoo`0<5?oo
nfX7ool03QCooo]Z2?oo018BoookJPWoo`0F4OoonfX7ool06QCooo]Z1?oo01`GoookJP?oo`0H6?oo
nfX3ool03aWooo]Z0ooo00EWoookJP?oo`056OoonfX3ool03aKooo]Z1?oo01PFoookJPGoo`0L5Ooo
nfX6ool06Q;ooo]Z2Ooo01HBoookJPKoo`0B5_oonfX6ool03QGooo]Z1Ooo00`DoookJP005?oonfX5
ool031Gooo]Z1_oo00hEoookJPKoo`0B5?oonfX8ool05Q;ooo]Z1ooo01XCoookJPGoo`0L5_oonfX4
ool061Oooo]Z1?oo00lHoookJPCoo`05IOoonfX4ool01ASooo]Z1?oo00lFoookJPCoo`0H5OoonfX6
ool071Cooo]Z1_oo01XCoookJPSoo`0F5?oonfX4ool04QOooo]Z1Ooo00hFoookJPCoo`0<5OoonfX0
01Kooo]Z0_oo00`GoookJPCoo`0>5ooonfX4ool04QKooo]Z1_oo01HDoookJPOoo`0J4ooonfX5ool0
71Gooo]Z1Ooo01PFoookJPCoo`0?6OoonfX4ool01F?ooo]Z1?oo00DIoookJPCoo`0?5OoonfX5ool0
61Cooo]Z1ooo01`CoookJPOoo`0J5?oonfX6ool05QGooo]Z0ooo018HoookJPCoo`0>6?oonfX2ool0
31Kooo]Z000GoookJP03ool03?oonf[ooo]Z01Kooo]Z0ooo00hHoookJP?oo`0B5ooonfX4ool05QGo
oo]Z1_oo01XDoookJPKoo`0L5?oonfX5ool061Kooo]Z1Ooo00lHoookJPGoo`05HOoonfX5ool01ASo
oo]Z1Ooo00lDoookJPKoo`0H4ooonfX7ool071Gooo]Z1_oo01XEoookJPCoo`0F5ooonfX00ooo01;o
oo]ZoookJP0HoookJP;oo`0>6OoonfX00ooo00cooo]ZoookJP0EoookJP00<OoonfX00ooo00kooo]Z
oookJP0HoookJP03ool04_oonf[ooo]Z01Oooo]Z0ooo01HFoookJPCoo`0J5OoonfX7ool071?ooo]Z
1_oo01PEoookJPKoo`0?5ooonfX6ool01Eoooo]Z1_oo00DGoookJPKoo`0?4ooonfX7ool061Gooo]Z
1Ooo01`FoookJPCoo`0J5_oonfX3ool05S?ooo]Z00?oo`0>oookJ_oonfX0<?oonfX006Oooo]Z00?o
o`0FoookJ_oonfX05OoonfX3ool06QKooo]Z1Ooo01`FoookJPKoo`0H5?oonfX6ool03aOooo]Z1ooo
00EMoookJPOoo`055ooonfX6ool03aGooo]Z1?oo01PGoookJPCoo`0L5ooonfX3ool06QOooo]Z00?o
o`0FoookJ_oonfX0IOoonfX0083ooo]Z00?oo`0JoookJ_oonfX05_oonfX2ool071Sooo]Z1?oo01PF
oookJPOoo`0?5ooonfX4ool01F7ooo]Z1?oo00DGoookJPOoo`0?5ooonfX2ool061Sooo]Z0_oo01`I
oookJP03ool06_oonf[ooo]Z07kooo]Z002IoookJP03ool07?oonf[ooo]Z01Oooo]Z00?oo`0Hoook
J_oonfX05ooonfX3ool03a_ooo]Z00?oo`05oookJ_oonfX0IOoonfX00ooo00Gooo]ZoookJP0Ioook
JP?oo`0?6?oonfX00ooo01Sooo]ZoookJP0GoookJP03ool07?oonf[ooo]Z09Sooo]Z003ooookJ_oo
oo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX0
0?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]Zoooo
nfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00
oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00N_oonfX2ool0
:Q[ooo]Z00?oo`0eoookJ_oonfX06?oonfX00ooo03?ooo]ZoookJP0IoookJP03ool08_oonf[ooo]Z
0:7ooo]Z00?oo`0RoookJ_oonfX06?oonfX00ooo03?ooo]ZoookJP0IoookJP03ool0=Ooonf[ooo]Z
01Sooo]Z0_oo02YPoookJPOoo`0=4ooonfX000gooo]Z3Ooo00d>oookJPOoo`0A5OoonfX4ool05QOo
oo]Z0ooo01lHoookJP?oo`0Z6OoonfX00ooo03Gooo]ZoookJP0HoookJP;oo`0c6_oonfX00ooo02;o
oo]ZoookJP0HoookJP03ool04?oonf[ooo]Z01Sooo]Z0_oo00DJoookJP03ool00?oonf[ooo]Z01So
oo]Z0_oo00DIoookJP;oo`0@6_oonfX00ooo02;ooo]ZoookJP0HoookJP03ool0<ooonf[ooo]Z01Wo
oo]Z00?oo`0eoookJ_oonfX05ooonfX3ool0:QSooo]Z0ooo01lGoookJPCoo`0F5?oonfX7ool04@oo
oo]Z3Ooo00d=oookJP003ooonfX;ool03A3ooo]Z2ooo014AoookJPOoo`0F4ooonfX6ool07aGooo]Z
1?oo02XGoookJP;oo`0e6OoonfX2ool0<aWooo]Z0_oo028IoookJP;oo`0@6?oonfX4ool01CGooo]Z
1?oo00DGoookJP?oo`0@6OoonfX2ool08QSooo]Z0_oo03<JoookJP;oo`0e5ooonfX4ool0:QGooo]Z
1Ooo01lCoookJPSoo`0F4?oonfX;ool04A7ooo]Z2ooo00d?oookJP004OoonfX9ool03A;ooo]Z2Ooo
014BoookJPWoo`0F4OoonfX8ool07a;ooo]Z1Ooo02XFoookJP?oo`0e6?oonfX2ool0<aWooo]Z0_oo
028HoookJP;oo`0@5ooonfX5ool01COooo]Z1?oo00DGoookJP?oo`0@6?oonfX2ool08QSooo]Z0_oo
03<IoookJP?oo`0e5OoonfX6ool0:Q;ooo]Z1ooo01lAoookJP[oo`0F4OoonfX9ool04A?ooo]Z2Ooo
00dAoookJP005?oonfX5ool03AGooo]Z1ooo014CoookJPSoo`0F4_oonfX9ool07a7ooo]Z1Ooo02XF
oookJP?oo`0e5ooonfX2ool0<aSooo]Z0ooo028GoookJP?oo`0@5_oonfX5ool01CWooo]Z1Ooo00DE
oookJPCoo`0@5ooonfX3ool08QOooo]Z0ooo03<GoookJP?oo`0e5OoonfX6ool0:Q7ooo]Z2?oo01lB
oookJPWoo`0F4ooonfX7ool04AGooo]Z1Ooo00dDoookJP005_oonfX3ool03AKooo]Z1Ooo014Foook
JPGoo`0F5?oonfX8ool07a7ooo]Z1ooo02XDoookJPCoo`0e5_oonfX3ool0<aOooo]Z0ooo028Foook
JPCoo`0@5?oonfX7ool01CWooo]Z1ooo00DCoookJPGoo`0@5_oonfX3ool08QKooo]Z1?oo03<Foook
JPCoo`0e4ooonfX8ool0:Q7ooo]Z1ooo01lDoookJPKoo`0F5OoonfX5ool04AOooo]Z0ooo00dFoook
JP006?oonfX00ooo00gooo]ZoookJP0FoookJP?oo`0A5ooonfX4ool05QGooo]Z1_oo01lCoookJPOo
o`0Z4ooonfX4ool0=AKooo]Z0ooo03<FoookJPCoo`0R5OoonfX4ool041?ooo]Z2?oo00DkoookJPOo
o`054ooonfX5ool041Gooo]Z1?oo028EoookJPCoo`0c5_oonfX4ool0=A;ooo]Z2?oo02XCoookJPGo
o`0O5_oonfX4ool05QKooo]Z0ooo014IoookJP03ool03Ooonf[ooo]Z01Kooo]Z000coookJP03ool0
4Ooonf[ooo]Z01Kooo]Z0ooo01HFoookJPCoo`0O5OoonfX7ool0:Q;ooo]Z1Ooo03DDoookJPCoo`0c
5OoonfX5ool08QCooo]Z1Ooo010BoookJPWoo`05>ooonfX8ool01A;ooo]Z1_oo010DoookJPCoo`0R
5OoonfX4ool0<aGooo]Z1Ooo03DAoookJPSoo`0Z5?oonfX4ool07aOooo]Z0ooo01HHoookJP03ool0
4Ooonf[ooo]Z037ooo]Z001=oookJP03ool05_oonf[ooo]Z01Kooo]Z0ooo01lEoookJPKoo`0Z4ooo
nfX6ool0=A?ooo]Z1Ooo03<DoookJPGoo`0R4ooonfX6ool041Cooo]Z1_oo00DmoookJPKoo`054ooo
nfX7ool041?ooo]Z1?oo028DoookJPGoo`0c5?oonfX6ool0=A?ooo]Z1_oo02XDoookJP?oo`0O6Ooo
nfX00ooo01Kooo]ZoookJP1;oookJP00IooonfX00ooo01oooo]ZoookJP0EoookJPCoo`0Z5?oonfX7
ool0=A;ooo]Z1Ooo03<CoookJPKoo`0R4_oonfX6ool041Kooo]Z1?oo00DooookJPCoo`055OoonfX7
ool041;ooo]Z1Ooo028CoookJPGoo`0c4ooonfX7ool0=ACooo]Z1?oo02XFoookJP03ool07ooonf[o
oo]Z06Kooo]Z001ooookJP?oo`0Z5_oonfX4ool0=ACooo]Z1Ooo03<CoookJPKoo`0R5?oonfX4ool0
41Oooo]Z0ooo00DooookJP?oo`055_oonfX5ool041Cooo]Z1Ooo028CoookJPKoo`0c5?oonfX4ool0
=AKooo]Z0ooo02YooookJP00P?oonfX00ooo02[ooo]ZoookJP0EoookJP;oo`0e5_oonfX6ool0<a7o
oo]Z1ooo028EoookJP?oo`0@6?oonfX00ooo00Gooo]ZoookJP0ooookJP03ool01Ooonf[ooo]Z01Go
oo]Z0ooo010FoookJPKoo`0R4OoonfX7ool0<aKooo]Z0_oo03DGoookJP03ool0:_oonf[ooo]Z07ko
oo]Z002HoookJP03ool0=Ooonf[ooo]Z01Gooo]Z0ooo03<HoookJP?oo`0R5_oonfX00ooo013ooo]Z
oookJP1boookJP03ool04?oonf[ooo]Z01Gooo]Z0ooo028HoookJP?oo`0c5ooonfX00ooo03Gooo]Z
oookJP2FoookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oook
JP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[o
oookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z
003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00UOoonfX00ooo08Kooo]ZoookJP0Joook
JP03ool0Tooonf[ooo]Z0=Oooo]Z00?oo`2CoookJ_oonfX06_oonfX00ooo08Kooo]ZoookJP2Coook
JP00UOoonfX00ooo08Kooo]ZoookJP0JoookJP03ool0Tooonf[ooo]Z0=Oooo]Z00?oo`2CoookJ_oo
nfX06_oonfX00ooo08Kooo]ZoookJP2CoookJP00<OoonfX4ool04dCooo]Z0_oo04/JoookJP;oo`26
6_oonfX2ool0Ta[ooo]Z0_oo04nQoookJP;oo`1?6_oonfX2ool0Ta[ooo]Z0_oo08HIoookJP;oo`1;
AOoonfX4ool04c7ooo]Z000CoookJPOoo`0>4OoonfX:ool04`oooo]Z3?oo01/?oookJPCoo`0[5_oo
nfX4ool0BaSooo]Z0ooo08HIoookJP;oo`2C6OoonfX3ool0CaWooo]Z0_oo028GoookJPCoo`0<=Ooo
nfX4ool031Oooo]Z0_oo028IoookJP?oo`1?6OoonfX2ool0TaWooo]Z0_oo08HHoookJPCoo`1;5ooo
nfX4ool0:`kooo]Z3Ooo01/?oookJPWoo`0C4_oonfX7ool03Q?ooo]Z000=oookJPgoo`0>3_oonfX=
ool04`oooo]Z00?oo`0KoookJ_oo01/02Ooo01/@oookJPSoo`0[4_oonfX6ool0BaKooo]Z0ooo08HH
oookJP;oo`2C6?oonfX3ool0CaOooo]Z1Ooo028AoookJPSoo`0<00?ooo]Zool03?oonfX06OoonfX0
0ooo007ooo]ZoookJP0HoookJP03ool03?oonf[oo`0<00Ooo`0<4OoonfX5ool08QOooo]Z0ooo04lG
oookJP?oo`2C6?oonfX3ool0QQGooo]Z1_oo04/BoookJPWoo`0[3ooonfX<ool06a3ooo]Z3?oo01<?
oookJPgoo`0>3OoonfX000oooo]Z2ooo00h@oookJP_oo`0C4ooonfX8ool06a;ooo]Z2Ooo02/@oook
JPOoo`1;5?oonfX4ool0QQKooo]Z0ooo09<FoookJPGoo`1?5?oonfX7ool08Poooo]Z2_oo00`koook
JP[oo`0<3ooonfX7ool08QCooo]Z1Ooo04lEoookJPCoo`2C5_oonfX4ool0QQ?ooo]Z1ooo04/@oook
JP[oo`0[4_oonfX8ool06a?ooo]Z2_oo01<AoookJP_oo`0>3ooonfX001;ooo]Z1ooo00hDoookJPOo
o`0C5OoonfX7ool06a?ooo]Z2?oo02/AoookJPSoo`1;4_oonfX4ool0QQKooo]Z1?oo09<DoookJPGo
o`1?4_oonfX9ool08Q3ooo]Z2?oo00`noookJPWoo`0<4?oonfX9ool08Q7ooo]Z1_oo04lDoookJPCo
o`2C5OoonfX5ool0QQ7ooo]Z2Ooo04/@oookJPWoo`0[4ooonfX7ool06aCooo]Z1ooo01<EoookJPOo
o`0>4_oonfX001Gooo]Z1?oo00hGoookJPCoo`0C5ooonfX4ool06aKooo]Z1Ooo02/CoookJPSoo`1;
4OoonfX5ool0QQGooo]Z1?oo09<CoookJPKoo`1?4OoonfX9ool08Q;ooo]Z1_oo00a1oookJPKoo`0<
4_oonfX9ool08Q7ooo]Z1_oo04lCoookJPCoo`2C5?oonfX5ool0QQ7ooo]Z2Ooo04/BoookJPKoo`0[
5OoonfX5ool06aKooo]Z1?oo01<HoookJPCoo`0>5OoonfX001Sooo]Z00?oo`0>oookJ_oonfX06?oo
nfX00ooo01?ooo]ZoookJP0GoookJP;oo`0K5ooonfX4ool0:a?ooo]Z2?oo04/AoookJPKoo`264ooo
nfX5ool0T`cooo]Z00?o0?lBoookJ_oonfX00ooonfX6ool0Ca;ooo]Z2?oo028CoookJPGoo`0<@ooo
nfX4ool031Cooo]Z2?oo028AoookJPOoo`1?1?oonfX2o`3o4Pcooo]Z1Ooo09<BoookJPKoo`264Ooo
nfX8ool0BaCooo]Z1?oo02/GoookJP;oo`0K6?oonfX00ooo01?ooo]ZoookJP0IoookJP03ool03_oo
nf[ooo]Z01Kooo]Z001>oookJP03ool06ooonf[ooo]Z01Kooo]Z0ooo02/DoookJPKoo`1;4_oonfX7
ool0QQ;ooo]Z1Ooo09<;oookJP;o0?lB1?oonfX7ool0Ca?ooo]Z1_oo028DoookJP?oo`0<A_oonfX3
ool031Gooo]Z1_oo028BoookJPSoo`1?0ooonfX3o`3o4P[ooo]Z1_oo09<AoookJPOoo`264_oonfX6
ool0BaGooo]Z0ooo02/HoookJP03ool06ooonf[ooo]Z04cooo]Z001XoookJP03ool0:ooonf[ooo]Z
01Cooo]Z1?oo04/DoookJPCoo`265?oonfX5ool0T`[ooo]Z0_l0oa86oookJPKoo`1?5?oonfX4ool0
8QKooo]Z00?oo`0<oookJ_oonfX0A_oonfX00ooo00cooo]ZoookJP0EoookJPCoo`0R5?oonfX5ool0
C`Kooo]Z0ol0oa89oookJPKoo`2C4ooonfX5ool0QQ?ooo]Z1Ooo04/FoookJP03ool0:ooonf[ooo]Z
06Kooo]Z0020oookJP?oo`1;5?oonfX2ool0QQGooo]Z1_oo09<9oookJP?o0?lB1ooonfX4ool0CaGo
oo]Z0ooo029ioookJP?oo`0R5?oonfX4ool0C`Oooo]Z1?l0oa88oookJPOoo`2C5?oonfX2ool0QQGo
oo]Z0ooo04^0oookJP00POoonfX00ooo04_ooo]ZoookJP0CoookJP03ool0Q_oonf[ooo]Z02;ooo]Z
1?l0oa88oookJP?oo`1?5_oonfX00ooo02;ooo]ZoookJP1ioookJP03ool08_oonf[ooo]Z01?ooo]Z
0ooo04l8oookJPGo0?lB8ooonfX00ooo08Kooo]ZoookJP0DoookJP03ool0Booonf[ooo]Z07oooo]Z
002koookJPCo0?lB2_oonfX00ooo04oooo]ZoookJP2XoookJP03ool0Cooonf[ooo]Z00Sooo]Z1Ol0
oa:koookJP00^_oonfX5o`3o4/3ooo]Z1_l0oa:joookJP00^OoonfX6o`3o4/3ooo]Z1ol0oa:ioook
JP00^?oonfX6o`3o4/;ooo]Z1ol0oa:hoookJP00^_oonfX4o`3o4/;ooo]Z1Ol0oa:joookJP00^_oo
nfX4o`3o4/;ooo]Z1?l0oa:koookJP00^_oonfX00ol0oa;ooo]Zo`3o4P34oookJP04o`3o4_oonf[o
oo]Zo`3o4[[ooo]Z002ioookJP03o`3o4_oonf[ooo]Z063ooo]Z1ooo00=RoookJP03o`3o4_oonf[o
oo]Z0;Oooo]Z002hoookJP03o`3o4_oonf[ooo]Z067ooo]Z1ooo00=RoookJP03o`3o4_oonf[ooo]Z
0;Oooo]Z002hoookJP03o`3o4_oonf[ooo]Z067ooo]Z1ooo00=SoookJP03o`3o4_oonf[ooo]Z0;Ko
oo]Z002;oookJP;o00co:_oonfX00ol0oa;ooo]ZoookJP1SoookJPGoo`03I?oonfX00ol0oa;ooo]Z
oookJP0YoookJP;o00coRooonfX008_ooo]Z1Ol03?lWoookJP03o`3o4_oonf[ooo]Z06?ooo]Z1Ooo
00=UoookJP03o`3o4_oonf[ooo]Z02Gooo]Z1Ol03?n;oookJP00S?oonfX7o`0<ob?ooo]Z00?o0?lB
oookJ_oonfX0I?oonfX5ool00fKooo]Z00?o0?lBoookJ_oonfX08OoonfX7o`0<ohcooo]Z002=oook
JPWo00co7ooonfX00ol0oa;ooo]ZoookJP1VoookJP?oo`03IooonfX00ol0oa;ooo]ZoookJP0Noook
JPWo00coSOoonfX008kooo]Z2Ol03?lNoookJP03o`3o4_oonf[ooo]Z047ooo]Z0_oo018SoookJP?o
o`038ooonfX2ool04T?ooo]Z00?o0?lBoookJ_oonfX07?oonfX9o`0<ohkooo]Z000GoookJP?oo`0>
6?oonfX3ool051Sooo]Z0ooo01looookJPSo00co7OoonfX00ol0oa;ooo]ZoookJP12oookJPGoo`0B
8?oonfX3ool00b3ooo]Z1Ooo0194oookJP03o`3o4_oonf[ooo]Z01_ooo]Z2?l03?looookJP?oo`0O
6?oonfX3ool051Sooo]Z0ooo00hGoookJP004ooonfX7ool03QCooo]Z1ooo01@DoookJPOoo`0O5ooo
nfX4ool0=RCooo]Z1ol03?lNoookJP03o`3o4_oonf[ooo]Z01Oooo]Z1?oo0:T<oookJPCoo`0d5ooo
nfX8ool04Qgooo]Z0ooo00<MoookJPSoo`0B5ooonfX4ool0=0cooo]Z1?oo0:TIoookJP03o`3o4_oo
nf[ooo]Z01cooo]Z1_l03?lUoookJPCoo`0f5ooonfX7ool07aCooo]Z1ooo01@DoookJPOoo`0>4ooo
nfX000oooo]Z2ooo00h@oookJP_oo`0D4?oonfX;ool07a7ooo]Z2_oo03H=oookJPcoo`1l3?oonfX6
o`0<oagooo]Z00?o0?lBoookJ_oonfX04_oonfX8ool0Z@kooo]Z2_oo03@@oookJPcoo`0B6ooonfX0
0ooo00?ooo]ZoookJP0IoookJP_oo`0B4OoonfX:ool0=0kooo]Z1ooo0:TEoookJP03o`3o4_oonf[o
oo]Z01_ooo]Z1Ol03?l<oookJPgoo`1l3OoonfX:ool0=Q7ooo]Z2_oo01lAoookJP[oo`0D4OoonfX;
ool03Poooo]Z000=oookJPgoo`0>3_oonfX=ool050kooo]Z3Ooo01l>oookJPgoo`0f3ooonfX:ool0
O0gooo]Z0ol03?l2oookJP03o`0<oooonf[ooo]Z01Wooo]Z00?o0?lBoookJ_oonfX04?oonfX:ool0
Z@oooo]Z3Ooo03@=oookJPgoo`0B6_oonfX00ooo00?ooo]ZoookJP0HoookJPcoo`0B3_oonfX=ool0
=0oooo]Z2Ooo0:TCoookJP03o`3o4_oonf[ooo]Z01Wooo]Z00?o00cooookJ_l03?l00_l03?l=oook
JP_oo`1l3ooonfX=ool0=Pkooo]Z3?oo01l?oookJPcoo`0D3ooonfX=ool03Pgooo]Z000@oookJP[o
o`0>4OoonfX:ool0517ooo]Z2_oo01l@oookJP_oo`0f4OoonfX8ool0O0kooo]Z00?o00cooookJ_oo
nfX0<?oonfX8ool0ZA7ooo]Z2ooo03@?oookJPKoo`0B@ooonfX5ool04Q3ooo]Z2ooo03@@oookJPSo
o`2Y<_oonfX00ol03?oooo]ZoookJP0=oookJPSoo`1l4OoonfX;ool0=Q3ooo]Z2Ooo01lBoookJPWo
o`0D4_oonfX:ool03Q3ooo]Z000DoookJPKoo`0>5OoonfX6ool051Gooo]Z1_oo01lCoookJPOoo`0f
4ooonfX7ool0O4;ooo]Z1_oo0:TCoookJPOoo`0dLooonfX7ool0=1?ooo]Z1Ooo0:U3oookJPOoo`1l
4ooonfX7ool0=Q?ooo]Z1Ooo01lFoookJPGoo`0D5_oonfX6ool03QCooo]Z000HoookJP;oo`0>6Ooo
nfX2ool051Wooo]Z0_oo01lFoookJPCoo`0f5OoonfX4ool0O4?ooo]Z1Ooo0:TDoookJPCoo`0dNOoo
nfX4ool0=1Cooo]Z1?oo0:U3oookJPGoo`1l5OoonfX4ool0=QKooo]Z0_oo01lIoookJP;oo`0D6Ooo
nfX2ool03QSooo]Z001YoookJP03ool0=_oonf[ooo]Z01Gooo]Z0_oo07a3oookJP?oo`2Y5_oonfX0
0ooo03Cooo]ZoookJP1moookJP03ool0=?oonf[ooo]Z01?ooo]Z0ooo0:U4oookJP;oo`1l5ooonfX0
0ooo03Kooo]ZoookJP1WoookJP00P_oonfX00ooo07cooo]ZoookJP12oookJP03ool0ZOoonf[ooo]Z
0:cooo]Z00?oo`2YoookJ_oonfX0@ooonfX00ooo07cooo]ZoookJP20oookJP00oooonf[ooookJT7o
oo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooook
J_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@Ooo
nfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJQgooo]Z1ooo00WooookJQgo
oo]Z003ooookJQgooo]Z1ooo00WooookJQgooo]Z003ooookJQgooo]Z1ooo00WooookJQgooo]Z003o
oookJQkooo]Z1Ooo00WooookJQkooo]Z003koookJP;oo`0E8?oonfX5ool02B3ooo]Z0_oo01Gkoook
JP00h?oonfX2ool0=aWooo]Z0ooo01DOoookJPGoo`097ooonfX3ool05AWooo]Z0_oo03OPoookJP00
J?oonfX2ool0=QOooo]Z0_oo07e5oookJP;oo`2^5_oonfX3ool0=aOooo]Z1Ooo01DNoookJPGoo`09
7_oonfX5ool05AOooo]Z0ooo03LFoookJP;oo`2^AOoonfX2ool0OAOooo]Z0_oo03IXoookJP005ooo
nfX2ool03QWooo]Z0_oo01@IoookJP;oo`0O5ooonfX4ool0=QGooo]Z1?oo07e5oookJP?oo`2^5?oo
nfX6ool0=aCooo]Z1ooo01DNoookJP?oo`097_oonfX6ool05AGooo]Z1_oo03LDoookJP?oo`2^AOoo
nfX4ool0OAGooo]Z1?oo03HFoookJP;oo`0O6OoonfX2ool051[ooo]Z0_oo00hGoookJP005?oonfX5
ool03QKooo]Z1Ooo01@FoookJPGoo`0O5OoonfX6ool0=QCooo]Z1Ooo07e4oookJPGoo`2^4ooonfX7
ool0=a?ooo]Z2?oo01DMoookJP?oo`097OoonfX7ool05ACooo]Z1ooo03LCoookJPGoo`2^@ooonfX6
ool0OACooo]Z1_oo03HDoookJPGoo`0O5_oonfX5ool051Oooo]Z1Ooo00hDoookJP004OoonfX8ool0
3Q?ooo]Z2?oo01@CoookJPSoo`0O5?oonfX7ool0=Q;ooo]Z1ooo07e3oookJPSoo`2^4OoonfX8ool0
=a7ooo]Z2_oo01DLoookJP?oo`097?oonfX9ool05A;ooo]Z2?oo03LAoookJPOoo`2^@ooonfX8ool0
OA;ooo]Z1ooo03HCoookJPSoo`0O4ooonfX8ool051Cooo]Z2?oo00hAoookJP003_oonfX<ool03Poo
oo]Z2ooo01@@oookJP_oo`0O4_oonfX:ool0=Poooo]Z2_oo07e2oookJPWoo`2^3ooonfX;ool0=a;o
oo]Z2?oo01DKoookJP?oo`096ooonfX7ool05A?ooo]Z2ooo03L?oookJPSoo`2^@ooonfX:ool0O@oo
oo]Z2_oo03HAoookJP_oo`0O4?oonfX;ool0513ooo]Z3?oo00h>oookJP003OoonfX=ool03Pkooo]Z
3Ooo01@>oookJPgoo`0O3ooonfX<ool0=Pkooo]Z2ooo07d>oookJP03o`0@oooonf[ooo]Z00;o013o
6ooonfX00ol0o`[ooo]ZoookJP0@oookJP_oo`2^3_oonfX<ool0=aGooo]Z1_oo01DJoookJP03ool0
2Ooonf[ooo]Z01Sooo]Z1Ooo01DFoookJPcoo`0g3_oonfX:ool0[Q?ooo]Z00?o0?l:oookJ_oonfX0
6OoonfX2o`0@o`03oookJ_l04?oooo]Z00gooo]Z3?oo07d>oookJPcoo`0f3ooonfX<ool07`oooo]Z
3?oo01@?oookJPgoo`0>3OoonfX001Cooo]Z1_oo00hBoookJPWoo`0D4_oonfX9ool07`kooo]Z3Ooo
03H=oookJPcoo`1m3_oonfX3o`0@oagooo]Z00?o0?l:oookJ_oonfX05?oonfX8ool0[QCooo]Z1_oo
03LHoookJP;oo`0E6_oonfX00ooo00Wooo]ZoookJP0HoookJP;oo`0E6?oonfX6ool0=aCooo]Z1ooo
0:hGoookJP03o`3o2_oonf[ooo]Z01_ooo]Z0_l04?l>oookJPgoo`1m3OoonfX=ool0=Pkooo]Z2?oo
01lCoookJPSoo`0D4ooonfX6ool03QCooo]Z000boookJP?oo`0D6?oonfX3ool07d7ooo]Z1?l04?lN
oookJP03o`3o2_oonf[ooo]Z01Wooo]Z0ooo0:jKoookJP?oo`2^6ooonfX00ol0o`[ooo]ZoookJP0L
oookJP?o013o@_oonfX3ool07aSooo]Z0ooo01@boookJP00T?oonfX6o`0@oakooo]Z00?o0?l:oook
J_oonfX0dooonfX00ol0o`[ooo]ZoookJP0LoookJPGo013oTOoonfX008oooo]Z2?l04?lMoookJP03
o`3o2_oonf[ooo]Z0=?ooo]Z00?o0?l:oookJ_oonfX06ooonfX7o`0@oi3ooo]Z002>oookJPOo013o
8?oonfX00ol0o`[ooo]ZoookJP3AoookJP03o`3o2_oonf[ooo]Z01kooo]Z1_l04?n?oookJP00S_oo
nfX5o`0@ob;ooo]Z00?o0?l:oookJ_oonfX0d?oonfX00ol0o`[ooo]ZoookJP0QoookJPGo013oS_oo
nfX008gooo]Z0ol04?lVoookJP03o`3o2_oonf[ooo]Z0<oooo]Z00?o0?l:oookJ_oonfX09?oonfX3
o`0@ohgooo]Z002<oookJP;o013o:OoonfX00ol0o`[ooo]ZoookJP3=oookJP03o`3o2_oonf[ooo]Z
02Oooo]Z0_l04?n<oookJP00RooonfX00ol04?oooo]ZoookJP0YoookJP03o`3o2_oonf[ooo]Z0<co
oo]Z00?o0?l:oookJ_oonfX0:_oonfX00ol04?oooo]ZoookJP29oookJP00^?oonfX00ol0o`[ooo]Z
oookJP3;oookJP03o`3o2_oonf[ooo]Z0;Kooo]Z002hoookJP03o`3o2_oonf[ooo]Z0<[ooo]Z00?o
0?l:oookJ_oonfX0]ooonfX00;Wooo]Z00?o0?l:oookJ_oonfX00_l0o`[3oookJP;o0?l:00?ooo]Z
o`3o2_oonfX0^OoonfX00;[ooo]Z1?l0o`[3oookJPCo0?l:^_oonfX00;Wooo]Z1Ol0o`[2oookJPKo
0?l:^OoonfX00;Sooo]Z1ol0o`[1oookJPOo0?l:^?oonfX00;Wooo]Z1_l0o`[1oookJPGo0?l:^_oo
nfX00;[ooo]Z1Ol0o`Y0oookJP03ool05_oonf[ooo]Z01[ooo]Z1ooo00lKoookJP;oo`0F?ooonfX5
o`3o2[_ooo]Z002koookJPGo0?l:8ooonfX00ooo02cooo]ZoookJP0HoookJP;oo`0F7?oonfX7ool0
3a_ooo]Z0ooo01HJoookJP03ool0;?oonf[ooo]Z027ooo]Z1?l0o`ZloookJP00P?oonfX00ooo04ko
oo]ZoookJP0DoookJP;oo`2<8ooonfX4o`3o2PWooo]Z0_oo05TGoookJP;oo`0/6OoonfX4ool05Q_o
oo]Z1ooo00lJoookJPGoo`0F6OoonfX2ool0;1Oooo]Z0_oo05T9oookJP?o0?l:9?oonfX2ool0S1Ko
oo]Z00?oo`1>oookJ_oonfX0O_oonfX006Oooo]Z00?oo`0/oookJ_oonfX05_oonfX00ooo04kooo]Z
oookJP0DoookJPCoo`2<5_oonfX3ool0W@Wooo]Z0ol0o`X7oookJPCoo`1I5_oonfX4ool0;1Oooo]Z
1Ooo01HLoookJPGoo`0?6ooonfX6ool05QOooo]Z1?oo02`FoookJP?oo`1I1ooonfX3o`3o2PWooo]Z
1?oo09dFoookJPCoo`2<5_oonfX00ooo04kooo]ZoookJP0EoookJP;oo`0/IooonfX001Kooo]Z0_oo
00hIoookJP;oo`0C6OoonfX2ool06aSooo]Z0_oo02`GoookJP?oo`1>5OoonfX5ool0S1;ooo]Z1_oo
09d:oookJP;o0?l:1_oonfX6ool0FACooo]Z1_oo02`EoookJPOoo`0F6ooonfX5ool03a_ooo]Z1ooo
01HEoookJPKoo`0/5?oonfX5ool0F@Kooo]Z0_l0o`X:oookJPOoo`2M4_oonfX5ool0S1Gooo]Z0ooo
04hFoookJP?oo`0/5ooonfX2ool06a[ooo]Z0_oo01<IoookJP;oo`0>5_oonfX001Gooo]Z0ooo00hH
oookJP?oo`0C6?oonfX3ool06aOooo]Z1?oo02`EoookJPGoo`1>5?oonfX6ool0S17ooo]Z1_oo09d;
oookJP;o0?l:1?oonfX7ool0FA?ooo]Z1ooo02`GoookJPGoo`0F6ooonfX5ool03a[ooo]Z1_oo01HG
oookJPOoo`0/4ooonfX6ool0F@Gooo]Z00?o0?l:oookJ_oonfX02OoonfX7ool0WA7ooo]Z1_oo08`D
oookJPGoo`1>5?oonfX5ool0;1Kooo]Z0ooo01/IoookJP?oo`0C6?oonfX3ool03QGooo]Z000Coook
JPKoo`0>5OoonfX6ool04aKooo]Z1Ooo01/EoookJPKoo`0/5?oonfX6ool0CQ;ooo]Z1ooo08`Boook
JPGoo`2M3?oonfX00ol0o`[ooo]ZoookJP04oookJPGoo`1I5OoonfX6ool0;1Oooo]Z1Ooo01HKoook
JP?oo`0?6ooonfX5ool05QOooo]Z1_oo02`DoookJPGoo`1I1_oonfX00ol0o`[ooo]ZoookJP0:oook
JPKoo`2M4_oonfX7ool0S1;ooo]Z1_oo04hDoookJPKoo`0/5?oonfX6ool06aKooo]Z1Ooo01<Foook
JPKoo`0>4ooonfX001;ooo]Z1ooo00hDoookJPOoo`0C5?oonfX7ool06aCooo]Z1ooo02`CoookJPSo
o`1>4OoonfX6ool0S1?ooo]Z1Ooo09dDoookJPGoo`1I5_oonfX4ool0;1Sooo]Z1?oo01HKoookJP?o
o`0?6ooonfX4ool05QSooo]Z1?oo02`FoookJPCoo`1I5?oonfX6ool0WA?ooo]Z1_oo08`AoookJPSo
o`1>4ooonfX7ool0;1?ooo]Z1ooo01/EoookJPOoo`0C5?oonfX7ool03Q;ooo]Z000AoookJPSoo`0>
4ooonfX8ool04a?ooo]Z2?oo01/CoookJPWoo`0/4OoonfX7ool0CQ?ooo]Z1Ooo08`DoookJPGoo`2M
5OoonfX4ool0FAOooo]Z1?oo02`IoookJP;oo`0F6ooonfX3ool03a[ooo]Z0ooo01HIoookJPCoo`0/
5_oonfX4ool0FAGooo]Z1Ooo09dEoookJPGoo`2<4ooonfX6ool0CQ;ooo]Z2Ooo02`BoookJPSoo`0K
5?oonfX8ool04a?ooo]Z2?oo00hAoookJP003ooonfX;ool03Q3ooo]Z2ooo01<AoookJP[oo`0K4Ooo
nfX7ool0;1?ooo]Z1_oo04hEoookJPCoo`2<5_oonfX4ool0WAKooo]Z0ooo05TIoookJP?oo`0/6Ooo
nfX2ool05Q[ooo]Z0ooo00lJoookJP;oo`0F6OoonfX3ool0;1Sooo]Z0ooo05TFoookJPGoo`2M5_oo
nfX4ool0S1Gooo]Z1Ooo04hDoookJPOoo`0/4?oonfX;ool06a7ooo]Z2_oo01<AoookJP_oo`0>3ooo
nfX000kooo]Z3?oo00h?oookJPSoo`0C5?oonfX;ool06a3ooo]Z1?oo02`GoookJP?oo`1>6?oonfX3
ool0S1Oooo]Z0ooo09dHoookJP?oo`1I6_oonfX00ooo02cooo]ZoookJP0HoookJP03ool05_oonf[o
oo]Z01Wooo]Z00?oo`0?oookJ_oonfX06OoonfX00ooo01Kooo]ZoookJP0HoookJP03ool0;?oonf[o
oo]Z01Sooo]Z0_oo05THoookJP?oo`2M6?oonfX3ool0S1Oooo]Z1?oo04hGoookJPCoo`0/3ooonfX<
ool06aCooo]Z1ooo01<@oookJPcoo`0>3_oonfX000gooo]Z1_oo00hEoookJP?oo`0C6OoonfX6ool0
6aGooo]Z0_oo02`IoookJP;oo`1>6_oonfX3ool0S1Oooo]Z0ooo09dIoookJP;oo`1I6_oonfX2ool0
;1[ooo]Z00?oo`0FoookJ_oonfX06?oonfX00ooo00oooo]ZoookJP0HoookJP03ool05_oonf[ooo]Z
01Sooo]Z0_oo02`IoookJP;oo`1I6OoonfX3ool0WASooo]Z0ooo08`IoookJP;oo`1>6_oonfX2ool0
;1Gooo]Z1_oo01/HoookJP?oo`0C5_oonfX6ool03Pgooo]Z001ioookJP03ool0C_oonf[ooo]Z01Wo
oo]Z0ooo08`IoookJP;oo`2M6_oonfX00ooo05Wooo]ZoookJP2PoookJP03ool0FOoonf[ooo]Z01So
oo]Z0ooo09dIoookJP?oo`2<6_oonfX00ooo04kooo]ZoookJP1hoookJP00UOoonfX2ool0S1[ooo]Z
0_oo09dKoookJP03ool0FOoonf[ooo]Z09kooo]Z00?oo`1IoookJ_oonfX06OoonfX2ool0WA_ooo]Z
0_oo08bEoookJP00UOoonfX00ooo08cooo]ZoookJP0IoookJP;oo`2Mf?oonfX2ool0WAcooo]Z00?o
o`2<oookJ_oonfX0TooonfX00;;ooo]Z00?oo`2MoookJ_oonfX0e_oonfX00ooo09gooo]ZoookJP2a
oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooo
nf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7o
oo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooook
J_oooo]Z@OoonfX00<cooo]Z0_oo02lGoookJP;oo`0O6ooonfX2ool05ASooo]Z1ooo018HoookJP;o
o`0E6_oonfX2ool07aSooo]Z0ooo02o;oookJP00O_oonfX2ool0;AOooo]Z1?oo03/DoookJPKoo`0m
5?oonfX5ool0;aGooo]Z1?oo01lHoookJPGoo`0E6?oonfX7ool04QSooo]Z1Ooo01DGoookJPCoo`0O
5_oonfX6ool0;a;ooo]Z1ooo03dEoookJP?oo`0k5_oonfX2ool0;Goooo]Z001VoookJP03ool07ooo
nf[ooo]Z01Gooo]Z1?oo02dEoookJPKoo`0k4_oonfX6ool0?A;ooo]Z1ooo02lDoookJPGoo`0O5_oo
nfX7ool05ASooo]Z1ooo018HoookJPKoo`0E5_oonfX6ool07aCooo]Z1ooo02lAoookJPOoo`0m4_oo
nfX6ool0>aCooo]Z1?oo02dHoookJP03ool07ooonf[ooo]Z06Cooo]Z000aoookJP03ool04?oonf[o
oo]Z01Sooo]Z00?oo`0FoookJ_oonfX05ooonfX00ooo01oooo]ZoookJP0DoookJPKoo`0]5?oonfX6
ool0>a;ooo]Z1_oo03dBoookJPOoo`0_4ooonfX7ool07aGooo]Z1ooo01DIoookJPGoo`0B6OoonfX6
ool05AKooo]Z1ooo01lCoookJPOoo`0_4OoonfX7ool0?A;ooo]Z1_oo03/CoookJPKoo`0]5_oonfX2
ool07aSooo]Z0_oo01HIoookJP;oo`0@<OoonfX001Kooo]Z0_oo00`HoookJP;oo`0@6OoonfX2ool0
5QSooo]Z0ooo01lEoookJPOoo`0]4ooonfX5ool0>aCooo]Z1Ooo03dCoookJPKoo`0_4ooonfX7ool0
7aKooo]Z1_oo01DIoookJPGoo`0B6OoonfX5ool05AKooo]Z2?oo01lCoookJPKoo`0_4ooonfX5ool0
?ACooo]Z1Ooo03/BoookJPOoo`0]5OoonfX4ool07aOooo]Z0ooo01HHoookJP?oo`0@6?oonfX2ool0
31Kooo]Z000EoookJP?oo`0<5ooonfX4ool041Oooo]Z1?oo01HFoookJPGoo`0O5?oonfX5ool0;AGo
oo]Z1?oo03/EoookJPCoo`0m5OoonfX5ool0;aCooo]Z1_oo01lGoookJPGoo`0E6OoonfX5ool04QWo
oo]Z1?oo01DGoookJPOoo`0O5?oonfX5ool0;aCooo]Z1Ooo03dEoookJPCoo`0k5?oonfX6ool0;A?o
oo]Z1_oo01lEoookJPGoo`0F5_oonfX5ool041Oooo]Z0ooo00`EoookJP004ooonfX6ool031Gooo]Z
1Ooo010FoookJPKoo`0F5?oonfX7ool07a;ooo]Z1Ooo02dFoookJPCoo`0k5OoonfX4ool0?AGooo]Z
1Ooo02lEoookJPGoo`0O6?oonfX5ool05AWooo]Z0ooo018IoookJPGoo`0E5ooonfX6ool07aGooo]Z
1Ooo02lDoookJPGoo`0m5OoonfX4ool0>aGooo]Z1Ooo02dBoookJPSoo`0O5?oonfX6ool05QGooo]Z
1_oo010EoookJPGoo`0<5?oonfX001;ooo]Z1ooo00`DoookJPOoo`0@5?oonfX7ool05Q?ooo]Z1_oo
01lDoookJPCoo`0]5_oonfX4ool0>aKooo]Z1?oo03dFoookJPCoo`0_5_oonfX5ool07aSooo]Z1?oo
01DIoookJP?oo`0B6OoonfX4ool05ASooo]Z1Ooo01lEoookJPGoo`0_5OoonfX5ool0?AKooo]Z1?oo
03/EoookJPGoo`0]4ooonfX7ool07a?ooo]Z1ooo01HDoookJPOoo`0@5?oonfX7ool031;ooo]Z000A
oookJPSoo`0<4ooonfX8ool041?ooo]Z2Ooo01HBoookJPCoo`0O5_oonfX3ool0;AOooo]Z1?oo03/G
oookJP?oo`0m5_oonfX4ool0;aOooo]Z1?oo01lHoookJPCoo`0E6OoonfX3ool04QWooo]Z0ooo01DI
oookJPCoo`0O5_oonfX4ool0;aOooo]Z0ooo03dGoookJPCoo`0k5_oonfX4ool0;AGooo]Z1Ooo01lB
oookJPWoo`0F4_oonfX9ool041?ooo]Z2?oo00`AoookJP003ooonfX;ool0317ooo]Z2_oo010Aoook
JPOoo`0F5?oonfX3ool07aOooo]Z0ooo02dHoookJP?oo`0k6?oonfX3ool0?AOooo]Z0ooo02lHoook
JP?oo`0O6OoonfX3ool05AWooo]Z0ooo018IoookJP?oo`0E6OoonfX3ool07aOooo]Z0ooo02lHoook
JP?oo`0m6?oonfX3ool0>aSooo]Z0_oo02dHoookJP?oo`0O5?oonfX7ool05Q7ooo]Z2_oo010Aoook
JP[oo`0<4?oonfX000kooo]Z2?oo00`DoookJPOoo`0@5?oonfX4ool05QOooo]Z0_oo01lIoookJP;o
o`0]6OoonfX2ool0>aWooo]Z0ooo03dHoookJP;oo`0_6OoonfX2ool07a[ooo]Z0_oo01DJoookJP03
ool04_oonf[ooo]Z01Sooo]Z0_oo01DIoookJP?oo`0O6?oonfX3ool0;aSooo]Z0ooo03dIoookJP;o
o`0k6OoonfX2ool0;AWooo]Z0_oo01lGoookJPCoo`0F5?oonfX7ool041Cooo]Z1ooo00`?oookJP00
3OoonfX3ool031Wooo]Z0ooo010HoookJP;oo`0F6OoonfX2ool07a[ooo]Z00?oo`0]oookJ_oonfX0
6?oonfX2ool0>aWooo]Z0_oo03dIoookJP;oo`0_6_oonfX2ool07a[ooo]Z00?oo`0EoookJ_oonfX0
6?oonfX00ooo01;ooo]ZoookJP0HoookJP03ool05Ooonf[ooo]Z01Sooo]Z0_oo01lIoookJP;oo`0_
6OoonfX3ool0?AWooo]Z0_oo03/JoookJP03ool0;Ooonf[ooo]Z01Sooo]Z0_oo01lIoookJP;oo`0F
6?oonfX3ool041Sooo]Z0ooo00`>oookJP00N_oonfX00ooo02gooo]ZoookJP0IoookJP03ool0>ooo
nf[ooo]Z01Wooo]Z00?oo`0moookJ_oonfX06?oonfX00ooo02oooo]ZoookJP0IoookJP03ool07ooo
nf[ooo]Z06Wooo]Z00?oo`0OoookJ_oonfX06?oonfX00ooo02oooo]ZoookJP0IoookJP03ool0?Ooo
nf[ooo]Z01Wooo]Z00?oo`0koookJ_oonfX06OoonfX00ooo02gooo]ZoookJP1hoookJP00/_oonfX0
0ooo03gooo]ZoookJP3GoookJP03ool0?Ooonf[ooo]Z0;3ooo]Z003ooookJ_oooo]Z@OoonfX00?oo
oo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1
oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooo
nf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7o
oo]Z003ooookJ_oooo]Z@OoonfX007gooo]Z0_oo01`GoookJP?oo`0Q<ooonfX4ool07AKooo]Z1?oo
01LGoookJPCoo`0C5ooonfX7ool04AOooo]Z1?oo01<GoookJPCoo`0G5_oonfX4ool07C?ooo]Z0_oo
024GoookJP;oo`0LO_oonfX006Gooo]Z00?oo`0GoookJ_oonfX05OoonfX4ool071Gooo]Z1_oo024C
oookJPOoo`0Q4ooonfX7ool07A?ooo]Z1ooo01LDoookJPOoo`0C5ooonfX7ool04AOooo]Z1ooo01<D
oookJPKoo`0G5?oonfX6ool07ACooo]Z1_oo024DoookJPGoo`0Q5OoonfX4ool071Sooo]Z00?oo`0G
oookJ_oonfX0HooonfX001Gooo]Z00?oo`0;oookJ_oonfX06?oonfX00ooo00kooo]ZoookJP0Hoook
JP03ool04_oonf[ooo]Z01Oooo]Z0_oo01LFoookJPKoo`0L4ooonfX7ool08A;ooo]Z1ooo024Coook
JPOoo`0M4ooonfX7ool05aCooo]Z1ooo01<GoookJPOoo`0A5ooonfX7ool04aCooo]Z1_oo01LDoook
JPKoo`0M5?oonfX6ool08A?ooo]Z1_oo024DoookJPGoo`0L5ooonfX2ool05aWooo]Z00?oo`0Boook
J_oonfX06?oonfX00ooo00kooo]ZoookJP0HoookJP03ool02ooonf[ooo]Z01?ooo]Z000EoookJP03
ool02ooonf[ooo]Z01Sooo]Z00?oo`0>oookJ_oonfX06?oonfX2ool04QOooo]Z1?oo01LEoookJPOo
o`0L4_oonfX7ool08A;ooo]Z1ooo024DoookJPKoo`0M5?oonfX6ool05aGooo]Z1_oo01<HoookJPGo
o`0A6?oonfX6ool04aGooo]Z1Ooo01LEoookJPKoo`0M5?oonfX6ool08A?ooo]Z1_oo024CoookJPOo
o`0L5OoonfX4ool05aOooo]Z0_oo018JoookJP03ool03_oonf[ooo]Z01Sooo]Z00?oo`0;oookJ_oo
nfX04ooonfX001Cooo]Z0ooo00/HoookJP?oo`0>6?oonfX4ool04QKooo]Z1Ooo01LCoookJPSoo`0L
4_oonfX6ool08ACooo]Z1Ooo024EoookJPGoo`0M5OoonfX6ool05aGooo]Z1_oo01<HoookJPGoo`0A
6?oonfX6ool04aGooo]Z1Ooo01LFoookJPCoo`0M5_oonfX5ool08ACooo]Z1Ooo024CoookJPOoo`0L
5?oonfX5ool05aKooo]Z1?oo018HoookJP?oo`0>6?oonfX3ool02aCooo]Z000CoookJPGoo`0;5_oo
nfX5ool03QKooo]Z1_oo018DoookJPOoo`0G4_oonfX7ool071?ooo]Z1Ooo024EoookJPGoo`0Q5Ooo
nfX5ool07AKooo]Z1Ooo01LFoookJPGoo`0C6?oonfX5ool04ASooo]Z1Ooo01<FoookJPCoo`0G5ooo
nfX4ool07AKooo]Z1?oo024FoookJPCoo`0Q5?oonfX6ool071?ooo]Z1ooo01LDoookJPKoo`0B5_oo
nfX5ool03QKooo]Z1Ooo00/CoookJP004_oonfX6ool02aGooo]Z1_oo00hFoookJPOoo`0B4ooonfX5
ool05aCooo]Z1_oo01`DoookJPGoo`0Q5OoonfX5ool08AKooo]Z1?oo01dFoookJPGoo`0G5_oonfX5
ool04aSooo]Z1Ooo014HoookJPGoo`0C5_oonfX4ool05aOooo]Z1?oo01dFoookJPCoo`0Q5_oonfX4
ool08AGooo]Z1Ooo01`EoookJPGoo`0G4ooonfX7ool04QGooo]Z1ooo00hDoookJPOoo`0;4_oonfX0
017ooo]Z2?oo00/CoookJPSoo`0>5?oonfX6ool04QCooo]Z1Ooo01LEoookJPGoo`0L5OoonfX4ool0
8AOooo]Z0ooo024GoookJPCoo`0M5ooonfX3ool05aSooo]Z1?oo01<IoookJP?oo`0A6OoonfX4ool0
4aOooo]Z0ooo01LHoookJP?oo`0M6?oonfX3ool08AOooo]Z1?oo024EoookJPGoo`0L5OoonfX5ool0
5aCooo]Z1_oo018CoookJPWoo`0>4_oonfX9ool02a7ooo]Z000@oookJPOoo`0;5OoonfX6ool03QGo
oo]Z1Ooo018EoookJPCoo`0G5ooonfX4ool071Kooo]Z1?oo024GoookJP?oo`0Q5ooonfX4ool07AOo
oo]Z0ooo01LIoookJP?oo`0C6OoonfX3ool04AWooo]Z0ooo01<HoookJP?oo`0G6?oonfX3ool07ASo
oo]Z0ooo024GoookJPCoo`0Q5_oonfX4ool071Oooo]Z1?oo01LEoookJPGoo`0B5?oonfX7ool03QCo
oo]Z1ooo00/AoookJP003ooonfX5ool02aOooo]Z1?oo00hGoookJPCoo`0B5ooonfX3ool05aSooo]Z
0ooo01`GoookJP?oo`0Q6?oonfX3ool08ASooo]Z0ooo01dGoookJP?oo`0G6OoonfX3ool04aWooo]Z
0ooo014IoookJP?oo`0C6?oonfX3ool05aSooo]Z0ooo01dHoookJP?oo`0Q6?oonfX3ool08AOooo]Z
0ooo01`HoookJP?oo`0G5ooonfX4ool04QKooo]Z1Ooo00hFoookJPGoo`0;4?oonfX000kooo]Z0ooo
00/IoookJP?oo`0>6OoonfX3ool04QOooo]Z0ooo01LHoookJP?oo`0L6?oonfX2ool08AWooo]Z0ooo
024HoookJP;oo`0M6OoonfX2ool05a[ooo]Z0_oo01<IoookJP?oo`0A6OoonfX2ool04aWooo]Z0_oo
01LJoookJP;oo`0M6?oonfX2ool08A[ooo]Z0_oo024HoookJP;oo`0L6OoonfX3ool05aOooo]Z0ooo
018IoookJP?oo`0>6?oonfX3ool02`oooo]Z000=oookJP;oo`0;6_oonfX00ooo00kooo]ZoookJP0H
oookJP?oo`0B6OoonfX00ooo01Oooo]ZoookJP0HoookJP;oo`0L6OoonfX2ool08A[ooo]Z00?oo`0Q
oookJ_oonfX05ooonfX2ool07AWooo]Z0_oo01LJoookJP;oo`0C6_oonfX00ooo017ooo]ZoookJP0H
oookJP;oo`0C6OoonfX2ool05a[ooo]Z00?oo`0MoookJ_oonfX06?oonfX00ooo027ooo]ZoookJP0H
oookJP;oo`0Q6OoonfX2ool071[ooo]Z00?oo`0GoookJ_oonfX05ooonfX2ool04Q_ooo]Z00?oo`0>
oookJ_oonfX06?oonfX00ooo00_ooo]ZoookJP0<oookJP00A?oonfX00ooo01;ooo]ZoookJP0Hoook
JP03ool05ooonf[ooo]Z01Wooo]Z00?oo`0LoookJ_oonfX06?oonfX00ooo027ooo]ZoookJP0Ioook
JP03ool08Ooonf[ooo]Z01Sooo]Z00?oo`0MoookJ_oonfX06?oonfX00ooo01Oooo]ZoookJP0Ioook
JP03ool04ooonf[ooo]Z01Sooo]Z00?oo`0AoookJ_oonfX06?oonfX00ooo01?ooo]ZoookJP0Hoook
JP03ool05ooonf[ooo]Z01Wooo]Z00?oo`0MoookJ_oonfX06?oonfX00ooo027ooo]ZoookJP0Ioook
JP03ool08Ooonf[ooo]Z01Sooo]Z00?oo`0LoookJ_oonfX06OoonfX00ooo01Oooo]ZoookJP0Hoook
JP03ool04_oonf[ooo]Z04;ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooo
nf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7o
oo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooook
J_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@Ooo
nfX00?oooo]ZoooonfY1oookJP00OOoonfX2ool04aOooo]Z0_oo01DIoookJPCoo`0F<_oonfX4ool0
4QOooo]Z1?oo010coookJPCoo`0@5ooonfX4ool04S;ooo]Z1?oo01HHoookJP;oo`0E5ooonfX2ool0
4gkooo]Z000]oookJP;oo`0<=?oonfX2ool04ASooo]Z1?oo01<EoookJPGoo`0E5_oonfX7ool05Q;o
oo]Z1ooo01@CoookJPOoo`0B5?oonfX7ool041Kooo]Z1ooo00lFoookJPKoo`0@5OoonfX7ool04Q?o
oo]Z1ooo01@BoookJPOoo`0F5OoonfX5ool05AGooo]Z1?oo01<HoookJP03ool04Ooonf[ooo]Z06?o
oo]Z000CoookJP;oo`096?oonfX4ool031Wooo]Z00?oo`0>oookJ_oonfX05_oonfX4ool04AKooo]Z
1Ooo01<DoookJPKoo`0E5OoonfX7ool05Q;ooo]Z1ooo01@CoookJPOoo`0B5?oonfX7ool041Kooo]Z
1ooo00lFoookJPKoo`0@5OoonfX7ool04Q?ooo]Z1ooo01@BoookJPOoo`0F4ooonfX7ool05ACooo]Z
1Ooo01<GoookJP;oo`0A6_oonfX00ooo00kooo]ZoookJP0HoookJP03ool03?oonf[ooo]Z01Sooo]Z
00?oo`09oookJ_oonfX04_oonfX001?ooo]Z0ooo00TFoookJPKoo`0<6?oonfX2ool03QKooo]Z1_oo
014EoookJPKoo`0C4ooonfX6ool05AGooo]Z1_oo01HCoookJPOoo`0D5?oonfX6ool04QGooo]Z1_oo
010FoookJPOoo`0?5_oonfX5ool041Kooo]Z1_oo018DoookJPOoo`0D4ooonfX6ool05Q?ooo]Z1ooo
01DCoookJPOoo`0C5OoonfX4ool04ASooo]Z0_oo00hIoookJP;oo`0<6OoonfX2ool02ACooo]Z000B
oookJPGoo`095OoonfX7ool031Kooo]Z1?oo00hEoookJPOoo`0A4ooonfX7ool04a?ooo]Z1Ooo01DF
oookJPKoo`0F5?oonfX5ool051Gooo]Z1Ooo018FoookJPKoo`0@5ooonfX5ool03aOooo]Z1Ooo010F
oookJPKoo`0B5OoonfX5ool051Cooo]Z1_oo01HDoookJPKoo`0E4ooonfX7ool04aCooo]Z1Ooo014G
oookJPCoo`0>5ooonfX4ool031Oooo]Z1?oo00TCoookJP004OoonfX7ool02ACooo]Z1Ooo00`Goook
JPKoo`0>5?oonfX5ool04AGooo]Z1_oo01<DoookJPGoo`0E5_oonfX5ool05QGooo]Z1Ooo01@Eoook
JPGoo`0B5ooonfX5ool041Oooo]Z1Ooo00lGoookJPGoo`0@5_oonfX5ool04QKooo]Z1Ooo01@Eoook
JPGoo`0F5OoonfX5ool05ACooo]Z1_oo01<CoookJPOoo`0A5OoonfX6ool03QGooo]Z1_oo00`Eoook
JPKoo`094_oonfX0017ooo]Z2?oo00TBoookJPGoo`0<6?oonfX7ool03Q;ooo]Z1Ooo014FoookJPGo
o`0C5OoonfX4ool05AOooo]Z1Ooo01HEoookJPGoo`0D5_oonfX4ool04QOooo]Z1Ooo010GoookJPGo
o`0?5ooonfX4ool041Oooo]Z1Ooo018FoookJPGoo`0D5OoonfX5ool05QGooo]Z1Ooo01DEoookJPGo
o`0C5OoonfX5ool04ACooo]Z1ooo00hDoookJPOoo`0<5?oonfX7ool02A;ooo]Z000@oookJPOoo`09
5?oonfX4ool031Sooo]Z1_oo00hDoookJPCoo`0A5ooonfX4ool04aKooo]Z1?oo01DGoookJPCoo`0F
5ooonfX3ool051Oooo]Z1?oo018HoookJP?oo`0@6OoonfX3ool03aWooo]Z0ooo010HoookJP?oo`0B
6?oonfX3ool051Oooo]Z0ooo01HGoookJPGoo`0E5OoonfX5ool04aGooo]Z1Ooo014EoookJPKoo`0>
5OoonfX6ool031Gooo]Z1_oo00TAoookJP004?oonfX5ool02AKooo]Z0ooo00`IoookJPCoo`0>5_oo
nfX3ool04ASooo]Z0ooo01<GoookJP?oo`0E6?oonfX3ool05QSooo]Z0ooo01@GoookJPCoo`0B6?oo
nfX3ool041Wooo]Z0ooo00lIoookJP?oo`0@6?oonfX3ool04QSooo]Z0ooo01@GoookJP?oo`0F6?oo
nfX4ool05AKooo]Z1?oo01<FoookJPCoo`0A5ooonfX4ool03QOooo]Z1?oo00`GoookJPCoo`094Ooo
nfX000oooo]Z1?oo00TGoookJP?oo`0<6OoonfX4ool03QKooo]Z0ooo014IoookJP?oo`0C5ooonfX3
ool05ASooo]Z0ooo01HHoookJP?oo`0D6?oonfX3ool04QSooo]Z0ooo010IoookJP?oo`0?6OoonfX2
ool041Wooo]Z0ooo018HoookJP?oo`0D5ooonfX3ool05QWooo]Z0ooo01DGoookJP?oo`0C6?oonfX2
ool04ASooo]Z1?oo00hGoookJPCoo`0<5ooonfX4ool02A3ooo]Z000>oookJPCoo`096?oonfX2ool0
31Wooo]Z0ooo00hHoookJP;oo`0A6OoonfX3ool04aSooo]Z0_oo01DIoookJP;oo`0F6OoonfX3ool0
51Sooo]Z0_oo018JoookJP;oo`0@6OoonfX3ool03aWooo]Z0_oo010IoookJP;oo`0B6OoonfX3ool0
51Sooo]Z0_oo01HIoookJP?oo`0E6?oonfX2ool04aWooo]Z0_oo014IoookJP?oo`0>6?oonfX3ool0
31Sooo]Z0ooo00T?oookJP003_oonfX2ool02A[ooo]Z00?oo`0<oookJ_oonfX06?oonfX00ooo00ko
oo]ZoookJP0HoookJP03ool04Ooonf[ooo]Z01Sooo]Z0_oo01<IoookJP;oo`0E6OoonfX2ool05Q[o
oo]Z00?oo`0DoookJ_oonfX05ooonfX2ool04Q[ooo]Z0_oo010JoookJP03ool03ooonf[ooo]Z01So
oo]Z0_oo010IoookJP;oo`0B6_oonfX00ooo01Cooo]ZoookJP0GoookJP;oo`0F6_oonfX2ool05AWo
oo]Z0_oo01<IoookJP03ool04Ooonf[ooo]Z01Wooo]Z00?oo`0>oookJ_oonfX06?oonfX00ooo00co
oo]ZoookJP0HoookJP03ool02Ooonf[ooo]Z00gooo]Z000=oookJP;oo`096_oonfX00ooo00cooo]Z
oookJP0HoookJP03ool03_oonf[ooo]Z01Sooo]Z0_oo014JoookJP03ool04ooonf[ooo]Z01Sooo]Z
00?oo`0EoookJ_oonfX06?oonfX2ool05Q[ooo]Z00?oo`0DoookJ_oonfX06?oonfX00ooo01;ooo]Z
oookJP0IoookJP03ool04?oonf[ooo]Z01Sooo]Z00?oo`0?oookJ_oonfX06?oonfX00ooo013ooo]Z
oookJP0HoookJP;oo`0B6_oonfX00ooo01Cooo]ZoookJP0HoookJP03ool05_oonf[ooo]Z01Wooo]Z
00?oo`0EoookJ_oonfX06?oonfX00ooo01?ooo]ZoookJP0HoookJP03ool04Ooonf[ooo]Z01Sooo]Z
0_oo00hJoookJP03ool03?oonf[ooo]Z01Sooo]Z00?oo`09oookJ_oonfX03?oonfX00?oooo]Zoooo
nfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00
oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooook
JT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003o
oookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z002GoookJP;oo`0?
oooonfX>oookJP;oo`0?UooonfX006?ooo]Z0_oo00dIoookJP;oo`0>5ooonfX5ool03aKooo]Z1?oo
010FoookJPOoo`0?4_oonfX7ool03QGooo]Z1_oo00hEoookJPOoo`0=5?oonfX7ool03QGooo]Z1_oo
00hCoookJPOoo`0?5_oonfX4ool041Kooo]Z1Ooo00lGoookJP;oo`0>6OoonfX2ool03F?ooo]Z000_
oookJP03ool02Ooonf[ooo]Z01Sooo]Z00?oo`0;oookJ_oonfX05_oonfX4ool03AOooo]Z1?oo00hE
oookJPKoo`0?5OoonfX6ool041Cooo]Z1ooo00lBoookJPOoo`0>5OoonfX6ool03QGooo]Z1ooo00dD
oookJPOoo`0>5OoonfX6ool03Q?ooo]Z1ooo00lCoookJPOoo`0@5?oonfX7ool03aGooo]Z1?oo00hG
oookJPCoo`0=6?oonfX00ooo00_ooo]ZoookJP0HoookJP03ool02Ooonf[ooo]Z02gooo]Z000Eoook
JP03ool02?oonf[ooo]Z01Oooo]Z0_oo00TIoookJP;oo`0;5_oonfX6ool03AKooo]Z1Ooo00hDoook
JPKoo`0?5OoonfX6ool041Cooo]Z1_oo00lCoookJPOoo`0>5OoonfX6ool03QGooo]Z1ooo00dDoook
JPOoo`0>5OoonfX6ool03QCooo]Z1_oo00lCoookJPOoo`0@5?oonfX7ool03aCooo]Z1Ooo00hFoook
JPGoo`0=5ooonfX2ool02aWooo]Z0_oo00THoookJP03ool02?oonf[ooo]Z01Cooo]Z000EoookJP03
ool02?oonf[ooo]Z01Kooo]Z1?oo00TGoookJPCoo`0;5OoonfX7ool03ACooo]Z1ooo00hCoookJPGo
o`0?5_oonfX5ool041Gooo]Z1_oo00lDoookJPGoo`0>5ooonfX5ool03QKooo]Z1Ooo00dFoookJPGo
o`0>5ooonfX5ool03QCooo]Z1_oo00lDoookJPKoo`0@5OoonfX6ool03a?ooo]Z1ooo00hDoookJPOo
o`0=5OoonfX4ool02aOooo]Z1?oo00TGoookJP03ool02?oonf[ooo]Z01Cooo]Z000DoookJP?oo`08
5_oonfX6ool02AGooo]Z1_oo00/DoookJPGoo`0=5_oonfX6ool03QCooo]Z1?oo00lGoookJPCoo`0@
5_oonfX5ool03aGooo]Z1Ooo00hGoookJPCoo`0>5ooonfX5ool03AKooo]Z1Ooo00hGoookJPCoo`0>
5_oonfX5ool03aGooo]Z1Ooo010FoookJPGoo`0?5?oonfX6ool03QGooo]Z1_oo00dDoookJPKoo`0;
5OoonfX6ool02AGooo]Z0ooo00PEoookJP004ooonfX5ool021Gooo]Z1ooo00TDoookJPOoo`0;4_oo
nfX5ool03AOooo]Z1Ooo00hEoookJPCoo`0?5ooonfX4ool041Kooo]Z1Ooo00lEoookJPGoo`0>5ooo
nfX4ool03QOooo]Z1Ooo00dFoookJPGoo`0>5ooonfX4ool03QKooo]Z1Ooo00lEoookJPGoo`0@5_oo
nfX5ool03aGooo]Z1Ooo00hFoookJPGoo`0=4ooonfX7ool02aCooo]Z1ooo00TDoookJPGoo`085?oo
nfX001;ooo]Z1ooo00PCoookJPKoo`095OoonfX6ool02aCooo]Z1?oo00dGoookJPGoo`0>5OoonfX4
ool03aOooo]Z1?oo010HoookJP?oo`0?5ooonfX3ool03QWooo]Z0ooo00hHoookJP?oo`0=6?oonfX3
ool03QWooo]Z0ooo00hGoookJP?oo`0?5ooonfX4ool041Oooo]Z1Ooo00lEoookJPGoo`0>5_oonfX5
ool03ACooo]Z1_oo00/EoookJPKoo`094ooonfX6ool021?ooo]Z000AoookJPWoo`084_oonfX4ool0
2AOooo]Z1?oo00/FoookJP?oo`0=6?oonfX4ool03QKooo]Z1?oo00lGoookJPCoo`0@6?oonfX3ool0
3aOooo]Z0ooo00hIoookJP?oo`0>6?oonfX3ool03ASooo]Z0ooo00hIoookJP?oo`0>5ooonfX3ool0
3aOooo]Z1?oo010HoookJPCoo`0?5_oonfX4ool03QOooo]Z1?oo00dFoookJPCoo`0;5ooonfX4ool0
2A;ooo]Z2?oo00PBoookJP004?oonfX8ool021?ooo]Z1?oo00TGoookJPCoo`0;5_oonfX3ool03AWo
oo]Z0ooo00hGoookJP?oo`0?6?oonfX3ool041Wooo]Z0ooo00lGoookJP?oo`0>6OoonfX3ool03QSo
oo]Z0ooo00dHoookJP?oo`0>6OoonfX3ool03QOooo]Z0ooo00lHoookJP?oo`0@6OoonfX3ool03aOo
oo]Z0ooo00hHoookJP?oo`0=5ooonfX4ool02aOooo]Z1?oo00TCoookJPOoo`084OoonfX000oooo]Z
1_oo00PEoookJP?oo`096?oonfX3ool02aSooo]Z0_oo00dJoookJP;oo`0>6?oonfX2ool03aWooo]Z
0_oo010JoookJP;oo`0?6?oonfX3ool03QWooo]Z0_oo00hIoookJP?oo`0=6?oonfX3ool03QWooo]Z
0_oo00hIoookJP;oo`0?6OoonfX2ool041Wooo]Z0ooo00lHoookJP;oo`0>6OoonfX2ool03AWooo]Z
0ooo00/HoookJP?oo`095OoonfX5ool0213ooo]Z000>oookJPCoo`086?oonfX00ooo00Wooo]Zoook
JP0HoookJP03ool02ooonf[ooo]Z01Sooo]Z00?oo`0=oookJ_oonfX06?oonfX2ool03QWooo]Z0_oo
00lIoookJP;oo`0@6_oonfX2ool03aWooo]Z00?oo`0>oookJ_oonfX06OoonfX00ooo00kooo]Zoook
JP0HoookJP03ool03Ooonf[ooo]Z01Sooo]Z00?oo`0>oookJ_oonfX06OoonfX00ooo00kooo]Zoook
JP0GoookJP;oo`0?6OoonfX2ool041[ooo]Z0_oo00lIoookJP;oo`0>6OoonfX2ool03A[ooo]Z00?o
o`0;oookJ_oonfX06?oonfX00ooo00Wooo]ZoookJP0FoookJP?oo`083ooonfX000gooo]Z0_oo00PJ
oookJP03ool02Ooonf[ooo]Z01Sooo]Z00?oo`0;oookJ_oonfX06?oonfX2ool03A[ooo]Z00?oo`0>
oookJ_oonfX06?oonfX00ooo00oooo]ZoookJP0HoookJP;oo`0@6_oonfX00ooo00oooo]ZoookJP0H
oookJP03ool03_oonf[ooo]Z01Wooo]Z00?oo`0>oookJ_oonfX06?oonfX00ooo00gooo]ZoookJP0H
oookJP03ool03_oonf[ooo]Z01Wooo]Z00?oo`0>oookJ_oonfX06?oonfX00ooo00oooo]ZoookJP0H
oookJP03ool04?oonf[ooo]Z01Wooo]Z00?oo`0?oookJ_oonfX06?oonfX00ooo00kooo]ZoookJP0H
oookJP03ool03Ooonf[ooo]Z01Sooo]Z0_oo00/JoookJP03ool02Ooonf[ooo]Z01Sooo]Z00?oo`08
oookJ_oonfX03?oonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z
@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oo
oo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1
oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooo
nf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX002gooo]Z0_oo00PcoookJP;oo`0:6OoonfX2ool0
2aOooo]Z1?oo00`IoookJP;oo`0<5ooonfX4ool031Gooo]Z1ooo00`EoookJPKoo`0<5OoonfX7ool0
2aCooo]Z1ooo00`EoookJPKoo`0<5_oonfX3ool031Sooo]Z0_oo00`IoookJPCoo`0<5_oonfX2ool0
2a[ooo]Z0_oo00XcoookJP;oo`08;OoonfX001Cooo]Z00?oo`07oookJ_oonfX05_oonfX4ool021Wo
oo]Z00?oo`09oookJ_oonfX05OoonfX4ool02QOooo]Z1?oo00/EoookJPKoo`0<5ooonfX5ool031Co
oo]Z1ooo00`BoookJPOoo`0<5OoonfX6ool031Gooo]Z1ooo00/DoookJPOoo`0<5OoonfX6ool031?o
oo]Z1_oo00`EoookJPGoo`0<5_oonfX7ool031Cooo]Z1?oo00/HoookJPCoo`0:5_oonfX2ool02AWo
oo]Z1?oo00PHoookJP03ool01ooonf[ooo]Z01;ooo]Z000DoookJP;oo`075_oonfX6ool021Sooo]Z
0_oo00TFoookJPGoo`0:5_oonfX5ool02aCooo]Z1_oo00`GoookJPKoo`0<4ooonfX7ool031;ooo]Z
1ooo00`EoookJPKoo`0<5OoonfX7ool02aCooo]Z1ooo00`EoookJPKoo`0<4ooonfX6ool031?ooo]Z
1ooo00`FoookJPOoo`0<4ooonfX5ool02aOooo]Z1Ooo00XEoookJP?oo`096?oonfX6ool021Kooo]Z
0_oo00LDoookJP004ooonfX4ool01aGooo]Z1ooo00PFoookJPCoo`095?oonfX7ool02QGooo]Z1_oo
00/CoookJPGoo`0<6?oonfX6ool031?ooo]Z1_oo00`DoookJPGoo`0<5ooonfX5ool031Kooo]Z1Ooo
00/FoookJPGoo`0<5ooonfX5ool031Cooo]Z1Ooo00`CoookJPOoo`0<5ooonfX6ool031;ooo]Z1ooo
00/EoookJPKoo`0:5?oonfX5ool02AKooo]Z1ooo00PEoookJPCoo`074ooonfX001;ooo]Z1_oo00LD
oookJPGoo`085ooonfX6ool02A?ooo]Z1_oo00XEoookJPOoo`0;4ooonfX5ool031Oooo]Z1_oo00`D
oookJPKoo`0<5?oonfX5ool031Oooo]Z1?oo00`GoookJPGoo`0;5_oonfX5ool031Oooo]Z1?oo00`E
oookJPGoo`0<5?oonfX6ool031Oooo]Z1_oo00`CoookJPKoo`0;5OoonfX7ool02Q;ooo]Z1ooo00TG
oookJPGoo`085?oonfX6ool01a;ooo]Z000BoookJPOoo`074_oonfX5ool021Sooo]Z1ooo00TBoook
JPGoo`0:5_oonfX6ool02aCooo]Z1?oo00`HoookJPGoo`0<5OoonfX5ool031Gooo]Z1Ooo00`Goook
JPCoo`0<5ooonfX5ool02aKooo]Z1Ooo00`GoookJPCoo`0<5_oonfX4ool031Gooo]Z1Ooo00`Hoook
JPGoo`0<5?oonfX5ool02aKooo]Z1_oo00XAoookJPSoo`096?oonfX5ool021;ooo]Z1ooo00LBoook
JP004OoonfX6ool01aCooo]Z1?oo00PHoookJPKoo`094ooonfX5ool02QOooo]Z1Ooo00/EoookJPCo
o`0<6?oonfX5ool031Gooo]Z1Ooo00`EoookJPGoo`0<5ooonfX4ool031Oooo]Z1Ooo00/FoookJPGo
o`0<5ooonfX4ool031Kooo]Z1?oo00`EoookJPGoo`0<6?oonfX5ool031Gooo]Z1Ooo00/FoookJPGo
o`0:4ooonfX7ool02ASooo]Z1?oo00PDoookJPKoo`074OoonfX0013ooo]Z1Ooo00LFoookJP?oo`08
6OoonfX4ool02AGooo]Z1?oo00XHoookJPCoo`0;5_oonfX3ool031Wooo]Z1?oo00`GoookJP?oo`0<
5ooonfX3ool031Wooo]Z0ooo00`HoookJP?oo`0;6?oonfX3ool031Wooo]Z0ooo00`GoookJP?oo`0<
5_oonfX5ool031Sooo]Z1?oo00`FoookJPCoo`0;5ooonfX4ool02QGooo]Z1Ooo00TIoookJP?oo`08
5_oonfX4ool01a7ooo]Z000?oookJPCoo`075ooonfX3ool021Wooo]Z1?oo00TFoookJP?oo`0:6Ooo
nfX3ool02aOooo]Z0ooo00`IoookJP?oo`0<6?oonfX3ool031Oooo]Z0ooo00`IoookJP?oo`0<6?oo
nfX3ool02aSooo]Z0ooo00`IoookJP?oo`0<5ooonfX3ool031Oooo]Z1?oo00`IoookJP?oo`0<5ooo
nfX3ool02aSooo]Z0ooo00XGoookJPCoo`096OoonfX3ool021Kooo]Z1?oo00L@oookJP003ooonfX3
ool01aSooo]Z0_oo00PIoookJP?oo`096?oonfX2ool02QWooo]Z0ooo00/HoookJP?oo`0<6OoonfX2
ool031Wooo]Z0ooo00`GoookJP?oo`0<6OoonfX3ool031Sooo]Z0ooo00/HoookJP?oo`0<6OoonfX3
ool031Oooo]Z0ooo00`HoookJP?oo`0<6OoonfX3ool031Sooo]Z0_oo00/IoookJP?oo`0:5ooonfX4
ool02AWooo]Z0_oo00PHoookJP?oo`073ooonfX000kooo]Z0_oo00LJoookJP03ool02?oonf[ooo]Z
01Sooo]Z00?oo`09oookJ_oonfX05ooonfX2ool02Q[ooo]Z0_oo00/IoookJP;oo`0<6OoonfX3ool0
31Wooo]Z0_oo00`HoookJP?oo`0<6OoonfX2ool031Wooo]Z0ooo00/HoookJP?oo`0<6OoonfX2ool0
31Wooo]Z0_oo00`HoookJP?oo`0<6_oonfX2ool031Wooo]Z0_oo00/IoookJP;oo`0:6OoonfX2ool0
2A[ooo]Z00?oo`08oookJ_oonfX06?oonfX00ooo00Oooo]ZoookJP0=oookJP003OoonfX2ool01a[o
oo]Z00?oo`08oookJ_oonfX06?oonfX00ooo00Wooo]ZoookJP0HoookJP;oo`0:6_oonfX00ooo00_o
oo]ZoookJP0HoookJP;oo`0<6OoonfX2ool031[ooo]Z0_oo00`IoookJP03ool03?oonf[ooo]Z01Wo
oo]Z00?oo`0<oookJ_oonfX06?oonfX00ooo00_ooo]ZoookJP0HoookJP03ool03?oonf[ooo]Z01Wo
oo]Z00?oo`0<oookJ_oonfX05ooonfX2ool031Wooo]Z0_oo00`JoookJP;oo`0<6_oonfX00ooo00_o
oo]ZoookJP0HoookJP03ool02_oonf[ooo]Z01Sooo]Z0_oo00TJoookJP03ool02?oonf[ooo]Z01So
oo]Z00?oo`07oookJ_oonfX03?oonfX007_ooo]Z00?oo`0;oookJ_oonfX06?oonfX00ooo00cooo]Z
oookJP0HoookJP03ool03?oonf[ooo]Z01Wooo]Z00?oo`0<oookJ_oonfX06?oonfX00ooo00cooo]Z
oookJP0IoookJP03ool03?oonf[ooo]Z01Sooo]Z00?oo`0;oookJ_oonfX06?oonfX00ooo00cooo]Z
oookJP0IoookJP03ool03?oonf[ooo]Z01Sooo]Z00?oo`0<oookJ_oonfX06?oonfX00ooo00cooo]Z
oookJP0IoookJP03ool03?oonf[ooo]Z01Sooo]Z00?oo`0;oookJ_oonfX0NOoonfX00?oooo]Zoooo
nfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00
oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooook
JT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003o
oookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z001koookJPCoo`09
5ooonfX4ool02ASooo]Z1?oo00TFoookJPCoo`0:5OoonfX7ool02QGooo]Z1_oo00TEoookJPOoo`09
5?oonfX7ool02AGooo]Z1_oo00XFoookJP?oo`0:6?oonfX3ool02ASooo]Z1?oo00TFoookJP;oo`09
O_oonfX002gooo]Z0_oo00LIoookJP;oo`076OoonfX2ool021Kooo]Z1_oo00TEoookJPOoo`095Ooo
nfX6ool02ACooo]Z1ooo00XBoookJPOoo`0:5OoonfX6ool02AGooo]Z1ooo00TDoookJPOoo`095Ooo
nfX6ool02Q?ooo]Z1_oo00XEoookJPKoo`095OoonfX7ool02ACooo]Z1?oo00THoookJP;oo`086_oo
nfX2ool01aWooo]Z0_oo00L]oookJP005?oonfX00ooo00Kooo]ZoookJP0FoookJPCoo`075ooonfX4
ool01aOooo]Z1?oo00PDoookJPKoo`095OoonfX7ool02AGooo]Z1_oo00TDoookJPOoo`0:4_oonfX7
ool02QGooo]Z1_oo00TEoookJPOoo`095?oonfX7ool02AGooo]Z1_oo00XCoookJPKoo`0:5OoonfX6
ool02AGooo]Z1ooo00TCoookJPGoo`095_oonfX4ool021Sooo]Z1?oo00LGoookJPCoo`076?oonfX0
0ooo00Kooo]ZoookJP0BoookJP005?oonfX2ool01QKooo]Z1_oo00LEoookJPKoo`075OoonfX6ool0
21?ooo]Z1Ooo00TFoookJPKoo`095_oonfX5ool02AGooo]Z1_oo00XDoookJPGoo`0:5ooonfX5ool0
2AKooo]Z1Ooo00TFoookJPGoo`095ooonfX5ool02QCooo]Z1Ooo00XFoookJPGoo`095_oonfX6ool0
2A;ooo]Z1ooo00TDoookJPKoo`085_oonfX6ool01aGooo]Z1_oo00LFoookJP;oo`065?oonfX001?o
oo]Z1?oo00HEoookJPOoo`075?oonfX7ool01aCooo]Z1ooo00PBoookJPGoo`095_oonfX6ool02AKo
oo]Z1Ooo00TEoookJPKoo`0:5?oonfX5ool02QOooo]Z1?oo00TGoookJPGoo`095_oonfX5ool02AOo
oo]Z1?oo00XEoookJPGoo`0:5_oonfX5ool02AKooo]Z1_oo00TBoookJPOoo`094ooonfX7ool021Go
oo]Z1ooo00LDoookJPOoo`075OoonfX4ool01Q?ooo]Z000BoookJPKoo`065?oonfX5ool01aKooo]Z
1Ooo00LFoookJPGoo`085?oonfX4ool02AOooo]Z1Ooo00TGoookJPCoo`095_oonfX5ool02QGooo]Z
1Ooo00XGoookJPCoo`095ooonfX5ool02AKooo]Z1Ooo00TGoookJPCoo`0:5_oonfX4ool02QOooo]Z
1?oo00TGoookJPGoo`094ooonfX6ool02AGooo]Z1Ooo00PGoookJPGoo`075_oonfX5ool01aCooo]Z
1_oo00HBoookJP004_oonfX7ool01Q;ooo]Z1Ooo00LFoookJPGoo`075_oonfX5ool021Gooo]Z1?oo
00TGoookJPGoo`095ooonfX4ool02AKooo]Z1Ooo00XEoookJPGoo`0:5ooonfX4ool02AOooo]Z1Ooo
00TFoookJPGoo`095ooonfX4ool02QKooo]Z1?oo00XGoookJPCoo`095ooonfX5ool02ACooo]Z1Ooo
00TFoookJPGoo`085ooonfX5ool01aKooo]Z1Ooo00LBoookJPOoo`064_oonfX0017ooo]Z1_oo00HD
oookJPCoo`075ooonfX4ool01aOooo]Z1?oo00PFoookJP?oo`096?oonfX4ool02ASooo]Z0ooo00TH
oookJP?oo`0:5ooonfX3ool02QWooo]Z0ooo00THoookJP?oo`096?oonfX3ool02AWooo]Z0ooo00XG
oookJP?oo`0:6?oonfX3ool02ASooo]Z1?oo00TEoookJPGoo`095_oonfX4ool021Sooo]Z1?oo00LG
oookJPCoo`075?oonfX6ool01Q7ooo]Z000@oookJPGoo`065_oonfX3ool01aSooo]Z0ooo00LHoook
JP?oo`085ooonfX3ool02ASooo]Z0ooo00TIoookJP?oo`096?oonfX3ool02QOooo]Z0ooo00XIoook
JP?oo`096?oonfX3ool02ASooo]Z0ooo00TIoookJP?oo`0:5ooonfX3ool02QSooo]Z0ooo00TIoook
JP?oo`095_oonfX4ool02AOooo]Z0ooo00PIoookJP?oo`076?oonfX3ool01aKooo]Z1?oo00HAoook
JP003ooonfX4ool01QOooo]Z0ooo00LHoookJP?oo`076?oonfX3ool021Sooo]Z0ooo00THoookJP?o
o`096OoonfX3ool02ASooo]Z0ooo00XGoookJP?oo`0:6OoonfX3ool02ASooo]Z0ooo00THoookJP?o
o`096OoonfX3ool02QOooo]Z0ooo00XHoookJP?oo`096OoonfX3ool02AOooo]Z0ooo00THoookJP?o
o`086OoonfX3ool01aSooo]Z0ooo00LFoookJPCoo`064?oonfX000oooo]Z0ooo00HHoookJP;oo`07
6OoonfX2ool01aWooo]Z0_oo00PIoookJP;oo`096OoonfX2ool02A[ooo]Z0_oo00TIoookJP;oo`0:
6?oonfX3ool02QWooo]Z0_oo00TIoookJP?oo`096?oonfX3ool02AWooo]Z0_oo00XIoookJP;oo`0:
6OoonfX2ool02A[ooo]Z0_oo00THoookJP;oo`096OoonfX2ool021[ooo]Z0_oo00LIoookJP;oo`07
6?oonfX3ool01Poooo]Z000>oookJP;oo`066_oonfX00ooo00Oooo]ZoookJP0HoookJP03ool01ooo
nf[ooo]Z01Sooo]Z00?oo`08oookJ_oonfX06?oonfX2ool02AWooo]Z0_oo00TJoookJP;oo`096Ooo
nfX2ool02QWooo]Z00?oo`0:oookJ_oonfX06OoonfX00ooo00Wooo]ZoookJP0HoookJP03ool02Ooo
nf[ooo]Z01Sooo]Z00?oo`09oookJ_oonfX06OoonfX00ooo00[ooo]ZoookJP0GoookJP;oo`0:6Ooo
nfX2ool02A[ooo]Z0_oo00TIoookJP;oo`096OoonfX00ooo00Sooo]ZoookJP0IoookJP03ool01ooo
nf[ooo]Z01Sooo]Z00?oo`07oookJ_oonfX06?oonfX00ooo00Kooo]ZoookJP0=oookJP003OoonfX2
ool01Q[ooo]Z00?oo`07oookJ_oonfX06?oonfX00ooo00Oooo]ZoookJP0HoookJP;oo`086_oonfX0
0ooo00Wooo]ZoookJP0HoookJP03ool02Ooonf[ooo]Z01Wooo]Z00?oo`09oookJ_oonfX06?oonfX0
0ooo00[ooo]ZoookJP0HoookJP03ool02_oonf[ooo]Z01Wooo]Z00?oo`09oookJ_oonfX06?oonfX0
0ooo00Wooo]ZoookJP0HoookJP03ool02Ooonf[ooo]Z01Wooo]Z00?oo`0:oookJ_oonfX06?oonfX0
0ooo00[ooo]ZoookJP0HoookJP03ool02Ooonf[ooo]Z01Wooo]Z00?oo`09oookJ_oonfX06?oonfX0
0ooo00Wooo]ZoookJP0HoookJP03ool02?oonf[ooo]Z01Sooo]Z0_oo00LJoookJP03ool01ooonf[o
oo]Z01Sooo]Z00?oo`06oookJ_oonfX03?oonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7o
oo]Z003ooookJ_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooook
J_oooo]Z@OoonfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@Ooo
nfX00?oooo]ZoooonfY1oookJP00oooonf[ooookJT7ooo]Z003ooookJ_oooo]Z@OoonfX00?oooo]Z
oooonfY1oookJP00\
\>"],
  ImageRangeCache->{{{0, 574.75}, {574.688, 0}} -> {-2.1032, -2.10381, \
0.00731868, 0.00731868}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Function that takes a two-dimensional vector function of (x,y) as \
an argument and returns its divergence\
\>", "Text"],

Cell[BoxData[
    \(divergence[{xcomp_\ , \ ycomp_}]\  := \ 
      Simplify[D[xcomp, x]\  + \ D[ycomp, y]]\)], "Input",
  CellTags->"mmtag:13:divergence__example_function"],

Cell[CellGroupData[{

Cell[BoxData[
    \(divgradthreehole\  = \ 
      divergence[gradfield[ThreeHolePotential]] // Simplify\)], "Input"],

Cell[BoxData[
    \(\(-\(\(3\ \((\@3 - 2\ x)\)\^2\)\/\(4\ \((1 - \@3\ x + x\^2 - y + \
y\^2)\)\^\(5/2\)\)\)\) - \(3\ \((1 - 2\ y)\)\^2\)\/\(4\ \((1 - \@3\ x + x\^2 \
- y + y\^2)\)\^\(5/2\)\) + 
      2\/\((1 - \@3\ x + x\^2 - y + y\^2)\)\^\(3/2\) - \(3\ \((\@3 + 2\ \
x)\)\^2\)\/\(4\ \((1 + \@3\ x + x\^2 - y + y\^2)\)\^\(5/2\)\) - \(3\ \((1 - 2\
\ y)\)\^2\)\/\(4\ \((1 + \@3\ x + x\^2 - y + y\^2)\)\^\(5/2\)\) + 
      2\/\((1 + \@3\ x + x\^2 - y + y\^2)\)\^\(3/2\) - \(3\ x\^2\)\/\((x\^2 + \
\((1 + y)\)\^2)\)\^\(5/2\) - \(3\ \((1 + y)\)\^2\)\/\((x\^2 + \((1 + y)\)\^2)\
\)\^\(5/2\) + 2\/\((x\^2 + \((1 + y)\)\^2)\)\^\(3/2\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(Plotting\ the\ divergence\ of\ the\ gradient\ \((\[Del]\(\(\[CenterDot]\
\)\((\[Del]\ f)\)\)\ is\ the\ ``Laplacian''\ \[Del]\^2\ f, \ 
        sometimes\ indicated\ with\ symbol\ \[CapitalDelta]f)\)\)], "Text",
  FontFamily->"Helvetica",
  CellTags->
  "mmtag:13:laplacian__example_divegence_of_gradient_of_1/r_potentials"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[divgradthreehole, {x, \(-2\), 2}, {y, \(-2\), 2}, 
      PlotPoints -> 60]\)], "Input",
  CellTags->"mmtag:13:Plot3D[]__example_divegence_of_1/r_potentials"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -26.9375 -19.3395 ]
[.02757 .24618 0 .66054 ]
[.17646 .18758 -26.486 -20 ]
[.17646 .18758 .45147 0 ]
[.3345 .12542 -13.0356 -20 ]
[.3345 .12542 .96436 0 ]
[.50253 .05935 -12.3059 -20 ]
[.50253 .05935 1.69409 0 ]
[.68156 -0.01098 -11.5762 -20 ]
[.68156 -0.01098 2.42381 0 ]
[.70096 -0.00478 0 -13.9157 ]
[.70096 -0.00478 26.9375 6.08431 ]
[.78313 .12104 0 -13.6413 ]
[.78313 .12104 26.9375 6.35872 ]
[.8565 .23339 0 -13.4028 ]
[.8565 .23339 14 6.59718 ]
[.9224 .33431 0 -13.1937 ]
[.9224 .33431 14 6.80633 ]
[.98191 .42546 0 -13.0087 ]
[.98191 .42546 14 6.99126 ]
[.0236 .26833 -36.9375 -6.10009 ]
[.0236 .26833 0 13.8999 ]
[.01245 .33822 -36.9375 -6.23149 ]
[.01245 .33822 0 13.7685 ]
[.00078 .41135 -26.9375 -6.36963 ]
[.00078 .41135 0 13.6304 ]
[-0.01144 .48795 -14 -6.51502 ]
[-0.01144 .48795 0 13.485 ]
[ -0.005 -0.005 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -87.9375 -23.3395 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -87.486 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -74.0356 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -73.3059 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -72.5762 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.01 w
.68874 0 m
.96935 .42924 L
s
.25 Mabswid
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -17.9157 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -17.6413 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -17.4028 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -17.1937 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -17.0087 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.01 w
.03716 .25514 m
0 .48963 L
s
.25 Mabswid
.03582 .26357 m
.04194 .26118 L
s
gsave
.0236 .26833 -97.9375 -10.1001 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.02473 .33359 m
.03087 .33128 L
s
gsave
.01245 .33822 -97.9375 -10.2315 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.01311 .40687 m
.01928 .40463 L
s
gsave
.00078 .41135 -87.9375 -10.3696 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.00095 .48363 m
.00715 .48147 L
s
gsave
-0.01144 .48795 -75 -10.515 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
.03364 .27732 m
.03732 .2759 L
s
.03145 .2912 m
.03512 .28979 L
s
.02923 .3052 m
.0329 .3038 L
s
.02699 .31933 m
.03067 .31794 L
s
.02245 .34798 m
.02613 .3466 L
s
.02015 .3625 m
.02384 .36113 L
s
.01782 .37715 m
.02152 .37579 L
s
.01548 .39194 m
.01918 .39059 L
s
.01073 .42194 m
.01443 .4206 L
s
.00832 .43714 m
.01202 .43582 L
s
.00588 .45249 m
.0096 .45118 L
s
.00343 .46799 m
.00714 .46668 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.657 .756 .923 r
.39267 .79827 .39816 .80295 .40734 .80036 .40187 .79564 Metetra
.657 .755 .922 r
.40187 .79564 .40734 .80036 .41654 .79776 .4111 .79299 Metetra
.658 .754 .921 r
.4111 .79299 .41654 .79776 .42578 .79514 .42036 .79032 Metetra
.658 .753 .92 r
.42036 .79032 .42578 .79514 .43506 .7925 .42965 .78764 Metetra
.659 .752 .919 r
.42965 .78764 .43506 .7925 .44436 .78985 .43897 .78494 Metetra
.659 .75 .918 r
.43897 .78494 .44436 .78985 .45369 .78718 .44833 .78222 Metetra
.659 .749 .917 r
.44833 .78222 .45369 .78718 .46305 .78451 .45771 .77949 Metetra
.659 .748 .915 r
.45771 .77949 .46305 .78451 .47245 .78182 .46713 .77675 Metetra
.659 .746 .914 r
.46713 .77675 .47245 .78182 .48187 .77913 .47657 .77401 Metetra
.659 .745 .913 r
.47657 .77401 .48187 .77913 .49133 .77644 .48605 .77126 Metetra
.659 .743 .912 r
.48605 .77126 .49133 .77644 .50082 .77375 .49556 .76851 Metetra
.658 .742 .911 r
.49556 .76851 .50082 .77375 .51034 .77105 .5051 .76577 Metetra
.658 .74 .911 r
.5051 .76577 .51034 .77105 .5199 .76837 .51468 .76304 Metetra
.657 .739 .91 r
.51468 .76304 .5199 .76837 .52948 .76569 .52429 .76031 Metetra
.656 .738 .91 r
.52429 .76031 .52948 .76569 .5391 .76302 .53392 .7576 Metetra
.655 .737 .91 r
.53392 .7576 .5391 .76302 .54876 .76036 .5436 .75491 Metetra
.654 .736 .909 r
.5436 .75491 .54876 .76036 .55844 .75771 .5533 .75224 Metetra
.653 .735 .91 r
.5533 .75224 .55844 .75771 .56816 .75507 .56304 .74958 Metetra
.652 .734 .91 r
.56304 .74958 .56816 .75507 .57791 .75245 .57282 .74693 Metetra
.651 .734 .91 r
.57282 .74693 .57791 .75245 .5877 .74983 .58263 .7443 Metetra
.65 .734 .911 r
.58263 .7443 .5877 .74983 .59752 .74722 .59247 .74168 Metetra
.65 .734 .911 r
.59247 .74168 .59752 .74722 .60738 .74461 .60235 .73907 Metetra
.649 .735 .912 r
.60235 .73907 .60738 .74461 .61727 .742 .61226 .73646 Metetra
.649 .735 .912 r
.61226 .73646 .61727 .742 .6272 .73939 .62221 .73385 Metetra
.649 .736 .913 r
.62221 .73385 .6272 .73939 .63717 .73678 .6322 .73123 Metetra
.649 .736 .913 r
.6322 .73123 .63717 .73678 .64717 .73415 .64222 .7286 Metetra
.649 .737 .913 r
.64222 .7286 .64717 .73415 .6572 .73152 .65228 .72596 Metetra
.649 .737 .914 r
.65228 .72596 .6572 .73152 .66727 .72887 .66237 .7233 Metetra
.649 .737 .914 r
.66237 .7233 .66727 .72887 .67738 .72621 .6725 .72062 Metetra
.65 .738 .914 r
.6725 .72062 .67738 .72621 .68752 .72353 .68267 .71793 Metetra
.65 .738 .914 r
.68267 .71793 .68752 .72353 .6977 .72084 .69287 .71521 Metetra
.65 .738 .913 r
.69287 .71521 .6977 .72084 .70791 .71814 .70311 .71248 Metetra
.651 .738 .913 r
.70311 .71248 .70791 .71814 .71817 .71542 .71338 .70973 Metetra
.651 .737 .913 r
.71338 .70973 .71817 .71542 .72846 .71269 .7237 .70697 Metetra
.651 .737 .912 r
.7237 .70697 .72846 .71269 .73878 .70995 .73405 .7042 Metetra
.651 .736 .912 r
.73405 .7042 .73878 .70995 .74914 .7072 .74443 .70142 Metetra
.651 .736 .912 r
.74443 .70142 .74914 .7072 .75955 .70445 .75486 .69864 Metetra
.65 .735 .911 r
.75486 .69864 .75955 .70445 .76999 .70171 .76532 .69586 Metetra
.65 .734 .911 r
.76532 .69586 .76999 .70171 .78047 .69896 .77582 .69308 Metetra
.649 .734 .911 r
.77582 .69308 .78047 .69896 .79098 .69622 .78637 .69032 Metetra
.648 .733 .911 r
.78637 .69032 .79098 .69622 .80154 .69349 .79695 .68757 Metetra
.647 .733 .911 r
.79695 .68757 .80154 .69349 .81214 .69077 .80758 .68483 Metetra
.646 .732 .912 r
.80758 .68483 .81214 .69077 .82278 .68806 .81824 .68211 Metetra
.645 .732 .913 r
.81824 .68211 .82278 .68806 .83347 .68536 .82895 .67941 Metetra
.644 .733 .913 r
.82895 .67941 .83347 .68536 .84419 .68267 .83971 .67672 Metetra
.643 .733 .914 r
.83971 .67672 .84419 .68267 .85496 .67999 .8505 .67405 Metetra
.642 .734 .915 r
.8505 .67405 .85496 .67999 .86577 .67732 .86134 .67139 Metetra
.641 .735 .916 r
.86134 .67139 .86577 .67732 .87662 .67465 .87222 .66873 Metetra
.641 .736 .918 r
.87222 .66873 .87662 .67465 .88751 .67198 .88315 .66608 Metetra
.64 .737 .919 r
.88315 .66608 .88751 .67198 .89845 .66931 .89412 .66343 Metetra
.64 .738 .92 r
.89412 .66343 .89845 .66931 .90943 .66664 .90513 .66078 Metetra
.639 .739 .921 r
.90513 .66078 .90943 .66664 .92045 .66396 .91619 .65812 Metetra
.639 .741 .922 r
.91619 .65812 .92045 .66396 .93152 .66127 .92728 .65544 Metetra
.639 .742 .923 r
.92728 .65544 .93152 .66127 .94263 .65856 .93843 .65276 Metetra
.639 .744 .925 r
.93843 .65276 .94263 .65856 .95378 .65584 .94961 .65005 Metetra
.639 .745 .925 r
.94961 .65005 .95378 .65584 .96497 .65311 .96084 .64733 Metetra
.639 .746 .926 r
.96084 .64733 .96497 .65311 .97621 .65036 .97211 .64459 Metetra
.639 .748 .927 r
.97211 .64459 .97621 .65036 .98749 .64759 .98342 .64183 Metetra
.64 .749 .928 r
.98342 .64183 .98749 .64759 .99881 .6448 .99478 .63905 Metetra
.658 .755 .922 r
.38715 .79354 .39267 .79827 .40187 .79564 .39637 .79086 Metetra
.659 .754 .921 r
.39637 .79086 .40187 .79564 .4111 .79299 .40562 .78817 Metetra
.659 .753 .919 r
.40562 .78817 .4111 .79299 .42036 .79032 .4149 .78545 Metetra
.66 .752 .918 r
.4149 .78545 .42036 .79032 .42965 .78764 .42422 .78271 Metetra
.66 .75 .917 r
.42422 .78271 .42965 .78764 .43897 .78494 .43356 .77995 Metetra
.661 .749 .915 r
.43356 .77995 .43897 .78494 .44833 .78222 .44293 .77717 Metetra
.661 .747 .914 r
.44293 .77717 .44833 .78222 .45771 .77949 .45234 .77438 Metetra
.661 .746 .913 r
.45234 .77438 .45771 .77949 .46713 .77675 .46177 .77158 Metetra
.661 .744 .911 r
.46177 .77158 .46713 .77675 .47657 .77401 .47124 .76877 Metetra
.661 .742 .91 r
.47124 .76877 .47657 .77401 .48605 .77126 .48074 .76596 Metetra
.661 .74 .909 r
.48074 .76596 .48605 .77126 .49556 .76851 .49027 .76315 Metetra
.66 .738 .908 r
.49027 .76315 .49556 .76851 .5051 .76577 .49983 .76034 Metetra
.659 .737 .907 r
.49983 .76034 .5051 .76577 .51468 .76304 .50943 .75755 Metetra
.658 .735 .906 r
.50943 .75755 .51468 .76304 .52429 .76031 .51905 .75478 Metetra
.657 .733 .906 r
.51905 .75478 .52429 .76031 .53392 .7576 .52871 .75203 Metetra
.656 .732 .905 r
.52871 .75203 .53392 .7576 .5436 .75491 .53841 .74929 Metetra
.655 .731 .905 r
.53841 .74929 .5436 .75491 .5533 .75224 .54813 .74659 Metetra
.654 .73 .905 r
.54813 .74659 .5533 .75224 .56304 .74958 .55789 .74391 Metetra
.652 .73 .906 r
.55789 .74391 .56304 .74958 .57282 .74693 .56769 .74125 Metetra
.651 .729 .906 r
.56769 .74125 .57282 .74693 .58263 .7443 .57752 .73861 Metetra
.65 .729 .907 r
.57752 .73861 .58263 .7443 .59247 .74168 .58738 .73599 Metetra
.649 .73 .908 r
.58738 .73599 .59247 .74168 .60235 .73907 .59728 .73338 Metetra
.649 .73 .908 r
.59728 .73338 .60235 .73907 .61226 .73646 .60722 .73077 Metetra
.648 .731 .909 r
.60722 .73077 .61226 .73646 .62221 .73385 .61719 .72816 Metetra
.648 .731 .91 r
.61719 .72816 .62221 .73385 .6322 .73123 .6272 .72554 Metetra
.648 .732 .91 r
.6272 .72554 .6322 .73123 .64222 .7286 .63724 .72291 Metetra
.649 .733 .911 r
.63724 .72291 .64222 .7286 .65228 .72596 .64733 .72027 Metetra
.649 .734 .911 r
.64733 .72027 .65228 .72596 .66237 .7233 .65744 .7176 Metetra
.649 .734 .911 r
.65744 .7176 .66237 .7233 .6725 .72062 .66759 .71491 Metetra
.65 .735 .911 r
.66759 .71491 .6725 .72062 .68267 .71793 .67778 .7122 Metetra
.651 .735 .911 r
.67778 .7122 .68267 .71793 .69287 .71521 .68801 .70946 Metetra
.651 .735 .911 r
.68801 .70946 .69287 .71521 .70311 .71248 .69827 .7067 Metetra
.652 .735 .91 r
.69827 .7067 .70311 .71248 .71338 .70973 .70857 .70392 Metetra
.652 .734 .91 r
.70857 .70392 .71338 .70973 .7237 .70697 .7189 .70112 Metetra
.652 .734 .909 r
.7189 .70112 .7237 .70697 .73405 .7042 .72927 .6983 Metetra
.652 .733 .909 r
.72927 .6983 .73405 .7042 .74443 .70142 .73968 .69548 Metetra
.652 .732 .908 r
.73968 .69548 .74443 .70142 .75486 .69864 .75013 .69266 Metetra
.651 .731 .908 r
.75013 .69266 .75486 .69864 .76532 .69586 .76062 .68984 Metetra
.651 .73 .907 r
.76062 .68984 .76532 .69586 .77582 .69308 .77114 .68703 Metetra
.65 .729 .907 r
.77114 .68703 .77582 .69308 .78637 .69032 .78171 .68424 Metetra
.649 .728 .907 r
.78171 .68424 .78637 .69032 .79695 .68757 .79232 .68146 Metetra
.647 .728 .907 r
.79232 .68146 .79695 .68757 .80758 .68483 .80297 .67871 Metetra
.646 .727 .908 r
.80297 .67871 .80758 .68483 .81824 .68211 .81366 .67598 Metetra
.645 .727 .909 r
.81366 .67598 .81824 .68211 .82895 .67941 .8244 .67328 Metetra
.643 .727 .91 r
.8244 .67328 .82895 .67941 .83971 .67672 .83518 .6706 Metetra
.642 .728 .911 r
.83518 .6706 .83971 .67672 .8505 .67405 .846 .66794 Metetra
.641 .729 .912 r
.846 .66794 .8505 .67405 .86134 .67139 .85687 .6653 Metetra
.64 .73 .913 r
.85687 .6653 .86134 .67139 .87222 .66873 .86779 .66267 Metetra
.639 .731 .915 r
.86779 .66267 .87222 .66873 .88315 .66608 .87874 .66005 Metetra
.639 .733 .916 r
.87874 .66005 .88315 .66608 .89412 .66343 .88975 .65743 Metetra
.638 .734 .918 r
.88975 .65743 .89412 .66343 .90513 .66078 .90079 .6548 Metetra
.638 .736 .919 r
.90079 .6548 .90513 .66078 .91619 .65812 .91188 .65217 Metetra
.638 .738 .921 r
.91188 .65217 .91619 .65812 .92728 .65544 .92301 .64953 Metetra
.637 .739 .922 r
.92301 .64953 .92728 .65544 .93843 .65276 .93419 .64686 Metetra
.638 .741 .923 r
.93419 .64686 .93843 .65276 .94961 .65005 .94541 .64418 Metetra
.638 .743 .925 r
.94541 .64418 .94961 .65005 .96084 .64733 .95667 .64148 Metetra
.638 .745 .926 r
.95667 .64148 .96084 .64733 .97211 .64459 .96798 .63876 Metetra
.638 .746 .927 r
.96798 .63876 .97211 .64459 .98342 .64183 .97932 .63601 Metetra
.639 .748 .927 r
.97932 .63601 .98342 .64183 .99478 .63905 .99072 .63323 Metetra
.659 .755 .92 r
.3816 .78875 .38715 .79354 .39637 .79086 .39084 .78603 Metetra
.66 .753 .919 r
.39084 .78603 .39637 .79086 .40562 .78817 .40011 .78328 Metetra
.661 .752 .918 r
.40011 .78328 .40562 .78817 .4149 .78545 .40941 .7805 Metetra
.662 .751 .916 r
.40941 .7805 .4149 .78545 .42422 .78271 .41875 .7777 Metetra
.662 .749 .915 r
.41875 .7777 .42422 .78271 .43356 .77995 .42811 .77487 Metetra
.663 .747 .913 r
.42811 .77487 .43356 .77995 .44293 .77717 .43751 .77203 Metetra
.664 .746 .911 r
.43751 .77203 .44293 .77717 .45234 .77438 .44693 .76916 Metetra
.664 .743 .909 r
.44693 .76916 .45234 .77438 .46177 .77158 .45639 .76629 Metetra
.664 .741 .908 r
.45639 .76629 .46177 .77158 .47124 .76877 .46588 .7634 Metetra
.664 .739 .906 r
.46588 .7634 .47124 .76877 .48074 .76596 .4754 .76051 Metetra
.663 .737 .905 r
.4754 .76051 .48074 .76596 .49027 .76315 .48495 .75762 Metetra
.662 .734 .903 r
.48495 .75762 .49027 .76315 .49983 .76034 .49453 .75474 Metetra
.661 .732 .902 r
.49453 .75474 .49983 .76034 .50943 .75755 .50415 .75188 Metetra
.66 .73 .901 r
.50415 .75188 .50943 .75755 .51905 .75478 .51379 .74905 Metetra
.659 .728 .9 r
.51379 .74905 .51905 .75478 .52871 .75203 .52347 .74624 Metetra
.657 .726 .9 r
.52347 .74624 .52871 .75203 .53841 .74929 .53318 .74347 Metetra
.656 .725 .9 r
.53318 .74347 .53841 .74929 .54813 .74659 .54293 .74073 Metetra
.654 .724 .9 r
.54293 .74073 .54813 .74659 .55789 .74391 .55271 .73803 Metetra
.652 .723 .901 r
.55271 .73803 .55789 .74391 .56769 .74125 .56253 .73536 Metetra
.651 .723 .902 r
.56253 .73536 .56769 .74125 .57752 .73861 .57238 .73272 Metetra
.65 .723 .903 r
.57238 .73272 .57752 .73861 .58738 .73599 .58226 .73011 Metetra
.649 .724 .904 r
.58226 .73011 .58738 .73599 .59728 .73338 .59218 .7275 Metetra
.648 .725 .905 r
.59218 .7275 .59728 .73338 .60722 .73077 .60214 .72491 Metetra
.648 .726 .906 r
.60214 .72491 .60722 .73077 .61719 .72816 .61214 .72231 Metetra
.647 .727 .907 r
.61214 .72231 .61719 .72816 .6272 .72554 .62217 .71971 Metetra
.648 .728 .907 r
.62217 .71971 .6272 .72554 .63724 .72291 .63223 .71708 Metetra
.648 .729 .908 r
.63223 .71708 .63724 .72291 .64733 .72027 .64234 .71444 Metetra
.649 .73 .908 r
.64234 .71444 .64733 .72027 .65744 .7176 .65248 .71177 Metetra
.649 .731 .908 r
.65248 .71177 .65744 .7176 .66759 .71491 .66265 .70907 Metetra
.65 .731 .908 r
.66265 .70907 .66759 .71491 .67778 .7122 .67286 .70634 Metetra
.651 .731 .908 r
.67286 .70634 .67778 .7122 .68801 .70946 .68311 .70357 Metetra
.652 .731 .908 r
.68311 .70357 .68801 .70946 .69827 .7067 .69339 .70078 Metetra
.653 .731 .907 r
.69339 .70078 .69827 .7067 .70857 .70392 .70371 .69795 Metetra
.653 .731 .906 r
.70371 .69795 .70857 .70392 .7189 .70112 .71407 .69511 Metetra
.653 .73 .905 r
.71407 .69511 .7189 .70112 .72927 .6983 .72446 .69225 Metetra
.653 .729 .904 r
.72446 .69225 .72927 .6983 .73968 .69548 .7349 .68937 Metetra
.653 .728 .904 r
.7349 .68937 .73968 .69548 .75013 .69266 .74536 .6865 Metetra
.653 .726 .903 r
.74536 .6865 .75013 .69266 .76062 .68984 .75587 .68363 Metetra
.652 .725 .902 r
.75587 .68363 .76062 .68984 .77114 .68703 .76642 .68078 Metetra
.651 .724 .902 r
.76642 .68078 .77114 .68703 .78171 .68424 .77701 .67795 Metetra
.649 .723 .902 r
.77701 .67795 .78171 .68424 .79232 .68146 .78764 .67514 Metetra
.648 .722 .902 r
.78764 .67514 .79232 .68146 .80297 .67871 .79832 .67237 Metetra
.646 .721 .903 r
.79832 .67237 .80297 .67871 .81366 .67598 .80904 .66964 Metetra
.644 .721 .904 r
.80904 .66964 .81366 .67598 .8244 .67328 .8198 .66694 Metetra
.643 .721 .905 r
.8198 .66694 .8244 .67328 .83518 .6706 .83061 .66428 Metetra
.641 .722 .906 r
.83061 .66428 .83518 .6706 .846 .66794 .84146 .66164 Metetra
.64 .723 .908 r
.84146 .66164 .846 .66794 .85687 .6653 .85236 .65903 Metetra
.638 .724 .91 r
.85236 .65903 .85687 .6653 .86779 .66267 .86331 .65644 Metetra
.637 .726 .912 r
.86331 .65644 .86779 .66267 .87874 .66005 .8743 .65386 Metetra
.637 .727 .914 r
.8743 .65386 .87874 .66005 .88975 .65743 .88533 .65128 Metetra
.636 .729 .916 r
.88533 .65128 .88975 .65743 .90079 .6548 .89641 .6487 Metetra
.636 .732 .917 r
.89641 .6487 .90079 .6548 .91188 .65217 .90754 .6461 Metetra
.636 .734 .919 r
.90754 .6461 .91188 .65217 .92301 .64953 .9187 .6435 Metetra
.636 .736 .921 r
.9187 .6435 .92301 .64953 .93419 .64686 .92992 .64087 Metetra
.636 .738 .922 r
.92992 .64087 .93419 .64686 .94541 .64418 .94117 .63822 Metetra
.636 .74 .924 r
.94117 .63822 .94541 .64418 .95667 .64148 .95247 .63555 Metetra
.637 .742 .925 r
.95247 .63555 .95667 .64148 .96798 .63876 .96381 .63284 Metetra
.637 .744 .926 r
.96381 .63284 .96798 .63876 .97932 .63601 .97519 .63011 Metetra
.637 .746 .927 r
.97519 .63011 .97932 .63601 .99072 .63323 .98662 .62735 Metetra
.661 .754 .919 r
.37602 .78391 .3816 .78875 .39084 .78603 .38528 .78113 Metetra
.662 .753 .917 r
.38528 .78113 .39084 .78603 .40011 .78328 .39457 .77832 Metetra
.663 .751 .916 r
.39457 .77832 .40011 .78328 .40941 .7805 .40389 .77548 Metetra
.664 .75 .914 r
.40389 .77548 .40941 .7805 .41875 .7777 .41325 .77261 Metetra
.665 .748 .912 r
.41325 .77261 .41875 .7777 .42811 .77487 .42263 .7697 Metetra
.666 .746 .91 r
.42263 .7697 .42811 .77487 .43751 .77203 .43205 .76677 Metetra
.666 .743 .908 r
.43205 .76677 .43751 .77203 .44693 .76916 .4415 .76382 Metetra
.667 .741 .906 r
.4415 .76382 .44693 .76916 .45639 .76629 .45098 .76085 Metetra
.667 .738 .903 r
.45098 .76085 .45639 .76629 .46588 .7634 .46049 .75787 Metetra
.667 .735 .901 r
.46049 .75787 .46588 .7634 .4754 .76051 .47003 .75488 Metetra
.666 .732 .899 r
.47003 .75488 .4754 .76051 .48495 .75762 .4796 .7519 Metetra
.665 .73 .898 r
.4796 .7519 .48495 .75762 .49453 .75474 .4892 .74893 Metetra
.664 .727 .896 r
.4892 .74893 .49453 .75474 .50415 .75188 .49883 .74599 Metetra
.662 .724 .895 r
.49883 .74599 .50415 .75188 .51379 .74905 .5085 .74308 Metetra
.66 .721 .894 r
.5085 .74308 .51379 .74905 .52347 .74624 .5182 .74021 Metetra
.658 .719 .894 r
.5182 .74021 .52347 .74624 .53318 .74347 .52793 .73739 Metetra
.656 .718 .894 r
.52793 .73739 .53318 .74347 .54293 .74073 .5377 .73462 Metetra
.654 .716 .894 r
.5377 .73462 .54293 .74073 .55271 .73803 .5475 .7319 Metetra
.652 .716 .895 r
.5475 .7319 .55271 .73803 .56253 .73536 .55733 .72923 Metetra
.65 .716 .896 r
.55733 .72923 .56253 .73536 .57238 .73272 .5672 .72659 Metetra
.649 .716 .897 r
.5672 .72659 .57238 .73272 .58226 .73011 .57711 .72399 Metetra
.647 .717 .899 r
.57711 .72399 .58226 .73011 .59218 .7275 .58705 .72141 Metetra
.647 .718 .9 r
.58705 .72141 .59218 .7275 .60214 .72491 .59703 .71884 Metetra
.646 .719 .901 r
.59703 .71884 .60214 .72491 .61214 .72231 .60705 .71627 Metetra
.646 .721 .903 r
.60705 .71627 .61214 .72231 .62217 .71971 .6171 .71369 Metetra
.647 .722 .904 r
.6171 .71369 .62217 .71971 .63223 .71708 .62719 .71109 Metetra
.647 .724 .905 r
.62719 .71109 .63223 .71708 .64234 .71444 .63731 .70846 Metetra
.648 .725 .905 r
.63731 .70846 .64234 .71444 .65248 .71177 .64747 .70579 Metetra
.649 .726 .905 r
.64747 .70579 .65248 .71177 .66265 .70907 .65767 .70308 Metetra
.65 .727 .905 r
.65767 .70308 .66265 .70907 .67286 .70634 .66791 .70033 Metetra
.652 .728 .905 r
.66791 .70033 .67286 .70634 .68311 .70357 .67818 .69753 Metetra
.653 .728 .904 r
.67818 .69753 .68311 .70357 .69339 .70078 .68848 .6947 Metetra
.654 .727 .903 r
.68848 .6947 .69339 .70078 .70371 .69795 .69882 .69182 Metetra
.655 .727 .902 r
.69882 .69182 .70371 .69795 .71407 .69511 .7092 .68892 Metetra
.655 .725 .901 r
.7092 .68892 .71407 .69511 .72446 .69225 .71962 .686 Metetra
.655 .724 .9 r
.71962 .686 .72446 .69225 .7349 .68937 .73007 .68306 Metetra
.655 .722 .898 r
.73007 .68306 .7349 .68937 .74536 .6865 .74056 .68012 Metetra
.654 .721 .897 r
.74056 .68012 .74536 .6865 .75587 .68363 .75109 .67719 Metetra
.653 .719 .897 r
.75109 .67719 .75587 .68363 .76642 .68078 .76166 .67427 Metetra
.652 .717 .896 r
.76166 .67427 .76642 .68078 .77701 .67795 .77227 .6714 Metetra
.65 .715 .896 r
.77227 .6714 .77701 .67795 .78764 .67514 .78292 .66856 Metetra
.648 .714 .896 r
.78292 .66856 .78764 .67514 .79832 .67237 .79362 .66577 Metetra
.646 .713 .897 r
.79362 .66577 .79832 .67237 .80904 .66964 .80437 .66303 Metetra
.644 .713 .898 r
.80437 .66303 .80904 .66964 .8198 .66694 .81516 .66034 Metetra
.642 .713 .899 r
.81516 .66034 .8198 .66694 .83061 .66428 .82599 .6577 Metetra
.64 .714 .901 r
.82599 .6577 .83061 .66428 .84146 .66164 .83688 .6551 Metetra
.638 .715 .903 r
.83688 .6551 .84146 .66164 .85236 .65903 .84781 .65254 Metetra
.636 .717 .905 r
.84781 .65254 .85236 .65903 .86331 .65644 .85879 .65 Metetra
.635 .719 .908 r
.85879 .65 .86331 .65644 .8743 .65386 .86981 .64748 Metetra
.634 .721 .91 r
.86981 .64748 .8743 .65386 .88533 .65128 .88088 .64496 Metetra
.634 .724 .913 r
.88088 .64496 .88533 .65128 .89641 .6487 .89199 .64244 Metetra
.633 .727 .915 r
.89199 .64244 .89641 .6487 .90754 .6461 .90315 .6399 Metetra
.633 .729 .917 r
.90315 .6399 .90754 .6461 .9187 .6435 .91436 .63735 Metetra
.634 .732 .919 r
.91436 .63735 .9187 .6435 .92992 .64087 .92561 .63477 Metetra
.634 .735 .921 r
.92561 .63477 .92992 .64087 .94117 .63822 .9369 .63216 Metetra
.634 .737 .923 r
.9369 .63216 .94117 .63822 .95247 .63555 .94823 .62952 Metetra
.635 .74 .924 r
.94823 .62952 .95247 .63555 .96381 .63284 .95961 .62685 Metetra
.635 .742 .925 r
.95961 .62685 .96381 .63284 .97519 .63011 .97103 .62415 Metetra
.636 .744 .926 r
.97103 .62415 .97519 .63011 .98662 .62735 .98249 .62141 Metetra
.663 .753 .917 r
.3704 .77902 .37602 .78391 .38528 .78113 .37968 .77618 Metetra
.664 .752 .915 r
.37968 .77618 .38528 .78113 .39457 .77832 .38899 .7733 Metetra
.666 .75 .913 r
.38899 .7733 .39457 .77832 .40389 .77548 .39834 .77038 Metetra
.667 .748 .911 r
.39834 .77038 .40389 .77548 .41325 .77261 .40771 .76742 Metetra
.668 .746 .909 r
.40771 .76742 .41325 .77261 .42263 .7697 .41712 .76443 Metetra
.669 .744 .906 r
.41712 .76443 .42263 .7697 .43205 .76677 .42656 .7614 Metetra
.67 .741 .904 r
.42656 .7614 .43205 .76677 .4415 .76382 .43603 .75834 Metetra
.67 .738 .901 r
.43603 .75834 .4415 .76382 .45098 .76085 .44553 .75525 Metetra
.67 .735 .898 r
.44553 .75525 .45098 .76085 .46049 .75787 .45506 .75215 Metetra
.67 .731 .895 r
.45506 .75215 .46049 .75787 .47003 .75488 .46462 .74905 Metetra
.67 .727 .893 r
.46462 .74905 .47003 .75488 .4796 .7519 .47422 .74595 Metetra
.668 .724 .891 r
.47422 .74595 .4796 .7519 .4892 .74893 .48384 .74286 Metetra
.667 .72 .889 r
.48384 .74286 .4892 .74893 .49883 .74599 .49349 .73982 Metetra
.665 .716 .887 r
.49349 .73982 .49883 .74599 .5085 .74308 .50318 .73681 Metetra
.662 .713 .886 r
.50318 .73681 .5085 .74308 .5182 .74021 .5129 .73387 Metetra
.66 .711 .885 r
.5129 .73387 .5182 .74021 .52793 .73739 .52265 .73099 Metetra
.657 .708 .885 r
.52265 .73099 .52793 .73739 .5377 .73462 .53243 .72818 Metetra
.654 .707 .886 r
.53243 .72818 .5377 .73462 .5475 .7319 .54225 .72544 Metetra
.651 .706 .887 r
.54225 .72544 .5475 .7319 .55733 .72923 .5521 .72277 Metetra
.649 .706 .889 r
.5521 .72277 .55733 .72923 .5672 .72659 .56199 .72016 Metetra
.647 .707 .891 r
.56199 .72016 .5672 .72659 .57711 .72399 .57192 .7176 Metetra
.645 .708 .893 r
.57192 .7176 .57711 .72399 .58705 .72141 .58188 .71506 Metetra
.644 .71 .895 r
.58188 .71506 .58705 .72141 .59703 .71884 .59188 .71254 Metetra
.644 .712 .896 r
.59188 .71254 .59703 .71884 .60705 .71627 .60192 .71002 Metetra
.644 .714 .898 r
.60192 .71002 .60705 .71627 .6171 .71369 .61199 .70748 Metetra
.645 .716 .9 r
.61199 .70748 .6171 .71369 .62719 .71109 .62211 .70491 Metetra
.646 .718 .901 r
.62211 .70491 .62719 .71109 .63731 .70846 .63225 .70229 Metetra
.647 .72 .901 r
.63225 .70229 .63731 .70846 .64747 .70579 .64244 .69964 Metetra
.649 .722 .902 r
.64244 .69964 .64747 .70579 .65767 .70308 .65266 .69692 Metetra
.651 .723 .901 r
.65266 .69692 .65767 .70308 .66791 .70033 .66292 .69415 Metetra
.652 .723 .901 r
.66292 .69415 .66791 .70033 .67818 .69753 .67321 .69132 Metetra
.654 .724 .9 r
.67321 .69132 .67818 .69753 .68848 .6947 .68353 .68844 Metetra
.655 .723 .899 r
.68353 .68844 .68848 .6947 .69882 .69182 .6939 .6855 Metetra
.657 .722 .897 r
.6939 .6855 .69882 .69182 .7092 .68892 .70429 .68253 Metetra
.657 .721 .895 r
.70429 .68253 .7092 .68892 .71962 .686 .71473 .67952 Metetra
.658 .719 .894 r
.71473 .67952 .71962 .686 .73007 .68306 .7252 .67649 Metetra
.657 .716 .892 r
.7252 .67649 .73007 .68306 .74056 .68012 .73571 .67346 Metetra
.657 .714 .89 r
.73571 .67346 .74056 .68012 .75109 .67719 .74626 .67045 Metetra
.655 .711 .889 r
.74626 .67045 .75109 .67719 .76166 .67427 .75685 .66746 Metetra
.653 .709 .888 r
.75685 .66746 .76166 .67427 .77227 .6714 .76748 .66452 Metetra
.651 .707 .888 r
.76748 .66452 .77227 .6714 .78292 .66856 .77815 .66164 Metetra
.648 .705 .888 r
.77815 .66164 .78292 .66856 .79362 .66577 .78887 .65882 Metetra
.646 .704 .889 r
.78887 .65882 .79362 .66577 .80437 .66303 .79964 .65608 Metetra
.643 .703 .89 r
.79964 .65608 .80437 .66303 .81516 .66034 .81046 .65341 Metetra
.64 .703 .892 r
.81046 .65341 .81516 .66034 .82599 .6577 .82132 .65081 Metetra
.638 .704 .894 r
.82132 .65081 .82599 .6577 .83688 .6551 .83224 .64827 Metetra
.635 .706 .897 r
.83224 .64827 .83688 .6551 .84781 .65254 .8432 .64577 Metetra
.633 .708 .9 r
.8432 .64577 .84781 .65254 .85879 .65 .85421 .64331 Metetra
.632 .71 .903 r
.85421 .64331 .85879 .65 .86981 .64748 .86527 .64087 Metetra
.631 .714 .906 r
.86527 .64087 .86981 .64748 .88088 .64496 .87638 .63844 Metetra
.631 .717 .909 r
.87638 .63844 .88088 .64496 .89199 .64244 .88753 .636 Metetra
.63 .72 .912 r
.88753 .636 .89199 .64244 .90315 .6399 .89873 .63354 Metetra
.63 .724 .915 r
.89873 .63354 .90315 .6399 .91436 .63735 .90997 .63106 Metetra
.631 .727 .917 r
.90997 .63106 .91436 .63735 .92561 .63477 .92126 .62855 Metetra
.631 .731 .919 r
.92126 .62855 .92561 .63477 .9369 .63216 .93259 .626 Metetra
.632 .734 .921 r
.93259 .626 .9369 .63216 .94823 .62952 .94396 .62341 Metetra
.633 .737 .923 r
.94396 .62341 .94823 .62952 .95961 .62685 .95538 .62078 Metetra
.634 .74 .925 r
.95538 .62078 .95961 .62685 .97103 .62415 .96683 .6181 Metetra
.634 .742 .926 r
.96683 .6181 .97103 .62415 .98249 .62141 .97834 .61539 Metetra
.665 .753 .916 r
.36475 .77406 .3704 .77902 .37968 .77618 .37405 .77115 Metetra
.667 .751 .913 r
.37405 .77115 .37968 .77618 .38899 .7733 .38338 .76819 Metetra
.668 .749 .911 r
.38338 .76819 .38899 .7733 .39834 .77038 .39275 .76519 Metetra
.67 .747 .908 r
.39275 .76519 .39834 .77038 .40771 .76742 .40215 .76213 Metetra
.672 .744 .905 r
.40215 .76213 .40771 .76742 .41712 .76443 .41158 .75903 Metetra
.673 .741 .902 r
.41158 .75903 .41712 .76443 .42656 .7614 .42104 .75588 Metetra
.674 .738 .899 r
.42104 .75588 .42656 .7614 .43603 .75834 .43053 .75269 Metetra
.675 .734 .895 r
.43053 .75269 .43603 .75834 .44553 .75525 .44006 .74947 Metetra
.675 .73 .892 r
.44006 .74947 .44553 .75525 .45506 .75215 .44961 .74622 Metetra
.675 .726 .888 r
.44961 .74622 .45506 .75215 .46462 .74905 .45919 .74296 Metetra
.674 .721 .885 r
.45919 .74296 .46462 .74905 .47422 .74595 .46881 .7397 Metetra
.672 .716 .882 r
.46881 .7397 .47422 .74595 .48384 .74286 .47845 .73647 Metetra
.67 .712 .879 r
.47845 .73647 .48384 .74286 .49349 .73982 .48813 .73328 Metetra
.668 .707 .877 r
.48813 .73328 .49349 .73982 .50318 .73681 .49783 .73016 Metetra
.664 .703 .876 r
.49783 .73016 .50318 .73681 .5129 .73387 .50757 .72711 Metetra
.661 .699 .875 r
.50757 .72711 .5129 .73387 .52265 .73099 .51733 .72417 Metetra
.657 .697 .875 r
.51733 .72417 .52265 .73099 .53243 .72818 .52714 .72132 Metetra
.653 .695 .876 r
.52714 .72132 .53243 .72818 .54225 .72544 .53697 .71857 Metetra
.65 .694 .878 r
.53697 .71857 .54225 .72544 .5521 .72277 .54684 .71592 Metetra
.647 .694 .88 r
.54684 .71592 .5521 .72277 .56199 .72016 .55675 .71335 Metetra
.644 .695 .882 r
.55675 .71335 .56199 .72016 .57192 .7176 .5667 .71085 Metetra
.642 .697 .885 r
.5667 .71085 .57192 .7176 .58188 .71506 .57668 .70839 Metetra
.641 .699 .888 r
.57668 .70839 .58188 .71506 .59188 .71254 .5867 .70594 Metetra
.641 .702 .891 r
.5867 .70594 .59188 .71254 .60192 .71002 .59676 .70349 Metetra
.641 .705 .893 r
.59676 .70349 .60192 .71002 .61199 .70748 .60686 .70102 Metetra
.643 .709 .895 r
.60686 .70102 .61199 .70748 .62211 .70491 .61699 .6985 Metetra
.644 .712 .896 r
.61699 .6985 .62211 .70491 .63225 .70229 .62716 .69593 Metetra
.646 .714 .897 r
.62716 .69593 .63225 .70229 .64244 .69964 .63737 .69329 Metetra
.648 .716 .898 r
.63737 .69329 .64244 .69964 .65266 .69692 .64761 .69058 Metetra
.651 .718 .897 r
.64761 .69058 .65266 .69692 .66292 .69415 .65789 .68779 Metetra
.653 .719 .897 r
.65789 .68779 .66292 .69415 .67321 .69132 .6682 .68492 Metetra
.656 .719 .895 r
.6682 .68492 .67321 .69132 .68353 .68844 .67855 .68197 Metetra
.658 .718 .893 r
.67855 .68197 .68353 .68844 .6939 .6855 .68893 .67896 Metetra
.659 .717 .891 r
.68893 .67896 .6939 .6855 .70429 .68253 .69935 .67589 Metetra
.66 .715 .889 r
.69935 .67589 .70429 .68253 .71473 .67952 .7098 .67277 Metetra
.661 .712 .886 r
.7098 .67277 .71473 .67952 .7252 .67649 .72029 .66963 Metetra
.66 .709 .884 r
.72029 .66963 .7252 .67649 .73571 .67346 .73081 .66648 Metetra
.659 .706 .882 r
.73081 .66648 .73571 .67346 .74626 .67045 .74138 .66335 Metetra
.658 .702 .88 r
.74138 .66335 .74626 .67045 .75685 .66746 .75198 .66026 Metetra
.655 .699 .878 r
.75198 .66026 .75685 .66746 .76748 .66452 .76263 .65723 Metetra
.652 .696 .878 r
.76263 .65723 .76748 .66452 .77815 .66164 .77333 .65429 Metetra
.649 .693 .878 r
.77333 .65429 .77815 .66164 .78887 .65882 .78407 .65144 Metetra
.645 .691 .879 r
.78407 .65144 .78887 .65882 .79964 .65608 .79486 .6487 Metetra
.641 .69 .88 r
.79486 .6487 .79964 .65608 .81046 .65341 .8057 .64606 Metetra
.638 .69 .883 r
.8057 .64606 .81046 .65341 .82132 .65081 .8166 .64351 Metetra
.635 .692 .886 r
.8166 .64351 .82132 .65081 .83224 .64827 .82754 .64106 Metetra
.632 .694 .889 r
.82754 .64106 .83224 .64827 .8432 .64577 .83854 .63866 Metetra
.63 .696 .893 r
.83854 .63866 .8432 .64577 .85421 .64331 .84959 .63632 Metetra
.628 .7 .897 r
.84959 .63632 .85421 .64331 .86527 .64087 .86069 .634 Metetra
.627 .704 .901 r
.86069 .634 .86527 .64087 .87638 .63844 .87183 .63168 Metetra
.626 .708 .905 r
.87183 .63168 .87638 .63844 .88753 .636 .88302 .62936 Metetra
.626 .713 .909 r
.88302 .62936 .88753 .636 .89873 .63354 .89426 .62701 Metetra
.627 .718 .912 r
.89426 .62701 .89873 .63354 .90997 .63106 .90555 .62462 Metetra
.627 .722 .915 r
.90555 .62462 .90997 .63106 .92126 .62855 .91687 .62219 Metetra
.628 .726 .918 r
.91687 .62219 .92126 .62855 .93259 .626 .92824 .61972 Metetra
.629 .73 .92 r
.92824 .61972 .93259 .626 .94396 .62341 .93965 .61719 Metetra
.63 .734 .922 r
.93965 .61719 .94396 .62341 .95538 .62078 .95111 .61461 Metetra
.631 .737 .924 r
.95111 .61461 .95538 .62078 .96683 .6181 .96261 .61198 Metetra
.632 .74 .925 r
.96261 .61198 .96683 .6181 .97834 .61539 .97414 .6093 Metetra
.668 .752 .914 r
.35906 .76905 .36475 .77406 .37405 .77115 .36838 .76606 Metetra
.67 .75 .911 r
.36838 .76606 .37405 .77115 .38338 .76819 .37774 .76301 Metetra
.672 .748 .908 r
.37774 .76301 .38338 .76819 .39275 .76519 .38713 .7599 Metetra
.674 .746 .905 r
.38713 .7599 .39275 .76519 .40215 .76213 .39656 .75673 Metetra
.676 .743 .901 r
.39656 .75673 .40215 .76213 .41158 .75903 .40601 .7535 Metetra
.677 .739 .897 r
.40601 .7535 .41158 .75903 .42104 .75588 .41549 .7502 Metetra
.679 .735 .893 r
.41549 .7502 .42104 .75588 .43053 .75269 .42501 .74685 Metetra
.68 .73 .888 r
.42501 .74685 .43053 .75269 .44006 .74947 .43456 .74345 Metetra
.68 .725 .884 r
.43456 .74345 .44006 .74947 .44961 .74622 .44413 .74001 Metetra
.68 .72 .879 r
.44413 .74001 .44961 .74622 .45919 .74296 .45374 .73655 Metetra
.679 .714 .875 r
.45374 .73655 .45919 .74296 .46881 .7397 .46337 .73309 Metetra
.677 .708 .871 r
.46337 .73309 .46881 .7397 .47845 .73647 .47304 .72966 Metetra
.674 .702 .867 r
.47304 .72966 .47845 .73647 .48813 .73328 .48273 .72629 Metetra
.671 .696 .865 r
.48273 .72629 .48813 .73328 .49783 .73016 .49246 .723 Metetra
.667 .69 .863 r
.49246 .723 .49783 .73016 .50757 .72711 .50221 .71983 Metetra
.662 .686 .862 r
.50221 .71983 .50757 .72711 .51733 .72417 .51199 .71679 Metetra
.657 .682 .862 r
.51199 .71679 .51733 .72417 .52714 .72132 .52181 .7139 Metetra
.652 .679 .863 r
.52181 .7139 .52714 .72132 .53697 .71857 .53166 .71115 Metetra
.647 .678 .865 r
.53166 .71115 .53697 .71857 .54684 .71592 .54155 .70854 Metetra
.643 .678 .868 r
.54155 .70854 .54684 .71592 .55675 .71335 .55148 .70605 Metetra
.64 .68 .872 r
.55148 .70605 .55675 .71335 .5667 .71085 .56144 .70365 Metetra
.638 .683 .876 r
.56144 .70365 .5667 .71085 .57668 .70839 .57144 .7013 Metetra
.637 .686 .88 r
.57144 .7013 .57668 .70839 .5867 .70594 .58148 .69898 Metetra
.636 .69 .884 r
.58148 .69898 .5867 .70594 .59676 .70349 .59156 .69665 Metetra
.637 .695 .887 r
.59156 .69665 .59676 .70349 .60686 .70102 .60168 .69428 Metetra
.639 .699 .89 r
.60168 .69428 .60686 .70102 .61699 .6985 .61184 .69185 Metetra
.641 .704 .892 r
.61184 .69185 .61699 .6985 .62716 .69593 .62203 .68934 Metetra
.644 .707 .893 r
.62203 .68934 .62716 .69593 .63737 .69329 .63226 .68674 Metetra
.648 .71 .893 r
.63226 .68674 .63737 .69329 .64761 .69058 .64252 .68404 Metetra
.651 .713 .893 r
.64252 .68404 .64761 .69058 .65789 .68779 .65282 .68122 Metetra
.654 .714 .892 r
.65282 .68122 .65789 .68779 .6682 .68492 .66316 .67831 Metetra
.658 .714 .89 r
.66316 .67831 .6682 .68492 .67855 .68197 .67352 .67528 Metetra
.66 .713 .887 r
.67352 .67528 .67855 .68197 .68893 .67896 .68392 .67216 Metetra
.663 .712 .884 r
.68392 .67216 .68893 .67896 .69935 .67589 .69436 .66896 Metetra
.664 .709 .881 r
.69436 .66896 .69935 .67589 .7098 .67277 .70482 .6657 Metetra
.665 .705 .877 r
.70482 .6657 .7098 .67277 .72029 .66963 .71533 .6624 Metetra
.664 .701 .874 r
.71533 .6624 .72029 .66963 .73081 .66648 .72586 .65908 Metetra
.663 .696 .871 r
.72586 .65908 .73081 .66648 .74138 .66335 .73644 .65579 Metetra
.661 .692 .868 r
.73644 .65579 .74138 .66335 .75198 .66026 .74706 .65255 Metetra
.657 .687 .866 r
.74706 .65255 .75198 .66026 .76263 .65723 .75772 .6494 Metetra
.653 .682 .865 r
.75772 .6494 .76263 .65723 .77333 .65429 .76843 .64637 Metetra
.649 .679 .865 r
.76843 .64637 .77333 .65429 .78407 .65144 .77919 .64348 Metetra
.644 .676 .866 r
.77919 .64348 .78407 .65144 .79486 .6487 .79001 .64074 Metetra
.639 .675 .868 r
.79001 .64074 .79486 .6487 .8057 .64606 .80088 .63815 Metetra
.634 .674 .871 r
.80088 .63815 .8057 .64606 .8166 .64351 .8118 .6357 Metetra
.63 .676 .875 r
.8118 .6357 .8166 .64351 .82754 .64106 .82278 .63337 Metetra
.627 .678 .879 r
.82278 .63337 .82754 .64106 .83854 .63866 .83382 .63112 Metetra
.624 .682 .884 r
.83382 .63112 .83854 .63866 .84959 .63632 .8449 .62894 Metetra
.622 .687 .89 r
.8449 .62894 .84959 .63632 .86069 .634 .85604 .62679 Metetra
.621 .692 .895 r
.85604 .62679 .86069 .634 .87183 .63168 .86723 .62464 Metetra
.621 .698 .9 r
.86723 .62464 .87183 .63168 .88302 .62936 .87847 .62247 Metetra
.621 .704 .904 r
.87847 .62247 .88302 .62936 .89426 .62701 .88975 .62026 Metetra
.622 .71 .909 r
.88975 .62026 .89426 .62701 .90555 .62462 .90107 .61801 Metetra
.623 .715 .912 r
.90107 .61801 .90555 .62462 .91687 .62219 .91244 .61569 Metetra
.624 .721 .916 r
.91244 .61569 .91687 .62219 .92824 .61972 .92386 .61331 Metetra
.626 .725 .919 r
.92386 .61331 .92824 .61972 .93965 .61719 .93531 .61087 Metetra
.627 .73 .921 r
.93531 .61087 .93965 .61719 .95111 .61461 .9468 .60836 Metetra
.629 .734 .923 r
.9468 .60836 .95111 .61461 .96261 .61198 .95834 .60578 Metetra
.63 .737 .925 r
.95834 .60578 .96261 .61198 .97414 .6093 .96992 .60314 Metetra
.671 .752 .911 r
.35334 .76397 .35906 .76905 .36838 .76606 .36269 .76089 Metetra
.673 .75 .908 r
.36269 .76089 .36838 .76606 .37774 .76301 .37207 .75774 Metetra
.676 .747 .905 r
.37207 .75774 .37774 .76301 .38713 .7599 .38148 .75452 Metetra
.678 .744 .901 r
.38148 .75452 .38713 .7599 .39656 .75673 .39093 .75121 Metetra
.68 .741 .896 r
.39093 .75121 .39656 .75673 .40601 .7535 .40041 .74782 Metetra
.683 .736 .891 r
.40041 .74782 .40601 .7535 .41549 .7502 .40992 .74435 Metetra
.684 .731 .886 r
.40992 .74435 .41549 .7502 .42501 .74685 .41946 .74079 Metetra
.686 .726 .88 r
.41946 .74079 .42501 .74685 .43456 .74345 .42903 .73716 Metetra
.686 .72 .874 r
.42903 .73716 .43456 .74345 .44413 .74001 .43863 .73348 Metetra
.686 .713 .869 r
.43863 .73348 .44413 .74001 .45374 .73655 .44826 .72975 Metetra
.685 .705 .863 r
.44826 .72975 .45374 .73655 .46337 .73309 .45792 .72602 Metetra
.683 .697 .857 r
.45792 .72602 .46337 .73309 .47304 .72966 .4676 .72232 Metetra
.679 .689 .853 r
.4676 .72232 .47304 .72966 .48273 .72629 .47732 .71869 Metetra
.674 .682 .849 r
.47732 .71869 .48273 .72629 .49246 .723 .48706 .71518 Metetra
.669 .675 .846 r
.48706 .71518 .49246 .723 .50221 .71983 .49683 .71183 Metetra
.662 .668 .845 r
.49683 .71183 .50221 .71983 .51199 .71679 .50663 .70867 Metetra
.656 .663 .845 r
.50663 .70867 .51199 .71679 .52181 .7139 .51646 .70573 Metetra
.649 .66 .847 r
.51646 .70573 .52181 .7139 .53166 .71115 .52633 .703 Metetra
.643 .658 .85 r
.52633 .703 .53166 .71115 .54155 .70854 .53623 .70047 Metetra
.638 .659 .854 r
.53623 .70047 .54155 .70854 .55148 .70605 .54617 .6981 Metetra
.634 .661 .859 r
.54617 .6981 .55148 .70605 .56144 .70365 .55615 .69587 Metetra
.631 .665 .864 r
.55615 .69587 .56144 .70365 .57144 .7013 .56617 .69371 Metetra
.63 .67 .87 r
.56617 .69371 .57144 .7013 .58148 .69898 .57623 .69157 Metetra
.63 .676 .875 r
.57623 .69157 .58148 .69898 .59156 .69665 .58633 .68942 Metetra
.631 .682 .88 r
.58633 .68942 .59156 .69665 .60168 .69428 .59647 .68721 Metetra
.634 .688 .883 r
.59647 .68721 .60168 .69428 .61184 .69185 .60665 .68491 Metetra
.638 .694 .886 r
.60665 .68491 .61184 .69185 .62203 .68934 .61686 .6825 Metetra
.642 .699 .888 r
.61686 .6825 .62203 .68934 .63226 .68674 .62712 .67995 Metetra
.646 .704 .888 r
.62712 .67995 .63226 .68674 .64252 .68404 .6374 .67727 Metetra
.651 .707 .888 r
.6374 .67727 .64252 .68404 .65282 .68122 .64772 .67443 Metetra
.656 .708 .886 r
.64772 .67443 .65282 .68122 .66316 .67831 .65808 .67145 Metetra
.66 .709 .884 r
.65808 .67145 .66316 .67831 .67352 .67528 .66846 .66833 Metetra
.664 .708 .88 r
.66846 .66833 .67352 .67528 .68392 .67216 .67888 .66507 Metetra
.667 .705 .876 r
.67888 .66507 .68392 .67216 .69436 .66896 .68932 .6617 Metetra
.669 .702 .871 r
.68932 .6617 .69436 .66896 .70482 .6657 .6998 .65824 Metetra
.67 .697 .867 r
.6998 .65824 .70482 .6657 .71533 .6624 .71032 .65471 Metetra
.669 .691 .862 r
.71032 .65471 .71533 .6624 .72586 .65908 .72086 .65116 Metetra
.668 .685 .857 r
.72086 .65116 .72586 .65908 .73644 .65579 .73145 .64763 Metetra
.665 .678 .853 r
.73145 .64763 .73644 .65579 .74706 .65255 .74207 .64418 Metetra
.66 .672 .85 r
.74207 .64418 .74706 .65255 .75772 .6494 .75274 .64086 Metetra
.655 .666 .849 r
.75274 .64086 .75772 .6494 .76843 .64637 .76347 .6377 Metetra
.648 .661 .848 r
.76347 .6377 .76843 .64637 .77919 .64348 .77424 .63475 Metetra
.642 .657 .849 r
.77424 .63475 .77919 .64348 .79001 .64074 .78508 .63202 Metetra
.635 .655 .852 r
.78508 .63202 .79001 .64074 .80088 .63815 .79597 .6295 Metetra
.629 .654 .856 r
.79597 .6295 .80088 .63815 .8118 .6357 .80693 .62719 Metetra
.624 .656 .861 r
.80693 .62719 .8118 .6357 .82278 .63337 .81794 .62504 Metetra
.62 .659 .867 r
.81794 .62504 .82278 .63337 .83382 .63112 .82902 .62302 Metetra
.617 .664 .873 r
.82902 .62302 .83382 .63112 .8449 .62894 .84015 .62107 Metetra
.615 .67 .88 r
.84015 .62107 .8449 .62894 .85604 .62679 .85134 .61916 Metetra
.614 .677 .887 r
.85134 .61916 .85604 .62679 .86723 .62464 .86257 .61724 Metetra
.614 .685 .893 r
.86257 .61724 .86723 .62464 .87847 .62247 .87386 .61529 Metetra
.614 .693 .899 r
.87386 .61529 .87847 .62247 .88975 .62026 .88518 .61328 Metetra
.616 .7 .905 r
.88518 .61328 .88975 .62026 .90107 .61801 .89656 .61119 Metetra
.618 .708 .91 r
.89656 .61119 .90107 .61801 .91244 .61569 .90797 .60902 Metetra
.619 .714 .914 r
.90797 .60902 .91244 .61569 .92386 .61331 .91943 .60677 Metetra
.622 .72 .917 r
.91943 .60677 .92386 .61331 .93531 .61087 .93093 .60443 Metetra
.624 .726 .92 r
.93093 .60443 .93531 .61087 .9468 .60836 .94246 .602 Metetra
.626 .73 .922 r
.94246 .602 .9468 .60836 .95834 .60578 .95404 .59949 Metetra
.628 .735 .924 r
.95404 .59949 .95834 .60578 .96992 .60314 .96566 .59691 Metetra
.674 .751 .909 r
.34758 .75884 .35334 .76397 .36269 .76089 .35696 .75566 Metetra
.677 .749 .905 r
.35696 .75566 .36269 .76089 .37207 .75774 .36636 .75239 Metetra
.68 .746 .901 r
.36636 .75239 .37207 .75774 .38148 .75452 .3758 .74902 Metetra
.683 .743 .896 r
.3758 .74902 .38148 .75452 .39093 .75121 .38527 .74556 Metetra
.686 .739 .891 r
.38527 .74556 .39093 .75121 .40041 .74782 .39478 .74198 Metetra
.689 .734 .885 r
.39478 .74198 .40041 .74782 .40992 .74435 .40431 .73828 Metetra
.691 .728 .878 r
.40431 .73828 .40992 .74435 .41946 .74079 .41388 .73447 Metetra
.693 .721 .871 r
.41388 .73447 .41946 .74079 .42903 .73716 .42348 .73055 Metetra
.694 .713 .863 r
.42348 .73055 .42903 .73716 .43863 .73348 .43311 .72654 Metetra
.694 .704 .855 r
.43311 .72654 .43863 .73348 .44826 .72975 .44276 .72246 Metetra
.692 .695 .848 r
.44276 .72246 .44826 .72975 .45792 .72602 .45244 .71836 Metetra
.689 .685 .841 r
.45244 .71836 .45792 .72602 .4676 .72232 .46215 .71428 Metetra
.684 .675 .835 r
.46215 .71428 .4676 .72232 .47732 .71869 .47189 .71029 Metetra
.678 .665 .83 r
.47189 .71029 .47732 .71869 .48706 .71518 .48165 .70645 Metetra
.671 .655 .826 r
.48165 .70645 .48706 .71518 .49683 .71183 .49143 .70285 Metetra
.662 .647 .824 r
.49143 .70285 .49683 .71183 .50663 .70867 .50124 .69952 Metetra
.654 .64 .824 r
.50124 .69952 .50663 .70867 .51646 .70573 .51109 .69652 Metetra
.645 .636 .827 r
.51109 .69652 .51646 .70573 .52633 .703 .52097 .69383 Metetra
.636 .634 .83 r
.52097 .69383 .52633 .703 .53623 .70047 .53088 .69143 Metetra
.629 .634 .836 r
.53088 .69143 .53623 .70047 .54617 .6981 .54083 .68928 Metetra
.624 .637 .843 r
.54083 .68928 .54617 .6981 .55615 .69587 .55083 .68731 Metetra
.621 .642 .85 r
.55083 .68731 .55615 .69587 .56617 .69371 .56087 .68544 Metetra
.62 .649 .858 r
.56087 .68544 .56617 .69371 .57623 .69157 .57094 .6836 Metetra
.62 .657 .865 r
.57094 .6836 .57623 .69157 .58633 .68942 .58106 .68171 Metetra
.623 .666 .871 r
.58106 .68171 .58633 .68942 .59647 .68721 .59122 .67974 Metetra
.627 .675 .876 r
.59122 .67974 .59647 .68721 .60665 .68491 .60142 .67763 Metetra
.632 .683 .88 r
.60142 .67763 .60665 .68491 .61686 .6825 .61166 .67536 Metetra
.638 .69 .882 r
.61166 .67536 .61686 .6825 .62712 .67995 .62194 .6729 Metetra
.644 .696 .883 r
.62194 .6729 .62712 .67995 .6374 .67727 .63224 .67025 Metetra
.651 .7 .882 r
.63224 .67025 .6374 .67727 .64772 .67443 .64258 .6674 Metetra
.657 .703 .88 r
.64258 .6674 .64772 .67443 .65808 .67145 .65296 .66434 Metetra
.663 .703 .877 r
.65296 .66434 .65808 .67145 .66846 .66833 .66336 .66109 Metetra
.668 .702 .872 r
.66336 .66109 .66846 .66833 .67888 .66507 .67379 .65764 Metetra
.672 .699 .866 r
.67379 .65764 .67888 .66507 .68932 .6617 .68425 .65404 Metetra
.675 .694 .86 r
.68425 .65404 .68932 .6617 .6998 .65824 .69473 .65029 Metetra
.676 .688 .853 r
.69473 .65029 .6998 .65824 .71032 .65471 .70525 .64645 Metetra
.676 .68 .847 r
.70525 .64645 .71032 .65471 .72086 .65116 .7158 .64256 Metetra
.673 .672 .84 r
.7158 .64256 .72086 .65116 .73145 .64763 .72638 .63869 Metetra
.669 .663 .835 r
.72638 .63869 .73145 .64763 .74207 .64418 .73701 .63492 Metetra
.663 .654 .831 r
.73701 .63492 .74207 .64418 .75274 .64086 .74768 .63133 Metetra
.656 .646 .828 r
.74768 .63133 .75274 .64086 .76347 .6377 .75841 .62799 Metetra
.648 .638 .827 r
.75841 .62799 .76347 .6377 .77424 .63475 .76919 .62495 Metetra
.639 .633 .828 r
.76919 .62495 .77424 .63475 .78508 .63202 .78004 .62223 Metetra
.63 .63 .831 r
.78004 .62223 .78508 .63202 .79597 .6295 .79096 .61984 Metetra
.622 .629 .836 r
.79096 .61984 .79597 .6295 .80693 .62719 .80195 .61774 Metetra
.615 .631 .843 r
.80195 .61774 .80693 .62719 .81794 .62504 .81301 .61588 Metetra
.61 .635 .851 r
.81301 .61588 .81794 .62504 .82902 .62302 .82413 .61418 Metetra
.606 .641 .859 r
.82413 .61418 .82902 .62302 .84015 .62107 .83532 .61258 Metetra
.604 .65 .868 r
.83532 .61258 .84015 .62107 .85134 .61916 .84656 .61102 Metetra
.603 .659 .877 r
.84656 .61102 .85134 .61916 .86257 .61724 .85785 .60942 Metetra
.604 .669 .886 r
.85785 .60942 .86257 .61724 .87386 .61529 .86919 .60777 Metetra
.606 .679 .894 r
.86919 .60777 .87386 .61529 .88518 .61328 .88057 .60602 Metetra
.608 .689 .9 r
.88057 .60602 .88518 .61328 .89656 .61119 .89199 .60416 Metetra
.611 .698 .906 r
.89199 .60416 .89656 .61119 .90797 .60902 .90346 .60218 Metetra
.614 .707 .911 r
.90346 .60218 .90797 .60902 .91943 .60677 .91496 .60008 Metetra
.616 .714 .915 r
.91496 .60008 .91943 .60677 .93093 .60443 .9265 .59786 Metetra
.619 .721 .919 r
.9265 .59786 .93093 .60443 .94246 .602 .93809 .59554 Metetra
.622 .727 .922 r
.93809 .59554 .94246 .602 .95404 .59949 .94971 .59312 Metetra
.625 .732 .924 r
.94971 .59312 .95404 .59949 .96566 .59691 .96137 .5906 Metetra
.677 .751 .907 r
.34179 .75364 .34758 .75884 .35696 .75566 .35119 .75035 Metetra
.681 .749 .902 r
.35119 .75035 .35696 .75566 .36636 .75239 .36062 .74694 Metetra
.685 .745 .897 r
.36062 .74694 .36636 .75239 .3758 .74902 .37009 .74342 Metetra
.689 .741 .891 r
.37009 .74342 .3758 .74902 .38527 .74556 .37959 .73976 Metetra
.692 .736 .885 r
.37959 .73976 .38527 .74556 .39478 .74198 .38912 .73595 Metetra
.696 .731 .877 r
.38912 .73595 .39478 .74198 .40431 .73828 .39868 .73198 Metetra
.699 .723 .869 r
.39868 .73198 .40431 .73828 .41388 .73447 .40828 .72785 Metetra
.702 .715 .859 r
.40828 .72785 .41388 .73447 .42348 .73055 .41791 .72355 Metetra
.703 .706 .85 r
.41791 .72355 .42348 .73055 .43311 .72654 .42757 .7191 Metetra
.703 .695 .84 r
.42757 .7191 .43311 .72654 .44276 .72246 .43725 .71454 Metetra
.701 .683 .83 r
.43725 .71454 .44276 .72246 .45244 .71836 .44696 .70991 Metetra
.697 .67 .821 r
.44696 .70991 .45244 .71836 .46215 .71428 .45669 .70529 Metetra
.691 .657 .812 r
.45669 .70529 .46215 .71428 .47189 .71029 .46645 .70076 Metetra
.683 .645 .806 r
.46645 .70076 .47189 .71029 .48165 .70645 .47623 .69646 Metetra
.673 .632 .801 r
.47623 .69646 .48165 .70645 .49143 .70285 .48602 .69247 Metetra
.662 .621 .799 r
.48602 .69247 .49143 .70285 .50124 .69952 .49585 .68891 Metetra
.65 .612 .799 r
.49585 .68891 .50124 .69952 .51109 .69652 .5057 .68582 Metetra
.638 .606 .801 r
.5057 .68582 .51109 .69652 .52097 .69383 .51559 .68322 Metetra
.627 .602 .806 r
.51559 .68322 .52097 .69383 .53088 .69143 .52551 .68106 Metetra
.617 .603 .813 r
.52551 .68106 .53088 .69143 .54083 .68928 .53547 .67927 Metetra
.61 .606 .822 r
.53547 .67927 .54083 .68928 .55083 .68731 .54548 .67772 Metetra
.606 .613 .832 r
.54548 .67772 .55083 .68731 .56087 .68544 .55553 .6763 Metetra
.605 .623 .842 r
.55553 .6763 .56087 .68544 .57094 .6836 .56562 .6749 Metetra
.607 .635 .852 r
.56562 .6749 .57094 .6836 .58106 .68171 .57576 .67342 Metetra
.611 .647 .861 r
.57576 .67342 .58106 .68171 .59122 .67974 .58594 .67179 Metetra
.617 .659 .868 r
.58594 .67179 .59122 .67974 .60142 .67763 .59616 .66996 Metetra
.625 .67 .874 r
.59616 .66996 .60142 .67763 .61166 .67536 .60642 .66789 Metetra
.633 .68 .877 r
.60642 .66789 .61166 .67536 .62194 .6729 .61672 .66556 Metetra
.642 .688 .878 r
.61672 .66556 .62194 .6729 .63224 .67025 .62705 .66297 Metetra
.651 .694 .877 r
.62705 .66297 .63224 .67025 .64258 .6674 .63741 .66009 Metetra
.659 .697 .874 r
.63741 .66009 .64258 .6674 .65296 .66434 .6478 .65694 Metetra
.667 .698 .869 r
.6478 .65694 .65296 .66434 .66336 .66109 .65821 .65351 Metetra
.674 .696 .863 r
.65821 .65351 .66336 .66109 .67379 .65764 .66865 .64982 Metetra
.679 .692 .855 r
.66865 .64982 .67379 .65764 .68425 .65404 .67912 .64589 Metetra
.683 .686 .846 r
.67912 .64589 .68425 .65404 .69473 .65029 .68961 .64175 Metetra
.685 .678 .837 r
.68961 .64175 .69473 .65029 .70525 .64645 .70012 .63745 Metetra
.684 .668 .828 r
.70012 .63745 .70525 .64645 .7158 .64256 .71066 .63306 Metetra
.681 .657 .82 r
.71066 .63306 .7158 .64256 .72638 .63869 .72124 .62869 Metetra
.675 .645 .812 r
.72124 .62869 .72638 .63869 .73701 .63492 .73185 .62444 Metetra
.667 .633 .806 r
.73185 .62444 .73701 .63492 .74768 .63133 .74251 .62044 Metetra
.657 .621 .802 r
.74251 .62044 .74768 .63133 .75841 .62799 .75323 .6168 Metetra
.646 .611 .801 r
.75323 .6168 .75841 .62799 .76919 .62495 .76402 .61362 Metetra
.634 .604 .802 r
.76402 .61362 .76919 .62495 .78004 .62223 .77488 .61093 Metetra
.622 .599 .806 r
.77488 .61093 .78004 .62223 .79096 .61984 .78583 .60874 Metetra
.612 .597 .812 r
.78583 .60874 .79096 .61984 .80195 .61774 .79686 .60698 Metetra
.603 .599 .82 r
.79686 .60698 .80195 .61774 .81301 .61588 .80796 .60556 Metetra
.596 .604 .83 r
.80796 .60556 .81301 .61588 .82413 .61418 .81914 .60436 Metetra
.592 .613 .842 r
.81914 .60436 .82413 .61418 .83532 .61258 .83039 .60328 Metetra
.59 .624 .854 r
.83039 .60328 .83532 .61258 .84656 .61102 .84169 .60221 Metetra
.59 .636 .865 r
.84169 .60221 .84656 .61102 .85785 .60942 .85305 .60108 Metetra
.591 .65 .877 r
.85305 .60108 .85785 .60942 .86919 .60777 .86445 .59983 Metetra
.594 .663 .887 r
.86445 .59983 .86919 .60777 .88057 .60602 .87589 .59843 Metetra
.598 .676 .895 r
.87589 .59843 .88057 .60602 .89199 .60416 .88738 .59686 Metetra
.602 .688 .903 r
.88738 .59686 .89199 .60416 .90346 .60218 .89889 .59513 Metetra
.606 .698 .909 r
.89889 .59513 .90346 .60218 .91496 .60008 .91045 .59323 Metetra
.61 .708 .914 r
.91045 .59323 .91496 .60008 .9265 .59786 .92204 .59118 Metetra
.614 .716 .918 r
.92204 .59118 .9265 .59786 .93809 .59554 .93367 .58898 Metetra
.618 .723 .921 r
.93367 .58898 .93809 .59554 .94971 .59312 .94534 .58665 Metetra
.621 .728 .923 r
.94534 .58665 .94971 .59312 .96137 .5906 .95704 .58421 Metetra
.681 .751 .904 r
.33597 .74838 .34179 .75364 .35119 .75035 .34539 .74496 Metetra
.686 .748 .899 r
.34539 .74496 .35119 .75035 .36062 .74694 .35485 .74141 Metetra
.69 .745 .893 r
.35485 .74141 .36062 .74694 .37009 .74342 .36434 .7377 Metetra
.695 .74 .886 r
.36434 .7377 .37009 .74342 .37959 .73976 .37387 .73381 Metetra
.7 .734 .878 r
.37387 .73381 .37959 .73976 .38912 .73595 .38343 .72973 Metetra
.704 .728 .868 r
.38343 .72973 .38912 .73595 .39868 .73198 .39303 .72542 Metetra
.708 .719 .858 r
.39303 .72542 .39868 .73198 .40828 .72785 .40266 .72087 Metetra
.711 .709 .846 r
.40266 .72087 .40828 .72785 .41791 .72355 .41232 .71608 Metetra
.713 .698 .834 r
.41232 .71608 .41791 .72355 .42757 .7191 .42201 .71105 Metetra
.713 .684 .821 r
.42201 .71105 .42757 .7191 .43725 .71454 .43173 .70581 Metetra
.71 .67 .808 r
.43173 .70581 .43725 .71454 .44696 .70991 .44147 .70043 Metetra
.705 .654 .796 r
.44147 .70043 .44696 .70991 .45669 .70529 .45124 .69501 Metetra
.698 .638 .786 r
.45124 .69501 .45669 .70529 .46645 .70076 .46102 .68969 Metetra
.687 .622 .777 r
.46102 .68969 .46645 .70076 .47623 .69646 .47081 .68465 Metetra
.674 .606 .771 r
.47081 .68465 .47623 .69646 .48602 .69247 .48062 .68008 Metetra
.659 .592 .768 r
.48062 .68008 .48602 .69247 .49585 .68891 .49046 .67614 Metetra
.643 .579 .768 r
.49046 .67614 .49585 .68891 .5057 .68582 .50031 .67295 Metetra
.627 .57 .77 r
.50031 .67295 .5057 .68582 .51559 .68322 .5102 .67051 Metetra
.613 .564 .776 r
.5102 .67051 .51559 .68322 .52551 .68106 .52012 .66876 Metetra
.6 .564 .785 r
.52012 .66876 .52551 .68106 .53547 .67927 .53008 .66756 Metetra
.591 .568 .797 r
.53008 .66756 .53547 .67927 .54548 .67772 .54009 .6667 Metetra
.586 .577 .81 r
.54009 .6667 .54548 .67772 .55553 .6763 .55015 .66599 Metetra
.585 .59 .824 r
.55015 .66599 .55553 .6763 .56562 .6749 .56026 .66527 Metetra
.588 .606 .837 r
.56026 .66527 .56562 .6749 .57576 .67342 .57042 .6644 Metetra
.595 .623 .849 r
.57042 .6644 .57576 .67342 .58594 .67179 .58062 .66327 Metetra
.604 .64 .859 r
.58062 .66327 .58594 .67179 .59616 .66996 .59087 .66184 Metetra
.615 .655 .866 r
.59087 .66184 .59616 .66996 .60642 .66789 .60115 .66006 Metetra
.626 .668 .871 r
.60115 .66006 .60642 .66789 .61672 .66556 .61147 .65792 Metetra
.638 .679 .872 r
.61147 .65792 .61672 .66556 .62705 .66297 .62182 .6554 Metetra
.65 .687 .871 r
.62182 .6554 .62705 .66297 .63741 .66009 .6322 .6525 Metetra
.662 .691 .867 r
.6322 .6525 .63741 .66009 .6478 .65694 .6426 .64922 Metetra
.672 .692 .86 r
.6426 .64922 .6478 .65694 .65821 .65351 .65303 .64557 Metetra
.681 .69 .852 r
.65303 .64557 .65821 .65351 .66865 .64982 .66348 .64154 Metetra
.688 .685 .842 r
.66348 .64154 .66865 .64982 .67912 .64589 .67394 .63716 Metetra
.693 .677 .83 r
.67394 .63716 .67912 .64589 .68961 .64175 .68443 .63246 Metetra
.695 .667 .818 r
.68443 .63246 .68961 .64175 .70012 .63745 .69493 .6275 Metetra
.694 .654 .806 r
.69493 .6275 .70012 .63745 .71066 .63306 .70544 .62238 Metetra
.689 .64 .795 r
.70544 .62238 .71066 .63306 .72124 .62869 .71599 .61723 Metetra
.681 .624 .785 r
.71599 .61723 .72124 .62869 .73185 .62444 .72657 .61223 Metetra
.671 .608 .777 r
.72657 .61223 .73185 .62444 .74251 .62044 .7372 .60757 Metetra
.657 .593 .772 r
.7372 .60757 .74251 .62044 .75323 .6168 .74789 .60347 Metetra
.642 .58 .769 r
.74789 .60347 .75323 .6168 .76402 .61362 .75867 .60006 Metetra
.626 .569 .77 r
.75867 .60006 .76402 .61362 .77488 .61093 .76954 .59742 Metetra
.611 .562 .775 r
.76954 .59742 .77488 .61093 .78583 .60874 .78052 .59555 Metetra
.597 .559 .782 r
.78052 .59555 .78583 .60874 .79686 .60698 .79159 .59434 Metetra
.585 .56 .792 r
.79159 .59434 .79686 .60698 .80796 .60556 .80277 .59362 Metetra
.577 .567 .805 r
.80277 .59362 .80796 .60556 .81914 .60436 .81402 .5932 Metetra
.572 .577 .82 r
.81402 .5932 .81914 .60436 .83039 .60328 .82535 .5929 Metetra
.57 .591 .835 r
.82535 .5929 .83039 .60328 .84169 .60221 .83673 .59256 Metetra
.571 .608 .851 r
.83673 .59256 .84169 .60221 .85305 .60108 .84817 .59208 Metetra
.574 .626 .865 r
.84817 .59208 .85305 .60108 .86445 .59983 .85964 .5914 Metetra
.579 .643 .878 r
.85964 .5914 .86445 .59983 .87589 .59843 .87116 .59047 Metetra
.585 .66 .889 r
.87116 .59047 .87589 .59843 .88738 .59686 .88271 .58929 Metetra
.591 .675 .899 r
.88271 .58929 .88738 .59686 .89889 .59513 .89429 .58787 Metetra
.597 .688 .906 r
.89429 .58787 .89889 .59513 .91045 .59323 .9059 .58622 Metetra
.603 .7 .912 r
.9059 .58622 .91045 .59323 .92204 .59118 .91754 .58436 Metetra
.608 .71 .917 r
.91754 .58436 .92204 .59118 .93367 .58898 .92922 .58231 Metetra
.613 .718 .92 r
.92922 .58231 .93367 .58898 .94534 .58665 .94094 .58011 Metetra
.617 .725 .923 r
.94094 .58011 .94534 .58665 .95704 .58421 .95269 .57776 Metetra
.686 .751 .901 r
.33011 .74306 .33597 .74838 .34539 .74496 .33956 .73951 Metetra
.691 .748 .895 r
.33956 .73951 .34539 .74496 .35485 .74141 .34905 .73579 Metetra
.696 .744 .888 r
.34905 .73579 .35485 .74141 .36434 .7377 .35857 .73187 Metetra
.702 .739 .88 r
.35857 .73187 .36434 .7377 .37387 .73381 .36813 .72772 Metetra
.708 .733 .87 r
.36813 .72772 .37387 .73381 .38343 .72973 .37772 .7233 Metetra
.714 .725 .858 r
.37772 .7233 .38343 .72973 .39303 .72542 .38736 .71857 Metetra
.719 .715 .845 r
.38736 .71857 .39303 .72542 .40266 .72087 .39702 .7135 Metetra
.723 .703 .831 r
.39702 .7135 .40266 .72087 .41232 .71608 .40672 .70806 Metetra
.725 .689 .815 r
.40672 .70806 .41232 .71608 .42201 .71105 .41646 .70224 Metetra
.725 .673 .8 r
.41646 .70224 .42201 .71105 .43173 .70581 .42622 .69605 Metetra
.722 .656 .784 r
.42622 .69605 .43173 .70581 .44147 .70043 .436 .68957 Metetra
.715 .637 .769 r
.436 .68957 .44147 .70043 .45124 .69501 .4458 .68294 Metetra
.706 .617 .756 r
.4458 .68294 .45124 .69501 .46102 .68969 .45561 .67638 Metetra
.692 .597 .745 r
.45561 .67638 .46102 .68969 .47081 .68465 .46543 .67017 Metetra
.675 .577 .738 r
.46543 .67017 .47081 .68465 .48062 .68008 .47525 .66465 Metetra
.656 .559 .733 r
.47525 .66465 .48062 .68008 .49046 .67614 .48509 .66011 Metetra
.635 .542 .732 r
.48509 .66011 .49046 .67614 .50031 .67295 .49494 .65676 Metetra
.613 .529 .735 r
.49494 .65676 .50031 .67295 .5102 .67051 .50481 .65464 Metetra
.593 .52 .741 r
.50481 .65464 .5102 .67051 .52012 .66876 .51472 .65361 Metetra
.576 .517 .752 r
.51472 .65361 .52012 .66876 .53008 .66756 .52468 .65339 Metetra
.564 .521 .766 r
.52468 .65339 .53008 .66756 .54009 .6667 .53469 .65367 Metetra
.557 .532 .783 r
.53469 .65367 .54009 .6667 .55015 .66599 .54475 .6541 Metetra
.556 .548 .801 r
.54475 .6541 .55015 .66599 .56026 .66527 .55487 .65443 Metetra
.562 .57 .819 r
.55487 .65443 .56026 .66527 .57042 .6644 .56505 .65446 Metetra
.572 .593 .836 r
.56505 .65446 .57042 .6644 .58062 .66327 .57527 .65408 Metetra
.585 .616 .849 r
.57527 .65408 .58062 .66327 .59087 .66184 .58553 .65321 Metetra
.601 .637 .859 r
.58553 .65321 .59087 .66184 .60115 .66006 .59584 .65184 Metetra
.617 .655 .865 r
.59584 .65184 .60115 .66006 .61147 .65792 .60618 .64995 Metetra
.634 .669 .867 r
.60618 .64995 .61147 .65792 .62182 .6554 .61655 .64754 Metetra
.65 .68 .865 r
.61655 .64754 .62182 .6554 .6322 .6525 .62695 .64462 Metetra
.665 .685 .859 r
.62695 .64462 .6322 .6525 .6426 .64922 .63737 .64118 Metetra
.679 .687 .851 r
.63737 .64118 .6426 .64922 .65303 .64557 .6478 .63723 Metetra
.69 .685 .84 r
.6478 .63723 .65303 .64557 .66348 .64154 .65826 .63275 Metetra
.699 .679 .827 r
.65826 .63275 .66348 .64154 .67394 .63716 .66872 .62775 Metetra
.705 .669 .812 r
.66872 .62775 .67394 .63716 .68443 .63246 .67918 .62226 Metetra
.707 .656 .796 r
.67918 .62226 .68443 .63246 .69493 .6275 .68965 .61633 Metetra
.706 .64 .78 r
.68965 .61633 .69493 .6275 .70544 .62238 .70012 .61009 Metetra
.7 .622 .766 r
.70012 .61009 .70544 .62238 .71599 .61723 .71061 .60373 Metetra
.689 .602 .753 r
.71061 .60373 .71599 .61723 .72657 .61223 .72113 .59752 Metetra
.675 .582 .744 r
.72113 .59752 .72657 .61223 .7372 .60757 .7317 .59179 Metetra
.658 .563 .737 r
.7317 .59179 .7372 .60757 .74789 .60347 .74234 .58688 Metetra
.638 .545 .734 r
.74234 .58688 .74789 .60347 .75867 .60006 .75309 .58309 Metetra
.617 .53 .734 r
.75309 .58309 .75867 .60006 .76954 .59742 .76396 .58056 Metetra
.596 .519 .739 r
.76396 .58056 .76954 .59742 .78052 .59555 .77497 .57924 Metetra
.577 .514 .747 r
.77497 .57924 .78052 .59555 .79159 .59434 .78611 .57895 Metetra
.562 .514 .759 r
.78611 .57895 .79159 .59434 .80277 .59362 .79737 .57938 Metetra
.551 .521 .775 r
.79737 .57938 .80277 .59362 .81402 .5932 .80873 .58019 Metetra
.545 .534 .793 r
.80873 .58019 .81402 .5932 .82535 .5929 .82016 .58108 Metetra
.543 .552 .813 r
.82016 .58108 .82535 .5929 .83673 .59256 .83165 .58183 Metetra
.546 .573 .833 r
.83165 .58183 .83673 .59256 .84817 .59208 .84319 .58228 Metetra
.552 .596 .852 r
.84319 .58228 .84817 .59208 .85964 .5914 .85476 .58238 Metetra
.56 .619 .869 r
.85476 .58238 .85964 .5914 .87116 .59047 .86636 .58208 Metetra
.568 .641 .883 r
.86636 .58208 .87116 .59047 .88271 .58929 .87798 .58141 Metetra
.577 .661 .894 r
.87798 .58141 .88271 .58929 .89429 .58787 .88963 .58038 Metetra
.586 .677 .903 r
.88963 .58038 .89429 .58787 .9059 .58622 .9013 .57903 Metetra
.594 .692 .91 r
.9013 .57903 .9059 .58622 .91754 .58436 .913 .57741 Metetra
.601 .704 .916 r
.913 .57741 .91754 .58436 .92922 .58231 .92473 .57554 Metetra
.607 .713 .92 r
.92473 .57554 .92922 .58231 .94094 .58011 .9365 .57347 Metetra
.612 .722 .923 r
.9365 .57347 .94094 .58011 .95269 .57776 .94829 .57123 Metetra
.69 .751 .898 r
.32422 .7377 .33011 .74306 .33956 .73951 .33369 .734 Metetra
.696 .748 .892 r
.33369 .734 .33956 .73951 .34905 .73579 .34321 .73008 Metetra
.703 .744 .883 r
.34321 .73008 .34905 .73579 .35857 .73187 .35276 .72593 Metetra
.71 .738 .873 r
.35276 .72593 .35857 .73187 .36813 .72772 .36236 .72147 Metetra
.717 .731 .862 r
.36236 .72147 .36813 .72772 .37772 .7233 .37199 .71665 Metetra
.724 .722 .848 r
.37199 .71665 .37772 .7233 .38736 .71857 .38166 .71142 Metetra
.731 .711 .832 r
.38166 .71142 .38736 .71857 .39702 .7135 .39137 .70569 Metetra
.736 .697 .814 r
.39137 .70569 .39702 .7135 .40672 .70806 .40112 .69939 Metetra
.738 .681 .795 r
.40112 .69939 .40672 .70806 .41646 .70224 .4109 .69249 Metetra
.738 .663 .776 r
.4109 .69249 .41646 .70224 .42622 .69605 .42072 .68496 Metetra
.735 .642 .756 r
.42072 .68496 .42622 .69605 .436 .68957 .43055 .67687 Metetra
.727 .62 .739 r
.43055 .67687 .436 .68957 .4458 .68294 .4404 .66838 Metetra
.715 .597 .723 r
.4404 .66838 .4458 .68294 .45561 .67638 .45026 .65981 Metetra
.698 .573 .711 r
.45026 .65981 .45561 .67638 .46543 .67017 .46011 .65166 Metetra
.677 .549 .702 r
.46011 .65166 .46543 .67017 .47525 .66465 .46995 .6445 Metetra
.652 .525 .696 r
.46995 .6445 .47525 .66465 .48509 .66011 .47978 .63893 Metetra
.624 .503 .694 r
.47978 .63893 .48509 .66011 .49494 .65676 .48961 .63533 Metetra
.596 .484 .696 r
.48961 .63533 .49494 .65676 .50481 .65464 .49946 .6338 Metetra
.568 .469 .702 r
.49946 .6338 .50481 .65464 .51472 .65361 .50934 .63406 Metetra
.544 .462 .713 r
.50934 .63406 .51472 .65361 .52468 .65339 .51927 .63559 Metetra
.527 .464 .729 r
.51927 .63559 .52468 .65339 .53469 .65367 .52927 .63777 Metetra
.518 .476 .75 r
.52927 .63777 .53469 .65367 .54475 .6541 .53933 .64005 Metetra
.517 .497 .773 r
.53933 .64005 .54475 .6541 .55487 .65443 .54945 .64202 Metetra
.525 .524 .797 r
.54945 .64202 .55487 .65443 .56505 .65446 .55964 .6434 Metetra
.54 .556 .819 r
.55964 .6434 .56505 .65446 .57527 .65408 .56988 .64408 Metetra
.56 .587 .838 r
.56988 .64408 .57527 .65408 .58553 .65321 .58017 .64401 Metetra
.583 .616 .851 r
.58017 .64401 .58553 .65321 .59584 .65184 .59049 .64319 Metetra
.606 .64 .859 r
.59049 .64319 .59584 .65184 .60618 .64995 .60086 .64164 Metetra
.628 .659 .861 r
.60086 .64164 .60618 .64995 .61655 .64754 .61125 .63939 Metetra
.65 .673 .859 r
.61125 .63939 .61655 .64754 .62695 .64462 .62166 .63645 Metetra
.669 .681 .852 r
.62166 .63645 .62695 .64462 .63737 .64118 .6321 .63281 Metetra
.686 .683 .841 r
.6321 .63281 .63737 .64118 .6478 .63723 .64254 .62846 Metetra
.701 .68 .827 r
.64254 .62846 .6478 .63723 .65826 .63275 .65299 .62338 Metetra
.712 .673 .81 r
.65299 .62338 .65826 .63275 .66872 .62775 .66343 .61753 Metetra
.72 .661 .791 r
.66343 .61753 .66872 .62775 .67918 .62226 .67387 .61091 Metetra
.722 .645 .771 r
.67387 .61091 .67918 .62226 .68965 .61633 .68428 .60356 Metetra
.72 .626 .752 r
.68428 .60356 .68965 .61633 .70012 .61009 .69468 .59561 Metetra
.712 .604 .734 r
.69468 .59561 .70012 .61009 .71061 .60373 .70507 .58731 Metetra
.699 .581 .719 r
.70507 .58731 .71061 .60373 .72113 .59752 .71548 .57909 Metetra
.681 .556 .707 r
.71548 .57909 .72113 .59752 .7317 .59179 .72593 .57152 Metetra
.658 .532 .699 r
.72593 .57152 .7317 .59179 .74234 .58688 .73647 .56523 Metetra
.632 .509 .695 r
.73647 .56523 .74234 .58688 .75309 .58309 .74715 .56076 Metetra
.604 .489 .695 r
.74715 .56076 .75309 .58309 .76396 .58056 .75801 .5584 Metetra
.577 .473 .699 r
.75801 .5584 .76396 .58056 .77497 .57924 .76907 .55808 Metetra
.552 .463 .708 r
.76907 .55808 .77497 .57924 .78611 .57895 .7803 .5594 Metetra
.532 .461 .722 r
.7803 .5594 .78611 .57895 .79737 .57938 .7917 .56176 Metetra
.517 .467 .74 r
.7917 .56176 .79737 .57938 .80873 .58019 .80321 .56458 Metetra
.509 .482 .762 r
.80321 .56458 .80873 .58019 .82016 .58108 .8148 .56734 Metetra
.508 .504 .786 r
.8148 .56734 .82016 .58108 .83165 .58183 .82643 .56971 Metetra
.513 .531 .812 r
.82643 .56971 .83165 .58183 .84319 .58228 .8381 .57151 Metetra
.523 .561 .836 r
.8381 .57151 .84319 .58228 .85476 .58238 .84979 .57268 Metetra
.534 .591 .857 r
.84979 .57268 .85476 .58238 .86636 .58208 .86148 .57322 Metetra
.547 .619 .875 r
.86148 .57322 .86636 .58208 .87798 .58141 .87319 .57319 Metetra
.56 .644 .89 r
.87319 .57319 .87798 .58141 .88963 .58038 .88492 .57265 Metetra
.572 .665 .901 r
.88492 .57265 .88963 .58038 .9013 .57903 .89666 .57168 Metetra
.583 .683 .909 r
.89666 .57168 .9013 .57903 .913 .57741 .90842 .57034 Metetra
.592 .697 .915 r
.90842 .57034 .913 .57741 .92473 .57554 .92021 .56868 Metetra
.6 .709 .92 r
.92021 .56868 .92473 .57554 .9365 .57347 .93202 .56677 Metetra
.607 .718 .923 r
.93202 .56677 .9365 .57347 .94829 .57123 .94387 .56463 Metetra
.695 .752 .896 r
.31828 .73229 .32422 .7377 .33369 .734 .32779 .72843 Metetra
.702 .749 .888 r
.32779 .72843 .33369 .734 .34321 .73008 .33734 .72431 Metetra
.71 .744 .878 r
.33734 .72431 .34321 .73008 .35276 .72593 .34692 .71989 Metetra
.718 .738 .867 r
.34692 .71989 .35276 .72593 .36236 .72147 .35655 .71508 Metetra
.727 .73 .853 r
.35655 .71508 .36236 .72147 .37199 .71665 .36623 .7098 Metetra
.736 .72 .836 r
.36623 .7098 .37199 .71665 .38166 .71142 .37595 .70395 Metetra
.744 .707 .817 r
.37595 .70395 .38166 .71142 .39137 .70569 .38571 .69739 Metetra
.75 .692 .796 r
.38571 .69739 .39137 .70569 .40112 .69939 .39552 .69 Metetra
.753 .673 .773 r
.39552 .69 .40112 .69939 .4109 .69249 .40536 .68163 Metetra
.753 .653 .75 r
.40536 .68163 .4109 .69249 .42072 .68496 .41525 .67219 Metetra
.749 .63 .728 r
.41525 .67219 .42072 .68496 .43055 .67687 .42517 .66167 Metetra
.74 .605 .708 r
.42517 .66167 .43055 .67687 .4404 .66838 .4351 .65025 Metetra
.726 .579 .69 r
.4351 .65025 .4404 .66838 .45026 .65981 .44503 .63836 Metetra
.706 .552 .677 r
.44503 .63836 .45026 .65981 .46011 .65166 .45493 .62682 Metetra
.68 .524 .667 r
.45493 .62682 .46011 .65166 .46995 .6445 .4648 .61672 Metetra
.649 .494 .66 r
.4648 .61672 .46995 .6445 .47978 .63893 .47462 .60923 Metetra
.613 .465 .657 r
.47462 .60923 .47978 .63893 .48961 .63533 .48441 .60521 Metetra
.575 .438 .657 r
.48441 .60521 .48961 .63533 .49946 .6338 .49419 .60484 Metetra
.537 .415 .661 r
.49419 .60484 .49946 .6338 .50934 .63406 .50401 .60754 Metetra
.504 .401 .671 r
.50401 .60754 .50934 .63406 .51927 .63559 .51389 .61223 Metetra
.479 .399 .688 r
.51389 .61223 .51927 .63559 .52927 .63777 .52384 .61772 Metetra
.465 .409 .711 r
.52384 .61772 .52927 .63777 .53933 .64005 .53389 .62304 Metetra
.464 .433 .739 r
.53389 .62304 .53933 .64005 .54945 .64202 .54401 .62756 Metetra
.475 .468 .77 r
.54401 .62756 .54945 .64202 .55964 .6434 .5542 .63096 Metetra
.497 .509 .8 r
.5542 .63096 .55964 .6434 .56988 .64408 .56446 .63317 Metetra
.526 .552 .825 r
.56446 .63317 .56988 .64408 .58017 .64401 .57477 .63419 Metetra
.558 .591 .843 r
.57477 .63419 .58017 .64401 .59049 .64319 .58512 .63411 Metetra
.59 .624 .854 r
.58512 .63411 .59049 .64319 .60086 .64164 .5955 .63302 Metetra
.621 .649 .857 r
.5955 .63302 .60086 .64164 .61125 .63939 .60591 .63097 Metetra
.649 .667 .854 r
.60591 .63097 .61125 .63939 .62166 .63645 .61634 .628 Metetra
.674 .677 .845 r
.61634 .628 .62166 .63645 .6321 .63281 .62679 .62412 Metetra
.696 .681 .831 r
.62679 .62412 .6321 .63281 .64254 .62846 .63724 .61927 Metetra
.714 .677 .813 r
.63724 .61927 .64254 .62846 .65299 .62338 .64767 .61339 Metetra
.728 .668 .791 r
.64767 .61339 .65299 .62338 .66343 .61753 .65809 .60638 Metetra
.737 .654 .768 r
.65809 .60638 .66343 .61753 .67387 .61091 .66847 .59817 Metetra
.74 .635 .743 r
.66847 .59817 .67387 .61091 .68428 .60356 .67881 .58872 Metetra
.737 .613 .72 r
.67881 .58872 .68428 .60356 .69468 .59561 .68909 .57811 Metetra
.727 .588 .7 r
.68909 .57811 .69468 .59561 .70507 .58731 .69931 .56666 Metetra
.711 .562 .683 r
.69931 .56666 .70507 .58731 .71548 .57909 .70952 .55501 Metetra
.689 .533 .671 r
.70952 .55501 .71548 .57909 .72593 .57152 .71975 .54414 Metetra
.66 .504 .662 r
.71975 .54414 .72593 .57152 .73647 .56523 .7301 .53527 Metetra
.627 .476 .658 r
.7301 .53527 .73647 .56523 .74715 .56076 .74065 .52952 Metetra
.591 .449 .657 r
.74065 .52952 .74715 .56076 .75801 .5584 .75148 .52751 Metetra
.554 .426 .66 r
.75148 .52751 .75801 .5584 .76907 .55808 .76261 .52906 Metetra
.521 .41 .668 r
.76261 .52906 .76907 .55808 .7803 .5594 .77402 .53333 Metetra
.494 .403 .681 r
.77402 .53333 .7803 .5594 .7917 .56176 .78564 .53911 Metetra
.474 .406 .701 r
.78564 .53911 .7917 .56176 .80321 .56458 .79739 .54528 Metetra
.464 .421 .726 r
.79739 .54528 .80321 .56458 .8148 .56734 .8092 .55101 Metetra
.463 .447 .755 r
.8092 .55101 .8148 .56734 .82643 .56971 .82105 .55583 Metetra
.47 .481 .787 r
.82105 .55583 .82643 .56971 .8381 .57151 .83289 .55957 Metetra
.484 .519 .817 r
.83289 .55957 .8381 .57151 .84979 .57268 .84472 .56221 Metetra
.502 .557 .845 r
.84472 .56221 .84979 .57268 .86148 .57322 .85654 .56386 Metetra
.521 .593 .867 r
.85654 .56386 .86148 .57322 .87319 .57319 .86835 .56464 Metetra
.539 .625 .885 r
.86835 .56464 .87319 .57319 .88492 .57265 .88016 .56471 Metetra
.556 .651 .899 r
.88016 .56471 .88492 .57265 .89666 .57168 .89198 .56417 Metetra
.57 .673 .908 r
.89198 .56417 .89666 .57168 .90842 .57034 .90381 .56315 Metetra
.583 .69 .915 r
.90381 .56315 .90842 .57034 .92021 .56868 .91565 .56173 Metetra
.593 .704 .92 r
.91565 .56173 .92021 .56868 .93202 .56677 .92752 .55999 Metetra
.601 .715 .924 r
.92752 .55999 .93202 .56677 .94387 .56463 .93941 .55799 Metetra
.7 .753 .893 r
.31231 .72685 .31828 .73229 .32779 .72843 .32185 .72282 Metetra
.708 .75 .884 r
.32185 .72282 .32779 .72843 .33734 .72431 .33143 .71849 Metetra
.717 .745 .874 r
.33143 .71849 .33734 .72431 .34692 .71989 .34105 .71377 Metetra
.727 .739 .86 r
.34105 .71377 .34692 .71989 .35655 .71508 .35072 .70857 Metetra
.738 .73 .844 r
.35072 .70857 .35655 .71508 .36623 .7098 .36044 .70277 Metetra
.748 .719 .825 r
.36044 .70277 .36623 .7098 .37595 .70395 .37021 .69618 Metetra
.758 .705 .802 r
.37021 .69618 .37595 .70395 .38571 .69739 .38004 .68861 Metetra
.765 .688 .777 r
.38004 .68861 .38571 .69739 .39552 .69 .38992 .67981 Metetra
.769 .668 .75 r
.38992 .67981 .39552 .69 .40536 .68163 .39985 .66947 Metetra
.77 .645 .724 r
.39985 .66947 .40536 .68163 .41525 .67219 .40984 .65733 Metetra
.765 .62 .699 r
.40984 .65733 .41525 .67219 .42517 .66167 .41988 .64316 Metetra
.755 .594 .677 r
.41988 .64316 .42517 .66167 .4351 .65025 .42994 .62703 Metetra
.74 .567 .659 r
.42994 .62703 .4351 .65025 .44503 .63836 .43999 .60947 Metetra
.717 .537 .645 r
.43999 .60947 .44503 .63836 .45493 .62682 .45 .59175 Metetra
.687 .505 .635 r
.45 .59175 .45493 .62682 .4648 .61672 .45992 .576 Metetra
.649 .469 .628 r
.45992 .576 .4648 .61672 .47462 .60923 .46974 .56472 Metetra
.603 .432 .623 r
.46974 .56472 .47462 .60923 .48441 .60521 .47945 .55988 Metetra
.552 .394 .621 r
.47945 .55988 .48441 .60521 .49419 .60484 .48911 .56192 Metetra
.5 .36 .622 r
.48911 .56192 .49419 .60484 .50401 .60754 .4988 .56948 Metetra
.454 .335 .628 r
.4988 .56948 .50401 .60754 .51389 .61223 .50856 .58015 Metetra
.417 .324 .642 r
.50856 .58015 .51389 .61223 .52384 .61772 .51844 .59153 Metetra
.396 .33 .665 r
.51844 .59153 .52384 .61772 .53389 .62304 .52844 .60194 Metetra
.392 .355 .698 r
.52844 .60194 .53389 .62304 .54401 .62756 .53855 .61048 Metetra
.407 .398 .737 r
.53855 .61048 .54401 .62756 .5542 .63096 .54874 .61689 Metetra
.439 .452 .776 r
.54874 .61689 .5542 .63096 .56446 .63317 .55901 .62124 Metetra
.48 .509 .81 r
.55901 .62124 .56446 .63317 .57477 .63419 .56933 .62374 Metetra
.526 .562 .835 r
.56933 .62374 .57477 .63419 .58512 .63411 .57971 .62463 Metetra
.571 .606 .849 r
.57971 .62463 .58512 .63411 .5955 .63302 .59011 .62411 Metetra
.612 .64 .854 r
.59011 .62411 .5955 .63302 .60591 .63097 .60054 .62232 Metetra
.649 .662 .85 r
.60054 .62232 .60591 .63097 .61634 .628 .61099 .61933 Metetra
.681 .675 .838 r
.61099 .61933 .61634 .628 .62679 .62412 .62145 .61514 Metetra
.708 .68 .821 r
.62145 .61514 .62679 .62412 .63724 .61927 .63189 .60966 Metetra
.73 .676 .798 r
.63189 .60966 .63724 .61927 .64767 .61339 .64232 .60276 Metetra
.746 .666 .772 r
.64232 .60276 .64767 .61339 .65809 .60638 .6527 .59421 Metetra
.757 .65 .743 r
.6527 .59421 .65809 .60638 .66847 .59817 .663 .58378 Metetra
.76 .629 .715 r
.663 .58378 .66847 .59817 .67881 .58872 .67321 .57123 Metetra
.756 .604 .689 r
.67321 .57123 .67881 .58872 .68909 .57811 .6833 .55647 Metetra
.745 .577 .666 r
.6833 .55647 .68909 .57811 .69931 .56666 .69325 .53979 Metetra
.727 .548 .649 r
.69325 .53979 .69931 .56666 .70952 .55501 .7031 .52205 Metetra
.7 .516 .636 r
.7031 .52205 .70952 .55501 .71975 .54414 .71294 .505 Metetra
.665 .483 .628 r
.71294 .505 .71975 .54414 .7301 .53527 .72292 .49107 Metetra
.623 .447 .624 r
.72292 .49107 .7301 .53527 .74065 .52952 .73321 .48275 Metetra
.577 .412 .622 r
.73321 .48275 .74065 .52952 .75148 .52751 .74398 .48146 Metetra
.529 .38 .623 r
.74398 .48146 .75148 .52751 .76261 .52906 .75527 .48678 Metetra
.485 .356 .629 r
.75527 .48678 .76261 .52906 .77402 .53333 .76699 .49675 Metetra
.448 .341 .64 r
.76699 .49675 .77402 .53333 .78564 .53911 .779 .50878 Metetra
.421 .34 .659 r
.779 .50878 .78564 .53911 .79739 .54528 .79115 .52072 Metetra
.406 .353 .686 r
.79115 .52072 .79739 .54528 .8092 .55101 .80332 .53125 Metetra
.405 .381 .719 r
.80332 .53125 .8092 .55101 .82105 .55583 .81546 .53979 Metetra
.415 .421 .758 r
.81546 .53979 .82105 .55583 .83289 .55957 .82754 .54627 Metetra
.435 .469 .796 r
.82754 .54627 .83289 .55957 .84472 .56221 .83956 .55091 Metetra
.461 .518 .831 r
.83956 .55091 .84472 .56221 .85654 .56386 .85153 .55398 Metetra
.488 .564 .859 r
.85153 .55398 .85654 .56386 .86835 .56464 .86346 .55578 Metetra
.514 .604 .881 r
.86346 .55578 .86835 .56464 .88016 .56471 .87536 .55656 Metetra
.537 .637 .897 r
.87536 .55656 .88016 .56471 .89198 .56417 .88726 .55653 Metetra
.556 .663 .908 r
.88726 .55653 .89198 .56417 .90381 .56315 .89915 .55588 Metetra
.572 .683 .916 r
.89915 .55588 .90381 .56315 .91565 .56173 .91106 .55472 Metetra
.585 .699 .921 r
.91106 .55472 .91565 .56173 .92752 .55999 .92298 .55317 Metetra
.595 .712 .925 r
.92298 .55317 .92752 .55999 .93941 .55799 .93492 .55129 Metetra
.704 .754 .891 r
.30631 .72139 .31231 .72685 .32185 .72282 .31587 .71719 Metetra
.714 .751 .881 r
.31587 .71719 .32185 .72282 .33143 .71849 .32549 .71263 Metetra
.725 .746 .869 r
.32549 .71263 .33143 .71849 .34105 .71377 .33515 .70761 Metetra
.737 .74 .854 r
.33515 .70761 .34105 .71377 .35072 .70857 .34486 .70199 Metetra
.749 .731 .835 r
.34486 .70199 .35072 .70857 .36044 .70277 .35463 .69559 Metetra
.762 .719 .813 r
.35463 .69559 .36044 .70277 .37021 .69618 .36446 .68817 Metetra
.773 .704 .787 r
.36446 .68817 .37021 .69618 .38004 .68861 .37436 .6794 Metetra
.781 .686 .758 r
.37436 .6794 .38004 .68861 .38992 .67981 .38433 .66883 Metetra
.787 .664 .728 r
.38433 .66883 .38992 .67981 .39985 .66947 .39438 .65591 Metetra
.788 .64 .699 r
.39438 .65591 .39985 .66947 .40984 .65733 .40451 .63998 Metetra
.783 .615 .672 r
.40451 .63998 .40984 .65733 .41988 .64316 .41473 .62036 Metetra
.774 .589 .649 r
.41473 .62036 .41988 .64316 .42994 .62703 .42501 .59661 Metetra
.758 .561 .631 r
.42501 .59661 .42994 .62703 .43999 .60947 .4353 .56907 Metetra
.733 .531 .618 r
.4353 .56907 .43999 .60947 .45 .59175 .44554 .5396 Metetra
.699 .496 .609 r
.44554 .5396 .45 .59175 .45992 .576 .45561 .51229 Metetra
.653 .454 .602 r
.45561 .51229 .45992 .576 .46974 .56472 .46544 .49287 Metetra
.595 .406 .595 r
.46544 .49287 .46974 .56472 .47945 .55988 .47501 .48629 Metetra
.527 .354 .589 r
.47501 .48629 .47945 .55988 .48911 .56192 .48443 .49369 Metetra
.457 .304 .585 r
.48443 .49369 .48911 .56192 .4988 .56948 .49384 .51155 Metetra
.392 .264 .585 r
.49384 .51155 .4988 .56948 .50856 .58015 .50338 .53411 Metetra
.34 .24 .593 r
.50338 .53411 .50856 .58015 .51844 .59153 .5131 .55633 Metetra
.306 .237 .613 r
.5131 .55633 .51844 .59153 .52844 .60194 .52301 .57535 Metetra
.297 .261 .648 r
.52301 .57535 .52844 .60194 .53855 .61048 .53307 .59019 Metetra
.315 .31 .695 r
.53307 .59019 .53855 .61048 .54874 .61689 .54326 .60097 Metetra
.358 .38 .747 r
.54326 .60097 .54874 .61689 .55901 .62124 .55353 .60826 Metetra
.418 .457 .793 r
.55353 .60826 .55901 .62124 .56933 .62374 .56388 .6127 Metetra
.484 .529 .828 r
.56388 .6127 .56933 .62374 .57971 .62463 .57427 .61481 Metetra
.546 .587 .847 r
.57427 .61481 .57971 .62463 .59011 .62411 .5847 .615 Metetra
.601 .631 .853 r
.5847 .615 .59011 .62411 .60054 .62232 .59515 .61353 Metetra
.648 .66 .847 r
.59515 .61353 .60054 .62232 .61099 .61933 .60561 .61051 Metetra
.688 .676 .833 r
.60561 .61051 .61099 .61933 .62145 .61514 .61608 .60595 Metetra
.721 .682 .811 r
.61608 .60595 .62145 .61514 .63189 .60966 .62652 .59971 Metetra
.748 .678 .783 r
.62652 .59971 .63189 .60966 .64232 .60276 .63692 .59153 Metetra
.767 .666 .751 r
.63692 .59153 .64232 .60276 .6527 .59421 .64725 .58098 Metetra
.779 .648 .718 r
.64725 .58098 .6527 .59421 .663 .58378 .65745 .56751 Metetra
.783 .626 .686 r
.65745 .56751 .663 .58378 .67321 .57123 .66747 .55047 Metetra
.779 .6 .657 r
.66747 .55047 .67321 .57123 .6833 .55647 .67726 .52927 Metetra
.767 .572 .634 r
.67726 .52927 .6833 .55647 .69325 .53979 .68677 .50376 Metetra
.747 .542 .618 r
.68677 .50376 .69325 .53979 .7031 .52205 .696 .47491 Metetra
.717 .509 .607 r
.696 .47491 .7031 .52205 .71294 .505 .70507 .44565 Metetra
.676 .47 .6 r
.70507 .44565 .71294 .505 .72292 .49107 .7143 .42109 Metetra
.623 .427 .596 r
.7143 .42109 .72292 .49107 .73321 .48275 .72408 .40716 Metetra
.563 .382 .593 r
.72408 .40716 .73321 .48275 .74398 .48146 .73475 .40748 Metetra
.501 .338 .592 r
.73475 .40748 .74398 .48146 .75527 .48678 .74638 .42098 Metetra
.442 .302 .594 r
.74638 .42098 .75527 .48678 .76699 .49675 .75876 .44263 Metetra
.393 .277 .601 r
.75876 .44263 .76699 .49675 .779 .50878 .77151 .46661 Metetra
.357 .268 .617 r
.77151 .46661 .779 .50878 .79115 .52072 .78435 .48873 Metetra
.335 .277 .643 r
.78435 .48873 .79115 .52072 .80332 .53125 .79708 .50704 Metetra
.331 .306 .68 r
.79708 .50704 .80332 .53125 .81546 .53979 .80965 .52115 Metetra
.345 .352 .724 r
.80965 .52115 .81546 .53979 .82754 .54627 .82205 .53151 Metetra
.372 .41 .771 r
.82205 .53151 .82754 .54627 .83956 .55091 .83431 .53878 Metetra
.409 .473 .815 r
.83431 .53878 .83956 .55091 .85153 .55398 .84645 .54363 Metetra
.447 .531 .851 r
.84645 .54363 .85153 .55398 .86346 .55578 .85851 .54664 Metetra
.483 .581 .877 r
.85851 .54664 .86346 .55578 .87536 .55656 .87052 .54825 Metetra
.514 .622 .896 r
.87052 .54825 .87536 .55656 .88726 .55653 .8825 .5488 Metetra
.539 .653 .909 r
.8825 .5488 .88726 .55653 .89915 .55588 .89447 .54854 Metetra
.56 .677 .917 r
.89447 .54854 .89915 .55588 .91106 .55472 .90643 .54767 Metetra
.576 .695 .923 r
.90643 .54767 .91106 .55472 .92298 .55317 .91841 .54631 Metetra
.589 .709 .926 r
.91841 .54631 .92298 .55317 .93492 .55129 .9304 .54457 Metetra
.709 .756 .889 r
.30026 .71593 .30631 .72139 .31587 .71719 .30986 .71156 Metetra
.72 .753 .879 r
.30986 .71156 .31587 .71719 .32549 .71263 .3195 .70677 Metetra
.732 .749 .865 r
.3195 .70677 .32549 .71263 .33515 .70761 .3292 .70144 Metetra
.746 .742 .848 r
.3292 .70144 .33515 .70761 .34486 .70199 .33896 .69538 Metetra
.761 .733 .827 r
.33896 .69538 .34486 .70199 .35463 .69559 .34878 .68836 Metetra
.775 .721 .802 r
.34878 .68836 .35463 .69559 .36446 .68817 .35868 .68002 Metetra
.788 .705 .773 r
.35868 .68002 .36446 .68817 .37436 .6794 .36866 .66986 Metetra
.799 .686 .74 r
.36866 .66986 .37436 .6794 .38433 .66883 .37875 .65718 Metetra
.805 .664 .707 r
.37875 .65718 .38433 .66883 .39438 .65591 .38895 .64098 Metetra
.807 .64 .675 r
.38895 .64098 .39438 .65591 .40451 .63998 .39929 .61992 Metetra
.804 .615 .647 r
.39929 .61992 .40451 .63998 .41473 .62036 .40978 .59229 Metetra
.795 .59 .625 r
.40978 .59229 .41473 .62036 .42501 .59661 .42043 .55629 Metetra
.78 .564 .608 r
.42043 .55629 .42501 .59661 .4353 .56907 .43119 .51096 Metetra
.725 .511 .601 r
.43119 .51096 .4353 .56907 .44554 .5396 .44159 .47149 Metetra
.579 .395 .596 r
.44159 .47149 .44554 .5396 .45561 .51229 .45101 .46845 Metetra
.589 .421 .621 r
.45101 .46845 .45561 .51229 .46544 .49287 .46045 .46541 Metetra
.605 .462 .661 r
.46045 .46541 .46544 .49287 .47501 .48629 .46993 .46235 Metetra
.61 .478 .676 r
.46993 .46235 .47501 .48629 .48443 .49369 .47945 .45928 Metetra
.597 .44 .64 r
.47945 .45928 .48443 .49369 .49384 .51155 .48899 .45621 Metetra
.5 .344 .601 r
.48899 .45621 .49384 .51155 .50338 .53411 .49847 .46551 Metetra
.242 .145 .539 r
.49847 .46551 .50338 .53411 .5131 .55633 .50789 .50809 Metetra
.19 .129 .553 r
.50789 .50809 .5131 .55633 .52301 .57535 .51763 .54168 Metetra
.17 .146 .586 r
.51763 .54168 .52301 .57535 .53307 .59019 .52761 .5662 Metetra
.189 .2 .64 r
.52761 .5662 .53307 .59019 .54326 .60097 .53777 .58317 Metetra
.248 .288 .708 r
.53777 .58317 .54326 .60097 .55353 .60826 .54804 .59436 Metetra
.334 .391 .773 r
.54804 .59436 .55353 .60826 .56388 .6127 .55839 .6012 Metetra
.428 .489 .821 r
.55839 .6012 .56388 .6127 .57427 .61481 .5688 .60478 Metetra
.514 .568 .847 r
.5688 .60478 .57427 .61481 .5847 .615 .57925 .60579 Metetra
.588 .624 .855 r
.57925 .60579 .5847 .615 .59515 .61353 .58972 .60468 Metetra
.648 .66 .847 r
.58972 .60468 .59515 .61353 .60561 .61051 .60021 .60164 Metetra
.697 .679 .829 r
.60021 .60164 .60561 .61051 .61608 .60595 .61068 .59667 Metetra
.737 .686 .802 r
.61068 .59667 .61608 .60595 .62652 .59971 .62112 .58956 Metetra
.767 .682 .769 r
.62112 .58956 .62652 .59971 .63692 .59153 .63149 .57985 Metetra
.789 .67 .732 r
.63149 .57985 .63692 .59153 .64725 .58098 .64175 .56681 Metetra
.803 .651 .693 r
.64175 .56681 .64725 .58098 .65745 .56751 .65182 .54936 Metetra
.808 .627 .658 r
.65182 .54936 .65745 .56751 .66747 .55047 .6616 .52598 Metetra
.805 .602 .628 r
.6616 .52598 .66747 .55047 .67726 .52927 .67094 .49489 Metetra
.793 .575 .605 r
.67094 .49489 .67726 .52927 .68677 .50376 .67971 .45451 Metetra
.773 .546 .59 r
.67971 .45451 .68677 .50376 .696 .47491 .68782 .40489 Metetra
.63 .432 .595 r
.68782 .40489 .696 .47491 .70507 .44565 .69747 .38899 Metetra
.583 .406 .607 r
.69747 .38899 .70507 .44565 .7143 .42109 .7078 .38567 Metetra
.597 .44 .64 r
.7078 .38567 .7143 .42109 .72408 .40716 .71816 .38232 Metetra
.61 .478 .676 r
.71816 .38232 .72408 .40716 .73475 .40748 .72856 .37897 Metetra
.605 .462 .661 r
.72856 .37897 .73475 .40748 .74638 .42098 .739 .37561 Metetra
.589 .421 .621 r
.739 .37561 .74638 .42098 .75876 .44263 .74947 .37223 Metetra
.37 .248 .58 r
.74947 .37223 .75876 .44263 .77151 .46661 .76275 .40628 Metetra
.279 .192 .575 r
.76275 .40628 .77151 .46661 .78435 .48873 .77679 .44655 Metetra
.247 .193 .597 r
.77679 .44655 .78435 .48873 .79708 .50704 .79042 .47739 Metetra
.238 .22 .635 r
.79042 .47739 .79708 .50704 .80965 .52115 .80361 .49971 Metetra
.254 .271 .686 r
.80361 .49971 .80965 .52115 .82205 .53151 .81643 .51532 Metetra
.291 .342 .743 r
.81643 .51532 .82205 .53151 .83431 .53878 .82897 .52594 Metetra
.342 .421 .798 r
.82897 .52594 .83431 .53878 .84645 .54363 .84132 .53294 Metetra
.396 .495 .843 r
.84132 .53294 .84645 .54363 .85851 .54664 .85353 .53735 Metetra
.445 .557 .875 r
.85353 .53735 .85851 .54664 .87052 .54825 .86565 .53988 Metetra
.487 .607 .897 r
.86565 .53988 .87052 .54825 .8825 .5488 .87772 .54104 Metetra
.52 .644 .911 r
.87772 .54104 .8825 .5488 .89447 .54854 .88976 .54119 Metetra
.546 .671 .92 r
.88976 .54119 .89447 .54854 .90643 .54767 .90178 .5406 Metetra
.566 .692 .925 r
.90178 .5406 .90643 .54767 .91841 .54631 .91381 .53943 Metetra
.582 .707 .928 r
.91381 .53943 .91841 .54631 .9304 .54457 .92585 .53783 Metetra
.714 .759 .888 r
.29417 .71048 .30026 .71593 .30986 .71156 .3038 .70595 Metetra
.726 .756 .877 r
.3038 .70595 .30986 .71156 .3195 .70677 .31348 .70095 Metetra
.74 .752 .862 r
.31348 .70095 .3195 .70677 .3292 .70144 .32322 .69531 Metetra
.755 .746 .844 r
.32322 .69531 .3292 .70144 .33896 .69538 .33303 .68882 Metetra
.772 .737 .821 r
.33303 .68882 .33896 .69538 .34878 .68836 .34291 .68116 Metetra
.789 .725 .793 r
.34291 .68116 .34878 .68836 .35868 .68002 .35287 .67186 Metetra
.804 .709 .76 r
.35287 .67186 .35868 .68002 .36866 .66986 .36295 .66021 Metetra
.816 .689 .725 r
.36295 .66021 .36866 .66986 .37875 .65718 .37316 .64514 Metetra
.824 .667 .688 r
.37316 .64514 .37875 .65718 .38895 .64098 .38355 .62503 Metetra
.827 .644 .655 r
.38355 .62503 .38895 .64098 .39929 .61992 .39416 .59738 Metetra
.825 .621 .626 r
.39416 .59738 .39929 .61992 .40978 .59229 .40507 .55852 Metetra
.819 .598 .604 r
.40507 .55852 .40978 .59229 .42043 .55629 .41634 .50341 Metetra
.721 .511 .605 r
.41634 .50341 .42043 .55629 .43119 .51096 .42674 .46892 Metetra
.59 .423 .624 r
.42674 .46892 .43119 .51096 .44159 .47149 .43614 .46587 Metetra
.664 .741 .907 r
.43614 .46587 .44159 .47149 .45101 .46845 .44558 .46282 Metetra
.664 .741 .907 r
.44558 .46282 .45101 .46845 .46045 .46541 .45504 .45976 Metetra
.664 .741 .907 r
.45504 .45976 .46045 .46541 .46993 .46235 .46454 .45668 Metetra
.664 .741 .907 r
.46454 .45668 .46993 .46235 .47945 .45928 .47408 .45359 Metetra
.664 .741 .907 r
.47408 .45359 .47945 .45928 .48899 .45621 .48364 .4505 Metetra
.664 .741 .907 r
.48364 .4505 .48899 .45621 .49847 .46551 .49325 .44739 Metetra
.622 .516 .712 r
.49325 .44739 .49847 .46551 .50789 .50809 .50288 .44427 Metetra
.042 .002 .481 r
.50288 .44427 .50789 .50809 .51763 .54168 .51233 .49977 Metetra
0 .003 .503 r
.51233 .49977 .51763 .54168 .52761 .5662 .52217 .53855 Metetra
.015 .06 .564 r
.52217 .53855 .52761 .5662 .53777 .58317 .53227 .56383 Metetra
.093 .169 .652 r
.53227 .56383 .53777 .58317 .54804 .59436 .54253 .57985 Metetra
.216 .308 .744 r
.54253 .57985 .54804 .59436 .55839 .6012 .55289 .58953 Metetra
.353 .443 .814 r
.55289 .58953 .55839 .6012 .5688 .60478 .56332 .59474 Metetra
.475 .548 .851 r
.56332 .59474 .5688 .60478 .57925 .60579 .57378 .59665 Metetra
.573 .619 .86 r
.57378 .59665 .57925 .60579 .58972 .60468 .58428 .59593 Metetra
.649 .663 .85 r
.58428 .59593 .58972 .60468 .60021 .60164 .59477 .59287 Metetra
.707 .686 .828 r
.59477 .59287 .60021 .60164 .61068 .59667 .60526 .58746 Metetra
.753 .694 .795 r
.60526 .58746 .61068 .59667 .62112 .58956 .61569 .57939 Metetra
.788 .69 .756 r
.61569 .57939 .62112 .58956 .63149 .57985 .62604 .56798 Metetra
.813 .677 .713 r
.62604 .56798 .63149 .57985 .64175 .56681 .63622 .55203 Metetra
.828 .657 .671 r
.63622 .55203 .64175 .56681 .65182 .54936 .64614 .52963 Metetra
.834 .634 .632 r
.64614 .52963 .65182 .54936 .6616 .52598 .65559 .49779 Metetra
.833 .61 .601 r
.65559 .49779 .6616 .52598 .67094 .49489 .66432 .45219 Metetra
.82 .583 .581 r
.66432 .45219 .67094 .49489 .67971 .45451 .67203 .3895 Metetra
.58 .397 .599 r
.67203 .3895 .67971 .45451 .68782 .40489 .68231 .38618 Metetra
.622 .516 .712 r
.68231 .38618 .68782 .40489 .69747 .38899 .69262 .38284 Metetra
.664 .741 .907 r
.69262 .38284 .69747 .38899 .7078 .38567 .70297 .37949 Metetra
.664 .741 .907 r
.70297 .37949 .7078 .38567 .71816 .38232 .71336 .37612 Metetra
.664 .741 .907 r
.71336 .37612 .71816 .38232 .72856 .37897 .72379 .37275 Metetra
.664 .741 .907 r
.72379 .37275 .72856 .37897 .739 .37561 .73425 .36936 Metetra
.664 .741 .907 r
.73425 .36936 .739 .37561 .74947 .37223 .74476 .36596 Metetra
.664 .741 .907 r
.74476 .36596 .74947 .37223 .76275 .40628 .7553 .36255 Metetra
.279 .21 .597 r
.7553 .36255 .76275 .40628 .77679 .44655 .76833 .39149 Metetra
.137 .098 .547 r
.76833 .39149 .77679 .44655 .79042 .47739 .78332 .44186 Metetra
.119 .12 .583 r
.78332 .44186 .79042 .47739 .80361 .49971 .79736 .4757 Metetra
.135 .176 .64 r
.79736 .4757 .80361 .49971 .81643 .51532 .81071 .49806 Metetra
.185 .261 .71 r
.81071 .49806 .81643 .51532 .82897 .52594 .82359 .5127 Metetra
.256 .36 .778 r
.82359 .5127 .82897 .52594 .84132 .53294 .83616 .52213 Metetra
.332 .455 .835 r
.83616 .52213 .84132 .53294 .85353 .53735 .84853 .52805 Metetra
.401 .533 .874 r
.84853 .52805 .85353 .53735 .86565 .53988 .86076 .53153 Metetra
.457 .592 .899 r
.86076 .53153 .86565 .53988 .87772 .54104 .87291 .53332 Metetra
.5 .636 .914 r
.87291 .53332 .87772 .54104 .88976 .54119 .88502 .53388 Metetra
.532 .667 .923 r
.88502 .53388 .88976 .54119 .90178 .5406 .89711 .53356 Metetra
.557 .689 .928 r
.89711 .53356 .90178 .5406 .91381 .53943 .90919 .53257 Metetra
.575 .706 .931 r
.90919 .53257 .91381 .53943 .92585 .53783 .92128 .5311 Metetra
.718 .761 .887 r
.28804 .70507 .29417 .71048 .3038 .70595 .2977 .70039 Metetra
.731 .759 .875 r
.2977 .70039 .3038 .70595 .31348 .70095 .30741 .69519 Metetra
.746 .756 .86 r
.30741 .69519 .31348 .70095 .32322 .69531 .31719 .68928 Metetra
.764 .751 .841 r
.31719 .68928 .32322 .69531 .33303 .68882 .32704 .68239 Metetra
.783 .743 .816 r
.32704 .68239 .33303 .68882 .34291 .68116 .33698 .67414 Metetra
.802 .731 .786 r
.33698 .67414 .34291 .68116 .35287 .67186 .34703 .66391 Metetra
.819 .715 .75 r
.34703 .66391 .35287 .67186 .36295 .66021 .3572 .65077 Metetra
.833 .696 .712 r
.3572 .65077 .36295 .66021 .37316 .64514 .36756 .63323 Metetra
.843 .674 .673 r
.36756 .63323 .37316 .64514 .38355 .62503 .37816 .60882 Metetra
.848 .652 .638 r
.37816 .60882 .38355 .62503 .39416 .59738 .38912 .57343 Metetra
.848 .631 .608 r
.38912 .57343 .39416 .59738 .40507 .55852 .4006 .52011 Metetra
.803 .583 .603 r
.4006 .52011 .40507 .55852 .41634 .50341 .41184 .46634 Metetra
.593 .432 .633 r
.41184 .46634 .41634 .50341 .42674 .46892 .42123 .46329 Metetra
.664 .741 .907 r
.42123 .46329 .42674 .46892 .43614 .46587 .43065 .46023 Metetra
.664 .741 .907 r
.43065 .46023 .43614 .46587 .44558 .46282 .44011 .45715 Metetra
.664 .741 .907 r
.44011 .45715 .44558 .46282 .45504 .45976 .4496 .45407 Metetra
.664 .741 .907 r
.4496 .45407 .45504 .45976 .46454 .45668 .45912 .45097 Metetra
.664 .741 .907 r
.45912 .45097 .46454 .45668 .47408 .45359 .46867 .44787 Metetra
.664 .741 .907 r
.46867 .44787 .47408 .45359 .48364 .4505 .47826 .44475 Metetra
.664 .741 .907 r
.47826 .44475 .48364 .4505 .49325 .44739 .48789 .44162 Metetra
.664 .741 .907 r
.48789 .44162 .49325 .44739 .50288 .44427 .49754 .43848 Metetra
.613 .125 0 r
.49754 .43848 .50288 .44427 .51233 .49977 .50715 .45032 Metetra
0 0 .384 r
.50715 .45032 .51233 .49977 .52217 .53855 .51677 .50842 Metetra
0 0 .446 r
.51677 .50842 .52217 .53855 .53227 .56383 .52678 .54386 Metetra
0 .01 .562 r
.52678 .54386 .53227 .56383 .54253 .57985 .53701 .56537 Metetra
.05 .199 .699 r
.53701 .56537 .54253 .57985 .55289 .58953 .54737 .57808 Metetra
.252 .386 .805 r
.54737 .57808 .55289 .58953 .56332 .59474 .55781 .58497 Metetra
.426 .528 .859 r
.55781 .58497 .56332 .59474 .57378 .59665 .56829 .58778 Metetra
.556 .619 .87 r
.56829 .58778 .57378 .59665 .58428 .59593 .5788 .58743 Metetra
.649 .671 .857 r
.5788 .58743 .58428 .59593 .59477 .59287 .58932 .58434 Metetra
.718 .697 .829 r
.58932 .58434 .59477 .59287 .60526 .58746 .59981 .57851 Metetra
.77 .706 .791 r
.59981 .57851 .60526 .58746 .61569 .57939 .61025 .56949 Metetra
.809 .701 .746 r
.61025 .56949 .61569 .57939 .62604 .56798 .62058 .55634 Metetra
.837 .688 .697 r
.62058 .55634 .62604 .56798 .63622 .55203 .63069 .53729 Metetra
.854 .668 .65 r
.63069 .53729 .63622 .55203 .64614 .52963 .64044 .50929 Metetra
.862 .646 .609 r
.64044 .50929 .64614 .52963 .65559 .49779 .64953 .4671 Metetra
.862 .624 .577 r
.64953 .4671 .65559 .49779 .66432 .45219 .65746 .40186 Metetra
.666 .469 .609 r
.65746 .40186 .66432 .45219 .67203 .3895 .6671 .38335 Metetra
.664 .741 .907 r
.6671 .38335 .67203 .3895 .68231 .38618 .6774 .38 Metetra
.664 .741 .907 r
.6774 .38 .68231 .38618 .69262 .38284 .68774 .37664 Metetra
.664 .741 .907 r
.68774 .37664 .69262 .38284 .70297 .37949 .69811 .37327 Metetra
.664 .741 .907 r
.69811 .37327 .70297 .37949 .71336 .37612 .70853 .36988 Metetra
.664 .741 .907 r
.70853 .36988 .71336 .37612 .72379 .37275 .71898 .36648 Metetra
.664 .741 .907 r
.71898 .36648 .72379 .37275 .73425 .36936 .72947 .36307 Metetra
.664 .741 .907 r
.72947 .36307 .73425 .36936 .74476 .36596 .74001 .35965 Metetra
.664 .741 .907 r
.74001 .35965 .74476 .36596 .7553 .36255 .75058 .35621 Metetra
.664 .741 .907 r
.75058 .35621 .7553 .36255 .76833 .39149 .76118 .35276 Metetra
0 0 .501 r
.76118 .35276 .76833 .39149 .78332 .44186 .7759 .40158 Metetra
0 0 .515 r
.7759 .40158 .78332 .44186 .79736 .4757 .79101 .45023 Metetra
0 .057 .578 r
.79101 .45023 .79736 .4757 .81071 .49806 .80497 .48054 Metetra
.042 .162 .665 r
.80497 .48054 .81071 .49806 .82359 .5127 .81821 .49958 Metetra
.145 .29 .754 r
.81821 .49958 .82359 .5127 .83616 .52213 .831 .51154 Metetra
.254 .411 .827 r
.831 .51154 .83616 .52213 .84853 .52805 .84352 .51895 Metetra
.349 .509 .875 r
.84352 .51895 .84853 .52805 .86076 .53153 .85586 .52336 Metetra
.423 .58 .904 r
.85586 .52336 .86076 .53153 .87291 .53332 .8681 .52572 Metetra
.478 .63 .919 r
.8681 .52572 .87291 .53332 .88502 .53388 .88027 .52665 Metetra
.518 .664 .928 r
.88027 .52665 .88502 .53388 .89711 .53356 .89241 .52657 Metetra
.547 .688 .932 r
.89241 .52657 .89711 .53356 .90919 .53257 .90455 .52575 Metetra
.568 .706 .934 r
.90455 .52575 .90919 .53257 .92128 .5311 .91668 .52438 Metetra
.721 .765 .887 r
.28186 .69969 .28804 .70507 .2977 .70039 .29155 .6949 Metetra
.735 .763 .875 r
.29155 .6949 .2977 .70039 .30741 .69519 .3013 .68953 Metetra
.752 .761 .86 r
.3013 .68953 .30741 .69519 .31719 .68928 .31112 .6834 Metetra
.772 .757 .84 r
.31112 .6834 .31719 .68928 .32704 .68239 .32101 .67618 Metetra
.793 .75 .814 r
.32101 .67618 .32704 .68239 .33698 .67414 .33101 .66742 Metetra
.814 .739 .782 r
.33101 .66742 .33698 .67414 .34703 .66391 .34112 .6564 Metetra
.834 .725 .744 r
.34112 .6564 .34703 .66391 .3572 .65077 .3514 .64196 Metetra
.851 .706 .702 r
.3514 .64196 .3572 .65077 .36756 .63323 .3619 .62215 Metetra
.863 .686 .661 r
.3619 .62215 .36756 .63323 .37816 .60882 .37273 .59363 Metetra
.87 .665 .624 r
.37273 .59363 .37816 .60882 .38912 .57343 .38407 .55034 Metetra
.872 .647 .594 r
.38407 .55034 .38912 .57343 .4006 .52011 .39623 .48095 Metetra
.699 .506 .623 r
.39623 .48095 .4006 .52011 .41184 .46634 .40628 .4607 Metetra
.664 .741 .907 r
.40628 .4607 .41184 .46634 .42123 .46329 .41569 .45763 Metetra
.664 .741 .907 r
.41569 .45763 .42123 .46329 .43065 .46023 .42513 .45454 Metetra
.664 .741 .907 r
.42513 .45454 .43065 .46023 .44011 .45715 .43461 .45145 Metetra
.664 .741 .907 r
.43461 .45145 .44011 .45715 .4496 .45407 .44412 .44834 Metetra
.664 .741 .907 r
.44412 .44834 .4496 .45407 .45912 .45097 .45366 .44523 Metetra
.664 .741 .907 r
.45366 .44523 .45912 .45097 .46867 .44787 .46324 .4421 Metetra
.664 .741 .907 r
.46324 .4421 .46867 .44787 .47826 .44475 .47285 .43896 Metetra
.664 .741 .907 r
.47285 .43896 .47826 .44475 .48789 .44162 .48249 .43581 Metetra
.664 .741 .907 r
.48249 .43581 .48789 .44162 .49754 .43848 .49217 .43265 Metetra
.664 .741 .907 r
.49217 .43265 .49754 .43848 .50715 .45032 .50188 .42948 Metetra
.854 .555 .023 r
.50188 .42948 .50715 .45032 .51677 .50842 .51142 .47875 Metetra
0 0 .257 r
.51142 .47875 .51677 .50842 .52678 .54386 .5213 .52495 Metetra
0 0 .408 r
.5213 .52495 .52678 .54386 .53701 .56537 .53149 .55186 Metetra
0 .053 .616 r
.53149 .55186 .53701 .56537 .54737 .57808 .54184 .56739 Metetra
.116 .317 .788 r
.54184 .56739 .54737 .57808 .55781 .58497 .55228 .57579 Metetra
.366 .511 .87 r
.55228 .57579 .55781 .58497 .56829 .58778 .56278 .57937 Metetra
.537 .623 .885 r
.56278 .57937 .56829 .58778 .5788 .58743 .57331 .57935 Metetra
.651 .683 .867 r
.57331 .57935 .5788 .58743 .58932 .58434 .58384 .57624 Metetra
.73 .712 .833 r
.58384 .57624 .58932 .58434 .59981 .57851 .59435 .57003 Metetra
.788 .721 .79 r
.59435 .57003 .59981 .57851 .61025 .56949 .6048 .56019 Metetra
.831 .717 .739 r
.6048 .56019 .61025 .56949 .62058 .55634 .61512 .54547 Metetra
.861 .703 .685 r
.61512 .54547 .62058 .55634 .63069 .53729 .62518 .52351 Metetra
.88 .683 .633 r
.62518 .52351 .63069 .53729 .64044 .50929 .63478 .49 Metetra
.889 .662 .588 r
.63478 .49 .64044 .50929 .64953 .4671 .64352 .43688 Metetra
.849 .616 .586 r
.64352 .43688 .64953 .4671 .65746 .40186 .65184 .38052 Metetra
.615 .497 .695 r
.65184 .38052 .65746 .40186 .6671 .38335 .66213 .37716 Metetra
.664 .741 .907 r
.66213 .37716 .6671 .38335 .6774 .38 .67246 .37379 Metetra
.664 .741 .907 r
.67246 .37379 .6774 .38 .68774 .37664 .68282 .3704 Metetra
.664 .741 .907 r
.68282 .3704 .68774 .37664 .69811 .37327 .69322 .36701 Metetra
.664 .741 .907 r
.69322 .36701 .69811 .37327 .70853 .36988 .70367 .3636 Metetra
.664 .741 .907 r
.70367 .3636 .70853 .36988 .71898 .36648 .71415 .36018 Metetra
.664 .741 .907 r
.71415 .36018 .71898 .36648 .72947 .36307 .72466 .35674 Metetra
.664 .741 .907 r
.72466 .35674 .72947 .36307 .74001 .35965 .73522 .35329 Metetra
.664 .741 .907 r
.73522 .35329 .74001 .35965 .75058 .35621 .74582 .34983 Metetra
.664 .741 .907 r
.74582 .34983 .75058 .35621 .76118 .35276 .75646 .34636 Metetra
0 0 .518 r
.75646 .34636 .76118 .35276 .7759 .40158 .76849 .36058 Metetra
0 0 .409 r
.76849 .36058 .7759 .40158 .79101 .45023 .78475 .42567 Metetra
0 0 .481 r
.78475 .42567 .79101 .45023 .80497 .48054 .79931 .46408 Metetra
0 .036 .595 r
.79931 .46408 .80497 .48054 .81821 .49958 .81289 .48732 Metetra
0 .205 .719 r
.81289 .48732 .81821 .49958 .831 .51154 .82588 .50158 Metetra
.156 .363 .817 r
.82588 .50158 .831 .51154 .84352 .51895 .83853 .51031 Metetra
.289 .486 .878 r
.83853 .51031 .84352 .51895 .85586 .52336 .85097 .5155 Metetra
.387 .571 .91 r
.85097 .5155 .85586 .52336 .8681 .52572 .86327 .51834 Metetra
.456 .627 .926 r
.86327 .51834 .8681 .52572 .88027 .52665 .87551 .51958 Metetra
.504 .664 .933 r
.87551 .51958 .88027 .52665 .89241 .52657 .8877 .51969 Metetra
.538 .689 .937 r
.8877 .51969 .89241 .52657 .90455 .52575 .89988 .519 Metetra
.563 .707 .938 r
.89988 .519 .90455 .52575 .91668 .52438 .91206 .51771 Metetra
.723 .768 .888 r
.27563 .69438 .28186 .69969 .29155 .6949 .28535 .68949 Metetra
.739 .768 .876 r
.28535 .68949 .29155 .6949 .3013 .68953 .29513 .68401 Metetra
.757 .767 .861 r
.29513 .68401 .3013 .68953 .31112 .6834 .30499 .67772 Metetra
.778 .764 .84 r
.30499 .67772 .31112 .6834 .32101 .67618 .31492 .67027 Metetra
.801 .759 .814 r
.31492 .67027 .32101 .67618 .33101 .66742 .32497 .66115 Metetra
.825 .75 .781 r
.32497 .66115 .33101 .66742 .34112 .6564 .33515 .64956 Metetra
.848 .737 .741 r
.33515 .64956 .34112 .6564 .3514 .64196 .34551 .63417 Metetra
.868 .721 .698 r
.34551 .63417 .3514 .64196 .3619 .62215 .35614 .6127 Metetra
.882 .702 .654 r
.35614 .6127 .3619 .62215 .37273 .59363 .36717 .58104 Metetra
.891 .683 .614 r
.36717 .58104 .37273 .59363 .38407 .55034 .37885 .53143 Metetra
.889 .663 .589 r
.37885 .53143 .38407 .55034 .39623 .48095 .39128 .4581 Metetra
.61 .482 .681 r
.39128 .4581 .39623 .48095 .40628 .4607 .40067 .45502 Metetra
.664 .741 .907 r
.40067 .45502 .40628 .4607 .41569 .45763 .41011 .45193 Metetra
.664 .741 .907 r
.41011 .45193 .41569 .45763 .42513 .45454 .41957 .44882 Metetra
.664 .741 .907 r
.41957 .44882 .42513 .45454 .43461 .45145 .42907 .44571 Metetra
.664 .741 .907 r
.42907 .44571 .43461 .45145 .44412 .44834 .4386 .44258 Metetra
.664 .741 .907 r
.4386 .44258 .44412 .44834 .45366 .44523 .44816 .43945 Metetra
.664 .741 .907 r
.44816 .43945 .45366 .44523 .46324 .4421 .45776 .4363 Metetra
.664 .741 .907 r
.45776 .4363 .46324 .4421 .47285 .43896 .46739 .43314 Metetra
.664 .741 .907 r
.46739 .43314 .47285 .43896 .48249 .43581 .47706 .42997 Metetra
.664 .741 .907 r
.47706 .42997 .48249 .43581 .49217 .43265 .48676 .42679 Metetra
.664 .741 .907 r
.48676 .42679 .49217 .43265 .50188 .42948 .4965 .4236 Metetra
.926 .538 .186 r
.4965 .4236 .50188 .42948 .51142 .47875 .50607 .45427 Metetra
.83 .55 .002 r
.50607 .45427 .51142 .47875 .5213 .52495 .51582 .50931 Metetra
.723 .401 0 r
.51582 .50931 .5213 .52495 .53149 .55186 .52595 .5404 Metetra
0 0 .465 r
.52595 .5404 .53149 .55186 .54184 .56739 .53629 .55803 Metetra
0 .233 .75 r
.53629 .55803 .54184 .56739 .55228 .57579 .54673 .56751 Metetra
.293 .497 .885 r
.54673 .56751 .55228 .57579 .56278 .57937 .55724 .57164 Metetra
.517 .635 .905 r
.55724 .57164 .56278 .57937 .57331 .57935 .56779 .57184 Metetra
.652 .7 .882 r
.56779 .57184 .57331 .57935 .58384 .57624 .57835 .5687 Metetra
.74 .73 .842 r
.57835 .5687 .58384 .57624 .59435 .57003 .58888 .56223 Metetra
.804 .74 .793 r
.58888 .56223 .59435 .57003 .6048 .56019 .59934 .55179 Metetra
.851 .736 .737 r
.59934 .55179 .6048 .56019 .61512 .54547 .60967 .53593 Metetra
.884 .723 .677 r
.60967 .53593 .61512 .54547 .62518 .52351 .61972 .51181 Metetra
.905 .704 .62 r
.61972 .51181 .62518 .52351 .63478 .49 .62924 .47403 Metetra
.917 .683 .57 r
.62924 .47403 .63478 .49 .64352 .43688 .63773 .41191 Metetra
.826 .612 .613 r
.63773 .41191 .64352 .43688 .65184 .38052 .64681 .37431 Metetra
.664 .741 .907 r
.64681 .37431 .65184 .38052 .66213 .37716 .65713 .37093 Metetra
.664 .741 .907 r
.65713 .37093 .66213 .37716 .67246 .37379 .66748 .36753 Metetra
.664 .741 .907 r
.66748 .36753 .67246 .37379 .68282 .3704 .67787 .36412 Metetra
.664 .741 .907 r
.67787 .36412 .68282 .3704 .69322 .36701 .6883 .3607 Metetra
.664 .741 .907 r
.6883 .3607 .69322 .36701 .70367 .3636 .69877 .35727 Metetra
.664 .741 .907 r
.69877 .35727 .70367 .3636 .71415 .36018 .70928 .35383 Metetra
.664 .741 .907 r
.70928 .35383 .71415 .36018 .72466 .35674 .71982 .35037 Metetra
.664 .741 .907 r
.71982 .35037 .72466 .35674 .73522 .35329 .73041 .3469 Metetra
.664 .741 .907 r
.73041 .3469 .73522 .35329 .74582 .34983 .74103 .34341 Metetra
.664 .741 .907 r
.74103 .34341 .74582 .34983 .75646 .34636 .7517 .33992 Metetra
.664 .741 .907 r
.7517 .33992 .75646 .34636 .76849 .36058 .7624 .33641 Metetra
.732 .455 0 r
.7624 .33641 .76849 .36058 .78475 .42567 .77885 .40544 Metetra
0 0 .312 r
.77885 .40544 .78475 .42567 .79931 .46408 .79387 .45031 Metetra
0 0 .474 r
.79387 .45031 .79931 .46408 .81289 .48732 .80769 .47675 Metetra
0 .102 .658 r
.80769 .47675 .81289 .48732 .82588 .50158 .82084 .4927 Metetra
.038 .312 .8 r
.82084 .4927 .82588 .50158 .83853 .51031 .83358 .50237 Metetra
.222 .467 .881 r
.83358 .50237 .83853 .51031 .85097 .5155 .84609 .5081 Metetra
.35 .566 .919 r
.84609 .5081 .85097 .5155 .86327 .51834 .85845 .51126 Metetra
.435 .627 .934 r
.85845 .51126 .86327 .51834 .87551 .51958 .87074 .5127 Metetra
.492 .666 .94 r
.87074 .5127 .87551 .51958 .8877 .51969 .88298 .51294 Metetra
.531 .692 .942 r
.88298 .51294 .8877 .51969 .89988 .519 .8952 .51232 Metetra
.558 .709 .942 r
.8952 .51232 .89988 .519 .91206 .51771 .90742 .51108 Metetra
.725 .772 .89 r
.26936 .68913 .27563 .69438 .28535 .68949 .27911 .68419 Metetra
.741 .773 .879 r
.27911 .68419 .28535 .68949 .29513 .68401 .28892 .67865 Metetra
.76 .773 .864 r
.28892 .67865 .29513 .68401 .30499 .67772 .2988 .67227 Metetra
.782 .772 .844 r
.2988 .67227 .30499 .67772 .31492 .67027 .30877 .6647 Metetra
.807 .769 .818 r
.30877 .6647 .31492 .67027 .32497 .66115 .31886 .65542 Metetra
.834 .763 .784 r
.31886 .65542 .32497 .66115 .33515 .64956 .32909 .64357 Metetra
.86 .754 .744 r
.32909 .64357 .33515 .64956 .34551 .63417 .33951 .62776 Metetra
.883 .74 .698 r
.33951 .62776 .34551 .63417 .35614 .6127 .35023 .60554 Metetra
.901 .723 .651 r
.35023 .60554 .35614 .6127 .36717 .58104 .3614 .57249 Metetra
.914 .706 .608 r
.3614 .57249 .36717 .58104 .37885 .53143 .37331 .52001 Metetra
.912 .691 .59 r
.37331 .52001 .37885 .53143 .39128 .4581 .38562 .4524 Metetra
.664 .741 .907 r
.38562 .4524 .39128 .4581 .40067 .45502 .39504 .4493 Metetra
.664 .741 .907 r
.39504 .4493 .40067 .45502 .41011 .45193 .40449 .44619 Metetra
.664 .741 .907 r
.40449 .44619 .41011 .45193 .41957 .44882 .41397 .44306 Metetra
.664 .741 .907 r
.41397 .44306 .41957 .44882 .42907 .44571 .42349 .43993 Metetra
.664 .741 .907 r
.42349 .43993 .42907 .44571 .4386 .44258 .43304 .43678 Metetra
.664 .741 .907 r
.43304 .43678 .4386 .44258 .44816 .43945 .44263 .43363 Metetra
.664 .741 .907 r
.44263 .43363 .44816 .43945 .45776 .4363 .45225 .43046 Metetra
.664 .741 .907 r
.45225 .43046 .45776 .4363 .46739 .43314 .46191 .42728 Metetra
.664 .741 .907 r
.46191 .42728 .46739 .43314 .47706 .42997 .47159 .42409 Metetra
.664 .741 .907 r
.47159 .42409 .47706 .42997 .48676 .42679 .48132 .42089 Metetra
.664 .741 .907 r
.48132 .42089 .48676 .42679 .4965 .4236 .49108 .41767 Metetra
.879 .452 .05 r
.49108 .41767 .4965 .4236 .50607 .45427 .50068 .43998 Metetra
.958 .629 .235 r
.50068 .43998 .50607 .45427 .51582 .50931 .51031 .49903 Metetra
.897 .52 .066 r
.51031 .49903 .51582 .50931 .52595 .5404 .52039 .53194 Metetra
.707 .278 0 r
.52039 .53194 .52595 .5404 .53629 .55803 .53071 .55045 Metetra
0 .137 .672 r
.53071 .55045 .53629 .55803 .54673 .56751 .54116 .56038 Metetra
.211 .489 .898 r
.54116 .56038 .54673 .56751 .55724 .57164 .55168 .56472 Metetra
.496 .653 .929 r
.55168 .56472 .55724 .57164 .56779 .57184 .56225 .56499 Metetra
.652 .722 .9 r
.56225 .56499 .56779 .57184 .57835 .5687 .57283 .56183 Metetra
.749 .751 .854 r
.57283 .56183 .57835 .5687 .58888 .56223 .58339 .55523 Metetra
.817 .762 .801 r
.58339 .55523 .58888 .56223 .59934 .55179 .59388 .54454 Metetra
.868 .76 .74 r
.59388 .54454 .59934 .55179 .60967 .53593 .60424 .52818 Metetra
.906 .748 .675 r
.60424 .52818 .60967 .53593 .61972 .51181 .61431 .50313 Metetra
.93 .73 .611 r
.61431 .50313 .61972 .51181 .62924 .47403 .62385 .46345 Metetra
.944 .71 .555 r
.62385 .46345 .62924 .47403 .63773 .41191 .63231 .39724 Metetra
.861 .67 .642 r
.63231 .39724 .63773 .41191 .64681 .37431 .64175 .36805 Metetra
.664 .741 .907 r
.64175 .36805 .64681 .37431 .65713 .37093 .65209 .36465 Metetra
.664 .741 .907 r
.65209 .36465 .65713 .37093 .66748 .36753 .66247 .36123 Metetra
.664 .741 .907 r
.66247 .36123 .66748 .36753 .67787 .36412 .67289 .3578 Metetra
.664 .741 .907 r
.67289 .3578 .67787 .36412 .6883 .3607 .68334 .35436 Metetra
.664 .741 .907 r
.68334 .35436 .6883 .3607 .69877 .35727 .69384 .3509 Metetra
.664 .741 .907 r
.69384 .3509 .69877 .35727 .70928 .35383 .70437 .34743 Metetra
.664 .741 .907 r
.70437 .34743 .70928 .35383 .71982 .35037 .71495 .34395 Metetra
.664 .741 .907 r
.71495 .34395 .71982 .35037 .73041 .3469 .72556 .34045 Metetra
.664 .741 .907 r
.72556 .34045 .73041 .3469 .74103 .34341 .73621 .33695 Metetra
.664 .741 .907 r
.73621 .33695 .74103 .34341 .7517 .33992 .7469 .33343 Metetra
.664 .741 .907 r
.7469 .33343 .7517 .33992 .7624 .33641 .75763 .32989 Metetra
.935 .57 .171 r
.75763 .32989 .7624 .33641 .77885 .40544 .77356 .39296 Metetra
.821 .465 0 r
.77356 .39296 .77885 .40544 .79387 .45031 .78876 .44073 Metetra
.668 .28 0 r
.78876 .44073 .79387 .45031 .80769 .47675 .80268 .46856 Metetra
0 0 .553 r
.80268 .46856 .80769 .47675 .82084 .4927 .81589 .48524 Metetra
0 .26 .769 r
.81589 .48524 .82084 .4927 .83358 .50237 .82869 .4953 Metetra
.153 .453 .882 r
.82869 .4953 .83358 .50237 .84609 .5081 .84124 .50125 Metetra
.316 .566 .928 r
.84124 .50125 .84609 .5081 .85845 .51126 .85364 .50455 Metetra
.417 .632 .943 r
.85364 .50455 .85845 .51126 .87074 .5127 .86596 .50606 Metetra
.482 .671 .947 r
.86596 .50606 .87074 .5127 .88298 .51294 .87824 .50634 Metetra
.525 .696 .947 r
.87824 .50634 .88298 .51294 .8952 .51232 .89049 .50574 Metetra
.554 .713 .946 r
.89049 .50574 .8952 .51232 .90742 .51108 .90275 .50451 Metetra
.725 .775 .893 r
.26304 .68395 .26936 .68913 .27911 .68419 .27281 .679 Metetra
.741 .777 .882 r
.27281 .679 .27911 .68419 .28892 .67865 .28264 .67345 Metetra
.761 .779 .868 r
.28264 .67345 .28892 .67865 .2988 .67227 .29255 .66707 Metetra
.785 .781 .849 r
.29255 .66707 .2988 .67227 .30877 .6647 .30256 .65951 Metetra
.811 .781 .824 r
.30256 .65951 .30877 .6647 .31886 .65542 .31267 .65027 Metetra
.841 .778 .792 r
.31267 .65027 .31886 .65542 .32909 .64357 .32293 .63851 Metetra
.87 .773 .752 r
.32293 .63851 .32909 .64357 .33951 .62776 .33339 .62286 Metetra
.898 .763 .705 r
.33339 .62286 .33951 .62776 .35023 .60554 .34415 .60099 Metetra
.92 .75 .655 r
.34415 .60099 .35023 .60554 .3614 .57249 .35536 .56866 Metetra
.937 .736 .607 r
.35536 .56866 .3614 .57249 .37331 .52001 .36731 .51775 Metetra
.947 .731 .577 r
.36731 .51775 .37331 .52001 .38562 .4524 .37992 .44667 Metetra
.664 .741 .907 r
.37992 .44667 .38562 .4524 .39504 .4493 .38936 .44355 Metetra
.664 .741 .907 r
.38936 .44355 .39504 .4493 .40449 .44619 .39884 .44041 Metetra
.664 .741 .907 r
.39884 .44041 .40449 .44619 .41397 .44306 .40834 .43727 Metetra
.664 .741 .907 r
.40834 .43727 .41397 .44306 .42349 .43993 .41788 .43411 Metetra
.664 .741 .907 r
.41788 .43411 .42349 .43993 .43304 .43678 .42746 .43095 Metetra
.664 .741 .907 r
.42746 .43095 .43304 .43678 .44263 .43363 .43706 .42777 Metetra
.664 .741 .907 r
.43706 .42777 .44263 .43363 .45225 .43046 .4467 .42458 Metetra
.664 .741 .907 r
.4467 .42458 .45225 .43046 .46191 .42728 .45638 .42138 Metetra
.664 .741 .907 r
.45638 .42138 .46191 .42728 .47159 .42409 .46609 .41817 Metetra
.664 .741 .907 r
.46609 .41817 .47159 .42409 .48132 .42089 .47584 .41495 Metetra
.664 .741 .907 r
.47584 .41495 .48132 .42089 .49108 .41767 .48562 .41171 Metetra
.91 .506 .133 r
.48562 .41171 .49108 .41767 .50068 .43998 .49516 .43844 Metetra
.941 .606 .366 r
.49516 .43844 .50068 .43998 .51031 .49903 .50474 .49509 Metetra
.923 .535 .226 r
.50474 .49509 .51031 .49903 .52039 .53194 .5148 .5269 Metetra
.819 .353 0 r
.5148 .5269 .52039 .53194 .53071 .55045 .5251 .54485 Metetra
0 .057 .558 r
.5251 .54485 .53071 .55045 .54116 .56038 .53555 .55447 Metetra
.132 .489 .903 r
.53555 .55447 .54116 .56038 .55168 .56472 .54609 .55865 Metetra
.478 .678 .953 r
.54609 .55865 .55168 .56472 .56225 .56499 .55668 .55883 Metetra
.651 .746 .919 r
.55668 .55883 .56225 .56499 .57283 .56183 .56728 .55565 Metetra
.754 .775 .87 r
.56728 .55565 .57283 .56183 .58339 .55523 .57787 .5491 Metetra
.827 .786 .814 r
.57787 .5491 .58339 .55523 .59388 .54454 .58841 .53852 Metetra
.883 .787 .751 r
.58841 .53852 .59388 .54454 .60424 .52818 .59882 .52243 Metetra
.925 .779 .681 r
.59882 .52243 .60424 .52818 .61431 .50313 .60897 .49789 Metetra
.954 .764 .608 r
.60897 .49789 .61431 .50313 .62385 .46345 .61863 .45929 Metetra
.97 .745 .541 r
.61863 .45929 .62385 .46345 .63231 .39724 .62729 .39546 Metetra
.977 .81 .609 r
.62729 .39546 .63231 .39724 .64175 .36805 .63666 .36176 Metetra
.664 .741 .907 r
.63666 .36176 .64175 .36805 .65209 .36465 .64702 .35833 Metetra
.664 .741 .907 r
.64702 .35833 .65209 .36465 .66247 .36123 .65743 .35489 Metetra
.664 .741 .907 r
.65743 .35489 .66247 .36123 .67289 .3578 .66787 .35143 Metetra
.664 .741 .907 r
.66787 .35143 .67289 .3578 .68334 .35436 .67835 .34797 Metetra
.664 .741 .907 r
.67835 .34797 .68334 .35436 .69384 .3509 .68888 .34449 Metetra
.664 .741 .907 r
.68888 .34449 .69384 .3509 .70437 .34743 .69944 .34099 Metetra
.664 .741 .907 r
.69944 .34099 .70437 .34743 .71495 .34395 .71004 .33749 Metetra
.664 .741 .907 r
.71004 .33749 .71495 .34395 .72556 .34045 .72068 .33397 Metetra
.664 .741 .907 r
.72068 .33397 .72556 .34045 .73621 .33695 .73136 .33044 Metetra
.664 .741 .907 r
.73136 .33044 .73621 .33695 .7469 .33343 .74208 .32689 Metetra
.664 .741 .907 r
.74208 .32689 .7469 .33343 .75763 .32989 .75284 .32333 Metetra
.938 .577 .182 r
.75284 .32333 .75763 .32989 .77356 .39296 .76897 .38994 Metetra
.919 .526 .155 r
.76897 .38994 .77356 .39296 .78876 .44073 .78401 .43604 Metetra
.822 .376 0 r
.78401 .43604 .78876 .44073 .80268 .46856 .79787 .46309 Metetra
.583 .105 0 r
.79787 .46309 .80268 .46856 .81589 .48524 .81105 .47935 Metetra
0 .216 .721 r
.81105 .47935 .81589 .48524 .82869 .4953 .82385 .48919 Metetra
.09 .448 .881 r
.82385 .48919 .82869 .4953 .84124 .50125 .83641 .49501 Metetra
.287 .574 .938 r
.83641 .49501 .84124 .50125 .85364 .50455 .84884 .49822 Metetra
.404 .641 .953 r
.84884 .49822 .85364 .50455 .86596 .50606 .86118 .49967 Metetra
.476 .679 .955 r
.86118 .49967 .86596 .50606 .87824 .50634 .87348 .49991 Metetra
.521 .702 .953 r
.87348 .49991 .87824 .50634 .89049 .50574 .88577 .49927 Metetra
.552 .717 .95 r
.88577 .49927 .89049 .50574 .90275 .50451 .89806 .498 Metetra
.724 .779 .896 r
.25666 .67884 .26304 .68395 .27281 .679 .26646 .67392 Metetra
.741 .782 .886 r
.26646 .67392 .27281 .679 .28264 .67345 .27631 .66841 Metetra
.76 .786 .874 r
.27631 .66841 .28264 .67345 .29255 .66707 .28625 .6621 Metetra
.784 .789 .857 r
.28625 .6621 .29255 .66707 .30256 .65951 .29627 .65469 Metetra
.812 .793 .834 r
.29627 .65469 .30256 .65951 .31267 .65027 .3064 .64568 Metetra
.844 .795 .804 r
.3064 .64568 .31267 .65027 .32293 .63851 .31668 .63433 Metetra
.877 .795 .765 r
.31668 .63433 .32293 .63851 .33339 .62286 .32715 .61941 Metetra
.909 .791 .718 r
.32715 .61941 .33339 .62286 .34415 .60099 .33789 .59888 Metetra
.937 .784 .665 r
.33789 .59888 .34415 .60099 .35536 .56866 .34905 .56916 Metetra
.959 .775 .61 r
.34905 .56916 .35536 .56866 .36731 .51775 .36086 .52368 Metetra
.975 .766 .557 r
.36086 .52368 .36731 .51775 .37992 .44667 .37378 .4499 Metetra
.874 .994 .767 r
.37378 .4499 .37992 .44667 .38936 .44355 .38365 .43775 Metetra
.664 .741 .907 r
.38365 .43775 .38936 .44355 .39884 .44041 .39315 .4346 Metetra
.664 .741 .907 r
.39315 .4346 .39884 .44041 .40834 .43727 .40267 .43144 Metetra
.664 .741 .907 r
.40267 .43144 .40834 .43727 .41788 .43411 .41223 .42826 Metetra
.664 .741 .907 r
.41223 .42826 .41788 .43411 .42746 .43095 .42183 .42507 Metetra
.664 .741 .907 r
.42183 .42507 .42746 .43095 .43706 .42777 .43146 .42187 Metetra
.664 .741 .907 r
.43146 .42187 .43706 .42777 .4467 .42458 .44112 .41866 Metetra
.664 .741 .907 r
.44112 .41866 .4467 .42458 .45638 .42138 .45082 .41544 Metetra
.664 .741 .907 r
.45082 .41544 .45638 .42138 .46609 .41817 .46055 .41221 Metetra
.664 .741 .907 r
.46055 .41221 .46609 .41817 .47584 .41495 .47032 .40896 Metetra
.664 .741 .907 r
.47032 .40896 .47584 .41495 .48562 .41171 .48012 .40571 Metetra
.947 .59 .278 r
.48012 .40571 .48562 .41171 .49516 .43844 .48947 .44812 Metetra
.882 .553 .422 r
.48947 .44812 .49516 .43844 .50474 .49509 .49908 .4969 Metetra
.886 .502 .303 r
.49908 .4969 .50474 .49509 .5148 .5269 .50914 .525 Metetra
.829 .355 .05 r
.50914 .525 .5148 .5269 .5251 .54485 .51945 .54108 Metetra
.525 0 0 r
.51945 .54108 .5251 .54485 .53555 .55447 .52991 .54972 Metetra
.079 .505 .9 r
.52991 .54972 .53555 .55447 .54609 .55865 .54047 .55337 Metetra
.467 .707 .973 r
.54047 .55337 .54609 .55865 .55668 .55883 .55107 .55332 Metetra
.649 .77 .937 r
.55107 .55332 .55668 .55883 .56728 .55565 .5617 .55012 Metetra
.754 .797 .887 r
.5617 .55012 .56728 .55565 .57787 .5491 .57233 .54375 Metetra
.83 .811 .832 r
.57233 .54375 .57787 .5491 .58841 .53852 .58292 .53366 Metetra
.891 .818 .769 r
.58292 .53366 .58841 .53852 .59882 .52243 .5934 .51852 Metetra
.939 .816 .696 r
.5934 .51852 .59882 .52243 .60897 .49789 .60367 .49583 Metetra
.974 .805 .613 r
.60367 .49583 .60897 .49789 .61863 .45929 .61352 .46093 Metetra
.992 .787 .527 r
.61352 .46093 .61863 .45929 .62729 .39546 .62257 .40501 Metetra
.987 .831 .448 r
.62257 .40501 .62729 .39546 .63666 .36176 .63153 .35542 Metetra
.664 .741 .907 r
.63153 .35542 .63666 .36176 .64702 .35833 .64192 .35197 Metetra
.664 .741 .907 r
.64192 .35197 .64702 .35833 .65743 .35489 .65235 .3485 Metetra
.664 .741 .907 r
.65235 .3485 .65743 .35489 .66787 .35143 .66282 .34502 Metetra
.664 .741 .907 r
.66282 .34502 .66787 .35143 .67835 .34797 .67333 .34153 Metetra
.664 .741 .907 r
.67333 .34153 .67835 .34797 .68888 .34449 .68388 .33803 Metetra
.664 .741 .907 r
.68388 .33803 .68888 .34449 .69944 .34099 .69447 .33451 Metetra
.664 .741 .907 r
.69447 .33451 .69944 .34099 .71004 .33749 .70509 .33098 Metetra
.664 .741 .907 r
.70509 .33098 .71004 .33749 .72068 .33397 .71576 .32744 Metetra
.664 .741 .907 r
.71576 .32744 .72068 .33397 .73136 .33044 .72647 .32388 Metetra
.664 .741 .907 r
.72647 .32388 .73136 .33044 .74208 .32689 .73722 .32031 Metetra
.112 .434 .874 r
.73722 .32031 .74208 .32689 .75284 .32333 .74866 .326 Metetra
.939 .579 .294 r
.74866 .326 .75284 .32333 .76897 .38994 .76497 .39538 Metetra
.896 .505 .276 r
.76497 .39538 .76897 .38994 .78401 .43604 .77958 .43585 Metetra
.851 .392 .067 r
.77958 .43585 .78401 .43604 .79787 .46309 .79323 .46014 Metetra
.674 .15 0 r
.79323 .46014 .79787 .46309 .81105 .47935 .80631 .47497 Metetra
0 .194 .667 r
.80631 .47497 .81105 .47935 .82385 .48919 .81906 .484 Metetra
.046 .456 .879 r
.81906 .484 .82385 .48919 .83641 .49501 .83161 .48935 Metetra
.271 .59 .947 r
.83161 .48935 .83641 .49501 .84884 .49822 .84403 .49226 Metetra
.398 .655 .962 r
.84403 .49226 .84884 .49822 .86118 .49967 .85639 .49352 Metetra
.474 .69 .961 r
.85639 .49352 .86118 .49967 .87348 .49991 .86872 .49363 Metetra
.521 .71 .958 r
.86872 .49363 .87348 .49991 .88577 .49927 .88103 .4929 Metetra
.552 .723 .953 r
.88103 .4929 .88577 .49927 .89806 .498 .89335 .49156 Metetra
.722 .782 .9 r
.25024 .6738 .25666 .67884 .26646 .67392 .26005 .66893 Metetra
.738 .786 .891 r
.26005 .66893 .26646 .67392 .27631 .66841 .26993 .66351 Metetra
.758 .792 .88 r
.26993 .66351 .27631 .66841 .28625 .6621 .27988 .65736 Metetra
.782 .798 .866 r
.27988 .65736 .28625 .6621 .29627 .65469 .28991 .65018 Metetra
.81 .804 .846 r
.28991 .65018 .29627 .65469 .3064 .64568 .30005 .64157 Metetra
.843 .811 .819 r
.30005 .64157 .3064 .64568 .31668 .63433 .31033 .63088 Metetra
.879 .817 .784 r
.31033 .63088 .31668 .63433 .32715 .61941 .32078 .61711 Metetra
.916 .822 .739 r
.32078 .61711 .32715 .61941 .33789 .59888 .33147 .59863 Metetra
.95 .823 .684 r
.33147 .59863 .33789 .59888 .34905 .56916 .34251 .57273 Metetra
.978 .821 .62 r
.34251 .57273 .34905 .56916 .36086 .52368 .35406 .5348 Metetra
.996 .817 .547 r
.35406 .5348 .36086 .52368 .37378 .4499 .36642 .4768 Metetra
.758 .752 .237 r
.36642 .4768 .37378 .4499 .38365 .43775 .3779 .43192 Metetra
.664 .741 .907 r
.3779 .43192 .38365 .43775 .39315 .4346 .38742 .42875 Metetra
.664 .741 .907 r
.38742 .42875 .39315 .4346 .40267 .43144 .39697 .42556 Metetra
.664 .741 .907 r
.39697 .42556 .40267 .43144 .41223 .42826 .40655 .42237 Metetra
.664 .741 .907 r
.40655 .42237 .41223 .42826 .42183 .42507 .41617 .41916 Metetra
.664 .741 .907 r
.41617 .41916 .42183 .42507 .43146 .42187 .42582 .41594 Metetra
.664 .741 .907 r
.42582 .41594 .43146 .42187 .44112 .41866 .4355 .41271 Metetra
.664 .741 .907 r
.4355 .41271 .44112 .41866 .45082 .41544 .44522 .40946 Metetra
.664 .741 .907 r
.44522 .40946 .45082 .41544 .46055 .41221 .45498 .40621 Metetra
.664 .741 .907 r
.45498 .40621 .46055 .41221 .47032 .40896 .46477 .40294 Metetra
.624 .728 .921 r
.46477 .40294 .47032 .40896 .48012 .40571 .47458 .40061 Metetra
.955 .627 .358 r
.47458 .40061 .48012 .40571 .48947 .44812 .4836 .46438 Metetra
.826 .501 .438 r
.4836 .46438 .48947 .44812 .49908 .4969 .49331 .50257 Metetra
.836 .454 .327 r
.49331 .50257 .49908 .4969 .50914 .525 .50342 .5254 Metetra
.792 .314 .088 r
.50342 .5254 .50914 .525 .51945 .54108 .51375 .53872 Metetra
.521 0 0 r
.51375 .53872 .51945 .54108 .52991 .54972 .52423 .54586 Metetra
.077 .542 .902 r
.52423 .54586 .52991 .54972 .54047 .55337 .5348 .54872 Metetra
.467 .735 .986 r
.5348 .54872 .54047 .55337 .55107 .55332 .54543 .54832 Metetra
.645 .791 .952 r
.54543 .54832 .55107 .55332 .5617 .55012 .55609 .5451 Metetra
.749 .816 .905 r
.55609 .5451 .5617 .55012 .57233 .54375 .56676 .53904 Metetra
.825 .833 .854 r
.56676 .53904 .57233 .54375 .58292 .53366 .5774 .5297 Metetra
.89 .847 .795 r
.5774 .5297 .58292 .53366 .5934 .51852 .58796 .51602 Metetra
.945 .856 .721 r
.58796 .51602 .5934 .51852 .60367 .49583 .59836 .49607 Metetra
.985 .853 .628 r
.59836 .49607 .60367 .49583 .61352 .46093 .60845 .46645 Metetra
.999 .835 .515 r
.60845 .46645 .61352 .46093 .62257 .40501 .61795 .42122 Metetra
.977 .797 .38 r
.61795 .42122 .62257 .40501 .63153 .35542 .62639 .34999 Metetra
.7 .787 .919 r
.62639 .34999 .63153 .35542 .64192 .35197 .63678 .34556 Metetra
.664 .741 .907 r
.63678 .34556 .64192 .35197 .65235 .3485 .64724 .34207 Metetra
.664 .741 .907 r
.64724 .34207 .65235 .3485 .66282 .34502 .65773 .33857 Metetra
.664 .741 .907 r
.65773 .33857 .66282 .34502 .67333 .34153 .66827 .33505 Metetra
.664 .741 .907 r
.66827 .33505 .67333 .34153 .68388 .33803 .67884 .33152 Metetra
.664 .741 .907 r
.67884 .33152 .68388 .33803 .69447 .33451 .68946 .32798 Metetra
.664 .741 .907 r
.68946 .32798 .69447 .33451 .70509 .33098 .70011 .32443 Metetra
.664 .741 .907 r
.70011 .32443 .70509 .33098 .71576 .32744 .71081 .32086 Metetra
.664 .741 .907 r
.71081 .32086 .71576 .32744 .72647 .32388 .72155 .31728 Metetra
.664 .741 .907 r
.72155 .31728 .72647 .32388 .73722 .32031 .73232 .31368 Metetra
.887 .49 .047 r
.73232 .31368 .73722 .32031 .74866 .326 .74613 .35304 Metetra
.825 .492 .425 r
.74613 .35304 .74866 .326 .76497 .39538 .7613 .40619 Metetra
.843 .46 .324 r
.7613 .40619 .76497 .39538 .77958 .43585 .77534 .43883 Metetra
.822 .364 .133 r
.77534 .43883 .77958 .43585 .79323 .46014 .7887 .45912 Metetra
.685 .141 0 r
.7887 .45912 .79323 .46014 .80631 .47497 .80163 .47177 Metetra
0 .208 .633 r
.80163 .47177 .80631 .47497 .81906 .484 .8143 .47957 Metetra
.035 .481 .882 r
.8143 .47957 .81906 .484 .83161 .48935 .82681 .48418 Metetra
.271 .613 .957 r
.82681 .48418 .83161 .48935 .84403 .49226 .83923 .48663 Metetra
.401 .672 .97 r
.83923 .48663 .84403 .49226 .85639 .49352 .85159 .48759 Metetra
.476 .701 .967 r
.85159 .48759 .85639 .49352 .86872 .49363 .86393 .48749 Metetra
.523 .718 .962 r
.86393 .48749 .86872 .49363 .88103 .4929 .87627 .48662 Metetra
.553 .729 .956 r
.87627 .48662 .88103 .4929 .89335 .49156 .88861 .48517 Metetra
.72 .785 .904 r
.24376 .6688 .25024 .6738 .26005 .66893 .25359 .66401 Metetra
.735 .79 .897 r
.25359 .66401 .26005 .66893 .26993 .66351 .26348 .65873 Metetra
.753 .796 .888 r
.26348 .65873 .26993 .66351 .27988 .65736 .27344 .65278 Metetra
.776 .805 .876 r
.27344 .65278 .27988 .65736 .28991 .65018 .28349 .64592 Metetra
.804 .814 .859 r
.28349 .64592 .28991 .65018 .30005 .64157 .29363 .63782 Metetra
.837 .826 .837 r
.29363 .63782 .30005 .64157 .31033 .63088 .30389 .62796 Metetra
.874 .839 .807 r
.30389 .62796 .31033 .63088 .32078 .61711 .31431 .61556 Metetra
.915 .852 .767 r
.31431 .61556 .32078 .61711 .33147 .59863 .32492 .59945 Metetra
.954 .865 .712 r
.32492 .59945 .33147 .59863 .34251 .57273 .33581 .57777 Metetra
.985 .873 .639 r
.33581 .57777 .34251 .57273 .35406 .5348 .34707 .54766 Metetra
.993 .869 .535 r
.34707 .54766 .35406 .5348 .36642 .4768 .35885 .50468 Metetra
.935 .826 .375 r
.35885 .50468 .36642 .4768 .3779 .43192 .37134 .44252 Metetra
.763 .876 .453 r
.37134 .44252 .3779 .43192 .38742 .42875 .38165 .42286 Metetra
.664 .741 .907 r
.38165 .42286 .38742 .42875 .39697 .42556 .39122 .41965 Metetra
.664 .741 .907 r
.39122 .41965 .39697 .42556 .40655 .42237 .40083 .41644 Metetra
.664 .741 .907 r
.40083 .41644 .40655 .42237 .41617 .41916 .41046 .41321 Metetra
.664 .741 .907 r
.41046 .41321 .41617 .41916 .42582 .41594 .42014 .40996 Metetra
.664 .741 .907 r
.42014 .40996 .42582 .41594 .4355 .41271 .42984 .40671 Metetra
.664 .741 .907 r
.42984 .40671 .4355 .41271 .44522 .40946 .43959 .40345 Metetra
.664 .741 .907 r
.43959 .40345 .44522 .40946 .45498 .40621 .44936 .40017 Metetra
.664 .741 .907 r
.44936 .40017 .45498 .40621 .46477 .40294 .45918 .39688 Metetra
.947 .591 .282 r
.45918 .39688 .46477 .40294 .47458 .40061 .46824 .439 Metetra
.758 .464 .488 r
.46824 .439 .47458 .40061 .4836 .46438 .4776 .4822 Metetra
.78 .451 .43 r
.4776 .4822 .4836 .46438 .49331 .50257 .48745 .50978 Metetra
.787 .396 .314 r
.48745 .50978 .49331 .50257 .50342 .5254 .49762 .52695 Metetra
.734 .24 .063 r
.49762 .52695 .50342 .5254 .51375 .53872 .50799 .53715 Metetra
.443 0 0 r
.50799 .53715 .51375 .53872 .52423 .54586 .5185 .54255 Metetra
.132 .603 .921 r
.5185 .54255 .52423 .54586 .5348 .54872 .52909 .54447 Metetra
.482 .76 .992 r
.52909 .54447 .5348 .54872 .54543 .54832 .53974 .54363 Metetra
.642 .804 .96 r
.53974 .54363 .54543 .54832 .55609 .5451 .55044 .54038 Metetra
.738 .827 .92 r
.55044 .54038 .55609 .5451 .56676 .53904 .56115 .53472 Metetra
.812 .849 .877 r
.56115 .53472 .56676 .53904 .5774 .5297 .57184 .52629 Metetra
.878 .872 .827 r
.57184 .52629 .5774 .5297 .58796 .51602 .58249 .51432 Metetra
.938 .893 .758 r
.58249 .51432 .58796 .51602 .59836 .49607 .59302 .49748 Metetra
.981 .903 .658 r
.59302 .49748 .59836 .49607 .60845 .46645 .60334 .47354 Metetra
.977 .879 .508 r
.60334 .47354 .60845 .46645 .61795 .42122 .61327 .43901 Metetra
.878 .788 .294 r
.61327 .43901 .61795 .42122 .62639 .34999 .62256 .38857 Metetra
0 0 .184 r
.62256 .38857 .62639 .34999 .63678 .34556 .6316 .33911 Metetra
.664 .741 .907 r
.6316 .33911 .63678 .34556 .64724 .34207 .64209 .33559 Metetra
.664 .741 .907 r
.64209 .33559 .64724 .34207 .65773 .33857 .65261 .33207 Metetra
.664 .741 .907 r
.65261 .33207 .65773 .33857 .66827 .33505 .66317 .32853 Metetra
.664 .741 .907 r
.66317 .32853 .66827 .33505 .67884 .33152 .67378 .32498 Metetra
.664 .741 .907 r
.67378 .32498 .67884 .33152 .68946 .32798 .68442 .32141 Metetra
.664 .741 .907 r
.68442 .32141 .68946 .32798 .70011 .32443 .6951 .31783 Metetra
.664 .741 .907 r
.6951 .31783 .70011 .32443 .71081 .32086 .70583 .31424 Metetra
.664 .741 .907 r
.70583 .31424 .71081 .32086 .72155 .31728 .71659 .31063 Metetra
0 .007 .55 r
.71659 .31063 .72155 .31728 .73232 .31368 .72849 .32393 Metetra
.903 .544 .348 r
.72849 .32393 .73232 .31368 .74613 .35304 .74355 .38113 Metetra
.775 .445 .427 r
.74355 .38113 .74613 .35304 .7613 .40619 .75768 .41881 Metetra
.793 .409 .328 r
.75768 .41881 .7613 .40619 .77534 .43883 .77116 .44334 Metetra
.775 .31 .141 r
.77116 .44334 .77534 .43883 .7887 .45912 .78421 .45921 Metetra
.645 .085 0 r
.78421 .45921 .7887 .45912 .80163 .47177 .79697 .46936 Metetra
0 .262 .64 r
.79697 .46936 .80163 .47177 .8143 .47957 .80955 .47568 Metetra
.059 .524 .894 r
.80955 .47568 .8143 .47957 .82681 .48418 .82202 .47937 Metetra
.288 .641 .966 r
.82202 .47937 .82681 .48418 .83923 .48663 .83441 .48125 Metetra
.413 .691 .977 r
.83441 .48125 .83923 .48663 .85159 .48759 .84678 .48182 Metetra
.484 .714 .972 r
.84678 .48182 .85159 .48759 .86393 .48749 .85913 .48146 Metetra
.528 .727 .965 r
.85913 .48146 .86393 .48749 .87627 .48662 .87148 .4804 Metetra
.557 .735 .959 r
.87148 .4804 .87627 .48662 .88861 .48517 .88385 .47882 Metetra
.716 .787 .908 r
.23723 .66384 .24376 .6688 .25359 .66401 .24708 .65916 Metetra
.73 .793 .902 r
.24708 .65916 .25359 .66401 .26348 .65873 .25698 .65403 Metetra
.747 .8 .895 r
.25698 .65403 .26348 .65873 .27344 .65278 .26696 .64832 Metetra
.769 .81 .886 r
.26696 .64832 .27344 .65278 .28349 .64592 .27701 .64183 Metetra
.795 .822 .873 r
.27701 .64183 .28349 .64592 .29363 .63782 .28714 .63429 Metetra
.826 .838 .857 r
.28714 .63429 .29363 .63782 .30389 .62796 .29739 .62532 Metetra
.863 .857 .833 r
.29739 .62532 .30389 .62796 .31431 .61556 .30776 .61436 Metetra
.904 .879 .8 r
.30776 .61436 .31431 .61556 .32492 .59945 .31829 .6006 Metetra
.946 .903 .75 r
.31829 .6006 .32492 .59945 .33581 .57777 .32902 .58291 Metetra
.974 .922 .67 r
.32902 .58291 .33581 .57777 .34707 .54766 .34001 .55966 Metetra
.951 .907 .531 r
.34001 .55966 .34707 .54766 .35885 .50468 .35131 .52874 Metetra
.78 .781 .28 r
.35131 .52874 .35885 .50468 .37134 .44252 .36299 .48774 Metetra
0 0 .064 r
.36299 .48774 .37134 .44252 .38165 .42286 .37502 .43502 Metetra
.732 .841 .397 r
.37502 .43502 .38165 .42286 .39122 .41965 .38544 .4137 Metetra
.664 .741 .907 r
.38544 .4137 .39122 .41965 .40083 .41644 .39507 .41046 Metetra
.664 .741 .907 r
.39507 .41046 .40083 .41644 .41046 .41321 .40473 .40721 Metetra
.664 .741 .907 r
.40473 .40721 .41046 .41321 .42014 .40996 .41442 .40395 Metetra
.664 .741 .907 r
.41442 .40395 .42014 .40996 .42984 .40671 .42415 .40068 Metetra
.664 .741 .907 r
.42415 .40068 .42984 .40671 .43959 .40345 .43391 .39739 Metetra
.664 .741 .907 r
.43391 .39739 .43959 .40345 .44936 .40017 .44371 .39409 Metetra
.943 .579 .263 r
.44371 .39409 .44936 .40017 .45918 .39688 .45263 .43209 Metetra
.753 .457 .482 r
.45263 .43209 .45918 .39688 .46824 .439 .46183 .47061 Metetra
.724 .422 .467 r
.46183 .47061 .46824 .439 .4776 .4822 .4715 .49805 Metetra
.74 .397 .4 r
.4715 .49805 .4776 .4822 .48745 .50978 .48151 .51663 Metetra
.736 .322 .264 r
.48151 .51663 .48745 .50978 .49762 .52695 .49176 .52861 Metetra
.65 .124 0 r
.49176 .52861 .49762 .52695 .50799 .53715 .50218 .53577 Metetra
.291 0 0 r
.50218 .53577 .50799 .53715 .5185 .54255 .51271 .53939 Metetra
.234 .676 .956 r
.51271 .53939 .5185 .54255 .52909 .54447 .52333 .54031 Metetra
.51 .778 .993 r
.52333 .54031 .52909 .54447 .53974 .54363 .53402 .53901 Metetra
.641 .808 .963 r
.53402 .53901 .53974 .54363 .55044 .54038 .54474 .53575 Metetra
.723 .828 .93 r
.54474 .53575 .55044 .54038 .56115 .53472 .55549 .5305 Metetra
.79 .853 .898 r
.55549 .5305 .56115 .53472 .57184 .52629 .56624 .52302 Metetra
.854 .885 .86 r
.56624 .52302 .57184 .52629 .58249 .51432 .57697 .51281 Metetra
.915 .921 .804 r
.57697 .51281 .58249 .51432 .59302 .49748 .58762 .49899 Metetra
.957 .946 .707 r
.58762 .49899 .59302 .49748 .60334 .47354 .59814 .48027 Metetra
.924 .914 .526 r
.59814 .48027 .60334 .47354 .61327 .43901 .60843 .45482 Metetra
.722 .744 .231 r
.60843 .45482 .61327 .43901 .62256 .38857 .61835 .42031 Metetra
0 0 .097 r
.61835 .42031 .62256 .38857 .6316 .33911 .62774 .37448 Metetra
0 0 .174 r
.62774 .37448 .6316 .33911 .64209 .33559 .6369 .32907 Metetra
.664 .741 .907 r
.6369 .32907 .64209 .33559 .65261 .33207 .64745 .32552 Metetra
.664 .741 .907 r
.64745 .32552 .65261 .33207 .66317 .32853 .65804 .32196 Metetra
.664 .741 .907 r
.65804 .32196 .66317 .32853 .67378 .32498 .66867 .31838 Metetra
.664 .741 .907 r
.66867 .31838 .67378 .32498 .68442 .32141 .67934 .31479 Metetra
.664 .741 .907 r
.67934 .31479 .68442 .32141 .6951 .31783 .69005 .31119 Metetra
.664 .741 .907 r
.69005 .31119 .6951 .31783 .70583 .31424 .70081 .30757 Metetra
0 0 .466 r
.70081 .30757 .70583 .31424 .71659 .31063 .71271 .3225 Metetra
.879 .517 .357 r
.71271 .3225 .71659 .31063 .72849 .32393 .72683 .36982 Metetra
.713 .411 .465 r
.72683 .36982 .72849 .32393 .74355 .38113 .74057 .40531 Metetra
.737 .398 .407 r
.74057 .40531 .74355 .38113 .75768 .41881 .75391 .43054 Metetra
.747 .35 .3 r
.75391 .43054 .75768 .41881 .77116 .44334 .76692 .44794 Metetra
.717 .233 .097 r
.76692 .44794 .77116 .44334 .78421 .45921 .77969 .45964 Metetra
.566 0 0 r
.77969 .45964 .78421 .45921 .79697 .46936 .79229 .46729 Metetra
0 .352 .692 r
.79229 .46729 .79697 .46936 .80955 .47568 .80478 .47207 Metetra
.117 .579 .917 r
.80478 .47207 .80955 .47568 .82202 .47937 .8172 .47479 Metetra
.32 .672 .976 r
.8172 .47479 .82202 .47937 .83441 .48125 .82958 .47602 Metetra
.431 .71 .982 r
.82958 .47602 .83441 .48125 .84678 .48182 .84194 .47617 Metetra
.495 .726 .975 r
.84194 .47617 .84678 .48182 .85913 .48146 .8543 .47551 Metetra
.535 .735 .967 r
.8543 .47551 .85913 .48146 .87148 .4804 .86666 .47423 Metetra
.562 .741 .96 r
.86666 .47423 .87148 .4804 .88385 .47882 .87905 .47249 Metetra
.711 .788 .912 r
.23065 .6589 .23723 .66384 .24708 .65916 .24051 .65433 Metetra
.724 .794 .907 r
.24051 .65433 .24708 .65916 .25698 .65403 .25043 .64937 Metetra
.74 .803 .902 r
.25043 .64937 .25698 .65403 .26696 .64832 .26041 .64392 Metetra
.759 .813 .896 r
.26041 .64392 .26696 .64832 .27701 .64183 .27046 .63781 Metetra
.783 .827 .887 r
.27046 .63781 .27701 .64183 .28714 .63429 .28059 .63084 Metetra
.811 .845 .875 r
.28059 .63084 .28714 .63429 .29739 .62532 .29081 .62274 Metetra
.845 .868 .859 r
.29081 .62274 .29739 .62532 .30776 .61436 .30114 .61314 Metetra
.884 .898 .834 r
.30114 .61314 .30776 .61436 .31829 .6006 .31159 .60152 Metetra
.923 .932 .794 r
.31159 .60152 .31829 .6006 .32902 .58291 .32219 .58722 Metetra
.945 .96 .718 r
.32219 .58722 .32902 .58291 .34001 .55966 .33296 .56942 Metetra
.888 .933 .555 r
.33296 .56942 .34001 .55966 .35131 .52874 .34392 .54725 Metetra
.34392 .54725 .35131 .52874 .36299 .48774 .35505 .52004 Metetra
0 0 .107 r
.35505 .52004 .36299 .48774 .37502 .43502 .36632 .48794 Metetra
.134 0 .327 r
.36632 .48794 .37502 .43502 .38544 .4137 .37758 .45302 Metetra
0 0 .226 r
.37758 .45302 .38544 .4137 .39507 .41046 .38861 .42012 Metetra
.775 .891 .48 r
.38861 .42012 .39507 .41046 .40473 .40721 .39895 .40118 Metetra
.664 .741 .907 r
.39895 .40118 .40473 .40721 .41442 .40395 .40867 .3979 Metetra
.504 .682 .946 r
.40867 .3979 .41442 .40395 .42415 .40068 .41831 .39768 Metetra
.893 .474 .179 r
.41831 .39768 .42415 .40068 .43391 .39739 .42736 .41941 Metetra
.758 .441 .449 r
.42736 .41941 .43391 .39739 .44371 .39409 .43645 .4463 Metetra
.669 .391 .491 r
.43645 .4463 .44371 .39409 .45263 .43209 .44578 .4722 Metetra
.674 .385 .474 r
.44578 .4722 .45263 .43209 .46183 .47061 .45542 .49383 Metetra
.692 .371 .428 r
.45542 .49383 .46183 .47061 .4715 .49805 .46535 .51029 Metetra
.698 .327 .341 r
.46535 .51029 .4715 .49805 .48151 .51663 .4755 .52194 Metetra
.669 .213 .16 r
.4755 .52194 .48151 .51663 .49176 .52861 .48583 .52958 Metetra
.509 0 0 r
.48583 .52958 .49176 .52861 .50218 .53577 .4963 .53404 Metetra
0 .513 .777 r
.4963 .53404 .50218 .53577 .51271 .53939 .50688 .536 Metetra
.357 .738 .987 r
.50688 .536 .51271 .53939 .52333 .54031 .51753 .53595 Metetra
.547 .786 .987 r
.51753 .53595 .52333 .54031 .53402 .53901 .52824 .5342 Metetra
.643 .802 .959 r
.52824 .5342 .53402 .53901 .54474 .53575 .539 .53091 Metetra
.707 .819 .934 r
.539 .53091 .54474 .53575 .55549 .5305 .54978 .52607 Metetra
.763 .845 .913 r
.54978 .52607 .55549 .5305 .56624 .52302 .56059 .51952 Metetra
.82 .882 .89 r
.56059 .51952 .56624 .52302 .57697 .51281 .57138 .51093 Metetra
.877 .93 .853 r
.57138 .51093 .57697 .51281 .58762 .49899 .58214 .4998 Metetra
.917 .974 .776 r
.58214 .4998 .58762 .49899 .59814 .48027 .59283 .48543 Metetra
.866 .949 .592 r
.59283 .48543 .59814 .48027 .60843 .45482 .60338 .46697 Metetra
.60338 .46697 .60843 .45482 .61835 .42031 .61375 .44357 Metetra
0 0 .107 r
.61375 .44357 .61835 .42031 .62774 .37448 .62386 .41486 Metetra
.106 0 .32 r
.62386 .41486 .62774 .37448 .6369 .32907 .63369 .38174 Metetra
.225 .026 .388 r
.63369 .38174 .6369 .32907 .64745 .32552 .64333 .34752 Metetra
0 0 .095 r
.64333 .34752 .64745 .32552 .65804 .32196 .65301 .31848 Metetra
.777 .889 .925 r
.65301 .31848 .65804 .32196 .66867 .31838 .66353 .31174 Metetra
.664 .741 .907 r
.66353 .31174 .66867 .31838 .67934 .31479 .67423 .30813 Metetra
0 .028 .566 r
.67423 .30813 .67934 .31479 .69005 .31119 .68579 .32052 Metetra
.829 .44 .315 r
.68579 .32052 .69005 .31119 .70081 .30757 .69829 .34728 Metetra
.703 .398 .456 r
.69829 .34728 .70081 .30757 .71271 .3225 .71118 .37626 Metetra
.663 .375 .473 r
.71118 .37626 .71271 .3225 .72683 .36982 .72416 .40247 Metetra
.685 .369 .434 r
.72416 .40247 .72683 .36982 .74057 .40531 .73709 .42377 Metetra
.701 .342 .364 r
.73709 .42377 .74057 .40531 .75391 .43054 .74989 .43995 Metetra
.698 .274 .236 r
.74989 .43995 .75391 .43054 .76692 .44794 .76255 .45167 Metetra
.641 .124 0 r
.76255 .45167 .76692 .44794 .77969 .45964 .7751 .45981 Metetra
.444 0 0 r
.7751 .45981 .77969 .45964 .79229 .46729 .78757 .4652 Metetra
0 .466 .776 r
.78757 .4652 .79229 .46729 .80478 .47207 .79998 .46852 Metetra
.195 .638 .946 r
.79998 .46852 .80478 .47207 .8172 .47479 .81235 .47028 Metetra
.362 .702 .984 r
.81235 .47028 .8172 .47479 .82958 .47602 .82471 .47087 Metetra
.454 .727 .985 r
.82471 .47087 .82958 .47602 .84194 .47617 .83707 .47057 Metetra
.509 .738 .977 r
.83707 .47057 .84194 .47617 .8543 .47551 .84943 .46959 Metetra
.544 .743 .968 r
.84943 .46959 .8543 .47551 .86666 .47423 .86182 .46809 Metetra
.567 .746 .961 r
.86182 .46809 .86666 .47423 .87905 .47249 .87423 .46618 Metetra
.707 .789 .915 r
.22402 .65396 .23065 .6589 .24051 .65433 .2339 .64951 Metetra
.718 .795 .912 r
.2339 .64951 .24051 .65433 .25043 .64937 .24383 .64473 Metetra
.732 .804 .909 r
.24383 .64473 .25043 .64937 .26041 .64392 .25381 .63953 Metetra
.749 .815 .904 r
.25381 .63953 .26041 .64392 .27046 .63781 .26387 .63379 Metetra
.769 .829 .899 r
.26387 .63379 .27046 .63781 .28059 .63084 .27399 .62737 Metetra
.794 .848 .892 r
.27399 .62737 .28059 .63084 .29081 .62274 .28419 .62007 Metetra
.823 .873 .882 r
.28419 .62007 .29081 .62274 .30114 .61314 .29448 .61166 Metetra
.857 .906 .867 r
.29448 .61166 .30114 .61314 .31159 .60152 .30487 .60184 Metetra
.89 .946 .839 r
.30487 .60184 .31159 .60152 .32219 .58722 .31536 .59024 Metetra
.905 .982 .778 r
.31536 .59024 .32219 .58722 .33296 .56942 .32597 .57651 Metetra
.836 .961 .627 r
.32597 .57651 .33296 .56942 .34392 .54725 .33668 .56035 Metetra
.33668 .56035 .34392 .54725 .35505 .52004 .34749 .54173 Metetra
0 0 .048 r
.34749 .54173 .35505 .52004 .36632 .48794 .35834 .5212 Metetra
.15 0 .275 r
.35834 .5212 .36632 .48794 .37758 .45302 .36914 .50022 Metetra
.33 .089 .389 r
.36914 .50022 .37758 .45302 .38861 .42012 .37979 .48133 Metetra
.437 .193 .445 r
.37979 .48133 .38861 .42012 .39895 .40118 .39016 .46765 Metetra
.5 .251 .468 r
.39016 .46765 .39895 .40118 .40867 .3979 .40022 .46168 Metetra
.548 .291 .477 r
.40022 .46168 .40867 .3979 .41831 .39768 .41001 .46397 Metetra
.581 .32 .486 r
.41001 .46397 .41831 .39768 .42736 .41941 .41966 .47279 Metetra
.607 .335 .479 r
.41966 .47279 .42736 .41941 .43645 .4463 .42932 .48509 Metetra
.628 .34 .461 r
.42932 .48509 .43645 .4463 .44578 .4722 .43909 .49796 Metetra
.645 .33 .425 r
.43909 .49796 .44578 .4722 .45542 .49383 .44904 .50942 Metetra
.652 .297 .358 r
.44904 .50942 .45542 .49383 .46535 .51029 .45916 .51854 Metetra
.637 .216 .228 r
.45916 .51854 .46535 .51029 .4755 .52194 .46945 .52512 Metetra
.549 .024 0 r
.46945 .52512 .4755 .52194 .48583 .52958 .47986 .52934 Metetra
.242 0 0 r
.47986 .52934 .48583 .52958 .4963 .53404 .49038 .53152 Metetra
.217 .69 .939 r
.49038 .53152 .4963 .53404 .50688 .536 .501 .53201 Metetra
.471 .771 .996 r
.501 .53201 .50688 .536 .51753 .53595 .51168 .53108 Metetra
.584 .78 .973 r
.51168 .53108 .51753 .53595 .52824 .5342 .52242 .52891 Metetra
.646 .786 .948 r
.52242 .52891 .52824 .5342 .539 .53091 .53321 .52559 Metetra
.693 .799 .931 r
.53321 .52559 .539 .53091 .54978 .52607 .54403 .52113 Metetra
.735 .823 .919 r
.54403 .52113 .54978 .52607 .56059 .51952 .55488 .51543 Metetra
.781 .861 .91 r
.55488 .51543 .56059 .51952 .57138 .51093 .56573 .50828 Metetra
.829 .915 .895 r
.56573 .50828 .57138 .51093 .58214 .4998 .57658 .4994 Metetra
.867 .976 .852 r
.57658 .4994 .58214 .4998 .59283 .48543 .5874 .48845 Metetra
.827 .986 .711 r
.5874 .48845 .59283 .48543 .60338 .46697 .59815 .47508 Metetra
.59815 .47508 .60338 .46697 .61375 .44357 .60882 .4591 Metetra
0 0 .02 r
.60882 .4591 .61375 .44357 .62386 .41486 .61937 .44069 Metetra
.131 0 .259 r
.61937 .44069 .62386 .41486 .63369 .38174 .62982 .4208 Metetra
.308 .068 .378 r
.62982 .4208 .63369 .38174 .64333 .34752 .64022 .40144 Metetra
.416 .174 .437 r
.64022 .40144 .64333 .34752 .65301 .31848 .65069 .38559 Metetra
.485 .24 .467 r
.65069 .38559 .65301 .31848 .66353 .31174 .6614 .37635 Metetra
.531 .274 .472 r
.6614 .37635 .66353 .31174 .67423 .30813 .67251 .37555 Metetra
.569 .307 .479 r
.67251 .37555 .67423 .30813 .68579 .32052 .68407 .38266 Metetra
.596 .325 .476 r
.68407 .38266 .68579 .32052 .69829 .34728 .69604 .39516 Metetra
.62 .333 .461 r
.69604 .39516 .69829 .34728 .71118 .37626 .70829 .40988 Metetra
.64 .331 .431 r
.70829 .40988 .71118 .37626 .72416 .40247 .72069 .42422 Metetra
.656 .312 .378 r
.72069 .42422 .72416 .40247 .73709 .42377 .73315 .43664 Metetra
.659 .264 .286 r
.73315 .43664 .73709 .42377 .74989 .43995 .7456 .44659 Metetra
.633 .163 .12 r
.7456 .44659 .74989 .43995 .76255 .45167 .75803 .45406 Metetra
.526 0 0 r
.75803 .45406 .76255 .45167 .7751 .45981 .77042 .45936 Metetra
.271 0 0 r
.77042 .45936 .7751 .45981 .78757 .4652 .78278 .46283 Metetra
.053 .579 .866 r
.78278 .46283 .78757 .4652 .79998 .46852 .79512 .46486 Metetra
.279 .69 .971 r
.79512 .46486 .79998 .46852 .81235 .47028 .80746 .46573 Metetra
.407 .728 .99 r
.80746 .46573 .81235 .47028 .82471 .47087 .8198 .4657 Metetra
.48 .742 .986 r
.8198 .4657 .82471 .47087 .83707 .47057 .83216 .46496 Metetra
.524 .747 .977 r
.83216 .46496 .83707 .47057 .84943 .46959 .84453 .46367 Metetra
.554 .75 .968 r
.84453 .46367 .84943 .46959 .86182 .46809 .85694 .46193 Metetra
.574 .751 .961 r
.85694 .46193 .86182 .46809 .87423 .46618 .86937 .45985 Metetra
.702 .789 .918 r
.21734 .649 .22402 .65396 .2339 .64951 .22723 .64468 Metetra
.711 .795 .916 r
.22723 .64468 .2339 .64951 .24383 .64473 .23717 .64006 Metetra
.723 .803 .914 r
.23717 .64006 .24383 .64473 .25381 .63953 .24717 .6351 Metetra
.738 .814 .912 r
.24717 .6351 .25381 .63953 .26387 .63379 .25722 .62971 Metetra
.755 .828 .909 r
.25722 .62971 .26387 .63379 .27399 .62737 .26734 .62378 Metetra
.775 .847 .905 r
.26734 .62378 .27399 .62737 .28419 .62007 .27753 .61718 Metetra
.799 .871 .901 r
.27753 .61718 .28419 .62007 .29448 .61166 .28779 .60978 Metetra
.826 .904 .893 r
.28779 .60978 .29448 .61166 .30487 .60184 .29812 .6014 Metetra
.853 .944 .879 r
.29812 .6014 .30487 .60184 .31536 .59024 .30854 .59187 Metetra
.864 .986 .841 r
.30854 .59187 .31536 .59024 .32597 .57651 .31903 .58105 Metetra
.81 .989 .733 r
.31903 .58105 .32597 .57651 .33668 .56035 .32959 .56889 Metetra
.586 .837 .472 r
.32959 .56889 .33668 .56035 .34749 .54173 .3402 .55557 Metetra
.3402 .55557 .34749 .54173 .35834 .5212 .35083 .54156 Metetra
.098 0 .157 r
.35083 .54156 .35834 .5212 .36914 .50022 .36141 .52778 Metetra
.288 .008 .302 r
.36141 .52778 .36914 .50022 .37979 .48133 .3719 .51557 Metetra
.401 .126 .377 r
.3719 .51557 .37979 .48133 .39016 .46765 .38225 .50635 Metetra
.471 .197 .415 r
.38225 .50635 .39016 .46765 .40022 .46168 .39244 .50119 Metetra
.518 .24 .432 r
.39244 .50119 .40022 .46168 .41001 .46397 .40249 .50032 Metetra
.552 .265 .433 r
.40249 .50032 .41001 .46397 .41966 .47279 .41247 .503 Metetra
.575 .274 .421 r
.41247 .503 .41966 .47279 .42932 .48509 .42247 .50788 Metetra
.591 .268 .391 r
.42247 .50788 .42932 .48509 .43909 .49796 .43253 .51353 Metetra
.597 .239 .332 r
.43253 .51353 .43909 .49796 .44904 .50942 .44269 .51883 Metetra
.581 .166 .22 r
.44269 .51883 .44904 .50942 .45916 .51854 .45297 .52309 Metetra
.509 .005 0 r
.45297 .52309 .45916 .51854 .46945 .52512 .46336 .52602 Metetra
.271 0 0 r
.46336 .52602 .46945 .52512 .47986 .52934 .47385 .52759 Metetra
.157 .674 .89 r
.47385 .52759 .47986 .52934 .49038 .53152 .48442 .5279 Metetra
.438 .771 .997 r
.48442 .5279 .49038 .53152 .501 .53201 .49507 .52711 Metetra
.557 .77 .977 r
.49507 .52711 .501 .53201 .51168 .53108 .50579 .52537 Metetra
.614 .76 .949 r
.50579 .52537 .51168 .53108 .52242 .52891 .51655 .52281 Metetra
.65 .759 .929 r
.51655 .52281 .52242 .52891 .53321 .52559 .52737 .51947 Metetra
.679 .768 .918 r
.52737 .51947 .53321 .52559 .54403 .52113 .53822 .51536 Metetra
.708 .789 .915 r
.53822 .51536 .54403 .52113 .55488 .51543 .54911 .51041 Metetra
.74 .824 .916 r
.54911 .51041 .55488 .51543 .56573 .50828 .56002 .5045 Metetra
.777 .876 .919 r
.56002 .5045 .56573 .50828 .57658 .4994 .57094 .49747 Metetra
.811 .944 .912 r
.57094 .49747 .57658 .4994 .5874 .48845 .58186 .48916 Metetra
.799 .998 .847 r
.58186 .48916 .5874 .48845 .59815 .47508 .59276 .47945 Metetra
.613 .898 .6 r
.59276 .47945 .59815 .47508 .60882 .4591 .60363 .46836 Metetra
.60363 .46836 .60882 .4591 .61937 .44069 .61446 .4562 Metetra
.092 0 .124 r
.61446 .4562 .61937 .44069 .62982 .4208 .62526 .44363 Metetra
.281 0 .285 r
.62526 .44363 .62982 .4208 .64022 .40144 .63608 .43183 Metetra
.393 .114 .367 r
.63608 .43183 .64022 .40144 .65069 .38559 .64696 .42224 Metetra
.464 .188 .409 r
.64696 .42224 .65069 .38559 .6614 .37635 .658 .41627 Metetra
.512 .233 .428 r
.658 .41627 .6614 .37635 .67251 .37555 .66925 .41466 Metetra
.547 .261 .432 r
.66925 .41466 .67251 .37555 .68407 .38266 .68077 .41724 Metetra
.574 .275 .423 r
.68077 .41724 .68407 .38266 .69604 .39516 .69254 .42292 Metetra
.595 .277 .4 r
.69254 .42292 .69604 .39516 .70829 .40988 .70451 .43024 Metetra
.609 .263 .357 r
.70451 .43024 .70829 .40988 .72069 .42422 .71662 .43785 Metetra
.613 .224 .282 r
.71662 .43785 .72069 .42422 .73315 .43664 .72882 .4448 Metetra
.595 .144 .151 r
.72882 .4448 .73315 .43664 .7456 .44659 .74107 .45057 Metetra
.524 0 0 r
.74107 .45057 .7456 .44659 .75803 .45406 .75333 .45499 Metetra
.345 0 0 r
.75333 .45499 .75803 .45406 .77042 .45936 .76561 .4581 Metetra
0 .518 .759 r
.76561 .4581 .77042 .45936 .78278 .46283 .7779 .46003 Metetra
.198 .671 .936 r
.7779 .46003 .78278 .46283 .79512 .46486 .7902 .46096 Metetra
.358 .729 .988 r
.7902 .46096 .79512 .46486 .80746 .46573 .80252 .46105 Metetra
.449 .747 .992 r
.80252 .46105 .80746 .46573 .8198 .4657 .81485 .46046 Metetra
.504 .753 .985 r
.81485 .46046 .8198 .4657 .83216 .46496 .82721 .45931 Metetra
.54 .755 .976 r
.82721 .45931 .83216 .46496 .84453 .46367 .8396 .45772 Metetra
.564 .755 .968 r
.8396 .45772 .84453 .46367 .85694 .46193 .85202 .45575 Metetra
.581 .755 .961 r
.85202 .45575 .85694 .46193 .86937 .45985 .86447 .45349 Metetra
.697 .788 .921 r
.21061 .64402 .21734 .649 .22723 .64468 .22052 .63981 Metetra
.705 .794 .92 r
.22052 .63981 .22723 .64468 .23717 .64006 .23047 .63535 Metetra
.715 .802 .919 r
.23047 .63535 .23717 .64006 .24717 .6351 .24047 .63061 Metetra
.727 .812 .918 r
.24047 .63061 .24717 .6351 .25722 .62971 .25053 .62552 Metetra
.741 .825 .917 r
.25053 .62552 .25722 .62971 .26734 .62378 .26065 .62002 Metetra
.757 .842 .916 r
.26065 .62002 .26734 .62378 .27753 .61718 .27082 .61402 Metetra
.776 .864 .915 r
.27082 .61402 .27753 .61718 .28779 .60978 .28106 .60743 Metetra
.797 .894 .913 r
.28106 .60743 .28779 .60978 .29812 .6014 .29136 .60017 Metetra
.816 .931 .908 r
.29136 .60017 .29812 .6014 .30854 .59187 .30172 .59217 Metetra
.825 .973 .891 r
.30172 .59217 .30854 .59187 .31903 .58105 .31214 .58338 Metetra
.796 .999 .835 r
.31214 .58338 .31903 .58105 .32959 .56889 .32261 .57387 Metetra
.657 .938 .676 r
.32261 .57387 .32959 .56889 .3402 .55557 .33311 .5638 Metetra
.33311 .5638 .3402 .55557 .35083 .54156 .34362 .55352 Metetra
.34362 .55352 .35083 .54156 .36141 .52778 .35411 .54361 Metetra
.183 0 .135 r
.35411 .54361 .36141 .52778 .3719 .51557 .36454 .53475 Metetra
.321 0 .247 r
.36454 .53475 .3719 .51557 .38225 .50635 .3749 .52766 Metetra
.405 .085 .305 r
.3749 .52766 .38225 .50635 .39244 .50119 .38518 .5228 Metetra
.459 .136 .33 r
.38518 .5228 .39244 .50119 .40249 .50032 .3954 .52028 Metetra
.493 .161 .331 r
.3954 .52028 .40249 .50032 .41247 .503 .40559 .51975 Metetra
.512 .16 .307 r
.40559 .51975 .41247 .503 .42247 .50788 .4158 .52058 Metetra
.515 .131 .25 r
.4158 .52058 .42247 .50788 .43253 .51353 .42605 .52202 Metetra
.49 .054 .137 r
.42605 .52202 .43253 .51353 .44269 .51883 .43636 .52345 Metetra
.403 0 0 r
.43636 .52345 .44269 .51883 .45297 .52309 .44676 .5244 Metetra
.163 0 0 r
.44676 .5244 .45297 .52309 .46336 .52602 .45724 .52466 Metetra
.223 .726 .901 r
.45724 .52466 .46336 .52602 .47385 .52759 .4678 .52414 Metetra
.47 .794 .999 r
.4678 .52414 .47385 .52759 .48442 .5279 .47843 .52287 Metetra
.57 .771 .973 r
.47843 .52287 .48442 .5279 .49507 .52711 .48912 .52095 Metetra
.613 .744 .939 r
.48912 .52095 .49507 .52711 .50579 .52537 .49986 .51848 Metetra
.636 .728 .914 r
.49986 .51848 .50579 .52537 .51655 .52281 .51065 .51553 Metetra
.651 .722 .901 r
.51065 .51553 .51655 .52281 .52737 .51947 .52149 .51217 Metetra
.665 .727 .896 r
.52149 .51217 .52737 .51947 .53822 .51536 .53237 .50838 Metetra
.681 .743 .898 r
.53237 .50838 .53822 .51536 .54911 .51041 .54329 .50413 Metetra
.701 .772 .907 r
.54329 .50413 .54911 .51041 .56002 .5045 .55424 .49931 Metetra
.725 .817 .922 r
.55424 .49931 .56002 .5045 .57094 .49747 .56522 .49382 Metetra
.75 .881 .939 r
.56522 .49382 .57094 .49747 .58186 .48916 .57622 .48758 Metetra
.757 .955 .938 r
.57622 .48758 .58186 .48916 .59276 .47945 .58722 .48054 Metetra
.674 .976 .842 r
.58722 .48054 .59276 .47945 .60363 .46836 .59823 .47276 Metetra
.59823 .47276 .60363 .46836 .61446 .4562 .60925 .4645 Metetra
.60925 .4645 .61446 .4562 .62526 .44363 .62027 .4562 Metetra
.201 0 .105 r
.62027 .4562 .62526 .44363 .63608 .43183 .63133 .44851 Metetra
.337 0 .235 r
.63133 .44851 .63608 .43183 .64696 .42224 .64245 .44219 Metetra
.42 .092 .301 r
.64245 .44219 .64696 .42224 .658 .41627 .65368 .4379 Metetra
.474 .148 .333 r
.65368 .4379 .658 .41627 .66925 .41466 .66505 .43599 Metetra
.511 .178 .34 r
.66505 .43599 .66925 .41466 .68077 .41724 .67659 .4364 Metetra
.536 .189 .327 r
.67659 .4364 .68077 .41724 .69254 .42292 .6883 .43863 Metetra
.551 .181 .292 r
.6883 .43863 .69254 .42292 .70451 .43024 .70015 .44197 Metetra
.554 .148 .225 r
.70015 .44197 .70451 .43024 .71662 .43785 .71212 .4457 Metetra
.536 .077 .11 r
.71212 .4457 .71662 .43785 .72882 .4448 .72418 .44926 Metetra
.475 0 0 r
.72418 .44926 .72882 .4448 .74107 .45057 .73631 .45226 Metetra
.333 0 0 r
.73631 .45226 .74107 .45057 .75333 .45499 .74849 .45453 Metetra
.098 0 0 r
.74849 .45453 .75333 .45499 .76561 .4581 .7607 .45601 Metetra
.147 .659 .897 r
.7607 .45601 .76561 .4581 .7779 .46003 .77295 .45673 Metetra
.319 .731 .978 r
.77295 .45673 .7779 .46003 .7902 .46096 .78522 .45676 Metetra
.423 .755 .995 r
.78522 .45676 .7902 .46096 .80252 .46105 .79752 .45619 Metetra
.486 .761 .991 r
.79752 .45619 .80252 .46105 .81485 .46046 .80985 .4551 Metetra
.527 .761 .983 r
.80985 .4551 .81485 .46046 .82721 .45931 .82222 .45358 Metetra
.554 .76 .974 r
.82222 .45358 .82721 .45931 .8396 .45772 .83462 .4517 Metetra
.573 .759 .966 r
.83462 .4517 .8396 .45772 .85202 .45575 .84706 .44952 Metetra
.587 .758 .96 r
.84706 .44952 .85202 .45575 .86447 .45349 .85953 .44709 Metetra
.692 .787 .924 r
.20384 .639 .21061 .64402 .22052 .63981 .21375 .63489 Metetra
.699 .793 .923 r
.21375 .63489 .22052 .63981 .23047 .63535 .22372 .63058 Metetra
.707 .8 .922 r
.22372 .63058 .23047 .63535 .24047 .63061 .23373 .62603 Metetra
.717 .809 .922 r
.23373 .62603 .24047 .63061 .25053 .62552 .2438 .62121 Metetra
.728 .821 .922 r
.2438 .62121 .25053 .62552 .26065 .62002 .25391 .61606 Metetra
.741 .836 .923 r
.25391 .61606 .26065 .62002 .27082 .61402 .26408 .61054 Metetra
.755 .855 .924 r
.26408 .61054 .27082 .61402 .28106 .60743 .27431 .6046 Metetra
.77 .879 .926 r
.27431 .6046 .28106 .60743 .29136 .60017 .28459 .59819 Metetra
.784 .911 .927 r
.28459 .59819 .29136 .60017 .30172 .59217 .29492 .5913 Metetra
.792 .948 .924 r
.29492 .5913 .30172 .59217 .31214 .58338 .30529 .58392 Metetra
.78 .983 .904 r
.30529 .58392 .31214 .58338 .32261 .57387 .31571 .57613 Metetra
.715 .987 .839 r
.31571 .57613 .32261 .57387 .33311 .5638 .32615 .56808 Metetra
.55 .9 .679 r
.32615 .56808 .33311 .5638 .34362 .55352 .3366 .55999 Metetra
.3366 .55999 .34362 .55352 .35411 .54361 .34705 .55221 Metetra
.34705 .55221 .35411 .54361 .36454 .53475 .35747 .54511 Metetra
.144 0 0 r
.35747 .54511 .36454 .53475 .3749 .52766 .36787 .53903 Metetra
.257 0 .079 r
.36787 .53903 .3749 .52766 .38518 .5228 .37822 .53423 Metetra
.324 0 .118 r
.37822 .53423 .38518 .5228 .3954 .52028 .38856 .53072 Metetra
.357 0 .111 r
.38856 .53072 .3954 .52028 .40559 .51975 .39889 .52833 Metetra
.356 0 .054 r
.39889 .52833 .40559 .51975 .4158 .52058 .40924 .52672 Metetra
.31 0 0 r
.40924 .52672 .4158 .52058 .42605 .52202 .41962 .52551 Metetra
.178 0 0 r
.41962 .52551 .42605 .52202 .43636 .52345 .43006 .52433 Metetra
.43006 .52433 .43636 .52345 .44676 .5244 .44056 .52291 Metetra
.395 .825 .96 r
.44056 .52291 .44676 .5244 .45724 .52466 .45112 .52108 Metetra
.555 .824 .996 r
.45112 .52108 .45724 .52466 .4678 .52414 .46174 .51881 Metetra
.616 .775 .957 r
.46174 .51881 .4678 .52414 .47843 .52287 .47241 .51612 Metetra
.638 .733 .917 r
.47241 .51612 .47843 .52287 .48912 .52095 .48314 .51312 Metetra
.645 .704 .889 r
.48314 .51312 .48912 .52095 .49986 .51848 .49391 .50991 Metetra
.648 .685 .871 r
.49391 .50991 .49986 .51848 .51065 .51553 .50472 .50658 Metetra
.648 .676 .863 r
.50472 .50658 .51065 .51553 .52149 .51217 .51558 .50319 Metetra
.65 .677 .863 r
.51558 .50319 .52149 .51217 .53237 .50838 .52648 .49974 Metetra
.654 .688 .869 r
.52648 .49974 .53237 .50838 .54329 .50413 .53742 .49617 Metetra
.662 .71 .883 r
.53742 .49617 .54329 .50413 .55424 .49931 .54841 .49239 Metetra
.675 .746 .904 r
.54841 .49239 .55424 .49931 .56522 .49382 .55943 .48828 Metetra
.69 .798 .932 r
.55943 .48828 .56522 .49382 .57622 .48758 .57049 .48375 Metetra
.7 .867 .961 r
.57049 .48375 .57622 .48758 .58722 .48054 .58158 .47877 Metetra
.676 .937 .966 r
.58158 .47877 .58722 .48054 .59823 .47276 .59269 .47338 Metetra
.546 .93 .863 r
.59269 .47338 .59823 .47276 .60925 .4645 .60383 .46773 Metetra
.60383 .46773 .60925 .4645 .62027 .4562 .615 .4621 Metetra
.025 0 0 r
.615 .4621 .62027 .4562 .63133 .44851 .62621 .45686 Metetra
.214 0 0 r
.62621 .45686 .63133 .44851 .64245 .44219 .63749 .45242 Metetra
.326 0 .092 r
.63749 .45242 .64245 .44219 .65368 .4379 .64884 .44912 Metetra
.395 0 .149 r
.64884 .44912 .65368 .4379 .66505 .43599 .66031 .44715 Metetra
.436 .028 .164 r
.66031 .44715 .66505 .43599 .67659 .4364 .67189 .44648 Metetra
.458 .034 .145 r
.67189 .44648 .67659 .4364 .6883 .43863 .68359 .44689 Metetra
.462 .009 .088 r
.68359 .44689 .6883 .43863 .70015 .44197 .6954 .44801 Metetra
.44 0 0 r
.6954 .44801 .70015 .44197 .71212 .4457 .70731 .44946 Metetra
.377 0 0 r
.70731 .44946 .71212 .4457 .72418 .44926 .71931 .4509 Metetra
.251 0 0 r
.71931 .4509 .72418 .44926 .73631 .45226 .73138 .45208 Metetra
.058 0 0 r
.73138 .45208 .73631 .45226 .74849 .45453 .74351 .45285 Metetra
.148 .671 .88 r
.74351 .45285 .74849 .45453 .7607 .45601 .75568 .45313 Metetra
.306 .74 .969 r
.75568 .45313 .7607 .45601 .77295 .45673 .7679 .45291 Metetra
.409 .764 .995 r
.7679 .45291 .77295 .45673 .78522 .45676 .78016 .45222 Metetra
.474 .769 .995 r
.78016 .45222 .78522 .45676 .79752 .45619 .79246 .4511 Metetra
.517 .769 .988 r
.79246 .4511 .79752 .45619 .80985 .4551 .8048 .44959 Metetra
.546 .766 .979 r
.8048 .44959 .80985 .4551 .82222 .45358 .81718 .44774 Metetra
.567 .764 .971 r
.81718 .44774 .82222 .45358 .83462 .4517 .82959 .4456 Metetra
.582 .762 .964 r
.82959 .4456 .83462 .4517 .84706 .44952 .84205 .44322 Metetra
.594 .761 .959 r
.84205 .44322 .84706 .44952 .85953 .44709 .85456 .44063 Metetra
.688 .786 .926 r
.19701 .63392 .20384 .639 .21375 .63489 .20694 .62991 Metetra
.694 .791 .925 r
.20694 .62991 .21375 .63489 .22372 .63058 .21692 .62572 Metetra
.7 .798 .925 r
.21692 .62572 .22372 .63058 .23373 .62603 .22694 .62135 Metetra
.708 .806 .926 r
.22694 .62135 .23373 .62603 .2438 .62121 .23702 .61674 Metetra
.717 .816 .926 r
.23702 .61674 .2438 .62121 .25391 .61606 .24714 .61189 Metetra
.727 .828 .928 r
.24714 .61189 .25391 .61606 .26408 .61054 .25731 .60676 Metetra
.737 .844 .93 r
.25731 .60676 .26408 .61054 .27431 .6046 .26753 .60131 Metetra
.748 .864 .933 r
.26753 .60131 .27431 .6046 .28459 .59819 .2778 .59554 Metetra
.758 .889 .937 r
.2778 .59554 .28459 .59819 .29492 .5913 .28811 .58944 Metetra
.764 .918 .94 r
.28811 .58944 .29492 .5913 .30529 .58392 .29846 .58303 Metetra
.761 .95 .939 r
.29846 .58303 .30529 .58392 .31571 .57613 .30885 .57637 Metetra
.737 .976 .923 r
.30885 .57637 .31571 .57613 .32615 .56808 .31927 .56957 Metetra
.671 .976 .874 r
.31927 .56957 .32615 .56808 .3366 .55999 .3297 .56278 Metetra
.545 .92 .772 r
.3297 .56278 .3366 .55999 .34705 .55221 .34014 .5562 Metetra
.372 .801 .621 r
.34014 .5562 .34705 .55221 .35747 .54511 .35058 .55002 Metetra
.35058 .55002 .35747 .54511 .36787 .53903 .36101 .54442 Metetra
.36101 .54442 .36787 .53903 .37822 .53423 .37143 .53952 Metetra
.37143 .53952 .37822 .53423 .38856 .53072 .38185 .53531 Metetra
.001 0 0 r
.38185 .53531 .38856 .53072 .39889 .52833 .39229 .53168 Metetra
.39229 .53168 .39889 .52833 .40924 .52672 .40274 .52844 Metetra
.22 .734 .704 r
.40274 .52844 .40924 .52672 .41962 .52551 .41324 .52537 Metetra
.425 .865 .908 r
.41324 .52537 .41962 .52551 .43006 .52433 .42377 .52224 Metetra
.579 .887 .99 r
.42377 .52224 .43006 .52433 .44056 .52291 .43436 .51889 Metetra
.649 .836 .972 r
.43436 .51889 .44056 .52291 .45112 .52108 .44499 .51526 Metetra
.673 .775 .927 r
.44499 .51526 .45112 .52108 .46174 .51881 .45567 .51134 Metetra
.676 .724 .886 r
.45567 .51134 .46174 .51881 .47241 .51612 .46639 .50722 Metetra
.671 .686 .855 r
.46639 .50722 .47241 .51612 .48314 .51312 .47715 .50306 Metetra
.662 .657 .834 r
.47715 .50306 .48314 .51312 .49391 .50991 .48794 .49902 Metetra
.651 .636 .822 r
.48794 .49902 .49391 .50991 .50472 .50658 .49877 .49525 Metetra
.64 .624 .818 r
.49877 .49525 .50472 .50658 .51558 .50319 .50964 .49183 Metetra
.631 .619 .82 r
.50964 .49183 .51558 .50319 .52648 .49974 .52055 .48876 Metetra
.624 .624 .83 r
.52055 .48876 .52648 .49974 .53742 .49617 .53151 .48596 Metetra
.622 .639 .846 r
.53151 .48596 .53742 .49617 .54841 .49239 .54252 .48329 Metetra
.625 .667 .87 r
.54252 .48329 .54841 .49239 .55943 .48828 .55358 .48057 Metetra
.631 .708 .902 r
.55358 .48057 .55943 .48828 .57049 .48375 .56468 .47766 Metetra
.637 .764 .94 r
.56468 .47766 .57049 .48375 .58158 .47877 .57583 .47446 Metetra
.632 .832 .977 r
.57583 .47446 .58158 .47877 .59269 .47338 .58702 .47097 Metetra
.59 .891 .989 r
.58702 .47097 .59269 .47338 .60383 .46773 .59825 .46726 Metetra
.467 .886 .917 r
.59825 .46726 .60383 .46773 .615 .4621 .60952 .46349 Metetra
.254 .758 .72 r
.60952 .46349 .615 .4621 .62621 .45686 .62085 .45988 Metetra
.62085 .45988 .62621 .45686 .63749 .45242 .63223 .45667 Metetra
.121 0 0 r
.63223 .45667 .63749 .45242 .64884 .44912 .64368 .45406 Metetra
.217 0 0 r
.64368 .45406 .64884 .44912 .66031 .44715 .65522 .45216 Metetra
.269 0 0 r
.65522 .45216 .66031 .44715 .67189 .44648 .66684 .45098 Metetra
.285 0 0 r
.66684 .45098 .67189 .44648 .68359 .44689 .67856 .4504 Metetra
.265 0 0 r
.67856 .4504 .68359 .44689 .6954 .44801 .69038 .45026 Metetra
.204 0 0 r
.69038 .45026 .6954 .44801 .70731 .44946 .70228 .45034 Metetra
.095 0 0 r
.70228 .45034 .70731 .44946 .71931 .4509 .71425 .45044 Metetra
.051 .617 .766 r
.71425 .45044 .71931 .4509 .73138 .45208 .7263 .45041 Metetra
.202 .71 .9 r
.7263 .45041 .73138 .45208 .74351 .45285 .73841 .45013 Metetra
.325 .758 .97 r
.73841 .45013 .74351 .45285 .75568 .45313 .75057 .44954 Metetra
.412 .776 .995 r
.75057 .44954 .75568 .45313 .7679 .45291 .76278 .44861 Metetra
.472 .779 .998 r
.76278 .44861 .7679 .45291 .78016 .45222 .77504 .44735 Metetra
.513 .776 .992 r
.77504 .44735 .78016 .45222 .79246 .4511 .78734 .44578 Metetra
.542 .773 .983 r
.78734 .44578 .79246 .4511 .8048 .44959 .79969 .44391 Metetra
.563 .769 .975 r
.79969 .44391 .8048 .44959 .81718 .44774 .81208 .44178 Metetra
.578 .766 .968 r
.81208 .44178 .81718 .44774 .82959 .4456 .82452 .43941 Metetra
.59 .764 .962 r
.82452 .43941 .82959 .4456 .84205 .44322 .83701 .43685 Metetra
.599 .762 .957 r
.83701 .43685 .84205 .44322 .85456 .44063 .84954 .4341 Metetra
.684 .785 .927 r
.19014 .62879 .19701 .63392 .20694 .62991 .20008 .62486 Metetra
.689 .789 .927 r
.20008 .62486 .20694 .62991 .21692 .62572 .21008 .62078 Metetra
.694 .795 .927 r
.21008 .62078 .21692 .62572 .22694 .62135 .22011 .61655 Metetra
.701 .802 .928 r
.22011 .61655 .22694 .62135 .23702 .61674 .2302 .61213 Metetra
.708 .81 .929 r
.2302 .61213 .23702 .61674 .24714 .61189 .24033 .60751 Metetra
.715 .821 .931 r
.24033 .60751 .24714 .61189 .25731 .60676 .2505 .60268 Metetra
.723 .833 .933 r
.2505 .60268 .25731 .60676 .26753 .60131 .26072 .59761 Metetra
.731 .849 .936 r
.26072 .59761 .26753 .60131 .2778 .59554 .27099 .59231 Metetra
.738 .868 .941 r
.27099 .59231 .2778 .59554 .28811 .58944 .2813 .58677 Metetra
.744 .89 .946 r
.2813 .58677 .28811 .58944 .29846 .58303 .29164 .58102 Metetra
.744 .914 .95 r
.29164 .58102 .29846 .58303 .30885 .57637 .30202 .5751 Metetra
.736 .939 .952 r
.30202 .5751 .30885 .57637 .31927 .56957 .31243 .56909 Metetra
.715 .959 .946 r
.31243 .56909 .31927 .56957 .3297 .56278 .32287 .56307 Metetra
.674 .966 .927 r
.32287 .56307 .3297 .56278 .34014 .5562 .33332 .55715 Metetra
.614 .956 .894 r
.33332 .55715 .34014 .5562 .35058 .55002 .34378 .55143 Metetra
.547 .93 .855 r
.34378 .55143 .35058 .55002 .36101 .54442 .35425 .54601 Metetra
.494 .904 .829 r
.35425 .54601 .36101 .54442 .37143 .53952 .36473 .54091 Metetra
.476 .896 .835 r
.36473 .54091 .37143 .53952 .38185 .53531 .37523 .53611 Metetra
.504 .91 .877 r
.37523 .53611 .38185 .53531 .39229 .53168 .38575 .53153 Metetra
.57 .93 .936 r
.38575 .53153 .39229 .53168 .40274 .52844 .3963 .52702 Metetra
.643 .926 .974 r
.3963 .52702 .40274 .52844 .41324 .52537 .40688 .52243 Metetra
.694 .887 .969 r
.40688 .52243 .41324 .52537 .42377 .52224 .41751 .51762 Metetra
.717 .828 .934 r
.41751 .51762 .42377 .52224 .43436 .51889 .42818 .51249 Metetra
.721 .769 .89 r
.42818 .51249 .43436 .51889 .44499 .51526 .43888 .50703 Metetra
.715 .717 .85 r
.43888 .50703 .44499 .51526 .45567 .51134 .44962 .50131 Metetra
.703 .674 .818 r
.44962 .50131 .45567 .51134 .46639 .50722 .46039 .49551 Metetra
.687 .638 .795 r
.46039 .49551 .46639 .50722 .47715 .50306 .47118 .4899 Metetra
.669 .608 .778 r
.47118 .4899 .47715 .50306 .48794 .49902 .482 .48477 Metetra
.649 .585 .769 r
.482 .48477 .48794 .49902 .49877 .49525 .49283 .4804 Metetra
.628 .567 .767 r
.49283 .4804 .49877 .49525 .50964 .49183 .5037 .47694 Metetra
.608 .556 .771 r
.5037 .47694 .50964 .49183 .52055 .48876 .51461 .47441 Metetra
.591 .554 .782 r
.51461 .47441 .52055 .48876 .53151 .48596 .52557 .47264 Metetra
.579 .562 .8 r
.52557 .47264 .53151 .48596 .54252 .48329 .53659 .47136 Metetra
.572 .583 .825 r
.53659 .47136 .54252 .48329 .55358 .48057 .54767 .47029 Metetra
.571 .616 .858 r
.54767 .47029 .55358 .48057 .56468 .47766 .55881 .46914 Metetra
.573 .662 .898 r
.55881 .46914 .56468 .47766 .57583 .47446 .57 .46773 Metetra
.573 .719 .942 r
.57 .46773 .57583 .47446 .58702 .47097 .58125 .466 Metetra
.561 .782 .981 r
.58125 .466 .58702 .47097 .59825 .46726 .59255 .46394 Metetra
.52 .832 1 r
.59255 .46394 .59825 .46726 .60952 .46349 .6039 .46167 Metetra
.436 .844 .97 r
.6039 .46167 .60952 .46349 .62085 .45988 .61531 .45932 Metetra
.314 .8 .883 r
.61531 .45932 .62085 .45988 .63223 .45667 .62677 .45705 Metetra
.187 .72 .771 r
.62677 .45705 .63223 .45667 .64368 .45406 .6383 .455 Metetra
.6383 .455 .64368 .45406 .65522 .45216 .6499 .45326 Metetra
.6499 .45326 .65522 .45216 .66684 .45098 .66158 .45187 Metetra
.66158 .45187 .66684 .45098 .67856 .4504 .67333 .45078 Metetra
.053 .619 .706 r
.67333 .45078 .67856 .4504 .69038 .45026 .68516 .44991 Metetra
.116 .667 .79 r
.68516 .44991 .69038 .45026 .70228 .45034 .69707 .44916 Metetra
.202 .719 .876 r
.69707 .44916 .70228 .45034 .71425 .45044 .70905 .4484 Metetra
.291 .759 .942 r
.70905 .4484 .71425 .45044 .7263 .45041 .72109 .44756 Metetra
.37 .781 .981 r
.72109 .44756 .7263 .45041 .73841 .45013 .7332 .44655 Metetra
.433 .788 .997 r
.7332 .44655 .73841 .45013 .75057 .44954 .74536 .44533 Metetra
.48 .788 .998 r
.74536 .44533 .75057 .44954 .76278 .44861 .75758 .44387 Metetra
.515 .784 .993 r
.75758 .44387 .76278 .44861 .77504 .44735 .76985 .44216 Metetra
.541 .779 .986 r
.76985 .44216 .77504 .44735 .78734 .44578 .78216 .44022 Metetra
.561 .774 .978 r
.78216 .44022 .78734 .44578 .79969 .44391 .79453 .43805 Metetra
.576 .77 .971 r
.79453 .43805 .79969 .44391 .81208 .44178 .80694 .43568 Metetra
.588 .767 .965 r
.80694 .43568 .81208 .44178 .82452 .43941 .81941 .43311 Metetra
.597 .765 .96 r
.81941 .43311 .82452 .43941 .83701 .43685 .83192 .43038 Metetra
.605 .763 .955 r
.83192 .43038 .83701 .43685 .84954 .4341 .84447 .4275 Metetra
.68 .783 .928 r
.18322 .6236 .19014 .62879 .20008 .62486 .19318 .61974 Metetra
.684 .787 .928 r
.19318 .61974 .20008 .62486 .21008 .62078 .20319 .61575 Metetra
.689 .792 .929 r
.20319 .61575 .21008 .62078 .22011 .61655 .21324 .61163 Metetra
.694 .798 .929 r
.21324 .61163 .22011 .61655 .2302 .61213 .22333 .60736 Metetra
.7 .805 .93 r
.22333 .60736 .2302 .61213 .24033 .60751 .23347 .60293 Metetra
.706 .813 .932 r
.23347 .60293 .24033 .60751 .2505 .60268 .24366 .59833 Metetra
.712 .824 .934 r
.24366 .59833 .2505 .60268 .26072 .59761 .25389 .59355 Metetra
.718 .836 .937 r
.25389 .59355 .26072 .59761 .27099 .59231 .26416 .58858 Metetra
.724 .85 .941 r
.26416 .58858 .27099 .59231 .2813 .58677 .27447 .58344 Metetra
.728 .866 .946 r
.27447 .58344 .2813 .58677 .29164 .58102 .28482 .57814 Metetra
.73 .883 .951 r
.28482 .57814 .29164 .58102 .30202 .5751 .2952 .5727 Metetra
.729 .902 .956 r
.2952 .5727 .30202 .5751 .31243 .56909 .30562 .56717 Metetra
.724 .919 .959 r
.30562 .56717 .31243 .56909 .32287 .56307 .31607 .56159 Metetra
.714 .933 .961 r
.31607 .56159 .32287 .56307 .33332 .55715 .32654 .55603 Metetra
.7 .943 .96 r
.32654 .55603 .33332 .55715 .34378 .55143 .33703 .55052 Metetra
.687 .947 .959 r
.33703 .55052 .34378 .55143 .35425 .54601 .34754 .54508 Metetra
.681 .946 .96 r
.34754 .54508 .35425 .54601 .36473 .54091 .35808 .53971 Metetra
.688 .941 .963 r
.35808 .53971 .36473 .54091 .37523 .53611 .36865 .53435 Metetra
.707 .928 .964 r
.36865 .53435 .37523 .53611 .38575 .53153 .37925 .5289 Metetra
.73 .902 .956 r
.37925 .5289 .38575 .53153 .3963 .52702 .38988 .52325 Metetra
.748 .862 .932 r
.38988 .52325 .3963 .52702 .40688 .52243 .40055 .51723 Metetra
.757 .813 .897 r
.40055 .51723 .40688 .52243 .41751 .51762 .41127 .51073 Metetra
.757 .762 .857 r
.41127 .51073 .41751 .51762 .42818 .51249 .42202 .50367 Metetra
.749 .713 .819 r
.42202 .50367 .42818 .51249 .43888 .50703 .43281 .49606 Metetra
.736 .67 .785 r
.43281 .49606 .43888 .50703 .44962 .50131 .44362 .48804 Metetra
.718 .63 .758 r
.44362 .48804 .44962 .50131 .46039 .49551 .45445 .47994 Metetra
.697 .595 .738 r
.45445 .47994 .46039 .49551 .47118 .4899 .46528 .47223 Metetra
.671 .563 .724 r
.46528 .47223 .47118 .4899 .482 .48477 .47611 .46546 Metetra
.642 .534 .716 r
.47611 .46546 .482 .48477 .49283 .4804 .48694 .46017 Metetra
.611 .509 .714 r
.48694 .46017 .49283 .4804 .5037 .47694 .4978 .45668 Metetra
.581 .491 .717 r
.4978 .45668 .5037 .47694 .51461 .47441 .50868 .45499 Metetra
.553 .48 .728 r
.50868 .45499 .51461 .47441 .52557 .47264 .51962 .45479 Metetra
.53 .481 .746 r
.51962 .45479 .52557 .47264 .53659 .47136 .53063 .45556 Metetra
.515 .494 .772 r
.53063 .45556 .53659 .47136 .54767 .47029 .54171 .45673 Metetra
.507 .521 .806 r
.54171 .45673 .54767 .47029 .55881 .46914 .55287 .45783 Metetra
.506 .562 .847 r
.55287 .45783 .55881 .46914 .57 .46773 .5641 .45855 Metetra
.509 .615 .893 r
.5641 .45855 .57 .46773 .58125 .466 .5754 .45872 Metetra
.509 .674 .939 r
.5754 .45872 .58125 .466 .59255 .46394 .58676 .45833 Metetra
.501 .732 .976 r
.58676 .45833 .59255 .46394 .6039 .46167 .59817 .45746 Metetra
.476 .778 .997 r
.59817 .45746 .6039 .46167 .61531 .45932 .60965 .45623 Metetra
.434 .803 .994 r
.60965 .45623 .61531 .45932 .62677 .45705 .62118 .4548 Metetra
.383 .805 .972 r
.62118 .4548 .62677 .45705 .6383 .455 .63277 .45328 Metetra
.335 .793 .944 r
.63277 .45328 .6383 .455 .6499 .45326 .64442 .45178 Metetra
.305 .78 .926 r
.64442 .45178 .6499 .45326 .66158 .45187 .65615 .45036 Metetra
.297 .775 .924 r
.65615 .45036 .66158 .45187 .67333 .45078 .66794 .44902 Metetra
.311 .778 .938 r
.66794 .44902 .67333 .45078 .68516 .44991 .6798 .44774 Metetra
.343 .787 .96 r
.6798 .44774 .68516 .44991 .69707 .44916 .69173 .44648 Metetra
.384 .794 .98 r
.69173 .44648 .69707 .44916 .70905 .4484 .70372 .44518 Metetra
.426 .798 .994 r
.70372 .44518 .70905 .4484 .72109 .44756 .71578 .44379 Metetra
.464 .798 .999 r
.71578 .44379 .72109 .44756 .7332 .44655 .7279 .44227 Metetra
.497 .794 .998 r
.7279 .44227 .7332 .44655 .74536 .44533 .74007 .44059 Metetra
.523 .789 .993 r
.74007 .44059 .74536 .44533 .75758 .44387 .75231 .43873 Metetra
.545 .783 .987 r
.75231 .43873 .75758 .44387 .76985 .44216 .76459 .43668 Metetra
.562 .778 .98 r
.76459 .43668 .76985 .44216 .78216 .44022 .77693 .43444 Metetra
.576 .774 .973 r
.77693 .43444 .78216 .44022 .79453 .43805 .78931 .43203 Metetra
.587 .771 .967 r
.78931 .43203 .79453 .43805 .80694 .43568 .80175 .42944 Metetra
.596 .768 .962 r
.80175 .42944 .80694 .43568 .81941 .43311 .81424 .42671 Metetra
.603 .766 .957 r
.81424 .42671 .81941 .43311 .83192 .43038 .82678 .42383 Metetra
.609 .764 .954 r
.82678 .42383 .83192 .43038 .84447 .4275 .83937 .42082 Metetra
.677 .782 .929 r
.17625 .61835 .18322 .6236 .19318 .61974 .18623 .61454 Metetra
.68 .785 .929 r
.18623 .61454 .19318 .61974 .20319 .61575 .19625 .61062 Metetra
.684 .789 .93 r
.19625 .61062 .20319 .61575 .21324 .61163 .20632 .6066 Metetra
.689 .794 .93 r
.20632 .6066 .21324 .61163 .22333 .60736 .21643 .60245 Metetra
.693 .8 .931 r
.21643 .60245 .22333 .60736 .23347 .60293 .22658 .59816 Metetra
.698 .807 .933 r
.22658 .59816 .23347 .60293 .24366 .59833 .23678 .59374 Metetra
.703 .815 .934 r
.23678 .59374 .24366 .59833 .25389 .59355 .24702 .58917 Metetra
.708 .824 .937 r
.24702 .58917 .25389 .59355 .26416 .58858 .2573 .58444 Metetra
.713 .834 .94 r
.2573 .58444 .26416 .58858 .27447 .58344 .26762 .57958 Metetra
.717 .846 .943 r
.26762 .57958 .27447 .58344 .28482 .57814 .27798 .57457 Metetra
.72 .858 .947 r
.27798 .57457 .28482 .57814 .2952 .5727 .28838 .56944 Metetra
.723 .871 .951 r
.28838 .56944 .2952 .5727 .30562 .56717 .29881 .5642 Metetra
.723 .883 .954 r
.29881 .5642 .30562 .56717 .31607 .56159 .30928 .55887 Metetra
.724 .893 .957 r
.30928 .55887 .31607 .56159 .32654 .55603 .31977 .55347 Metetra
.724 .9 .958 r
.31977 .55347 .32654 .55603 .33703 .55052 .3303 .548 Metetra
.727 .902 .957 r
.3303 .548 .33703 .55052 .34754 .54508 .34086 .54243 Metetra
.734 .899 .953 r
.34086 .54243 .34754 .54508 .35808 .53971 .35146 .53672 Metetra
.745 .889 .945 r
.35146 .53672 .35808 .53971 .36865 .53435 .36209 .53077 Metetra
.758 .869 .929 r
.36209 .53077 .36865 .53435 .37925 .5289 .37276 .52446 Metetra
.77 .84 .905 r
.37276 .52446 .37925 .5289 .38988 .52325 .38348 .51763 Metetra
.778 .802 .872 r
.38348 .51763 .38988 .52325 .40055 .51723 .39425 .51009 Metetra
.78 .759 .834 r
.39425 .51009 .40055 .51723 .41127 .51073 .40506 .50167 Metetra
.776 .716 .796 r
.40506 .50167 .41127 .51073 .42202 .50367 .41592 .49223 Metetra
.766 .674 .761 r
.41592 .49223 .42202 .50367 .43281 .49606 .4268 .48177 Metetra
.751 .634 .731 r
.4268 .48177 .43281 .49606 .44362 .48804 .43771 .47047 Metetra
.73 .596 .706 r
.43771 .47047 .44362 .48804 .45445 .47994 .44862 .45884 Metetra
.704 .559 .687 r
.44862 .45884 .45445 .47994 .46528 .47223 .45951 .44771 Metetra
.672 .523 .674 r
.45951 .44771 .46528 .47223 .47611 .46546 .47036 .43816 Metetra
.635 .488 .666 r
.47036 .43816 .47611 .46546 .48694 .46017 .48118 .43127 Metetra
.593 .455 .663 r
.48118 .43127 .48694 .46017 .4978 .45668 .49198 .42773 Metetra
.55 .427 .664 r
.49198 .42773 .4978 .45668 .50868 .45499 .50281 .42755 Metetra
.51 .406 .672 r
.50281 .42755 .50868 .45499 .51962 .45479 .51369 .43006 Metetra
.475 .396 .688 r
.51369 .43006 .51962 .45479 .53063 .45556 .52466 .43418 Metetra
.449 .401 .713 r
.52466 .43418 .53063 .45556 .54171 .45673 .53572 .43883 Metetra
.435 .423 .747 r
.53572 .43883 .54171 .45673 .55287 .45783 .54688 .44318 Metetra
.431 .462 .791 r
.54688 .44318 .55287 .45783 .5641 .45855 .55814 .44671 Metetra
.437 .515 .84 r
.55814 .44671 .5641 .45855 .5754 .45872 .56947 .44922 Metetra
.447 .576 .891 r
.56947 .44922 .5754 .45872 .58676 .45833 .58088 .45073 Metetra
.456 .64 .935 r
.58088 .45073 .58676 .45833 .59817 .45746 .59235 .45136 Metetra
.46 .697 .969 r
.59235 .45136 .59817 .45746 .60965 .45623 .60388 .45128 Metetra
.456 .741 .99 r
.60388 .45128 .60965 .45623 .62118 .4548 .61547 .45068 Metetra
.446 .771 .997 r
.61547 .45068 .62118 .4548 .63277 .45328 .62712 .44972 Metetra
.435 .788 .997 r
.62712 .44972 .63277 .45328 .64442 .45178 .63883 .44853 Metetra
.428 .796 .995 r
.63883 .44853 .64442 .45178 .65615 .45036 .65059 .44719 Metetra
.429 .8 .994 r
.65059 .44719 .65615 .45036 .66794 .44902 .66243 .44577 Metetra
.438 .803 .995 r
.66243 .44577 .66794 .44902 .6798 .44774 .67432 .44428 Metetra
.454 .803 .998 r
.67432 .44428 .6798 .44774 .69173 .44648 .68628 .44271 Metetra
.474 .802 1 r
.68628 .44271 .69173 .44648 .70372 .44518 .6983 .44106 Metetra
.495 .8 .999 r
.6983 .44106 .70372 .44518 .71578 .44379 .71038 .43931 Metetra
.516 .795 .996 r
.71038 .43931 .71578 .44379 .7279 .44227 .72252 .43743 Metetra
.535 .791 .992 r
.72252 .43743 .7279 .44227 .74007 .44059 .73471 .43541 Metetra
.551 .786 .986 r
.73471 .43541 .74007 .44059 .75231 .43873 .74697 .43325 Metetra
.565 .781 .98 r
.74697 .43325 .75231 .43873 .76459 .43668 .75927 .43093 Metetra
.577 .777 .974 r
.75927 .43093 .76459 .43668 .77693 .43444 .77163 .42845 Metetra
.587 .773 .968 r
.77163 .42845 .77693 .43444 .78931 .43203 .78404 .42584 Metetra
.595 .77 .963 r
.78404 .42584 .78931 .43203 .80175 .42944 .79651 .42308 Metetra
.602 .768 .959 r
.79651 .42308 .80175 .42944 .81424 .42671 .80903 .42019 Metetra
.608 .766 .955 r
.80903 .42019 .81424 .42671 .82678 .42383 .82159 .41718 Metetra
.613 .764 .952 r
.82159 .41718 .82678 .42383 .83937 .42082 .83421 .41406 Metetra
.674 .78 .93 r
.16923 .61303 .17625 .61835 .18623 .61454 .17923 .60926 Metetra
.677 .783 .93 r
.17923 .60926 .18623 .61454 .19625 .61062 .18927 .60541 Metetra
.68 .787 .93 r
.18927 .60541 .19625 .61062 .20632 .6066 .19935 .60146 Metetra
.684 .791 .931 r
.19935 .60146 .20632 .6066 .21643 .60245 .20948 .5974 Metetra
.688 .796 .932 r
.20948 .5974 .21643 .60245 .22658 .59816 .21964 .59322 Metetra
.692 .801 .933 r
.21964 .59322 .22658 .59816 .23678 .59374 .22986 .58893 Metetra
.696 .807 .934 r
.22986 .58893 .23678 .59374 .24702 .58917 .24011 .58451 Metetra
.701 .814 .936 r
.24011 .58451 .24702 .58917 .2573 .58444 .2504 .57996 Metetra
.705 .822 .938 r
.2504 .57996 .2573 .58444 .26762 .57958 .26074 .57528 Metetra
.709 .831 .94 r
.26074 .57528 .26762 .57958 .27798 .57457 .27112 .57047 Metetra
.713 .839 .942 r
.27112 .57047 .27798 .57457 .28838 .56944 .28153 .56553 Metetra
.717 .848 .944 r
.28153 .56553 .28838 .56944 .29881 .5642 .29199 .56046 Metetra
.721 .855 .945 r
.29199 .56046 .29881 .5642 .30928 .55887 .30248 .55525 Metetra
.726 .861 .945 r
.30248 .55525 .30928 .55887 .31977 .55347 .31301 .54989 Metetra
.732 .864 .943 r
.31301 .54989 .31977 .55347 .3303 .548 .32358 .54435 Metetra
.741 .863 .938 r
.32358 .54435 .3303 .548 .34086 .54243 .33419 .53857 Metetra
.751 .857 .928 r
.33419 .53857 .34086 .54243 .35146 .53672 .34484 .53246 Metetra
.764 .845 .912 r
.34484 .53246 .35146 .53672 .36209 .53077 .35554 .52588 Metetra
.777 .824 .89 r
.35554 .52588 .36209 .53077 .37276 .52446 .36629 .51865 Metetra
.788 .796 .86 r
.36629 .51865 .37276 .52446 .38348 .51763 .3771 .51052 Metetra
.794 .762 .824 r
.3771 .51052 .38348 .51763 .39425 .51009 .38797 .50122 Metetra
.796 .724 .785 r
.38797 .50122 .39425 .51009 .40506 .50167 .3989 .49042 Metetra
.791 .685 .747 r
.3989 .49042 .40506 .50167 .41592 .49223 .40989 .47784 Metetra
.781 .646 .713 r
.40989 .47784 .41592 .49223 .4268 .48177 .42092 .4633 Metetra
.765 .608 .684 r
.42092 .4633 .4268 .48177 .43771 .47047 .43197 .44695 Metetra
.743 .571 .661 r
.43197 .44695 .43771 .47047 .44862 .45884 .44301 .42946 Metetra
.714 .533 .644 r
.44301 .42946 .44862 .45884 .45951 .44771 .454 .41227 Metetra
.676 .494 .631 r
.454 .41227 .45951 .44771 .47036 .43816 .46489 .39752 Metetra
.63 .452 .623 r
.46489 .39752 .47036 .43816 .48118 .43127 .47568 .38756 Metetra
.576 .408 .617 r
.47568 .38756 .48118 .43127 .49198 .42773 .48639 .38396 Metetra
.518 .367 .616 r
.48639 .38396 .49198 .42773 .50281 .42755 .49708 .38675 Metetra
.461 .332 .619 r
.49708 .38675 .50281 .42755 .51369 .43006 .50784 .39436 Metetra
.411 .31 .629 r
.50784 .39436 .51369 .43006 .52466 .43418 .51871 .40447 Metetra
.372 .304 .651 r
.51871 .40447 .52466 .43418 .53572 .43883 .52972 .41494 Metetra
.349 .319 .684 r
.52972 .41494 .53572 .43883 .54688 .44318 .54086 .4243 Metetra
.342 .356 .73 r
.54086 .4243 .54688 .44318 .55814 .44671 .55213 .43188 Metetra
.351 .412 .784 r
.55213 .43188 .55814 .44671 .56947 .44922 .56349 .43752 Metetra
.371 .481 .842 r
.56349 .43752 .56947 .44922 .58088 .45073 .57494 .44138 Metetra
.396 .555 .894 r
.57494 .44138 .58088 .45073 .59235 .45136 .58646 .44374 Metetra
.421 .623 .936 r
.58646 .44374 .59235 .45136 .60388 .45128 .59804 .44493 Metetra
.44 .679 .965 r
.59804 .44493 .60388 .45128 .61547 .45068 .60968 .44522 Metetra
.454 .722 .983 r
.60968 .44522 .61547 .45068 .62712 .44972 .62138 .44486 Metetra
.464 .752 .992 r
.62138 .44486 .62712 .44972 .63883 .44853 .63313 .44402 Metetra
.473 .771 .996 r
.63313 .44402 .63883 .44853 .65059 .44719 .64495 .44286 Metetra
.482 .783 .998 r
.64495 .44286 .65059 .44719 .66243 .44577 .65682 .44146 Metetra
.493 .79 .998 r
.65682 .44146 .66243 .44577 .67432 .44428 .66875 .43987 Metetra
.505 .793 .997 r
.66875 .43987 .67432 .44428 .68628 .44271 .68074 .43813 Metetra
.519 .793 .995 r
.68074 .43813 .68628 .44271 .6983 .44106 .69279 .43626 Metetra
.532 .791 .992 r
.69279 .43626 .6983 .44106 .71038 .43931 .7049 .43426 Metetra
.546 .788 .988 r
.7049 .43426 .71038 .43931 .72252 .43743 .71706 .43213 Metetra
.558 .785 .984 r
.71706 .43213 .72252 .43743 .73471 .43541 .72928 .42987 Metetra
.569 .781 .979 r
.72928 .42987 .73471 .43541 .74697 .43325 .74156 .42747 Metetra
.579 .778 .973 r
.74156 .42747 .74697 .43325 .75927 .43093 .7539 .42494 Metetra
.588 .774 .968 r
.7539 .42494 .75927 .43093 .77163 .42845 .76628 .42228 Metetra
.595 .772 .964 r
.76628 .42228 .77163 .42845 .78404 .42584 .77872 .41949 Metetra
.602 .769 .96 r
.77872 .41949 .78404 .42584 .79651 .42308 .79122 .41658 Metetra
.608 .767 .956 r
.79122 .41658 .79651 .42308 .80903 .42019 .80376 .41356 Metetra
.612 .766 .953 r
.80376 .41356 .80903 .42019 .82159 .41718 .81636 .41043 Metetra
.617 .765 .95 r
.81636 .41043 .82159 .41718 .83421 .41406 .82902 .40721 Metetra
.672 .779 .93 r
.16216 .60764 .16923 .61303 .17923 .60926 .17218 .60391 Metetra
.674 .782 .93 r
.17218 .60391 .17923 .60926 .18927 .60541 .18224 .60011 Metetra
.677 .785 .931 r
.18224 .60011 .18927 .60541 .19935 .60146 .19234 .59621 Metetra
.68 .788 .931 r
.19234 .59621 .19935 .60146 .20948 .5974 .20248 .59222 Metetra
.684 .792 .932 r
.20248 .59222 .20948 .5974 .21964 .59322 .21267 .58813 Metetra
.687 .796 .932 r
.21267 .58813 .21964 .59322 .22986 .58893 .2229 .58394 Metetra
.691 .801 .933 r
.2229 .58394 .22986 .58893 .24011 .58451 .23317 .57962 Metetra
.695 .807 .934 r
.23317 .57962 .24011 .58451 .2504 .57996 .24348 .5752 Metetra
.699 .813 .935 r
.24348 .5752 .2504 .57996 .26074 .57528 .25383 .57064 Metetra
.704 .819 .936 r
.25383 .57064 .26074 .57528 .27112 .57047 .26423 .56595 Metetra
.709 .825 .937 r
.26423 .56595 .27112 .57047 .28153 .56553 .27467 .56112 Metetra
.714 .83 .937 r
.27467 .56112 .28153 .56553 .29199 .56046 .28515 .55614 Metetra
.72 .835 .936 r
.28515 .55614 .29199 .56046 .30248 .55525 .29567 .55097 Metetra
.727 .838 .933 r
.29567 .55097 .30248 .55525 .31301 .54989 .30623 .54558 Metetra
.736 .839 .928 r
.30623 .54558 .31301 .54989 .32358 .54435 .31684 .53991 Metetra
.747 .836 .919 r
.31684 .53991 .32358 .54435 .33419 .53857 .3275 .53386 Metetra
.761 .829 .905 r
.3275 .53386 .33419 .53857 .34484 .53246 .33821 .5273 Metetra
.775 .816 .885 r
.33821 .5273 .34484 .53246 .35554 .52588 .34898 .52003 Metetra
.789 .796 .858 r
.34898 .52003 .35554 .52588 .36629 .51865 .35982 .51179 Metetra
.801 .769 .824 r
.35982 .51179 .36629 .51865 .3771 .51052 .37073 .5022 Metetra
.809 .738 .786 r
.37073 .5022 .3771 .51052 .38797 .50122 .38172 .49079 Metetra
.811 .702 .746 r
.38172 .49079 .38797 .50122 .3989 .49042 .3928 .47698 Metetra
.807 .666 .707 r
.3928 .47698 .3989 .49042 .40989 .47784 .40396 .4601 Metetra
.798 .63 .673 r
.40396 .4601 .40989 .47784 .42092 .4633 .41521 .43955 Metetra
.783 .594 .645 r
.41521 .43955 .42092 .4633 .43197 .44695 .4265 .41506 Metetra
.76 .558 .624 r
.4265 .41506 .43197 .44695 .44301 .42946 .43779 .38732 Metetra
.729 .52 .608 r
.43779 .38732 .44301 .42946 .454 .41227 .44899 .35864 Metetra
.686 .476 .597 r
.44899 .35864 .454 .41227 .46489 .39752 .45999 .33336 Metetra
.63 .426 .588 r
.45999 .33336 .46489 .39752 .47568 .38756 .47074 .31689 Metetra
.56 .37 .581 r
.47074 .31689 .47568 .38756 .48639 .38396 .48126 .31322 Metetra
.483 .313 .574 r
.48126 .31322 .48639 .38396 .49708 .38675 .49169 .32237 Metetra
.405 .261 .57 r
.49169 .32237 .49708 .38675 .50784 .39436 .50219 .34041 Metetra
.336 .222 .572 r
.50219 .34041 .50784 .39436 .51871 .40447 .51286 .36194 Metetra
.282 .203 .586 r
.51286 .36194 .51871 .40447 .52972 .41494 .52374 .38261 Metetra
.246 .208 .616 r
.52374 .38261 .52972 .41494 .54086 .4243 .53483 .40009 Metetra
.234 .241 .662 r
.53483 .40009 .54086 .4243 .55213 .43188 .54608 .41367 Metetra
.246 .301 .723 r
.54608 .41367 .55213 .43188 .56349 .43752 .55746 .42358 Metetra
.277 .382 .79 r
.55746 .42358 .56349 .43752 .57494 .44138 .56894 .43043 Metetra
.32 .47 .854 r
.56894 .43043 .57494 .44138 .58646 .44374 .5805 .43488 Metetra
.366 .554 .905 r
.5805 .43488 .58646 .44374 .59804 .44493 .59213 .4375 Metetra
.407 .625 .942 r
.59213 .4375 .59804 .44493 .60968 .44522 .60381 .43877 Metetra
.44 .678 .965 r
.60381 .43877 .60968 .44522 .62138 .44486 .61556 .43906 Metetra
.466 .717 .978 r
.61556 .43906 .62138 .44486 .63313 .44402 .62736 .43864 Metetra
.486 .744 .985 r
.62736 .43864 .63313 .44402 .64495 .44286 .63922 .4377 Metetra
.503 .761 .989 r
.63922 .4377 .64495 .44286 .65682 .44146 .65113 .43638 Metetra
.517 .772 .989 r
.65113 .43638 .65682 .44146 .66875 .43987 .6631 .43477 Metetra
.53 .778 .989 r
.6631 .43477 .66875 .43987 .68074 .43813 .67512 .43295 Metetra
.542 .781 .987 r
.67512 .43295 .68074 .43813 .69279 .43626 .68721 .43094 Metetra
.553 .782 .984 r
.68721 .43094 .69279 .43626 .7049 .43426 .69934 .42877 Metetra
.564 .781 .98 r
.69934 .42877 .7049 .43426 .71706 .43213 .71154 .42646 Metetra
.573 .779 .976 r
.71154 .42646 .71706 .43213 .72928 .42987 .72379 .42401 Metetra
.582 .777 .972 r
.72379 .42401 .72928 .42987 .74156 .42747 .7361 .42144 Metetra
.589 .774 .968 r
.7361 .42144 .74156 .42747 .7539 .42494 .74846 .41874 Metetra
.596 .772 .964 r
.74846 .41874 .7539 .42494 .76628 .42228 .76088 .41592 Metetra
.602 .77 .96 r
.76088 .41592 .76628 .42228 .77872 .41949 .77335 .41299 Metetra
.607 .768 .957 r
.77335 .41299 .77872 .41949 .79122 .41658 .78587 .40996 Metetra
.612 .767 .954 r
.78587 .40996 .79122 .41658 .80376 .41356 .79845 .40682 Metetra
.616 .765 .951 r
.79845 .40682 .80376 .41356 .81636 .41043 .81109 .40359 Metetra
.619 .764 .949 r
.81109 .40359 .81636 .41043 .82902 .40721 .82377 .40028 Metetra
.67 .778 .931 r
.15505 .60219 .16216 .60764 .17218 .60391 .16508 .59849 Metetra
.672 .78 .931 r
.16508 .59849 .17218 .60391 .18224 .60011 .17516 .59472 Metetra
.675 .783 .931 r
.17516 .59472 .18224 .60011 .19234 .59621 .18528 .59087 Metetra
.677 .785 .931 r
.18528 .59087 .19234 .59621 .20248 .59222 .19544 .58693 Metetra
.68 .789 .931 r
.19544 .58693 .20248 .59222 .21267 .58813 .20565 .5829 Metetra
.684 .792 .932 r
.20565 .5829 .21267 .58813 .2229 .58394 .21589 .57877 Metetra
.687 .796 .932 r
.21589 .57877 .2229 .58394 .23317 .57962 .22618 .57454 Metetra
.691 .8 .933 r
.22618 .57454 .23317 .57962 .24348 .5752 .23651 .57019 Metetra
.695 .805 .933 r
.23651 .57019 .24348 .5752 .25383 .57064 .24689 .56572 Metetra
.7 .809 .933 r
.24689 .56572 .25383 .57064 .26423 .56595 .25731 .56111 Metetra
.705 .814 .932 r
.25731 .56111 .26423 .56595 .27467 .56112 .26777 .55634 Metetra
.712 .818 .931 r
.26777 .55634 .27467 .56112 .28515 .55614 .27828 .55138 Metetra
.719 .821 .928 r
.27828 .55138 .28515 .55614 .29567 .55097 .28883 .5462 Metetra
.728 .823 .923 r
.28883 .5462 .29567 .55097 .30623 .54558 .29943 .54074 Metetra
.739 .822 .916 r
.29943 .54074 .30623 .54558 .31684 .53991 .31009 .5349 Metetra
.753 .819 .904 r
.31009 .5349 .31684 .53991 .3275 .53386 .3208 .52855 Metetra
.768 .811 .887 r
.3208 .52855 .3275 .53386 .33821 .5273 .33157 .52152 Metetra
.785 .798 .863 r
.33157 .52152 .33821 .5273 .34898 .52003 .34241 .51352 Metetra
.801 .779 .833 r
.34241 .51352 .34898 .52003 .35982 .51179 .35334 .50418 Metetra
.814 .754 .796 r
.35334 .50418 .35982 .51179 .37073 .5022 .36436 .49294 Metetra
.823 .724 .755 r
.36436 .49294 .37073 .5022 .38172 .49079 .3755 .47905 Metetra
.827 .69 .713 r
.3755 .47905 .38172 .49079 .3928 .47698 .38676 .46144 Metetra
.825 .656 .673 r
.38676 .46144 .3928 .47698 .40396 .4601 .39818 .43874 Metetra
.817 .623 .639 r
.39818 .43874 .40396 .4601 .41521 .43955 .40975 .40928 Metetra
.804 .59 .613 r
.40975 .40928 .41521 .43955 .4265 .41506 .42147 .37155 Metetra
.783 .557 .593 r
.42147 .37155 .4265 .41506 .43779 .38732 .43325 .32531 Metetra
.698 .479 .587 r
.43325 .32531 .43779 .38732 .44899 .35864 .44445 .29239 Metetra
.561 .373 .583 r
.44445 .29239 .44899 .35864 .45999 .33336 .45483 .2887 Metetra
.574 .403 .612 r
.45483 .2887 .45999 .33336 .47074 .31689 .46526 .285 Metetra
.588 .439 .646 r
.46526 .285 .47074 .31689 .48126 .31322 .47573 .28128 Metetra
.588 .439 .646 r
.47573 .28128 .48126 .31322 .49169 .32237 .48623 .27755 Metetra
.574 .403 .612 r
.48623 .27755 .49169 .32237 .50219 .34041 .49678 .2738 Metetra
.34 .211 .554 r
.49678 .2738 .50219 .34041 .51286 .36194 .5072 .29943 Metetra
.172 .094 .52 r
.5072 .29943 .51286 .36194 .52374 .38261 .51784 .33858 Metetra
.121 .086 .541 r
.51784 .33858 .52374 .38261 .53483 .40009 .5288 .36929 Metetra
.1 .113 .585 r
.5288 .36929 .53483 .40009 .54608 .41367 .54001 .39178 Metetra
.112 .176 .651 r
.54001 .39178 .54608 .41367 .55746 .42358 .55139 .40752 Metetra
.157 .271 .732 r
.55139 .40752 .55746 .42358 .56894 .43043 .56289 .41815 Metetra
.223 .381 .811 r
.56289 .41815 .56894 .43043 .5805 .43488 .57449 .42506 Metetra
.295 .487 .876 r
.57449 .42506 .5805 .43488 .59213 .4375 .58616 .4293 Metetra
.36 .575 .922 r
.58616 .4293 .59213 .4375 .60381 .43877 .59789 .43164 Metetra
.413 .641 .95 r
.59789 .43164 .60381 .43877 .61556 .43906 .60968 .43262 Metetra
.454 .689 .967 r
.60968 .43262 .61556 .43906 .62736 .43864 .62152 .43263 Metetra
.485 .721 .975 r
.62152 .43263 .62736 .43864 .63922 .4377 .63342 .43194 Metetra
.509 .743 .979 r
.63342 .43194 .63922 .4377 .65113 .43638 .64537 .43075 Metetra
.527 .757 .981 r
.64537 .43075 .65113 .43638 .6631 .43477 .65738 .42917 Metetra
.542 .766 .98 r
.65738 .42917 .6631 .43477 .67512 .43295 .66944 .42731 Metetra
.555 .771 .979 r
.66944 .42731 .67512 .43295 .68721 .43094 .68156 .42521 Metetra
.565 .773 .976 r
.68156 .42521 .68721 .43094 .69934 .42877 .69373 .42293 Metetra
.575 .774 .973 r
.69373 .42293 .69934 .42877 .71154 .42646 .70596 .42049 Metetra
.583 .774 .97 r
.70596 .42049 .71154 .42646 .72379 .42401 .71824 .4179 Metetra
.59 .773 .967 r
.71824 .4179 .72379 .42401 .7361 .42144 .73058 .41519 Metetra
.597 .771 .963 r
.73058 .41519 .7361 .42144 .74846 .41874 .74297 .41236 Metetra
.602 .77 .96 r
.74297 .41236 .74846 .41874 .76088 .41592 .75542 .40941 Metetra
.607 .769 .957 r
.75542 .40941 .76088 .41592 .77335 .41299 .76792 .40636 Metetra
.612 .767 .954 r
.76792 .40636 .77335 .41299 .78587 .40996 .78048 .40322 Metetra
.615 .766 .952 r
.78048 .40322 .78587 .40996 .79845 .40682 .79309 .39998 Metetra
.619 .765 .95 r
.79309 .39998 .79845 .40682 .81109 .40359 .80576 .39666 Metetra
.622 .764 .948 r
.80576 .39666 .81109 .40359 .82377 .40028 .81848 .39326 Metetra
.668 .777 .931 r
.14788 .59667 .15505 .60219 .16508 .59849 .15794 .59299 Metetra
.67 .779 .931 r
.15794 .59299 .16508 .59849 .17516 .59472 .16803 .58925 Metetra
.672 .781 .931 r
.16803 .58925 .17516 .59472 .18528 .59087 .17817 .58543 Metetra
.675 .783 .931 r
.17817 .58543 .18528 .59087 .19544 .58693 .18835 .58153 Metetra
.678 .786 .931 r
.18835 .58153 .19544 .58693 .20565 .5829 .19858 .57755 Metetra
.681 .789 .931 r
.19858 .57755 .20565 .5829 .21589 .57877 .20884 .57347 Metetra
.684 .792 .931 r
.20884 .57347 .21589 .57877 .22618 .57454 .21915 .56929 Metetra
.688 .795 .931 r
.21915 .56929 .22618 .57454 .23651 .57019 .22951 .565 Metetra
.692 .799 .931 r
.22951 .565 .23651 .57019 .24689 .56572 .23991 .56058 Metetra
.697 .803 .93 r
.23991 .56058 .24689 .56572 .25731 .56111 .25035 .55601 Metetra
.703 .806 .929 r
.25035 .55601 .25731 .56111 .26777 .55634 .26084 .55127 Metetra
.71 .809 .926 r
.26084 .55127 .26777 .55634 .27828 .55138 .27138 .54631 Metetra
.719 .811 .922 r
.27138 .54631 .27828 .55138 .28883 .5462 .28196 .54109 Metetra
.73 .812 .916 r
.28196 .54109 .28883 .5462 .29943 .54074 .2926 .53553 Metetra
.742 .811 .906 r
.2926 .53553 .29943 .54074 .31009 .5349 .3033 .5295 Metetra
.758 .808 .892 r
.3033 .5295 .31009 .5349 .3208 .52855 .31406 .52285 Metetra
.775 .8 .873 r
.31406 .52285 .3208 .52855 .33157 .52152 .3249 .51534 Metetra
.794 .788 .847 r
.3249 .51534 .33157 .52152 .34241 .51352 .33582 .5066 Metetra
.812 .77 .813 r
.33582 .5066 .34241 .51352 .35334 .50418 .34684 .49612 Metetra
.828 .746 .773 r
.34684 .49612 .35334 .50418 .36436 .49294 .35798 .48311 Metetra
.839 .718 .73 r
.35798 .48311 .36436 .49294 .3755 .47905 .36929 .46639 Metetra
.845 .686 .685 r
.36929 .46639 .3755 .47905 .38676 .46144 .38079 .44419 Metetra
.845 .654 .645 r
.38079 .44419 .38676 .46144 .39818 .43874 .39255 .41387 Metetra
.839 .624 .612 r
.39255 .41387 .39818 .43874 .40975 .40928 .40462 .37166 Metetra
.829 .596 .586 r
.40462 .37166 .40975 .40928 .42147 .37155 .41706 .31277 Metetra
.669 .458 .591 r
.41706 .31277 .42147 .37155 .43325 .32531 .42807 .28927 Metetra
.582 .423 .632 r
.42807 .28927 .43325 .32531 .44445 .29239 .43844 .28557 Metetra
.664 .741 .907 r
.43844 .28557 .44445 .29239 .45483 .2887 .44886 .28185 Metetra
.664 .741 .907 r
.44886 .28185 .45483 .2887 .46526 .285 .45931 .27812 Metetra
.664 .741 .907 r
.45931 .27812 .46526 .285 .47573 .28128 .4698 .27438 Metetra
.664 .741 .907 r
.4698 .27438 .47573 .28128 .48623 .27755 .48033 .27062 Metetra
.664 .741 .907 r
.48033 .27062 .48623 .27755 .49678 .2738 .49091 .26684 Metetra
.664 .741 .907 r
.49091 .26684 .49678 .2738 .5072 .29943 .50152 .26305 Metetra
.303 .229 .605 r
.50152 .26305 .5072 .29943 .51784 .33858 .5121 .2792 Metetra
0 0 .455 r
.5121 .2792 .51784 .33858 .5288 .36929 .52283 .33109 Metetra
0 0 .492 r
.52283 .33109 .5288 .36929 .54001 .39178 .53394 .36636 Metetra
0 .032 .563 r
.53394 .36636 .54001 .39178 .55139 .40752 .5453 .38972 Metetra
.002 .143 .659 r
.5453 .38972 .55139 .40752 .56289 .41815 .55681 .40494 Metetra
.098 .281 .762 r
.55681 .40494 .56289 .41815 .57449 .42506 .56844 .41465 Metetra
.204 .416 .847 r
.56844 .41465 .57449 .42506 .58616 .4293 .58014 .42064 Metetra
.301 .527 .905 r
.58014 .42064 .58616 .4293 .59789 .43164 .59191 .42409 Metetra
.378 .609 .94 r
.59191 .42409 .59789 .43164 .60968 .43262 .60374 .42577 Metetra
.435 .666 .959 r
.60374 .42577 .60968 .43262 .62152 .43263 .61562 .42622 Metetra
.477 .704 .968 r
.61562 .42622 .62152 .43263 .63342 .43194 .62756 .42579 Metetra
.508 .729 .973 r
.62756 .42579 .63342 .43194 .64537 .43075 .63955 .42473 Metetra
.531 .746 .974 r
.63955 .42473 .64537 .43075 .65738 .42917 .65159 .4232 Metetra
.548 .757 .974 r
.65159 .4232 .65738 .42917 .66944 .42731 .66369 .42132 Metetra
.562 .763 .972 r
.66369 .42132 .66944 .42731 .68156 .42521 .67584 .41918 Metetra
.573 .767 .97 r
.67584 .41918 .68156 .42521 .69373 .42293 .68805 .41681 Metetra
.582 .769 .968 r
.68805 .41681 .69373 .42293 .70596 .42049 .70031 .41427 Metetra
.59 .769 .965 r
.70031 .41427 .70596 .42049 .71824 .4179 .71263 .41158 Metetra
.596 .769 .962 r
.71263 .41158 .71824 .4179 .73058 .41519 .725 .40875 Metetra
.602 .769 .96 r
.725 .40875 .73058 .41519 .74297 .41236 .73743 .40581 Metetra
.607 .768 .957 r
.73743 .40581 .74297 .41236 .75542 .40941 .74991 .40276 Metetra
.611 .767 .954 r
.74991 .40276 .75542 .40941 .76792 .40636 .76245 .39961 Metetra
.615 .766 .952 r
.76245 .39961 .76792 .40636 .78048 .40322 .77504 .39637 Metetra
.618 .765 .95 r
.77504 .39637 .78048 .40322 .79309 .39998 .78769 .39304 Metetra
.621 .765 .948 r
.78769 .39304 .79309 .39998 .80576 .39666 .80039 .38964 Metetra
.624 .764 .946 r
.80039 .38964 .80576 .39666 .81848 .39326 .81315 .38616 Metetra
.666 .776 .931 r
.14067 .59109 .14788 .59667 .15794 .59299 .15074 .58743 Metetra
.668 .777 .931 r
.15074 .58743 .15794 .59299 .16803 .58925 .16086 .5837 Metetra
.67 .779 .931 r
.16086 .5837 .16803 .58925 .17817 .58543 .17102 .57991 Metetra
.673 .781 .931 r
.17102 .57991 .17817 .58543 .18835 .58153 .18122 .57604 Metetra
.676 .784 .931 r
.18122 .57604 .18835 .58153 .19858 .57755 .19146 .57208 Metetra
.679 .786 .931 r
.19146 .57208 .19858 .57755 .20884 .57347 .20175 .56804 Metetra
.682 .789 .931 r
.20175 .56804 .20884 .57347 .21915 .56929 .21208 .5639 Metetra
.686 .792 .93 r
.21208 .5639 .21915 .56929 .22951 .565 .22246 .55964 Metetra
.69 .795 .929 r
.22246 .55964 .22951 .565 .23991 .56058 .23288 .55525 Metetra
.696 .797 .928 r
.23288 .55525 .23991 .56058 .25035 .55601 .24335 .55071 Metetra
.702 .8 .926 r
.24335 .55071 .25035 .55601 .26084 .55127 .25387 .54597 Metetra
.71 .803 .923 r
.25387 .54597 .26084 .55127 .27138 .54631 .26443 .541 Metetra
.719 .804 .918 r
.26443 .541 .27138 .54631 .28196 .54109 .27505 .53573 Metetra
.731 .805 .91 r
.27505 .53573 .28196 .54109 .2926 .53553 .28573 .53006 Metetra
.745 .805 .9 r
.28573 .53006 .2926 .53553 .3033 .5295 .29647 .52386 Metetra
.763 .802 .884 r
.29647 .52386 .3033 .5295 .31406 .52285 .30728 .51693 Metetra
.782 .795 .863 r
.30728 .51693 .31406 .52285 .3249 .51534 .31818 .50896 Metetra
.803 .784 .835 r
.31818 .50896 .3249 .51534 .33582 .5066 .32918 .49952 Metetra
.824 .768 .799 r
.32918 .49952 .33582 .5066 .34684 .49612 .3403 .48794 Metetra
.842 .745 .756 r
.3403 .48794 .34684 .49612 .35798 .48311 .35158 .47314 Metetra
.856 .718 .71 r
.35158 .47314 .35798 .48311 .36929 .46639 .36307 .45345 Metetra
.864 .689 .664 r
.36307 .45345 .36929 .46639 .38079 .44419 .37485 .42611 Metetra
.866 .66 .622 r
.37485 .42611 .38079 .44419 .39255 .41387 .38705 .3866 Metetra
.863 .633 .589 r
.38705 .3866 .39255 .41387 .40462 .37166 .39983 .32742 Metetra
.767 .544 .595 r
.39983 .32742 .40462 .37166 .41706 .31277 .41164 .28614 Metetra
.596 .461 .668 r
.41164 .28614 .41706 .31277 .42807 .28927 .422 .28242 Metetra
.664 .741 .907 r
.422 .28242 .42807 .28927 .43844 .28557 .4324 .2787 Metetra
.664 .741 .907 r
.4324 .2787 .43844 .28557 .44886 .28185 .44283 .27495 Metetra
.664 .741 .907 r
.44283 .27495 .44886 .28185 .45931 .27812 .45331 .2712 Metetra
.664 .741 .907 r
.45331 .2712 .45931 .27812 .4698 .27438 .46383 .26742 Metetra
.664 .741 .907 r
.46383 .26742 .4698 .27438 .48033 .27062 .47439 .26364 Metetra
.664 .741 .907 r
.47439 .26364 .48033 .27062 .49091 .26684 .48499 .25984 Metetra
.664 .741 .907 r
.48499 .25984 .49091 .26684 .50152 .26305 .49563 .25602 Metetra
.664 .741 .907 r
.49563 .25602 .50152 .26305 .5121 .2792 .50632 .25219 Metetra
0 0 .393 r
.50632 .25219 .5121 .2792 .52283 .33109 .51694 .28623 Metetra
0 0 .374 r
.51694 .28623 .52283 .33109 .53394 .36636 .5279 .3385 Metetra
0 0 .446 r
.5279 .3385 .53394 .36636 .5453 .38972 .5392 .37107 Metetra
0 0 .562 r
.5392 .37107 .5453 .38972 .55681 .40494 .55071 .39143 Metetra
0 .166 .697 r
.55071 .39143 .55681 .40494 .56844 .41465 .56235 .4041 Metetra
.092 .34 .813 r
.56235 .4041 .56844 .41465 .58014 .42064 .57408 .41185 Metetra
.23 .482 .89 r
.57408 .41185 .58014 .42064 .59191 .42409 .58589 .41637 Metetra
.337 .582 .933 r
.58589 .41637 .59191 .42409 .60374 .42577 .59775 .41871 Metetra
.413 .648 .955 r
.59775 .41871 .60374 .42577 .61562 .42622 .60967 .41956 Metetra
.466 .691 .965 r
.60967 .41956 .61562 .42622 .62756 .42579 .62165 .41937 Metetra
.504 .72 .969 r
.62165 .41937 .62756 .42579 .63955 .42473 .63367 .41844 Metetra
.531 .738 .97 r
.63367 .41844 .63955 .42473 .65159 .4232 .64575 .41697 Metetra
.551 .75 .969 r
.64575 .41697 .65159 .4232 .66369 .42132 .65789 .41509 Metetra
.566 .757 .968 r
.65789 .41509 .66369 .42132 .67584 .41918 .67007 .4129 Metetra
.577 .762 .966 r
.67007 .4129 .67584 .41918 .68805 .41681 .68232 .41048 Metetra
.587 .765 .964 r
.68232 .41048 .68805 .41681 .70031 .41427 .69461 .40786 Metetra
.594 .766 .961 r
.69461 .40786 .70031 .41427 .71263 .41158 .70696 .40508 Metetra
.6 .767 .959 r
.70696 .40508 .71263 .41158 .725 .40875 .71937 .40216 Metetra
.606 .767 .957 r
.71937 .40216 .725 .40875 .73743 .40581 .73183 .39912 Metetra
.61 .766 .954 r
.73183 .39912 .73743 .40581 .74991 .40276 .74435 .39598 Metetra
.614 .766 .952 r
.74435 .39598 .74991 .40276 .76245 .39961 .75692 .39274 Metetra
.618 .765 .95 r
.75692 .39274 .76245 .39961 .77504 .39637 .76955 .38941 Metetra
.621 .765 .948 r
.76955 .38941 .77504 .39637 .78769 .39304 .78223 .386 Metetra
.623 .764 .947 r
.78223 .386 .78769 .39304 .80039 .38964 .79497 .38252 Metetra
.626 .764 .945 r
.79497 .38252 .80039 .38964 .81315 .38616 .80777 .37897 Metetra
.665 .775 .931 r
.1334 .58545 .14067 .59109 .15074 .58743 .1435 .5818 Metetra
.667 .776 .931 r
.1435 .5818 .15074 .58743 .16086 .5837 .15363 .57808 Metetra
.669 .778 .931 r
.15363 .57808 .16086 .5837 .17102 .57991 .16381 .5743 Metetra
.671 .78 .931 r
.16381 .5743 .17102 .57991 .18122 .57604 .17403 .57045 Metetra
.674 .782 .931 r
.17403 .57045 .18122 .57604 .19146 .57208 .1843 .56652 Metetra
.677 .784 .93 r
.1843 .56652 .19146 .57208 .20175 .56804 .19461 .56251 Metetra
.68 .786 .93 r
.19461 .56251 .20175 .56804 .21208 .5639 .20496 .55839 Metetra
.684 .789 .929 r
.20496 .55839 .21208 .5639 .22246 .55964 .21536 .55415 Metetra
.689 .791 .928 r
.21536 .55415 .22246 .55964 .23288 .55525 .22581 .54978 Metetra
.694 .794 .927 r
.22581 .54978 .23288 .55525 .24335 .55071 .2363 .54525 Metetra
.701 .796 .924 r
.2363 .54525 .24335 .55071 .25387 .54597 .24685 .54051 Metetra
.709 .798 .92 r
.24685 .54051 .25387 .54597 .26443 .541 .25744 .53552 Metetra
.719 .8 .915 r
.25744 .53552 .26443 .541 .27505 .53573 .2681 .5302 Metetra
.732 .801 .907 r
.2681 .5302 .27505 .53573 .28573 .53006 .27881 .52444 Metetra
.748 .801 .895 r
.27881 .52444 .28573 .53006 .29647 .52386 .2896 .51809 Metetra
.767 .799 .879 r
.2896 .51809 .29647 .52386 .30728 .51693 .30046 .51091 Metetra
.788 .794 .857 r
.30046 .51091 .30728 .51693 .31818 .50896 .31141 .50257 Metetra
.812 .785 .827 r
.31141 .50257 .31818 .50896 .32918 .49952 .32248 .49253 Metetra
.835 .77 .79 r
.32248 .49253 .32918 .49952 .3403 .48794 .3337 .47997 Metetra
.857 .75 .745 r
.3337 .47997 .3403 .48794 .35158 .47314 .34511 .46357 Metetra
.873 .725 .696 r
.34511 .46357 .35158 .47314 .36307 .45345 .3568 .44109 Metetra
.883 .698 .647 r
.3568 .44109 .36307 .45345 .37485 .42611 .36888 .40869 Metetra
.887 .671 .604 r
.36888 .40869 .37485 .42611 .38705 .3866 .38158 .35946 Metetra
.885 .646 .572 r
.38158 .35946 .38705 .3866 .39983 .32742 .39516 .283 Metetra
.571 .4 .611 r
.39516 .283 .39983 .32742 .41164 .28614 .4055 .27927 Metetra
.664 .741 .907 r
.4055 .27927 .41164 .28614 .422 .28242 .41589 .27553 Metetra
.664 .741 .907 r
.41589 .27553 .422 .28242 .4324 .2787 .42631 .27177 Metetra
.664 .741 .907 r
.42631 .27177 .4324 .2787 .44283 .27495 .43677 .268 Metetra
.664 .741 .907 r
.43677 .268 .44283 .27495 .45331 .2712 .44727 .26422 Metetra
.664 .741 .907 r
.44727 .26422 .45331 .2712 .46383 .26742 .45782 .26042 Metetra
.664 .741 .907 r
.45782 .26042 .46383 .26742 .47439 .26364 .4684 .25661 Metetra
.664 .741 .907 r
.4684 .25661 .47439 .26364 .48499 .25984 .47903 .25278 Metetra
.664 .741 .907 r
.47903 .25278 .48499 .25984 .49563 .25602 .4897 .24894 Metetra
.664 .741 .907 r
.4897 .24894 .49563 .25602 .50632 .25219 .50041 .24508 Metetra
.664 .741 .907 r
.50041 .24508 .50632 .25219 .51694 .28623 .51116 .2412 Metetra
0 0 .205 r
.51116 .2412 .51694 .28623 .5279 .3385 .52189 .31078 Metetra
0 0 .285 r
.52189 .31078 .5279 .3385 .5392 .37107 .5331 .3531 Metetra
0 0 .426 r
.5331 .3531 .5392 .37107 .55071 .39143 .54459 .37852 Metetra
0 .036 .606 r
.54459 .37852 .55071 .39143 .56235 .4041 .55624 .39396 Metetra
0 .258 .768 r
.55624 .39396 .56235 .4041 .57408 .41185 .56799 .40328 Metetra
.148 .438 .874 r
.56799 .40328 .57408 .41185 .58589 .41637 .57982 .40872 Metetra
.291 .559 .928 r
.57982 .40872 .58589 .41637 .59775 .41871 .59172 .41162 Metetra
.388 .636 .954 r
.59172 .41162 .59775 .41871 .60967 .41956 .60367 .41281 Metetra
.454 .684 .964 r
.60367 .41281 .60967 .41956 .62165 .41937 .61568 .41281 Metetra
.499 .714 .967 r
.61568 .41281 .62165 .41937 .63367 .41844 .62774 .41198 Metetra
.53 .733 .968 r
.62774 .41198 .63367 .41844 .64575 .41697 .63986 .41055 Metetra
.552 .746 .967 r
.63986 .41055 .64575 .41697 .65789 .41509 .65203 .40866 Metetra
.568 .754 .965 r
.65203 .40866 .65789 .41509 .67007 .4129 .66425 .40645 Metetra
.58 .759 .963 r
.66425 .40645 .67007 .4129 .68232 .41048 .67653 .40397 Metetra
.59 .762 .961 r
.67653 .40397 .68232 .41048 .69461 .40786 .68886 .40128 Metetra
.598 .764 .959 r
.68886 .40128 .69461 .40786 .70696 .40508 .70125 .39842 Metetra
.604 .765 .956 r
.70125 .39842 .70696 .40508 .71937 .40216 .71369 .39542 Metetra
.609 .765 .954 r
.71369 .39542 .71937 .40216 .73183 .39912 .72618 .3923 Metetra
.613 .765 .952 r
.72618 .3923 .73183 .39912 .74435 .39598 .73874 .38908 Metetra
.617 .765 .95 r
.73874 .38908 .74435 .39598 .75692 .39274 .75134 .38576 Metetra
.62 .765 .949 r
.75134 .38576 .75692 .39274 .76955 .38941 .76401 .38236 Metetra
.623 .764 .947 r
.76401 .38236 .76955 .38941 .78223 .386 .77673 .37888 Metetra
.625 .764 .946 r
.77673 .37888 .78223 .386 .79497 .38252 .7895 .37532 Metetra
.627 .764 .944 r
.7895 .37532 .79497 .38252 .80777 .37897 .80234 .37171 Metetra
.664 .774 .931 r
.12608 .57975 .1334 .58545 .1435 .5818 .1362 .5761 Metetra
.666 .775 .931 r
.1362 .5761 .1435 .5818 .15363 .57808 .14635 .5724 Metetra
.667 .777 .931 r
.14635 .5724 .15363 .57808 .16381 .5743 .15656 .56863 Metetra
.67 .778 .931 r
.15656 .56863 .16381 .5743 .17403 .57045 .1668 .56479 Metetra
.672 .78 .931 r
.1668 .56479 .17403 .57045 .1843 .56652 .17709 .56087 Metetra
.675 .782 .93 r
.17709 .56087 .1843 .56652 .19461 .56251 .18742 .55687 Metetra
.678 .784 .93 r
.18742 .55687 .19461 .56251 .20496 .55839 .1978 .55277 Metetra
.682 .786 .929 r
.1978 .55277 .20496 .55839 .21536 .55415 .20822 .54855 Metetra
.687 .788 .927 r
.20822 .54855 .21536 .55415 .22581 .54978 .21869 .5442 Metetra
.693 .791 .925 r
.21869 .5442 .22581 .54978 .2363 .54525 .22921 .53967 Metetra
.7 .793 .923 r
.22921 .53967 .2363 .54525 .24685 .54051 .23978 .53493 Metetra
.709 .796 .919 r
.23978 .53493 .24685 .54051 .25744 .53552 .25041 .52992 Metetra
.719 .798 .913 r
.25041 .52992 .25744 .53552 .2681 .5302 .26109 .52456 Metetra
.733 .799 .905 r
.26109 .52456 .2681 .5302 .27881 .52444 .27184 .51874 Metetra
.75 .8 .893 r
.27184 .51874 .27881 .52444 .2896 .51809 .28267 .51227 Metetra
.77 .799 .877 r
.28267 .51227 .2896 .51809 .30046 .51091 .29358 .50492 Metetra
.793 .796 .854 r
.29358 .50492 .30046 .51091 .31141 .50257 .30459 .4963 Metetra
.819 .789 .824 r
.30459 .4963 .31141 .50257 .32248 .49253 .31572 .48583 Metetra
.846 .778 .785 r
.31572 .48583 .32248 .49253 .3337 .47997 .32703 .47256 Metetra
.87 .76 .739 r
.32703 .47256 .3337 .47997 .34511 .46357 .33856 .45496 Metetra
.889 .738 .687 r
.33856 .45496 .34511 .46357 .3568 .44109 .35041 .43034 Metetra
.902 .713 .636 r
.35041 .43034 .3568 .44109 .36888 .40869 .36278 .3939 Metetra
.909 .688 .591 r
.36278 .3939 .36888 .40869 .38158 .35946 .37595 .33646 Metetra
.881 .651 .586 r
.37595 .33646 .38158 .35946 .39516 .283 .38895 .27611 Metetra
.664 .741 .907 r
.38895 .27611 .39516 .283 .4055 .27927 .39932 .27235 Metetra
.664 .741 .907 r
.39932 .27235 .4055 .27927 .41589 .27553 .40973 .26859 Metetra
.664 .741 .907 r
.40973 .26859 .41589 .27553 .42631 .27177 .42017 .2648 Metetra
.664 .741 .907 r
.42017 .2648 .42631 .27177 .43677 .268 .43066 .26101 Metetra
.664 .741 .907 r
.43066 .26101 .43677 .268 .44727 .26422 .44119 .2572 Metetra
.664 .741 .907 r
.44119 .2572 .44727 .26422 .45782 .26042 .45176 .25337 Metetra
.664 .741 .907 r
.45176 .25337 .45782 .26042 .4684 .25661 .46237 .24953 Metetra
.664 .741 .907 r
.46237 .24953 .4684 .25661 .47903 .25278 .47303 .24567 Metetra
.664 .741 .907 r
.47303 .24567 .47903 .25278 .4897 .24894 .48372 .2418 Metetra
.664 .741 .907 r
.48372 .2418 .4897 .24894 .50041 .24508 .49446 .23791 Metetra
.664 .741 .907 r
.49446 .23791 .50041 .24508 .51116 .2412 .50524 .23401 Metetra
.946 .587 .235 r
.50524 .23401 .51116 .2412 .52189 .31078 .5159 .28726 Metetra
.776 .489 0 r
.5159 .28726 .52189 .31078 .5331 .3531 .527 .33778 Metetra
.673 .337 0 r
.527 .33778 .5331 .3531 .54459 .37852 .53845 .36723 Metetra
0 0 .479 r
.53845 .36723 .54459 .37852 .55624 .39396 .5501 .38478 Metetra
0 .174 .706 r
.5501 .38478 .55624 .39396 .56799 .40328 .56186 .39527 Metetra
.059 .398 .855 r
.56186 .39527 .56799 .40328 .57982 .40872 .57372 .40138 Metetra
.245 .544 .926 r
.57372 .40138 .57982 .40872 .59172 .41162 .58564 .40466 Metetra
.365 .63 .955 r
.58564 .40466 .59172 .41162 .60367 .41281 .59762 .40607 Metetra
.443 .681 .965 r
.59762 .40607 .60367 .41281 .61568 .41281 .60967 .4062 Metetra
.494 .712 .968 r
.60967 .4062 .61568 .41281 .62774 .41198 .62176 .40543 Metetra
.528 .731 .967 r
.62176 .40543 .62774 .41198 .63986 .41055 .63391 .40401 Metetra
.552 .743 .965 r
.63391 .40401 .63986 .41055 .65203 .40866 .64612 .40211 Metetra
.57 .751 .963 r
.64612 .40211 .65203 .40866 .66425 .40645 .65837 .39985 Metetra
.583 .757 .961 r
.65837 .39985 .66425 .40645 .67653 .40397 .67069 .39732 Metetra
.592 .76 .959 r
.67069 .39732 .67653 .40397 .68886 .40128 .68305 .39456 Metetra
.6 .762 .956 r
.68305 .39456 .68886 .40128 .70125 .39842 .69548 .39164 Metetra
.606 .763 .954 r
.69548 .39164 .70125 .39842 .71369 .39542 .70795 .38857 Metetra
.611 .764 .953 r
.70795 .38857 .71369 .39542 .72618 .3923 .72048 .38537 Metetra
.615 .764 .951 r
.72048 .38537 .72618 .3923 .73874 .38908 .73307 .38207 Metetra
.619 .764 .949 r
.73307 .38207 .73874 .38908 .75134 .38576 .74572 .37868 Metetra
.622 .764 .947 r
.74572 .37868 .75134 .38576 .76401 .38236 .75842 .37521 Metetra
.624 .764 .946 r
.75842 .37521 .76401 .38236 .77673 .37888 .77118 .37166 Metetra
.627 .764 .945 r
.77118 .37166 .77673 .37888 .7895 .37532 .78399 .36804 Metetra
.629 .763 .944 r
.78399 .36804 .7895 .37532 .80234 .37171 .79686 .36436 Metetra
.663 .773 .931 r
.11871 .574 .12608 .57975 .1362 .5761 .12885 .57035 Metetra
.664 .774 .931 r
.12885 .57035 .1362 .5761 .14635 .5724 .13903 .56664 Metetra
.666 .776 .931 r
.13903 .56664 .14635 .5724 .15656 .56863 .14925 .56288 Metetra
.668 .777 .931 r
.14925 .56288 .15656 .56863 .1668 .56479 .15951 .55905 Metetra
.671 .779 .931 r
.15951 .55905 .1668 .56479 .17709 .56087 .16982 .55515 Metetra
.674 .78 .93 r
.16982 .55515 .17709 .56087 .18742 .55687 .18018 .55116 Metetra
.677 .782 .929 r
.18018 .55116 .18742 .55687 .1978 .55277 .19058 .54707 Metetra
.681 .784 .928 r
.19058 .54707 .1978 .55277 .20822 .54855 .20102 .54286 Metetra
.686 .787 .927 r
.20102 .54286 .20822 .54855 .21869 .5442 .21152 .53851 Metetra
.692 .789 .925 r
.21152 .53851 .21869 .5442 .22921 .53967 .22207 .53399 Metetra
.699 .791 .922 r
.22207 .53399 .22921 .53967 .23978 .53493 .23266 .52925 Metetra
.708 .794 .918 r
.23266 .52925 .23978 .53493 .25041 .52992 .24332 .52424 Metetra
.719 .796 .912 r
.24332 .52424 .25041 .52992 .26109 .52456 .25404 .51886 Metetra
.733 .799 .904 r
.25404 .51886 .26109 .52456 .27184 .51874 .26482 .513 Metetra
.75 .801 .893 r
.26482 .513 .27184 .51874 .28267 .51227 .27568 .50648 Metetra
.772 .802 .877 r
.27568 .50648 .28267 .51227 .29358 .50492 .28663 .49904 Metetra
.797 .801 .855 r
.28663 .49904 .29358 .50492 .30459 .4963 .29769 .49028 Metetra
.825 .797 .825 r
.29769 .49028 .30459 .4963 .31572 .48583 .30888 .47959 Metetra
.854 .789 .786 r
.30888 .47959 .31572 .48583 .32703 .47256 .32025 .46597 Metetra
.882 .775 .739 r
.32025 .46597 .32703 .47256 .33856 .45496 .33187 .44777 Metetra
.905 .756 .685 r
.33187 .44777 .33856 .45496 .35041 .43034 .34386 .42209 Metetra
.922 .733 .631 r
.34386 .42209 .35041 .43034 .36278 .3939 .35641 .38362 Metetra
.931 .711 .582 r
.35641 .38362 .36278 .3939 .37595 .33646 .36993 .32197 Metetra
.907 .689 .595 r
.36993 .32197 .37595 .33646 .38895 .27611 .3827 .26917 Metetra
.664 .741 .907 r
.3827 .26917 .38895 .27611 .39932 .27235 .39309 .26539 Metetra
.664 .741 .907 r
.39309 .26539 .39932 .27235 .40973 .26859 .40352 .26159 Metetra
.664 .741 .907 r
.40352 .26159 .40973 .26859 .42017 .2648 .414 .25778 Metetra
.664 .741 .907 r
.414 .25778 .42017 .2648 .43066 .26101 .42451 .25396 Metetra
.664 .741 .907 r
.42451 .25396 .43066 .26101 .44119 .2572 .43507 .25012 Metetra
.664 .741 .907 r
.43507 .25012 .44119 .2572 .45176 .25337 .44566 .24627 Metetra
.664 .741 .907 r
.44566 .24627 .45176 .25337 .46237 .24953 .4563 .2424 Metetra
.664 .741 .907 r
.4563 .2424 .46237 .24953 .47303 .24567 .46698 .23851 Metetra
.664 .741 .907 r
.46698 .23851 .47303 .24567 .48372 .2418 .4777 .23461 Metetra
.664 .741 .907 r
.4777 .23461 .48372 .2418 .49446 .23791 .48847 .2307 Metetra
.664 .741 .907 r
.48847 .2307 .49446 .23791 .50524 .23401 .49928 .22677 Metetra
.937 .565 .198 r
.49928 .22677 .50524 .23401 .5159 .28726 .50989 .27233 Metetra
.921 .578 .125 r
.50989 .27233 .5159 .28726 .527 .33778 .52088 .32704 Metetra
.838 .444 0 r
.52088 .32704 .527 .33778 .53845 .36723 .53229 .35848 Metetra
.652 .212 0 r
.53229 .35848 .53845 .36723 .5501 .38478 .54392 .37705 Metetra
0 .097 .626 r
.54392 .37705 .5501 .38478 .56186 .39527 .5557 .38808 Metetra
0 .367 .832 r
.5557 .38808 .56186 .39527 .57372 .40138 .56757 .39449 Metetra
.203 .536 .925 r
.56757 .39449 .57372 .40138 .58564 .40466 .57952 .39795 Metetra
.346 .63 .958 r
.57952 .39795 .58564 .40466 .59762 .40607 .59153 .39944 Metetra
.435 .682 .968 r
.59153 .39944 .59762 .40607 .60967 .4062 .6036 .39961 Metetra
.491 .713 .969 r
.6036 .39961 .60967 .4062 .62176 .40543 .61573 .39883 Metetra
.528 .731 .967 r
.61573 .39883 .62176 .40543 .63391 .40401 .62792 .39739 Metetra
.553 .743 .965 r
.62792 .39739 .63391 .40401 .64612 .40211 .64015 .39545 Metetra
.571 .751 .962 r
.64015 .39545 .64612 .40211 .65837 .39985 .65245 .39315 Metetra
.585 .756 .96 r
.65245 .39315 .65837 .39985 .67069 .39732 .66479 .39055 Metetra
.595 .759 .957 r
.66479 .39055 .67069 .39732 .68305 .39456 .6772 .38774 Metetra
.602 .761 .955 r
.6772 .38774 .68305 .39456 .69548 .39164 .68965 .38475 Metetra
.608 .762 .953 r
.68965 .38475 .69548 .39164 .70795 .38857 .70217 .38161 Metetra
.613 .763 .951 r
.70217 .38161 .70795 .38857 .72048 .38537 .71474 .37834 Metetra
.617 .764 .949 r
.71474 .37834 .72048 .38537 .73307 .38207 .72736 .37497 Metetra
.621 .764 .948 r
.72736 .37497 .73307 .38207 .74572 .37868 .74004 .37151 Metetra
.623 .764 .946 r
.74004 .37151 .74572 .37868 .75842 .37521 .75278 .36797 Metetra
.626 .764 .945 r
.75278 .36797 .75842 .37521 .77118 .37166 .76557 .36436 Metetra
.628 .763 .944 r
.76557 .36436 .77118 .37166 .78399 .36804 .77843 .36068 Metetra
.63 .763 .943 r
.77843 .36068 .78399 .36804 .79686 .36436 .79134 .35694 Metetra
.662 .772 .932 r
.11128 .56818 .11871 .574 .12885 .57035 .12144 .56453 Metetra
.663 .773 .931 r
.12144 .56453 .12885 .57035 .13903 .56664 .13164 .56083 Metetra
.665 .775 .931 r
.13164 .56083 .13903 .56664 .14925 .56288 .14189 .55707 Metetra
.667 .776 .931 r
.14189 .55707 .14925 .56288 .15951 .55905 .15217 .55324 Metetra
.67 .778 .93 r
.15217 .55324 .15951 .55905 .16982 .55515 .16251 .54935 Metetra
.672 .779 .93 r
.16251 .54935 .16982 .55515 .18018 .55116 .17288 .54536 Metetra
.676 .781 .929 r
.17288 .54536 .18018 .55116 .19058 .54707 .18331 .54128 Metetra
.68 .783 .928 r
.18331 .54128 .19058 .54707 .20102 .54286 .19378 .53708 Metetra
.684 .785 .927 r
.19378 .53708 .20102 .54286 .21152 .53851 .2043 .53275 Metetra
.69 .787 .925 r
.2043 .53275 .21152 .53851 .22207 .53399 .21487 .52823 Metetra
.697 .79 .922 r
.21487 .52823 .22207 .53399 .23266 .52925 .22549 .52351 Metetra
.706 .793 .918 r
.22549 .52351 .23266 .52925 .24332 .52424 .23618 .5185 Metetra
.718 .796 .913 r
.23618 .5185 .24332 .52424 .25404 .51886 .24692 .51313 Metetra
.732 .799 .905 r
.24692 .51313 .25404 .51886 .26482 .513 .25774 .50727 Metetra
.75 .802 .894 r
.25774 .50727 .26482 .513 .27568 .50648 .26863 .50075 Metetra
.772 .805 .88 r
.26863 .50075 .27568 .50648 .28663 .49904 .27961 .49331 Metetra
.798 .807 .859 r
.27961 .49331 .28663 .49904 .29769 .49028 .29071 .48457 Metetra
.828 .806 .83 r
.29071 .48457 .29769 .49028 .30888 .47959 .30194 .4739 Metetra
.86 .802 .793 r
.30194 .4739 .30888 .47959 .32025 .46597 .31336 .46034 Metetra
.892 .793 .745 r
.31336 .46034 .32025 .46597 .33187 .44777 .32503 .44225 Metetra
.919 .779 .69 r
.32503 .44225 .33187 .44777 .34386 .42209 .33708 .41683 Metetra
.94 .761 .632 r
.33708 .41683 .34386 .42209 .35641 .38362 .34971 .37891 Metetra
.954 .741 .578 r
.34971 .37891 .35641 .38362 .36993 .32197 .36332 .31851 Metetra
.959 .751 .579 r
.36332 .31851 .36993 .32197 .3827 .26917 .3764 .26218 Metetra
.664 .741 .907 r
.3764 .26218 .3827 .26917 .39309 .26539 .38682 .25837 Metetra
.664 .741 .907 r
.38682 .25837 .39309 .26539 .40352 .26159 .39728 .25455 Metetra
.664 .741 .907 r
.39728 .25455 .40352 .26159 .414 .25778 .40777 .25071 Metetra
.664 .741 .907 r
.40777 .25071 .414 .25778 .42451 .25396 .41831 .24686 Metetra
.664 .741 .907 r
.41831 .24686 .42451 .25396 .43507 .25012 .4289 .24299 Metetra
.664 .741 .907 r
.4289 .24299 .43507 .25012 .44566 .24627 .43952 .23911 Metetra
.664 .741 .907 r
.43952 .23911 .44566 .24627 .4563 .2424 .45018 .23521 Metetra
.664 .741 .907 r
.45018 .23521 .4563 .2424 .46698 .23851 .46089 .2313 Metetra
.664 .741 .907 r
.46089 .2313 .46698 .23851 .4777 .23461 .47164 .22737 Metetra
.664 .741 .907 r
.47164 .22737 .4777 .23461 .48847 .2307 .48243 .22343 Metetra
.664 .741 .907 r
.48243 .22343 .48847 .2307 .49928 .22677 .49327 .21947 Metetra
.942 .576 .216 r
.49327 .21947 .49928 .22677 .50989 .27233 .50378 .26854 Metetra
.941 .577 .265 r
.50378 .26854 .50989 .27233 .52088 .32704 .51471 .32193 Metetra
.894 .475 .098 r
.51471 .32193 .52088 .32704 .53229 .35848 .52609 .35275 Metetra
.755 .273 0 r
.52609 .35275 .53229 .35848 .54392 .37705 .53771 .37101 Metetra
0 .045 .54 r
.53771 .37101 .54392 .37705 .5557 .38808 .54949 .38186 Metetra
0 .351 .808 r
.54949 .38186 .5557 .38808 .56757 .39449 .56138 .38816 Metetra
.172 .539 .926 r
.56138 .38816 .56757 .39449 .57952 .39795 .57335 .39154 Metetra
.335 .637 .963 r
.57335 .39154 .57952 .39795 .59153 .39944 .58539 .39297 Metetra
.431 .688 .972 r
.58539 .39297 .59153 .39944 .6036 .39961 .59749 .39307 Metetra
.49 .716 .971 r
.59749 .39307 .6036 .39961 .61573 .39883 .60965 .39224 Metetra
.529 .734 .968 r
.60965 .39224 .61573 .39883 .62792 .39739 .62187 .39073 Metetra
.555 .744 .965 r
.62187 .39073 .62792 .39739 .64015 .39545 .63414 .38873 Metetra
.573 .751 .962 r
.63414 .38873 .64015 .39545 .65245 .39315 .64647 .38636 Metetra
.587 .756 .959 r
.64647 .38636 .65245 .39315 .66479 .39055 .65885 .3837 Metetra
.597 .759 .956 r
.65885 .3837 .66479 .39055 .6772 .38774 .67129 .38082 Metetra
.604 .761 .954 r
.67129 .38082 .6772 .38774 .68965 .38475 .68378 .37776 Metetra
.61 .762 .952 r
.68378 .37776 .68965 .38475 .70217 .38161 .69633 .37455 Metetra
.615 .763 .95 r
.69633 .37455 .70217 .38161 .71474 .37834 .70893 .37122 Metetra
.619 .763 .948 r
.70893 .37122 .71474 .37834 .72736 .37497 .7216 .36778 Metetra
.622 .763 .947 r
.7216 .36778 .72736 .37497 .74004 .37151 .73432 .36426 Metetra
.625 .763 .946 r
.73432 .36426 .74004 .37151 .75278 .36797 .74709 .36065 Metetra
.627 .763 .944 r
.74709 .36065 .75278 .36797 .76557 .36436 .75993 .35698 Metetra
.629 .763 .943 r
.75993 .35698 .76557 .36436 .77843 .36068 .77282 .35324 Metetra
.631 .763 .942 r
.77282 .35324 .77843 .36068 .79134 .35694 .78577 .34944 Metetra
.661 .772 .932 r
.10381 .56232 .11128 .56818 .12144 .56453 .11398 .55866 Metetra
.662 .773 .931 r
.11398 .55866 .12144 .56453 .13164 .56083 .12421 .55496 Metetra
.664 .774 .931 r
.12421 .55496 .13164 .56083 .14189 .55707 .13447 .5512 Metetra
.666 .775 .931 r
.13447 .5512 .14189 .55707 .15217 .55324 .14478 .54737 Metetra
.668 .777 .931 r
.14478 .54737 .15217 .55324 .16251 .54935 .15514 .54348 Metetra
.671 .778 .93 r
.15514 .54348 .16251 .54935 .17288 .54536 .16554 .5395 Metetra
.674 .78 .929 r
.16554 .5395 .17288 .54536 .18331 .54128 .17598 .53543 Metetra
.678 .782 .928 r
.17598 .53543 .18331 .54128 .19378 .53708 .18648 .53124 Metetra
.683 .784 .927 r
.18648 .53124 .19378 .53708 .2043 .53275 .19702 .52691 Metetra
.689 .786 .925 r
.19702 .52691 .2043 .53275 .21487 .52823 .20762 .52241 Metetra
.696 .789 .922 r
.20762 .52241 .21487 .52823 .22549 .52351 .21827 .5177 Metetra
.705 .792 .919 r
.21827 .5177 .22549 .52351 .23618 .5185 .22898 .51272 Metetra
.716 .796 .914 r
.22898 .51272 .23618 .5185 .24692 .51313 .23975 .50738 Metetra
.73 .8 .907 r
.23975 .50738 .24692 .51313 .25774 .50727 .25059 .50156 Metetra
.748 .804 .897 r
.25059 .50156 .25774 .50727 .26863 .50075 .26151 .49511 Metetra
.77 .809 .884 r
.26151 .49511 .26863 .50075 .27961 .49331 .27252 .48777 Metetra
.796 .813 .865 r
.27252 .48777 .27961 .49331 .29071 .48457 .28364 .47918 Metetra
.828 .817 .839 r
.28364 .47918 .29071 .48457 .30194 .4739 .2949 .46877 Metetra
.862 .818 .804 r
.2949 .46877 .30194 .4739 .31336 .46034 .30634 .45565 Metetra
.897 .815 .758 r
.30634 .45565 .31336 .46034 .32503 .44225 .31803 .43837 Metetra
.93 .807 .703 r
.31803 .43837 .32503 .44225 .33708 .41683 .33007 .41444 Metetra
.956 .795 .641 r
.33007 .41444 .33708 .41683 .34971 .37891 .34265 .37946 Metetra
.975 .78 .578 r
.34265 .37946 .34971 .37891 .36332 .31851 .3561 .3253 Metetra
.991 .787 .534 r
.3561 .3253 .36332 .31851 .3764 .26218 .37006 .25514 Metetra
.664 .741 .907 r
.37006 .25514 .3764 .26218 .38682 .25837 .3805 .2513 Metetra
.664 .741 .907 r
.3805 .2513 .38682 .25837 .39728 .25455 .39098 .24745 Metetra
.664 .741 .907 r
.39098 .24745 .39728 .25455 .40777 .25071 .40151 .24359 Metetra
.664 .741 .907 r
.40151 .24359 .40777 .25071 .41831 .24686 .41207 .23971 Metetra
.664 .741 .907 r
.41207 .23971 .41831 .24686 .4289 .24299 .42268 .23581 Metetra
.664 .741 .907 r
.42268 .23581 .4289 .24299 .43952 .23911 .43333 .2319 Metetra
.664 .741 .907 r
.43333 .2319 .43952 .23911 .45018 .23521 .44402 .22798 Metetra
.664 .741 .907 r
.44402 .22798 .45018 .23521 .46089 .2313 .45476 .22404 Metetra
.664 .741 .907 r
.45476 .22404 .46089 .2313 .47164 .22737 .46553 .22008 Metetra
.664 .741 .907 r
.46553 .22008 .47164 .22737 .48243 .22343 .47635 .21611 Metetra
.664 .741 .907 r
.47635 .21611 .48243 .22343 .49327 .21947 .48721 .21212 Metetra
.954 .605 .268 r
.48721 .21212 .49327 .21947 .50378 .26854 .49753 .2751 Metetra
.899 .532 .336 r
.49753 .2751 .50378 .26854 .51471 .32193 .50845 .32215 Metetra
.879 .454 .183 r
.50845 .32215 .51471 .32193 .52609 .35275 .51982 .34994 Metetra
.78 .278 0 r
.51982 .34994 .52609 .35275 .53771 .37101 .53145 .36662 Metetra
.513 0 0 r
.53145 .36662 .53771 .37101 .54949 .38186 .54324 .37661 Metetra
0 .358 .792 r
.54324 .37661 .54949 .38186 .56138 .38816 .55515 .3824 Metetra
.161 .555 .929 r
.55515 .3824 .56138 .38816 .57335 .39154 .56714 .38545 Metetra
.333 .65 .969 r
.56714 .38545 .57335 .39154 .58539 .39297 .5792 .38666 Metetra
.433 .697 .976 r
.5792 .38666 .58539 .39297 .59749 .39307 .59133 .38661 Metetra
.493 .723 .974 r
.59133 .38661 .59749 .39307 .60965 .39224 .60352 .38565 Metetra
.532 .737 .969 r
.60352 .38565 .60965 .39224 .62187 .39073 .61577 .38405 Metetra
.558 .747 .965 r
.61577 .38405 .62187 .39073 .63414 .38873 .62808 .38196 Metetra
.576 .753 .961 r
.62808 .38196 .63414 .38873 .64647 .38636 .64044 .3795 Metetra
.589 .756 .958 r
.64044 .3795 .64647 .38636 .65885 .3837 .65285 .37677 Metetra
.599 .759 .955 r
.65285 .37677 .65885 .3837 .67129 .38082 .66533 .37381 Metetra
.606 .761 .953 r
.66533 .37381 .67129 .38082 .68378 .37776 .67786 .37068 Metetra
.612 .762 .951 r
.67786 .37068 .68378 .37776 .69633 .37455 .69044 .3674 Metetra
.617 .763 .949 r
.69044 .3674 .69633 .37455 .70893 .37122 .70308 .36401 Metetra
.62 .763 .947 r
.70308 .36401 .70893 .37122 .7216 .36778 .71578 .36051 Metetra
.624 .763 .946 r
.71578 .36051 .7216 .36778 .73432 .36426 .72854 .35692 Metetra
.626 .763 .945 r
.72854 .35692 .73432 .36426 .74709 .36065 .74135 .35325 Metetra
.628 .763 .944 r
.74135 .35325 .74709 .36065 .75993 .35698 .75423 .34952 Metetra
.63 .763 .943 r
.75423 .34952 .75993 .35698 .77282 .35324 .76716 .34572 Metetra
.632 .763 .942 r
.76716 .34572 .77282 .35324 .78577 .34944 .78015 .34186 Metetra
.66 .771 .932 r
.09627 .55639 .10381 .56232 .11398 .55866 .10647 .55273 Metetra
.662 .772 .932 r
.10647 .55273 .11398 .55866 .12421 .55496 .11672 .54903 Metetra
.663 .773 .931 r
.11672 .54903 .12421 .55496 .13447 .5512 .127 .54526 Metetra
.665 .774 .931 r
.127 .54526 .13447 .5512 .14478 .54737 .13734 .54144 Metetra
.667 .776 .931 r
.13734 .54144 .14478 .54737 .15514 .54348 .14771 .53755 Metetra
.67 .777 .93 r
.14771 .53755 .15514 .54348 .16554 .5395 .15813 .53357 Metetra
.673 .779 .929 r
.15813 .53357 .16554 .5395 .17598 .53543 .1686 .52951 Metetra
.677 .781 .929 r
.1686 .52951 .17598 .53543 .18648 .53124 .17912 .52533 Metetra
.681 .783 .927 r
.17912 .52533 .18648 .53124 .19702 .52691 .18969 .52102 Metetra
.687 .786 .926 r
.18969 .52102 .19702 .52691 .20762 .52241 .20031 .51654 Metetra
.694 .788 .923 r
.20031 .51654 .20762 .52241 .21827 .5177 .21099 .51186 Metetra
.702 .792 .92 r
.21099 .51186 .21827 .5177 .22898 .51272 .22172 .50691 Metetra
.713 .796 .916 r
.22172 .50691 .22898 .51272 .23975 .50738 .23252 .50162 Metetra
.727 .8 .91 r
.23252 .50162 .23975 .50738 .25059 .50156 .24338 .49588 Metetra
.744 .806 .901 r
.24338 .49588 .25059 .50156 .26151 .49511 .25432 .48955 Metetra
.766 .812 .89 r
.25432 .48955 .26151 .49511 .27252 .48777 .26536 .48238 Metetra
.792 .82 .874 r
.26536 .48238 .27252 .48777 .28364 .47918 .2765 .47407 Metetra
.824 .827 .851 r
.2765 .47407 .28364 .47918 .2949 .46877 .28777 .46412 Metetra
.86 .834 .82 r
.28777 .46412 .2949 .46877 .30634 .45565 .29921 .45177 Metetra
.898 .838 .778 r
.29921 .45177 .30634 .45565 .31803 .43837 .31087 .4358 Metetra
.936 .839 .724 r
.31087 .4358 .31803 .43837 .33007 .41444 .32285 .41426 Metetra
.968 .835 .659 r
.32285 .41426 .33007 .41444 .34265 .37946 .33528 .38381 Metetra
.99 .826 .586 r
.33528 .38381 .34265 .37946 .3561 .3253 .34839 .33872 Metetra
1 .814 .507 r
.34839 .33872 .3561 .3253 .37006 .25514 .36257 .26895 Metetra
.757 .847 .4 r
.36257 .26895 .37006 .25514 .3805 .2513 .37414 .24418 Metetra
.664 .741 .907 r
.37414 .24418 .3805 .2513 .39098 .24745 .38464 .24031 Metetra
.664 .741 .907 r
.38464 .24031 .39098 .24745 .40151 .24359 .39519 .23641 Metetra
.664 .741 .907 r
.39519 .23641 .40151 .24359 .41207 .23971 .40579 .23251 Metetra
.664 .741 .907 r
.40579 .23251 .41207 .23971 .42268 .23581 .41642 .22858 Metetra
.664 .741 .907 r
.41642 .22858 .42268 .23581 .43333 .2319 .4271 .22464 Metetra
.664 .741 .907 r
.4271 .22464 .43333 .2319 .44402 .22798 .43781 .22069 Metetra
.664 .741 .907 r
.43781 .22069 .44402 .22798 .45476 .22404 .44858 .21672 Metetra
.664 .741 .907 r
.44858 .21672 .45476 .22404 .46553 .22008 .45938 .21273 Metetra
.664 .741 .907 r
.45938 .21273 .46553 .22008 .47635 .21611 .47023 .20873 Metetra
.712 .25 0 r
.47023 .20873 .47635 .21611 .48721 .21212 .48081 .22578 Metetra
.891 .548 .391 r
.48081 .22578 .48721 .21212 .49753 .2751 .4911 .28835 Metetra
.843 .477 .36 r
.4911 .28835 .49753 .2751 .50845 .32215 .50209 .3262 Metetra
.836 .407 .215 r
.50209 .3262 .50845 .32215 .51982 .34994 .51349 .34936 Metetra
.756 .241 0 r
.51349 .34936 .51982 .34994 .53145 .36662 .52513 .36357 Metetra
.507 0 0 r
.52513 .36357 .53145 .36662 .54324 .37661 .53694 .37217 Metetra
0 .391 .793 r
.53694 .37217 .54324 .37661 .55515 .3824 .54886 .37712 Metetra
.171 .582 .937 r
.54886 .37712 .55515 .3824 .56714 .38545 .56087 .37965 Metetra
.343 .669 .975 r
.56087 .37965 .56714 .38545 .5792 .38666 .57296 .38052 Metetra
.441 .709 .98 r
.57296 .38052 .5792 .38666 .59133 .38661 .58512 .38022 Metetra
.499 .73 .976 r
.58512 .38022 .59133 .38661 .60352 .38565 .59734 .37909 Metetra
.536 .742 .971 r
.59734 .37909 .60352 .38565 .61577 .38405 .60962 .37735 Metetra
.561 .75 .965 r
.60962 .37735 .61577 .38405 .62808 .38196 .62196 .37514 Metetra
.579 .754 .961 r
.62196 .37514 .62808 .38196 .64044 .3795 .63435 .37259 Metetra
.592 .758 .958 r
.63435 .37259 .64044 .3795 .65285 .37677 .64681 .36977 Metetra
.601 .76 .955 r
.64681 .36977 .65285 .37677 .66533 .37381 .65932 .36674 Metetra
.608 .761 .952 r
.65932 .36674 .66533 .37381 .67786 .37068 .67188 .36353 Metetra
.614 .762 .95 r
.67188 .36353 .67786 .37068 .69044 .3674 .6845 .36018 Metetra
.618 .763 .948 r
.6845 .36018 .69044 .3674 .70308 .36401 .69718 .35671 Metetra
.622 .763 .947 r
.69718 .35671 .70308 .36401 .71578 .36051 .70992 .35315 Metetra
.625 .763 .945 r
.70992 .35315 .71578 .36051 .72854 .35692 .72271 .3495 Metetra
.627 .763 .944 r
.72271 .3495 .72854 .35692 .74135 .35325 .73557 .34577 Metetra
.629 .763 .943 r
.73557 .34577 .74135 .35325 .75423 .34952 .74848 .34198 Metetra
.631 .763 .942 r
.74848 .34198 .75423 .34952 .76716 .34572 .76145 .33812 Metetra
.633 .763 .941 r
.76145 .33812 .76716 .34572 .78015 .34186 .77448 .33421 Metetra
.659 .771 .932 r
.08868 .55042 .09627 .55639 .10647 .55273 .0989 .54675 Metetra
.661 .772 .932 r
.0989 .54675 .10647 .55273 .11672 .54903 .10917 .54304 Metetra
.662 .773 .931 r
.10917 .54304 .11672 .54903 .127 .54526 .11948 .53927 Metetra
.664 .774 .931 r
.11948 .53927 .127 .54526 .13734 .54144 .12983 .53545 Metetra
.666 .775 .931 r
.12983 .53545 .13734 .54144 .14771 .53755 .14023 .53156 Metetra
.669 .777 .93 r
.14023 .53156 .14771 .53755 .15813 .53357 .15068 .52759 Metetra
.672 .778 .93 r
.15068 .52759 .15813 .53357 .1686 .52951 .16117 .52353 Metetra
.675 .78 .929 r
.16117 .52353 .1686 .52951 .17912 .52533 .17171 .51936 Metetra
.68 .782 .928 r
.17171 .51936 .17912 .52533 .18969 .52102 .1823 .51507 Metetra
.685 .785 .926 r
.1823 .51507 .18969 .52102 .20031 .51654 .19295 .51062 Metetra
.692 .788 .924 r
.19295 .51062 .20031 .51654 .21099 .51186 .20364 .50597 Metetra
.7 .791 .922 r
.20364 .50597 .21099 .51186 .22172 .50691 .2144 .50107 Metetra
.71 .796 .918 r
.2144 .50107 .22172 .50691 .23252 .50162 .22522 .49586 Metetra
.723 .801 .913 r
.22522 .49586 .23252 .50162 .24338 .49588 .23611 .49023 Metetra
.739 .808 .906 r
.23611 .49023 .24338 .49588 .25432 .48955 .24707 .48405 Metetra
.76 .816 .897 r
.24707 .48405 .25432 .48955 .26536 .48238 .25812 .47713 Metetra
.785 .825 .884 r
.25812 .47713 .26536 .48238 .2765 .47407 .26927 .46919 Metetra
.816 .836 .865 r
.26927 .46919 .2765 .47407 .28777 .46412 .28054 .45983 Metetra
.852 .848 .839 r
.28054 .45983 .28777 .46412 .29921 .45177 .29197 .44844 Metetra
.892 .861 .803 r
.29197 .44844 .29921 .45177 .31087 .4358 .30359 .4341 Metetra
.933 .871 .754 r
.30359 .4341 .31087 .4358 .32285 .41426 .31546 .41537 Metetra
.969 .878 .688 r
.31546 .41537 .32285 .41426 .33528 .38381 .32769 .38999 Metetra
.992 .876 .602 r
.32769 .38999 .33528 .38381 .34839 .33872 .34041 .35442 Metetra
.986 .86 .491 r
.34041 .35442 .34839 .33872 .36257 .26895 .35382 .30321 Metetra
.862 .788 .292 r
.35382 .30321 .36257 .26895 .37414 .24418 .36772 .23701 Metetra
.664 .741 .907 r
.36772 .23701 .37414 .24418 .38464 .24031 .37826 .23311 Metetra
.664 .741 .907 r
.37826 .23311 .38464 .24031 .39519 .23641 .38884 .22919 Metetra
.664 .741 .907 r
.38884 .22919 .39519 .23641 .40579 .23251 .39945 .22525 Metetra
.664 .741 .907 r
.39945 .22525 .40579 .23251 .41642 .22858 .41011 .2213 Metetra
.664 .741 .907 r
.41011 .2213 .41642 .22858 .4271 .22464 .42082 .21733 Metetra
.664 .741 .907 r
.42082 .21733 .4271 .22464 .43781 .22069 .43156 .21335 Metetra
.664 .741 .907 r
.43156 .21335 .43781 .22069 .44858 .21672 .44235 .20935 Metetra
.664 .741 .907 r
.44235 .20935 .44858 .21672 .45938 .21273 .45318 .20533 Metetra
.664 .741 .907 r
.45318 .20533 .45938 .21273 .47023 .20873 .46406 .2013 Metetra
.952 .6 .262 r
.46406 .2013 .47023 .20873 .48081 .22578 .47394 .26006 Metetra
.772 .445 .432 r
.47394 .26006 .48081 .22578 .4911 .28835 .48451 .30391 Metetra
.792 .42 .352 r
.48451 .30391 .4911 .28835 .50209 .3262 .49562 .33211 Metetra
.785 .345 .204 r
.49562 .33211 .50209 .3262 .51349 .34936 .50707 .35009 Metetra
.702 .171 0 r
.50707 .35009 .51349 .34936 .52513 .36357 .51874 .3614 Metetra
.45 0 0 r
.51874 .3614 .52513 .36357 .53694 .37217 .53057 .36829 Metetra
0 .451 .816 r
.53057 .36829 .53694 .37217 .54886 .37712 .54252 .37221 Metetra
.205 .619 .95 r
.54252 .37221 .54886 .37712 .56087 .37965 .55456 .37407 Metetra
.364 .691 .981 r
.55456 .37407 .56087 .37965 .57296 .38052 .56667 .3745 Metetra
.454 .723 .983 r
.56667 .3745 .57296 .38052 .58512 .38022 .57886 .3739 Metetra
.508 .739 .977 r
.57886 .3739 .58512 .38022 .59734 .37909 .59111 .37254 Metetra
.543 .748 .971 r
.59111 .37254 .59734 .37909 .60962 .37735 .60342 .37063 Metetra
.566 .753 .966 r
.60342 .37063 .60962 .37735 .62196 .37514 .61579 .36829 Metetra
.583 .757 .961 r
.61579 .36829 .62196 .37514 .63435 .37259 .62822 .36563 Metetra
.595 .759 .957 r
.62822 .36563 .63435 .37259 .64681 .36977 .64071 .36271 Metetra
.604 .761 .954 r
.64071 .36271 .64681 .36977 .65932 .36674 .65325 .35959 Metetra
.61 .762 .951 r
.65325 .35959 .65932 .36674 .67188 .36353 .66585 .3563 Metetra
.616 .762 .949 r
.66585 .3563 .67188 .36353 .6845 .36018 .67851 .35288 Metetra
.62 .763 .948 r
.67851 .35288 .6845 .36018 .69718 .35671 .69123 .34935 Metetra
.623 .763 .946 r
.69123 .34935 .69718 .35671 .70992 .35315 .70401 .34572 Metetra
.626 .763 .945 r
.70401 .34572 .70992 .35315 .72271 .3495 .71684 .342 Metetra
.628 .763 .944 r
.71684 .342 .72271 .3495 .73557 .34577 .72973 .33821 Metetra
.63 .763 .943 r
.72973 .33821 .73557 .34577 .74848 .34198 .74268 .33436 Metetra
.632 .763 .942 r
.74268 .33436 .74848 .34198 .76145 .33812 .75569 .33045 Metetra
.633 .763 .941 r
.75569 .33045 .76145 .33812 .77448 .33421 .76876 .32649 Metetra
.659 .77 .932 r
.08104 .54439 .08868 .55042 .0989 .54675 .09128 .54071 Metetra
.66 .771 .932 r
.09128 .54071 .0989 .54675 .10917 .54304 .10157 .53699 Metetra
.661 .772 .932 r
.10157 .53699 .10917 .54304 .11948 .53927 .1119 .53323 Metetra
.663 .773 .931 r
.1119 .53323 .11948 .53927 .12983 .53545 .12228 .5294 Metetra
.665 .775 .931 r
.12228 .5294 .12983 .53545 .14023 .53156 .1327 .52551 Metetra
.667 .776 .931 r
.1327 .52551 .14023 .53156 .15068 .52759 .14316 .52154 Metetra
.67 .778 .93 r
.14316 .52154 .15068 .52759 .16117 .52353 .15368 .51749 Metetra
.674 .779 .929 r
.15368 .51749 .16117 .52353 .17171 .51936 .16424 .51334 Metetra
.678 .782 .928 r
.16424 .51334 .17171 .51936 .1823 .51507 .17486 .50907 Metetra
.683 .784 .927 r
.17486 .50907 .1823 .51507 .19295 .51062 .18552 .50464 Metetra
.689 .787 .925 r
.18552 .50464 .19295 .51062 .20364 .50597 .19625 .50004 Metetra
.697 .791 .923 r
.19625 .50004 .20364 .50597 .2144 .50107 .20702 .4952 Metetra
.706 .796 .92 r
.20702 .4952 .2144 .50107 .22522 .49586 .21786 .49008 Metetra
.718 .801 .916 r
.21786 .49008 .22522 .49586 .23611 .49023 .22877 .48458 Metetra
.733 .809 .911 r
.22877 .48458 .23611 .49023 .24707 .48405 .23975 .47859 Metetra
.752 .818 .904 r
.23975 .47859 .24707 .48405 .25812 .47713 .25081 .47195 Metetra
.775 .829 .894 r
.25081 .47195 .25812 .47713 .26927 .46919 .26197 .46445 Metetra
.804 .843 .88 r
.26197 .46445 .26927 .46919 .28054 .45983 .27323 .45575 Metetra
.838 .859 .86 r
.27323 .45575 .28054 .45983 .29197 .44844 .28463 .44541 Metetra
.878 .879 .831 r
.28463 .44541 .29197 .44844 .30359 .4341 .29619 .43276 Metetra
.92 .899 .789 r
.29619 .43276 .30359 .4341 .31546 .41537 .30796 .41685 Metetra
.958 .918 .728 r
.30796 .41685 .31546 .41537 .32769 .38999 .31998 .39627 Metetra
.975 .924 .633 r
.31998 .39627 .32769 .38999 .34041 .35442 .33234 .36908 Metetra
.933 .891 .483 r
.33234 .36908 .34041 .35442 .35382 .30321 .34511 .33271 Metetra
.755 .758 .246 r
.34511 .33271 .35382 .30321 .36772 .23701 .35834 .28437 Metetra
.35834 .28437 .36772 .23701 .37826 .23311 .37183 .22586 Metetra
.664 .741 .907 r
.37183 .22586 .37826 .23311 .38884 .22919 .38243 .22191 Metetra
.664 .741 .907 r
.38243 .22191 .38884 .22919 .39945 .22525 .39307 .21794 Metetra
.664 .741 .907 r
.39307 .21794 .39945 .22525 .41011 .2213 .40376 .21396 Metetra
.664 .741 .907 r
.40376 .21396 .41011 .2213 .42082 .21733 .41449 .20996 Metetra
.664 .741 .907 r
.41449 .20996 .42082 .21733 .43156 .21335 .42526 .20595 Metetra
.664 .741 .907 r
.42526 .20595 .43156 .21335 .44235 .20935 .43608 .20192 Metetra
.664 .741 .907 r
.43608 .20192 .44235 .20935 .45318 .20533 .44694 .19788 Metetra
.946 .585 .239 r
.44694 .19788 .45318 .20533 .46406 .2013 .45662 .24874 Metetra
.724 .411 .449 r
.45662 .24874 .46406 .2013 .47394 .26006 .46693 .28955 Metetra
.731 .393 .408 r
.46693 .28955 .47394 .26006 .48451 .30391 .47779 .31842 Metetra
.744 .357 .318 r
.47779 .31842 .48451 .30391 .49562 .33211 .48904 .33812 Metetra
.726 .264 .153 r
.48904 .33812 .49562 .33211 .50707 .35009 .50056 .35119 Metetra
.621 .065 0 r
.50056 .35119 .50707 .35009 .51874 .3614 .51228 .35959 Metetra
.345 0 0 r
.51228 .35959 .51874 .3614 .53057 .36829 .52414 .3647 Metetra
.01 .528 .859 r
.52414 .3647 .53057 .36829 .54252 .37221 .53612 .36749 Metetra
.256 .66 .965 r
.53612 .36749 .54252 .37221 .55456 .37407 .54818 .36862 Metetra
.394 .713 .987 r
.54818 .36862 .55456 .37407 .56667 .3745 .56033 .36855 Metetra
.472 .736 .985 r
.56033 .36855 .56667 .3745 .57886 .3739 .57254 .3676 Metetra
.52 .747 .978 r
.57254 .3676 .57886 .3739 .59111 .37254 .58482 .36599 Metetra
.551 .753 .971 r
.58482 .36599 .59111 .37254 .60342 .37063 .59717 .36388 Metetra
.572 .757 .965 r
.59717 .36388 .60342 .37063 .61579 .36829 .60957 .36139 Metetra
.587 .759 .96 r
.60957 .36139 .61579 .36829 .62822 .36563 .62204 .35861 Metetra
.598 .761 .957 r
.62204 .35861 .62822 .36563 .64071 .36271 .63456 .35558 Metetra
.606 .762 .953 r
.63456 .35558 .64071 .36271 .65325 .35959 .64714 .35237 Metetra
.613 .762 .951 r
.64714 .35237 .65325 .35959 .66585 .3563 .65978 .349 Metetra
.618 .763 .949 r
.65978 .349 .66585 .3563 .67851 .35288 .67247 .34551 Metetra
.621 .763 .947 r
.67247 .34551 .67851 .35288 .69123 .34935 .68523 .3419 Metetra
.625 .763 .945 r
.68523 .3419 .69123 .34935 .70401 .34572 .69804 .33821 Metetra
.627 .763 .944 r
.69804 .33821 .70401 .34572 .71684 .342 .71091 .33443 Metetra
.629 .763 .943 r
.71091 .33443 .71684 .342 .72973 .33821 .72384 .33058 Metetra
.631 .763 .942 r
.72384 .33058 .72973 .33821 .74268 .33436 .73683 .32667 Metetra
.633 .763 .941 r
.73683 .32667 .74268 .33436 .75569 .33045 .74988 .32271 Metetra
.634 .763 .941 r
.74988 .32271 .75569 .33045 .76876 .32649 .76299 .31869 Metetra
.658 .77 .932 r
.07334 .53831 .08104 .54439 .09128 .54071 .0836 .53462 Metetra
.659 .771 .932 r
.0836 .53462 .09128 .54071 .10157 .53699 .09391 .5309 Metetra
.66 .772 .932 r
.09391 .5309 .10157 .53699 .1119 .53323 .10426 .52712 Metetra
.662 .773 .932 r
.10426 .52712 .1119 .53323 .12228 .5294 .11466 .52329 Metetra
.664 .774 .931 r
.11466 .52329 .12228 .5294 .1327 .52551 .1251 .5194 Metetra
.666 .775 .931 r
.1251 .5194 .1327 .52551 .14316 .52154 .13559 .51544 Metetra
.669 .777 .93 r
.13559 .51544 .14316 .52154 .15368 .51749 .14613 .5114 Metetra
.672 .779 .93 r
.14613 .5114 .15368 .51749 .16424 .51334 .15672 .50726 Metetra
.676 .781 .929 r
.15672 .50726 .16424 .51334 .17486 .50907 .16736 .50301 Metetra
.68 .784 .928 r
.16736 .50301 .17486 .50907 .18552 .50464 .17804 .49862 Metetra
.686 .787 .927 r
.17804 .49862 .18552 .50464 .19625 .50004 .18879 .49406 Metetra
.693 .79 .925 r
.18879 .49406 .19625 .50004 .20702 .4952 .19959 .4893 Metetra
.702 .795 .923 r
.19959 .4893 .20702 .4952 .21786 .49008 .21045 .48427 Metetra
.713 .801 .92 r
.21045 .48427 .21786 .49008 .22877 .48458 .22137 .47891 Metetra
.726 .809 .916 r
.22137 .47891 .22877 .48458 .23975 .47859 .23236 .47313 Metetra
.743 .818 .911 r
.23236 .47313 .23975 .47859 .25081 .47195 .24343 .4668 Metetra
.764 .83 .904 r
.24343 .4668 .25081 .47195 .26197 .46445 .25459 .45974 Metetra
.79 .846 .894 r
.25459 .45974 .26197 .46445 .27323 .45575 .26585 .45172 Metetra
.821 .866 .88 r
.26585 .45172 .27323 .45575 .28463 .44541 .27722 .44241 Metetra
.857 .89 .86 r
.27722 .44241 .28463 .44541 .29619 .43276 .28872 .43138 Metetra
.897 .919 .828 r
.28872 .43138 .29619 .43276 .30796 .41685 .30038 .41801 Metetra
.932 .948 .776 r
.30038 .41801 .30796 .41685 .31998 .39627 .31223 .40152 Metetra
.94 .962 .683 r
.31223 .40152 .31998 .39627 .33234 .36908 .32429 .38094 Metetra
.862 .912 .509 r
.32429 .38094 .33234 .36908 .34511 .33271 .33659 .35525 Metetra
.33659 .35525 .34511 .33271 .35834 .28437 .34911 .32375 Metetra
0 0 .087 r
.34911 .32375 .35834 .28437 .37183 .22586 .36177 .28688 Metetra
.066 0 .274 r
.36177 .28688 .37183 .22586 .38243 .22191 .37436 .24752 Metetra
.37436 .24752 .38243 .22191 .39307 .21794 .38658 .21198 Metetra
.717 .8 .917 r
.38658 .21198 .39307 .21794 .40376 .21396 .39736 .20657 Metetra
.664 .741 .907 r
.39736 .20657 .40376 .21396 .41449 .20996 .40812 .20254 Metetra
.607 .72 .925 r
.40812 .20254 .41449 .20996 .42526 .20595 .41887 .1999 Metetra
.894 .477 .095 r
.41887 .1999 .42526 .20595 .43608 .20192 .42872 .2275 Metetra
.76 .418 .406 r
.42872 .2275 .43608 .20192 .44694 .19788 .43873 .25903 Metetra
.653 .355 .453 r
.43873 .25903 .44694 .19788 .45662 .24874 .44909 .28818 Metetra
.674 .353 .422 r
.44909 .28818 .45662 .24874 .46693 .28955 .45986 .31203 Metetra
.692 .333 .362 r
.45986 .31203 .46693 .28955 .47779 .31842 .47097 .3301 Metetra
.693 .277 .252 r
.47097 .3301 .47779 .31842 .48904 .33812 .48236 .34308 Metetra
.652 .153 .053 r
.48236 .34308 .48904 .33812 .50056 .35119 .49397 .35196 Metetra
.502 0 0 r
.49397 .35196 .50056 .35119 .51228 .35959 .50574 .35773 Metetra
.196 0 0 r
.50574 .35773 .51228 .35959 .52414 .3647 .51764 .36115 Metetra
.117 .609 .909 r
.51764 .36115 .52414 .3647 .53612 .36749 .52965 .36283 Metetra
.316 .7 .98 r
.52965 .36283 .53612 .36749 .54818 .36862 .54175 .36321 Metetra
.427 .734 .991 r
.54175 .36321 .54818 .36862 .56033 .36855 .55392 .36262 Metetra
.492 .748 .986 r
.55392 .36262 .56033 .36855 .57254 .3676 .56617 .3613 Metetra
.533 .755 .978 r
.56617 .3613 .57254 .3676 .58482 .36599 .57848 .35941 Metetra
.56 .758 .971 r
.57848 .35941 .58482 .36599 .59717 .36388 .59086 .3571 Metetra
.578 .76 .965 r
.59086 .3571 .59717 .36388 .60957 .36139 .6033 .35445 Metetra
.592 .761 .96 r
.6033 .35445 .60957 .36139 .62204 .35861 .6158 .35153 Metetra
.601 .762 .956 r
.6158 .35153 .62204 .35861 .63456 .35558 .62835 .34839 Metetra
.609 .763 .953 r
.62835 .34839 .63456 .35558 .64714 .35237 .64097 .34508 Metetra
.615 .763 .95 r
.64097 .34508 .64714 .35237 .65978 .349 .65364 .34163 Metetra
.619 .763 .948 r
.65364 .34163 .65978 .349 .67247 .34551 .66638 .33806 Metetra
.623 .763 .946 r
.66638 .33806 .67247 .34551 .68523 .3419 .67917 .33438 Metetra
.626 .763 .945 r
.67917 .33438 .68523 .3419 .69804 .33821 .69202 .33062 Metetra
.628 .763 .944 r
.69202 .33062 .69804 .33821 .71091 .33443 .70493 .32678 Metetra
.63 .763 .943 r
.70493 .32678 .71091 .33443 .72384 .33058 .7179 .32287 Metetra
.632 .763 .942 r
.7179 .32287 .72384 .33058 .73683 .32667 .73093 .31891 Metetra
.634 .763 .941 r
.73093 .31891 .73683 .32667 .74988 .32271 .74402 .31488 Metetra
.635 .763 .94 r
.74402 .31488 .74988 .32271 .76299 .31869 .75718 .31081 Metetra
.657 .77 .932 r
.06558 .53217 .07334 .53831 .0836 .53462 .07586 .52848 Metetra
.658 .77 .932 r
.07586 .52848 .0836 .53462 .09391 .5309 .08619 .52475 Metetra
.66 .771 .932 r
.08619 .52475 .09391 .5309 .10426 .52712 .09657 .52097 Metetra
.661 .772 .932 r
.09657 .52097 .10426 .52712 .11466 .52329 .10699 .51713 Metetra
.663 .773 .932 r
.10699 .51713 .11466 .52329 .1251 .5194 .11745 .51324 Metetra
.665 .775 .931 r
.11745 .51324 .1251 .5194 .13559 .51544 .12797 .50929 Metetra
.667 .776 .931 r
.12797 .50929 .13559 .51544 .14613 .5114 .13853 .50525 Metetra
.67 .778 .93 r
.13853 .50525 .14613 .5114 .15672 .50726 .14914 .50113 Metetra
.674 .78 .93 r
.14914 .50113 .15672 .50726 .16736 .50301 .15979 .4969 Metetra
.678 .783 .929 r
.15979 .4969 .16736 .50301 .17804 .49862 .17051 .49255 Metetra
.683 .786 .928 r
.17051 .49255 .17804 .49862 .18879 .49406 .18127 .48804 Metetra
.69 .79 .927 r
.18127 .48804 .18879 .49406 .19959 .4893 .19209 .48335 Metetra
.697 .794 .925 r
.19209 .48335 .19959 .4893 .21045 .48427 .20297 .47842 Metetra
.707 .8 .923 r
.20297 .47842 .21045 .48427 .22137 .47891 .21391 .47321 Metetra
.719 .808 .92 r
.21391 .47321 .22137 .47891 .23236 .47313 .22491 .46764 Metetra
.733 .818 .917 r
.22491 .46764 .23236 .47313 .24343 .4668 .23599 .46161 Metetra
.751 .83 .913 r
.23599 .46161 .24343 .4668 .25459 .45974 .24715 .45499 Metetra
.773 .846 .907 r
.24715 .45499 .25459 .45974 .26585 .45172 .25839 .44762 Metetra
.8 .867 .898 r
.25839 .44762 .26585 .45172 .27722 .44241 .26974 .43926 Metetra
.831 .894 .885 r
.26974 .43926 .27722 .44241 .28872 .43138 .28119 .42965 Metetra
.865 .927 .865 r
.28119 .42965 .28872 .43138 .30038 .41801 .29276 .41842 Metetra
.895 .963 .828 r
.29276 .41842 .30038 .41801 .31223 .40152 .30446 .40518 Metetra
.897 .987 .751 r
.30446 .40518 .31223 .40152 .32429 .38094 .31631 .38949 Metetra
.807 .941 .583 r
.31631 .38949 .32429 .38094 .33659 .35525 .32829 .37105 Metetra
.32829 .37105 .33659 .35525 .34911 .32375 .34038 .3499 Metetra
0 0 .029 r
.34038 .3499 .34911 .32375 .36177 .28688 .3525 .32681 Metetra
.115 0 .238 r
.3525 .32681 .36177 .28688 .37436 .24752 .36453 .30369 Metetra
.297 .043 .349 r
.36453 .30369 .37436 .24752 .38658 .21198 .37632 .28369 Metetra
.409 .149 .406 r
.37632 .28369 .38658 .21198 .39736 .20657 .38775 .27042 Metetra
.47 .196 .415 r
.38775 .27042 .39736 .20657 .40812 .20254 .39879 .26641 Metetra
.533 .25 .431 r
.39879 .26641 .40812 .20254 .41887 .1999 .40952 .27169 Metetra
.566 .283 .445 r
.40952 .27169 .41887 .1999 .42872 .2275 .42013 .28376 Metetra
.596 .298 .435 r
.42013 .28376 .42872 .2275 .43873 .25903 .43081 .29901 Metetra
.621 .302 .41 r
.43081 .29901 .43873 .25903 .44909 .28818 .44167 .3143 Metetra
.639 .29 .364 r
.44167 .3143 .44909 .28818 .45986 .31203 .45276 .32771 Metetra
.645 .251 .283 r
.45276 .32771 .45986 .31203 .47097 .3301 .46409 .33843 Metetra
.625 .164 .138 r
.46409 .33843 .47097 .3301 .48236 .34308 .47561 .34642 Metetra
.54 0 0 r
.47561 .34642 .48236 .34308 .49397 .35196 .4873 .35197 Metetra
.328 0 0 r
.4873 .35197 .49397 .35196 .50574 .35773 .49913 .35551 Metetra
0 .54 .805 r
.49913 .35551 .50574 .35773 .51764 .36115 .51108 .35742 Metetra
.229 .68 .952 r
.51108 .35742 .51764 .36115 .52965 .36283 .52312 .35808 Metetra
.377 .733 .99 r
.52312 .35808 .52965 .36283 .54175 .36321 .53525 .35774 Metetra
.462 .752 .992 r
.53525 .35774 .54175 .36321 .55392 .36262 .54746 .35664 Metetra
.513 .759 .985 r
.54746 .35664 .55392 .36262 .56617 .3613 .55974 .35495 Metetra
.546 .761 .977 r
.55974 .35495 .56617 .3613 .57848 .35941 .57209 .35279 Metetra
.569 .763 .97 r
.57209 .35279 .57848 .35941 .59086 .3571 .5845 .35026 Metetra
.585 .763 .964 r
.5845 .35026 .59086 .3571 .6033 .35445 .59697 .34744 Metetra
.596 .763 .959 r
.59697 .34744 .6033 .35445 .6158 .35153 .6095 .34439 Metetra
.605 .764 .955 r
.6095 .34439 .6158 .35153 .62835 .34839 .6221 .34114 Metetra
.612 .764 .952 r
.6221 .34114 .62835 .34839 .64097 .34508 .63475 .33773 Metetra
.617 .764 .95 r
.63475 .33773 .64097 .34508 .65364 .34163 .64746 .33419 Metetra
.621 .764 .948 r
.64746 .33419 .65364 .34163 .66638 .33806 .66023 .33054 Metetra
.625 .764 .946 r
.66023 .33054 .66638 .33806 .67917 .33438 .67306 .32679 Metetra
.627 .764 .944 r
.67306 .32679 .67917 .33438 .69202 .33062 .68595 .32296 Metetra
.63 .764 .943 r
.68595 .32296 .69202 .33062 .70493 .32678 .6989 .31906 Metetra
.631 .763 .942 r
.6989 .31906 .70493 .32678 .7179 .32287 .71191 .31509 Metetra
.633 .763 .941 r
.71191 .31509 .7179 .32287 .73093 .31891 .72498 .31107 Metetra
.634 .763 .941 r
.72498 .31107 .73093 .31891 .74402 .31488 .73812 .30699 Metetra
.636 .763 .94 r
.73812 .30699 .74402 .31488 .75718 .31081 .75131 .30286 Metetra
.657 .769 .932 r
.05776 .52598 .06558 .53217 .07586 .52848 .06807 .52228 Metetra
.658 .77 .932 r
.06807 .52228 .07586 .52848 .08619 .52475 .07842 .51854 Metetra
.659 .771 .932 r
.07842 .51854 .08619 .52475 .09657 .52097 .08882 .51475 Metetra
.66 .772 .932 r
.08882 .51475 .09657 .52097 .10699 .51713 .09926 .51092 Metetra
.662 .773 .932 r
.09926 .51092 .10699 .51713 .11745 .51324 .10975 .50703 Metetra
.664 .774 .932 r
.10975 .50703 .11745 .51324 .12797 .50929 .12028 .50307 Metetra
.666 .776 .931 r
.12028 .50307 .12797 .50929 .13853 .50525 .13086 .49905 Metetra
.669 .777 .931 r
.13086 .49905 .13853 .50525 .14914 .50113 .14149 .49494 Metetra
.672 .78 .931 r
.14149 .49494 .14914 .50113 .15979 .4969 .15218 .49074 Metetra
.676 .782 .93 r
.15218 .49074 .15979 .4969 .17051 .49255 .16291 .48642 Metetra
.68 .785 .929 r
.16291 .48642 .17051 .49255 .18127 .48804 .17369 .48196 Metetra
.686 .789 .928 r
.17369 .48196 .18127 .48804 .19209 .48335 .18453 .47734 Metetra
.693 .793 .927 r
.18453 .47734 .19209 .48335 .20297 .47842 .19543 .47252 Metetra
.701 .799 .926 r
.19543 .47252 .20297 .47842 .21391 .47321 .20638 .46746 Metetra
.711 .807 .924 r
.20638 .46746 .21391 .47321 .22491 .46764 .2174 .46209 Metetra
.723 .816 .923 r
.2174 .46209 .22491 .46764 .23599 .46161 .22849 .45635 Metetra
.738 .828 .92 r
.22849 .45635 .23599 .46161 .24715 .45499 .23965 .45014 Metetra
.756 .844 .917 r
.23965 .45014 .24715 .45499 .25839 .44762 .25088 .44334 Metetra
.778 .864 .913 r
.25088 .44334 .25839 .44762 .26974 .43926 .2622 .43582 Metetra
.803 .89 .907 r
.2622 .43582 .26974 .43926 .28119 .42965 .27361 .4274 Metetra
.83 .924 .896 r
.27361 .4274 .28119 .42965 .29276 .41842 .28511 .4179 Metetra
.853 .963 .874 r
.28511 .4179 .29276 .41842 .30446 .40518 .29672 .40712 Metetra
.854 .996 .823 r
.29672 .40712 .30446 .40518 .31631 .38949 .30841 .39491 Metetra
.78 .976 .696 r
.30841 .39491 .31631 .38949 .32829 .37105 .32019 .38125 Metetra
.32019 .38125 .32829 .37105 .34038 .3499 .33202 .36639 Metetra
.33202 .36639 .34038 .3499 .3525 .32681 .34385 .35096 Metetra
.072 0 .121 r
.34385 .35096 .3525 .32681 .36453 .30369 .35562 .33611 Metetra
.257 0 .259 r
.35562 .33611 .36453 .30369 .37632 .28369 .36725 .32344 Metetra
.373 .08 .333 r
.36725 .32344 .37632 .28369 .38775 .27042 .37869 .31458 Metetra
.447 .153 .371 r
.37869 .31458 .38775 .27042 .39879 .26641 .38993 .31058 Metetra
.498 .197 .386 r
.38993 .31058 .39879 .26641 .40952 .27169 .40102 .31147 Metetra
.535 .223 .385 r
.40102 .31147 .40952 .27169 .42013 .28376 .41206 .31619 Metetra
.563 .233 .368 r
.41206 .31619 .42013 .28376 .43081 .29901 .42314 .32313 Metetra
.581 .226 .331 r
.42314 .32313 .43081 .29901 .44167 .3143 .43433 .3307 Metetra
.588 .194 .264 r
.43433 .3307 .44167 .3143 .45276 .32771 .44566 .33774 Metetra
.574 .125 .147 r
.44566 .33774 .45276 .32771 .46409 .33843 .45715 .34359 Metetra
.514 0 0 r
.45715 .34359 .46409 .33843 .47561 .34642 .46879 .34802 Metetra
.363 0 0 r
.46879 .34802 .47561 .34642 .4873 .35197 .48056 .35102 Metetra
.104 0 0 r
.48056 .35102 .4873 .35197 .49913 .35551 .49245 .35276 Metetra
.155 .66 .906 r
.49245 .35276 .49913 .35551 .51108 .35742 .50444 .3534 Metetra
.33 .733 .981 r
.50444 .3534 .51108 .35742 .52312 .35808 .51653 .35314 Metetra
.433 .758 .995 r
.51653 .35314 .52312 .35808 .53525 .35774 .5287 .35216 Metetra
.494 .765 .991 r
.5287 .35216 .53525 .35774 .54746 .35664 .54094 .35058 Metetra
.534 .767 .983 r
.54094 .35058 .54746 .35664 .55974 .35495 .55325 .34853 Metetra
.56 .767 .975 r
.55325 .34853 .55974 .35495 .57209 .35279 .56563 .3461 Metetra
.578 .766 .968 r
.56563 .3461 .57209 .35279 .5845 .35026 .57808 .34336 Metetra
.591 .766 .962 r
.57808 .34336 .5845 .35026 .59697 .34744 .59059 .34037 Metetra
.601 .765 .958 r
.59059 .34037 .59697 .34744 .6095 .34439 .60315 .33718 Metetra
.609 .765 .954 r
.60315 .33718 .6095 .34439 .6221 .34114 .61578 .33381 Metetra
.615 .765 .951 r
.61578 .33381 .6221 .34114 .63475 .33773 .62847 .3303 Metetra
.619 .764 .949 r
.62847 .3303 .63475 .33773 .64746 .33419 .64122 .32667 Metetra
.623 .764 .947 r
.64122 .32667 .64746 .33419 .66023 .33054 .65403 .32294 Metetra
.626 .764 .945 r
.65403 .32294 .66023 .33054 .67306 .32679 .6669 .31912 Metetra
.629 .764 .944 r
.6669 .31912 .67306 .32679 .68595 .32296 .67983 .31523 Metetra
.631 .764 .943 r
.67983 .31523 .68595 .32296 .6989 .31906 .69282 .31126 Metetra
.632 .764 .942 r
.69282 .31126 .6989 .31906 .71191 .31509 .70587 .30723 Metetra
.634 .763 .941 r
.70587 .30723 .71191 .31509 .72498 .31107 .71898 .30315 Metetra
.635 .763 .94 r
.71898 .30315 .72498 .31107 .73812 .30699 .73215 .29902 Metetra
.636 .763 .94 r
.73215 .29902 .73812 .30699 .75131 .30286 .74539 .29484 Metetra
.656 .769 .933 r
.04988 .51975 .05776 .52598 .06807 .52228 .06021 .51603 Metetra
.657 .77 .933 r
.06021 .51603 .06807 .52228 .07842 .51854 .07058 .51228 Metetra
.658 .771 .932 r
.07058 .51228 .07842 .51854 .08882 .51475 .081 .50849 Metetra
.659 .771 .932 r
.081 .50849 .08882 .51475 .09926 .51092 .09147 .50465 Metetra
.661 .773 .932 r
.09147 .50465 .09926 .51092 .10975 .50703 .10198 .50075 Metetra
.663 .774 .932 r
.10198 .50075 .10975 .50703 .12028 .50307 .11254 .4968 Metetra
.665 .775 .932 r
.11254 .4968 .12028 .50307 .13086 .49905 .12314 .49279 Metetra
.667 .777 .932 r
.12314 .49279 .13086 .49905 .14149 .49494 .13379 .48869 Metetra
.67 .779 .931 r
.13379 .48869 .14149 .49494 .15218 .49074 .1445 .48451 Metetra
.673 .781 .931 r
.1445 .48451 .15218 .49074 .16291 .48642 .15525 .48023 Metetra
.677 .784 .93 r
.15525 .48023 .16291 .48642 .17369 .48196 .16605 .47582 Metetra
.682 .788 .93 r
.16605 .47582 .17369 .48196 .18453 .47734 .17691 .47127 Metetra
.688 .792 .929 r
.17691 .47127 .18453 .47734 .19543 .47252 .18783 .46656 Metetra
.695 .797 .929 r
.18783 .46656 .19543 .47252 .20638 .46746 .1988 .46163 Metetra
.703 .804 .928 r
.1988 .46163 .20638 .46746 .2174 .46209 .20983 .45645 Metetra
.713 .813 .927 r
.20983 .45645 .2174 .46209 .22849 .45635 .22092 .45097 Metetra
.725 .824 .926 r
.22092 .45097 .22849 .45635 .23965 .45014 .23208 .44513 Metetra
.74 .839 .925 r
.23208 .44513 .23965 .45014 .25088 .44334 .24331 .43884 Metetra
.757 .857 .924 r
.24331 .43884 .25088 .44334 .2622 .43582 .25462 .43202 Metetra
.776 .881 .923 r
.25462 .43202 .2622 .43582 .27361 .4274 .266 .42457 Metetra
.796 .912 .919 r
.266 .42457 .27361 .4274 .28511 .4179 .27745 .4164 Metetra
.812 .949 .91 r
.27745 .4164 .28511 .4179 .29672 .40712 .28898 .40744 Metetra
.814 .986 .884 r
.28898 .40744 .29672 .40712 .30841 .39491 .30058 .39765 Metetra
.767 .996 .812 r
.30058 .39765 .30841 .39491 .32019 .38125 .31223 .38713 Metetra
.611 .911 .639 r
.31223 .38713 .32019 .38125 .33202 .36639 .32392 .3761 Metetra
.32392 .3761 .33202 .36639 .34385 .35096 .33561 .36502 Metetra
.33561 .36502 .34385 .35096 .35562 .33611 .34726 .35458 Metetra
.165 0 .095 r
.34726 .35458 .35562 .33611 .36725 .32344 .35883 .3456 Metetra
.299 0 .2 r
.35883 .3456 .36725 .32344 .37869 .31458 .37031 .33887 Metetra
.385 .042 .256 r
.37031 .33887 .37869 .31458 .38993 .31058 .38169 .33487 Metetra
.442 .094 .278 r
.38169 .33487 .38993 .31058 .40102 .31147 .393 .33361 Metetra
.48 .119 .276 r
.393 .33361 .40102 .31147 .41206 .31619 .4043 .33461 Metetra
.503 .121 .248 r
.4043 .33461 .41206 .31619 .42314 .32313 .41563 .33711 Metetra
.511 .097 .19 r
.41563 .33711 .42314 .32313 .43433 .3307 .42703 .34026 Metetra
.497 .036 .087 r
.42703 .34026 .43433 .3307 .44566 .33774 .43854 .3434 Metetra
.444 0 0 r
.43854 .3434 .44566 .33774 .45715 .34359 .45016 .34605 Metetra
.32 0 0 r
.45016 .34605 .45715 .34359 .46879 .34802 .4619 .34797 Metetra
.11 0 0 r
.4619 .34797 .46879 .34802 .48056 .35102 .47375 .34908 Metetra
.124 .655 .866 r
.47375 .34908 .48056 .35102 .49245 .35276 .4857 .3494 Metetra
.301 .738 .967 r
.4857 .3494 .49245 .35276 .50444 .3534 .49774 .349 Metetra
.412 .766 .995 r
.49774 .349 .50444 .3534 .51653 .35314 .50987 .34797 Metetra
.48 .774 .996 r
.50987 .34797 .51653 .35314 .5287 .35216 .52208 .34641 Metetra
.523 .774 .989 r
.52208 .34641 .5287 .35216 .54094 .35058 .53436 .3444 Metetra
.552 .772 .98 r
.53436 .3444 .54094 .35058 .55325 .34853 .54671 .34201 Metetra
.572 .771 .973 r
.54671 .34201 .55325 .34853 .56563 .3461 .55912 .33933 Metetra
.587 .769 .966 r
.55912 .33933 .56563 .3461 .57808 .34336 .5716 .33638 Metetra
.598 .768 .961 r
.5716 .33638 .57808 .34336 .59059 .34037 .58415 .33323 Metetra
.606 .767 .957 r
.58415 .33323 .59059 .34037 .60315 .33718 .59675 .32989 Metetra
.612 .766 .953 r
.59675 .32989 .60315 .33718 .61578 .33381 .60942 .32641 Metetra
.618 .765 .95 r
.60942 .32641 .61578 .33381 .62847 .3303 .62214 .3228 Metetra
.622 .765 .948 r
.62214 .3228 .62847 .3303 .64122 .32667 .63493 .31908 Metetra
.625 .765 .946 r
.63493 .31908 .64122 .32667 .65403 .32294 .64778 .31527 Metetra
.628 .764 .945 r
.64778 .31527 .65403 .32294 .6669 .31912 .66069 .31138 Metetra
.63 .764 .943 r
.66069 .31138 .6669 .31912 .67983 .31523 .67365 .30742 Metetra
.632 .764 .942 r
.67365 .30742 .67983 .31523 .69282 .31126 .68668 .30339 Metetra
.633 .764 .941 r
.68668 .30339 .69282 .31126 .70587 .30723 .69978 .2993 Metetra
.635 .764 .941 r
.69978 .2993 .70587 .30723 .71898 .30315 .71293 .29516 Metetra
.636 .763 .94 r
.71293 .29516 .71898 .30315 .73215 .29902 .72614 .29097 Metetra
.637 .763 .939 r
.72614 .29097 .73215 .29902 .74539 .29484 .73942 .28674 Metetra
.655 .769 .933 r
.04194 .51345 .04988 .51975 .06021 .51603 .05229 .50973 Metetra
.656 .769 .933 r
.05229 .50973 .06021 .51603 .07058 .51228 .06269 .50597 Metetra
.657 .77 .933 r
.06269 .50597 .07058 .51228 .081 .50849 .07313 .50216 Metetra
.658 .771 .933 r
.07313 .50216 .081 .50849 .09147 .50465 .08362 .49832 Metetra
.66 .772 .932 r
.08362 .49832 .09147 .50465 .10198 .50075 .09415 .49442 Metetra
.661 .773 .932 r
.09415 .49442 .10198 .50075 .11254 .4968 .10473 .49047 Metetra
.663 .775 .932 r
.10473 .49047 .11254 .4968 .12314 .49279 .11536 .48646 Metetra
.665 .776 .932 r
.11536 .48646 .12314 .49279 .13379 .48869 .12603 .48238 Metetra
.668 .778 .932 r
.12603 .48238 .13379 .48869 .1445 .48451 .13676 .47823 Metetra
.671 .78 .932 r
.13676 .47823 .1445 .48451 .15525 .48023 .14753 .47397 Metetra
.674 .783 .931 r
.14753 .47397 .15525 .48023 .16605 .47582 .15836 .46962 Metetra
.678 .786 .931 r
.15836 .46962 .16605 .47582 .17691 .47127 .16923 .46514 Metetra
.683 .79 .931 r
.16923 .46514 .17691 .47127 .18783 .46656 .18017 .46051 Metetra
.689 .795 .931 r
.18017 .46051 .18783 .46656 .1988 .46163 .19115 .45571 Metetra
.696 .802 .931 r
.19115 .45571 .1988 .46163 .20983 .45645 .2022 .45071 Metetra
.704 .81 .931 r
.2022 .45071 .20983 .45645 .22092 .45097 .2133 .44546 Metetra
.714 .82 .931 r
.2133 .44546 .22092 .45097 .23208 .44513 .22447 .43993 Metetra
.725 .833 .931 r
.22447 .43993 .23208 .44513 .24331 .43884 .2357 .43407 Metetra
.737 .849 .932 r
.2357 .43407 .24331 .43884 .25462 .43202 .24699 .42782 Metetra
.751 .87 .934 r
.24699 .42782 .25462 .43202 .266 .42457 .25835 .42114 Metetra
.765 .896 .935 r
.25835 .42114 .266 .42457 .27745 .4164 .26977 .41399 Metetra
.776 .927 .934 r
.26977 .41399 .27745 .4164 .28898 .40744 .28126 .40634 Metetra
.777 .962 .926 r
.28126 .40634 .28898 .40744 .30058 .39765 .2928 .39823 Metetra
.752 .988 .896 r
.2928 .39823 .30058 .39765 .31223 .38713 .30438 .38976 Metetra
.666 .972 .813 r
.30438 .38976 .31223 .38713 .32392 .3761 .31599 .3811 Metetra
.486 .861 .641 r
.31599 .3811 .32392 .3761 .33561 .36502 .32761 .37258 Metetra
.32761 .37258 .33561 .36502 .34726 .35458 .33921 .36458 Metetra
.33921 .36458 .34726 .35458 .35883 .3456 .35077 .35757 Metetra
.154 0 0 r
.35077 .35757 .35883 .3456 .37031 .33887 .3623 .35193 Metetra
.262 0 .042 r
.3623 .35193 .37031 .33887 .38169 .33487 .37378 .34792 Metetra
.331 0 .078 r
.37378 .34792 .38169 .33487 .393 .33361 .38524 .34553 Metetra
.371 0 .073 r
.38524 .34553 .393 .33361 .4043 .33461 .3967 .34453 Metetra
.385 0 .029 r
.3967 .34453 .4043 .33461 .41563 .33711 .4082 .34453 Metetra
.372 0 0 r
.4082 .34453 .41563 .33711 .42703 .34026 .41976 .34508 Metetra
.318 0 0 r
.41976 .34508 .42703 .34026 .43854 .3434 .4314 .34577 Metetra
.208 0 0 r
.4314 .34577 .43854 .3434 .45016 .34605 .44314 .34631 Metetra
.038 0 0 r
.44314 .34631 .45016 .34605 .4619 .34797 .45496 .34648 Metetra
.15 .682 .859 r
.45496 .34648 .4619 .34797 .47375 .34908 .46688 .3462 Metetra
.303 .753 .959 r
.46688 .3462 .47375 .34908 .4857 .3494 .47889 .34543 Metetra
.407 .779 .993 r
.47889 .34543 .4857 .3494 .49774 .349 .49098 .34419 Metetra
.474 .785 .998 r
.49098 .34419 .49774 .349 .50987 .34797 .50315 .34252 Metetra
.518 .783 .993 r
.50315 .34252 .50987 .34797 .52208 .34641 .5154 .34046 Metetra
.547 .78 .985 r
.5154 .34046 .52208 .34641 .53436 .3444 .52772 .33806 Metetra
.568 .776 .977 r
.52772 .33806 .53436 .3444 .54671 .34201 .5401 .33538 Metetra
.583 .773 .97 r
.5401 .33538 .54671 .34201 .55912 .33933 .55255 .33245 Metetra
.595 .771 .964 r
.55255 .33245 .55912 .33933 .5716 .33638 .56507 .32931 Metetra
.604 .769 .959 r
.56507 .32931 .5716 .33638 .58415 .33323 .57765 .32599 Metetra
.611 .768 .955 r
.57765 .32599 .58415 .33323 .59675 .32989 .59029 .32253 Metetra
.616 .767 .952 r
.59029 .32253 .59675 .32989 .60942 .32641 .60299 .31893 Metetra
.62 .766 .949 r
.60299 .31893 .60942 .32641 .62214 .3228 .61576 .31522 Metetra
.624 .766 .947 r
.61576 .31522 .62214 .3228 .63493 .31908 .62858 .31142 Metetra
.627 .765 .946 r
.62858 .31142 .63493 .31908 .64778 .31527 .64147 .30753 Metetra
.629 .765 .944 r
.64147 .30753 .64778 .31527 .66069 .31138 .65442 .30356 Metetra
.631 .764 .943 r
.65442 .30356 .66069 .31138 .67365 .30742 .66743 .29953 Metetra
.633 .764 .942 r
.66743 .29953 .67365 .30742 .68668 .30339 .6805 .29544 Metetra
.634 .764 .941 r
.6805 .29544 .68668 .30339 .69978 .2993 .69363 .29129 Metetra
.635 .764 .94 r
.69363 .29129 .69978 .2993 .71293 .29516 .70682 .28709 Metetra
.636 .764 .94 r
.70682 .28709 .71293 .29516 .72614 .29097 .72008 .28285 Metetra
.637 .763 .939 r
.72008 .28285 .72614 .29097 .73942 .28674 .73339 .27856 Metetra
.655 .768 .933 r
.03395 .50711 .04194 .51345 .05229 .50973 .04432 .50337 Metetra
.656 .769 .933 r
.04432 .50337 .05229 .50973 .06269 .50597 .05474 .4996 Metetra
.656 .77 .933 r
.05474 .4996 .06269 .50597 .07313 .50216 .0652 .49579 Metetra
.658 .771 .933 r
.0652 .49579 .07313 .50216 .08362 .49832 .07571 .49193 Metetra
.659 .772 .933 r
.07571 .49193 .08362 .49832 .09415 .49442 .08627 .48803 Metetra
.66 .773 .933 r
.08627 .48803 .09415 .49442 .10473 .49047 .09687 .48409 Metetra
.662 .774 .933 r
.09687 .48409 .10473 .49047 .11536 .48646 .10752 .48008 Metetra
.664 .775 .932 r
.10752 .48008 .11536 .48646 .12603 .48238 .11821 .47601 Metetra
.666 .777 .932 r
.11821 .47601 .12603 .48238 .13676 .47823 .12896 .47188 Metetra
.668 .779 .932 r
.12896 .47188 .13676 .47823 .14753 .47397 .13975 .46766 Metetra
.671 .782 .932 r
.13975 .46766 .14753 .47397 .15836 .46962 .1506 .46334 Metetra
.675 .785 .932 r
.1506 .46334 .15836 .46962 .16923 .46514 .1615 .45892 Metetra
.679 .789 .932 r
.1615 .45892 .16923 .46514 .18017 .46051 .17245 .45438 Metetra
.684 .793 .932 r
.17245 .45438 .18017 .46051 .19115 .45571 .18345 .44969 Metetra
.689 .799 .933 r
.18345 .44969 .19115 .45571 .2022 .45071 .19451 .44484 Metetra
.696 .806 .933 r
.19451 .44484 .2022 .45071 .2133 .44546 .20563 .43979 Metetra
.703 .815 .934 r
.20563 .43979 .2133 .44546 .22447 .43993 .2168 .43453 Metetra
.711 .826 .936 r
.2168 .43453 .22447 .43993 .2357 .43407 .22803 .42902 Metetra
.721 .839 .938 r
.22803 .42902 .2357 .43407 .24699 .42782 .23932 .42324 Metetra
.73 .857 .941 r
.23932 .42324 .24699 .42782 .25835 .42114 .25067 .41715 Metetra
.739 .878 .944 r
.25067 .41715 .25835 .42114 .26977 .41399 .26208 .41076 Metetra
.746 .903 .947 r
.26208 .41076 .26977 .41399 .28126 .40634 .27354 .40406 Metetra
.747 .932 .949 r
.27354 .40406 .28126 .40634 .2928 .39823 .28504 .39711 Metetra
.734 .96 .942 r
.28504 .39711 .2928 .39823 .30438 .38976 .29659 .38998 Metetra
.691 .974 .915 r
.29659 .38998 .30438 .38976 .31599 .3811 .30816 .38282 Metetra
.6 .951 .848 r
.30816 .38282 .31599 .3811 .32761 .37258 .31975 .37583 Metetra
.45 .867 .725 r
.31975 .37583 .32761 .37258 .33921 .36458 .33134 .36925 Metetra
.33134 .36925 .33921 .36458 .35077 .35757 .34292 .36333 Metetra
.34292 .36333 .35077 .35757 .3623 .35193 .35449 .3583 Metetra
.029 0 0 r
.35449 .3583 .3623 .35193 .37378 .34792 .36605 .35426 Metetra
.11 0 0 r
.36605 .35426 .37378 .34792 .38524 .34553 .37762 .35123 Metetra
.15 0 0 r
.37762 .35123 .38524 .34553 .3967 .34453 .3892 .34909 Metetra
.15 0 0 r
.3892 .34909 .3967 .34453 .4082 .34453 .40082 .34763 Metetra
.108 0 0 r
.40082 .34763 .4082 .34453 .41976 .34508 .4125 .34658 Metetra
.022 0 0 r
.4125 .34658 .41976 .34508 .4314 .34577 .42424 .34572 Metetra
.1 .656 .764 r
.42424 .34572 .4314 .34577 .44314 .34631 .43606 .34484 Metetra
.23 .737 .891 r
.43606 .34484 .44314 .34631 .45496 .34648 .44797 .34379 Metetra
.341 .781 .964 r
.44797 .34379 .45496 .34648 .46688 .3462 .45995 .34248 Metetra
.423 .796 .993 r
.45995 .34248 .46688 .3462 .47889 .34543 .47201 .34089 Metetra
.48 .798 .999 r
.47201 .34089 .47889 .34543 .49098 .34419 .48415 .33898 Metetra
.519 .793 .995 r
.48415 .33898 .49098 .34419 .50315 .34252 .49637 .33677 Metetra
.547 .788 .988 r
.49637 .33677 .50315 .34252 .5154 .34046 .50866 .33429 Metetra
.567 .783 .98 r
.50866 .33429 .5154 .34046 .52772 .33806 .52101 .33156 Metetra
.582 .778 .973 r
.52101 .33156 .52772 .33806 .5401 .33538 .53344 .3286 Metetra
.593 .775 .967 r
.53344 .3286 .5401 .33538 .55255 .33245 .54592 .32545 Metetra
.602 .772 .961 r
.54592 .32545 .55255 .33245 .56507 .32931 .55848 .32213 Metetra
.609 .77 .957 r
.55848 .32213 .56507 .32931 .57765 .32599 .57109 .31867 Metetra
.615 .769 .954 r
.57109 .31867 .57765 .32599 .59029 .32253 .58377 .31507 Metetra
.619 .768 .951 r
.58377 .31507 .59029 .32253 .60299 .31893 .59651 .31137 Metetra
.623 .767 .949 r
.59651 .31137 .60299 .31893 .61576 .31522 .60932 .30756 Metetra
.626 .766 .947 r
.60932 .30756 .61576 .31522 .62858 .31142 .62218 .30367 Metetra
.628 .765 .945 r
.62218 .30367 .62858 .31142 .64147 .30753 .63511 .2997 Metetra
.631 .765 .944 r
.63511 .2997 .64147 .30753 .65442 .30356 .64809 .29567 Metetra
.632 .765 .942 r
.64809 .29567 .65442 .30356 .66743 .29953 .66114 .29157 Metetra
.634 .764 .941 r
.66114 .29157 .66743 .29953 .6805 .29544 .67425 .28741 Metetra
.635 .764 .941 r
.67425 .28741 .6805 .29544 .69363 .29129 .68742 .28321 Metetra
.636 .764 .94 r
.68742 .28321 .69363 .29129 .70682 .28709 .70066 .27895 Metetra
.637 .764 .939 r
.70066 .27895 .70682 .28709 .72008 .28285 .71396 .27465 Metetra
.638 .763 .939 r
.71396 .27465 .72008 .28285 .73339 .27856 .72732 .27031 Metetra
.654 .768 .933 r
.02589 .50071 .03395 .50711 .04432 .50337 .03628 .49696 Metetra
.655 .769 .933 r
.03628 .49696 .04432 .50337 .05474 .4996 .04672 .49317 Metetra
.656 .769 .933 r
.04672 .49317 .05474 .4996 .0652 .49579 .05721 .48935 Metetra
.657 .77 .933 r
.05721 .48935 .0652 .49579 .07571 .49193 .06774 .48549 Metetra
.658 .771 .933 r
.06774 .48549 .07571 .49193 .08627 .48803 .07832 .48159 Metetra
.659 .772 .933 r
.07832 .48159 .08627 .48803 .09687 .48409 .08894 .47764 Metetra
.66 .773 .933 r
.08894 .47764 .09687 .48409 .10752 .48008 .09961 .47364 Metetra
.662 .775 .933 r
.09961 .47364 .10752 .48008 .11821 .47601 .11033 .46958 Metetra
.664 .776 .933 r
.11033 .46958 .11821 .47601 .12896 .47188 .1211 .46546 Metetra
.666 .778 .933 r
.1211 .46546 .12896 .47188 .13975 .46766 .13191 .46127 Metetra
.669 .781 .933 r
.13191 .46127 .13975 .46766 .1506 .46334 .14278 .45699 Metetra
.672 .783 .933 r
.14278 .45699 .1506 .46334 .1615 .45892 .1537 .45262 Metetra
.675 .787 .933 r
.1537 .45262 .1615 .45892 .17245 .45438 .16467 .44815 Metetra
.679 .791 .934 r
.16467 .44815 .17245 .45438 .18345 .44969 .17569 .44356 Metetra
.683 .796 .934 r
.17569 .44356 .18345 .44969 .19451 .44484 .18676 .43884 Metetra
.688 .802 .935 r
.18676 .43884 .19451 .44484 .20563 .43979 .19789 .43397 Metetra
.694 .809 .937 r
.19789 .43397 .20563 .43979 .2168 .43453 .20908 .42893 Metetra
.7 .819 .938 r
.20908 .42893 .2168 .43453 .22803 .42902 .22032 .4237 Metetra
.707 .83 .941 r
.22032 .4237 .22803 .42902 .23932 .42324 .23161 .41828 Metetra
.713 .844 .944 r
.23161 .41828 .23932 .42324 .25067 .41715 .24296 .41265 Metetra
.719 .86 .949 r
.24296 .41265 .25067 .41715 .26208 .41076 .25436 .40682 Metetra
.723 .88 .954 r
.25436 .40682 .26208 .41076 .27354 .40406 .26581 .40081 Metetra
.723 .902 .959 r
.26581 .40081 .27354 .40406 .28504 .39711 .2773 .39465 Metetra
.715 .926 .962 r
.2773 .39465 .28504 .39711 .29659 .38998 .28883 .38842 Metetra
.694 .946 .959 r
.28883 .38842 .29659 .38998 .30816 .38282 .30039 .38222 Metetra
.651 .954 .943 r
.30039 .38222 .30816 .38282 .31975 .37583 .31197 .37618 Metetra
.58 .941 .907 r
.31197 .37618 .31975 .37583 .33134 .36925 .32357 .37044 Metetra
.483 .9 .849 r
.32357 .37044 .33134 .36925 .34292 .36333 .33518 .36516 Metetra
.375 .837 .779 r
.33518 .36516 .34292 .36333 .35449 .3583 .34679 .36046 Metetra
.277 .772 .72 r
.34679 .36046 .35449 .3583 .36605 .35426 .35842 .3564 Metetra
.207 .723 .688 r
.35842 .3564 .36605 .35426 .37762 .35123 .37007 .35299 Metetra
.173 .702 .695 r
.37007 .35299 .37762 .35123 .3892 .34909 .38174 .35016 Metetra
.176 .71 .738 r
.38174 .35016 .3892 .34909 .40082 .34763 .39345 .3478 Metetra
.212 .738 .806 r
.39345 .3478 .40082 .34763 .4125 .34658 .40522 .34574 Metetra
.272 .772 .88 r
.40522 .34574 .4125 .34658 .42424 .34572 .41705 .34386 Metetra
.341 .799 .941 r
.41705 .34386 .42424 .34572 .43606 .34484 .42895 .34201 Metetra
.405 .813 .979 r
.42895 .34201 .43606 .34484 .44797 .34379 .44092 .3401 Metetra
.457 .815 .996 r
.44092 .3401 .44797 .34379 .45995 .34248 .45296 .33805 Metetra
.498 .81 1 r
.45296 .33805 .45995 .34248 .47201 .34089 .46507 .33581 Metetra
.529 .803 .996 r
.46507 .33581 .47201 .34089 .48415 .33898 .47726 .33338 Metetra
.552 .796 .989 r
.47726 .33338 .48415 .33898 .49637 .33677 .48952 .33074 Metetra
.569 .789 .982 r
.48952 .33074 .49637 .33677 .50866 .33429 .50185 .3279 Metetra
.583 .784 .975 r
.50185 .3279 .50866 .33429 .52101 .33156 .51425 .32488 Metetra
.594 .779 .969 r
.51425 .32488 .52101 .33156 .53344 .3286 .52671 .32169 Metetra
.602 .776 .963 r
.52671 .32169 .53344 .3286 .54592 .32545 .53924 .31834 Metetra
.609 .773 .959 r
.53924 .31834 .54592 .32545 .55848 .32213 .55183 .31485 Metetra
.614 .771 .955 r
.55183 .31485 .55848 .32213 .57109 .31867 .56448 .31125 Metetra
.619 .769 .952 r
.56448 .31125 .57109 .31867 .58377 .31507 .5772 .30753 Metetra
.622 .768 .95 r
.5772 .30753 .58377 .31507 .59651 .31137 .58998 .30372 Metetra
.625 .767 .948 r
.58998 .30372 .59651 .31137 .60932 .30756 .60282 .29982 Metetra
.628 .766 .946 r
.60282 .29982 .60932 .30756 .62218 .30367 .61572 .29585 Metetra
.63 .766 .944 r
.61572 .29585 .62218 .30367 .63511 .2997 .62869 .2918 Metetra
.632 .765 .943 r
.62869 .2918 .63511 .2997 .64809 .29567 .64171 .28769 Metetra
.633 .765 .942 r
.64171 .28769 .64809 .29567 .66114 .29157 .6548 .28353 Metetra
.635 .764 .941 r
.6548 .28353 .66114 .29157 .67425 .28741 .66795 .27931 Metetra
.636 .764 .94 r
.66795 .27931 .67425 .28741 .68742 .28321 .68117 .27504 Metetra
.637 .764 .94 r
.68117 .27504 .68742 .28321 .70066 .27895 .69444 .27073 Metetra
.638 .764 .939 r
.69444 .27073 .70066 .27895 .71396 .27465 .70778 .26638 Metetra
.639 .764 .938 r
.70778 .26638 .71396 .27465 .72732 .27031 .72119 .26198 Metetra
.654 .768 .933 r
.01777 .49425 .02589 .50071 .03628 .49696 .02818 .49049 Metetra
.654 .768 .933 r
.02818 .49049 .03628 .49696 .04672 .49317 .03865 .48669 Metetra
.655 .769 .933 r
.03865 .48669 .04672 .49317 .05721 .48935 .04916 .48286 Metetra
.656 .77 .933 r
.04916 .48286 .05721 .48935 .06774 .48549 .05971 .47899 Metetra
.657 .771 .933 r
.05971 .47899 .06774 .48549 .07832 .48159 .07031 .47508 Metetra
.658 .772 .933 r
.07031 .47508 .07832 .48159 .08894 .47764 .08095 .47113 Metetra
.659 .773 .933 r
.08095 .47113 .08894 .47764 .09961 .47364 .09165 .46713 Metetra
.661 .774 .933 r
.09165 .46713 .09961 .47364 .11033 .46958 .10239 .46308 Metetra
.662 .776 .933 r
.10239 .46308 .11033 .46958 .1211 .46546 .11318 .45897 Metetra
.664 .777 .933 r
.11318 .45897 .1211 .46546 .13191 .46127 .12401 .4548 Metetra
.666 .779 .934 r
.12401 .4548 .13191 .46127 .14278 .45699 .1349 .45056 Metetra
.669 .782 .934 r
.1349 .45056 .14278 .45699 .1537 .45262 .14584 .44624 Metetra
.671 .785 .934 r
.14584 .44624 .1537 .45262 .16467 .44815 .15683 .44183 Metetra
.675 .789 .935 r
.15683 .44183 .16467 .44815 .17569 .44356 .16787 .43733 Metetra
.678 .793 .936 r
.16787 .43733 .17569 .44356 .18676 .43884 .17896 .43271 Metetra
.682 .798 .937 r
.17896 .43271 .18676 .43884 .19789 .43397 .19011 .42798 Metetra
.686 .804 .938 r
.19011 .42798 .19789 .43397 .20908 .42893 .2013 .42312 Metetra
.69 .812 .94 r
.2013 .42312 .20908 .42893 .22032 .4237 .21255 .41812 Metetra
.695 .821 .943 r
.21255 .41812 .22032 .4237 .23161 .41828 .22385 .41298 Metetra
.699 .832 .946 r
.22385 .41298 .23161 .41828 .24296 .41265 .23521 .4077 Metetra
.703 .845 .951 r
.23521 .4077 .24296 .41265 .25436 .40682 .24661 .40229 Metetra
.705 .86 .956 r
.24661 .40229 .25436 .40682 .26581 .40081 .25806 .39676 Metetra
.704 .876 .962 r
.25806 .39676 .26581 .40081 .2773 .39465 .26955 .39116 Metetra
.699 .894 .968 r
.26955 .39116 .2773 .39465 .28883 .38842 .28108 .38553 Metetra
.687 .911 .972 r
.28108 .38553 .28883 .38842 .30039 .38222 .29264 .37995 Metetra
.666 .924 .974 r
.29264 .37995 .30039 .38222 .31197 .37618 .30424 .37451 Metetra
.632 .93 .97 r
.30424 .37451 .31197 .37618 .32357 .37044 .31585 .36929 Metetra
.588 .927 .959 r
.31585 .36929 .32357 .37044 .33518 .36516 .32749 .36439 Metetra
.536 .913 .944 r
.32749 .36439 .33518 .36516 .34679 .36046 .33915 .35988 Metetra
.484 .892 .929 r
.33915 .35988 .34679 .36046 .35842 .3564 .35083 .3558 Metetra
.443 .872 .921 r
.35083 .3558 .35842 .3564 .37007 .35299 .36254 .35214 Metetra
.419 .857 .925 r
.36254 .35214 .37007 .35299 .38174 .35016 .37429 .34888 Metetra
.414 .849 .94 r
.37429 .34888 .38174 .35016 .39345 .3478 .38608 .34593 Metetra
.425 .845 .96 r
.38608 .34593 .39345 .3478 .40522 .34574 .39792 .34322 Metetra
.448 .842 .98 r
.39792 .34322 .40522 .34574 .41705 .34386 .40982 .34065 Metetra
.474 .837 .993 r
.40982 .34065 .41705 .34386 .42895 .34201 .42178 .33814 Metetra
.501 .83 .999 r
.42178 .33814 .42895 .34201 .44092 .3401 .43381 .3356 Metetra
.525 .821 .999 r
.43381 .3356 .44092 .3401 .45296 .33805 .44591 .33299 Metetra
.545 .811 .995 r
.44591 .33299 .45296 .33805 .46507 .33581 .45808 .33028 Metetra
.562 .803 .989 r
.45808 .33028 .46507 .33581 .47726 .33338 .47031 .32743 Metetra
.575 .795 .983 r
.47031 .32743 .47726 .33338 .48952 .33074 .48261 .32444 Metetra
.586 .789 .976 r
.48261 .32444 .48952 .33074 .50185 .3279 .49498 .3213 Metetra
.596 .783 .97 r
.49498 .3213 .50185 .3279 .51425 .32488 .50742 .31803 Metetra
.603 .779 .965 r
.50742 .31803 .51425 .32488 .52671 .32169 .51992 .31463 Metetra
.609 .776 .96 r
.51992 .31463 .52671 .32169 .53924 .31834 .53249 .3111 Metetra
.614 .773 .957 r
.53249 .3111 .53924 .31834 .55183 .31485 .54512 .30746 Metetra
.619 .771 .953 r
.54512 .30746 .55183 .31485 .56448 .31125 .55781 .30373 Metetra
.622 .77 .951 r
.55781 .30373 .56448 .31125 .5772 .30753 .57056 .29989 Metetra
.625 .768 .948 r
.57056 .29989 .5772 .30753 .58998 .30372 .58338 .29598 Metetra
.628 .767 .947 r
.58338 .29598 .58998 .30372 .60282 .29982 .59626 .29199 Metetra
.63 .766 .945 r
.59626 .29199 .60282 .29982 .61572 .29585 .6092 .28793 Metetra
.632 .766 .944 r
.6092 .28793 .61572 .29585 .62869 .2918 .62221 .28381 Metetra
.633 .765 .942 r
.62221 .28381 .62869 .2918 .64171 .28769 .63528 .27964 Metetra
.635 .765 .941 r
.63528 .27964 .64171 .28769 .6548 .28353 .6484 .27541 Metetra
.636 .765 .941 r
.6484 .27541 .6548 .28353 .66795 .27931 .6616 .27113 Metetra
.637 .764 .94 r
.6616 .27113 .66795 .27931 .68117 .27504 .67485 .2668 Metetra
.638 .764 .939 r
.67485 .2668 .68117 .27504 .69444 .27073 .68817 .26243 Metetra
.638 .764 .939 r
.68817 .26243 .69444 .27073 .70778 .26638 .70156 .25802 Metetra
.639 .764 .938 r
.70156 .25802 .70778 .26638 .72119 .26198 .715 .25357 Metetra
.653 .768 .933 r
.00958 .48775 .01777 .49425 .02818 .49049 .02002 .48396 Metetra
.654 .768 .933 r
.02002 .48396 .02818 .49049 .03865 .48669 .03051 .48015 Metetra
.654 .769 .933 r
.03051 .48015 .03865 .48669 .04916 .48286 .04104 .47631 Metetra
.655 .769 .933 r
.04104 .47631 .04916 .48286 .05971 .47899 .05161 .47243 Metetra
.656 .77 .933 r
.05161 .47243 .05971 .47899 .07031 .47508 .06224 .46851 Metetra
.657 .771 .933 r
.06224 .46851 .07031 .47508 .08095 .47113 .07291 .46456 Metetra
.658 .772 .933 r
.07291 .46456 .08095 .47113 .09165 .46713 .08362 .46056 Metetra
.659 .773 .934 r
.08362 .46056 .09165 .46713 .10239 .46308 .09438 .45652 Metetra
.661 .775 .934 r
.09438 .45652 .10239 .46308 .11318 .45897 .10519 .45242 Metetra
.662 .776 .934 r
.10519 .45242 .11318 .45897 .12401 .4548 .11605 .44827 Metetra
.664 .778 .934 r
.11605 .44827 .12401 .4548 .1349 .45056 .12696 .44405 Metetra
.666 .78 .934 r
.12696 .44405 .1349 .45056 .14584 .44624 .13792 .43977 Metetra
.668 .783 .935 r
.13792 .43977 .14584 .44624 .15683 .44183 .14893 .43541 Metetra
.671 .786 .936 r
.14893 .43541 .15683 .44183 .16787 .43733 .15999 .43098 Metetra
.673 .79 .936 r
.15999 .43098 .16787 .43733 .17896 .43271 .1711 .42645 Metetra
.676 .794 .938 r
.1711 .42645 .17896 .43271 .19011 .42798 .18226 .42184 Metetra
.679 .8 .939 r
.18226 .42184 .19011 .42798 .2013 .42312 .19347 .41712 Metetra
.683 .806 .941 r
.19347 .41712 .2013 .42312 .21255 .41812 .20474 .4123 Metetra
.686 .813 .943 r
.20474 .4123 .21255 .41812 .22385 .41298 .21605 .40738 Metetra
.688 .822 .947 r
.21605 .40738 .22385 .41298 .23521 .4077 .22742 .40235 Metetra
.691 .831 .951 r
.22742 .40235 .23521 .4077 .24661 .40229 .23883 .39724 Metetra
.691 .842 .955 r
.23883 .39724 .24661 .40229 .25806 .39676 .25028 .39207 Metetra
.691 .855 .961 r
.25028 .39207 .25806 .39676 .26955 .39116 .26178 .38685 Metetra
.687 .867 .967 r
.26178 .38685 .26955 .39116 .28108 .38553 .27332 .38163 Metetra
.679 .88 .973 r
.27332 .38163 .28108 .38553 .29264 .37995 .2849 .37646 Metetra
.667 .891 .979 r
.2849 .37646 .29264 .37995 .30424 .37451 .29651 .3714 Metetra
.65 .899 .983 r
.29651 .3714 .30424 .37451 .31585 .36929 .30815 .36651 Metetra
.627 .903 .985 r
.30815 .36651 .31585 .36929 .32749 .36439 .31982 .36184 Metetra
.601 .902 .986 r
.31982 .36184 .32749 .36439 .33915 .35988 .33152 .35744 Metetra
.575 .896 .986 r
.33152 .35744 .33915 .35988 .35083 .3558 .34325 .35333 Metetra
.553 .888 .986 r
.34325 .35333 .35083 .3558 .36254 .35214 .35502 .34951 Metetra
.537 .878 .988 r
.35502 .34951 .36254 .35214 .37429 .34888 .36683 .34595 Metetra
.529 .868 .992 r
.36683 .34595 .37429 .34888 .38608 .34593 .37868 .34262 Metetra
.529 .858 .996 r
.37868 .34262 .38608 .34593 .39792 .34322 .39059 .33947 Metetra
.534 .847 .998 r
.39059 .33947 .39792 .34322 .40982 .34065 .40255 .33642 Metetra
.543 .837 .999 r
.40255 .33642 .40982 .34065 .42178 .33814 .41457 .33343 Metetra
.554 .827 .997 r
.41457 .33343 .42178 .33814 .43381 .3356 .42665 .33044 Metetra
.565 .817 .993 r
.42665 .33044 .43381 .3356 .44591 .33299 .4388 .32742 Metetra
.575 .808 .987 r
.4388 .32742 .44591 .33299 .45808 .33028 .45102 .32433 Metetra
.584 .8 .982 r
.45102 .32433 .45808 .33028 .47031 .32743 .4633 .32115 Metetra
.592 .793 .976 r
.4633 .32115 .47031 .32743 .48261 .32444 .47564 .31787 Metetra
.599 .787 .97 r
.47564 .31787 .48261 .32444 .49498 .3213 .48805 .31449 Metetra
.606 .782 .966 r
.48805 .31449 .49498 .3213 .50742 .31803 .50053 .31101 Metetra
.611 .779 .961 r
.50053 .31101 .50742 .31803 .51992 .31463 .51307 .30742 Metetra
.615 .776 .957 r
.51307 .30742 .51992 .31463 .53249 .3111 .52568 .30373 Metetra
.619 .773 .954 r
.52568 .30373 .53249 .3111 .54512 .30746 .53834 .29996 Metetra
.622 .771 .952 r
.53834 .29996 .54512 .30746 .55781 .30373 .55108 .2961 Metetra
.625 .77 .949 r
.55108 .2961 .55781 .30373 .57056 .29989 .56387 .29216 Metetra
.628 .768 .947 r
.56387 .29216 .57056 .29989 .58338 .29598 .57673 .28815 Metetra
.63 .767 .946 r
.57673 .28815 .58338 .29598 .59626 .29199 .58965 .28408 Metetra
.632 .767 .944 r
.58965 .28408 .59626 .29199 .6092 .28793 .60263 .27994 Metetra
.633 .766 .943 r
.60263 .27994 .6092 .28793 .62221 .28381 .61567 .27575 Metetra
.634 .765 .942 r
.61567 .27575 .62221 .28381 .63528 .27964 .62878 .2715 Metetra
.636 .765 .941 r
.62878 .2715 .63528 .27964 .6484 .27541 .64195 .2672 Metetra
.637 .765 .94 r
.64195 .2672 .6484 .27541 .6616 .27113 .65519 .26286 Metetra
.637 .764 .94 r
.65519 .26286 .6616 .27113 .67485 .2668 .66848 .25848 Metetra
.638 .764 .939 r
.66848 .25848 .67485 .2668 .68817 .26243 .68185 .25405 Metetra
.639 .764 .938 r
.68185 .25405 .68817 .26243 .70156 .25802 .69527 .24959 Metetra
.64 .764 .938 r
.69527 .24959 .70156 .25802 .715 .25357 .70876 .24508 Metetra
.653 .767 .933 r
.00134 .48118 .00958 .48775 .02002 .48396 .0118 .47738 Metetra
.653 .768 .933 r
.0118 .47738 .02002 .48396 .03051 .48015 .02231 .47356 Metetra
.654 .768 .933 r
.02231 .47356 .03051 .48015 .04104 .47631 .03286 .4697 Metetra
.654 .769 .933 r
.03286 .4697 .04104 .47631 .05161 .47243 .04346 .46581 Metetra
.655 .77 .934 r
.04346 .46581 .05161 .47243 .06224 .46851 .0541 .46189 Metetra
.656 .771 .934 r
.0541 .46189 .06224 .46851 .07291 .46456 .06479 .45793 Metetra
.657 .772 .934 r
.06479 .45793 .07291 .46456 .08362 .46056 .07553 .45392 Metetra
.658 .773 .934 r
.07553 .45392 .08362 .46056 .09438 .45652 .08632 .44988 Metetra
.659 .774 .934 r
.08632 .44988 .09438 .45652 .10519 .45242 .09715 .44579 Metetra
.66 .775 .934 r
.09715 .44579 .10519 .45242 .11605 .44827 .10803 .44165 Metetra
.662 .777 .935 r
.10803 .44165 .11605 .44827 .12696 .44405 .11896 .43746 Metetra
.664 .779 .935 r
.11896 .43746 .12696 .44405 .13792 .43977 .12994 .43321 Metetra
.665 .781 .935 r
.12994 .43321 .13792 .43977 .14893 .43541 .14097 .42889 Metetra
.667 .784 .936 r
.14097 .42889 .14893 .43541 .15999 .43098 .15205 .42451 Metetra
.669 .787 .937 r
.15205 .42451 .15999 .43098 .1711 .42645 .16318 .42006 Metetra
.672 .791 .938 r
.16318 .42006 .1711 .42645 .18226 .42184 .17436 .41554 Metetra
.674 .795 .939 r
.17436 .41554 .18226 .42184 .19347 .41712 .18559 .41093 Metetra
.676 .8 .941 r
.18559 .41093 .19347 .41712 .20474 .4123 .19687 .40625 Metetra
.678 .806 .944 r
.19687 .40625 .20474 .4123 .21605 .40738 .2082 .40149 Metetra
.68 .813 .946 r
.2082 .40149 .21605 .40738 .22742 .40235 .21958 .39666 Metetra
.681 .82 .95 r
.21958 .39666 .22742 .40235 .23883 .39724 .23101 .39178 Metetra
.681 .828 .954 r
.23101 .39178 .23883 .39724 .25028 .39207 .24248 .38685 Metetra
.68 .837 .959 r
.24248 .38685 .25028 .39207 .26178 .38685 .25399 .3819 Metetra
.677 .846 .964 r
.25399 .3819 .26178 .38685 .27332 .38163 .26555 .37696 Metetra
.672 .855 .969 r
.26555 .37696 .27332 .38163 .2849 .37646 .27714 .37207 Metetra
.665 .863 .975 r
.27714 .37207 .2849 .37646 .29651 .3714 .28878 .36726 Metetra
.654 .869 .98 r
.28878 .36726 .29651 .3714 .30815 .36651 .30044 .36257 Metetra
.641 .873 .984 r
.30044 .36257 .30815 .36651 .31982 .36184 .31215 .35804 Metetra
.627 .875 .988 r
.31215 .35804 .31982 .36184 .33152 .35744 .32389 .3537 Metetra
.612 .873 .991 r
.32389 .3537 .33152 .35744 .34325 .35333 .33567 .34955 Metetra
.599 .869 .993 r
.33567 .34955 .34325 .35333 .35502 .34951 .34748 .34561 Metetra
.588 .862 .994 r
.34748 .34561 .35502 .34951 .36683 .34595 .35934 .34186 Metetra
.581 .854 .995 r
.35934 .34186 .36683 .34595 .37868 .34262 .37125 .33826 Metetra
.578 .846 .995 r
.37125 .33826 .37868 .34262 .39059 .33947 .38321 .33479 Metetra
.578 .836 .994 r
.38321 .33479 .39059 .33947 .40255 .33642 .39523 .33141 Metetra
.581 .827 .992 r
.39523 .33141 .40255 .33642 .41457 .33343 .4073 .32807 Metetra
.585 .818 .988 r
.4073 .32807 .41457 .33343 .42665 .33044 .41944 .32475 Metetra
.589 .81 .984 r
.41944 .32475 .42665 .33044 .4388 .32742 .43164 .32141 Metetra
.595 .802 .979 r
.43164 .32141 .4388 .32742 .45102 .32433 .4439 .31803 Metetra
.6 .796 .974 r
.4439 .31803 .45102 .32433 .4633 .32115 .45622 .31458 Metetra
.605 .79 .97 r
.45622 .31458 .4633 .32115 .47564 .31787 .46861 .31107 Metetra
.609 .785 .965 r
.46861 .31107 .47564 .31787 .48805 .31449 .48106 .30748 Metetra
.613 .781 .961 r
.48106 .30748 .48805 .31449 .50053 .31101 .49358 .30381 Metetra
.617 .778 .958 r
.49358 .30381 .50053 .31101 .51307 .30742 .50616 .30006 Metetra
.62 .775 .955 r
.50616 .30006 .51307 .30742 .52568 .30373 .51881 .29624 Metetra
.623 .773 .952 r
.51881 .29624 .52568 .30373 .53834 .29996 .53151 .29234 Metetra
.626 .771 .95 r
.53151 .29234 .53834 .29996 .55108 .2961 .54428 .28837 Metetra
.628 .77 .948 r
.54428 .28837 .55108 .2961 .56387 .29216 .55712 .28433 Metetra
.63 .768 .946 r
.55712 .28433 .56387 .29216 .57673 .28815 .57001 .28023 Metetra
.632 .767 .945 r
.57001 .28023 .57673 .28815 .58965 .28408 .58297 .27607 Metetra
.633 .767 .943 r
.58297 .27607 .58965 .28408 .60263 .27994 .596 .27186 Metetra
.634 .766 .942 r
.596 .27186 .60263 .27994 .61567 .27575 .60908 .26759 Metetra
.636 .765 .941 r
.60908 .26759 .61567 .27575 .62878 .2715 .62223 .26328 Metetra
.637 .765 .941 r
.62223 .26328 .62878 .2715 .64195 .2672 .63544 .25892 Metetra
.637 .765 .94 r
.63544 .25892 .64195 .2672 .65519 .26286 .64872 .25452 Metetra
.638 .764 .939 r
.64872 .25452 .65519 .26286 .66848 .25848 .66206 .25007 Metetra
.639 .764 .939 r
.66206 .25007 .66848 .25848 .68185 .25405 .67546 .24559 Metetra
.639 .764 .938 r
.67546 .24559 .68185 .25405 .69527 .24959 .68893 .24107 Metetra
.64 .764 .938 r
.68893 .24107 .69527 .24959 .70876 .24508 .70247 .23651 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.01 w
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -87.9375 -23.3395 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -87.486 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -74.0356 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -73.3059 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -72.5762 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 467.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001db000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJXKo
oo]Z2Ol007nboookJP00oooonfZ6oookJPWo001o/_oonfX00?oooo]ZQ_oonfX4o`00OkOooo]Z003o
oookJXOooo]Z1?l007nfoookJP00oooonfZ8oookJPGo001o]?oonfX00?oooo]ZR_oonfX4o`00Ok?o
oo]Z003ooookJX_ooo]Z0ol007ncoookJP00oooonfZ<oookJP?o001o/_oonfX00?oooo]ZQ_oonfX3
o`00O`?ooo]Z0ol007nboookJP00oooonfZ6oookJP?o001o0ooonfX3o`00Ok;ooo]Z003ooookJXKo
oo]Z1?l007l2oookJP?o001o6_oonfX9o`00Ohoooo]Z003ooookJXOooo]Z1ol007lKoookJPWo001o
SooonfX00?oooo]ZR?oonfX5o`00Oacooo]Z1?l007nDoookJP00oooonfZMoookJP[o001o0ooonfX4
o`00Oi?ooo]Z003ooookJYgooo]Z2_l007l4oookJPGo001oTOoonfX00?oooo]Z[OoonfX4o`00Oi3o
oo]Z003ooookJZkooo]Z0ol007n@oookJP00oooonfZ_oookJP?o001oSooonfX00?oooo]ZT?oonfX6
o`0001?ooo]Z0ol007l3oookJP?o001oSooonfX00?oooo]ZSOoonfX9o`0001?ooo]Z0ol007l3oook
JP?o001oSooonfX00?oooo]ZRooonfX<o`0001;ooo]Z1?l007l2oookJP?o001oSooonfX00?oooo]Z
R?oonfX@o`0001;ooo]Z1ol007n@oookJP00oooonfZ6oookJQ;o00004ooonfX5o`00Oi7ooo]Z003o
oookJX?ooo]Z5_l0002XoookJP00oooonfZ0oookJQ7o000000?ooo]Zo`000?l000001_l0002Woook
JP00oooonfYnoookJQ7o00001?oonfX7o`000:Oooo]Z003ooookJW_ooo]Z4Ol00007oookJPSo0000
Y_oonfX00?oooo]ZNOoonfXAo`0000Wooo]Z2Ol0002UoookJP00oooonfYfoookJQ7o00003?oonfX0
0ol0003ooo]Zo`000006o`000:Gooo]Z003ooookJWCooo]Z4?l0000@oookJPWo0000Y?oonfX00?oo
oo]ZLOoonfXAo`0001;ooo]Z00?o0000oookJ_l000001ol0002SoookJP00oooonfY_oookJQ3o0000
5OoonfX00ol0003ooo]ZoookJP07o`000:?ooo]Z003ooookJVcooo]Z4Ol0000GoookJP03o`000?oo
nf[ooo]Z00So0000X_oonfX00?oooo]ZJOoonfXAo`0001[ooo]Z00Co0000oookJ_oonf[ooo]Z2?l0
002QoookJP00oooonfYWoookJQ7o00007?oonfX00ol0003ooo]ZoookJP02oookJPOo0000XOoonfX0
0?oooo]ZI?oonfXAo`0001oooo]Z00?o0000oookJ_oonfX00_oonfX8o`000:3ooo]Z003ooookJV;o
oo]Z4Ol0000QoookJP03o`000?oonf[ooo]Z00?ooo]Z1ol0002PoookJP00oooonfYOoookJQ7o0000
9?oonfX00ol0003ooo]ZoookJP04oookJPOo0000WooonfX00?oooo]Z:?oonfX3o`00Oc;ooo]Z4?l0
000WoookJP03o`000?oonf[ooo]Z00Cooo]Z2?l0002NoookJP00oooonfXXoookJP?o001o;ooonfXA
o`0002Wooo]Z00?o0000oookJ_oonfX01OoonfX7o`0009kooo]Z003ooookJRSooo]Z0ol007l]oook
JQ3o0000;?oonfX00ol0003ooo]ZoookJP05oookJPSo0000WOoonfX00?oooo]Z:?oonfX3o`00Ob[o
oo]Z4Ol0000^oookJP03o`000?oonf[ooo]Z00Kooo]Z2?l0002LoookJP00oooonfXXoookJP?o001o
:?oonfX@o`00037ooo]Z00?o0000oookJ_oonfX01ooonfX7o`0009cooo]Z003ooookJRSooo]Z0ol0
07lUoookJQ7o0000<ooonfX00ol0003ooo]ZoookJP07oookJPSo0000VooonfX00?oooo]Z:?oonfX3
o`00Ob;ooo]Z4Ol0000foookJP03o`000?oonf[ooo]Z00Sooo]Z2?l0002JoookJP00oooonfXXoook
JP?o001o8?oonfXAo`0003Sooo]Z00?o0000oookJ_oonfX02OoonfX7o`0009[ooo]Z003ooookJRSo
oo]Z0ol007lMoookJQ7o0000??oonfX00ol0003ooo]ZoookJP08oookJPSo0000VOoonfX00?oooo]Z
9OoonfX6o`00Oa_ooo]Z4Ol0000noookJP03o`000?oonf[ooo]Z00Wooo]Z2?l0002HoookJP00oooo
nfXUoookJPKo001o6?oonfXAo`00047ooo]Z00?o0000oookJ_oonfX02_oonfX7o`0009Sooo]Z003o
oookJROooo]Z1?l007lFoookJQ3o0000A?oonfX00ol0003ooo]ZoookJP0:oookJPSo0000UooonfX0
0?oooo]Z:?oonfX3o`00Oa?ooo]Z4Ol00016oookJP03o`000?oonf[ooo]Z00_ooo]Z2?l0002Foook
JP00oooonfXloookJQ3o0000BOoonfX00ol0003ooo]ZoookJP0<oookJPOo0000U_oonfX00?oooo]Z
>OoonfXAo`0004_ooo]Z00?o0000oookJ_oonfX03?oonfX8o`0009Gooo]Z003ooookJSKooo]Z4Ol0
001>oookJP03o`000?oonf[ooo]Z00gooo]Z2?l0002DoookJP00oooonfXdoookJQ7o0000D?oonfX0
0ol0003ooo]ZoookJP0>oookJPOo0000U?oonfX00?oooo]Z<OoonfXAo`0005?ooo]Z00?o0000oook
J_oonfX03_oonfX8o`0009?ooo]Z003ooookJRoooo]Z4Ol0001EoookJP03o`000?oonf[ooo]Z00oo
oo]Z2?l0002BoookJP00oooonfX/oookJQ7o0000F?oonfX00ol0003ooo]ZoookJP0@oookJPOo0000
T_oonfX00?oooo]Z:_oonfX@o`0005_ooo]Z00?o0000oookJ_oonfX04?oonfX8o`00097ooo]Z003o
oookJROooo]Z4Ol0001MoookJP03o`000?oonf[ooo]Z017ooo]Z2?l0002@oookJP00oooonfXUoook
JQ3o0000H?oonfX00ol0003ooo]ZoookJP0BoookJPOo0000T?oonfX00?oooo]Z8_oonfXAo`0000;o
oo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0BoookJPSo0000SooonfX00?oooo]Z
7ooonfXAo`0006Gooo]Z00?o0000oookJ_oonfX04ooonfX8o`0008kooo]Z003ooookJQgooo]Z4Ol0
001XoookJP03o`000?oonf[ooo]Z01?ooo]Z1ol0002>oookJP00oooonfXJoookJQ7o0000JooonfX0
0ol0003ooo]ZoookJP0CoookJPSo0000SOoonfX00?oooo]Z6?oonfXAo`0006gooo]Z00?o0000oook
J_oonfX05?oonfX7o`0008gooo]Z003ooookJQGooo]Z4Ol0001`oookJP03o`000?oonf[ooo]Z01Go
oo]Z1ol0002<oookJP00oooonfXCoookJQ3o0000LooonfX00ol0003ooo]ZoookJP0EoookJPSo0000
RooonfX00?oooo]Z4?oonfXAo`0007Gooo]Z00?o0000oookJ_oonfX05_oonfX7o`0008_ooo]Z003o
oookJPkooo]Z4?l0001hoookJP03o`000?oonf[ooo]Z01Kooo]Z2?l0002:oookJP00oooonfX;oook
JQ7o0000N_oonfX00ol0003ooo]ZoookJP0GoookJPSo0000ROoonfX00?oooo]Z2OoonfX@o`0007go
oo]Z00?o0000oookJ_oonfX06?oonfX7o`0008Wooo]Z003ooookJPKooo]Z4Ol0001ooookJP03o`00
0?oonf[ooo]Z01Sooo]Z2?l00028oookJP00oooonfX3oookJQ7o0000P_oonfX00ol0003ooo]Zoook
JP0IoookJPSo0000QooonfX00<Wooo]Z1Ol007lboookJQ7o0000Q?oonfX00ol0003ooo]ZoookJP0J
oookJPOo0000QooonfX00<Sooo]Z1ol007l^oookJQ7o0000QooonfX00ol0003ooo]ZoookJP0Joook
JPSo0000Q_oonfX00<Sooo]Z0ol007l01?oonf[o001oo`00Ool007l/oookJQ7o0000ROoonfX00ol0
003ooo]ZoookJP0KoookJPSo0000QOoonfX00<Oooo]Z0ol007l3oookJP?o001o:?oonfXAo`0008co
oo]Z00?o0000oookJ_oonfX07?oonfX7o`0008Gooo]Z0037oookJP?o001o0ooonfX3o`00ObKooo]Z
4?l0002?oookJP03o`000?oonf[ooo]Z01cooo]Z2?l0000LoookJP?o001oIOoonfX00<Oooo]Z0ol0
07l3oookJP?o001o8ooonfXAo`0009;ooo]Z00?o0000oookJ_oonfX07?oonfX8o`0001_ooo]Z0ol0
07mUoookJP00aooonfX3o`00O`?ooo]Z0ol007lQoookJQ3o0000UOoonfX00ol0003ooo]ZoookJP0M
oookJPOo00006ooonfX3o`00OfGooo]Z0037oookJP?o001o0ooonfX3o`00Oakooo]Z4Ol0002Goook
JP03o`000?oonf[ooo]Z01gooo]Z2?l0000:oookJP[o001o1_oonfX3o`00OfGooo]Z0037oookJP?o
001o0ooonfX3o`00Oa_ooo]Z4Ol0002JoookJP03o`000?oonf[ooo]Z01kooo]Z2?l00009oookJP[o
001o1_oonfX3o`00OfGooo]Z0037oookJP?o001o0ooonfX3o`00OaWooo]Z4Ol0002LoookJP03o`00
0?oonf[ooo]Z01oooo]Z1ol0000IoookJP?o001oIOoonfX00<Sooo]Z0ol007l01?oonf[o001oo`00
Ool007lGoookJQ7o0000WooonfX00ol0003ooo]ZoookJP0OoookJPSo00006?oonfX3o`00OfGooo]Z
0038oookJPOo001o5OoonfXAo`000:7ooo]Z00?o0000oookJ_oonfX08?oonfX8o`0001Oooo]Z0ol0
07mUoookJP00bOoonfX5o`00Oa?ooo]Z4Ol0002ToookJP03o`000?oonf[ooo]Z027ooo]Z1ol0000G
oookJP?o001oIOoonfX00=oooo]Z4?l0002WoookJP03o`000?oonf[ooo]Z027ooo]Z2?l0000Coook
JPKo001oIOoonfX00=cooo]Z4Ol0002YoookJP03o`000?oonf[ooo]Z02;ooo]Z2?l0000BoookJPKo
001oIOoonfX00=[ooo]Z4?l0002/oookJP03o`000?oonf[ooo]Z02;ooo]Z2?l0000DoookJPCo001o
IOoonfX00=Oooo]Z4Ol0002^oookJP03o`000?oonf[ooo]Z02?ooo]Z2?l0000DoookJP?o001oIOoo
nfX00=Gooo]Z4?l0002aoookJP03o`000?oonf[ooo]Z02Cooo]Z2?l0001koookJP00d_oonfXAo`00
0;?ooo]Z00?o0000oookJ_oonfX09OoonfX7o`0007_ooo]Z003?oookJQ7o0000]_oonfX00ol0003o
oo]ZoookJP0UoookJPSo0000N_oonfX00<gooo]Z4Ol0002hoookJP03o`000?oonf[ooo]Z02Kooo]Z
1ol0001joookJP00b_oonfXAo`000;_ooo]Z00?o0000oookJ_oonfX09ooonfX7o`0007Wooo]Z0038
oookJQ;o0000_OoonfX00ol0003ooo]ZoookJP0VoookJPSo0000N?oonfX00<Gooo]Z4Ol00031oook
JP03o`000?oonf[ooo]Z02Oooo]Z1ol0001hoookJP00`ooonfX@o`000<Cooo]Z00?o0000oookJ_oo
nfX09ooonfX8o`0007Oooo]Z0030oookJQ7o0000a_oonfX00ol0003ooo]ZoookJP0XoookJPSo0000
M_oonfX00;kooo]Z4?l00039oookJP03o`000?oonf[ooo]Z02Wooo]Z1ol0001foookJP00^ooonfXA
o`000<_ooo]Z00?o0000oookJ_oonfX0:OoonfX8o`0007Gooo]Z002hoookJQ7o0000c_oonfX00ol0
003ooo]ZoookJP0ZoookJPSo0000M?oonfX00;Kooo]Z4Ol0003@oookJP03o`000?oonf[ooo]Z02_o
oo]Z1ol0001doookJP00/ooonfXAo`000=?ooo]Z00?o0000oookJ_oonfX0:ooonfX8o`0007?ooo]Z
002aoookJQ7o0000eOoonfX00ol0003ooo]ZoookJP0/oookJPSo0000L_oonfX00:kooo]Z4Ol0003H
oookJP03o`000?oonf[ooo]Z02gooo]Z1ol0001boookJP00[?oonfX@o`000=_ooo]Z00?o0000oook
J_oonfX0;OoonfX8o`00077ooo]Z001foookJP?o001o<?oonfXAo`000=gooo]Z00?o0000oookJ_oo
nfX0;_oonfX8o`00073ooo]Z001foookJP?o001o;_oonfX@o`000>3ooo]Z00?o0000oookJ_oonfX0
;ooonfX7o`00073ooo]Z001foookJP?o001o:ooonfXAo`000>;ooo]Z00?o0000oookJ_oonfX0;ooo
nfX8o`0006oooo]Z001VoookJP[o001o1_oonfX3o`00ObWooo]Z4?l0003UoookJP03o`000?oonf[o
oo]Z033ooo]Z2?l0001^oookJP00I_oonfX:o`00O`Kooo]Z0ol007lVoookJQ7o0000j?oonfX00ol0
003ooo]ZoookJP0`oookJPOo0000K_oonfX007Kooo]Z0ol007lSoookJQ7o0000jooonfX00ol0003o
oo]ZoookJP0`oookJPSo0000KOoonfX007Kooo]Z0ol007lQoookJQ7o0000kOoonfX00ol0003ooo]Z
oookJP0aoookJPSo0000K?oonfX007Kooo]Z0ol007lNoookJQ7o0000l?oonfX00ol0003ooo]Zoook
JP0boookJPOo0000K?oonfX007Kooo]Z0ol007lLoookJQ7o0000l_oonfX00ol0003ooo]ZoookJP0b
oookJPSo0000JooonfX007?ooo]Z1_l007lIoookJQ7o0000mOoonfX00ol0003ooo]ZoookJP0coook
JPSo0000J_oonfX007?ooo]Z1_l007lGoookJQ3o0000n?oonfX00ol0003ooo]ZoookJP0doookJPOo
0000J_oonfX007Gooo]Z1?l007lDoookJQ7o0000n_oonfX00ol0003ooo]ZoookJP0doookJPSo0000
JOoonfX007Kooo]Z0ol007lBoookJQ3o0000oOoonfX00ol0003ooo]ZoookJP0eoookJPSo0000J?oo
nfX008Sooo]Z4Ol0003ooookJP03o`000?oonf[ooo]Z03Kooo]Z1ol0001XoookJP00QOoonfXAo`00
0?oooo]Z0ooonfX00ol0003ooo]ZoookJP0foookJPSo0000IooonfX008?ooo]Z4Ol0003ooookJPGo
oo]Z00?o0000oookJ_oonfX0=ooonfX7o`0006Oooo]Z0020oookJQ7o0000oooonfX8oookJP03o`00
0?oonf[ooo]Z03Sooo]Z1ol0001VoookJP00O_oonfXAo`000?oooo]Z2_oonfX00ol0003ooo]Zoook
JP0hoookJPSo0000IOoonfX007_ooo]Z4Ol0003ooookJPgooo]Z00?o0000oookJ_oonfX0>OoonfX7
o`0006Gooo]Z001ioookJQ3o0000QOoonfX2o`0008Sooo]Z00?o0000oookJ_oonfX0>OoonfX8o`00
06Cooo]Z001foookJQ7o0000N?oonfX3o`0000Wooo]Z0ol000000oo2JfOo0000o`000027oookJP03
o`000?oonf[ooo]Z03[ooo]Z2?l0001SoookJP00M?oonfXAo`0007Oooo]Z0ol000001?n8?fko0000
onAj6?l00005oookJP?o00001?o2JfL00ol0003olYDmo`000006oookJP;o0000OooonfX00ol0003o
oo]ZoookJP0joookJPOo0000HooonfX0077ooo]Z4Ol0001goookJP?o00001?n8?fh2o`000003onAj
6?l0003ooo]Z00?o000000?oi7XHo`000?o2JfL01?o2JfL2o`000004oo:E?Ol0003ooo]ZoookJP?o
000000?olYDmo`000?oonfX0O_oonfX00ol0003ooo]ZoookJP0joookJPSo0000H_oonfX006kooo]Z
4Ol0001goookJP?o000000?oN39Zo`000?n8?fh01?n8?fh2o`0000;oi7XH00?o0000onAj6?oTNQP0
0_oTNQP00ol0003o`V]Wol9[I`03ol9[I`;o00000_obUCd2o`0000ColYDm0_l0001noookJP03o`00
0?oonf[ooo]Z03_ooo]Z2?l0001QoookJP00K?oonfXAo`0007Oooo]Z0_l00004ogPbJP03o`000?n8
?fkoR3m^00?oR3m^0_l00006onAj6003o`000?o2JfOo`V]W00?o`V]W00?o0000ojMJLol000002?ob
UCd00ol0003oliU3o`00001moookJP03o`000?oonf[ooo]Z03cooo]Z1ol0001QoookJP00JOoonfXA
o`0007Sooo]Z0_l000000omX9VOo0000ogPbJP03ogPbJP03o`000?n8?fkoR3m^00;oR3m^00Co0000
oi18LOn@B77o00001OoTNQP00ol0003o`V]Wol9[I`03ol9[I`03o`000?nWFW?o000000OolYDm00Go
0000okUYL_l0003oliU3o`00001loookJP03o`000?oonf[ooo]Z03cooo]Z2?l0001PoookJP00Iooo
nfXAo`0007Sooo]Z0_l00003ofPVI`05o`000?mh<V[oN39ZogPbJ_l000001On8?fh01?l0003oT4Qa
oi18LOl00005onAj6003o`000?o2JfOo`V]W00?o`V]W00?o0000ojMJLol000001oobUCd01Ol0003o
^FUbo`000?ocVD?o000007cooo]Z00?o0000oookJ_oonfX0?OoonfX8o`0005oooo]Z001ToookJQ7o
0000N_oonfX00ol0003oJ2IWofPVI`03ofPVI`05o`000?mh<V[oN39ZogPbJ_l000001On8?fh01?l0
003oT4Qaoi18LOl00004onAj6003o`000?o2JfOo`V]W00Co`V]W00Co0000ojMJLonWFW?o00001_ob
UCd00ol0003o^FUbo`000002oo>I@`03o`000?oonf[ooo]Z00Cooo]Z0_l0001coookJP03o`000?oo
nf[ooo]Z03kooo]Z1ol0001OoookJP00H_oonfX@o`0007gooo]Z00?o0000ofPVIomX9VL00_mX9VL0
0ol0003oN39ZogPbJP02ogPbJP03o`000?n8?fkoR3m^00?oR3m^00Go0000oi18LOn@B77oT4Qao`00
0003onAj6003o`000?o2JfOo`V]W00Co`V]W00Co0000ojMJLonWFW?o00001_obUCd00ol0003o^FUb
o`000003oo>I@`03o`000?oonf[ooo]Z00?o000000?o]Sl0o`000?oonfX0L_oonfX00ol0003ooo]Z
oookJP0noookJPSo0000G_oonfX005oooo]Z4Ol0001noookJP;o00001?mX9VL00ol0003oN39ZogPb
JP02ogPbJP03o`000?n8?fkoR3m^00?oR3m^00Go0000oi18LOn@B77oT4Qao`000003onAj6003o`00
0?o2JfOo`V]W00Co`V]W00Co0000ojMJLonWFW?o00001_obUCd00ol0003o^FUbo`000003oo>I@`?o
00000onf?`03o`0007;ooo]Z00?o0000oookJ_oonfX0?ooonfX8o`0005gooo]Z001MoookJQ3o0000
POoonfX2o`0000CoJ2IW00?o0000ogPbJ_mh<VX00_mh<VX00ol0003oR3m^ohPoKP03ohPoKP05o`00
0?n@B77oT4Qaoi18LOl000000ooTNQP00ol0003o`V]Wol9[I`04ol9[I`04o`000?nWFW?oYeYco`00
00KolYDm00?o0000okUYL_l000001?ocVD<00ol0003o]Sl0okHo0002okHo00;o000000?om9Y4o`00
0?oonfX0L?oonfX00ol0003ooo]ZoookJP10oookJPOo0000GOoonfX005[ooo]Z4Ol00023oookJP03
o`000?mX9VOoJ2IW00?oJ2IW00?o0000ogPbJ_mh<VX00_mh<VX00ol0003oR3m^ohPoKP03ohPoKP03
o`000?n@B77oT4Qa00;oT4Qa00?o0000onAj6?l000001oo2JfL01?l0003oYeYcojMJLol00006oo:E
?@03o`000?niJG;o000000GoliU300Co0000okHo0?nf?`3o00000_oTS6@00ol0003om9Y4o`00001`
oookJP03o`000?oonf[ooo]Z043ooo]Z2?l0000=oookJPGo001oB_oonfX0027ooo]Z2Ol007l^oook
JQ3o0000PooonfX4o`0000GoJ2IW00?o0000ogPbJ_mh<VX00_mh<VX00ol0003oR3m^ohPoKP03ohPo
KP03o`000?n@B77oT4Qa00;oT4Qa00?o0000onAj6?l000001_o2JfL00ol0003oYeYcojMJL`02ojMJ
L`03o`000?obUCgolYDm00;olYDm00Go0000okUYL_niJG;o^FUbo`000004oo>I@`04o`000?nf?`3o
]Sl0o`0000;oi8aT00Co0000ooBJA?l0003o0000KooonfX00ol0003ooo]ZoookJP11oookJPSo0000
2ooonfX7o`00OdWooo]Z000QoookJPWo001o:ooonfXAo`0008;ooo]Z0ol000001?l@04Ko0000o`00
0?l00004ofPVI`03o`000?mh<V[oN39Z00;oN39Z00?o0000ohPoK_n8?fh00on8?fh00ol0003oT4Qa
oi18L@03oi18L@03o`000?oTNQSo000000Ko`V]W00?o0000ojMJLonWFW<00_nWFW<00ol0003olYDm
oo:E?@02oo:E?@05o`000?niJG;o^FUbokUYL_l000001OocVD<00ol0003o]Sl0o`000002onB<I005
o`000?odVTCo0000oo6C=ol00000K_oonfX00ol0003ooo]ZoookJP12oookJPOo00002ooonfX3o`00
O`04oookJ_l007oo001oo`00OdWooo]Z000QoookJPCo001o;OoonfXAo`0008Cooo]Z00?o0000oa00
A_l@04H00_l@04H3o`0000CoJ2IW00?o0000ogPbJ_mh<VX00_mh<VX00ol0003oR3m^ohPoKP03ohPo
KP03o`000?n@B77oT4Qa00CoT4Qa00?o0000ol9[Ioo2JfL01Oo2JfL00ol0003oYeYcojMJL`02ojMJ
L`03o`000?obUCgolYDm00;olYDm00Go0000okUYL_niJG;o^FUbo`000006oo>I@`05o`000?oTS6Co
i8aTonB<I?l000000_odVT@00ol0003olI<go`00001]oookJP03o`000?oonf[ooo]Z04;ooo]Z2?l0
0009oookJP?o001o0ooonfX3o`00OdSooo]Z000EoookJP[o001o0ooonfX4o`00Ob[ooo]Z4Ol00026
oookJP04o`000?l@04Ko4016oa00AP;o000000?oC0]Io`000?mX9VL00omX9VL00ol0003oN39ZogPb
JP02ogPbJP03o`000?n8?fkoR3m^00?oR3m^00?o0000oi18LOn@B7401?n@B7400ol0003o`V]Wol9[
I`05ol9[I`03o`000?nWFW?oYeYc00;oYeYc00?o0000oo:E?OobUCd00_obUCd01Ol0003o^FUbokUY
L_niJG;o000000KoliU300Go0000onB<I?oTS6Coi8aTo`000002ooBJA004o`000?oaTcOolI<go`00
06cooo]Z00?o0000oookJ_oonfX0@ooonfX8o`0000Sooo]Z0ol007l3oookJP?o001oB?oonfX001Go
oo]Z2_l007l4oookJPGo001o9OoonfXAo`0008Wooo]Z00Co0000oa00A_l@04Ko40160_l000000om<
2eWo0000ofPVI`03ofPVI`03o`000?mh<V[oN39Z00;oN39Z00?o0000ohPoK_n8?fh00on8?fh00ol0
003oT4Qaoi18L@04oi18L@03o`000?o2JfOo`V]W00Go`V]W00?o0000ojMJLonWFW<00onWFW<01Ol0
003olYDmoo:E?OobUCgo000000?o^FUb00?o0000oo>I@oocVD<01?ocVD<00ol0003oi8aTonB<I002
onB<I003o`000?odVTCo000000;olI<g00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP14
oookJPOo00002?oonfX3o`00O`?ooo]Z0ol007m8oookJP009OoonfX4o`00Ob;ooo]Z4Ol0002:oook
JP;o00000ol@04H00ol0003oC0]Io`000005ofPVI`03o`000?mh<V[oN39Z00;oN39Z00?o0000ohPo
K_n8?fh00on8?fh00ol0003oT4Qaoi18L@04oi18L@;o00001_o2JfL00ol0003oYeYcojMJL`03ojMJ
L`05o`000?obUCgolYDmoo:E?Ol000000oniJG800ol0003oliU3oo>I@`03oo>I@`;o00001?oTS6@0
0ol0003om9Y4o`000002oo6C=`;o0000JooonfX00ol0003ooo]ZoookJP14oookJPSo00001ooonfX3
o`00O`?ooo]Z0ol007m8oookJP009_oonfX3o`00Oaoooo]Z4Ol0002=oookJP04o`000?l@04Ko4016
oa00AP;o000000?oC0]Io`000?mX9VL01?mX9VL00ol0003oN39ZogPbJP02ogPbJP03o`000?n8?fko
R3m^00?oR3m^00?o0000oi18LOn@B7401?n@B742o`0000Ko`V]W00?o0000ojMJLonWFW<00onWFW<0
1?l0003olYDmoo:E?Ol00005okUYLP03o`000?ocVD?oliU300;oliU300?o0000olEaK_l000000ooT
S6@01?l0003om9Y4ooBJA?l00002oo6C=`;o0000JooonfX00ol0003ooo]ZoookJP14oookJPSo0000
1_oonfX3o`00O`?ooo]Z0ol007m8oookJP009ooonfX3o`00Oacooo]Z4?l0002@oookJP04o`000?l@
04Ko4016oa00AP;o000000?oC0]Io`000?mX9VL00omX9VL00ol0003oN39ZogPbJP03ogPbJP03o`00
0?n8?fkoR3m^00?oR3m^00?o0000oi18LOn@B7401?n@B742o`0000Ko`V]W00?o0000ojMJLonWFW<0
0onWFW<01?l0003olYDmoo:E?Ol00005okUYLP03o`000?ocVD?oliU300;oliU300?o0000olEaK_l0
00000ooTS6@01?l0003om9Y4ooBJA?l00002oo6C=`03o`000?o_T3;o000006[ooo]Z00?o0000oook
J_oonfX0AOoonfX7o`0000Kooo]Z0ol007l3oookJP?o001oB?oonfX0027ooo]Z0ol007l3oookJP?o
001o6OoonfXAo`00093ooo]Z0ol00003oa00AP04o`000?m<2eWoC0]Io`0000CoJ2IW00?o0000ogPb
J_mh<VX00_mh<VX00ol0003oR3m^ohPoKP03ohPoKP03o`000?n@B77oT4Qa00CoT4Qa00Co0000oiQ<
KonHC6oo00001Oo2JfL00ol0003oYeYcojMJL`03ojMJL`04o`000?obUCgolYDmo`0000Go^FUb00?o
0000oo>I@oocVD<00_ocVD<00ol0003oaG5^o`000003onB<I004o`000?odVTCom9Y4o`0000;olI<g
00?o0000onn@<_l00000IooonfX4o`0004Oooo]Z2?l00005oookJP?o001o0ooonfX3o`00OdSooo]Z
000QoookJP?o001o0ooonfX3o`00OaOooo]Z4?l0002CoookJP?o00000ol@04H01?l0003oC0]Iod`;
FOl00004ofPVI`03o`000?mh<V[oN39Z00;oN39Z00?o0000ohPoK_n8?fh00on8?fh00ol0003oT4Qa
oi18L@04oi18L@04o`000?nHC6ooV4a_o`0000Co`V]W00?o0000ojMJLonWFW<01OnWFW<00ol0003o
lYDmo`000005okUYLP03o`000?ocVD?oliU300;oliU300?o0000olEaK_l000000ooTS6@01?l0003o
m9Y4ooBJA?l00002oo6C=`04o`000?o_T3;o0000o`0006?ooo]Z0ol00002oj?3l0;o0000B?oonfX8
o`0000Gooo]Z0ol007l01?oonf[o001oo`00Ool007m9oookJP008OoonfX4o`00O`;ooo]Z0ol007lD
oookJQ7o0000UOoonfX3o`0000;o40160_l00002od`;F@03o`000?mX9VOoJ2IW00;oJ2IW00?o0000
ogPbJ_mh<VX00_mh<VX00ol0003oR3m^ohPoKP03ohPoKP03o`000?n@B77oT4Qa00CoT4Qa00Co0000
oiQ<KonHC6oo00001?o2JfL00ol0003oYeYcojMJL`05ojMJL`03o`000?obUCgo000000Go^FUb00Go
0000oo>I@oocVD?oliU3o`000002olEaKP03o`000?oTS6Coi8aT00;oi8aT00?o0000ooBJA?l00000
0_oaTcL00ol0003oki0bonn@<P02o`0005oooo]Z0ol00006oj?3l003o`000?oonf[ooo]Z04Kooo]Z
2?l00005oookJPOo001oBOoonfX002;ooo]Z1ol007lBoookJQ7o0000V?oonfX2o`0000?o401600Go
0000od`;FOm<2eWoC0]Io`000004ofPVI`03o`000?mh<V[oN39Z00;oN39Z00?o0000ohPoK_n8?fh0
0on8?fh00ol0003oT4Qaoi18L@04oi18L@05o`000?nHC6ooV4a_oiQ<Kol000000oo2JfL00ol0003o
YeYcojMJL`05ojMJL`03o`000?obUCgo000000Go^FUb00Go0000oo>I@oocVD?oliU3o`000002olEa
KP03o`000?oTS6Coi8aT00;oi8aT00Co0000ooBJA?odVTCo00000_oaTcL01Ol0003oki0bo`000?ob
USco000005_ooo]Z0ol000000onS`o3o0000oj?3l006oj?3l0;o0000B?oonfX8o`0000Gooo]Z1Ol0
07m:oookJP008ooonfX5o`00Oa7ooo]Z4Ol0002IoookJP?o00000ol@04H01?l0003oC0]Iod`;FOl0
0005ofPVI`03o`000?mh<V[oN39Z00;oN39Z00?o0000ohPoK_n8?fh00on8?fh00ol0003oT4Qaoi18
L@04oi18L@05o`000?nHC6ooV4a_oiQ<Kol000000oo2JfL00ol0003oYeYcojMJL`05ojMJL`03o`00
0?obUCgo000000Ko^FUb00Co0000oo>I@oocVD?o00000_o5LFh00ol0003oi8aTonB<I002onB<I004
o`000?odVTCom9Y4o`0000;olI<g00Go0000onn@<_l0003olYHlo`00001IoookJP;o00001OnS`o00
0ol0003oXl?`oj?3l004oj?3l003o`000?nS`o3o000004Sooo]Z1ol0001DoookJP00=_oonfXAo`00
09cooo]Z0ol00002oa00AP;o00000_m<2eT00ol0003oJ2IWofPVI`02ofPVI`03o`000?mh<V[oN39Z
00?oN39Z00?o0000ohPoK_n8?fh00on8?fh00ol0003oT4Qaoi18L@04oi18L@05o`000?nHC6ooV4a_
oiQ<Kol000000oo2JfL00ol0003oYeYcojMJL`05ojMJL`;o00001oniJG801?l0003oliU3oo>I@ol0
0003olEaKP05o`000?oTS6Coi8aTonB<I?l000000_odVT@02?l0003olI<goo6C=ol0003oki0bo`00
0?obUSco0000E_oonfX3o`0000SoXl?`00?o0000oj?3l?nS`o000_nS`o05o`0004Sooo]Z1ol0001C
oookJP00=?oonfXAo`0009kooo]Z0ol00002oa00AP05o`000?m<2eWoC0]Iod`;FOl000001?mX9VL0
0ol0003oN39ZogPbJP03ogPbJP03o`000?n8?fkoR3m^00?oR3m^00?o0000oi18LOn@B7401?n@B740
0ol0003oV4a_oiQ<K`02oiQ<K`04o`000?o2JfOo`V]Wo`0000SoYeYc00?o0000okUYL_niJG801Oni
JG801?l0003oliU3oo>I@ol00003olEaKP05o`000?oTS6Coi8aTonB<I?l000000_odVT@02?l0003o
lI<goo6C=ol0003oki0bo`000?obUSco0000DooonfX3o`0000;oXl?`00?o0000oj?3l?nS`o001onS
`o06o`0000;oXl?`00?o0000oookJ_oonfX0A_oonfX8o`0005;ooo]Z000aoookJQ7o0000XOoonfX3
o`0000;o401600Go0000od`;FOm<2eWoC0]Io`000004ofPVI`03o`000?mh<V[oN39Z00;oN39Z00?o
0000ohPoK_n8?fh01?n8?fh00ol0003oT4Qaoi18L@04oi18L@03o`000?nHC6ooV4a_00;oV4a_00Co
0000ol9[Ioo2JfOo00002?nWFW<00ol0003o^FUbokUYLP05okUYLP03o`000?ocVD?o000000CoaG5^
00Go0000onB<I?oTS6Coi8aTo`000003ooBJA003o`000?oaTcOo000000;oki0b00?o0000oo:F??l0
0000CooonfX3o`0000KoXl?`00?o0000oj?3l?nS`o001?nS`o05o`0000?oXl?`00Co0000oj?3l?nS
`o3o0000B?oonfX7o`0005;ooo]Z000`oookJPoo0000Y?oonfX3o`000003oa00A_l0003o000000?o
C0]I00?o0000ofPVIomX9VL00_mX9VL00ol0003oN39ZogPbJP02ogPbJP03o`000?n8?fkoR3m^00?o
R3m^00?o0000oi18LOn@B7401?n@B7400ol0003oV4a_oiQ<K`03oiQ<K`04o`000?o2JfOo`V]Wo`00
00SoYeYc00?o0000okUYL_niJG801OniJG800ol0003oliU3o`000004olEaKP03o`000?oTS6Coi8aT
00;oi8aT00Co0000ooBJA?odVTCo00000_oaTcL01Ol0003oki0bo`000?obUSco000004cooo]Z0ol0
00000onS`o3o0000oj?3l007oj?3l003o`000?nS`o3oXl?`00Co00000_nS`o000ol0003oXl?`oj?3
l003oj?3l004o`000?nS`o3oXl?`o`0004Oooo]Z2?l0001AoookJP00<?oonfX=o`000:Gooo]Z0ol0
0002oa00AP;o00000om<2eT00ol0003oJ2IWofPVI`02ofPVI`03o`000?mh<V[oN39Z00;oN39Z00?o
0000ohPoK_n8?fh00on8?fh00ol0003oT4Qaoi18L@04oi18L@03o`000?nHC6ooV4a_00CoV4a_0_l0
0009ojMJL`03o`000?niJG;o^FUb00Go^FUb00?o0000oo>I@ol000001?o5LFh00ol0003oi8aTonB<
I002onB<I004o`000?odVTCom9Y4o`0000;olI<g00Go0000onn@<_l0003olYHlo`000019oookJP?o
00001OnS`o000ol0003oXl?`oj?3l005oj?3l0?o00001onS`o000ol0003oXl?`oj?3l003oj?3l004
o`000?nS`o3o0000o`0004Oooo]Z2?l0001@oookJP00<?oonfX:o`000:Sooo]Z0ol00002oa00AP05
o`000?m<2eWoC0]Iod`;FOl000001?mX9VL00ol0003oN39ZogPbJP03ogPbJP03o`000?n8?fkoR3m^
00?oR3m^00?o0000oi18LOn@B7401?n@B7400ol0003oV4a_oiQ<K`04oiQ<K`;o00002?nWFW<00ol0
003o[5Y/o`000006okUYLP03o`000?ocVD?o000000CoaG5^00?o0000onB<I?oTS6@00_oTS6@01?l0
003om9Y4ooBJA?l00002oo6C=`05o`000?o_T3;o0000oo:F??l00000A_oonfX3o`0000WoXl?`00Co
0000oj?3l?nS`o3oXl?`0ol000000onS`o3o0000oj?3l008oj?3l004o`000?nS`o3oXl?`oj?3l0?o
000000?oXl?`o`000?oonfX0AooonfX7o`00053ooo]Z000`oookJPSo0000Z_oonfX3o`000003oa00
A_l0003o000000?oC0]I00?o0000ofPVIomX9VL00_mX9VL00ol0003oN39ZogPbJP03ogPbJP03o`00
0?n8?fkoR3m^00?oR3m^00?o0000oi18LOn@B7401?n@B7400ol0003oV4a_oiQ<K`04oiQ<K`;o0000
2?nWFW<00ol0003o[5Y/o`000007okUYLP;o00001?o5LFh00ol0003oi8aTonB<I002onB<I00;o`00
0?odVTCom9Y4ooBJA?l0003olI<go`000?o_T3;o0000oo:F??l00000@ooonfX3o`0000?oXl?`00?o
0000oj?3l?nS`o001_nS`o04o`0000GoXl?`00?o0000oj?3l?nS`o001_nS`o001?l0003oXl?`o`00
0?l00002oj?3l004o`000?nS`o3oXl?`o`0004Oooo]Z2?l0001?oookJP00;ooonfX7o`000:cooo]Z
0ol000000ol@04Ko0000o`000003od`;F@03o`000?mX9VOoJ2IW00;oJ2IW00?o0000ogPbJ_mh<VX0
0omh<VX00ol0003oR3m^ohPoKP03ohPoKP03o`000?n@B77oT4Qa00CoT4Qa00?o0000oiQ<KonHC6l0
1OnHC6l00ol0003oYeYcojMJL`06ojMJL`03o`000?n/FVco000000Oo^FUb00?o0000olEaK_o5LFh0
1?o5LFh01Ol0003oi8aTonB<I?oTS6Co000000?om9Y400?o0000oo6C=ol000000_o_T382o`0003oo
oo]Z1?l00007oj?3l003o`000?nS`o3oXl?`00?oXl?`1?l00008oj?3l003o`000?nS`o3oXl?`00Co
Xl?`0ol00005oj?3l004o`000?nS`o3oXl?`o`0004Oooo]Z2?l0001>oookJP00;ooonfX6o`000003
oookJ_l0003ooo]Z0:[ooo]Z00Co0000o`005_l0003o40160_l00003od`;F@03o`000?mX9VOoJ2IW
00;oJ2IW00?o0000ogPbJ_mh<VX00omh<VX00ol0003oR3m^ohPoKP03ohPoKP03o`000?n@B77oT4Qa
00CoT4Qa00?o0000oiQ<KonHC6l01OnHC6l00ol0003oYeYcojMJL`06ojMJL`03o`000?n/FVco0000
00Oo^FUb00?o0000olEaK_o5LFh01?o5LFh00ol0003oi8aTonB<I002onB<I004o`000?odVTCom9Y4
o`0000;olI<g00Go0000onn@<_l0003olYHlo`00000koookJP?o00000_nS`o000ol0003oXl?`oj?3
l007oj?3l003o`000?nS`o3oXl?`00?o00000onS`o000ol0003oXl?`oj?3l006oj?3l003o`000?nS
`o3oXl?`00?o00000_nS`o000ol0003oXl?`oj?3l003oj?3l005o`000?nS`o3oXl?`oj?3l?l00000
AooonfX7o`0004kooo]Z000_oookJPKo00000_oonfX00ol0003ooo]ZoookJP2WoookJP?o000000Co
4016o`000?lM03co00000om<2eT00ol0003oJ2IWofPVI`02ofPVI`03o`000?mh<V[oN39Z00;oN39Z
00?o0000ohPoK_n8?fh01?n8?fh00ol0003oT4Qaoi18L@04oi18L@03o`000?nHC6ooV4a_00GoV4a_
00?o0000ojMJLonWFW<01OnWFW<01?l0003o[5Y/ojaJK?l00007okUYLP03o`000?o5LFkoaG5^00Co
aG5^00?o0000onB<I?oTS6@00_oTS6@01?l0003om9Y4ooBJA?l00002oo6C=`05o`000?o_T3;o0000
oo:F??l00000>?oonfX3o`0000KoXl?`00?o0000oj?3l?nS`o001_nS`o03o`0000OoXl?`00?o0000
oj?3l?nS`o001?nS`o04o`0000KoXl?`00?o0000oj?3l?nS`o000onS`o000ol0003oXl?`o`000002
o`0004Kooo]Z2?l0001=oookJP00;ooonfX6o`0000?ooo]Z00?o0000oookJ_oonfX0Y_oonfX3o`00
0004oa00A_l0003o7@0lo`0000?oC0]I00?o0000ofPVIomX9VL00_mX9VL00ol0003oN39ZogPbJP02
ogPbJP03o`000?n8?fkoR3m^00CoR3m^00?o0000oi18LOn@B7400on@B7400ol0003oV4a_oiQ<K`06
oiQ<K`;o00001_nWFW<01Ol0003o[5Y/ojaJK?n/FVco000000Ko^FUb00?o0000olEaK_o5LFh01?o5
LFh00ol0003oi8aTonB<I002onB<I004o`000?odVTCom9Y4o`0000;olI<g00Go0000onn@<_l0003o
lYHlo`00000eoookJP?o000000?oX/?`o`000?nS`o001onS`o000ol0003oXl?`oj?3l002oj?3l0?o
000000?oXl?`o`000?nS`o002?nS`o000ol0003oXl?`oj?3l003o`0000;oXl?`00?o0000oj?3l?nS
`o001_nS`o000ol0003oXl?`oj?3l004o`0000;oXl?`00?o0000oookJ_oonfX0AOoonfX8o`0004co
oo]Z000_oookJPGo00001OoonfX00ol0003ooo]ZoookJP2UoookJP?o000000?o4016o`000?l00000
0om<2eT00ol0003oJ2IWofPVI`02ofPVI`03o`000?mh<V[oN39Z00;oN39Z0ol00004ohPoKP03o`00
0?n@B77oT4Qa00CoT4Qa00?o0000oiQ<KonHC6l01OnHC6l00ol0003oWTeXo`000006ojMJL`05o`00
0?n/FVco[5Y/ojaJK?l000001OniJG800ol0003o^fAXo`000005olEaKP03o`000?oTS6Coi8aT00;o
i8aT00Oo0000ooBJA?odVTCom9Y4o`000?oaTcOo000000;oki0b0_l0000coookJP;o00001OnR`o00
0ol0003oXl?`oj?3l006oj?3l0Co00001OnS`o000ol0003oXl?`oj?3l006oj?3l0?o00001_nS`o00
0ol0003oXl?`oj?3l004oj?3l0Co00001?nS`o001?l0003oXl?`oj?3l?l00017oookJPOo0000C?oo
nfX001Wooo]Z0ol007l5oookJPGo001o2OoonfX5o`0000Kooo]Z00?o0000oookJ_oonfX0Y?oonfX0
1_l0003o000Fo`000?l0003o7@0lo`0000?oC0]I00?o0000ofPVIomX9VL00_mX9VL00ol0003oN39Z
o`000002o`000003og8WG_l0003oOc9R00;o00000_n8?fh00ol0003oT4Qaoi18L@04oi18L@03o`00
0?nHC6ooV4a_00GoV4a_00?o0000oii=J?l000001_nWFW<01Ol0003o[5Y/ojaJK?n/FVco000000Go
^FUb00?o0000ok]TJ?l000001Oo5LFh00ol0003oi8aTonB<I002onB<I004o`000?odVTCom9Y4ooBJ
A0?o00000_o_T382o`00033ooo]Z0ol00008oj;3l003o`000?nS`o3oXl?`00?oXl?`1?l00008oj?3
l003o`000?nS`o3oXl?`00;oXl?`0ol000000onS`o3o0000oj?3l007oj?3l003o`000?nS`o3oXl?`
00?o00000_nS`o000ol0003oXl?`oj?3l003oj?3l005o`000?nS`o3oXl?`oj?3l?l00000A_oonfX8
o`0004_ooo]Z000IoookJP?o001o1?oonfX7o`00O`Sooo]Z1Ol00007oookJP03o`000?oonf[ooo]Z
0:?ooo]Z00Ko0000o`005_l0003o0000oad0??l00003od`;F@03o`000?mX9VOoJ2IW00;oJ2IW0_l0
0004og8WGP04o`000?mo<V;oOc9RoglbHP?o00001_n@B7400ol0003oV4a_oiQ<K`05oiQ<K`04o`00
0?nNCFSoWTeXo`0000CoYeYc00?o0000ojaJK?n/FV`00_n/FV`00ol0003o^FUbokUYLP03okUYLP03
o`000?nkI6So000000GoaG5^00?o0000onB<I?oTS6@00_oTS6@01_l0003om9Y4ooBJA?odVTCo0000
oo2C@`;o000000?oki0bo`000?l00000;OoonfX3o`0000?oX/Ca00?o0000oj;3l?nR`o001_nR`o00
0ol0003oXl?`o`000003o`0000;oX/?`00?o0000oj?3l?nS`o001_nS`o000ol0003oXl?`o`000002
o`0000GoXl?`00?o0000oj?3l?nS`o001OnS`o03o`0000KoXl?`00?o0000oj?3l?nS`o000onS`o00
0ol0003oXl?`oj?3l002o`0004Kooo]Z2?l0001:oookJP006OoonfX3o`00O`?ooo]Z1?l007l01?oo
nf[o001oo`00Ool007l7oookJPKo00002?oonfX00ol0003ooo]ZoookJP2QoookJP;o000000Go000F
o`000?l0003o7@0lo`000003od`;F@03o`000?mX9VOoJ2IW00;oJ2IW00?o0000og8WG_mb9eh00_mb
9eh00ol0003oOc9RoglbHP04oglbHP03o`000?n@B77oT4Qa00CoT4Qa00?o0000oiQ<KonHC6l01OnH
C6l01?l0003oWTeXoii=J?l00004ojMJL`03o`000?n/FVco[5Y/00?o[5Y/00?o0000okUYL_niJG80
0_niJG800ol0003o^fAXo`000006olEaKP03o`000?oTS6Coi8aT00;oi8aT00Co0000ooBJA?l0003o
00000_o`Td<01Ol0003oki0bo`000?obUSco000002Sooo]Z1?l00007oj;4l@03o`000?nR`o3oX/?`
00CoX/?`1?l00006oj;3l003o`000?nS`o3oXl?`00CoXl?`0ol00009oj?3l004o`000?nS`o3oXl?`
oj?3l0?o000000?oXl?`o`000?nS`o001onS`o000ol0003oXl?`oj?3l002oj?3l0?o000000?oXl?`
o`000?oonfX0A_oonfX7o`0004[ooo]Z0009oookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oook
JP?o001o1_oonfX6o`0000Wooo]Z00?o0000oookJ_oonfX0X?oonfX4o`0000;o7@0l00Go0000od`;
FOm<2eWoC0]Io`000003ofPVI`;o00001?mb9eh00ol0003oOc9RoglbHP04oglbHP03o`000?n@B77o
T4Qa00CoT4Qa00?o0000oiQ<KonHC6l01OnHC6l01?l0003oWTeXoii=J?l00004ojMJL`03o`000?n/
FVco[5Y/00?o[5Y/00Go0000okUYL_niJG;o^FUbo`000003ok]TJ003o`000?o5LFkoaG5^00?oaG5^
00?o0000onB<I?oTS6@00_oTS6@2o`0000;oiXQF00Oo0000oo2C@ol0003oki0bo`000?obUSco0000
02Gooo]Z0ol00002oj;4l@03o`000?nRa?7oX/Ca00OoX/Ca00?o0000oj;3l?nR`o000ol00002oj;3
l@03o`000?nR`o3oX/?`00KoX/?`00?o0000oj?3l?nS`o000ol00003oj;3l003o`000?nS`o3oXl?`
00KoXl?`00Co0000oj?3l?l0003o00001OnS`o000ol0003oXl?`oj?3l006oj?3l004o`000?nS`o3o
0000o`0000;oXl?`00Co0000oj?3l?nS`o3o0000A_oonfX8o`0004Wooo]Z0009oookJP[o001o1_oo
nfX3o`00O`Wooo]Z0ol007l6oookJPKo00002_oonfX00ol0003ooo]ZoookJP2OoookJP04o`000?l0
01Ko0000o`0000;o7@0l00Go0000od`;FOm<2eWoC0]Io`000002ofPVI`;o00001Omb9eh00ol0003o
Oc9RoglbHP04oglbHP;o00001On@B7400ol0003oV4a_oiQ<K`04oiQ<K`03o`000?nNCFSoWTeX00;o
WTeX00Go0000ojMJLonWFW?oYeYco`000005ojaJK005o`000?niJG;o^FUbokUYL_l000000onkI6P0
0ol0003oaG5^olEaKP03olEaKP03o`000?oTS6Coi8aT00;oi8aT00Ko0000onJ8E_oVR5KoiXQFo`00
0?o`Td<2o`000003onn@<_l0003o000002;ooo]Z0ol00006oj;4l@03o`000?nRa?7oX/Ca00GoX/Ca
1?l00006oj;3l@03o`000?nR`o3oX/?`00CoX/?`1?l00007oj;3l003o`000?nS`o3oXl?`00CoXl?`
0ol00008oj?3l003o`000?nS`o3oXl?`00CoXl?`0ol00004oj?3l005o`000?nS`o3oXl?`oj?3l?l0
0000A_oonfX8o`0004Sooo]Z000IoookJP?o001o2OoonfX3o`00O`Kooo]Z1_l0000;oookJP03o`00
0?oonf[ooo]Z09kooo]Z00Ko0000o`005_l0003o0000oad0??l00004od`;F@05o`000?mX9VOo0000
oelDEOl000001Omb9eh00ol0003oOc9RoglbHP03oglbHP04o`000?n8>F;oR3URo`0000CoT4Qa00?o
0000oiQ<KonHC6l01?nHC6l00ol0003oWTeXoii=J002oii=J005o`000?nWFW?oYeYcojMJLol00000
1On/FV`01Ol0003o^FUbokUYL_niJG;o000000?o^fAX00?o0000olEaK_o5LFh00oo5LFh00ol0003o
i8aTonB<I002onB<I005o`000?oVR5KoiXQFonJ8E_l000000_o`Td<01?l0003oki0bo`000?l0000O
oookJP?o000000?oXLCao`000?nRa?401onRa?400ol0003oX/Caoj;4l@05o`000003oj;4lOl0003o
X/?a00OoX/?a00?o0000oj;3l?nR`o000ol00003oj;3l003o`000?nR`o3oX/?`00KoX/?`00?o0000
oj?3l?nS`o000ol00002oj;3l003o`000?nS`o3oXl?`00KoXl?`00?o0000oj?3l?nS`o001?l00002
oj?3l003o`000?nS`o3oXl?`00?oXl?`00Co0000oj?3l?nS`o3o0000AooonfX7o`0004Sooo]Z000I
oookJP?o001o1?oonfX2o`00O`;ooo]Z1?l007l6oookJPGo00003OoonfX00ol0003ooo]ZoookJP2M
oookJP03o`000?l001Ko000000;o7@0l00Oo0000od`;FOm<2eWoC0]Io`000?mX9VOo000000;oGaAE
00?o0000og8WG_mb9eh00omb9eh00ol0003oOc9RoglbHP03oglbHP05o`000?n8>F;oR3URohPiH_l0
00000_n@B7400ol0003oV4a_oiQ<K`05oiQ<K`03o`000?nNCFSoWTeX00;oWTeX00Co0000ojMJLonW
FW?o00001on/FV`01?l0003o^FUbokUYL_l00003ok]TJ003o`000?o5LFkoaG5^00?oaG5^00Co0000
onB<I?oTS6Coi8aT0_l00003onJ8EP03o`000?o`Td?ol9=300Co00007OoonfX2o`0000GoXLCa00?o
0000oj;4lOnRa?401OnRa?46o`0000CoX/Ca00?o0000oj;3lOnR`o401OnR`o43o`0000OoX/?`00?o
0000oj;3l?nR`o001?nR`o04o`0000KoX/?`00?o0000oj?3l?nS`o001?nS`o04o`0000OoXl?`00?o
0000oj?3l?nS`o000onS`o04o`0004Kooo]Z2?l00017oookJP006OoonfX3o`00O`Cooo]Z1ol007l7
oookJPGo00003_oonfX2o`0009cooo]Z0_l000001Ol001Ko0000oad0??lM03co000000?oC0]I0_l0
0003oelDE@03o`000?mb9ekoLRMN00;oLRMN00?o0000oglbH_mo<V801?mo<V800ol0003oR3URohPi
HP02ohPiHP03o`000?n@B77o000000OoV4a_00?o0000oii=J?nNCFP00onNCFP00ol0003oYeYco`00
0007ojaJK003o`000?niJG;o000000Go^fAX00?o0000olEaK_o5LFh00_o5LFh01ol0003oi8aTonB<
I?oTS6Co0000omMjG?l000000_oVR5H00ol0003ol9=3oo2C@`04o`0001[ooo]Z0ol00008oj74l@04
o`000?nRa?7oX/Caoj;4l@Ko00002?nRa?401?l0003oX/?aoj;3lOnR`o43o`000003oj;3lOl0003o
X/?`00SoX/?`00?o0000oj;3l?nR`o000ol00002oj;3l003o`000?nR`o3oX/?`00KoX/?`00?o0000
oj?3l?nS`o000ol00003oj;3l003o`000?nS`o3oXl?`00KoXl?`00?o0000oj?3l?nS`o000ol00002
oj?3l003o`000?oonf[ooo]Z04Gooo]Z2?l00016oookJP006OoonfX3o`00O`Cooo]Z1_l007l7oook
JPKo00004?oonfX00ol0003ooo]ZoookJP2IoookJP04o`000?l001Ko0000o`0000;o7@0l00Go0000
od`;FOm<2eWoC0]Io`000004oelDE@03o`000?mb9ekoLRMN00;oLRMN00?o0000oglbH_mo<V801?mo
<V800ol0003oR3URohPiHP03ohPiHP;o00001onHC6l00ol0003oWTeXoii=J003oii=J003o`000?nW
FW?o000000Oo[5Y/00?o0000okUYL_l000001OnkI6P00ol0003oaG5^olEaKP02olEaKP04o`000?oT
S6Coi8aTo`0000;oegYL00So0000onJ8E_oVR5KoiXQFo`000?o`Td?o0000on^C7`;o00005ooonfX3
o`0000;oXLCb00?o0000oj74lOnQa?401_nQa?400ol0003oX/Cao`000004o`0000;oXLCa00?o0000
oj;4lOnRa?401_nRa?401?l0003oX/?ao`000?l00005oj;3l@03o`000?nR`o3oX/?`00KoX/?`0ol0
0006oj;3l003o`000?nR`o3oX/?`00CoX/?`1?l00007oj;3l003o`000?nS`o3oXl?`00CoXl?`1?l0
0003oj?3l004o`000?nS`o3oXl?`o`0004Oooo]Z1ol00016oookJP005_oonfX6o`00O`Cooo]Z0_l0
07l;oookJPKo00004OoonfX00ol0003ooo]ZoookJP2HoookJP03o`000?l001Ko000000?o7@0l00Go
0000od`;FOm<2eWoC0]Io`000003oelDE@03o`000?mb9ekoLRMN00?oLRMN00?o0000oglbH_mo<V80
1?mo<V800ol0003oR3URohPiHP04ohPiHP03o`000?nHC6ooV4a_00GoV4a_00?o0000oii=J?nNCFP0
0onNCFP00ol0003oYeYco`000007ojaJK003o`000?niJG;o000000Go^fAX00?o0000olEaK_o5LFh0
0oo5LFh2o`0000?oegYL00So0000onJ8E_oVR5KoiXQFo`000?o`Td?o0000on^C7`?o00004_oonfX4
o`0000KoXLCb00?o0000oj74lOnQa?401?nQa?45o`0000KoXLCa00?o0000oj;4lOnRa?401?nRa?43
o`0000SoX/?a00?o0000oj;3l?nR`o000_nR`o03o`000003oj;3lOl0003oX/?`00OoX/?`00?o0000
oj;3l?nR`o000ol00002oj;3l003o`000?nR`o3oX/?`00OoX/?`00?o0000oj?3l?nS`o000ol00002
oj;3l003o`000?nS`o3oXl?`00?oXl?`00Co0000oj?3l?nS`o3o0000A_oonfX8o`0004Gooo]Z000F
oookJPKo001o1?oonfX2o`00O`_ooo]Z1_l0000BoookJP03o`000?oonf[ooo]Z09Oooo]Z00?o0000
o`005_l000000olM03`00ol0003oC0]Iod`;F@02o`0000?oGaAE00?o0000og8WG_mb9eh00omb9eh0
0ol0003oOc9RoglbHP03oglbHP03o`000?n8>F;oR3UR00GoR3UR00?o0000oiQ<KonHC6l01?nHC6l0
0ol0003oWTeXoii=J005oii=J003o`000?n/FVco[5Y/00Ko[5Y/00?o0000okUYL_l000001_nkI6P0
0ol0003oaG5^olEaKP02olEaKP;o00000ooGNU`01Ol0003oiXQFonJ8E_oVR5Ko000000;ol9=300Co
0000on^C7ol0003o00003ooonfX3o`0000?oX<Gb00?o0000oj74l_nQa?801OnQa?800ol0003oXLCa
oj74l@05o`000003oj74l_l0003oXLCa00OoXLCa00?o0000oj;4lOnRa?400ol00003oj74l@03o`00
0?nR`o7oX/?a00KoX/?a00Co0000oj;3l?l0003o00001OnR`o400ol0003oX/?`oj;3l005oj;3l0?o
00001_nR`o000ol0003oX/?`oj;3l006oj;3l0?o00001_nR`o000ol0003oXl?`oj?3l003oj?3l0Co
0000A_oonfX8o`0004Cooo]Z000HoookJPCo001o1OoonfX7o`00O`Gooo]Z1_l0000CoookJP03o`00
0?oonf[ooo]Z09Kooo]Z00?o0000o`005_l000000_lM03`01Ol0003oC0]Iod`;FOm<2eWo000000Co
GaAE00?o0000og8WG_mb9eh00omb9eh00ol0003oOc9RoglbHP03oglbHP03o`000?n8>F;oR3UR00Go
R3UR0_l00005oiQ<K`03o`000?nNCFSoWTeX00GoWTeX00?o0000ojaJK?n/FV`01on/FV`00ol0003o
^fAXok]TJ005ok]TJ003o`000?o5LFkoaG5^00;oaG5^00?o0000omMjG?oGNU`00ooGNU`01?l0003o
iXQFonJ8E_l00002oo2C@`04o`000?o[Taoo0000o`0000_ooo]Z1?l00007oj35lP03o`000?nQa?;o
XLCb00CoXLCb1Ol00005oj74lP03o`000?nQa?7oXLCa00CoXLCa1?l00007oj74l@03o`000?nR`o7o
X/?a00CoX/?a0ol00008oj;3l@04o`000?nR`o3oX/?`oj;3l0?o000000?oX/?`o`000?nR`o001onR
`o000ol0003oX/?`oj;3l002oj;3l0?o000000?oX/?`o`000?nR`o001onR`o000ol0003oXl?`oj?3
l003o`0000;oXl?`00?o0000oookJ_oonfX0AOoonfX7o`0004Cooo]Z000IoookJP?o001o1OoonfX7
o`00O`Gooo]Z1Ol0000EoookJP03o`000?oonf[ooo]Z09Cooo]Z00Co0000o`005_l0003o00000_lM
03`00ol0003oC0]Iod`;F@02o`0000CoGaAE00?o0000og8WG_mb9eh00_mb9eh00ol0003oOc9Roglb
HP04oglbHP03o`000?n8>F;oR3UR00CoR3UR00Co0000oi0kG_n@>eko00001?nHC6l00ol0003oWTeX
oii=J005oii=J003o`000?n/FVco[5Y/00Oo[5Y/00?o0000ok]TJ?nkI6P01OnkI6P00ol0003oaG5^
olEaKP02olEaKP03o`000?oGNUcoegYL00?oegYL00Co0000onJ8E_oVR5Ko00000_o`Td<01?l0003o
ji<Oo`000?l00008oookJP?o00000onPaO<00ol0003oX<Gboj35lP06oj35lP03o`000?nQa?;oXLCb
00Ko00002?nQa?800ol0003oXLCaoj74l@03o`0000?oXLCa00?o0000oj74lOnQa?401_nQa?400ol0
003oX/?aoj;3l@03o`0000;oXL?a00?o0000oj;3lOnR`o401_nR`o401?l0003oX/?`o`000?l00005
oj;3l003o`000?nR`o3oX/?`00KoX/?`00Co0000oj;3l?l0003o00001OnR`o000ol0003oX/?`oj;3
l005oj;3l0?o00000onS`o001?l0003oXl?`oj?3l?l00016oookJPSo0000@ooonfX002gooo]Z1Ol0
000FoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000o`005_l000000olM03`00ol0003oC0]Iod`;
F@02o`0000CoGaAE00?o0000og8WG_mb9eh00_mb9eh00ol0003oOc9RoglbHP04oglbHP03o`000?n8
>F;oR3UR00CoR3UR00Go0000oi0kG_n@>ekoT3]No`000003oiQ<K`03o`000?nNCFSoWTeX00GoWTeX
0_l00008ojaJK003o`000?nkI6So^fAX00Go^fAX00Co0000olEaK_o5LFkoaG5^0_l00005omMjG007
o`000?oVR5KoiXQFonJ8E_l0003ol9=3o`000002on^C7`03o`000?oonf[ooo]Z00;ooo]Z1?l00007
oj35l`03o`000?nPaO;oX<Gb00CoX<Gb1_l00004oj34lP03o`000?nQa?;oXLCb00CoXLCb1?l00007
oj74l@03o`000?nQa?7oXLCa00CoXLCa1?l00006oj73l@03o`000?nR`o7oX/?a00CoX/?a0ol00008
oj;3l003o`000?nR`o3oX/?`00CoX/?`0ol00008oj;3l004o`000?nR`o3oX/?`oj;3l0?o000000?o
X/?`o`000?nS`o001?nS`o001?l0003oXl?`oj?3l?l00016oookJPSo0000@_oonfX002cooo]Z1_l0
000GoookJP03o`000?oonf[ooo]Z09;ooo]Z00?o0000o`005_l000000olM03`01Ol0003oC0]Io`00
0?m104;o000000?oGaAE00?o0000og8WG_mb9eh00omb9eh00ol0003oOc9RoglbHP03oglbHP03o`00
0?n8>F;oR3UR00GoR3UR00Go0000oi0kG_n@>ekoT3]No`000003oiQ<K`03o`000?nNCFSoWTeX00Co
WTeX00?o0000oj=:GOl000001on/FV`00ol0003o/EELo`000007ok]TJ006o`000?o5LFkoaG5^o`00
0?o:Je[o00001?oGNU`01ol0003oiXQFonJ8E_oVR5Ko0000oo2C@ol000000_o[Tal00ol0003ooo]Z
o`000002o`0000?oWlGc00?o0000oj35lonPaO<01_nPaO<00ol0003oX<Gboj35lP03o`000004oio5
l_l0003o0000o`0000OoX<Cb00?o0000oj74l_nQa?800ol00003oj34lP03o`000?nQa?7oXLCa00Ko
XLCa00?o0000oj74lOnQa?400ol00002oj74l@03o`000?nQ`o7oXL?a00KoXL?a00?o0000oj;3lOnR
`o400ol00003oj73l@03o`000?nR`o3oX/?`00KoX/?`00?o0000oj;3l?nR`o000ol00002oj;3l003
o`000?nR`o3oX/?`00KoX/?`00Co0000oj;3l?l0003o00001OnR`o000ol0003oXl?`oj?3l003oj?3
l004o`000?nS`o3oXl?`o`0004Kooo]Z1ol00012oookJP00;?oonfX6o`0001Sooo]Z00?o0000oook
J_oonfX0TOoonfX3o`0000?o7@0l0_l00002od40@P05o`000?mO55GoGaAEoelDEOl000001Omb9eh0
0ol0003oOc9RoglbHP03oglbHP03o`000?n8>F;oR3UR00CoR3UR00?o0000oi0kG_n@>eh00on@>eh0
0ol0003oV4a_o`000007oii=J004o`000?nSBUgoXdYMo`0000Ko[5Y/00?o0000ok5EG?l000001onk
I6P01_l0003oaG5^olEaK_l0003obV]Jo`0000GoegYL00Co0000onJ8E_oVR5Ko00000_o`Td<4o`00
00OoWlGc00?o0000oj35lonPaO<01?nPaO<4o`000004oio5l_l0003o0000o`0000;oWlGb00?o0000
oj34l_nPa?801?nPa?84o`0000OoX<Cb00?o0000oj74lOnQa?401?nQa?44o`0000KoXLCa00?o0000
oj73lOnQ`o401?nQ`o44o`0000OoXL?a00?o0000oj;3l?nR`o001?nR`o04o`0000KoX/?`00?o0000
oj;3l?nR`o001?nR`o03o`0000SoX/?`00?o0000oj?3l?nS`o000_nS`o000ol0003oXl?`o`000002
o`0004Gooo]Z2?l00011oookJP00;?oonfX6o`0001Wooo]Z00?o0000oookJ_oonfX0SooonfX01?l0
003o000Fo`000?l00003oad0?0;o000000?o@@12o`000?mO55D00omO55D00ol0003oLRMNog8WGP03
og8WGP03o`000?mo<V;oOc9R00?oOc9R00?o0000ohPiH_n8>F801?n8>F800ol0003oT3]Noi0kGP04
oi0kGP;o00001onNCFP01?l0003oXdYMoj=:GOl00006ojaJK003o`000?naEEco000000Oo^fAX00?o
0000olEaK_l000000_o:JeX00ol0003oegYLomMjG003omMjG003o`000?oVR5KoiXQF00?o00000onN
a_@00ol0003oWlGcoio5l`06oio5l`03o`000?nPaO?oX<Gc00?o00000_nOaO<3o`0000KoWlGb00?o
0000oj34l_nPa?800ol00003oio4lP03o`000?nPa?;oX<Cb00KoX<Cb00?o0000oj74lOnQa?400ol0
0002oj34lP03o`000?nQa?7oXLCa00KoXLCa00?o0000oj73lOnQ`o400ol00002oj73l@03o`000?nQ
`o7oXL?a00OoXL?a00?o0000oj;3l?nR`o000ol00002oj;3l@03o`000?nR`o3oX/?`00KoX/?`00?o
0000oj;3l?nR`o000ol00002oj;3l003o`000?nR`o3oX/?`00KoX/?`00?o0000oj?3l?nS`o001?l0
0002oj;3l003o`000?oonf[ooo]Z04Cooo]Z1ol00011oookJP00;?oonfX6o`0001[ooo]Z00?o0000
oookJ_oonfX0S_oonfX01?l0003o000Fo`000?l00002oad0?0;o00000_m104800ol0003oGaAEoelD
E@02oelDE@03o`000?mb9ekoLRMN00;oLRMN00?o0000oglbH_mo<V801?mo<V800ol0003oR3URohPi
HP04ohPiHP03o`000?n@>ekoT3]N00GoT3]N00?o0000oii=J?nNCFP01?nNCFP00ol0003oXdYMoj=:
G@02oj=:G@03o`000?n/FVco[5Y/00;o[5Y/00Go0000ok5EG?naEEco/EELo`000006ok]TJ003o`00
0?o5LFko000000?obV]J00?o0000omMjG?oGNU`00_oGNU`3o`0000OoW/Kd00?o0000oio5lonOaO<0
1?nOaO<4o`0000;oWlGc0ol000000onOaO?o0000oio5lP05oio5lPCo00001onOa?800ol0003oX<Cb
oj34lP04oj34lPCo00001_nPa?800ol0003oXLCaoj74l@04oj74l@Co00001_nQ`o400ol0003oXL?a
oj73l@05oj73l@Co00001_nR`o400ol0003oX/?`oj;3l004oj;3l0Co00001_nR`o000ol0003oX/?`
oj;3l004oj;3l0Co00001?nR`o001?l0003oX/?`oj;3l?l00016oookJPOo0000@?oonfX002cooo]Z
1Ol0000LoookJP03o`000?oonf[ooo]Z08gooo]Z0ol00003oad0?0;o00000_m104800ol0003oGaAE
oelDE@02oelDE@03o`000?mb9ekoLRMN00;oLRMN00?o0000oglbH_mo<V800omo<V800ol0003oR3UR
ohPiHP04ohPiHP03o`000?n@>ekoT3]N00KoT3]N00?o0000oii=J?nNCFP01?nNCFP00ol0003oXdYM
oj=:G@02oj=:G@03o`000?n/FVco[5Y/00;o[5Y/00Go0000ok5EG?naEEco/EELo`000007ok]TJ0;o
00000oo:JeX00ol0003oegYLo`000002o`0000;oWLOe00?o0000oik6m?nNa_@01_nNa_@00ol0003o
WlGcoio5l`03o`0000;oW/Gd1?l00005oio5l`03o`000?nOaO;oWlGb00?o00000onOaO<00ol0003o
WlCboio4lP06oio4lP03o`000?nPa?;oX<Cb00?o00000_nOa?800ol0003oX<Cboj34lP06oj34lP03
o`000?nQa?7oXLCa00?o00000_nP`o400ol0003oXL?aoj73l@06oj73l@03o`000?nQ`o7oXL?a00Co
00000_nQ`o400ol0003oX/?aoj;3l@06oj;3l@03o`000?nR`o3oX/?`00?o00000_nR`o000ol0003o
X/?`oj;3l006oj;3l003o`000?nR`o3oX/?`00?o00000onR`o000ol0003oX/?`oj;3l002oj;3l005
o`000?nR`o3oX/?`oj;3l?l00000AOoonfX8o`0003oooo]Z000/oookJPGo00007OoonfX00ol0003o
oo]ZoookJP2;oookJPCo00000olM03`01Ol0003o@@12od40@_m104;o000000?oGaAE00?o0000og8W
G_mb9eh00omb9eh00ol0003oOc9RoglbHP03oglbHP03o`000?n8>F;oR3UR00CoR3UR00?o0000oi0k
G_n@>eh01On@>eh00ol0003oU3UDo`000005oii=J003o`000?nSBUgoXdYM00;oXdYM00?o0000ojaJ
K?n/FV`00_n/FV`00ol0003o/EELok5EG002ok5EG003o`000?nkI6So^fAX00Co^fAX00?o0000olY[
F_o:JeX01?l00006oig7m@03o`000?nNa_CoW/Kd00CoW/Kd1?l00003oik5m0Co00001_nOaO<4o`00
00OoWlGc00?o0000oio4l_nOa?801?nOa?84o`0000KoWlCb00?o0000oj34l_nPa?801?nPa?84o`00
00KoX<?a00?o0000oj73lOnQ`o401?nQ`o44o`0000OoXL?a00?o0000oj;3lOnR`o401?nR`o44o`00
00KoX/?`00?o0000oj;3l?nR`o001?nR`o04o`0000OoX/?`00?o0000oj;3l?nR`o000_nR`o000ol0
003oX/?`o`000002o`0004Gooo]Z1ol0000ooookJP00;?oonfX5o`0001kooo]Z00?o0000oookJ_oo
nfX0R_oonfX01?l0003o000Fo`000?l00003oad0?004o`000?m104;o@@12o`0000CoGaAE00?o0000
og8WG_mb9eh00omb9eh00ol0003oOc9RoglbHP03oglbHP03o`000?n8>F;oR3UR00CoR3UR00?o0000
oi0kG_n@>eh01On@>eh01?l0003oU3UDoi@iE?l00004oii=J003o`000?nSBUgoXdYM00?oXdYM00Co
0000ojaJK?n/FVco00001OnaEE`00ol0003o^fAXok]TJ004ok]TJ0?o00000_nLaoH00ol0003oWLOe
oig7m@06oig7m@03o`000?nNa_CoW/Kd00?o00000onMa_@4o`0000CoW/Gd00?o0000oio5lonOaO<0
0ol00003oik5l`03o`000?nOaO?oWlGc00KoWlGc00?o0000oio4l_nOa?800ol00002oio4l`03o`00
0?nOa?;oWlCb00KoWlCb00?o0000oj34l_nPa?800ol00003oj34lP03o`000?nP`o7oX<?a00GoX<?a
00?o0000oj73lOnQ`o400ol00003oj73l@03o`000?nQ`o7oXL?a00KoXL?a00?o0000oj;3lOnR`o40
0ol00002oj73l@03o`000?nR`o3oX/?`00KoX/?`00?o0000oj;3l?nR`o000ol00003oj;3l003o`00
0?nR`o3oX/?`00KoX/?`00?o0000oj;3l?nR`o000ol00002oj;3l003o`000?oonf[ooo]Z04?ooo]Z
2?l0000noookJP00:ooonfX6o`0001oooo]Z00?o0000oookJ_oonfX0ROoonfX2o`000004o`001ol0
003o7@0load0?0;o00000_m104800ol0003oGaAEoelDE@02oelDE@03o`000?mb9ekoLRMN00?oLRMN
00?o0000oglbH_mo<V800omo<V800ol0003oR3URohPiHP04ohPiHP03o`000?n@>ekoT3]N00GoT3]N
00Co0000oi@iE?nD>ECo00000onNCFP00ol0003oXdYMoj=:G@04oj=:G@04o`000?n/FVco[5Y/o`00
00Go/EEL00?o0000ok]TJ?nkI6P01?l00006oic7mP03o`000?nMaoGoWLOe00CoWLOe1?l00005oig6
m0?o00001_nNaO@3o`0000OoW/Gc00?o0000oio5lonOaO<01?nOaO<4o`0000KoWlCc00?o0000oio4
l_nOa?801?nOa?84o`0000OoX<Cb00?o0000oj33lOnP`o401?nP`o43o`0000OoXL?a00?o0000oj73
lOnQ`o401?nQ`o44o`0000KoXL?a00?o0000oj;3l?nR`o001?nR`o04o`0000OoX/?`00?o0000oj;3
l?nR`o001?nR`o04o`0000?oX/?`00Co0000oj;3l?nR`o3o0000AOoonfX8o`0003gooo]Z000[oook
JPKo00008?oonfX2o`0008Wooo]Z0ol00003oad0?005o`000?m104;o@@12od40@_l000001?mO55D0
0ol0003oLRMNog8WGP02og8WGP03o`000?mo<V;oOc9R00CoOc9R00?o0000ohPiH_n8>F800on8>F80
0ol0003oT3]Noi0kGP05oi0kGP03o`000?nD>ECoU3UD00;oU3UD00Co0000oii=J?nNCFSo00001onS
BUd00ol0003o[5Y/o`000005ok5EG0?o00000onKb?L00ol0003oW<Ofoic7mP05oic7mP03o`000?nM
aoGoWLOe00?o00000onLaoH00ol0003oWLKdoig6m003o`0000?oWLKd00?o0000oik5m?nNaO@00ol0
0002oig5m003o`000?nNaO?oW/Gc00KoW/Gc00?o0000oio5lonOaO<00ol00002oik4l`03o`000?nO
a??oWlCc00KoWlCc00?o0000oio4l_nOa?800ol00002oio4lP03o`000?nPa?;oX<Cb00OoX<Cb00?o
0000oj33lOnP`o400ol000000onP`o;o0000oj73l@08oj73l@03o`000?nQ`o7oXL?a00?o00000_nQ
`o400ol0003oXL?aoj73l@06oj73l@03o`000?nR`o3oX/?`00?o00000onQ`o400ol0003oX/?`oj;3
l006oj;3l003o`000?nR`o3oX/?`00?o00000_nR`o000ol0003oX/?`oj;3l002oj;3l005o`000?nR
`o3oX/?`oj;3l?l00000AOoonfX7o`0003gooo]Z000[oookJPKo00008_oonfX00ol0003ooo]Zoook
JP25oookJPCo00000_lM03`2o`0000?o@@1200?o0000oelDEOmO55D00_mO55D01?l0003oLRMNog8W
G_mb9eh5o`0000;oOc9R00?o0000ohPiH_n8>F801?n8>F800ol0003oT3]Noi0kGP05oi0kGP03o`00
0?nD>ECoU3UD00;oU3UD00Co0000oii=J?nNCFSo00001onSBUd2o`0000;o/EEL1?l00007oi_8m`03
o`000?nLaoKoW<Of00CoW<Of0ol00006oic7mP?o00001OnMa_@4o`0000KoWLGd00?o0000oik5lonN
aO<01?nNaO<4o`0000KoW/Cc00?o0000oio4lonOa?<01?nOa?<4o`0000KoWlCb00?o0000oj34l_nP
a?801_nPa?83o`0000GoX<?b00?o0000oj73lOnQ`o401_nQ`o43o`0000KoXL?a00?o0000oj73lOnQ
`o401OnQ`o43o`0000OoXL?a00?o0000oj;3l?nR`o001?nR`o04o`0000KoX/?`00?o0000oj;3l?nR
`o000_nR`o000ol0003oX/?`o`000002o`0004Cooo]Z2?l0000loookJP00:ooonfX6o`0002?ooo]Z
00?o0000oookJ_oonfX0Q?oonfX2o`000004o`001ol0003o7@0load0?0;o00000_m104800ol0003o
GaAEoelDE@02oelDE@03o`000?mb9eko000000;o000000?oHPY1o`000?ma64L00_ma64L5o`0000Co
R3UR00?o0000oi0kG_n@>eh01?n@>eh00ol0003oU3UDoi@iE004oi@iE0;o00002OnSBUd3o`0000?o
V/[h00?o0000oi_8monKb?L01_nKb?L00ol0003oW<Ofoic7mP03o`0000;oVlSg00Co0000oic7m_nL
aoKoW<Of0ol00002oic7mP03o`000?nMa_CoWLKd00?o00000_nKa_D00ol0003oWLGdoig5m006oig5
m003o`000?nNaO?oW/Gc00?o00000_nMaO@00ol0003oW/Ccoik4l`06oik4l`03o`000?nOa??oWlCc
00?o00000_nNa?<00ol0003oWlCboio4lP06oio4lP03o`000?nPa?;oX<Cb00;oX<Cb0ol000000onO
a?;o0000oj33lP06oj33lP03o`000?nQ`o7oXL?a00;oXL?a0ol000000onP`o7o0000oj73l@07oj73
l@04o`000?nQ`o7oXL?aoj73l@?o000000?oXL?ao`000?nQ`o402?nQ`o400ol0003oX/?`oj;3l003
o`0000;oX/?`00?o0000oj;3l?nR`o001_nR`o000ol0003oX/?`oj;3l003o`0000;oX/?`00?o0000
oookJ_oonfX0@ooonfX8o`0003_ooo]Z000[oookJPGo00009OoonfX00ol0003ooo]ZoookJP23oook
JP;o000000?o0007o`000?lM03`00_l00003od40@P04o`000?mO55GoGaAEoelDE@?o00001?mR2T40
0ol0003oLAQ7og4HA`03og4HA`03o`000?mj7TKoNQi600Co00001on@>eh00ol0003oU3UDoi@iE005
oi@iE003o`000?nSBUgoXdYM00CoXdYM0ol00007oi[:n003o`000?nKb?OoVlSg00CoVlSg1?l00006
oi_8m`?o00001?nLaoH4o`0000KoVlKe00?o0000oig5m?nMaO@01?nMaO@4o`0000KoWLGd00?o0000
oik4lonNa?<01?nNa?<4o`0000KoW/Cc00?o0000oio4l_nOa?801_nOa?801?l0003oX<Cbo`000?l0
0005oio4lP03o`000?nP`o;oX<?b00GoX<?b00Co0000oj73lOl0003o00001OnP`o400ol0003oXL?a
oj73l@05oj73l@04o`000?nQ`o7o0000o`0000GoXL?a00?o0000oj73lOnQ`o401_nQ`o43o`0000Ko
X/?`00?o0000oj;3l?nR`o001OnR`o03o`0000?oX/?`00Co0000oj;3l?nR`o3o0000AOoonfX7o`00
03_ooo]Z000[oookJPGo00009_oonfX00ol0003ooo]ZoookJP22oookJP?o000000Co7@0lo`000?lB
01ko00000om104801_l0003oGaAEoelDEOl0003oC00co`0000CoHPY100?o0000og4HAoma64L00oma
64L00ol0003oNQi6ogXNAP04ogXNAP;o00001_n@>eh00ol0003oU3UDoi@iE005oi@iE004o`000?nS
BUgoXdYMoj=:G@?o00000_nIboT00ol0003oV/[hoi[:n006oi[:n003o`000?nKb?OoVlSg00?o0000
0_nIbOP00ol0003oVlSgoi_8m`02oi_8m`?o000000CoVlSgo`000?nLaoKoW<Of0ol00002oi[7m`03
o`000?nKa_GoVlKe00KoVlKe00?o0000oig5m?nMaO@00ol00003oi_5m@03o`000?nMaOCoWLGd00Go
WLGd00?o0000oik4lonNa?<00ol00003oig4m003o`000?nNa??oW/Cc00GoW/Cc00?o0000oio4l_nO
a?801?nOa?83o`0000SoWlCb00?o0000oj33l_nP`o800onP`o83o`0000SoX<?a00?o0000oj73lOnQ
`o400onQ`o43o`0000SoXL?a00?o0000oj73lOnQ`o400_nQ`o43o`000003oj73lOl0003oX/?`00Oo
X/?`00Co0000oj;3l?nR`o3oX/?`0ol000000onR`o3o0000oj;3l003oj;3l005o`000?nR`o3oX/?`
oj;3l?l00000A?oonfX8o`0003[ooo]Z000ZoookJPKo00009ooonfX00ol0003ooo]ZoookJP20oook
JP;o000000Ko0007o`000?lM03co0000oa807_l00003od40@P03o`000?mO55Go000000;oC00c00?o
0000of8:@OmR2T400_mR2T400ol0003oLAQ7og4HA`03og4HA`03o`000?mj7TKoNQi600CoNQi600?o
0000oh0N?ol000001?n@>eh00ol0003oU3UDoi@iE005oi@iE0Go00001_nIboT00ol0003oV/[hoi[:
n004oi[:n0Co00001_nIbOP4o`0000?oVlSg1?l00006oi[7m`03o`000?nKa_GoVlKe00CoVlKe1?l0
0007oi_5m@03o`000?nMaOCoWLGd00CoWLGd0ol00007oig4m003o`000?nNa??oW/Cc00GoW/Cc00?o
0000oio4l_nOa?800ol00002oik4lP03o`000?nOa?;oWlCb00KoWlCb00?o0000oj33l_nP`o800ol0
0002oio3lP03o`000?nP`o7oX<?a00KoX<?a00?o0000oj73lOnQ`o400ol00003oj73l@03o`000?nQ
`o7oXL?a00KoXL?a00Co0000oj73lOl0003o00001OnQ`o400ol0003oX/?`oj;3l005oj;3l004o`00
0?nR`o3o0000o`0000GoX/?`00?o0000oj;3l?nR`o000_nR`o000ol0003oX/?`oj;3l002o`0004Co
oo]Z2?l0000ioookJP00:_oonfX6o`0002Sooo]Z00?o0000oookJ_oonfX0OooonfX2o`000003o`00
1ol0003o000000;o4P0N00Co0000od40@_m104;o@@120_l00002od`0<`03o`000?mR2T7oHPY100?o
HPY100?o0000og4HAoma64L00oma64L00ol0003oNQi6ogXNAP03ogXNAP04o`000?n07SooP1hooh0N
?`;o00000_n@>eh00ol0003oU3UDoi@iE003oi@iE0?o00001?nHcOX00ol0003oVL_ioiW;n@04oiW;
n@03o`000?nJb_SoV/[h00?o00000onGboT00ol0003oVLWhoiW9n002oiW9n0Co00000_nKb?L3o`00
00?oV<Sh00?o0000oi[7monJaoL01OnJaoL00ol0003oVlKeoi_6m@03o`0000?oV/Kf00?o0000oi_5
mOnKaOD01_nKaOD00ol0003oWLGdoig5m003o`0000;oVlGd00?o0000oig4m?nMa?@01_nMa?@00ol0
003oW/Ccoik4l`02oik4l`Go00001_nNa?800ol0003oWlCboio4lP04oio4lPCo00001_nO`o800ol0
003oX<?aoj33l@04oj33l@Co00001onQ`o400ol0003oXL?aoj73l@04oj73l@?o00002?nQ`o400ol0
003oX/?`oj;3l003oj;3l0?o00002?nR`o001?l0003oX/?`oj;3l?nR`o03o`000003oj;3l?l0003o
oo]Z04Cooo]Z1ol0000ioookJP00:_oonfX6o`0002Wooo]Z00?o0000oookJ_oonfX0O_oonfX2o`00
0005o`001ol0003o0000oa807_l000000om10482o`0000?oC00c00?o0000of8:@OmR2T400_mR2T40
0ol0003oLAQ7og4HA`03og4HA`03o`000?mj7TKoNQi600CoNQi600?o0000oh0N?on07Sl00on07Sl0
1?l0003oT3]No`000?nD>E@4o`0000SoV<gj00Co0000oiW;nOnIboWoVL_i1Ol00007oiO;n@04o`00
0?nIbOSo0000o`0000?oVLWh0ol00007oiS8n003o`000?nJaoOoV/Og00CoV/Og0ol00007oi[6mP03
o`000?nKaOGoVlGe00CoVlGe1?l00006oi_5m003o`000?nMa?CoWLCd00CoWLCd1_l00003oig4l`03
o`000?nNa?;oW/Cb00KoW/Cb00?o0000oio4l_nOa?800ol00002oio3lP03o`000?nO`o;oWl?b00Ko
Wl?b00?o0000oj33lOnP`o400ol00003oj33l@03o`000?nQ`o7oXL?a00KoXL?a00?o0000oj73lOnQ
`o400ol00002oj73l@03o`000?nQ`o7oXL?a00KoXL?a00?o0000oj;3l?nR`o000ol00002oj73l@03
o`000?nR`o3oX/?`00KoX/?`00Ko0000oj;3l?l0003o0000oj;3l?l00003oj;3l003o`000?oonf[o
oo]Z04;ooo]Z2?l0000>oookJP?o001o9ooonfX002[ooo]Z1_l0000ZoookJP03o`000?oonf[ooo]Z
07cooo]Z0_l00002o`001`04o`000?lB01ko4P0No`0000?o@@1200?o0000od`0<om<03<00_m<03<0
0ol0003oHPY1of8:@@02of8:@@03o`000?ma64OoLAQ700?oLAQ700?o0000ogXNA_mj7TH01?mj7TH0
0ol0003oP1hooh0N?`04oh0N?`?o00001?nFco/00ol0003oV<gjoiS=nP04oiS=nPGo00001OnEc?/0
0ol0003oUl_ioiO;n@03oiO;n@?o00000_nIbOP3o`0000?oU/Wi00?o0000oiS8n?nHb?P01OnHb?P0
0ol0003oV/Ogoi[7m`03o`0000;oV<Oh00?o0000oi[6m_nJa_H01_nJa_H00ol0003oVlGeoi_5m@03
o`0000;oV/Gf00?o0000oi_5m?nKaO@01_nKaO@00ol0003oWLCdoig4m003o`0000;oW<Cd00?o0000
oig4lonMa?<01OnMa?<00ol0003oW/Cboik4lP04oik4lPCo00001_nO`o800ol0003oWl?boio3lP04
oio3lPCo00001onP`o400ol0003oXL?aoj73l@04oj73l@Co00001_nQ`o400ol0003oXL?aoj73l@04
oj73l@Co00001_nQ`o400ol0003oX/?`oj;3l004oj;3l0?o00001?nR`o001Ol0003oX/?`oj;3l?nR
`o3o000004Cooo]Z2?l0000=oookJP?o001o9ooonfX002[ooo]Z1Ol0000/oookJP03o`000?oonf[o
oo]Z07_ooo]Z0_l000000ol000Oo0000o`000002oa807P05o`000?m104;o@@12od40@_l000000om<
03<00ol0003oHPY1of8:@@03of8:@@03o`000?ma64OoLAQ700?oLAQ700?o0000ogXNA_mj7TH00omj
7TH00ol0003oP1hooh0N?`05o`0000SoU/ok00?o0000oiS=n_nHcOX00ol00002oi?>o003o`000?nE
c?_oULck00KoULck00?o0000oiO;nOl000001ol00007oiK9n@03o`000?nHb?SoV<Sh00;oV<Sh1Ol0
0006oiS7n003o`000?nJa_KoV/Kf00CoV/Kf1?l00006oi[5mP03o`000?nKaOCoVlGd00CoVlGd1?l0
0006oic4m003o`000?nMa??oWLCc00GoWLCc00?o0000oik4l_nNa?800ol00002oik3l`03o`000?nO
`o;oWl?b00KoWl?b00?o0000oio3l_nO`o800ol00003oio3lP03o`000?nP`o7oX<?a00KoX<?a00?o
0000oj73lOnQ`o400ol00002oj33l@03o`000?nQ`o7oXL?a00KoXL?a00?o0000oj73lOnQ`o400ol0
0002oj73l@03o`000?nQ`o7oXL?a00KoXL?a00?o0000oj;3l?nR`o000ol00002oj;3l003o`000?nR
`o3oX/?`00?oX/?`00Co0000oj;3l?nR`o3o0000AOoonfX7o`0000gooo]Z0ol007lWoookJP00:_oo
nfX5o`0002gooo]Z00?o0000oookJ_oonfX0N_oonfX2o`000003o`001ol0003o4P0N00;o4P0N00Co
0000od40@_m104;o00001?m<03<00ol0003oHPY1of8:@@02of8:@@03o`000?ma64OoLAQ700?oLAQ7
00?o0000ogXNA_mj7TH00_mj7TH5o`0000GoUM7l00?o0000oiK?nonFco/01?nFco/4o`0000KoTlkl
00?o0000oiG<nonEc?/01?nEc?/6o`0000CoTl_k00?o0000oiK9nOnFbOT01?nFbOT6o`0000CoULSi
00?o0000oiS7n?nHaoP01OnHaoP00ol0003oV/Kfoi[6mP03o`0000;oUlKg00?o0000oi[5m_nJaOH0
1_nJaOH00ol0003oVlGdoi_5m003o`0000;oV/Ce00?o0000oic4m?nLa?@01_nLa?@00ol0003oWLCc
oig4l`02oig4l`Go00001_nN`o<00ol0003oWl?boio3lP04oio3lPCo00001onO`o800ol0003oX<?a
oj33l@04oj33l@Co00001_nP`o400ol0003oXL?aoj73l@04oj73l@Co00001_nQ`o400ol0003oXL?a
oj73l@04oj73l@Co00001_nR`o000ol0003oX/?`oj;3l003oj;3l0Co0000A?oonfX8o`0000cooo]Z
0ol007lWoookJP00:OoonfX6o`0002kooo]Z00?o0000oookJ_oonfX0NOoonfX01?l0003o0007o`00
1ol00002oa807P03o`000?m104;o@@1200;o00001?m<03<00ol0003oHPY1of8:@@02of8:@@03o`00
0?ma64OoLAQ700?oLAQ700?o0000ogXNA_l000000_l00004oiCCo@03o`000?nEdOcoUM7l00CoUM7l
00?o0000oiK?nonFco/00ol00004oi3AoP03o`000?nCc_coTlkl00CoTlkl00?o0000oiG<nonEc?/0
0ol00004oho=o@03o`000?nCbo_oTl_k00CoTl_k00?o0000oiK9nOnFbOT00ol00003oi79n`03o`00
0?nEb?WoULSi00GoULSi00?o0000oiS7n?nHaoP00_nHaoP5o`0000KoUlKg00?o0000oi[5m_nJaOH0
1?nJaOH4o`0000KoV/Ce00?o0000oic4m?nLa?@01?nLa?@6o`0000CoW<Cc00?o0000oik3lonN`o<0
1OnN`o<00ol0003oWl?boio3lP03o`0000?oW/?b00?o0000oio3l_nO`o801_nO`o800ol0003oX<?a
oj33l@03o`0000;oWl?b00?o0000oj33lOnP`o401_nP`o400ol0003oXL?aoj73l@03o`0000;oX<?a
00?o0000oj73lOnQ`o401_nQ`o400ol0003oXL?aoj73l@03o`0000;oXL?a00?o0000oj;3l?nR`o00
1_nR`o000ol0003oX/?`oj;3l003o`0000;oX/?`00?o0000oookJ_oonfX0@ooonfX8o`0000_ooo]Z
0ol007lWoookJP00:OoonfX6o`0002oooo]Z00?o0000oookJ_oonfX0MooonfX2o`000003o`001ol0
003o000000;o4P0N00Go0000od40@_l0003o:P0Ho`000003od`0<`03o`000?mR2T7oHPY100?oHPY1
00?o0000og4HAoma64L00_ma64L3o`0000SoU=?m00Co0000oiGAo?nEdOcoUM7l1Ol00008oi3AoP04
o`000?nCc_coTlkloi?>o0Go00002?n?cOd01?l0003oTl_koi?;nonCbo/5o`0000OoTLWk00?o0000
oiG8nOnEb?T01?nEb?T5o`0000GoU<Oi00?o0000oiO6monGa_L01?nGa_L00ol0003oV/Gfoi[5mP03
o`0000?oV<Gf00?o0000oi[4mOnJa?D01OnJa?D00ol0003oW<Cdoic4m003o`0000?oVlCd00?o0000
oic4lonLa?<01OnLa?<00ol0003oW/?coik3l`04oik3l`?o00001onN`o800ol0003oWl?boio3lP04
oio3lPCo00001_nO`o800ol0003oX<?aoj33l@04oj33l@Co00001_nP`o400ol0003oXL?aoj73l@04
oj73l@Co00001_nQ`o400ol0003oX/?`oj;3l004oj;3l0Co00000onR`o001?l0003oX/?`oj;3l?l0
0015oookJPOo00002ooonfX3o`00ObOooo]Z000YoookJPKo0000<?oonfX00ol0003ooo]ZoookJP1f
oookJP;o000000?o0007o`000?lB01h00_lB01h2o`000003obX06?l0003oC00c00?oC00c00?o0000
of8:@OmR2T400_mR2T400ol0003oLAQ7og4HA`03o`0000?oTmKn00?o0000oiCCoOnDdod01?nDdod5
o`0000GoSM?o00?o0000oi3Ao_n@dOh01?n@dOh7o`0000?oRlon00?o0000oho=oOn?cOd01?n?cOd5
o`0000GoSL_m00?o0000oi79nonAbO/01OnAbO/00ol0003oULSioiG8n@03o`0000;oTLSj00?o0000
oiC7nOnDaoT01_nDaoT01?l0003oUlKgoiO6monGa_L5o`0000OoV<Gf00?o0000oi[4mOnJa?D01?nJ
a?D3o`0000OoVlCd00?o0000oic4lonLa?<01OnLa?<00ol0003oW/?coik3l`03o`0000;oWL?c00?o
0000oik3l_nN`o801_nN`o800ol0003oWl?boio3lP03o`0000;oW/?b00?o0000oio3l_nO`o801_nO
`o800ol0003oX<?aoj33l@03o`0000;oX<?a00?o0000oj33lOnP`o401_nP`o400ol0003oXL?aoj73
l@03o`0000;oXL?a00?o0000oj73lOnQ`o401_nQ`o400ol0003oX/?`oj;3l003o`0000;oXL?a00?o
0000oj;3l?nR`o000onR`o001?l0003oX/?`oj;3l?l00014oookJPSo00002_oonfX3o`00ObOooo]Z
000YoookJPKo0000<OoonfX2o`0007Kooo]Z00Co0000o`001ol0003o00000_lB01h2o`0000;o:P0H
00?o0000od`0<om<03<00_m<03<01?l0003oHPY1of8:@OmR2T44o`0000OoTmKn00?o0000oiCCoOnD
dod00ol00004oh_Fo`03o`000?n=doooSM?o00CoSM?o00?o0000oi3Ao_n@dOh00ol000000on6d_oo
0000o`000002o`0000KoRlon00?o0000oho=oOn?cOd00ol00003ohO=oP03o`000?n=bogoSL_m00Go
SL_m00?o0000oi79nonAbO/00_nAbO/5o`0000KoTLSj00?o0000oiC7nOnDaoT01?nDaoT5o`0000Co
ULGh00?o0000oiS5m_nHaOH01_nHaOH00ol0003oV/Ceoi[4m@03o`0000;oVLCf00?o0000oi_4m?nK
a?@01_nKa?@00ol0003oW<Ccoic4l`02oic4l`Go00001_nM`o<00ol0003oW/?boik3lP04oik3lPCo
00001_nN`o800ol0003oWl?boio3lP04oio3lPCo00001_nP`o400ol0003oX<?aoj33l@04oj33l@Co
00001_nQ`o400ol0003oXL?aoj73l@04oj73l@Co00001_nQ`o400ol0003oX/?`oj;3l003oj;3l0Co
0000A?oonfX8o`0000Wooo]Z0ol007lWoookJP00:OoonfX5o`0003Cooo]Z00?o0000oookJ_oonfX0
L_oonfX2o`000003o`001ol0003o000000;o4P0N00Go0000obX06?lZ01So:P0Ho`000003od`0<`03
o`000?mR2T7o000000;o00001?nCf?h00ol0003oTmKnoi?FoP04oi?FoP?o00002?n;e_l01?l0003o
SM?oohgCoon=dol5o`000004ohKBool0003o0000o`0000CoQ];o00Co0000oh_?o_n;cokoRlon1Ol0
0007ohO=oP03o`000?n=bogoSL_m00;oSL_m1ol00004ohc9o003o`000?nAb?[oTLSj00GoTLSj00?o
0000oiC7nOnDaoT00ol00002oi76nP03o`000?nEaOSoULGh00GoULGh00?o0000oiS5m_nHaOH01?nH
aOH4o`0000KoVLCf00?o0000oi_4m?nKa?@01?nKa?@6o`0000?oVl?d00?o0000oig3lonM`o<01_nM
`o<00ol0003oW/?boik3lP03o`0000;oWL?c00?o0000oik3l_nN`o801_nN`o800ol0003oWl?boio3
lP03o`0000;oWl?b00?o0000oj33lOnP`o401_nP`o400ol0003oX<?aoj33l@03o`0000;oX<?a00?o
0000oj73lOnQ`o401_nQ`o400ol0003oXL?aoj73l@03o`0000;oXL?a00?o0000oj73lOnQ`o401_nQ
`o400ol0003oX/?`oj;3l003o`0000;oX/?`00?o0000oookJ_oonfX0@ooonfX7o`0000Wooo]Z0ol0
07lWoookJP004ooonfX3o`00O`Gooo]Z1Ol007l9oookJPGo0000=OoonfX00ol0003ooo]ZoookJP1a
oookJPCo00000olB01h01?l0003o:P0HobX06?l00003od`0<`?o00002?nCf?h00ol0003oTmKnoi?F
oP03o`0000?oR=So0_l00004oh_Fo`Ko00001?n0e?l3o`0000CoQ];o1_l00005ogo?o`;o00000on7
cOh7o`0000GoQ<_n00?o0000ohc9o?n<bO`01?n<bO`00ol0003oTLSjoi78nP02oi78nPGo00001_nA
a_X00ol0003oULGhoiG5n005oiG5n003o`000?nHaOKoV<Gf00?o00000_nFa?L00ol0003oVLCfoiW4
mP06oiW4mP03o`000?nKa?CoVlCd00?o00000_nI`oD00ol0003oVl?doi_3m005oi_3m003o`000?nM
`o?oWL?c00CoWL?c1?l00006oig3l`03o`000?nN`o;oW/?b00CoW/?b1?l00006oio3lP03o`000?nP
`o7oX<?a00CoX<?a1?l00006oj33l@03o`000?nQ`o7oXL?a00CoXL?a1?l00006oj73l@03o`000?nQ
`o7oXL?a00CoXL?a1?l00003oj;3l004o`000?nR`o3oX/?`o`0004Cooo]Z2?l00005oookJPKo001o
9ooonfX001?ooo]Z0ol007l4oookJPOo001o2?oonfX5o`0003Kooo]Z00?o0000oookJ_oonfX0L?oo
nfX4o`0000;o4P0N00Co0000obX06?lZ01So:P0H1?l00003oiCJoP;o00001?nCf?h5o`0000OoR=So
1Ol00005ogWFoPco00001Omdd?h00ol0003oOlooogo?o`02ogo?o`Ko00001Omjc?l00ol0003oQ<_n
ohC;oP05ohC;oP04o`000?n<bOcoS<Wlohc9o0Oo00001On<ao`00ol0003oTLKjoi76nP04oi76nP03
o`000?nEaOSoULGh00;oULGh1Ol00006oiK4m`03o`000?nIa?KoVLCf00CoVLCf1?l00006oiW3m@03
o`000?nK`oCoVl?d00GoVl?d00?o0000oig3lonM`o<00ol00002oic3l`03o`000?nM`o?oWL?c00Ko
WL?c00?o0000oik3l_nN`o800ol00002oik3lP03o`000?nO`o;oWl?b00KoWl?b00?o0000oj33lOnP
`o400ol00002oio3l@03o`000?nP`o7oX<?a00KoX<?a00?o0000oj73lOnQ`o400ol00002oj33l@03
o`000?nQ`o7oXL?a00KoXL?a00?o0000oj73lOnQ`o400ol00002oj73l@03o`000?nR`o3oX/?`00?o
X/?`00Co0000oj;3l?nR`o3o0000@ooonfX9o`0000Cooo]Z1_l007lWoookJP004ooonfX3o`00O`Co
oo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPKo0000=ooonfX00ol0003ooo]ZoookJP1^oook
JPGo000000Co4P0No`000?l0003o:P0H0ol00007oiCJoPGo00001On7foh2o`0000;oR=So0ol00003
og;GnP;o00001?mie_h6o`0000GoIm3j0_l00003ogC@oPOo00001Om/boh00ol0003oN/coog[<o`04
og[<o`03o`000?n4bokoQ<_n00;oQ<_n1_l00005ohC8oP03o`000?n<aocoS<Ol00GoS<Ol00Co0000
oi76n_nAa_[oTLKj1ol00004oi;5n@03o`000?nFa?OoU/Cg00GoU/Cg00?o0000oiW4m_nIa?H00ol0
0002oiO4mP03o`000?nI`oGoVL?e00KoVL?e00?o0000oi_3m?nK`o@00_nK`o@5o`0000KoW<?c00?o
0000oig3lonM`o<01?nM`o<4o`0000KoW/?b00?o0000oio3l_nO`o801?nO`o84o`0000KoWl?a00?o
0000oj33lOnP`o401?nP`o44o`0000KoX<?a00?o0000oj73lOnQ`o401?nQ`o44o`0000KoXL?a00?o
0000oj;3l?nR`o000_nR`o000ol0003oX/?`o`000002o`0004Cooo]Z1ol00006oookJPCo001o9ooo
nfX000?ooo]Z2_l007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l6oookJPKo0000>?oonfX0
0ol0003ooo]ZoookJP1]oookJPCo000000?o4P0No`000?l000000_l00003oiKLoP;o00000_nDf_h3
o`0000?oQmkm0_l00004ohOKoPKo00001?mbeoX7o`0000GoElc`00?o0000ofO@n_mWd?X00_mWd?X6
o`0000GoElOf0_l00006ofc;oP04o`000?mjc?ooN/coog[<o`Oo00001?mib?l00ol0003oQ<SnohC8
oP05ohC8oP03o`000?n<aocoS<Ol00;oS<Ol1_l00004ohg5nP03o`000?nBaOWoT/Gi00GoT/Gi00?o
0000oiK4monFa?L00_nFa?L5o`0000KoUlCf00?o0000oiW3mOnI`oD01?nI`oD6o`0000CoV/?d00?o
0000oic3lonL`o<01OnL`o<00ol0003oWL?coig3l`03o`0000;oWL?c00?o0000oik3l_nN`o801_nN
`o800ol0003oWl?boio3lP03o`0000;oW/?b00?o0000oio3lOnO`o401_nO`o400ol0003oX<?aoj33
l@03o`0000;oX<?a00?o0000oj33lOnP`o401_nP`o400ol0003oXL?aoj73l@03o`0000;oXL?a00?o
0000oj73lOnQ`o401_nQ`o400ol0003oX/?`oj;3l003o`0000;oXL?a00?o0000oookJ_oonfX0@_oo
nfX8o`0000Kooo]Z0ol007lWoookJP000ooonfX:o`00O`Kooo]Z0ol007l3oookJP?o001o0ooonfX3
o`00O`Kooo]Z1_l0000ioookJP03o`000?oonf[ooo]Z06cooo]Z1_l00007oiKLoP?o00001on7g_d5
o`0000CoK=Se;_l00005ofS7oP03o`000?mib?ooNLSo00CoNLSo00?o0000ohC8o_n4b?h00_n4b?h7
o`0000?oQLKm00?o0000ohg5n_n=aOX01On=aOX00ol0003oT/Gioi;5n@04oi;5n@Go00001OnCa?L0
0ol0003oUlCfoiO4mP04oiO4mP03o`000?nI`oGoVL?e00?o00000onH`oD00ol0003oV/?doi[3m005
oi[3m003o`000?nL`o?oW<?c00;oW<?c1Ol00006oig3l`03o`000?nN`o;oW/?b00CoW/?b1?l00006
oik3lP03o`000?nO`o7oWl?a00CoWl?a1?l00006oj33l@03o`000?nP`o7oX<?a00CoX<?a1?l00006
oj73l@03o`000?nQ`o7oXL?a00CoXL?a1?l00003oj73l@04o`000?nQ`o7oXL?ao`0004Cooo]Z2?l0
000_oookJP004ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX6o`0003[ooo]Z00?o0000
oookJ_oonfX0J_oonfX3o`0000CoVMkn0_l00002oiKLoP?o00000on9h?`2o`0000;oQmkm0ol00002
ofWIl0ko00001?oDV9H01Ol0003oZgFGoj]eUon[MIOo000000?ob8jG00?o0000ok9jU_nbNYH01?nb
NYH01Ol0003oSenEohmOUOl0003o[gVH00Wo00001Om=`?D00ol0003oJ<OnofS7oP04ofS7oP04o`00
0?mib?ooNLSoogW8o`Oo00001?mja_h00ol0003oQLKmohG6o@04ohG6o@03o`000?n=aO[oSLGj00Go
SLGj00?o0000oi;5nOnBaOT00ol00002oho4n@03o`000?nCa?OoTlCg00KoTlCg00Co0000oiO4m_nG
a?KoUlCf1Ol00007oiS3m@03o`000?nJ`oCoV/?d00CoV/?d1Ol00004oi_3l`03o`000?nM`o?oWL?c
00GoWL?c00?o0000oik3l_nN`o800ol00002oik3lP03o`000?nN`o;oW/?b00KoW/?b00?o0000oio3
lOnO`o400ol00002oio3lP03o`000?nP`o7oX<?a00KoX<?a00?o0000oj33lOnP`o400ol00002oj33
l@03o`000?nQ`o7oXL?a00KoXL?a00?o0000oj73lOnQ`o400ol00002oj73l@03o`000?nQ`o7oXL?a
00?oXL?a00Co0000oj73lOnQ`o7o0000A?oonfX7o`0002oooo]Z000CoookJP?o001o0ooonfX3o`00
O`?ooo]Z0ol007l6oookJPGo0000??oonfX00ol0003ooo]ZoookJP1VoookJP?o00001onIg_h5o`00
00CoRN3l3ol00003ombRUP?o000000?oa8^Ho`000?oDV9H01?oDV9H01Ol0003oZgFGoj]eUon[MIOo
000000?ob8jG00?o0000ok9jU_nbNYH01?nbNYH00ol0003oSenEo`000004ojmiV003o`000?nQKIKo
XFfF00;oXFfF4_l00005ofW4oP03o`000?mja_koN/Kn00CoN/Kn00?o0000ohG6oOn5a_d01?n5a_d0
0ol0003oSLGjohg5nP02ohg5nPGo00001_n?a?T00ol0003oTlCgoi?4m`04oi?4m`Go00001?nE`oH0
0ol0003oV<?eoiS3m@06oiS3m@03o`000?nJ`oCoV/?d00?o00000_nI`o@00ol0003oVl?coi_3l`05
oi_3l`03o`000?nM`o?oWL?c00CoWL?c0ol00006oik3lP03o`000?nN`o;oW/?b00CoW/?b1?l00006
oio3lP03o`000?nP`o7oX<?a00CoX<?a1?l00006oj33l@03o`000?nQ`o7oXL?a00CoXL?a1?l00006
oj73l@03o`000?nQ`o7oXL?a00;oXL?a00?o0000oj73lOl000000_l00013oookJPSo0000;_oonfX0
01?ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0000moookJP03o`000?oonf[ooo]Z
06;ooo]Z0ol00003oicOo@;o00000_nIg_h3o`0000CoSN?l1Ol00003of_Kk0Ko00001OoRYI85o`00
00?oa8^H00?o0000omBHU_oDV9H00ooDV9H01Ol0003oZgFGoj]eUon[MIOo000000?ob8jG00?o0000
ok9jU_nbNYH01?nbNYH00ol0003oSenEo`000004ojmiV003o`000?nQKIKoXFfF00?oXFfF00Co0000
ohmNU?n?GYCoSejD1ol00005odflm`03o`000?mYa?koJLCn00CoJLCn00?o0000og[6o_mja_h01?mj
a_h01?l0003oQLKmohG6oOn5a_d7o`0000CoR<Ck00?o0000oho4nOn?a?T01On?a?T00ol0003oTlCg
oi?4m`03o`0000;oTL?h00?o0000oiG3m_nE`oH01OnE`oH00ol0003oV<?eoiS3m@04oiS3m@Co0000
1_nI`o@00ol0003oVl?coi_3l`05oi_3l`03o`000?nM`o?oWL?c00?o00000_nL`o<00ol0003oW/?b
oik3lP05oik3lP03o`000?nN`o;oW/?b00?o00000onN`o800ol0003oWl?boio3lP05oio3lP03o`00
0?nP`o7oX<?a00?o00000onO`o400ol0003oX<?aoj33l@05oj33l@03o`000?nQ`o7oXL?a00?o0000
0onP`o400ol0003oXL?aoj73l@05oj73l@03o`000?nQ`o7oXL?a00?o00000_nQ`o400ol0003ooo]Z
oookJP12oookJPOo0000;_oonfX001?ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Gooo]Z1_l0
000noookJP03o`000?oonf[ooo]Z05kooo]Z0ol00007oicOo@Co00000on=ho`3o`0000CoLMo[1Ol0
0002onR`U`03o`000?oQYYKo000000CohZFB0_l00003ombRUP04o`000?o4RiSoa8^Ho`0000Koe9RF
00Go0000oj]eUon[MIOoZgFGo`000003olR>U`03o`000?nbNYKo/WZF00Co/WZF0_l00005ojmiV003
o`000?nQKIKoXFfF00CoXFfF00?o0000ohmNU?n?GY@00on?GY@00ol0003oNe2Bo`00000Ho`0000Go
O/?m00?o0000ohS4non8a?/01?n8a?/00ol0003oSlCioho4n@02oho4n@Go00001_nA`oP00ol0003o
UL?foiG3mP05oiG3mP03o`000?nH`oGoV<?e00?o00000_nG`_D00ol0003oVL?doiW3m006oiW3m003
o`000?nK`o?oVl?c00;oVl?c1Ol00006oic3l`03o`000?nN`o;oW/?b00CoW/?b0ol00007oik3lP03
o`000?nO`o;oWl?b00CoWl?b0ol00007oio3l@03o`000?nP`o7oX<?a00CoX<?a0ol00007oj33l@03
o`000?nQ`o7oXL?a00CoXL?a0ol00003oj73l@04o`000?nQ`o7oXL?ao`0004Cooo]Z1ol0000]oook
JP004?oonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o1OoonfX6o`0003oooo]Z00?o0000oookJ_oo
nfX0F_oonfX3o`0000?oX=ol0_l00002oicOo@?o00001?nCiO`4o`0000?oLMo[1Ol000000oo^]YCo
0000onR`U`02onR`U`;o00000_oRYI83o`000003on:UT_l0003og::F00;og::F00Co0000olB;V?o4
RiSo00001_oDV9H01?l0003oZgFGoj]eUol00004olR>U`03o`000?nbNYKo/WZF00Co/WZF0_l00005
ojmiV003o`000?nQKIKoXFfF00CoXFfF00?o0000ohmNU?n?GY@00on?GY@00ol0003oNe2Bog]@TP02
og]@TP03o`000?mW@Y7o000000Ko00001?mD^o/00ol0003oK/;nofk2oP04ofk2oP03o`000?mn`ogo
O/?m00GoO/?m00Co0000ohS4non8a?_oR<Ck1ol00004oh_2nP03o`000?nA`oSoTL?h00GoTL?h00?o
0000oiG3m_nE`oH00_nE`oH5o`0000KoUl;e00?o0000oiW3m?nI`o@01?nI`o@6o`0000?oVl?c00?o
0000oic3lonL`o<01_nL`o<00ol0003oW/?boik3lP03o`0000;oWL?b00?o0000oik3l_nN`o801_nN
`o800ol0003oWl?boio3lP03o`0000;oWl?b00?o0000oio3lOnO`o401_nO`o400ol0003oX<?aoj33
l@03o`0000;oX<?a00?o0000oj33lOnP`o401_nP`o400ol0003oXL?aoj73l@03o`0000;oXL?a00?o
0000oj73lOnQ`o400_nQ`o401?l0003oXL?aoj73lOl00013oookJPSo0000;?oonfX0013ooo]Z1_l0
07l4oookJP?o001o00Cooo]Zo`00Ool007oo001o1_oonfX6o`00043ooo]Z00?o0000oookJ_oonfX0
EooonfX2o`0000OoX=ol0ol00005oi?Uo0;o00001?mki>d5o`0000Cok[JD00?o0000onR`UooX/9L0
0_oX/9L3o`0000CohZFB00Go0000ombRU_oLXYKog::Fo`000002olB;V003o`000?oDV9Koe9RF00Co
e9RF00Co0000oj]eUon[MIOo00001?o8SYL00ol0003o/WZFok9jUP04ok9jUP;o00001On_NIP00ol0
003oXFfFoj5]UP04oj5]UP03o`000?n?GYCoSejD00?oSejD00?o0000og]@T_mkD9800_mkD9800ol0
003oId:AofM2T@02ofM2T@03o`000?l0R/ko000000Go000000?oE;_ko`000?m^`_h01Om^`_h00ol0
003oO/?mogk3o@02ogk3o@Ko00001On3`_`00ol0003oRl;joh_2nP04oh_2nP03o`000?nA`oSoTL?h
00;oTL?h1ol00004oi?2m`03o`000?nG`_GoUl;e00GoUl;e00?o0000oiW3m?nI`o@00ol00002oiW2
m003o`000?nK`o?oVl?c00GoVl?c00?o0000oic3lonL`o<01?nL`o<4o`0000KoWL?b00?o0000oik3
l_nN`o801?nN`o84o`0000KoWl?b00?o0000oio3lOnO`o401?nO`o44o`0000KoX<?a00?o0000oj33
lOnP`o401?nP`o44o`0000KoXL?a00Go0000oj73lOnQ`o7oXL?ao`000002oj73l@;o0000@ooonfX7
o`0002cooo]Z000BoookJPCo001o1?oonfX7o`00O`Kooo]Z1_l00011oookJP03o`000?oonf[ooo]Z
05Cooo]Z0ol00006oj3Oo0;o00000onIi_`2o`000003oi?Uo?l0003o000000?oNnC]1?l00002ooBm
T`03o`000?o^]YCok[JD00;ok[JD00?o0000onR`UooX/9L01?l00005on:UTP03o`000?oLXYKog::F
00;og::F00Co0000olB;V?o4RiSo00001_oDV9H01?l0003oZgFGoj]eUol00004olR>U`03o`000?nb
NYKo/WZF00Co/WZF00?o0000ojmiV?n_NIP01?n_NIP00ol0003oXFfFoj5]UP04oj5]UP03o`000?n?
GYCoSejD00?oSejD00?o0000og]@T_mkD9800_mkD9800ol0003oId:AofM2T@02ofM2TAGo00001?mf
`?d00ol0003oPl;loh?2o005oh?2o004o`000?n;`_[oRl;joh_2nPOo00001?n?`_P00ol0003oTl;g
oi?2m`05oi?2m`03o`000?nG`_GoUl;e00;oUl;e1Ol00006oiW2m003o`000?nK`o?oVl?c00GoVl?c
00?o0000oic3lonL`o<00ol00002oic3l`03o`000?nM`o;oWL?b00KoWL?b00?o0000oik3l_nN`o80
0ol00002oik3lP03o`000?nO`o;oWl?b00KoWl?b00?o0000oio3lOnO`o400ol00002oio3lP03o`00
0?nP`o7oX<?a00KoX<?a00?o0000oj33lOnP`o400ol00002oj33l@03o`000?nQ`o7oXL?a00KoXL?a
00?o0000oj73lOnQ`o400ol000000onQ`o7o0000oookJP12oookJPSo0000:ooonfX001?ooo]Z0ol0
07l5oookJPGo001o1ooonfX5o`0004?ooo]Z0_l0001AoookJP?o00000onTgo/3o`000003oj3Oo?l0
003o000000KoVNKl2?l000000ooiai?o0000ooBmT`02ooBmT`03o`000?o^]YCok[JD00;ok[JD0ol0
0003onR`U`03o`000?oRYI;ohZFB00?ohZFB00?o0000ombRU_oLXYH00_oLXYH00ol0003oa8^Ho`00
0007omBHUP04o`000?n[MIOoZgFGo`0000Cob8jG00?o0000ok9jU_nbNYH01?nbNYH00ol0003o[gVH
ojmiV004ojmiV003o`000?nQKIKoXFfF00CoXFfF00?o0000ohmNU?n?GY@00on?GY@00ol0003oNe2B
og]@TP02og]@TP03o`000?mW@Y7oId:A00;oId:A00Co0000oeHhT_mF>9;oESRB2_l00005of2ko@;o
00001Omf`?d00ol0003oPl;loh?2o002oh?2o0Ko00001?n8`OX00ol0003oSl;hoho2n005oho2n003
o`000?nC`_OoTl;g00CoTl;g1Ol00003oiK2m@03o`000?nI`_CoVL;d00KoVL;d00?o0000oi_3lonK
`o<00_nK`o<5o`0000KoW<?c00?o0000oig3l_nM`o801?nM`o84o`0000KoW/?b00?o0000oio3l_nO
`o801?nO`o84o`0000KoWl?b00?o0000oj33lOnP`o401?nP`o44o`0000KoX<?a00?o0000oj73lOnQ
`o401?nQ`o44o`0000;oXL?a00Co0000oj73lOnQ`o7o0000@ooonfX8o`0002[ooo]Z000WoookJPGo
0000AOoonfX00ol0003ooo]ZoookJP1;oookJP?o00001onTgo/5o`0000?oVNKl0ol00002ohWYl@Co
00000ooiai<01_l0003om;fCooBmTood_I?o0000onjfU0Co00001OoX/9L00ol0003ohZFBon:UTP03
on:UTP03o`000?oLXYKog::F00?og::F0_l00007omBHUP03o`000?n[MIOo000000Gob8jG00?o0000
ok9jU_nbNYH00onbNYH2o`0000Ko[gVH00?o0000oj5]U_nQKIH01?nQKIH00ol0003oSejDohmNU003
ohmNU003o`000?mkD9;oNe2B00;oNe2B00?o0000ofM2TOmW@Y400_mW@Y400ol0003oESRBoeHhTP02
oeHhTP03o`000?l/68Go;1R500?o000000?o7I_Xo`000?l000004Ol00003ogfoo003o`000?n8`O[o
R<7j00GoR<7j00?o0000oho2n?n?`_P01On?`_P00ol0003oTl;goi?2m`03o`0000;oT/7g00?o0000
oiK2mOnF`_D01?nF`_D00ol0003oVL;doiW2m004oiW2m0Ko00001?nJ`_@00ol0003oW<?coic3l`05
oic3l`03o`000?nM`o;oWL?b00?o00000_nM`o<00ol0003oW/?boik3lP06oik3lP03o`000?nO`o;o
Wl?b00?o00000_nN`o800ol0003oWl?boio3lP06oio3lP03o`000?nP`o7oX<?a00?o00000_nO`o80
0ol0003oX<?aoj33l@06oj33l@03o`000?nQ`o7oXL?a00?o00000_nP`o401Ol0003oXL?aoj73lOnQ
`o7o000000?oXL?a00?o0000oookJ_oonfX0@OoonfX7o`0002[ooo]Z000VoookJPKo0000A_oonfX0
0ol0003ooo]ZoookJP18oookJP;o00000onWg_X2o`0000;oY=ok0ol00005oj3Wo0Co00000_n9jO44
o`000003oogCU_l0003onLNC00;onLNC00?o0000ooBmTood_I<00ol00003onjfU003o`000?oX/9Oo
j;2G00;oj;2G00?o0000on>[V_l000001?oRYI800ol0003og::FombRUP03ombRUP;o00002?oDV9H2
o`0000Gob8jG00?o0000ok9jU_nbNYH00onbNYH2o`0000Ko[gVH00?o0000oj5]U_nQKIH01?nQKIH0
0ol0003oSejDohmNU003ohmNU003o`000?mkD9;oNe2B00;oNe2B00?o0000ofM2TOmW@Y400_mW@Y40
0ol0003oESRBoeHhTP02oeHhTP03o`000?l/68Go;1R500;o;1R51?l00002oafKj003o`000?m@/o[o
D;?j00?oD;?j00?o0000offkoOm]^od01?m]^od00ol0003oOKologfoo003ogfoo003o`000?n8`O[o
R<7j00GoR<7j00?o0000oho2n?n?`_P00_n?`_P5o`0000KoT/7g00?o0000oiK2mOnF`_D01?nF`_D0
0ol0003oVL;doiW2m003o`0000;oV<;d00?o0000oi[2m?nJ`_@01_nJ`_@00ol0003oW<?coic3l`02
oic3l`Go00001_nM`o<00ol0003oW/?boik3lP04oik3lPCo00001_nN`o800ol0003oWl?boio3lP04
oio3lPCo00001_nO`o800ol0003oX<?aoj33l@04oj33l@Co00001_nP`o401Ol0003oXL?aoj73lOnQ
`o7o000000;oXL?a0_l00012oookJPSo0000:OoonfX002Kooo]Z1_l00017oookJP03o`000?oonf[o
oo]Z04Gooo]Z0_l00006ojONnP?o00001OnPio`3o`0000CoU^ge1Ol00002oogCUP04o`000?oiai?o
nLNCooW7T`Co00001?o^]Y@00ol0003oj;2GonR`U`03onR`U`03o`000?oSZi[o000000CohZFB00?o
0000ombRU_oLXYH00ooLXYH2o`0000Soe9RF0_l00005olR>U`03o`000?nbNYKo/WZF00?o/WZF0_l0
0007ojmiV003o`000?nQKIKoXFfF00?oXFfF00?o0000ohmNU?n?GY@00on?GY@00ol0003oNe2Bog]@
TP02og]@TP03o`000?mW@Y7oId:A00;oId:A00?o0000oeHhT_mF>9800_mF>982o`0000?o;1R500?o
0000oahFR_lN5XX01Ol00005oe2cnP03o`000?m]^ogoKK_m00CoKK_m00?o0000ogfoo?mm_o`00omm
_o`00ol0003oR<7johS1nP02ohS1nPOo00001?n=`?P00ol0003oT/7goi;1m`05oi;1m`04o`000?nF
`_GoU/;eoiK2m@Go00001_nH`_@00ol0003oV/;doi[2m004oi[2m0Ko00000onK`_<00ol0003oWL?c
oig3l`06oig3l`03o`000?nN`o;oW/?b00?o00000_nM`o800ol0003oW/?boik3lP06oik3lP03o`00
0?nO`o;oWl?b00?o00000_nO`o800ol0003oWl?boio3lP06oio3lP03o`000?nP`o7oX<?a00?o0000
0_nP`o400ol0003oX<?aoj33l@06oj33l@03o`000?nQ`o7oXL?a00?o000000?oXL?ao`000?oonfX0
@_oonfX8o`0002Sooo]Z000VoookJPKo0000B?oonfX00ol0003ooo]ZoookJP12oookJP?o00001OnW
g_X2o`0000?oY^Kk0_l000000onPioco0000o`000004oiK]m@Ko000000KooN2Jo`000?omdiKooM>F
o`000?oiai<2o`0000?om;fC00?o0000onjfU?o^]Y@00_o^]Y@00ol0003oj;2GonR`U`03onR`U`03
o`000?oSZi[o000000?ohZFB00?o0000ombRU_oLXYH01?oLXYH2o`0000Soe9RF0_l00005olR>U`03
o`000?nbNYKo/WZF00;o/WZF00?o0000okZ5Vol000001on_NIP00ol0003oXFfFoj5]UP03oj5]UP03
o`000?n?GYCoSejD00?oSejD00?o0000og]@T_mkD9800_mkD9800ol0003oId:AofM2T@03ofM2T@04
o`000?mF>9;oESRBoeHhTP;o00000ol/68D00ol0003o7QJ:oahFRP0Lo`0000?oQKoj00?o0000ohg0
n?n=`?P01_n=`?P00ol0003oT/7goi;1m`02oi;1m`Ko00001?nE`OH00ol0003oV<;doiS2m005oiS2
m003o`000?nJ`_CoV/;d00?o00000_nI`_@00ol0003oVl;coi_2l`05oi_2l`03o`000?nM`o?oWL?c
00CoWL?c1?l00006oig3lP03o`000?nN`o;oW/?b00CoW/?b1?l00006oio3lP03o`000?nO`o;oWl?b
00CoWl?b1?l00006oj33l@03o`000?nP`o7oX<?a00CoX<?a1?l00002oj73l@04o`000?nQ`o7oXL?a
o`0004?ooo]Z1ol0000XoookJP009_oonfX6o`0004Wooo]Z00?o0000oookJ_oonfX0?_oonfX3o`00
00?oZ]ci0_l000000onWg_[o0000o`000006ojKVn`_o000000ConNbRo`000?omh9[o00000_omdiH3
o`000003ooW7Tol0003om;fC00;om;fC00?o0000onjfU?o^]Y@00_o^]Y@00ol0003oj;2GonR`U`03
onR`U`03o`000?oSZi[o000000?ohZFB00?o0000ombRU_oLXYH01?oLXYH00ol0003oe9RFomBHUP07
omBHUP03o`000?o8SYOob8jG00Cob8jG00?o0000ok9jU_nbNYH00_nbNYH01?l0003o^XFKokZ5Vol0
0006ojmiV003o`000?nQKIKoXFfF00?oXFfF00?o0000ohmNU?n?GY@00on?GY@00ol0003oNe2Bog]@
TP02og]@TP03o`000?mW@Y7oId:A00?oId:A00Oo0000oeHhT_mF>9;oESRBo`000?m8<iKo000000;o
;1R500Ko0000oahFR_lN5X[o7QJ:o`000?l007d5o`0000Co@JSg00?o0000ofBfo?mT]_`00omT]_`0
0ol0003oN;clogRlo005ogRlo003o`000?n5_o[oQKoj00?oQKoj00?o0000ohg0n?n=`?P01?n=`?P6
o`0000?oT<3g00?o0000oiG1m_nE`OH01OnE`OH00ol0003oV<;doiS2m004oiS2m0?o00001_nI`_@0
0ol0003oVl;coi_2l`05oi_2l`03o`000?nM`o?oWL?c00?o00000_nL`o<00ol0003oWL?boig3lP06
oig3lP03o`000?nN`o;oW/?b00?o00000_nN`o800ol0003oWl?boio3lP06oio3lP03o`000?nO`o;o
Wl?b00?o00000_nO`o800ol0003oX<?aoj33l@06oj33l@03o`000?nP`o7oX<?a00?o00000_nP`o40
1Ol0003oXL?aoj73lOnQ`o7o000000?oXL?a00?o0000oookJ_oonfX0@?oonfX8o`0002Oooo]Z000V
oookJPGo0000BooonfX00ol0003ooo]ZoookJP0joookJP?o00001onZg?T3o`0000GoY^Kk0_l00002
oj7^n0?o00000_nDl>P4o`000003ooW/X_l0003ooN2J00Co00000ooiai<01Ol0003om;fCooBmTood
_I?o000000Cok[JD00?o0000onR`UooX/9L00_oX/9L01?l0003ohj^Jon>[V_l00003on:UTP03o`00
0?oLXYKog::F00Cog::F00?o0000omBHU_oDV9H01ooDV9H00ol0003ob8jGolR>U`04olR>U`03o`00
0?nbNYKo/WZF00;o/WZF00Co0000okZ5VonjQI_o00001_n_NIP00ol0003oXFfFoj5]UP03oj5]UP03
o`000?n?GYCoSejD00?oSejD00?o0000og]@T_mkD9800omkD9800ol0003oId:AofM2T@02ofM2T@03
o`000?mF>9;oESRB00;oESRB0_l00002ob`HQ@05o`000?lN5X[o7QJ:oahFR_l000000_l007d3o`00
0003o`1cd?l0003o000000;o000000?o@JSgo`000?mT]_`01?mT]_`00ol0003oN;clogRlo005ogRl
o003o`000?n5_o[oQKoj00?oQKoj00?o0000ohg0n?n=`?P00ol00002oh^on003o`000?n@`?OoT<3g
00GoT<3g00?o0000oiG1m_nE`OH01OnE`OH00ol0003oV<;doiS2m003o`0000;oUl;e00?o0000oiW2
m?nI`_@01OnI`_@00ol0003oVl;coi_2l`02oi_2l`Go00001_nL`o<00ol0003oWL?boig3lP04oig3
lPCo00001_nN`o800ol0003oWl?boio3lP04oio3lPCo00001_nO`o800ol0003oX<?aoj33l@04oj33
l@Co00001_nP`o401_l0003oXL?aoj73lOnQ`o7o0000oj73l@?o0000@_oonfX8o`0002Kooo]Z000V
oookJPGo0000C?oonfX00ol0003ooo]ZoookJP0foookJP?o00000on/f_P00ol0003oZ]cioj[Ln@02
oj[Ln@;o00000onZi?X2o`000003ojKVnol0003o000000;oXNkh0_l00003oiC`j0Go000000?onNbR
o`000?l000000_l00002oogCUP05o`000?oiai?onLNCooW7Tol000000ood_I<00ol0003ok[JDonjf
U002onjfU003o`000?oX/9Ooj;2G00;oj;2G00Go0000on>[V_oSZi[ohj^Jo`000002on:UTP03o`00
0?oLXYKog::F00Cog::F00?o0000omBHU_oDV9H01ooDV9H00ol0003ob8jGolR>U`05olR>U`04o`00
0?nbNYKo/WZFo`0000?o^XFK00?o0000ojmiV?n_NIP01?n_NIP00ol0003oXFfFoj5]UP03oj5]UP03
o`000?n?GYCoSejD00CoSejD00?o0000og]@T_mkD9800_mkD9800ol0003oId:AofM2T@02ofM2T@03
o`000?mF>9;oESRB00;oESRB00Go0000odPcU_l0003o;1R5o`000003oahFRP;o000000?o001mo`00
0?l000001?l00002ocBNl`Oo000000?oI;Klo`000?mh_?`00omh_?`;o`0000KoRkoh00?o0000oi30
mon@`?L01On@`?L00ol0003oUL7foiG1mP02oiG1mPGo00001_nG`_D00ol0003oVL;doiW2m004oiW2
m0Go00001?nK`_<00ol0003oW<?coic3l`05oic3l`03o`000?nM`o;oWL?b00?o00000_nM`o<00ol0
003oW/?boik3lP06oik3lP03o`000?nO`o;oWl?b00?o00000_nN`o800ol0003oWl?boio3lP06oio3
lP03o`000?nP`o7oX<?a00?o00000_nO`o800ol0003oX<?aoj33l@05oj33l@03o`000?nQ`o7oXL?a
00?o00000_nP`o400ol0003ooo]ZoookJP11oookJPOo00009_oonfX002Kooo]Z1Ol0001=oookJP03
o`000?oonf[ooo]Z03?ooo]Z0_l00007ojcJn004o`000?nZg?Wo0000o`0000KoZ^Cj4_l00002oogP
VP04o`000?omdiKooM>Fo`0000?onLNC00Co0000ooBmTood_I?o00001?o^]Y@00ol0003oj;2GonR`
U`03onR`U`07o`000?oSZi[ohj^Jon>[V_l0003ohZFBo`000007ombRUP03o`000?oDV9Koe9RF00Ko
e9RF0_l00007olR>U`04o`000?nbNYKo/WZFo`0000?o^XFK00?o0000ojmiV?n_NIP01?n_NIP00ol0
003oXFfFoj5]UP03oj5]UP03o`000?n?GYCoSejD00CoSejD00?o0000og]@T_mkD9800_mkD9800ol0
003oId:AofM2T@02ofM2T@03o`000?mF>9;oESRB00;oESRB00?o0000odPcU_m8<iH00_l00003oahF
RP;o000000?o001mo`000?l000000_l000000ol0I<_o0000o`000005ocBNl`03o`000?mM/?_oGK3k
00Ko00000omd^O/00ol0003oP[gjoh:mnP05oh:mnP03o`000?n;_oSoRkoh00CoRkoh00?o0000oi30
mon@`?L00_n@`?L7o`0000CoU<7f00?o0000oiO2mOnG`_D01OnG`_D00ol0003oVL;doiW2m003o`00
00;oVL;d00?o0000oi_2lonK`_<01OnK`_<00ol0003oW<?coic3l`02oic3l`Go00001_nM`o<00ol0
003oW/?boik3lP04oik3lPCo00001_nN`o800ol0003oWl?boio3lP04oio3lPCo00001_nO`o800ol0
003oX<?aoj33l@04oj33l@?o00000onP`o401?l0003oX<?aoj33lOl00012oookJPSo00009OoonfX0
02Gooo]Z1_l0001>oookJP03o`000?oonf[ooo]Z033ooo]Z0ol00007ojcJn0Co00001OnZi?X2o`00
00?oZ^ci00Co0000ojKdlOnVm?7oY_Ca0_l000000onIlmWo0000o`000003o`0000;onNbR00?o0000
oogPV_l000000_omdiH01Ol0003onLNCooW7Tooiai?o000000?om;fC00?o0000onjfU?o^]Y@00_o^
]Y@00ol0003oj;2GonR`U`03onR`U`07o`000?oSZi[ohj^Jon>[V_l0003ohZFBo`000006ombRUP;o
00002?oDV9H2o`0000Oob8jG00?o0000ok9jU_l000001?njQI/00ol0003o[gVHojmiV004ojmiV003
o`000?nQKIKoXFfF00CoXFfF00?o0000ohmNU?n?GY@00on?GY@00ol0003oNe2Bog]@TP02og]@TP03
o`000?mW@Y7oId:A00;oId:A00?o0000oeHhT_mF>9800_mF>9801_l0003oB3>FodPcU_l0003o;1R5
o`0000?o7QJ:0_l000000ol007go0000o`000003o`000003o`1Tbol0003o000000?o000000?o=9kc
o`000?mM/?/00omM/?/00ol0003oM;WkogBin`04ogBin`03o`000?n2_O[oP[gj00GoP[gj00Co0000
oh^on?n;_oSoRkoh1ol00003ohnom`03o`000?nD`OKoU<7f00KoU<7f00?o0000oiO2mOnG`_D00_nG
`_D5o`0000KoVL;d00?o0000oi_2lonK`_<01?nK`_<5o`0000CoW<?c00?o0000oig3lonM`o<01OnM
`o<00ol0003oW/?boik3lP03o`0000;oWL?b00?o0000oik3l_nN`o801_nN`o800ol0003oWl?boio3
lP03o`0000;oWl?b00?o0000oio3l_nO`o801_nO`o800ol0003oX<?aoj33l@03o`000003oio3l_l0
003oX<?a00?oX<?a00Go0000oj33lOnP`o7oX<?ao`000012oookJPSo00009?oonfX002Gooo]Z1_l0
001?oookJP03o`000?oonf[ooo]Z02gooo]Z0_l00003ojgHmP;o00000_n/f_P3o`0000Co[N7i0_l0
00000onZi?[o0000o`000003oj[/n@;o00000onVm?400ol0003oVO?Io`000006o`000006ooW/X_l0
003ooN2JoogPV_l0003ooM>F1_l00003ooBmT`03o`000?o^]YCok[JD00;ok[JD00?o0000onR`UooX
/9L00_oX/9L00ol0003ohj^Jon>[VP02on>[VP03o`000?oRYI;o000000Kog::F00?o0000omJOW?l0
00001ooDV9H2o`0000Oob8jG00?o0000ok9jU_l000001?njQI/00ol0003o[gVHojmiV004ojmiV003
o`000?nQKIKoXFfF00CoXFfF00?o0000ohmNU?n?GY@00on?GY@00ol0003oNe2Bog]@TP02og]@TP03
o`000?mW@Y7oId:A00;oId:A00?o0000oeHhT_mF>9800_mF>9801?l0003oB3>FodPcU_m8<iH2o`00
00?o7QJ:0_l000000ol007go0000o`000007o`0000;o:iC_1_l000000omM/?_o0000ogBin`05ogBi
n`03o`000?n2_O[oP[gj00;oP[gj1_l00004ohVmn003o`000?n?_oOoSkog00CoSkog00?o0000oiC1
m_nD`OH01?nD`OH6o`0000?oU/7e00?o0000oiW2m?nI`_@01_nI`_@00ol0003oVl;coi_2l`03o`00
00;oV/;d00?o0000oic3lonL`o<01OnL`o<00ol0003oWL?coig3l`02oig3l`Go00001_nM`o800ol0
003oW/?boik3lP04oik3lPCo00001_nO`o800ol0003oWl?boio3lP04oio3lPCo00001OnO`o800ol0
003oX<?aoj33l@02oj33l@03o`000?nP`o7o000000;o0000@_oonfX7o`0002Cooo]Z000UoookJPKo
0000D?oonfX00ol0003ooo]ZoookJP0ZoookJP;o00001_n]f?H3o`0000So[N7i1?l00002oj[/n@04
o`000?nVm?7oY_CaojKdl@Wo000000Col?J^o`000?oik:;o00000_omh9X2o`000003ooOEZ?l0003o
m<^T00;om<^T0_l00002ooBmT`03o`000?o^]YCok[JD00;ok[JD00?o0000onR`UooX/9L00_oX/9L0
0ol0003ohj^Jon>[VP02on>[VP03o`000?oRYI;o000000Kog::F00?o0000omJOW?l000001_oDV9H0
0ol0003ocINLo`000007olR>U`03o`000?nbNYKo000000Co^XFK00?o0000ojmiV?n_NIP01?n_NIP0
0ol0003oXFfFoj5]UP04oj5]UP03o`000?n?GYCoSejD00?oSejD00?o0000og]@T_mkD9800_mkD980
0ol0003oId:AofM2T@02ofM2T@03o`000?mF>9;oESRB00;oESRB00Co0000odPcU_m8<iKoB3>F0_l0
0003oahFRP03o`000?lI79Go000000Oo000000?o05_:o`000?l000001?l[U>l00ol0003oEj_ioeN[
n@0=o`0000?oOk[i00?o0000ohVmn?n9_OP01On9_OP00ol0003oSkogohnom`04ohnom`03o`000?nD
`OKoU<7f00?o00000_nC`?H00ol0003oU/7eoiK1m@05oiK1m@03o`000?nI`_CoVL;d00CoVL;d1?l0
0006oi[2m003o`000?nL`o?oW<?c00CoW<?c1Ol00004oic3l`03o`000?nM`o;oWL?b00GoWL?b00?o
0000oik3l_nN`o800ol00002oik3lP03o`000?nO`o;oWl?b00KoWl?b00?o0000oio3l_nO`o800ol0
0002oio3lP03o`000?nO`o;oWl?b00GoWl?b00?o0000oj33lOnP`o400ol00002oj33l@03o`000?oo
nf[ooo]Z043ooo]Z2?l0000SoookJP009OoonfX6o`00057ooo]Z00?o0000oookJ_oonfX09ooonfX3
o`0000Go[MSf0_l00003ojoMm`;o00001?n]hOT2o`0000Co[nWh2ol000000oo4o/oo0000o`000002
o`0000;onNbR00Ko0000oogPV_l0003o0000ooOEZ?l00003ooC;Y003o`000?o``Z7ol<:Q00;o0000
1?o^]Y@00ol0003oj;2GonR`U`03onR`U`03o`000?oSZi[ohj^J00?ohj^J0_l00006ombRUP03o`00
0?oFWico000000Koe9RF00?o0000olfGW?l000001oo8SYL2o`0000Go^XFK00?o0000ojmiV?n_NIP0
1?n_NIP00ol0003oXFfFoj5]UP04oj5]UP03o`000?n?GYCoSejD00?oSejD00?o0000og]@T_mkD980
0_mkD9800ol0003oId:AofM2T@02ofM2T@03o`000?mF>9;oESRB00;oESRB00?o0000odPcU_m8<iH0
0_m8<iH01_l0003o7QJ:oahFR_lN5X[o0000oaTLU@;o000000?o00R@o`000?l000001Ol000000ol0
Fl[o0000o`000002o`000003ob^Dkol0003oEj_i00CoEj_i00?o0000og2en_m`]OX00om`]OX00ol0
003oOk[iognjn@04ognjn@03o`000?n9_OSoRKgh00GoRKgh00Co0000ohnomon?_oOoSkog1Ol00006
oi?0mP03o`000?nF`OGoU/7e00GoU/7e00?o0000oiW2m?nI`_@00ol00002oiS2m003o`000?nJ`_Co
V/;d00KoV/;d00?o0000oic3lonL`o<00ol000000onK`o?o0000oic3l`07oic3l`03o`000?nM`o;o
WL?b00;oWL?b1Ol00006oik3lP03o`000?nO`o;oWl?b00CoWl?b1?l00006oio3lP03o`000?nO`o;o
Wl?b00CoWl?b0ol00002oj33l@05o`000?nP`o7oX<?aoj33lOl00000@_oonfX8o`0002;ooo]Z000U
oookJPGo0000DooonfX00ol0003ooo]ZoookJP0SoookJP?o00000on^e_D2o`000003ojgHm_l0003o
000000Oo[mgg00Co0000ojgQnOl0003o00001?n_jOP2o`0000;o/O;e0ol000001?n`nN[o0000o`00
0?l00002olCnc`?o000000Gol?J^o`000?oik:;o0000oogPVP02o`0000;ommFX00Go0000ooC;Y?od
bjCom<^To`000003oo32X@03o`000?o^]YCok[JD00;ok[JD00?o0000onR`UooX/9L00_oX/9L00ol0
003ohj^Jon>[VP04on>[VP03o`000?oLXYKog::F00Cog::F00Co0000omJOW?oFWico00001_oDV9H0
1?l0003ocINLolfGW?l00006olR>U`;o00001OnjQI/00ol0003o[gVHojmiV004ojmiV003o`000?nQ
KIKoXFfF00CoXFfF00?o0000ohmNU?n?GY@00_n?GY@5o`000003og]@T_l0003oId:A00?oId:A00?o
0000oeHhT_mF>9800omF>9801Ol0003oB3>FodPcU_m8<iKo000000?o7QJ:00?o0000oaTLUOlI79D0
1?l000000ol008oo0000o`000005o`0000;o:Hk]1ol000000omGZoWo0000og2enP04og2enP03o`00
0?mo^_WoOk[i00CoOk[i00?o0000ohVmn?n9_OP00_n9_OP6o`0000GoS[og00?o0000oi?0m_nC`?H0
1?nC`?H00ol0003oU/7eoiK1m@02oiK1m@Go00001_nH`_@00ol0003oV/;doi[2m004oi[2m0Co0000
1OnK`o<00ol0003oW<?coic3l`04oic3l`Ko00001?nM`o<00ol0003oW/?boik3lP05oik3lP03o`00
0?nO`o;oWl?b00?o00000_nN`o800ol0003oWl?boio3lP06oio3lP03o`000?nO`o;oWl?b00?o0000
00?oWl?bo`000?nP`o400onP`o401Ol0003oX<?aoj33lOnP`o7o000004;ooo]Z1ol0000RoookJP00
9OoonfX5o`0005Cooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000Oo[]Ke0ol00008ojoMm`Co0000
0_n_jOP2o`000003ok7bmOl0003o000000;o00000_n`nNX3o`0000;oa?k?0ol000001?o`mZko0000
ooW/X_oik:82o`000005ooSP/?l0003ommFXooOEZ?l000000oodbj@01Ol0003ol<:Qoo32XOo``Z7o
000000Cok[JD00?o0000onR`UooX/9L00_oX/9L00ol0003ohj^Jon>[VP04on>[VP03o`000?oLXYKo
g::F00Cog::F00Co0000omJOW?oFWico00001OoDV9H01Ol0003ocINLolfGW?o=Uico000000Kob8jG
0_l00006okZ5V`03o`000?n_NISo[gVH00?o[gVH00?o0000oj5]U_nQKIH01?nQKIH00ol0003oSejD
o`000002o`000003oi=XWOl0003oQ5fM00;oQ5fM0ol00004ofM2T@03o`000?mF>9;oESRB00;oESRB
00Co0000odPcU_m8<iKoB3>F0_l00003oahFRP07o`000?lI79Go0000o`000?l0293o0000o`00S`05
o`000003o`1Ic_l0003o000000Co:Hk]00Co0000oeFVn?mEY_SoEJKh4ol00004ohRln003o`000?n>
_oOoS[og00GoS[og00Co0000oi?0m_nC`?KoTl3f1ol00004oiK1m@03o`000?nH`_CoV<;d00GoV<;d
00?o0000oi[2m?nJ`_@00ol00002oi[2m003o`000?nK`o?oVl?c00GoVl?c00?o0000oic3lonL`o<0
0ol00002oic3l`03o`000?nM`o?oWL?c00KoWL?c00?o0000oik3l_nN`o800_nN`o85o`0000KoW/?b
00?o0000oio3l_nO`o801?nO`o84o`0000GoWl?b00?o0000oj33lOnP`o400_nP`o400ol0003oX<?a
o`000002o`00047ooo]Z2?l0000QoookJP009?oonfX6o`0005Gooo]Z0_l0000MoookJP;o00000on^
do@00ol0003o[]KeojkFm@02ojkFm@;o00000on`f_H00ol0003o[mggojoMm`02ojoMm`?o00001?nb
i?L5o`000003ok7bmOl0003o/?WZ00;o/?WZ0ol00002olCnc`06o`000?o7nK;o0000o`000?o`mZko
00000_oik:800ol0003on>2`o`000002ooOEZ005o`000?odbjCom<^TooC;Y?l000001?o``Z42o`00
00?ok[JD00?o0000onR`UooX/9L00_oX/9L00ol0003ohj^Jon>[VP04on>[VP03o`000?oLXYKog::F
00Cog::F00Co0000omJOW?oFWico00001OoDV9H01Ol0003ocINLolfGW?o=Uico000000Kob8jG00?o
0000okZ5VonjQI/01OnjQI/00ol0003o[gVHojmiV004ojmiV003o`000?nQKIKoXFfF00;oXFfF0ol0
0004oi=XW@03o`000?n4GIgoQ5fM00;oQ5fM00?o0000ogIDW_l000000omW@Y400ol0003oESRBoeHh
TP02oeHhTP07o`000?m8<iKoB3>FodPcU_l0003o?SFMo`000002oahFRP05o`000?lI79Go6AbEo`00
0?l029000_l000000ol008oo0000o`000004o`000004o`1Ic_l0003o0000o`0000;o:Hk]00?o0000
oeFVn?mEY_P00_mEY_P00ol0003oK[;iofjbn@04ofjbn@03o`000?mn^OWoO[Wi00CoO[Wi00?o0000
ohRln?n8_?P01On8_?P00ol0003oS[ogohjom`02ohjom`Ko00000onB`?H00ol0003oU/7eoiK1m@06
oiK1m@03o`000?nH`_CoV<;d00;oV<;d1Ol00006oi[2m003o`000?nK`o?oVl?c00CoVl?c0ol00006
oic3l`03o`000?nM`o?oWL?c00CoWL?c1_l00004oig3l`03o`000?nN`o;oW/?b00GoW/?b00?o0000
oio3l_nO`o800ol00002oik3lP03o`000?nO`o;oWl?b00GoWl?b00?o0000oj33lOnP`o400ol00002
oio3lP03o`000?oonf[ooo]Z043ooo]Z2?l0000PoookJP009?oonfX6o`0005Oooo]Z00?o0000oook
J_oonfX06?oonfX2o`0000Ko[]?d00Co0000ojkFmOl0003o00001_n`f_H01?l0003o[mggo`000?l0
0005ok;Tm`Co00000_ngkOH6o`000004ol3liOl0003oa?k?olCnc`Co000000?ol?J^o`000?oik:80
0_l00002ooSP/004o`000?ogeJSommFXo`0000?om<^T00Go0000oo32XOo``Z7ol<:Qo`000002onbk
X@04o`000?o^]YCok[JDo`0000Coj;2G00?o0000on>[V_oSZiX00ooSZiX2o`0000Kog::F00Co0000
omJOW?oFWico00001OoDV9H01Ol0003ocINLolfGW?o=Uico000000Kob8jG00?o0000okZ5VonjQI/0
1OnjQI/00ol0003o[gVHojmiV004ojmiV007o`000?nQKIKoXFfFoj5]U_l0003oXG>Oo`000005oi=X
W@03o`000?n4GIgoQ5fM00;oQ5fM00?o0000ogIDW_mfE9h00_l000000omW@Y7o0000oeHhTP03oeHh
TP03o`000?m8<iKoB3>F00;oB3>F0_l00002oahFRP03o`000?lI79Go6AbE00;o000000Go00R@o`00
0?l008oo0000o`09V`03o`000003o`1Me?l0003o000000Ko00001?mEY_P00ol0003oK[;iofjbn@04
ofjbn@03o`000?mn^OWoO[Wi00CoO[Wi00?o0000ohRln?n8_?P00_n8_?P7o`0000?oS[kg00?o0000
oi;0m_nB`?H01?nB`?H00ol0003oU/7eoiK1m@04oiK1m@Ko00001?nH`_@00ol0003oV/;doi[2m005
oi[2m003o`000?nK`o?oVl?c00?o00000_nK`o@00ol0003oW<?coic3l`05oic3l`03o`000?nM`o?o
WL?c00?o00000_nL`o<00ol0003oWL?coig3l`06oig3l`03o`000?nN`o;oW/?b00;oW/?b1Ol00006
oik3lP03o`000?nO`o;oWl?b00CoWl?b0ol00002oio3lP05o`000?nO`o;oWl?boio3l_l00000@_oo
nfX7o`00023ooo]Z000ToookJPKo0000F?oonfX00ol0003ooo]ZoookJP0EoookJP?o00001on^do@3
o`0000Oo/=[f1Ol00002ok;Tm`?o00001?ngkOH01Ol0003o^oGaok_elOnkmO7o000000;o`?cU00?o
0000olCncoo4o/l00_l000001?oJo];o0000oo3f[_o`mZh2o`000004ooG[^_l0003on>2`o`0000?o
mmFX00Go0000ooC;Y?odbjCom<^To`000003oo32X@04o`000?o/^j7ok;^QonbkX@;o00001?oX/9L0
0ol0003ohj^Jon>[VP04on>[VP03o`000?oMZ9oo000000Cog::F00?o0000omJOW?oFWi`00_oFWi`0
1Ol0003oe9RFomBHU_oDV9Ko000000CocINL00?o0000olR>Uoo8SYL00oo8SYL2o`0000Oo^XFK00?o
0000ojmiV?n_NIP01?n_NIP01?l0003oXFfFoj5]U_l00002oj5cW`03o`000?nCJ9goTfRM00?oTfRM
00?o0000ohAMWOn4GId00_n4GId00ol0003oMUBNogIDWP02ogIDWP;o00001?mF>9800ol0003oB3>F
odPcUP02odPcUP05o`000?ln=Igo0000oahFR_l000000olI79D00ol0003o00R@o`000002o`00S`05
o`000?l02I_o0000o`0/]?l000000ol0GM@2o`0000;o;8W]1Ol000000omEY_So0000ofjbn@05ofjb
n@04o`000?mn^OWoO[Wiogjin@Oo00000on7^oL00ol0003oS[kgohjnm`05ohjnm`03o`000?nB`?Ko
T/3f00CoT/3f00?o0000oiK1mOnF`OD00ol00002oiG1m@03o`000?nH`_CoV<;d00KoV<;d00?o0000
oi[2m?nJ`_@00_nJ`_@5o`0000KoVl?d00?o0000oic3lonL`o<01?nL`o<3o`0000KoW<?c00?o0000
oig3lonM`o<01?nM`o<6o`0000CoW/?c00?o0000oik3l_nN`o801OnN`o800ol0003oWl?boio3lP03
o`000003oik3l_l0003oWl?b00?oWl?b00Go0000oio3l_nO`o;oWl?bo`000011oookJPSo00007ooo
nfX002Cooo]Z1_l0001IoookJP03o`000?oonf[ooo]Z017ooo]Z0ol00003ojkAl`03o`000?n^doCo
[]?d00;o[]?d0_l00003ok3Gm003o`000?n`f_Ko/=[f00;o/=[f0_l00004okCPmPCo00001?ngkOH2
o`0000;o^oGa0_l00002ol3li@04o`000?o4o/ooa?k?o`0000;of_kB0_l00002oo3f[P03o`000?oe
jk[o000000;on>2`00Co0000ooOEZ?ogeJSo00000oodbj@00ol0003ol<:Qoo32X@02oo32X@03o`00
0?o/^j7ok;^Q00;ok;^Q00?o0000onR`UooX/9L00_oX/9L00ol0003ohj^Jon>[VP04on>[VP03o`00
0?oMZ9oo000000Cog::F00?o0000omJOW?oFWi`00_oFWi`01Ol0003oe9RFomBHU_oDV9Ko000000Co
cINL00?o0000olR>Uoo8SYL00oo8SYL2o`0000Oo^XFK00?o0000ojmiV?n_NIP01?n_NIP00ol0003o
XFfFo`000003oj5cW`03o`000?nCJ9goTfRM00CoTfRM00?o0000ohAMWOn4GId00_n4GId00ol0003o
MUBNogIDWP02ogIDWP03o`000?mF>9;oESRB00;oESRB00?o0000odPcU_m8<iH00_m8<iH00ol0003o
?SFMocheW@02o`0000?o6AbE00Go0000o`08T?l0293o0000o`00S`02o`000004o`09Vol0003o0000
o`0000Co05gD0ol000001?l/RNgo0000oeFSm_mEXoH<o`0000CoOKOh00?o0000ohNkmon7^oL01?n7
^oL00ol0003oS[kgohjnm`05ohjnm`04o`000?nB`?KoT/3foi;0mPGo00001_nE`OD00ol0003oV<;d
oiS2m004oiS2m0Ko00000onI`o@00ol0003oVl?doi_3m006oi_3m003o`000?nL`o?oW<?c00?o0000
00?oVl?do`000?nL`o<01onL`o<00ol0003oWL?coig3l`03o`0000;oWLCc00?o0000oik3lonN`o<0
1_nN`o<00ol0003oW/?boik3lP02oik3lPGo00001OnN`o800ol0003oWl?boio3lP02oio3lP03o`00
0?nO`o;o000000;o0000@OoonfX8o`0001kooo]Z000ToookJPGo0000FooonfX00ol0003ooo]Zoook
JP0>oookJP;o00001on^dO<01?l0003o[]?do`000?l00006ok3Gm004o`000?n`f_Ko0000o`0000?o
]>3f1?l00003okWVm@;o000000?o]ngfo`000?nkmO400_nkmO401?l0003o`?cUol3liOo0o>D4o`00
00;of_kB0_l000000oo`mZko0000o`000002ooG[^P04o`000?ohh;3on>2`o`0000;ommFX00Go0000
ooC;Y?odbjCom<^To`000003oo32X@03o`000?o/^j7ok;^Q00?ok;^Q00?o0000onR`UooX/9L00_oX
/9L00ol0003ohj^Jon>[VP03on>[VP04o`000?oMZ9oogJROo`0000Cog::F00?o0000omJOW?oFWi`0
0_oFWi`01Ol0003oe9RFomBHU_oDV9Ko000000CocINL00?o0000olR>Uoo8SYL00oo8SYL2o`0000Oo
^XFK00?o0000ojmiV?n_NIP01?n_NIP2o`0000CoXG>O00?o0000oi=XWOnCJ9d01?nCJ9d00ol0003o
Q5fMohAMW@02ohAMW@03o`000?mfE9koMUBN00;oMUBN0_l00003oeHhTP03o`000?m8<iKoB3>F00;o
B3>F00Ko0000ocheWOln=Igo0000oahFR_l00002oaTLU@;o000000Co00R@o`000?l0003o002?0ol0
00001?l0@/Co0000o`000?l00002o`1Me003o`000?lcRNco<hW/00?o00001?mEXoH00ol0003oK[3h
ofj`n004ofj`n003o`000?mm]oSoOKOh00CoOKOh00?o0000ohNkmon7^oL01?n7^oL00ol0003oS[kg
ohjnm`02ohjnm`Ko00001OnB`?H00ol0003oUL7eoiG1m@04oiG1m@03o`000?nH`_CoV<;d00?o0000
0_nG`_D00ol0003oVL?doiW3m005oiW3m003o`000?nK`oCoVl?d00CoVl?d1?l00005oi_3m003o`00
0?nL`o?oW<?c00CoW<?c1?l00006oig4l`03o`000?nN`o?oW/?c00CoW/?c1_l00003oik3l`03o`00
0?nN`o;oW/?b00GoW/?b00?o0000oio3l_nO`o800ol00002oio3lP03o`000?oonf[ooo]Z043ooo]Z
1ol0000NoookJP009?oonfX5o`0005cooo]Z00?o0000oookJ_oonfX02ooonfX3o`0000So[]7c0ol0
0007ok3Gm0?o000000Ko]>3fo`000?l0003o0000okCPm_l00006okWVm@_o000000Kod?cRo`000?oJ
o];of_kBo`000?oUo<02o`000004onkba_l0003omN^jo`0000;on>2`00Co0000ooOEZ?ogeJSo0000
1?odbj@01Ol0003ol<:Qoo32XOo``Z7o000000Cok;^Q00?o0000onJfX_l000000ooX/9L00ol0003o
hj^Jon>[VP03on>[VP04o`000?oMZ9oogJROo`0000?og::F00?o0000omJOW?oFWi`00ooFWi`01?l0
003oe9RFomBHU_l00005olfGW003o`000?o8SYOob8jG00;ob8jG00Co0000ol:>Woo2SYoo00001_nj
QI/00ol0003o[gVHojmiV004ojmiV003o`000?nQLiooXG>O00CoXG>O00?o0000oi=XWOnCJ9d00onC
J9d00ol0003oQ5fMohAMW@02ohAMW@03o`000?mfE9koMUBN00;oMUBN00?o0000ofU?XOl000000_mF
>9800ol0003oB3>FodPcUP02odPcUP04o`000?ln=Igo?SFMocheW@;o00000olI79D2o`000005o`08
T?l0003o0000o`000?l0:[800_l000000ol0@/Co0000o`000004o`0000Co<hW/1?l000000omEXoKo
0000ofj`n005ofj`n003o`000?mm]oSoOKOh00CoOKOh00Co0000ohNkmon7^oOoQk_g1ol00003ohfn
m`03o`000?nB`?KoT/3f00KoT/3f00Co0000oiG1mOnE`OGoUL7e1Ol00006oiO2m@03o`000?nI`oCo
VL?d00GoVL?d00?o0000oi_3m?nK`o@00ol00002oi[3m003o`000?nK`oCoVl?d00GoVl?d00?o0000
oic3lonL`o<00ol00002oic4m003o`000?nMa??oWLCc00KoWLCc00?o0000oik3lonN`o<00ol00002
oig4l`03o`000?nN`o?oW/?c00GoW/?c00?o0000oik3l_nN`o800_nN`o85o`0000;oWl?b00Go0000
oio3l_nO`o;oWl?bo`000011oookJPSo00007OoonfX002?ooo]Z1_l0001MoookJP03o`000?oonf[o
oo]Z00Oooo]Z0ol00003ojk@lP;o00001?n^dO<2o`0000?o/=Cc00?o0000ok3Gm?n`eo@00_n`eo@2
o`0000;o]=cd0ol000000ondh?Ko0000o`000006okWVm@05o`000?nok_;o_nkboko^l_l000000oo6
m^d01Ol0003od?cRom3lh_o@o>;o000000;of_kB00?o0000onGl`?l000000_o^l/H01?l0003omN^j
ooG[^_l00002ooSP/004o`000?ogeJSommFXo`0000?om<^T00?o0000oo32XOo``Z400_o``Z400ol0
003ok;^QonbkX@02onbkX@03o`000?oV]Z;o000000;oj;2G00?o0000on>[V_oSZiX01?oSZiX01?l0
003ogJROomfXWol00003ombRUP03o`000?oFWicoeYnL00?oeYnL00Co0000omBHU_oDV9Ko00001Oo=
Ui`00ol0003ob8jGolR>U`02olR>U`04o`000?o2SYoo`XjOo`0000Ko^XFK00?o0000ojmiV?n_NIP0
1?n_NIP00ol0003oXG>Ooj5cW`04oj5cW`03o`000?nCJ9goTfRM00?oTfRM00?o0000ohAMWOn4GId0
0_n4GId00ol0003oMUBNogIDWP02ogIDWP04o`000?mYCj7oJDnQo`0000;oESRB00?o0000odPcU_m8
<iH00_m8<iH01Ol0003o?SFMocheWOln=Igo000000?o6AbE00Go0000oa`]Y_l0003o0000o`0TZ002
o`000003o`0Z/_l0003o000000;o04;400?o0000o`mUf_l?IMX00_l00003oc>9k004o`000?mHXOGo
F:7eoeRQmA?o00000on7^oL00ol0003oSKkgohfnm`05ohfnm`03o`000?nB`?KoT/3f00CoT/3f1Ol0
0003oiG1mP03o`000?nG`_GoUl;e00KoUl;e00?o0000oiW3m?nI`o@00_nI`o@5o`0000KoV/?d00?o
0000oi_3m?nK`o@01?nK`o@3o`0000KoW<Cd00?o0000oig4lonMa?<01?nMa?<4o`0000KoWLCc00?o
0000oik3lonN`o<01?nN`o<5o`0000CoW/?c00Go0000oio3l_nO`o;oWl?bo`000003oio3lP03o`00
0?oonf[ooo]Z03oooo]Z2?l0000LoookJP008ooonfX6o`0005kooo]Z00?o0000oookJ_oonfX00ooo
nfX3o`0000So[]3b00Co0000ojkAlol0003o00001_n`e?<01Ol0003o/=Odo`000?l0003o]=cd00?o
00000_ndg?@3o`0000Go^NKe0_l00003oko^lP05o`000?o6m^goa_K]olKfkOl000000oo@o>800ol0
003of_kBom[ndP03o`0000;ok_;600Co0000ooG[^_oejk[o00000_ohh;001Ol0003ommFXooOEZ?og
eJSo000000?om<^T00Go0000oo32XOo``Z7ol<:Qo`000005onbkX@03o`000?oV]Z;o000000;oj;2G
00?o0000on>[V_oSZiX00ooSZiX00ol0003ogJROomfXW`02omfXW`04o`000?oLXYKog::Fo`0000Go
eYnL00Co0000omBHU_oDV9Ko00001Oo=Ui`01Ol0003ob8jGolR>Uoo8SYOo000000?o`XjO00?o0000
okZ5VonjQI/01?njQI/00ol0003o[gVHojmiV003ojmiV0;o00001_nQLil00ol0003oTfRMoi=XW@03
oi=XW@03o`000?n4GIgoQ5fM00;oQ5fM00?o0000ogIDW_mfE9h00omfE9h01_l0003oJDnQofU?XOl0
003oESRBo`0000CoB3>F00Go0000ocheWOln=Igo?SFMo`000003oaTLU@04o`000?lL;JKo0000o`00
00;o02BX0_l000000ol0:[;o0000o`12a002o`12a004o`000?l?IM[o3fGJo`mUfP?o000000?o<hW/
o`000?mHXOD01?mHXOD00ol0003oKjkgofn^m`03ofn^m`03o`000?mm]_SoOKKh00GoOKKh00?o0000
ohNkmon7^oL00on7^oL00ol0003oSKkgohfnm`05ohfnm`03o`000?nB`?KoT/3f00?o00000_nA`?H0
0ol0003oUL7foiG1mP04oiG1mP03o`000?nG`_GoUl;e00CoUl;e1_l00004oiW3m@03o`000?nJ`oCo
V/?d00GoV/?d00?o0000oi_3m?nK`o@00ol000000onKa?Co0000oic4m007oic4m003o`000?nMa??o
WLCc00?o00000_nLa?@00ol0003oWLCcoig4l`06oig4l`03o`000?nN`o?oW/?c00?o000000?oWLCc
o`000?nN`o<01onN`o<01?l0003oWl?boio3l_nO`o85o`00047ooo]Z1ol0000LoookJP008ooonfX6
o`0005oooo]Z00?o0000oookJ_oonfX00_l00003ojg>l@;o00001_n^d?83o`0000Oo/=Cc1Ol00003
okCLm0;o00000onihO@3o`000003okWVmOl0003o_nkb00?o_nkb00Go0000olKfkOo6m^goa_K]o`00
0003om3lhP03o`000?oJo];of_kB00;o000000GoiOKCo`000?o^l/Kok_;6o`000002ooG[^P04o`00
0?ohh;3on>2`o`0000;ommFX00?o0000ooC;Y?odbj@00_odbj@01Ol0003ol<:Qoo32XOo``Z7o0000
00Cok;^Q00Oo0000onJfX_oV]Z;oi[JRo`000?oX/9Oo000000Gohj^J00?o0000omfXWooMZ9l00_oM
Z9l01?l0003og::FombRU_l00005omJOW003o`000?oDV9Ko000000KocINL00Go0000olR>Uoo8SYOo
b8jGo`000003ol:>W`03o`000?njQI_o^XFK00Co^XFK00?o0000ojmiV?n_NIP00_n_NIP00ol0003o
[GjQo`000006oj5cW`03o`000?nCJ9goTfRM00?oTfRM00?o0000ohAMWOn4GId00on4GId00ol0003o
MUBNogIDWP02ogIDWP04o`000?mYCj7oJDnQofU?X@;o00001?m8<iH01?l0003o?SFMocheWOln=Id2
o`0000;o6AbE00?o0000oa`]Y_lL;JH00_l00002o`0TZ004o`000?l0:[;o02Zbo`0000?o04;40_l0
00001?l?IM[o0000ocj;kOlnRnd3o`0000GoF:7e00?o0000ofn^mom_[_L00om_[_L00ol0003oOKKh
ogffn005ogffn003o`000?n7^oOoQk_g00?oQk_g00?o0000ohfnmon=__L00_n=__L5o`0000KoTL3f
00?o0000oiG1m_nE`OH01?nE`OH00ol0003oUl;eoiO2m@03o`0000;oUl?f00?o0000oiW3mOnI`oD0
1_nI`oD00ol0003oV/?doi[3m002oi[3m0Go00001OnKa?@00ol0003oW<Cdoic4m004oic4m0Co0000
1_nLa?@00ol0003oWLCcoig4l`04oig4l`Co00001OnMa?<00ol0003oW/?coik3l`04oik3l`Ko0000
1?nN`o800ol0003ooo]ZoookJP0noookJPSo00006ooonfX002?ooo]Z1_l0001PoookJP;o00001on]
c_400ol0003o[]3bojk@lP03o`0000?o/=;b00?o0000ok3Dlon`e?<00_n`e?<4o`000004ok?Hlol0
003o0000okCLm0;o00001onihO@4o`0000;o_nkb00Go0000olKfkOo6m^goa_K]o`000003om3lhPCo
00000_oUm]<01?l0003ok_;6onkba_l00002ooG[^P04o`000?ohh;3on>2`o`0000?ommFX00Go0000
ooC;Y?odbjCom<^To`000004oo32X@03o`000?o/^j7ok;^Q00;ok;^Q00Oo0000onJfX_oV]Z;oi[JR
o`000?oX/9Oo000000Gohj^J00?o0000omfXWooMZ9l00_oMZ9l00ol0003og::Fo`000007omJOW0;o
00001_o=Ui`01Ol0003ob8jGolR>Uoo8SYOo000000?o`XjO00?o0000okZ5VonjQI/01OnjQI/01?l0
003o[gVHojmiV?l00002ojenX@03o`000?nQLiooXG>O00CoXG>O00?o0000oi=XWOnCJ9d00onCJ9d0
0ol0003oQ5fMohAMW@03ohAMW@03o`000?mfE9koMUBN00;oMUBN00?o0000ofU?XOmYCj400_mYCj42
o`0000?oB3>F00?o0000ocheWOln=Id00_ln=Id2o`0000;o6AbE00Co0000oa`]Y_lL;JKo00000ol0
9:P2o`000006o`0Z/_l0003o0000o`12a?l0003o9G3O0ol00004ocj;k@Go000000?oF:7eo`000?m_
[_L01?m_[_L00ol0003oOKKhogffn002ogffn0go00001?n=__L00ol0003oTL3foi70mP05oi70mP04
o`000?nE`OKoUL7foiG1mPGo00001_nG`oH00ol0003oVL?eoiW3m@04oiW3m@Ko00001?nIa?D00ol0
003oVlCdoi_4m004oi_4m003o`000?nLa?CoW<Cd00?o00000onKa?@00ol0003oW<Cdoic4m005oic4
m003o`000?nMa??oWLCc00?o00000_nLa?@00ol0003oWLCcoig4l`05oig4l`03o`000?nN`o?oW/?c
00?o00000_nM`o<01Ol0003oW/?boik3l_nN`o;o000000CoW/?b00?o0000oookJ_oonfX0?_oonfX7
o`0001_ooo]Z000SoookJPGo0000GooonfX3o`0000So[Lka0ol00007ok3BlP03o`000?n`e??o0000
00;o00001Oncf?<3o`0000Go^N7d0ol00004okkWlP_o00000_oJm]l00ol0003oiOKCo`000002onkb
aP05o`000?oejk[omN^jooG[^_l000000_ohh;001Ol0003ommFXooOEZ?ogeJSo000000?om<^T00?o
0000oo32XOo``Z400_o``Z400ol0003ok;^QonbkX@02onbkX@04o`000?oV]Z;oi[JRonJfXP;o0000
1OoSZiX00ol0003ogJROomfXW`03omfXW`03o`000?oLXYKo000000OoeYnL0_l00007olfGW003o`00
0?o8SYOo000000Co`XjO00?o0000okZ5VonjQI/01OnjQI/01?l0003o[gVHojmiV?l00003ojenX@03
o`000?nQLiooXG>O00?oXG>O00?o0000oi=XWOnCJ9d01?nCJ9d00ol0003oQ5fMohAMW@02ohAMW@03
o`000?mfE9koMUBN00;oMUBN00?o0000ofU?XOmYCj400_mYCj400ol0003oGdfVo`000002odPcUP03
o`000?ln=Igo?SFM00;o?SFM00Go0000oc/mZOl0003o6AbEo`000003oa`]YP05o`000?l09:So02BX
o`000?lIAl<00_l000001?lGEm3o0000o`12a?l00002obE`g`;o00001?lnRnd01?l0003oGJ7doefQ
m?mMXO@<o`0000?oO[Kg00?o0000ohNkmon7^oL01On7^oL00ol0003oSKkgohfnm`04ohfnm`03o`00
0?nA`?KoTL3f00;oTL3f1_l00005oiC2mP03o`000?nG`oKoUl?f00CoUl?f00?o0000oiW3mOnI`oD0
0ol00002oiS4mP03o`000?nIa?GoVLCe00KoVLCe00Co0000oi_4m?nKa?CoVlCd1Ol00007oi_4m003
o`000?nLa?CoW<Cd00;oW<Cd1Ol00006oic4m003o`000?nMa??oWLCc00CoWLCc0ol00006oig3l`05
o`000?nN`o;oW/?boik3l_l000000_nN`o83o`00043ooo]Z1ol0000JoookJP008ooonfX5o`0005co
oo]Z0ol00003ojg<l003o`000?n]c_7o[Lka00;o[Lka0ol00003ojo@l@03o`000?n`d_;o/=;b00?o
/=;b1?l00005ok?Hl`;o00000onhg?82o`000003okWQm?l0003o000000Ko_^Ob00Go0000olK]koo6
kNooa^g_o`000004olobj005o`000?oJm]oof_KOom[fgol000000_oUm]<01?l0003ok_;6onkba_l0
0002ooG[^P05o`000?ohh;3on>2`ooSP/?l000000_ogeJP00ol0003om<^TooC;Y002ooC;Y005o`00
0?o``Z7ol<:Qoo32XOl000001?o/^j400ol0003oi[JRonJfXP03onJfXP03o`000?oSZi[ohj^J00?o
hj^J00?o0000omfXWooMZ9l00ooMZ9l00ol0003og::Fo`000007omJOW003o`000?o=UicocINL00Ko
cINL00?o0000olR>Uol000001?o2SYl00ol0003o^XFKokZ5V`05okZ5V`03o`000?n_NISo000000Co
[GjQ00?o0000oj5cWonQLil00onQLil00ol0003oTfRMoi=XW@04oi=XW@03o`000?n4GIgoQ5fM00;o
Q5fM00?o0000ogIDW_mfE9h00_mfE9h00ol0003oJDnQofU?X@02ofU?X@06o`000?mOCJKoGdfVo`00
0?m8<iKo00001?ln=Id01Ol0003o>cfYo`000?lI79Go000000?o72fV0_l00002o`0TZ005o`000?lI
Al?o0000o`000?lGEm000ol00003obE`g`?o00000_lnRnd00ol0003oGJ7doefQm003oefQm003o`00
0?ma[_OoLJkg00CoLJkg00?o0000ogjfmomn]_L00omn]_L00ol0003oQk_gohNkm`05ohNkm`04o`00
0?n=__OoSKkgohfnm`Oo00001?nA`OL00ol0003oU<;foiC2mP05oiC2mP04o`000?nG`oKoUl?foiO3
mPGo00001_nHa?H00ol0003oVLCeoiW4m@04oiW4m@Go00001?nJa?D00ol0003oVlCdoi_4m004oi_4
m0Ko00001?nKa?@00ol0003oW<Cdoic4m005oic4m003o`000?nMa??oWLCc00?o000000?oW<Cdo`00
0?nM`o<01onM`o<00ol0003oW/?boik3lP03o`0000;oWL?c00?o0000oookJ_oonfX0?_oonfX8o`00
01Wooo]Z000DoookJPGo001o2_oonfX5o`0005Wooo]Z0ol00007ojg<l004o`000?n]c_7o0000o`00
00Oo[m3a00?o0000ok3Bl_l000000ol00003ok;DlP;o000000?o/mSco`000?l000001_nhg?83o`00
00Go_^Ob0_l00003olK]k`03o`000?o?l^Soco;X00;oco;X00Go0000om[fgooJm]oof_KOo`000002
onGfd`04o`000?o^l/Kok_;6o`0000?omN^j00Co0000ooSP/?ohh;3o00000oogeJP01Ol0003om<^T
ooC;Y?odbjCo000000Col<:Q00?o0000onbkXOo/^j400_o/^j400ol0003oi[JRonJfXP03onJfXP03
o`000?oSZi[ohj^J00?ohj^J00?o0000omfXWooMZ9l01?oMZ9l2o`0000OoeYnL00?o0000olfGW?o=
Ui`01_o=Ui`2o`0000Ko`XjO00?o0000okZ5VonjQI/01?njQI/2o`0000Go[GjQ00?o0000oj5cWonQ
Lil01?nQLil00ol0003oTfRMoi=XW@03oi=XW@03o`000?n4GIgoQ5fM00;oQ5fM00?o0000ogIDW_mf
E9h00_mfE9h00ol0003oJDnQofU?X@02ofU?X@07o`000?mOCJKoGdfVoem=Y_l0003oB3>Fo`000003
ocheW@03o`000?lk?JWo>cfY00;o00001?lL;JH2o`000004o`0TZ?l0003o6DO3oaU7``;o00000_lG
Em001Ol0003o9G3OobE`golUL=oo000000;oBXo]1?l00005oefQm003o`000?ma[_OoLJkg00CoLJkg
00?o0000ogjfmomn]_L00omn]_L00ol0003oQk_gohNkm`02ohNkm`Ko00000on=__L00ol0003oTL7g
oi71m`06oi71m`03o`000?nD`_KoU<;f00;oU<;f1_l00004oiK3mP03o`000?nHa?KoV<Cf00GoV<Cf
00?o0000oiW4mOnIa?D00ol00002oiS4mP03o`000?nJa?GoV/Ce00GoV/Ce00?o0000oi_4m?nKa?@0
0ol00002oi[5m@03o`000?nKa?CoVlCd00KoVlCd00?o0000oic4m?nLa?@00_nLa?@5o`0000GoW<Cd
00?o0000oig3lonM`o<01?nM`o<4o`000003oig3lol0003oWL?c00?oWL?c00?o0000oookJ_oonfX0
?_oonfX7o`0001Wooo]Z000CoookJPOo001o2?oonfX6o`0005Oooo]Z0_l00002ojc;l003o`000?n]
c?3o[Lc`00Go[Lc`0ol00007ojo@l@Co00001onbe?83o`0000Ko^=cb00Co0000okgPlOnmh?7o_N3a
0ol000000onnio;o0000olK]k`03olK]k`03o`000?o?l^Soco;X00;oco;X00Go0000om[fgooJm]oo
f_KOo`000002onGfd`05o`000?o^l/Kok_;6onkba_l000000_oejkX01Ol0003on>2`ooSP/?ohh;3o
000000?ommFX00Go0000ooC;Y?odbjCom<^To`000004oo32X@03o`000?o/^j7ok;^Q00;ok;^Q00?o
0000onJfX_oV]Z800_oV]Z800ol0003oh[:Uo`000003on>[VP03o`000?oMZ9oogJRO00GogJRO00?o
0000omJOW?oFWi`01OoFWi`2o`0000SocINL0_l00006ol:>W`03o`000?njQI_o^XFK00Co^XFK00?o
0000ojenXOn]OZ401?n]OZ400ol0003oXG>Ooj5cW`04oj5cW`03o`000?nCJ9goTfRM00?oTfRM00?o
0000ohAMWOn4GId00_n4GId00ol0003oMUBNogIDWP02ogIDWP03o`000?mYCj7oJDnQ00?oJDnQ00Co
0000oem=Y_mOCJKoGdfV0_l00004ocheW@03o`000?lk?JWo>cfY00;o00000olL;JH01Ol0003o:4Fk
o`000?l09:So000000;o6DO300Co0000oaMGd?lGEm3o5eO@0ol000000olUL=oo0000odZ?k@03odZ?
kASo00000on7^oL00ol0003oSKkgohfnm`04ohfnm`03o`000?nA`OOoTL7g00CoTL7g1_l00004oi?3
m`03o`000?nF`oKoU/?f00CoU/?f00?o0000oiS4m_nHa?H00_nHa?H5o`0000KoV<Cf00?o0000oi[4
mOnJa?D01?nJa?D3o`0000KoV/Ge00?o0000oi_4m?nKa?@01?nKa?@6o`0000?oVlCd00?o0000oic4
m?nLa?@01OnLa?@00ol0003oWL?coig3l`03o`0000;oW<Cc00Go0000oig3lonM`o?oWL?co`000004
oig3l`03o`000?oonf[ooo]Z03gooo]Z2?l0000:oookJPWo001o1OoonfX001;ooo]Z1?l007l01?oo
nf[o001oo`00Ool007l8oookJPKo0000EOoonfX2o`0000Go[<_`00?o0000ojg<l?n]c?000_n]c?02
o`0000?o[/k`0_l00003ojo@l@?o00000onad_400ol0003o/]Cbok;DlP02ok;DlP;o00000onff?40
1?l0003o^=cbokSLl_nhg?82o`0000Ko_N3a1?l00002olK]k`03o`000?o?l^Soco;X00;oco;X00Go
0000om[fgooJm]oof_KOo`000003onGfd`04o`000?o^l/Kok_;6o`0000?omN^j2_l00002ooC;Y005
o`000?o``Z7ol<:Qoo32XOl000001?o/^j400ol0003oi[JRonJfXP03onJfXP03o`000?oR/ZGo0000
00?ohj^J00?o0000omfXWooMZ9l01OoMZ9l00ol0003oeYnLomJOW005omJOW0;o00002?o=Ui`2o`00
00Ko`XjO00?o0000okZ5VonjQI/01?njQI/00ol0003o[GjQojenX@04ojenX@03o`000?nQLiooXG>O
00CoXG>O00?o0000oi=XWOnCJ9d00onCJ9d00ol0003oQ5fMohAMW@03ohAMW@03o`000?mfE9koMUBN
00;oMUBN00?o0000ofU?XOmYCj400_mYCj400ol0003oGdfVoem=YP02oem=YP;o00000oln=Id01?l0
003o>cfYoc/mZOlk?JT2o`0000;o72fV00?o0000obQ5^olXAK/00_l00003oaU7``;o000000Co5eO@
o`000?ljNn?o>W_S0ol00005odZ?k@03o`000?mSX_CoHj;d00;oHj;d00?o0000ogB_m_md[oH01?md
[oH00ol0003oOkKgognfm`04ognfm`03o`000?n7^oOoQk_g00CoQk_g00?o0000ohfnmon=__L01?n=
__L00ol0003oTL7goi71m`03o`0000;oT<7g00?o0000oi?3monC`oL01_nC`oL01?l0003oU/?foiK3
m_nF`oH7o`0000CoUlCg00?o0000oiS4m_nHa?H01OnHa?H00ol0003oV/Ceoi[4m@03o`0000;oV<Gf
00?o0000oi[5mOnJaOD01OnJaOD00ol0003oVlCdoi_4m003o`0000;oV/Ge00?o0000oi_4m?nKa?@0
1OnKa?@00ol0003oW<Cdoic4m002oic4m0Go00001_nLa?<01Ol0003oWL?coig3lonM`o?o000000;o
WL?c0ol0000ooookJPSo00002OoonfX9o`00O`Gooo]Z0006oookJP[o001o0_oonfX3o`00O`?ooo]Z
0ol007l7oookJPKo0000DooonfX3o`0000Oo[<_`00Co0000ojg<l?l0003o00001on^c_04o`0000Ko
/M;a00Co0000ok;Dl_l0003o00001_nff?400ol0003o^=cbo`000006okgPl@;o00001?o3iNl4o`00
00;oco;X00Go0000om[fgooJm]oof_KOo`000003onGfd`Wo00000_o^g/401Ol0003okmJionoF^Oo_
e[Wo000000;ok/jc0ol00003oo32X@03o`000?o/^j7ok;^Q00;ok;^Q00?o0000onJfX_oV]Z800ooV
]Z800ol0003oh[:Uo`000003on>[VP03o`000?oMZ9oogJRO00GogJRO00?o0000omJOW?oFWi`01OoF
Wi`00ol0003odInSo`000007olfGW003o`000?o2SYoo`XjO00Go`XjO00?o0000okZ5VonjQI/00onj
QI/2o`0000Ko[GjQ00?o0000oj5cWonQLil01?nQLil00ol0003oTfRMoi=XW@03oi=XW@03o`000?n4
GIgoQ5fM00?oQ5fM00?o0000ogIDW_mfE9h00_mfE9h00ol0003oJDnQofU?X@02ofU?X@03o`000?mO
CJKoGdfV00;oGdfV00?o0000oeUA[ol000000_ln=Id01ol0003o>cfYoc/mZOlk?JWo0000oci=^Ol0
00000_lL;JH01?l0003o:4FkobQ5^ol00003oaU7``05o`000?ldJ]So0000oaMGd?l000001?ljNn<5
o`000003odZ?kOl0003oHj;d00?oHj;d00?o0000ogB_m_md[oH01?md[oH00ol0003oOkKgognfm`04
ognfm`03o`000?n7^oOoQk_g00CoQk_g00Co0000ohfnmon=__OoSKkg1Ol00006oi31m`03o`000?nC
`oOoTl?g00CoTl?g1Ol00004oiC4m`03o`000?nGa?OoUlCg00GoUlCg00?o0000oiS4m_nHa?H00_nH
a?H5o`0000KoV<Gf00?o0000oi[5mOnJaOD00_nJaOD5o`0000KoV/Ge00?o0000oi_4m?nKa?@01?nK
a?@5o`0000CoVlCd00?o0000oic4lonLa?<01OnLa?<00ol0003oWL?coig3l`03o`0000;oW<?c00?o
0000oookJ_oonfX0?_oonfX7o`0000Wooo]Z1?l007l:oookJP001_oonfX:o`00O`Sooo]Z0ol007l7
oookJPKo0000D?oonfX3o`0000?o[<[`00?o0000ojc;l?n/bo001?n/bo03o`0000Go[/k`1_l00007
ok7Bl@?o00001onff?43o`0000Go_N3a00?o0000ol?Ukoo3iNl00oo3iNl00ol0003obnW[ol_Yj`02
ol_Yj`_o00000_oUjm<01Ol0003ojnK9on_VbOo[i/Wo000000;ok]k100Go0000onoF^Oo_e[WokmJi
o`000004onk>/`03o`000?o[ak3o000000;ol<:Q00?o0000onbkXOo/^j400_o/^j400ol0003oi[JR
onJfXP02onJfXP07o`000?oR/ZGoh[:Uon:bYOl0003ohj^Jo`000007omfXW`;o00001_oFWi`01?l0
003odInSom6OXol00007olfGW003o`000?o2SYoo`XjO00Go`XjO00?o0000okZ5VonjQI/00_njQI/0
0ol0003o]XRTo`000006ojenX@03o`000?nQLiooXG>O00CoXG>O00?o0000oi=XWOnCJ9d00onCJ9d0
0ol0003oQ5fMohAMW@03ohAMW@03o`000?mfE9koMUBN00;oMUBN00?o0000ofU?XOmYCj400_mYCj40
0ol0003oGdfVoem=YP02oem=YP06o`000?mIDJooFE6_o`000?ln=Igo00000olk?JT01_l0003o?Tfi
oci=^Ol0003o72fVo`0000?o:4Fk0_l00002oaU7``03o`000?ldJ]So000000;o00001?ljNn<01?l0
003oEYC^oeJDk_mFU>h6o`000003of>Rm?l0003oM:of00GoM:of00Co0000ognfmomo]_OoOkKg3Ol0
0004ohfon003o`000?n@`OOoT<7g00GoT<7g00?o0000oi?3monC`oL00ol00002oi;4n003o`000?nD
a?OoU<Cg00GoU<Cg00?o0000oiO4monGa?L00_nGa?L7o`0000CoUlGg00?o0000oiS5m_nHaOH01?nH
aOH5o`0000CoV<Gf00?o0000oi[5mOnJaOD01OnJaOD00ol0003oVlCdoi_4m003o`000003oi[4mOl0
003oVlCd00OoVlCd00?o0000oic4lonLa?<00_nLa?<5o`000003oic3lol0003oW<?c00?oW<?c00?o
0000oookJ_oonfX0?OoonfX8o`0000Wooo]Z1?l007l9oookJP006?oonfX3o`00O`Oooo]Z1Ol0001>
oookJP?o00001on/b_000ol0003o[<_`ojc;l003o`0000?o[Lc`1Ol000000on^c_3o0000o`000003
ok3?l003o`000?nad_7o/M;a00;o/M;a0_l00003okCDl003o`000?nff?7o]]Sa00;o]]Sa0_l00003
ok[Kl0;o000000?o_N3ao`000?l000001Oo3iNl00ol0003obnW[ol_Yj`02ol_Yj`03o`000?oDk>Go
e>cU00;oe>cU00?o0000omg]gOoMkMd00_oMkMd01?l0003oiN_ConG[dol00003on_Vb@05o`000?o^
g/7ok]k1onkN`Ol000000oo_e[T01Ol0003ok/jconk>/oo^c[?o000000?ojlN`0_l00004onbkX@03
o`000?oV]Z;oi[JR00?oi[JR00Oo0000on:bYOoR/ZGoh[:Uo`000?oSZi[o000000OogJRO00?o0000
omRWYOl000001OoFWi`01?l0003odInSom6OXol00006olfGW0;o00001oo2SYl00ol0003o^XFKokZ5
V`02okZ5V`04o`000?nfR:Co]XRTo`0000Ko[GjQ00?o0000oj5cWonQLil00onQLil00ol0003oTfRM
oi=XW@03oi=XW@03o`000?n4GIgoQ5fM00?oQ5fM00?o0000ogIDW_mfE9h00_mfE9h00ol0003oJDnQ
ofU?X@02ofU?X@03o`000?mOCJKoGdfV00?oGdfV00?o0000oeUA[omIDJl00_l00004oc/mZ@03o`00
0?lnCKWo?Tfi00;o00000olXAK/01Ol0003o>F7?o`000?lIAl?o000000?o=6[H00?o0000ocYkholj
Nn<00oljNn<00ol0003oEYC^oeJDkP02oeJDkP04o`000?mYYOCoJJGdofVUm0co00000on1^?P00ol0
003oQkchohNln005ohNln003o`000?n=_oSoSKoh00CoSKoh00?o0000oi31mon@`OL00_n@`OL5o`00
00KoT/Ch00?o0000oiC4monDa?L01?nDa?L5o`0000CoULKh00?o0000oiO5monGaOL01OnGaOL00ol0
003oV<GfoiS5mP03o`000003oiK6mol0003oV<Gf00OoV<Gf00?o0000oi[5mOnJaOD00_nJaOD5o`00
00GoV/Ce00?o0000oi_4m?nKa?@01?nKa?@6o`0000CoVlCd00Co0000oic3lonL`o?o00000onL`o<0
0ol0003ooo]ZoookJP0noookJPSo00002OoonfX5o`00O`Oooo]Z000CoookJP;o001o0_oonfX4o`00
O`Oooo]Z1Ol0001<oookJP;o00000_n[bNl00ol0003o[<[`ojc:l005ojc:l0?o00001On]c?04o`00
0003ojk>l?l0003o000000Ko/<o`00Co0000ok7BlOl0003o00001_nde?001?l0003o]]Sao`000?l0
0006ok[Kl0?o00001Oo3iNl00ol0003obnW[ol_Yj`02ol_Yj`03o`000?oDk>Goe>cU00;oe>cU00?o
0000omg]gOoMkMd00_oMkMd01?l0003oiN_ConG[dol00003on_Vb@05o`000?o^g/7ok]k1onkN`Ol0
00000oo_e[T00ol0003ok/jconk>/`02onk>/`03o`000?o[ak3ojlN`00;ojlN`00?o0000onbkXOo/
^j400_o/^j400ol0003oi[JRonJfXP03onJfXP07o`000?oR/ZGoh[:Uon:bYOl0003ohj^Jo`000007
omfXW`03o`000?oHYjGo000000GoeYnL00Co0000om6OXooAWj?o00001_o=Ui`2o`0000Oo`XjO00Go
0000okZ5VonjQI_o^XFKo`000003okJ8Y003o`000?n]OZ7o[GjQ00Co[GjQ00?o0000oj5cWonQLil0
0onQLil00ol0003oTfRMoi=XW@04oi=XW@03o`000?n4GIgoQ5fM00;oQ5fM00?o0000ogIDW_mfE9h0
0_mfE9h00ol0003oJDnQofU?X@03ofU?X@03o`000?mOCJKoGdfV00;oGdfV00Co0000oeUA[omIDJoo
FE6_0_l00003oc/mZ@04o`000?lnCKWo?Tfioci=^@;o00000olXAK/00ol0003o>F7?o`000002o`00
00?o=6[H1Ol000000oljNn?o0000oeJDkP03oeJDkP03o`000?mYYOCoJJGd00;oJJGd00?o0000ogN`
momg/?L01Omg/?L00ol0003oPKShoh6hn003oh6hn003o`000?n7_?SoQkch00GoQkch00Co0000ohfo
n?n=_oSoSKoh1ol00004oho3n003o`000?nBa?SoT/Ch00GoT/Ch00?o0000oiC4monDa?L00ol00000
0onCa_Wo0000oiG6n007oiG6n003o`000?nGaOOoUlGg00;oUlGg1Ol00005oiK6m`03o`000?nHaOKo
V<Gf00CoV<Gf1_l00004oiS5mP03o`000?nJa?GoV/Ce00CoV/Ce00?o0000oi_4m?nKa?@00ol00002
oi[4m@03o`000?nKa?CoVlCd00KoVlCd00?o0000oic3lonL`o<01Ol00010oookJPOo00002ooonfX4
o`00O`Kooo]Z000CoookJPOo001o1ooonfX6o`0004[ooo]Z0_l00005oj_9k`03o`000?n/b_3o[<[`
00;o[<[`0_l00003ojg;l003o`000?n]c?3o000000;o00000_n]c?04o`0000Oo/<o`0ol00007okCD
l0?o00001Onjfo02o`0000?o`=k_0ol000000oo3iNoo0000ol_Yj`03ol_Yj`03o`000?oDk>Goe>cU
00;oe>cU00?o0000omg]gOoMkMd00_oMkMd01Ol0003oiN_ConG[dooUjm?o000000?ojnK900Go0000
onkN`Oo^g/7ok]k1o`000003onoF^@05o`000?o^c[?ok/jconk>/ol000001Oo[ak000ol0003ok;^Q
onbkX@02onbkX@03o`000?oV]Z;oi[JR00;oi[JR00?o0000on:bYOoR/ZD00ooR/ZD00ol0003ogJRO
omfXW`05omfXW`04o`000?oHYjGof:NUo`0000CoeYnL00Go0000om6OXooAWj?odInSo`000005olfG
W004o`000?o8V:Gob9RUo`0000Oo`XjO00?o0000okZ5Vol000001?nfR:@00ol0003o[GjQojenX@04
ojenX@03o`000?nQLiooXG>O00?oXG>O00?o0000oi=XWOnCJ9d01?nCJ9d00ol0003oQ5fMohAMW@03
ohAMW@05o`000?mfE9koMUBNogIDW_l000001OmYCj400ol0003oGdfVoem=YP02oem=YP03o`000?mI
DJooFE6_00;oFE6_0_l00002oc/mZ@03o`000?lnCKWo?Tfi00;o?Tfi0_l00002obQ5^`05o`000?li
HLoo>F7?ocUQcol000001?ldJ]P01?l0003oCHKWodf6iom=Q^L6o`000003oeJDk_l0003oJJGd00?o
JJGd00?o0000ogN`momg/?L01Omg/?L00ol0003oPKShoh6hn003oh6hn003o`000?n7_?SoQkch00;o
Qkch1_l00005ohc1n@03o`000?n?`oSoSl?h00CoSl?h00?o0000oi;4n?nBa?P00_nBa?P5o`0000Go
TlKi00?o0000oiG6n?nEa_P01?nEa_P6o`0000CoU<Kh00?o0000oiK6monFa_L01?nFa_L00ol0003o
V<GfoiS5mP03o`0000;oU/Kg00?o0000oiS5m_nHaOH01_nHaOH01?l0003oV/Ceoi[4mOnJa?D5o`00
00KoV/Ce00?o0000oi_4m?nKa?@01?nKa?@5o`0000CoVl?d00?o0000oookJ_oonfX0?OoonfX8o`00
00_ooo]Z0ol007l6oookJP004ooonfX6o`00O`Sooo]Z1_l00018oookJP?o00001on[bNl01?l0003o
[<[`o`000?l00004ojg;l0?o00000_n]c?03o`0000Co[lg`00?o0000ok3?l?n`co000_n`co02o`00
00?o/m7`00?o0000okCDl?nde?000_nde?02o`0000?o^=K`0_l000000onjfo3o0000o`000007ol3N
k`Co00000_o;jN/00ol0003oe>cUomC/i@02omC/i@03o`000?oMkMgogNgM00;ogNgM00Go0000onG[
dooUjm?oiN_Co`000003on_Vb@05o`000?o^g/7ok]k1onkN`Ol000000oo_e[T00ol0003ok/jconk>
/`02onk>/`03o`000?o[ak3ojlN`00;ojlN`00?o0000onO1[ol000000_o/^j400ol0003oi[JRonJf
XP03onJfXP03o`000?oR/ZGoh[:U00?oh[:U00?o0000omfXWooMZ9l01OoMZ9l01?l0003of:NUomRW
YOl00004omJOW003o`000?oAWj?odInS00;odInS00?o0000olfGW?o=Ui`00_o=Ui`01?l0003ob9RU
olRHYOl00007ol:>W`03o`000?njQI_o000000Co]XRT00?o0000ojenXOn]OZ401?n]OZ400ol0003o
XG>Ooj5cW`04oj5cW`03o`000?nCJ9goTfRM00?oTfRM00?o0000ohAMWOn4GId00on4GId01Ol0003o
MUBNogIDW_mfE9ko000000GoJDnQ00?o0000oem=Y_mOCJH00_mOCJH00ol0003oFE6_oeUA[`02oeUA
[`03o`000?mGFk[o000000;o>cfY00Oo0000oci=^OlnCKWo?Tfio`000?m6HL[o000000;o:4Fk00Co
0000ocUQcoliHLoo>F7?0ol00002ocAZf003o`000?m=Q^OoCHKW00;oCHKW00Co0000of2Kl?mPVo3o
H9_`1_l000000omYYOCo0000ogN`m`03ogN`m`go00001?n7__T00ol0003oS<7iohc1n@05ohc1n@04
o`000?n?`oSoSl?hoho3n0Oo00001?n@aOT00ol0003oTlKioi?6n@04oi?6n@03o`000?nEa_SoULKh
00?o00000_nBaoT00ol0003oU<KhoiC6n006oiC6n004o`000?nFa_OoU/KgoiK6m`Go00001_nFa_L0
0ol0003oV<GfoiS5mP04oiS5mPGo00001?nHaOH00ol0003oV/Ceoi[4m@05oi[4m@03o`000?nKa?Co
VlCd00?o00000_nJa?@01?l0003oVl?doi_3m?l00004oi_3m003o`000?oonf[ooo]Z03gooo]Z2?l0
000;oookJP?o001o1OoonfX001?ooo]Z0_l007l<oookJPKo0000AOoonfX3o`0000?oZ/S_00?o0000
oj_9kon[bNl01?n[bNl3o`0000;o[L_`0ol00002ojg;l0?o00002?n_cO001?l0003o/<o`o`000?l0
0006ok?Al004o`000?nde?3o0000o`0000Ko^=K`0ol00006ol3Nk`;o00001?o6hN`4o`0000;oe>cU
00?o0000omg]gOoMkMd00_oMkMd01Ol0003oiN_ConG[dooUjm?o000000CojnK900Go0000onkN`Oo^
g/7ok]k1o`000003onoF^@05o`000?o^c[?ok/jconk>/ol000001Oo[ak001_l0003oil6_onO1[ol0
003ok;^Qo`0000Goi[JR00?o0000on:bYOoR/ZD00ooR/ZD00ol0003ogJROomfXW`05omfXW`05o`00
0?oHYjGof:NUomRWYOl000000_oFWi`00ol0003odInSom6OX`03om6OX`05o`000?o=UicocINLolfG
W?l000000oo8V:D00ol0003o`XjOol:>W`05ol:>W`;o00001OnfR:@00ol0003o[GjQojenX@04ojen
X@03o`000?nQLiooXG>O00CoXG>O00?o0000oi=XWOnCJ9d00_nCJ9d9o`0000?oMUBN00?o0000ofU?
XOmYCj400_mYCj400ol0003oGdfVoem=YP03oem=YP05o`000?mIDJooFE6_oeUA[ol000000_mGFkX0
0ol0003o>cfYo`000004oci=^@03o`000?m6HL[o000000;o00000oliHLl00ol0003oBgcPod]lh004
o`0000CoCHKW00?o0000of2Kl?mPVo000_mPVo001?l0003oKj[eofnZmOm_Z_D6o`0000?oN[Cg00?o
0000oh:jnOn2^_T01On2^_T00ol0003oQkkiohNnn@04ohNnn@03o`000?n<`OWoS<7i00;oS<7i1_l0
0004ohk5nP03o`000?n@aOWoT<Gi00GoT<Gi00Co0000oi?6nOnCa_WoTlKi1Ol00006oi;7n@03o`00
0?nDa_SoU<Kh00CoU<Kh1Ol00004oiC7n@03o`000?nFa_OoU/Kg00GoU/Kg00?o0000oiS5m_nHaOH0
0ol00002oiK5m`03o`000?nHaOKoV<Gf00GoV<Gf00?o0000oi[4mOnJa?D00_nJa?D5o`0000KoV/Cd
00Co0000oi_3m?nK`oCo00000_nK`o@3o`0003oooo]Z1ol00005oookJP?o001o0ooonfX3o`00O`Go
oo]Z000CoookJP;o001o3?oonfX6o`0004;ooo]Z0ol00007oj[8k`03o`000?n[bNooZlW_00?o0000
0on/b^l2o`0000?o[L_`0_l00003ojk<k`03o`000?n_cO3o[lg`00Go[lg`0ol00007ok?Al0?o0000
1_nhe_001Ol0003o_=W^okcIk_nlfNko000000Co`=k_00?o0000olKQk?o6hN`00oo6hN`00ol0003o
cN?XolgSj002olgSj0Co00000_oMkMd00ol0003oiN_ConG[d`02onG[d`05o`000?o[i/WojnK9on_V
bOl000000oo^g/400ol0003okmJionoF^@02onoF^@05o`000?o^c[?ok/jconk>/ol000001?o[ak00
1ol0003oil6_onO1[ooW`Joo0000onbkXOl000001?oV]Z800ol0003oh[:Uon:bY@03on:bY@03o`00
0?oM/:Wo000000GogJRO00?o0000omRWYOoHYjD00_oHYjD01?l0003oeYnLomJOW?l00005om6OX`05
o`000?o=UicocINLolfGW?l000000oo8V:D00ol0003o`XjOol:>W`05ol:>W`03o`000?nfR:Co]XRT
00Co]XRT00?o0000ojenXOn]OZ401?n]OZ400ol0003oXG>Ooj5cW`04oj5cW`03o`000?nCJ9go0000
00;o000000?oUgBYo`000?n<KJT01?n<KJT00ol0003oPVN/o`000003o`0000CoJDnQ00?o0000oem=
Y_mOCJH00omOCJH00ol0003oFE6_oeUA[`02oeUA[`03o`000?mGFk[oEe^j00;o00001?lnCKT01Ol0
003oAV7:odIQb_m6HL[o000000Co>F7?00?o0000od]lh?m;O>000_m;O>05o`000003odf6iol0003o
H9_`00?oH9_`00?o0000ofnZmOm_Z_D01?m_Z_D00ol0003oN[CgogZdm`03ogZdm`03o`000?n2^_Wo
P[[i00GoP[[i00Co0000ohNnnOn7__WoQkki1ol00004oh[4nP03o`000?n>aO[oS/Gj00CoS/Gj00?o
0000oi35nOn@aOT00_n@aOT6o`0000CoT<Oj00?o0000oi;7nOnBaoT01OnBaoT00ol0003oU<KhoiC6
n003o`0000;oTLOj00?o0000oiC7nOnDaoT01OnDaoT00ol0003oU/KgoiK6m`02oiK6m`Go00001_nF
aOL00ol0003oV<GfoiS5mP03oiS5mPKo00001?nHa?H00ol0003oV/Cdoi[4m004oi[4m003o`000?nK
`oCoVl?d00?o00000_nJ`o@00ol0003ooo]ZoookJP0moookJPOo00001OoonfX3o`00O`?ooo]Z0ol0
07l5oookJP005?oonfX7o`00O`Kooo]Z1Ol00010oookJP?o00000_nZanl00ol0003oZ/S_oj[8k`05
oj[8k`?o00000on/b^l3o`000003ojc:kol0003o[L_`00;o00001_n^c>l00ol0003o[lg`ojo=l002
ojo=l0;o00000onacnl00ol0003o/m7`ok?Al002ok?Al0;o00000onfdnl01?l0003o^=K`okSFl?nh
e_02o`0000Go_=W^00Co0000ol3Nkol0003o00001?o6hN`2o`0000GocN?X00Co0000omCTh_oDi>;o
e>CR1?l00002onG[d`05o`000?o[i/WojnK9on_VbOl000001?o^g/401Ol0003okmJionoF^Oo_e[Wo
000000?ok/jc00?o0000on_7/?o[ak000oo[ak000ol0003oil6_onO1[`02onO1[`03o`000?oV]Z;o
i[JR00?oi[JR00?o0000on:bYOoR/ZD00ooR/ZD00ol0003ogK2Yo`000005omfXW`03o`000?oHYjGo
f:NU00;of:NU00Co0000omJOW?oFWico00001OoAWj<01Ol0003ocINLolfGW?o=Uico000000?ob9RU
00?o0000ol:>Woo2SYl01Oo2SYl00ol0003o]XRTokJ8Y005okJ8Y003o`000?n]OZ7o[GjQ00?o[GjQ
00?o0000oj5cWonQLil00onQLil3o`0000CoUgBY00?o0000oha]ZOn<KJT00on<KJT00ol0003oPVN/
oh9W[002oh9W[0?o00000omYCj400ol0003oGdfVoem=YP02oem=YP03o`000?mIDJooFE6_00;oFE6_
00Co0000oeMK^_mGFk[oEe^j0_l00003oci=^@03o`000?m6HL[oAV7:00;oAV7:0ol00002ocUQc`03
o`000?m;O>3oBgcP00;oBgcP00Co0000oebCk?mLTncoG9?/1_l000000omPVo3o0000ofnZm@05ofnZ
m@03o`000?mj]?OoN[Cg00?oN[Cg00?o0000oh:jnOn2^_T00_n2^_T6o`0000CoQ/7k00?o0000oh[4
n_n:a?X01On:a?X01?l0003oS/Gjohk5n_n>aOX7o`0000CoSLSk00?o0000oi37n_n@aoX01?n@aoX0
0ol0003oT/Oioi;7n@02oi;7n@Go00001_nAaoX00ol0003oU<OioiC7n@02oiC7n@Oo00001?nCa_T0
0ol0003oU/GgoiK5m`04oiK5m`03o`000?nHaOKoV<Gf00?o00000_nFaOL00ol0003oV<CfoiS4mP06
oiS4mP04o`000?nJa?CoV/Cdoi[4m0Go000000?oV/?do`000?nJ`o@00onJ`o@00ol0003ooo]Zoook
JP0koookJPSo00001OoonfX4o`00O`;ooo]Z0ol007l5oookJP005?oonfX7o`00O`Kooo]Z1Ol0000m
oookJP?o00001_nZanl00ol0003oZ/S_oj[8k`02oj[8k`;o00000_n[bNl4o`0000Co[<[_0ol00008
ojk<k`04o`000?n_cO3o0000o`0000Ko/Lo_00Co0000ok?Al?l0003o00001_nfdnl00ol0003o^=K`
o`000007okcIkP?o00001?o6hN`00ol0003ocN?XolgSj004olgSj003o`000?oDi>;oe>CR00;oe>CR
00Co0000om_Sg?oKhmcofn?L1?l00002on_Vb@05o`000?o^g/7ok]k1onkN`Ol000001?o_e[T01Ol0
003ok/jconk>/oo^c[?o000000CojlN`00?o0000onO1[ooW`Jl00ooW`Jl00ol0003oi[JRonJfXP03
onJfXP03o`000?oR/ZGoh[:U00?oh[:U00?o0000omf`ZOl000001?oMZ9l00ol0003of:NUomRWY@03
omRWY@03o`000?oFWico000000KodInS00Co0000olfGW?o=Uico00001Oo8V:D00ol0003o`XjOol:>
W`03ol:>W`;o00001onfR:@00ol0003o[GjQojenX@04ojenX@07o`000?nQLiooXG>Ooj5cWol0003o
XWbZo`000005oiMdZ@03o`000?n<KJWoS6fY00CoS6fY00Go0000oh9W[?n2IjcoPVN/o`000002ogUU
/0Co00001?mOCJH00ol0003oFE6_oeUA[`02oeUA[`03o`000?mGFk[oEe^j00;oEe^j0_l00003oci=
^@05o`000?m6HL[oAV7:odIQb_l000000_mAN=X4o`0000CoBgcP00?o0000oebCk?mLTn`00_mLTn`0
1?l0003oJJCcofVTlomYY?<Co`0000CoP[kj00?o0000ohK1non6`O/01?n6`O/00ol0003oR/Cjoh[4
nP02oh[4nPKo00001?n:ao`00ol0003oSLSkohg8n`05ohg8n`04o`000?n@ao[oT<Ojoi37nPOo0000
1?n>b?/00ol0003oTLOjoi77nP04oi77nPGo00001?n@aoX00ol0003oTlKioi?6n@05oi?6n@04o`00
0?nFaOOoU/GgoiK5m`Go00001_nFaOL00ol0003oV<CfoiS4mP04oiS4mPGo00001?nH`oD01?l0003o
V/?doi[3m?l00004oi[3m003o`000?oonf[ooo]Z03Oooo]Z0ol00003oookJPGo00001_oonfX7o`00
O`Kooo]Z000PoookJPKo0000>ooonfX2o`0000;oZLO_00?o0000oj[7konZanl01OnZanl01?l0003o
Z/S_o`000?l00002oj_9k`Co00001?n/b^l2o`0000?o[L__0_l00006ojk<k`?o00001onacnl3o`00
00Oo]]?_0ol00005okcIkP;o00000oo1fn`2o`000003olKQk?l0003ocN?X00GocN?X00?o0000omCT
h_oDi>800_oDi>800ol0003ofn?Lom_Sg003om_Sg003o`000?oPhMCoh>7D00Co00000_o^g/401Ol0
003okmJionoF^Oo_e[Wo000000?ok/jc00?o0000on_7/?o[ak000oo[ak000ol0003oil6_onO1[`02
onO1[`03o`000?oS_:oo000000?oi[JR00?o0000on:bYOoR/ZD00ooR/ZD01Ol0003ogK2Yomf`ZOoM
/:Wo000000?ogJRO00?o0000omRWYOoHYjD00ooHYjD00ol0003oeYnLo`000006om6OX`04o`000?o=
UicocINLo`0000Gob9RU00?o0000ol:>Woo2SYl00_o2SYl00ol0003o_Y:Yo`000007okJ8Y003o`00
0?n]OZ7o[GjQ00Co[GjQ00Co0000oj5cWol0003o00000_nRO:X00ol0003oUgBYoiMdZ@04oiMdZ@03
o`000?n<KJWoS6fY00?oS6fY00Go0000oh9W[?n2IjcoPVN/o`000005ogUU/0?o00000_mOCJH00ol0
003oFE6_oeUA[`03oeUA[`06o`000?mGFk[oEe^joeMK^_l0003oFFW80_l000000olnCKWo0000odIQ
bP03odIQbP03o`000?mAN=[oDGSJ00;oDGSJ1?l00002od]lh003o`000?mLTncoG9?/00;oG9?/00?o
0000ofVTlomYY?<00omYY?<00ol0003oM;3gogB`m`04ogB`m`03o`000?ml^?WoO;Si00?oO;Si00?o
0000oh:nn_n2__X01On2__X01?l0003oQ/7kohK1non6`O/7o`0000CoQlOm00?o0000oh[7o?n:ao`0
1?n:ao`00ol0003oSLSkohg8n`02ohg8n`Ko00001?n;bO`00ol0003oS/Skohk8n`05ohk8n`03o`00
0?nAao[oTLOj00?o00000_n=bO`00ol0003oT<Ojoi37nP05oi37nP03o`000?nCa_WoTlKi00;oTlKi
1_l00004oi?6n@03o`000?nFaOOoU/Gg00GoU/Gg00?o0000oiS4m_nHa?H00ol00002oiK4m`03o`00
0?nH`oGoV<?e00GoV<?e00Go0000oi[3m?nJ`oCo0000oi[3m004o`0003Cooo]Z1?l00008oookJP03
o`000?oonf[ooo]Z00Oooo]Z1Ol007l7oookJP008?oonfX6o`0003Wooo]Z0_l00005ojW7k`03o`00
0?nZanooZ/O_00CoZ/O_1_l00004oj_9k`04o`000?n/b^oo0000o`0000Oo[L__00?o0000ojk<kon^
c>l00ol00003ok3=k`03o`000?nacnoo/Lo_00;o/Lo_0_l00003ok?@k`03o`000?nfdnoo]]?_00;o
]]?_0_l00003okWEkP;o000000?o_=W^o`000?l000001_o1fn`3o`0000GocN?X00?o0000omCTh_oD
i>800_oDi>800ol0003ofn?Lom_Sg003om_Sg003o`000?oPhMCoh>7D00;oh>7D00?o0000onCLcOoT
g<d01?l00002onoF^@05o`000?o^c[?ok/jconk>/ol000001?o[ak000ol0003oil6_onO1[`03onO1
[`04o`000?oS_:oohkb_o`0000;oi[JR00?o0000on:bYOoR/ZD00ooR/ZD01Ol0003ogK2Yomf`ZOoM
/:Wo000000?ogJRO00?o0000omRWYOoHYjD01?oHYjD2o`0000OodInS0_l00006olRHY@03o`000?o2
SYoo`XjO00;o`XjO00Co0000okjBZOnnTZWo00001_nfR:@00ol0003o[GjQojenX@04ojenX@;o0000
1?nRO:X00ol0003oUgBYoiMdZ@04oiMdZ@03o`000?n<KJWoS6fY00?oS6fY00?o0000oh9W[?n2Ij`0
0_n2Ij`00ol0003oNFF`ogUU/002ogUU/003o`000?mbI[KoLVJf00Co00001?mIDJl00ol0003oEe^j
oeMK^P02oeMK^P03o`000?mIJLSoFFW800;o00001Om6HLX00ol0003oDGSJoe5hfP02oe5hfP03o`00
0?mMSNOoGHgW00?o00001OmLTn`00ol0003oJJCcofVTl`03ofVTl`03o`000?md/?OoM;3g00CoM;3g
00?o0000ogbhnOml^?T00oml^?T00ol0003oP[kjoh:nnP02oh:nnPKo00001?n4aOd00ol0003oQlOm
ohO7o@05ohO7o@04o`000?n:aocoR/Oloh[7o0Oo00001?n8b_d00ol0003oRlWloh_9o004oh_9o003
o`000?n>b?_oS/Sk00;oS/Sk1Ol00006ohg9o003o`000?n@ao[oT<Oj00;oT<Oj1ol00004oho7nP03
o`000?nCa_WoTlKi00CoTlKi00?o0000oiK5monFaOL00_nFaOL5o`0000KoU/Cg00?o0000oiS3mOnH
`oD00onH`oD6o`0000CoVL?d00?o0000oookJ_oonfX0;_oonfX3o`0000cooo]Z00?o0000oookJ_oo
nfX04ooonfX0023ooo]Z1_l0000goookJP?o00001onYanl00ol0003oZ/O_oj[7k`07o`0000KoZlW_
0ol00008ojg;k`?o00001on`cNl01?l0003o/Lo_o`000?l00006ok?@k`04o`000?nfdnoo0000o`00
00Ko^MG^0ol00006ol7Kk004o`000?o7gNWoamgYolOMj@?o000000?ocN?Xo`000?oDi>800ooDi>80
0ol0003ofn?Lom_Sg003om_Sg003o`000?oPhMCoh>7D00;oh>7D00?o0000onCLcOoTg<d00_oTg<d0
0ol0003oiMK7onGFa`03o`0000;ok/jc00?o0000on_7/?o[ak000oo[ak000ol0003oil6_onO1[`02
onO1[`05o`000?oS_:oohkb_on>l[ol000000_oV]Z800ol0003oh[:Uon:bY@02on:bY@03o`000?oM
/:WogK2Y00?ogK2Y00?o0000omfXWol000001ooHYjD00ol0003odInSom6OX`06om6OX`;o00001_o8
V:D01Ol0003o`XjOol:>Woo2SYoo000000?o_Y:Y00?o0000okJ8Y?nfR:@01?nfR:@00ol0003o[GjQ
ojenX@03ojenX@;o00001_nRO:X00ol0003oUgBYoiMdZ@03oiMdZ@03o`000?n<KJWoS6fY00?oS6fY
00?o0000oh9W[?n2Ij`00_n2Ij`00ol0003oNFF`ogUU/003ogUU/003o`000?mbI[KoLVJf00;oLVJf
0_l00003oeUA[`03o`000?mGFk[oEe^j00;oEe^j00?o0000oeUYb?mIJLP00_mIJLP3o`0000;oAV7:
00?o0000oe5hf_mAN=X00omAN=X00ol0003oGHgWoef=i`02oef=iago00001?n0`_d00ol0003oQ<Gm
ohC5o@04ohC5o@03o`000?n7aogoQlOm00;oQlOm1_l00004ohC;oP03o`000?n8b_goR<[m00GoR<[m
00Co0000oh_9o?n;bOcoRlWl1ol00005ohS:o@04o`000?n=bOcoSLWlohg9o0Oo00001?n;b?`00ol0
003oSlOjoho7nP05oho7nP04o`000?nCa_WoTlKioi?6n@Oo00001?nCaOP00ol0003oU/CgoiK4m`04
oiK4m`03o`000?nH`oGoV<?e00?o00000_nG`oH01?l0003oVL?doiW3m?l00005oiW3m003o`000?oo
nf[ooo]Z02[ooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z01;ooo]Z000PoookJPKo0000=?oonfX3
o`0000?oZLK_00?o0000ojW7konYanl01?nYanl6o`0000CoZlS_00?o0000oj_9kon[bNl00ol00003
ojc9k`;o00001?n]bnl2o`0000;o[/__00?o0000ok3=kon`cNl01On`cNl3o`0000Oo/m3_0ol00006
okWEkP05o`000?nme^co_MK/okgFk?l000000oo1fn`2o`0000KoamgY1?l00002omCThP03o`000?oK
hmcofn?L00?ofn?L00?o0000on3Qe?oPhM@00_oPhM@00ol0003oi=c=onCLc@02onCLc@03o`000?oU
e/OoiMK700;oiMK700Go0000onG@`_l0003ok/jco`000004on_7/003o`000?oW`Jooil6_00?oil6_
00?o0000on>l[ooS_:l00_oS_:l2o`0000Goh[:U00?o0000omf`ZOoM/:T00ooM/:T00ol0003ogJRO
o`000007omRWY@03o`000?oAWj?odInS00KodInS00?o0000olRHYOo8V:D01Oo8V:D01Ol0003o`XjO
ol:>Woo2SYoo000000?o_Y:Y00?o0000okJ8Y?nfR:@01?nfR:@00ol0003o[GjQojenX@02ojenX@03
o`000?n/QJco000000KoXWbZ00?o0000oiMdZOnGM:T00onGM:T00ol0003oS6fYoha]Z@03oha]Z@03
o`000?n2IjcoPVN/00;oPVN/00?o0000ogUU/?miIK000omiIK000ol0003oLVJfog9V]P02og9V]P06
o`000?m_K;oo0000o`000?mIDJoo00001?mGFkX00ol0003oFFW8oeUYb002oeUYb003o`000?mNNmOo
GW_G00Co00001OmAN=X01Ol0003oGHgWoef=iomMSNOo000000GoJ9oa00?o0000og2]mom`[OL01?m`
[OL00ol0003oMkOjogNgnP04ogNgnP03o`000?ml__coO;kl00?oO;kl00?o0000oh32oOn0`_d01On0
`_d01?l0003oQ<GmohC5oOn4aOd7o`0000GoPL_o00?o0000ohC;o_n4boh00on4boh00ol0003oR<[m
ohS:o@02ohS:o@Ko00001On4boh00ol0003oR<[mohS:o@02ohS:o@Ko00001?n5bOh00ol0003oRlSl
oh_8o005oh_8o003o`000?n?ao[oSlOj00;oSlOj1_l00004oho6nP03o`000?nCaOSoTlGh00GoTlGh
00Co0000oiK4monFa?OoU/Cg1Ol00006oiO3mP04o`000?nI`oCoVL?do`0000?oVL?d0ol0000Woook
JPCo00004ooonfX00ol0003ooo]ZoookJP0BoookJP008?oonfX5o`0003;ooo]Z0ol00007ojW6k`03
o`000?nYanooZLO_00So00001On[b>l3o`0000So[<W_00Co0000ojg;kol0003o00001On^bnl00ol0
003o/<g_ok3=k`02ok3=k`;o00000onbc^h00ol0003o/m3_ok?@k`02ok?@k`;o00000onfdNh01?l0
003o^MG^okWEk_nieNh2o`0000Go_MK/00?o0000ol7Kk?l000001_o7gNT2o`0000Coc=gU0ol00004
om_Sg003o`000?oPhMCoh>7D00;oh>7D00?o0000onCLcOoTg<d00_oTg<d00ol0003oiMK7onGFa`02
onGFa`04o`000?oUd<;oiM32onG@`P;o00001?o[ak000ol0003oil6_onO1[`02onO1[`03o`000?oS
_:oohkb_00Cohkb_00?o0000on:bYOoR/ZD00ooR/ZD00ol0003ogK2Yomf`Z@03omf`Z@03o`000?oM
Z9oo000000Kof:NU0_l00008om6OX`03o`000?o8V:Gob9RU00Gob9RU00Co0000ol:>Woo2SYoo0000
1?nnTZT00ol0003o]XRTokJ8Y004okJ8Y005o`000?n]OZ7o[GjQojenXOl000000_n/QJ`00ol0003o
XWbZoj9lZP04oj9lZP03o`000?nGM:WoUgBY00?oUgBY00?o0000oha]ZOn<KJT01?n<KJT00ol0003o
PVN/oh9W[002oh9W[003o`000?miIK3oNFF`00;oNFF`00?o0000og9V]_mbI[H00ombI[H00ol0003o
Kfboofm/_`03o`0000CoEe^j00?o0000oeUYb?mIJLP00_mIJLP00ol0003oGW_Goeike`02oeike`Go
000000?oDGSJo`000?mMSNL00omMSNL00ol0003oJ9oaofROl@03ofROl@03o`000?m`[OOoL:gg00Co
L:gg00?o0000ogNgn_mg]oX01?mg]oX00ol0003oO;klogbno003ogbno003o`000?n0`_goP<;m00;o
P<;m1_l00005ogk:o`03o`000?n1boooPL_o00;oPL_o3Ol00005ogk<o`04o`000?n4bokoQ<_nohC;
oPOo00001?mobol00ol0003oQLWnohG9oP04ohG9oP03o`000?n;b?coRlSl00;oRlSl1ol00003oh[7
o003o`000?n?a_[oSlKj00GoSlKj00?o0000oi?5n?nCaOP00_nCaOP6o`0000CoTlCg00?o0000oiO3
m_nG`oH01OnG`oH00ol0003oVL?doiW3m003o`0000;oV<;e00?o0000oookJ_oonfX08_oonfX3o`00
01Oooo]Z00?o0000oookJ_oonfX04_oonfX0023ooo]Z1Ol0000_oookJP?o00000onXa^l00ol0003o
ZLK_ojW6k`04ojW6k`?o000000?oZ/O_o`000?l000001OnZanl00ol0003oZlS_o`000002o`0000?o
ZlS_0_l00006ojc9k`?o00001on^bnl01?l0003o/<g_o`000?l00006ok;>kP04o`000?ncd>oo0000
o`0000Ko]]7^00?o0000okWEk_l000001onme^`3o`0000GoamgY00?o0000olcMiOo<gND00oo<gND0
1?l0003od]gQom;MhOoBgN42o`000003om_Sg?l0003oh>7D00Coh>7D00Go0000onCLcOoTg<goi=c=
o`000004onGFa`03o`000?oUd<;oiM3200;oiM3200?o0000onC;__l000000_o[ak000ol0003oil6_
onO1[`03onO1[`03o`000?oS_:oohkb_00Cohkb_00?o0000on:bYOoR/ZD00_oR/ZD00ol0003ogK2Y
omf`Z@05omf`Z@03o`000?oHYjGof:NU00Gof:NU00?o0000om>W[?l000001_oAWj<2o`0000Sob9RU
0_l00005okjBZ@03o`000?nfR:Co]XRT00Go]XRT00?o0000ojenXOl000001?n/QJ`00ol0003oXWbZ
oj9lZP03oj9lZP03o`000?nGM:WoUgBY00CoUgBY00?o0000oha]ZOn<KJT00on<KJT00ol0003oPVN/
oh9W[002oh9W[003o`000?miIK3oNFF`00?oNFF`00?o0000og9V]_mbI[H00_mbI[H00ol0003oKfbo
ofm/_`02ofm/_`?o00000_mGFkX00ol0003oFFW8oeUYb003oeUYb003o`000?mNNmOoGW_G00;oGW_G
00Co0000ofF>i?mUS^CoIHkT1_l000000omMSNOo0000ofROl@04ofROl@03o`000?m`[OOoL:gg00Co
L:gg00Co0000ogNgn_mg]o[oMkOj3Ol00005og_8o`04o`000?mnb_ooO/[oogk:o`Oo00001OmdcOl0
0ol0003oNLgoogW=o`03ogW=o`03o`000?mnc?ooO/co00;oO/co1_l00004ogK<o`03o`000?mobooo
Ol_o00GoOl_o00Co0000ohG9o_n5bOkoQLWn1ol00004oh?8oP03o`000?n:aocoR/Ol00CoR/Ol00?o
0000oho6n_n?a_X00_n?a_X7o`0000?oT<Ci00?o0000oi?4monCa?L01OnCa?L00ol0003oUl?foiO3
mP02oiO3mPKo00001OnH`_D00ol0003ooo]ZoookJP0NoookJP?o00006_oonfX00ol0003ooo]Zoook
JP0BoookJP008?oonfX5o`0002cooo]Z0ol00007ojS6k`03o`000?nYa^ooZLK_00?o000000CoZLO_
o`000?l0003o00001onZanl2o`0000SoZlS_00?o0000ojc9kon/bNl00ol00003ojg:k`03o`000?n^
bnoo[/__00Co[/__0ol00007ok;>kP?o00001onfdNh3o`0000Go_MK/0_l00003ol7HjP;o000000?o
amgYo`000?l000001?o<gND2o`0000God]gQ0ol00004on3Qe005o`000?oTg<goi=c=onCLcOl00000
1?oUe/L00ol0003oiM32onG@`P02onG@`P07o`000?oTbkkoi<^nonC;__l0003ojlN`o`000005onO1
[`03o`000?oS_:oohkb_00?ohkb_00?o0000omni/_l000000ooR/ZD00ol0003ogK2Yomf`Z@05omf`
Z@03o`000?oHYjGof:NU00Cof:NU00Co0000om>W[?oCYjco00001_oAWj<00ol0003oc:6/o`000007
olRHY@;o00001_nnTZT00ol0003o]XRTokJ8Y004okJ8Y0;o00001On/QJ`00ol0003oXWbZoj9lZP03
oj9lZP03o`000?nGM:WoUgBY00CoUgBY00?o0000oha]ZOn<KJT00on<KJT00ol0003oPVN/oh9W[002
oh9W[003o`000?miIK3oNFF`00?oNFF`00?o0000og9V]_mbI[H00_mbI[H00ol0003oKfboofm/_`02
ofm/_`03o`000?m^M/[oKWK:00?o00001OmIJLP00ol0003oGW_Goeike`03oeike`03o`000?mUS^Co
IHkT00;oIHkT00Co0000of^Okom[WnooJio_4_l00004ogK0o@03o`000?miaOkoNLGn00CoNLGn00?o
0000og_8oomkb?l00_mkb?l6o`0000GoL<gn00?o0000ogC=oomdcOl00_mdcOl=o`0000GoKLcn00?o
0000ogK<oomfc?l00omfc?l00ol0003oOl_oogo;o`02ogo;o`Ko00001?mjbOl00ol0003oPlSnoh?8
oP05oh?8oP04o`000?n:aocoR/Oloh[7o0Oo00001?n:aO/00ol0003oT<Cioi34n@04oi34n@03o`00
0?nCa?OoTlCg00;oTlCg1ol00004oiC3mP03o`000?nH`_Go000000CoV<;e00?o0000oookJ_oonfX0
6ooonfX3o`0001gooo]Z00?o0000oookJ_oonfX04_oonfX001oooo]Z1_l0000YoookJP?o00000onX
a^l00ol0003oZ<K_ojS6k`04ojS6k`?o000000CoZLO_o`000?l0003o00000onYanl00ol0003oZ/O_
oj[7k`02oj[7k`;o00000_n[b>l00ol0003oZlS_oj_8k`05oj_8k`?o00001on]b^l00ol0003o[/__
ojk;k`03o`0000?o/<c^00?o0000ok;>k_nbc^h00_nbc^h2o`0000?o]<o^00?o0000okKAk_nfdNh0
0_nfdNh2o`0000?o^M;]0_l000000onme^co0000o`000006ol7HjP?o00001?o<gND00ol0003od]gQ
om;Mh@04om;Mh@04o`000?oFfmcoe]_LomKKg0;o000000?oh>7Do`000?oTg<d00_oTg<d00ol0003o
iMK7onGFa`02onGFa`03o`000?oUd<;oiM3200;oiM3200?o0000onC;__oTbkh00ooTbkh00ol0003o
il6_onO1[`03onO1[`03o`000?oS_:oohkb_00Cohkb_00?o0000omni/_l000000_oR/ZD00ol0003o
gK2Yomf`Z@05omf`Z@;o00001_oHYjD01?l0003odjN/om>W[?l00005om6OX`04o`000?o<XJcoc:6/
o`0000Oob9RU00?o0000okjBZOnnTZT01OnnTZT00ol0003o]XRTokJ8Y004okJ8Y003o`000?n/QJco
[8F/00Co[8F/00?o0000oj9lZ_nRO:X01?nRO:X00ol0003oUgBYoiMdZ@03oiMdZ@03o`000?n<KJWo
S6fY00?oS6fY00?o0000oh9W[?n2Ij`00on2Ij`00ol0003oNFF`ogUU/002ogUU/003o`000?mbI[Ko
LVJf00?oLVJf00?o0000ofm/_om_K;l00_m_K;l00ol0003oKWK:ofifbP02ofifbPGo000000?oFFW8
o`000?mNNmL01?mNNmL00ol0003oIHkTofF>i002ofF>i003o`000?m[WnooJio_00?oJio_00?o0000
og2]mom`[OL00om`[OL00ol0003oM;SkogBhn`05ogBhn`03o`000?mf`?goM/3m00?oM/3m00Co0000
ogW5o_miaOkoNLGn1ol00005ofg<oP04o`000?m`cOkoL<gnog3=oPOo00001OmGbOD00ol0003oH/_j
of;;nP03of;;nP03o`000?m]c?koKLcn00;oKLcn3Ol00004ofk9o`03o`000?mjbOooN/Wo00CoN/Wo
00?o0000oh?8o_n3b?h00_n3b?h6o`0000CoPlKm00?o0000oh[5non:aO/01On:aO/01?l0003oT<Ci
oi34nOn@a?T7o`0000CoTL?h00?o0000oiC3m_nD`oH01OnD`oH01?l0003oV<;eo`000?nH`_D4o`00
01Sooo]Z1?l0000PoookJP03o`000?oonf[ooo]Z01;ooo]Z000OoookJPKo00009_oonfX3o`0000Oo
Z<K_00Co0000ojS6konXa^ooZ<K_0_l000001?nYa^oo0000o`000?l00007ojW7k`04o`000?nZanoo
0000o`0000GoZlS_00?o0000oj_8kon[b>l00_n[b>l2o`0000;o[<W^00?o0000ojg:kon]b^l01On]
b^l3o`0000Oo/<c^00Co0000ok;>k_l0003o00001_ndcnh01?l0003o]]7^o`000?l00006okWBk@?o
00001_o1f>X01?l0003oaMSXolGHj?o5f>P2o`000003olcMiOl0003od]gQ00Cod]gQ0_l00005omKK
g0Co000000?oi=c=o`000?oUe/L01?oUe/L00ol0003oiM32onG@`P02onG@`P03o`000?oTbkkoi<^n
00?oi<^n0_l00004onO1[`03o`000?oS_:oohkb_00?ohkb_00Oo0000omni/_oO^K;ogkVbo`000?oR
/ZGo000000OogK2Y00?o0000omR_[ol000001?oHYjD01Ol0003odjN/om>W[?oCYjco000000GodInS
00Co0000olbQ[?o<XJco00001oo8V:D00ol0003o_Y:YokjBZ@05okjBZ@03o`000?nfR:Co]XRT00?o
]XRT0_l00006ojb5[003o`000?nRO:[oXWbZ00CoXWbZ00?o0000oiMdZOnGM:T00onGM:T00ol0003o
S6fYoha]Z@03oha]Z@03o`000?n2IjcoPVN/00?oPVN/00?o0000ogUU/?miIK000omiIK000ol0003o
LVJfog9V]P02og9V]P03o`000?m_K;ooKfbo00;oKfbo00?o0000ofifb_m^M/X00_m^M/X00ol0003o
Kh?Gofn3e`02ofn3e`Ko000000?oGW_Go`000?mUS^@01?mUS^@00ol0003oJio_of^Ok`03of^Ok`03
o`000?m`[OOoL:gg00?oL:gg00?o0000ogBhnomd^?/00_md^?/<o`0000GoKL_n00?o0000ofg<o_m]
c?h00_m]c?h6o`0000?oClO`5?l00004od[2l@03o`000?mNao_oG/Ok00;oG/Ok5?l00003ogS7o`03
o`000?n3a_goPlKm00GoPlKm00?o0000oh[5non:aO/00_n:aO/6o`0000CoRlCj00?o0000oi73n?nA
`oP01OnA`oP00ol0003oU<?foiC3mP02oiC3mPKo00001?nF`_D00ol0003ooo]ZoookJP0BoookJP?o
00009?oonfX00ol0003ooo]ZoookJP0BoookJP007ooonfX6o`0002Cooo]Z0_l00003ojS5k`03o`00
0?nXa^ooZ<K_00GoZ<K_00?o0000ojS6kol000000ol00003ojW6k`03o`000?nYanooZLO_00CoZLO_
0ol00007oj_8k`04o`000?n[b>oo0000o`0000Go[<W^00?o0000ojg:kon]b^l00_n]b^l2o`0000?o
[l_^00?o0000ok3<k_n`c>h01?n`c>h3o`0000Oo]<o^0ol00006okWBk@05o`000?nldn_o_=?[okcC
jol000000oo1f>X2o`0000GoaMSX0ol00004om;Mh@03o`000?oFfmcoe]_L00Coe]_L00?o0000om[I
e_oJfMH00_oJfMH2o`0000CoiMK700?o0000onG@`_oUd<800_oUd<800ol0003oi<^nonC;_P03onC;
_P04o`000?oQa[gohLJmo`0000;oil6_00?o0000on>l[ooS_:l00ooS_:l00ol0003ogkVbomni/P02
omni/P03o`000?oR/ZGo000000KogK2Y00Co0000omR_[ooH[joo00001?oHYjD00ol0003odjN/om>W
[002om>W[005o`000?oAWj?odInSom6OXol000000oo<XJ`00ol0003ob9RUolRHY@04olRHY@;o0000
1onnTZT00ol0003o]XRTokJ8Y002okJ8Y003o`000?ndSjoo000000Ko[8F/00?o0000oj9lZ_nRO:X0
1?nRO:X00ol0003oUgBYoiMdZ@03oiMdZ@03o`000?n<KJWoS6fY00CoS6fY00?o0000oh9W[?n2Ij`0
0_n2Ij`00ol0003oNFF`ogUU/003ogUU/003o`000?mbI[KoLVJf00?oLVJf00?o0000ofm/_om_K;l0
0_m_K;l00ol0003oKWK:ofifbP02ofifbP03o`000?m_PmOoKh?G00?oKh?G00Co0000og:Ci?mbTnCo
LY?T6?l00005og;5o`04o`000?m_bOooKlWoofo9oc?o00001Olc]NH00ol0003oDl;hoe?2n003oe?2
n003o`000?mYa_koJLKn00CoJLKn00?o0000ogS7oomhaol00omhaol00ol0003oPlKmoh?6o@02oh?6
o@Oo00000on4a?`00ol0003oRlCjoh_4nP05oh_4nP03o`000?nA`oSoTL?h00;oTL?h1ol00003oi;2
m`03o`000?nF`_Go000000GoU/;e00?o0000oookJ_oonfX03_oonfX3o`0002Sooo]Z00?o0000oook
J_oonfX04OoonfX001oooo]Z1_l0000SoookJP03o`000?nXaNooZ<G_00CoZ<G_00?o0000ojS6konX
a^l01?nXa^l3o`0000OoZLK_00?o0000ojW7konYanl00ol00003oj[7k`03o`000?n[b>ooZlS_00Co
ZlS_0ol00007ojc9kP04o`000?n]b^oo0000o`0000Ko[l_^00?o0000ok3<k_n`c>h00ol00003ok;=
kP03o`000?ndcnko]<o^00;o]<o^0_l00003okK@k@04o`000?nid^go^M;]okWBk@;o00001Onldn/0
0ol0003o`MSZo`000006olGHj004o`000?o:f>Cob]STol[Hi0;o000000?od]gQo`000?oFfm`01OoF
fm`00ol0003of]WFom[IeP03om[IeP06o`000?oLeM7o0000o`000?oUe/Oo00001OoUd<800ol0003o
i<^nonC;_P02onC;_P03o`000?oQa[gohLJm00;ohLJm00?o0000onO1[ol000001OoS_:l00ol0003o
gkVbomni/P03omni/P03o`000?oM/:WogK2Y00CogK2Y00Go0000omR_[ooH[joof:n_o`000004omRW
Y@03o`000?oCYjcodjN/00;odjN/00Co0000om6OXooAWj?o00001Oo<XJ`00ol0003ob9RUolRHY@02
olRHY@04o`000?o3Vjoo`i^_o`0000Ko_Y:Y00Go0000okJ8Y?nfR:Co]XRTo`000003okB?[`03o`00
0?n/QJco[8F/00Co[8F/00?o0000oj9lZ_nRO:X00onRO:X00ol0003oUgBYoiMdZ@04oiMdZ@03o`00
0?n<KJWoS6fY00?oS6fY00?o0000oh9W[?n2Ij`00on2Ij`00ol0003oNFF`ogUU/002ogUU/003o`00
0?mbI[KoLVJf00?oLVJf00?o0000ofm/_om_K;l00_m_K;l00ol0003oKWK:ofifbP03ofifbP03o`00
0?m_PmOoKh?G00?oKh?G00?o0000og:Ci?mbTn@00_mbTn@00ol0003oM:?_ogBSk`04ogBSk`03o`00
0?me/_SoMK;h00?oMK;h00?o0000ogBmoOmd_Od01?md_Od2o`0000?oL/Go1_l00003oeG;l@Wo0000
0_oLWi<00ol0003odIFDom6EU005om6EU003o`000?o5RiOoaH^G00GoaH^G00?o0000oj5^V?nQKYP0
0_nQKYP2o`0000Ko[GRI00?o0000oim]V?nOKIP00_nOKIPPo`0000CoNLCn00?o0000ohC4o?n4a?`0
1?n4a?`00ol0003oRlCjoh_4nP02oh_4nPOo00000on=`_T00ol0003oT/;goi;2m`05oi;2m`03o`00
0?nF`_Go000000;oU/;e1?l0000;oookJPCo0000:ooonfX00ol0003ooo]ZoookJP0AoookJP007ooo
nfX5o`0002;ooo]Z0ol00007ojS5k`03o`000?nXa^ooZ<K_00?o00000onYa^l00ol0003oZLK_ojW6
k`04ojW6k`?o00001onZanl00ol0003oZlS_oj_8k`03o`0000?o[<S^00?o0000ojc9k_n/bNh01?n/
bNh3o`0000Oo[l_^0ol00007ok;=kP04o`000?ndcnko0000o`0000Ko]]3]00?o0000okWBkOl00000
1onldn/3o`0000GoaMSX00?o0000ol[Hi?o:f>@00oo:f>@3o`0000Goe]_L00?o0000om[Ie_oJfMH0
0ooJfMH00ol0003og=GAomcEd@02omcEd@;o00001?oUd<800ol0003oi<^nonC;_P03onC;_P03o`00
0?oQa[gohLJm00?ohLJm00?o0000on>l[ooS_:l00ooS_:l00ol0003ogkVbomni/P04omni/P03o`00
0?oM/:WogK2Y00CogK2Y00?o0000omR_[ooH[jl00_oH[jl01?l0003of:NUomRWYOl00005om>W[004
o`000?oAWj?odInSo`0000Goc:6/00?o0000olRHYOo8V:D00_o8V:D01?l0003o`i^_ol>K[ol00007
okjBZ@03o`000?nfR:Co000000Co]8n_00?o0000ojb5[?n/QJ`01?n/QJ`00ol0003oXWbZoj9lZP03
oj9lZP03o`000?nGM:WoUgBY00CoUgBY00?o0000oha]ZOn<KJT04ol000000ombI[Ko0000ofm/_`04
ofm/_`03o`000?m^M/[oKWK:00;oKWK:00?o0000ofn3eom_PmL01?m_PmL00ol0003oLY?Tog:Ci002
og:Ci003o`000?mdXnooM:?_00CoM:?_00?o0000ogFbn?me/_P00ome/_P00ol0003oM;gmogBmo@02
ogBmo@Ko00000omRc_P9o`000003omVMU_l0003og9nC00Gog9nC00?o0000om6EU?oAUI@01OoAUI@0
0ol0003oaH^GolF;U`05olF;U`03o`000?nQKYSoXFjH00;oXFjH00?o0000okN2Vol000001On]N9T0
0ol0003oWffHoim]V003oim]V003o`000?n@HIOoT66G00?oT66G00?o0000oh1FUol000001_l00000
0olUZn7o0000odjmn005odjmn003o`000?mX`okoJ<?n00?oJ<?n00?o0000ogW4o_mia?h01?mia?h0
1?l0003oQ<ClohC4o?n4a?`7o`0000CoQ/;k00?o0000ohg2nOn=`_T01?n=`_T00ol0003oT/;goi;2
m`04oi;2m`Go00000onD`OH00ol0003ooo]ZoookJP06oookJP?o0000;ooonfX00ol0003ooo]Zoook
JP0AoookJP007ooonfX5o`0001oooo]Z0ol00003ojS5k`03o`000?nXaNooZ<G_00CoZ<G_0ol00007
ojW6k`03o`000?nYa^ooZLK_00?o00000onYa^h00ol0003oZ/O_oj[7k`04oj[7k`?o00001on/b>h0
0ol0003o[<W^ojc9kP03o`0000?o[LW^00?o0000ojo;k_n_bnh00_n_bnh2o`0000;o/<_^00?o0000
ok;=k_nbcNh01OnbcNh3o`0000Oo]]3]0ol00006okcCj`05o`000?o0e>Wo`=CYol3DjOl000000oo5
f>P00ol0003ob]STol[Hi003ol[Hi005o`000?o=en7ocMOQolgGhOl000000ooFfm`00ol0003of]WF
om[IeP03om[IeP03o`000?oLeM7og=GA00?og=GA00?o0000omcAcOl000000_oUd<800ol0003oi<^n
onC;_P03onC;_P03o`000?oQa[gohLJm00CohLJm00?o0000on>l[ooS_:l00ooS_:l00ol0003ogkVb
omni/P03omni/P03o`000?oK]kGo000000CogK2Y00?o0000omR_[ooH[jl00ooH[jl01?l0003of:NU
omRWYOl00005om>W[003o`000?oAWj?o000000Koc:6/00Go0000olRHYOo8V:Gob9RUo`000003ol>K
[`03o`000?nnTZWo_Y:Y00Go_Y:Y0_l00005okB?[`03o`000?n/QJco[8F/00Co[8F/00?o0000oj9l
Z_nRO:X01?nRO:X00ol0003oUgBYoiMdZ@02oiMdZ@Co00000onDOKL00ol0003oSGZjohej^P03ohej
^P03o`000?n7NkkoQg^n00?oQg^n00Co0000oh=naOn3O/GoPgk51_l000000om_K;oo0000ofifbP04
ofifbP03o`000?m_PmOoKh?G00?oKh?G00?o0000og:Ci?mbTn@00ombTn@01?l0003oM:?_ogBSkomd
Xnl=o`0000?oKlgn2Ol000000ooZ[Y7o0000on>YUP02on>YUP03o`000?oIWIKo000000Kog9nC00?o
0000om6EU?oAUI@01OoAUI@00ol0003oaH^GolF;U`05olF;U`05o`000?nQKYSoXFjHoj5^V?l00000
0_ngPY/00ol0003o[GRIojehV@03ojehV@03o`000?nOKISoWffH00?oWffH00?o0000oi1QUon@HIL0
0on@HIL00ol0003oP5JGoh1FU`03oh1FU`03o`000?maCISoLDfH01Wo00001?ml`_d00ol0003oQ/;k
ohK2n`05ohK2n`03o`000?n=`_WoSL;i00CoSL;i00?o0000oi;2monB`_L00ol000001On@`OOo0000
oiC1m_nD`OKo000000CoU<7f00?o0000oookJ_oonfX00_oonfX3o`0003;ooo]Z00?o0000oookJ_oo
nfX04OoonfX001kooo]Z1_l0000LoookJP?o00001onXaNl00ol0003oZ<G_ojS5k`03o`0000?oZ<G_
00?o0000ojW6konYa^l01?nYa^l3o`0000OoZLK^00?o0000oj[7konZanl00ol00002oj_7kP03o`00
0?n/b>ko[<S^00Go[<S^0ol00007ojg9kP04o`000?n_bnko0000o`0000Go/<_^00?o0000ok;=k_nb
cNh00_nbcNh2o`0000?o/lg]00?o0000okK@kOnfd>d00_nfd>d2o`0000?o^M3/00Co0000okcCjonl
dn_o_=?[0_l00005ol3Dj@03o`000?o5f>So000000Gob]ST00?o0000olgGhOo=en400oo=en400ol0
003oe]_Lo`000005om[IeP03o`000?oLeM7og=GA00?og=GA00Oo0000omcAcOoLdLgog=7=o`000?oU
d<;o000000Goi<^n00?o0000on76_OoQa[d00ooQa[d00ol0003og/:mo`000003on>l[`03o`000?oO
^K;ogkVb00CogkVb00?o0000om^g]Ol000001?oM/:T00ol0003of:n_omR_[`03omR_[`03o`000?oH
YjGo000000OodjN/0_l00006olbQ[004o`000?o8V:Gob9RUo`0000Co`i^_00?o0000okjBZOnnTZT0
1OnnTZT00ol0003o]8n_okB?[`04okB?[`03o`000?n/QJco[8F/00Co[8F/00?o0000oj9lZ_nRO:X0
1?nRO:X00ol0003oUgBYo`000002o`000003oib2]_l0003oU7fg00CoU7fg00?o0000ohej^_n=N[X0
0on=N[X00ol0003oQg^nohMk_P04ohMk_P03o`000?n3O/GoPgk500;oPgk500Co0000oh65c_n1QLko
PHG>5ol00004oh2kn@03o`000?miaoooNLOo00CoNLOo1Ol000001_m@c>;o0000o`000?l0003olKF>
o`0000CojZjA00Oo0000on>YU_oSZIKohjVFo`000?oIWIKo000000Gog9nC0_l00007om6EU003o`00
0?o5RiOoaH^G00GoaH^G00Go0000oj5^V?nQKYSoXFjHo`000002okN2V`03o`000?n]N9Wo[GRI00?o
[GRI00?o0000oim]V?nOKIP00onOKIP00ol0003oT66Goi1QU`03oi1QU`03o`000?n0EYOoP5JG00?o
P5JG00?o0000og5=V?maCIP00_maCIP00ol0003oI4JIo`000004o`000003obFXiOl0003oDK_j00Go
DK_j00?o0000ofc1o_m/`Oh01?m/`Oh00ol0003oO<;mogc2o@03ogc2o@03o`000?n6`__oQ/;k00;o
Q/;k3?l00005oi31m`03o`000?nD`OKo000000GoU<7f1?l0000eoookJP03o`000?oonf[ooo]Z017o
oo]Z000NoookJPKo00006OoonfX3o`0000?oYlG_00?o0000ojS5konXaNl01?nXaNl3o`0000OoZ<G_
00?o0000ojW6konYa^l00ol00002ojW6kP03o`000?nYa^koZLK^00GoZLK^0ol00006oj_7kP03o`00
0?n/b>ko[<S^00;o[<S^0_l00002ojc8kP03o`000?n]bNko[LW^00Go[LW^0ol00007ok3;kP04o`00
0?nbcNko0000o`0000Ko/lg]00Co0000okK@kOl0003o00001_nid>`00ol0003o_=?[o`000007ol3D
j@?o00001?o:f>@00ol0003ocMOQolgGh@04olgGh@?o00001?oJfMH00ol0003og=GAomcEd@03omcE
d@03o`000?oLdLgog=7=00?og=7=0_l00004onC;_P03o`000?oQa[gohLJm00?ohLJm00Oo0000omk2
_OoN`[gog/:mo`000?oS_:oo000000KogkVb00Go0000om^g]OoK]kGofkNeo`000002omf`Z@03o`00
0?oH[joof:n_00Gof:n_0_l00007om>W[003o`000?o<XJcoc:6/00Goc:6/00Co0000olRHYOo8V:Go
00001Oo3Vjl00ol0003o_Y:YokjBZ@03okjBZ@;o00001ondSjl00ol0003o[8F/ojb5[003ojb5[003
o`000?nRO:[oXWbZ00?oXWbZ0ol00004oib2]P03o`000?nDOKOoU7fg00CoU7fg00?o0000ohej^_n=
N[X00on=N[X00ol0003oQg^nohMk_P03ohMk_P03o`000?n3O/GoPgk500?oPgk500?o0000oh65c_n1
QLh00_n1QLh00ol0003oPHoHoh6?f003oh6?f003o`000?n2WNCoPYgT00?oPYgT00?o0000oh:/l?n2
[?001?n2[?000ol0003oP;_ioh2kn@04oh2kn@03o`000?miaoooNLOo00?o00000om_f?P4o`0000?o
lKF>00?o0000onZ^TOoZ[Y400_oZ[Y401?l0003ohjVFon>YU_oSZIH2o`0000Kog9nC0_l00006om6E
U0;o00001oo5RiL01Ol0003oXFjHoj5^V?nQKYSo000000;o]h:K00?o0000ojehVOn]N9T00on]N9T0
0ol0003oWffHoim]V003oim]V003o`000?n@HIOoT66G00CoT66G00?o0000oh1FUon0EYL00_n0EYL0
0ol0003oLDfHog5=V002og5=V004o`000?mTAYWoI4JIofA6V@;o000000?oAc6Co`000?l000006?l0
0004oh70o003o`000?n:`OWoR/7i00?oR/7i00?o0000oi31mon@`OL01On@`OL00ol0003oU<7fo`00
0002oiC1mPCo0000=ooonfX00ol0003ooo]ZoookJP0AoookJP007_oonfX6o`0001Kooo]Z0ol00007
ojO5k`03o`000?nXaNooZ<G_00Co000000?oZ<G^o`000?nXaNl01_nXaNl3o`0000KoZLK^00?o0000
ojW6k_nYa^h00_nYa^h2o`0000;oZ/O^00?o0000oj_7k_n[anh01On[anh01?l0003o[<S^o`000?l0
0005ojc8kP03o`000?n]bNko[LW^00;o[LW^0_l00003ojk:kP03o`000?n`bnko/<_^00Co/<_^0ol0
0007ok?=k@?o00001onid>`3o`0000Go`=CY0_l00003ol?Di`;o000000?ob]STo`000?o=en401Oo=
en401?l0003od=KMom3FgOo@e]d2o`000003om[Ie_l0003og=GA00Cog=GA00?o0000omcAcOoLdLd0
1?oLdLd00ol0003og<g;o`000002onC;_P03o`000?oQa[gohLJm00CohLJm00Oo0000omk2_OoN`[go
g/:mo`000?oS_:oo000000KogkVb00Oo0000om^g]OoK]kGofkNeo`000?oM/:Wo000000Sof:n_00?o
0000om>W[?oCYj`01_oCYj`00ol0003oc:6/olbQ[006olbQ[0;o00001_o3Vjl00ol0003o_Y:YokjB
Z@02okjBZ@03o`000?njV;Co000000Oo]8n_00?o0000ojb5[?n/QJ`01?n/QJ`00ol0003oXWbZoj9l
ZP02o`000003ojB8]ol0003oW8:f00GoW8:f00?o0000oiAm]onDOKL00onDOKL00ol0003oSGZjohej
^P03ohej^P03o`000?n7NkkoQg^n00?oQg^n00?o0000oh=naOn3O/D00on3O/D00ol0003oPHG>oh65
cP03oh65cP03o`000?n1SmSoPHoH00?oPHoH00?o0000oh:Mi?n2WN@00on2WN@00ol0003oPZc`oh:/
l004oh:/l004o`000?n0^oWoP;_ioh2kn@Ko00000_m_f?P4o`000003ooC3Vol0003o000000?olKF>
00?o0000onZ^TOoZ[Y400_oZ[Y401?l0003ohjVFon>YU_oSZIH2o`0000Kog9nC00?o0000omFLVOl0
00001OoAUI@00ol0003obi>Jo`000006olF;U`04o`000?nQKYSoXFjHo`0000?o]h:K00?o0000ojeh
VOn]N9T00on]N9T00ol0003oWffHoim]V004oim]V003o`000?n@HIOoT66G00?oT66G00?o0000oh1F
Uon0EYL00_n0EYL00ol0003oLDfHog5=V002og5=V003o`000?mTAYWoI4JI00;oI4JI0_l00003odLa
T`Oo000000?o<Z__o`000?mK^_`00omK^_`00ol0003oL[omog:oo@04og:oo@03o`000?n1`?coPL3l
00GoPL3l00?o0000oh[1nOn:`OT00on:`OT00ol0003oT<7goi31m`02oi31m`Oo00000onB`?H00ol0
003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z017ooo]Z000NoookJPKo00004ooonfX3o`0000?o
YlG_00?o0000ojO5konWaNl01?nWaNl4o`0000GoZ<G^00?o0000ojS5konXaNl00_nXaNl2o`0000;o
ZLK^00?o0000ojW6k_nYa^h01OnYa^h01?l0003oZLK^o`000?l00005oj[7kP03o`000?n[ankoZlO^
00CoZlO^0ol00007ojc8kP04o`000?n]bNko0000o`0000Ko[/[^00?o0000ok3;k_n`bnh00ol00003
ok7<k@03o`000?nccNgo/lg]00;o/lg]0_l00003okK>k003o`000?nid>co^M3/00;o^M3/0_l00003
ok_AjP;o000000?o`=CYo`000?l000001_o3e>L3o`0000GocMOQ00?o0000om3FgOo@e]d00oo@e]d3
o`0000Gog=GA00?o0000omcAcOoLdLd00ooLdLd01ol0003og<g;omc=booLcL_o0000onC;__l00000
1OoQa[d00ol0003og/:momk2_@03omk2_@03o`000?oO^K;ogkVb00CogkVb00?o0000om^g]OoK]kD0
0_oK]kD00ol0003ogK2Yo`000008omR_[`03o`000?oCYjcodjN/00GodjN/00?o0000oljZ]?l00000
1oo<XJ`00ol0003o`i^_ol>K[`05ol>K[`05o`000?nnTZWo_Y:YokjBZOl000000onjV;@00ol0003o
]8n_okB?[`04okB?[`03o`000?n/QJco[8F/00Co[8F/0ol00003ojB8]`03o`000?nLP[KoW8:f00Co
W8:f00?o0000oiAm]onDOKL00onDOKL00ol0003oSGZjohej^P03ohej^P03o`000?n7NkkoQg^n00Co
Qg^n00?o0000oh=naOn3O/D00on3O/D00ol0003oPHG>oh65cP02oh65cP03o`000?n1SmSoPHoH00Co
PHoH00?o0000oh:Mi?n2WN@00on2WN@01?l0003oPZc`oh:/l?n2[?06o`0000GoQMCo1?l000000ooi
cYco0000ooC3V`02ooC3V`05o`000?oa]HkolKF>oo6eS_l000000ooZ[Y400ol0003ohjVFon>YUP03
on>YUP03o`000?oLWi?og9nC00Cog9nC00?o0000omFLVOl000001OoAUI@00ol0003obi>Jo`000006
olF;U`04o`000?nQKYSoXFjHo`0000?o]h:K00?o0000ojehVOn]N9T00on]N9T00ol0003oWffHoim]
V004oim]V003o`000?n@HIOoT66G00?oT66G00?o0000oh1FUon0EYL00_n0EYL00ol0003oLDfHog5=
V003og5=V004o`000?mTAYWoI4JIofA6V@;o00001?m7<I<3o`0000?o3ICM1_l000000omK^_co0000
og:oo@05og:oo@03o`000?n1`?coPL3l00;oPL3l3Ol00004ohfom`;o00001OnB`?H00ol0003ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z017ooo]Z000NoookJPGo00004OoonfX3o`0000OoYlG_00?o
0000ojO5konWaNl01?l000000onXaNko0000ojS5kP06ojS5kP04o`000?nXaNoo0000o`0000GoZLK^
00?o0000ojW6k_nYa^h01?nYa^h3o`0000OoZ/O^00?o0000oj_7k_n[anh00ol00003oj_8kP03o`00
0?n/b>ko[<S^00Co[<S^0ol00007ojk:kP?o00001onac>d01?l0003o/lg]o`000?l00006okK>k004
o`000?nid>co0000o`0000Ko^m7Z0ol00006ol?Di`05o`000?o6e>Coa]CTolKDi?l000000oo=en40
0ol0003od=KMom3Fg@03om3Fg@05o`000?oBdmWod]?Iom;CfOl000000ooLeM400ol0003og=7=omcA
c@03omcAc@03o`000?oLcL_og<g;00?og<g;00?o0000on76_OoQa[d00ooQa[d00ol0003og/:momk2
_@04omk2_@03o`000?oO^K;ogkVb00?ogkVb00?o0000om^g]OoK]kD01?oK]kD00ol0003of:n_omR_
[`06omR_[`03o`000?oC/;Ko000000GodjN/00Co0000oljZ]?o>Z[Co00001oo<XJ`00ol0003o`i^_
ol>K[`05ol>K[`04o`000?nnTZWo_Y:Yo`0000Co^YRd00?o0000okB?[ondSjl01?ndSjl00ol0003o
[8F/ojb5[003ojb5[0;o00001_nTR;L00ol0003oW8:foib2]P03oib2]P03o`000?nDOKOoU7fg00Co
U7fg00?o0000ohej^_n=N[X00on=N[X00ol0003oQg^nohMk_P03ohMk_P03o`000?n3O/GoPgk500?o
Pgk500?o0000oh65c_n1QLh00on1QLh00ol0003oPHoHoh6?f003oh6?f004o`000?n2WNCoPYgToh:M
i0Ko00001On?b?/00ol0003oQMCoohGDo`06o`0000;onLjL00Go0000ooC3Vood`i_om<>Ko`000003
oo6eSP05o`000?oZ[Y7ojZjAonZ^TOl000001OoSZIH00ol0003og9nCombOT`04ombOT`03o`000?oE
W9Wo000000GodIFD00?o0000ol^CV_l000001_o5RiL01?l0003oXFjHoj5^V?l00003okN2V`03o`00
0?n]N9Wo[GRI00?o[GRI00?o0000oim]V?nOKIP01?nOKIP00ol0003oT66Goi1QU`03oi1QU`03o`00
0?n0EYOoP5JG00;oP5JG00?o0000og5=V?maCIP00omaCIP00ol0003oI4JIofA6V@02ofA6V@03o`00
0?m7<I?oAc6C00;oAc6C00?o0000oclaV?l000001Ol000001?l=U=go0000odN`n?m7/?P=o`0000?o
N[gl00?o0000ohJon_n6_oX01?n6_oX00ol0003oSKogohfom`05ohfom`;o00000_nB`?H4o`0003Ko
oo]Z00?o0000oookJ_oonfX04?oonfX001kooo]Z1Ol0000>oookJP?o00000onWa>h00ol0003oYlG_
ojO5k`04ojO5k`Co00001OnXaNh00ol0003oZ<G^ojS5kP04ojS5kP?o00001onYa^h00ol0003oZLK^
ojW6kP03o`0000?oZLK^00?o0000oj[7k_nZanh01?nZanh3o`0000OoZlS^00?o0000ojc8k_n/b>h0
0ol00003ojg9kP03o`000?n^b^ko[/[^00;o[/[^0_l00002ok3:k@03o`000?nac>go/Lc]00Go/Lc]
0ol00007okK>k0?o00001_nkdNX01Ol0003o_]7YokkAjOnndNWo000000?o`mCW0_l00005olKDi003
o`000?o=en7o000000God=KM00?o0000om;CfOoBdmT00ooBdmT00ol0003og=GAo`000005omcAc@03
o`000?oLcL_og<g;00Cog<g;00?o0000on76_OoQa[d00_oQa[d00ol0003og/:momk2_@04omk2_@03
o`000?oK_kko000000CogkVb00?o0000om^g]OoK]kD01?oK]kD00ol0003of:n_omR_[`05omR_[`04
o`000?oC/;Kodk2fo`0000GodjN/00Co0000oljZ]?o>Z[Co00001_o<XJ`2o`0000So`i^_0_l00005
okZH]003o`000?ndSjoo]8n_00Co]8n_00Co0000ojb5[?n/QJco[8F/0_l000000on[T;Wo0000ojB8
]`05ojB8]`03o`000?nLP[KoW8:f00CoW8:f00?o0000oiAm]onDOKL00onDOKL00ol0003oSGZjohej
^P03ohej^P03o`000?n7NkkoQg^n00?oQg^n00?o0000oh=naOn3O/D00on3O/D00ol0003oPHG>oh65
cP03oh65cP04o`000?n1SmSoPHoHoh6?f0Ko00001?nB^?400ol0003oSlSkoho8n`04oho8n`Ko0000
00?on^62o`000?l000000_oicY`01?l0003om<>KooC3Vood`i/2o`000003oo6eS_l0003ojZjA00?o
jZjA00?o0000on>YU_oSZIH00ooSZIH00ol0003og9nCombOT`03ombOT`04o`000?oEW9WoeIbIo`00
00GodIFD00?o0000ol^CV_l000001oo5RiL2o`0000Co]h:K00?o0000ojehVOn]N9T01?n]N9T00ol0
003oWffHoim]V003oim]V003o`000?n@HIOoT66G00?oT66G00?o0000oh1FUon0EYL00on0EYL00ol0
003oLDfHog5=V002og5=V003o`000?mTAYWoI4JI00;oI4JI00?o0000odLaTom7<I<00_m7<I<00ol0
003o?c6HoclaV002o`000003oahNUOl0003o000000Oo000000?oAk3ho`000?mX^_d01?mX^_d00ol0
003oN[glogZmo004ogZmo003o`000?n6_o[oQ[oj00CoQ[oj00?o0000ohfomon=_oL00_n=_oL6o`00
00?oTKkf00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0@oookJP007OoonfX6o`0000_o
oo]Z0ol00007ojO4kP04o`000?nWaNooYlG_ojO5k`?o00000_nWaNh00ol0003oZ<G^ojS5kP04ojS5
kP03o`000?nXaNkoZ<G^00?o00000onXaNh2o`0000GoZLK^0ol00007ojW6kP03o`000?nZankoZ/O^
00?o00000on[anh00ol0003oZlS^oj_8kP04oj_8kP?o00001on]bNh01?l0003o[/[^o`000?l00005
ok3:k@03o`000?nac>go/Lc]00;o/Lc]0_l00003ok?<k@03o`000?nfc^co]/k/00;o]/k/0_l00003
okS>j`04o`000?nkdN[o^m7Zok_AjP;o00001OnndNT00ol0003o`mCWo`000007olKDi0?o00001?o@
e]d00ol0003od]?Iom;Cf@04om;Cf@?o00001?oLdLd00ol0003og<g;omc=b`04omc=b`03o`000?oJ
bLWo000000?ohLJm00?o0000omk2_OoN`[d00ooN`[d01Ol0003ofknnom^o__oK_kko000000;ogkVb
00?o0000om^g]OoK]kD01?oK]kD00ol0003oe[Njo`000006omR_[`04o`000?oC/;Kodk2fo`0000Co
djN/00?o0000oljZ]?o>Z[@00_o>Z[@00ol0003oc:6/olbQ[002olbQ[004o`000?o7YKKoajFfo`00
00Oo`i^_00?o0000okZH]?njV;@01?njV;@00ol0003o]8n_okB?[`05okB?[`?o00000on[T;T00ol0
003oY8RgojB8]`04ojB8]`03o`000?nLP[KoW8:f00CoW8:f00?o0000oiAm]onDOKL00onDOKL00ol0
003oSGZjohej^P03ohej^P03o`000?n7NkkoQg^n00CoQg^n00?o0000oh=naOn3O/D03?l00003oi:Y
i@03o`000?nB^?7oT[Sa00GoT[Sa00?o0000oho8non?b?/00ol000000onGi?go0000o`000004o`00
0005oocJX?l0003onLjLooW>W?l000000_od`i/00ol0003ok[ZLonjjW002o`0000CojZjA00?o0000
on>YU_oSZIH00ooSZIH00ol0003og9nCombOT`03ombOT`04o`000?oEW9WoeIbIo`0000CodIFD00Co
0000ol^CV_o;Ti[o00001oo5RiL2o`0000Go]h:K00?o0000ojehVOn]N9T00on]N9T00ol0003oWffH
oim]V003oim]V003o`000?n@HIOoT66G00?oT66G00?o0000oh1FUon0EYL00on0EYL00ol0003oLDfH
og5=V002og5=V003o`000?mTAYWoI4JI00;oI4JI0_l00003odLaT`03o`000?lo<ISo?c6H00;o0000
0_lN7YD6o`0000;o<J?b1ol000000omX^_go0000ogZmo004ogZmo003o`000?n6_o[oQ[oj00;oQ[oj
1ol00003oh^nm`03o`000?nA__Ko000000CoTKkf00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP0@oookJP007OoonfX6o`0000Sooo]Z0ol00003ojO4kP03o`000?nWa>koYlC^00GoYlC^0ol0
0006ojO5kP03o`000?nXaNkoZ<G^00?oZ<G^0ol00008ojS5kP03o`000?nYa^ko000000;o00000onY
a^h2o`0000GoZLK^0ol00007oj_7kP03o`000?n[b>koZlS^00?o00000on/b>h00ol0003o[LW^ojg9
kP04ojg9kP?o00001on`b^d01?l0003o/Lc]o`000?l00006ok?<k@04o`000?nfc^co0000o`0000Ko
^<k[00?o0000ok_Aj_l000001onndNT3o`0000Koa]CT00Co0000olSCh_o8dn;ob=?R0_l000000oo@
e]go0000om;Cf@05om;Cf@04o`000?oCdMKodm7Fom?AeP;o000000?og=7=o`000?oLcL/01OoLcL/0
1ol0003of/W9om[9bOoJbLWo0000on76_Ol000001_oN`[d00ol0003ofknnom^o_P02om^o_P03o`00
0?oO^K;o000000GofkNe00Co0000omJg^_oF]k[o00001OoH[jl00ol0003odk2fom>`]P02om>`]P04
o`000?oCYjcodjN/o`0000GocZZd00Go0000olbQ[?o<XJcoc:6/o`000003olNU]P03o`000?o3Vjoo
`i^_00Go`i^_00?o0000okZH]?njV;@01OnjV;@00ol0003o]8n_okB?[`03okB?[`;o00001_n[T;T0
0ol0003oY8RgojB8]`04ojB8]`03o`000?nLP[KoW8:f00?oW8:f00?o0000oiAm]onDOKL00onDOKL0
0ol0003oSGZjohej^P04ohej^P03o`000?n7NkkoQg^n00Ko00000onBUM<00ol0003oTYgKoi:Mf`03
oi:Mf`03o`000?nBZNGoTZWU00CoTZWU00?o0000oi:hlOnB^?401?nB^?44o`000004oiOToOl0003o
0000oh_^g0Go000000Coo=ZPo`000?oicYco00000ood`i/00ol0003ok[ZLonjjW002o`0000CojZjA
00?o0000on>YU_oSZIH00ooSZIH00ol0003og9nCombOT`03ombOT`04o`000?oEW9WoeIbIo`0000Co
dIFD00Co0000ol^CV_o;Ti[o00001oo5RiL2o`0000Go]h:K00?o0000ojehVOn]N9T00on]N9T00ol0
003oWffHoim]V003oim]V003o`000?n@HIOoT66G00?oT66G00?o0000oh1FUon0EYL00on0EYL00ol0
003oLDfHog5=V002og5=V003o`000?mTAYWoI4JI00;oI4JI0_l00003odLaT`03o`000?lo<ISo?c6H
00;o00000olN7YD00ol0003o00jCo`000005o`000003oc6Sl_l0003oG;?k00?oG;?k3?l00004oh:l
nP03o`000?n;__OoRkkg00CoRkkg0_l00005oi6nmP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX04?oonfX001gooo]Z1_l00006oookJP;o00001onWa>h01?l0003oYlC^ojO4k_nWa>h6o`00
00OoYlG^00?o0000ojS5k_l000000_l00003ojS5kP;o00001_nXaNh2o`0000SoZLK^00?o0000ojW6
k_l000000_l00003oj[6kP03o`000?n[ankoZlO^00CoZlO^0ol00007ojc8kP03o`000?n]bNko[LW^
00?o00000on^bNh00ol0003o/<[]ok3:k@04ok3:k@?o00001oncc>d3o`0000Oo^<k[0ol00006okkA
j@05o`000?o0dNOo`=7Wol3Aiol000000oo6e>@2o`0000Gob=?R0ol00005om;Cf@03o`000?oCdMKo
dm7F00Codm7F0_l00005omc=b`03o`000?oJbLWof/W900?of/W900?o0000omk2_OoN`[d01?oN`[d0
0ol0003ofknnom^o_P04om^o_P03o`000?oK]kGofkNe00CofkNe00Go0000omJg^_oF]k[oe[Njo`00
0003omR_[`03o`000?oC/;Kodk2f00?odk2f00Co0000om>W[?oCYjco00001Oo>Z[@01?l0003oc:6/
olbQ[?l00004olNU]P03o`000?o3Vjoo`i^_00Co`i^_00?o0000ol2R^ol000001_njV;@00ol0003o
]8n_okB?[`02okB?[`03o`000?nbV;co000000KoZi2i00?o0000ojB8]onTR;L01?nTR;L00ol0003o
W8:foib2]P03oib2]P03o`000?nDOKOoU7fg00CoU7fg00?o0000ohej^_n=N[X01_l00003oiB?c003
o`000?nBUM?oTYGC00CoTYGC00?o0000oi:MfonBWM/00onBWM/00ol0003oTZWUoi:Yi@04oi:Yi@03
o`000?nB^?7oT[Sa00?o00000onQe?X8o`000003oo_WZ?l0003o000000;onLjL00Go0000ooC3Vood
`i_om<>Ko`000003onjjW003o`000?oZ[Y7ojZjA00;ojZjA00?o0000on>YU_oSZIH00_oSZIH2o`00
00Gog9nC00Co0000omFLVOoEW9Wo00001?oAUI@01?l0003obi>Jol^CV_l00007olF;U`03o`000?ng
PY_o]h:K00Co]h:K00?o0000ojehVOn]N9T00on]N9T00ol0003oWffHoim]V003oim]V003o`000?n@
HIOoT66G00?oT66G00?o0000oh1FUon0EYL00on0EYL00ol0003oLDfHog5=V002og5=V003o`000?mT
AYWoI4JI00?oI4JI0_l00002odLaT`05o`000?lo<ISo?c6HoclaV?l000000olN7YD2o`000003o`0>
Tol0003o000000;o000000Co7ICZo`000?l0003o00001_mL/o/00ol0003oM;[logBjo003ogBjo003
o`000?n2_?[oP[cj00GoP[cj00Co0000oh^nmon;__OoRkkg2ol0000coookJP03o`000?oonf[ooo]Z
013ooo]Z000MoookJPKo00000ooonfX3o`0000;oYlC^00?o0000ojO4k_nWa>h01OnWa>h6o`0000?o
YlC^00?o0000ojO5k_nWaNh01?nWaNh3o`0000OoZ<G^00?o0000ojS5k_nXaNh00ol00002ojS5kP03
o`000?nYa^koZLK^00GoZLK^0_l00007oj[6kP04o`000?n[ankoZlO^oj_7kP;o00000on[anh00ol0
003o[<S^ojc8kP04ojc8kP?o00001on^bNh00ol0003o/<[]ok3:k@03o`0000?o/L_]00?o0000ok?<
kOncc>d00_ncc>d2o`0000?o]<c/00?o0000okS>jonhc^/00_nhc^/2o`0000?o^LoZ00Co0000okkA
jOnndNWo_]7Y0_l00005ol3Ai`03o`000?o6e>Co000000Kob=?R00Go0000ol[Agoo:dMoob]7Oo`00
0003om;Cf@03o`000?oCdMKodm7F00Codm7F00Co0000om?>e?oCc]Co00000ooLcL/00ol0003of/W9
om[9b@04om[9b@;o00001?oN`[d00ol0003ofknnom^o_P05om^o_P03o`000?oK]kGofkNe00?ofkNe
00?o0000omJg^_oF]kX00ooF]kX01?l0003of:n_omR_[ol00005om>`]P03o`000?oCYjco000000Oo
cZZd0_l00006olNU]P03o`000?o3Vjoo`i^_00;o`i^_00Co0000ol2R^oo0X[_o00001_njV;@01Ol0
003o]8n_okB?[ondSjoo000000;o/YRl00?o0000oj^@^On[T;T01?n[T;T00ol0003oY8RgojB8]`04
ojB8]`03o`000?nLP[KoW8:f00CoW8:f00?o0000oiAm]onDOKL01_l00003oiN=b003o`000?nDSlco
U8o<00CoU8o<00?o0000oi:EdonBUM<00onBUM<00ol0003oTYgKoi:Mf`04oi:Mf`04o`000?nBZNGo
TZWUoi:Yi@Go00001?nQe?X2o`0000;o[Nog1?l000001Oo/jHKo0000o`000?olfZ3o000000;onLjL
00Go0000ooC3Vood`i_om<>Ko`000003onjjW005o`000?oZ[Y7ojZjAonZ^TOl000001OoSZIH00ol0
003og:FKo`000004ombOT`05o`000?oEW9WoeIbIomFLVOl000000ooAUI@01Ol0003obi>Jol^CV_o;
Ti[o000000KoaH^G00?o0000okN2VongPY/01?ngPY/00ol0003o[GRIojehV@03ojehV@03o`000?nO
KISoWffH00?oWffH00?o0000oi1QUon@HIL01?n@HIL00ol0003oP5JGoh1FU`02oh1FU`03o`000?ma
CISoLDfH00;oLDfH00?o0000ofA6VOmTAYT00omTAYT00ol0003oFdBMo`000002odLaT`03o`000?lo
<ISo?c6H00;o00000olN7YD00ol0003o00jCo`000006o`000003oafDj_l0003o000000[o000000?o
M;[lo`000?n2_?X00on2_?X6o`0000?oR;cg00?o0000ohnmmOl000001?n?_OD00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z013ooo]Z000MoookJPGo000000Cooo]Zo`000?l0003o00001_nW
a>h00ol0003oYlC^ojO4kP02ojO4kPGo00001onWa>h00ol0003oYlG^ojO5kP03o`0000?oZ<G^00?o
0000ojS5k_nXaNh01?nXaNh3o`0000KoZ<G^00?o0000ojW6k_nYa^h00_nYa^h2o`0000;oZLK^00?o
0000oj[6k_nZa^h01OnZa^h00ol0003oZlO^o`000006oj_7kP04o`000?n/b>ko[<S^ojc8kP;o0000
0on]b>h00ol0003o[/W^ojk9kP04ojk9kP?o00001onabnd01?l0003o/lc]o`000?l00006okC<k004
o`000?nhc^_o0000o`0000Ko^LoZ00?o0000okkAjOl000001oo0dNL3o`0000Gob=?R00?o0000ol[A
goo:dMl00oo:dMl00ol0003od]?Io`000006om?AeP03o`000?oCc]CodlkD00;odlkD00?o0000omc=
bol000001_oJbLT01?l0003of<O8omS7b?l00003omk2_@03o`000?oK_kkofknn00Cofknn00?o0000
omNn`Ol000000ooK]kD00ol0003oe[NjomJg^P04omJg^P03o`000?oH[joo000000Oodk2f00?o0000
oljZ]?o>Z[@01_o>Z[@00ol0003oajFfolNU]P05olNU]P05o`000?o3Vjoo`i^_ol>K[ol000000oo0
X[/00ol0003o^YRdokZH]004okZH]004o`000?ndSjoo]8n_o`0000Co/YRl00?o0000oj^@^On[T;T0
1?n[T;T00ol0003oY8RgojB8]`03ojB8]`03o`000?nLP[KoW8:f00?oW8:f1?l00003oi^>a@03o`00
0?nGSLSoUhg800CoUhg800?o0000oiB?c?nDSl`00onDSl`00ol0003oTYGCoi:Ed`04oi:Ed`03o`00
0?nBWM_oTYgK00?oTYgK1?l00005oj?3l004o`000?nQe?[o0000o`0000;o[Nog0ol000002?o<omSo
0000o`000?l0003onnNXo`000?olfZ3o00000_oicY`01?l0003om<>KooC3Vol00004onjjW0;o0000
0_oZ[Y400ol0003ohjVFon>YUP03on>YUP03o`000?oLYI_o000000?og9nC00?o0000omFLVOoEW9T0
0_oEW9T01?l0003odIFDom6EU?l00004ol^CVP03o`000?o5RiOoaH^G00CoaH^G00?o0000okN2Vong
PY/01?ngPY/00ol0003o[GRIojehV@03ojehV@03o`000?nOKISoWffH00CoWffH00?o0000oi1QUon@
HIL00on@HIL00ol0003oP5JGoh1FU`02oh1FU`03o`000?maCISoLDfH00;oLDfH00?o0000ofA6VOmT
AYT00omTAYT00ol0003oFdBMo`000002odLaT`05o`000?lo<ISo?c6HoclaV?l000000olN7YD01Ol0
003o00jCo`0>Tol0003o00VH00So00001OmA[?T01?l0003oK[Gkofjenom^]O/6o`0000?oO[Wi00?o
0000ohRlmon8_?L01?n8_?L00ol0003oSkgeo`000004ohnmm@03o`000?oonf[ooo]Z033ooo]Z00?o
0000oookJ_oonfX04?oonfX001gooo]Z1_l00003ojO4kP03o`000?nWa>koYlC^00CoYlC^1_l00003
ojO4kP03o`000?nWa>koYlC^00CoYlC^0ol00007ojS5kP03o`000?nXaNkoZ<G^00?o00000_nXaNh0
0ol0003oZ<G^ojS5kP05ojS5kP04o`000?nYa^ko0000o`0000GoZLK^00?o0000oj[6k_nZa^h01?nZ
a^h3o`0000OoZlO^00?o0000ojc8k_l000001_n]b>h01?l0003o[/W^ojk9k_n^bNh2o`0000?o[lW]
0_l00005ok7;k@?o00001ondc>`3o`0000Oo^LoZ0ol00006ol3Ai`05o`000?o2d>Go`]3Uol;@iOl0
00000oo8dn800ol0003ob]7Ool[Ag`04ol[Ag`?o00001OoCdMH00ol0003odlkDom?>e004om?>e003
o`000?oJbLWof/W900Cof/W900?o0000omS7b?oHalP00_oHalP00ol0003og/:mo`000006om^o_P05
o`000?oG_/7oekk1omNn`Ol000000_oK]kD00ol0003oe[NjomJg^P05omJg^P03o`000?oC/;Kodk2f
00Kodk2f00?o0000oljZ]?o>Z[@01_o>Z[@00ol0003oajFfolNU]P05olNU]P04o`000?o3Vjoo`i^_
o`0000Go`::k00?o0000okZH]?njV;@01?njV;@2o`0000Go/YRl00?o0000oj^@^On[T;T01?n[T;T0
0ol0003oY8RgojB8]`04ojB8]`03o`000?nLP[Ko000000;o000000?oX974o`000?nKS/D01OnKS/D0
0ol0003oUhg8oiN=b003oiN=b003o`000?nDSlcoU8o<00CoU8o<00?o0000oi:EdonBUM<00onBUM<0
0ol0003oTYgKoi:Mf`03o`000003oj6ei_l0003oXl?`00KoXl?`1?l000001On]koOo0000o`000?l0
003oc?oH00Co000000?onnNXo`000?l000000_oicY`01Ol0003om<>KooC3Vood`i_o000000?ok[ZL
00?o0000onNdW_l000000_oZ[Y400ol0003ohjVFon>YUP03on>YUP03o`000?oLYI_o000000?og9nC
00?o0000omFLVOoEW9T00_oEW9T01?l0003odIFDom6EU?l00004ol^CVP03o`000?o5RiOoaH^G00?o
aH^G0_l00006okN2V`03o`000?n]N9Wo[GRI00?o[GRI00?o0000oim]V?nOKIP01?nOKIP00ol0003o
T66Goi1QU`03oi1QU`03o`000?n0EYOoP5JG00;oP5JG00?o0000og5=V?maCIP00omaCIP00ol0003o
I4JIofA6V@02ofA6V@06o`000?mKA9goFdBMo`000?m7<I?o00000olo<IP01?l0003o7QjEoahNUOlN
7YD2o`000005o`0>Tol0003o0000o`000?l008d01?l000000ol?Q^Co0000o`000004o`000003oe6/
nOl0003oK[Gk00?oK[Gk00?o0000ogjinOmn^OT01Omn^OT00ol0003oR;cgohRlm`04ohRlm`;o0000
0_n?_OD4o`0003;ooo]Z00?o0000oookJ_oonfX03ooonfX001gooo]Z0ol00007ojO4kP04o`000?nW
a>koYlC^ojO4kPGo00001onWa>h00ol0003oYlC^ojO4kP03o`0000;oYlG^00?o0000ojS5k_nXaNh0
1OnXaNh3o`0000KoZ<G^00?o0000ojS5k_nXaNh01?nXaNh3o`0000OoZLK^00?o0000oj[6k_nZa^h0
0ol00003oj_7kP03o`000?n[ankoZlO^00CoZlO^0ol00007ojg8kP03o`000?n^bNko000000Oo[lW]
00?o0000ok7;kOl000000_l00003ok;;k003o`000?ndc>co]<c/00;o]<c/0_l00003okK=j`03o`00
0?nicn[o^LoZ00;o^LoZ0_l00003ok_?j@04o`000?o0dNOo`=7Wol3Ai`;o00001Oo2d>D00ol0003o
b=?Ro`000006ol[Ag`05o`000?o;d=gobm3Mol_@gOl000000ooCdMH00ol0003odlkDom?>e004om?>
e0;o00001OoJbLT00ol0003of<O8omS7b004omS7b003o`000?oK_kkofknn00Cofknn00?o0000omNn
`OoG_/400_oG_/400ol0003ofkNeo`000008omJg^P03o`000?oC/;Kodk2f00Godk2f00?o0000olnc
__l000001_o>Z[@00ol0003obZnoo`000007olNU]P;o00001_o0X[/00ol0003o^YRdokZH]003okZH
]0;o00001_nbV;`00ol0003oZi2ioj^@^@04oj^@^@03o`000?nTR;OoY8Rg00?oY8Rg0ol00005oj2A
a003o`000?nKS/GoVhk500?oVhk500?o0000oiN=b?nGSLP01?nGSLP00ol0003oU8o<oiB?c003oiB?
c004o`000?nBUM?oTYGCoi:Ed`Go00001OnQ]NH00ol0003oXl?`oj?3l002oj?3l0;o00000oncgOH4
o`000003olcof?l0003o000000;o000000ConnNXo`000?olfZ3o00000_oicY`01Ol0003om<>KooC3
Vood`i_o000000?ok[ZL00?o0000onNdW_l000000_oZ[Y400ol0003ohjVFon>YUP03on>YUP03o`00
0?oLYI_o000000?og9nC00?o0000omFLVOoEW9T00_oEW9T01?l0003odIFDom6EU?l00004ol^CVP03
o`000?o5RiOoaH^G00?oaH^G0_l00006okN2V`03o`000?n]N9Wo[GRI00?o[GRI00?o0000oim]V?nO
KIP01?nOKIP00ol0003oT66Goi1QU`05o`0000CoP5JG00?o0000og5=V?maCIP00_maCIP00ol0003o
I4JIofA6V@02ofA6V@06o`000?mKA9goFdBMo`000?m7<I?o00000olo<IP2o`0000?o7QjE00Oo0000
o`0>Tol03Y?o0000o`09V?l0003o002=00;o000000?o27_Qo`000?l000000_l00003odVTm`Ko0000
00?oK[Gko`000?mn^OT00omn^OT=o`0000CoS[ce00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Z
oookJP0?oookJP007?oonfX5o`0000OoYlC^1Ol00003ojO4kP;o00001OnWa>h3o`0000KoYlG^00?o
0000ojS5k_nXaNh00_nXaNh2o`0000;oZ<G^00?o0000ojS5k_nXaNh01OnXaNh00ol0003oZ<G^ojS5
kP03o`0000?oZLK^00?o0000ojW6k_nYa^h01?nYa^h3o`0000OoZlO^00?o0000oj_7k_n[anh00ol0
0003ojc7kP03o`000?n]b>ko[LS^00Co[LS^0ol00007ojo9k@;o00001onbbn`01?l0003o]<c/o`00
0?l00006okK=j`04o`000?nicn[o0000o`0000Ko^loY00?o0000ol3Aiol000001oo2d>D3o`0000Go
b]7O00?o0000ol_@gOo;d=d00oo;d=d00ol0003odm7Fo`000006om?>e004o`000?oCc=?odlcCo`00
00?of/W900?o0000omS7b?oHalP01?oHalP00ol0003oeLG:o`000005om^o_P03o`000?oG_/7oekk1
00?oekk100?o0000omJg^_oF]kX01_oF]kX00ol0003od[W1o`000005om>`]P04o`000?o?/kkock>n
o`0000GocZZd00Co0000olZ__oo:[koo00001oo7YKH00ol0003o`::kol2R^`06ol2R^`07o`000?nj
V;Co^YRdokZH]?l0003o]j72o`000007ok:H_003o`000?n[T;WoZi2i00CoZi2i00?o0000ojB8]ol0
00000_l000000onVULCo0000oj2Aa005oj2Aa003o`000?nKS/GoVhk500CoVhk500?o0000oiN=b?nG
SLP00onGSLP00ol0003oU8o<oiB?c003oiB?c0Co00000onOZ]h00ol0003oXKGVoj6eiP05oj6eiP04
o`000?nS`o3o0000o`0000Co/mgf00Go0000ol7dl?o1m?3o0000olcof005o`000004oo_WZ?l0003o
o=ZPo`0000;onLjL00Go0000ooC3Vood`i_om<>Ko`000003onjjW006o`000?oW]9koikBNo`000?oZ
[Y7o00001?oSZIH01?l0003og:FKombUVol00003ombOT`03o`000?oEW9WoeIbI00;oeIbI00Co0000
om6EU?oAUICo00001?o;TiX00ol0003oaH^GolF;U`03olF;U`03o`000?noRYko000000Go]h:K00?o
0000ojehVOn]N9T00on]N9T00ol0003oWffHoim]V003oim]V0Co00000onCJIl01?l0003oQf6Oo`00
0?l00002oh1FU`03o`000?maCISoLDfH00;oLDfH00?o0000ofA6VOmTAYT00_mTAYT01?l0003oFdBM
oe]4WOmKA9d2o`0000Co?c6H00Co0000oahNUOlN7YGo7QjE0_l000000ol03Y?o0000o`09V002o`00
0003o`00SOl0003o000000?o27_Q0_l00004odVTm`04o`000?mY/?[oJK3jofV`nPKo00000omk]_P0
0ol0003oQk[gohNjm`04ohNjm`03o`000?n>_?Go000000GoS[ce00?o0000oookJ_oonfX0;_oonfX0
0ol0003ooo]ZoookJP0?oookJP007?oonfX6o`0000?oYlC^1_l00007ojO4kP03o`000?nWa>ko0000
00;o00000onWa>h00ol0003oYlG^ojO5kP04ojO5kP04o`000?nXaNko0000o`0000GoZ<G^00?o0000
ojS5k_nXaNh01?nXaNh3o`0000OoZLK^00?o0000ojW6k_nYa^h00ol00003oj[6kP03o`000?n[anko
ZlO^00CoZlO^0ol00007ojc7kP03o`000?n]b>ko[LS^00?o00000on^b>d00ol0003o[lW]ojo9k@02
ojo9k@;o00000_n`b^d00ol0003o//_/ok;;k004ok;;k0?o00001onfcN/3o`0000Oo^loY0ol00006
ol;@i@05o`000?o4cn?oa<oSolC?hol000000oo:dMl00ol0003obm3Mol_@g@04ol_@g@?o00001OoC
c]@00ol0003odlcCom?<d`02om?<d`03o`000?oJbLWo000000Kof<O800Go0000omG5b_oEaL[oeLG:
o`000003om^o_P03o`000?oG_/7oekk100Coekk100?o0000omJg^_oF]kX01OoF]kX01?l0003od[W1
om:i`Ol00004om>`]P03o`000?o?/kkock>n00;ock>n00Go0000oljZ]?o>Z[CocZZdo`000004olZ_
_`03o`000?o7YKKoajFf00?oajFf0_l00008ol2R^`04o`000?njV;Co^YRdo`0000?o]j7200?o0000
ok:H_?nbV;`01?nbV;`00ol0003oZi2ioj^@^@03oj^@^@?o00001OnVUL@00ol0003oX974oj2Aa003
oj2Aa003o`000?nKS/GoVhk500CoVhk500?o0000oiN=b?nGSLP00onGSLP00ol0003oU8o<oiB?c003
o`000003oinSf?l0003oWj[N00GoWj[N00?o0000oj6ei_nQ]NH01?nQ]NH3o`0000?o/mgf0_l00002
ol7dl004o`000?o<omSo0000om?l]P?o000000GonnNXo`000?olfZ3oo=ZPo`000002ooW>W004o`00
0?od`i_om<>Ko`0000Cok[ZL00Ko0000onNdW_oW]9ko0000onZ^TOl00004on>YUP05o`000?oLYI_o
g:FKombUVol000000_oLWi<00ol0003oeIbIomFLV@02omFLV@03o`000?oAUICo000000Gobi>J00?o
0000olF;Uoo5RiL00_o5RiL01?l0003o_hZNokn:W_l00006okN2V`03o`000?n]N9Wo[GRI00?o[GRI
00Oo0000oim]V?nOKISoWffHo`000?nOLYoo000000GoTfVO00Co0000ohMQWon7HIooQf6O0ol00004
og5=V003o`000?mTAYWoI4JI00?oI4JI00Co0000oe]4WOmKA9goFdBM0_l00003oclaV0;o00000_lN
7YD01_l0003o8RfSo`000?l03Y?o0000o`09V0;o000000Co002=o`000?l0003o00000ol8Nn44o`00
0003odVTmol0003oJK3j00CoJK3j00?o0000og^fn?mk]_P01?mk]_P00ol0003oQk[gohNjm`04ohNj
m`;o00000on>_?D4o`0002oooo]Z00?o0000oookJ_oonfX03ooonfX000kooo]Z1Ol007l9oookJPco
00000onWa>h00ol0003oYlC^ojO4kP04ojO4kP;o00001onWa>h00ol0003oYlG^ojO5kP03ojO5kP?o
00001onXaNh00ol0003oZ<G^ojS5kP03o`0000?oZ<G^00?o0000ojW6k_nYa^h01?nYa^h3o`0000Oo
Z/K^00?o0000oj_7k_n[anh00ol00003oj_7kP03o`000?n/anko[<O^00Co[<O^0ol00007ojk8k@04
o`000?n_bNgo0000o`0000Go/<[]00Co0000ok;;k?nbbnco//_/0_l00003ok?;k003o`000?nfcN_o
]/g[00;o]/g[0_l00003okO=jP03o`000?nkcnWo^loY00;o^loY0_l00003okg>i`04o`000?o2d>Go
`]3Uol;@i@;o00001Oo4cn<00ol0003ob]7Oo`000006ol_@g@05o`000?o<c]_oc<kKolc>fol00000
0ooCc]@00ol0003odlcCom?<d`03om?<d`?o00001OoHalP00ol0003oeLG:omG5bP03omG5bP03o`00
0?oK_kko000000Koekk100?o0000om>naOl000001OoF]kX00ol0003od[W1om:i`@02om:i`@04o`00
0?oC/;Kodk2fo`0000Gock>n00Co0000oljZ]?o>Z[Co00001Oo:[kl00ol0003oajFfolNU]P02olNU
]P04o`000?o4[<;oa:c2o`0000Oo`::k00?o0000okZH]?l000001?ngXL800ol0003o/YRlok:H_004
ok:H_004o`000?n[T;WoZi2ioj^@^@;o000000?oZi_7o`000?nVUL@01OnVUL@00ol0003oX974oj2A
a004oj2Aa003o`000?nKS/GoVhk500?oVhk500Co0000oiN=b?nGSLSoUhg81Ol00005oinSf003o`00
0?nOZ]koWj[N00CoWj[N00?o0000oj6ei_nQ]NH00ol00003ok3<kP03o`000?ncgOKo000000?o`OC`
00?o0000olcof?l000000ol000001_odl[Co0000oo_WZ?l0003oo=ZPo`0000?onLjL00Co0000ooC3
Vood`i_o00000oo^^Y`01?l0003oikBNonNdW_oW]9h2o`0000GohjVF00Oo0000ombUVooLYI_og:FK
o`000?oLWi?o000000GoeIbI00?o0000om6EU?l000001_o;TiX01Ol0003oaH^GolF;Uoo5RiOo0000
00;o_hZN00?o0000okN2VongPY/01?ngPY/00ol0003o[GRIojehV@03ojehV@04o`000?nOKISoWffH
o`0000;oWg:O00?o0000oi=YWonCJIl00onCJIl00ol0003oQf6OohMQW`03ohMQW`03o`000?maCISo
LDfH00;oLDfH00?o0000ofA6VOmTAYT00omTAYT01?l0003oFdBMoe]4WOmKA9d2o`0000?o?c6H00So
0000oc`hX_l0003o7QjEo`000?lR;J?o0000o`0>T`?o000000Co01ZXo`000?l0003o04;41Ol00003
odFLm0Oo000000?oJK3jo`000?mk]_P01Omk]_P01?l0003oQk[gohNjmon7^_L7o`0000?oSK[d00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0?oookJP003OoonfX7o`00O`Sooo]Z1_l00000
0ooonf[o0000o`000007ojO4kP03o`000?nWa>koYlC^00?o00000_nWa>h00ol0003oYlC^ojO4kP05
ojO4kP03o`000?nWaNko000000;o00000onXaNh2o`0000GoZ<G^0ol00007ojS5kP03o`000?nYa^ko
ZLK^00?o00000_nYa^h00ol0003oZ/K^oj[6kP05oj[6kP?o00001on[anh00ol0003o[<O^ojc7kP03
o`0000?o[LS^00?o0000ojk8kOn^b>d01?n^b>d3o`0000Oo/<[]00?o0000ok;;k?l000001_ncbn`0
1?l0003o]/g[o`000?l00006okO=jP04o`000?nkcnWo0000o`0000Ko_LkW00?o0000ol;@iOl00000
1oo4cn<3o`0000Gobm3M00?o0000olc>foo<c]/00oo<c]/00ol0003odlkDo`000005om?<d`05o`00
0?oAbM;odLWBom79d_l000000ooHalP00ol0003oeLG:omG5bP05omG5bP03o`000?oG_/7oekk100Co
ekk100Go0000om>naOoC_/Godkk5o`000004omJg^P03o`000?oB^L7od[W100;od[W100?o0000om>`
]_l000001_o?/kh00ol0003ocZZdo`000007olZ__`04o`000?o7YKKoajFfo`0000?oa:c200?o0000
ol2R^oo0X[/01Oo0X[/2o`0000Ko]j7200?o0000ok:H_?nbV;`01?nbV;`3o`0000CoZi_700?o0000
ojJEa?nVUL@00onVUL@00ol0003oX974oj2Aa004oj2Aa003o`000?nKS/GoVhk500?oVhk51?l00003
oinOe003o`000?nOXmSoWj?H00GoWj?H00?o0000oinZg_nOZ]h00onOZ]h3o`0000Ko/<c^1?l00000
0oo1m?3o0000o`000002o`000009omgif_l0003o0000ooCb]?l0003onnNXo`000?olfZ3o000000;o
nLjL00Go0000ooC3Vood`i_om<>Ko`000003onjjW003o`000?oW]9koikBN00;oikBN00?o0000on>Y
U_oSZIH00ooSZIH01ol0003og:FKombUVooLYI_o0000ombOTol000001OoEW9T00ol0003odIFDo`00
0006ol^CVP05o`000?o5RiOoaH^GolF;Uol000000_noRYh00ol0003o]h:KokN2V`04okN2V`03o`00
0?n]N9Wo[GRI00?o[GRI00?o0000oim]V?l000000onOLYl00ol0003oTfVOoi=YW`04oi=YW`03o`00
0?n7HIooQf6O00;oQf6O0_l00003og5=V003o`000?mTAYWoI4JI00?oI4JI00?o0000oe]4WOmKA9d0
0_mKA9d01ol0003o?c6HoclaV?lo<ISo0000oc`hX_l000000_lN7YD00ol0003o8RfSo`000002o`00
0003o`09V?l0003o01ZX00;o000000Co04;4o`000?l;M>7o2gCQ0_l00005odFLm004o`000?mV[?So
IZchofJ/n0co00000on5]oH00ol0003oSK[do`000005ohfjm003o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX03ooonfX000gooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo00001?oo
nfX00ol0003oYlC^ojO4kP04ojO4kP?o00001_nWa>h00ol0003oYlC^ojO4kP04ojO4kP?o00001onX
aNh00ol0003oZ<G^o`000002o`0000?oZ<G^0_l00005ojS5kP?o00001_nYa^h00ol0003oZ/K^oj[6
kP02oj[6kP;o00000_nZa^h00ol0003oZlO^oj_7kP05oj_7kP?o00001on]b>h00ol0003o[/S]ojk8
k@03o`0000?o[/W]00?o0000ok3:kOn`b^d01?n`b^d3o`0000Ko/l_/0ol00007okO=jP?o00001onm
c^L3o`0000Koa<oS00Go0000olG?h_o5cn;oaLoRo`000003ol_@g@03o`000?o<c]_oc<kK00Coc<kK
0_l00005om?<d`03o`000?oAbM;odLWB00?odLWB00?o0000omS7b?l000001ooEaLX2o`0000Goekk1
00?o0000om>naOoC_/D00_oC_/D01Ol0003oe[NjomJg^_oF]k[o000000Kod[W100?o0000olnc__o?
/kh01_o?/kh00ol0003obZnoolZ__`06olZ__`03o`000?o7YKKo000000Goa:c200?o0000ol2R^oo0
X[/00oo0X[/00ol0003o_:_8o`000006okNQ`P03o`000?nbV;co/YRl00?o/YRl0_l00006oj^Ka`03
o`000?nVULCoYYG400CoYYG400?o0000oj2Aa?nPTL@00onPTL@00ol0003oVhk5oi^>a@03o`000003
oj6NdOl0003oWioD00GoWioD00?o0000oinSf?nOXmP01?nOXmP00ol0003oWj[NoinZgP03o`0000;o
[;kW00?o0000ok3<k_n`c>h00_n`c>h2o`0000?o_n7`1?l00002omgifP;o000000Com?:do`000?ok
ijSo00000_olfZ001?l0003onLjLooW>W?l00003ooC3V`05o`000?o^^Ycok[ZLonjjW?l000001?oW
]9h00ol0003ohjVFon>YUP02on>YUP03o`000?oLYI_og:FK00;og:FK00?o0000ombOTol000001_oE
W9T2o`0000Kobi>J00Co0000olF;Uoo5RiOo00000onoRYh00ol0003o]h:KokN2V`04okN2V`03o`00
0?n]N9Wo[GRI00?o[GRI0_l00005oimbW`03o`000?nCJIooTfVO00?oTfVO00?o0000ohMQWon7HIl0
0_n7HIl00ol0003oO5^Qo`000002og5=V003o`000?mTAYWoI4JI00?oI4JI00?o0000oe]4WOmKA9d0
0_mKA9d00ol0003o?c6HoclaV002oclaV008o`000?ll>:;o0000oahNUOl0003o8RfSo`000?l03Y<4
o`000004o`0JZ?l0003o04;4o`12a0;o00000_l;M>45o`000003odFLm?l0003oIZch00CoIZch00?o
0000ogVcmomi/oL00omi/oL00ol0003oQKOfohFgmP04ohFgmP03o`000?n=^_Co000000GoSK[d00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0?oookJP003?oonfX3o`00O`?ooo]Z0ol007l7
oookJPGo00001OoonfX00ol0003oYlC^ojO4kP03o`0000;oYlC^00?o0000ojO4k_nWa>h01OnWa>h0
0ol0003oYlC^ojO4kP03o`0000?oYlC^00?o0000ojS5k_nXaNh01?nXaNh2o`0000SoZ<G^00?o0000
ojS5k_l000000_l00003ojW5kP03o`000?nYa^koZLK^00CoZLK^00Co0000oj[6k_l0003o00001OnZ
a^h00ol0003oZlO^oj_7kP02oj_7kP;o00000_n/anh00ol0003o[LS^ojg8kP05ojg8kP?o00001on^
bNd00ol0003o/<[]ok3:k@03o`0000?o/L[/00Co0000ok?;k?ncbnco/l_/0_l00003okC;j`03o`00
0?ngcN[o]lgZ00;o]lgZ0_l00003okW=j@03o`000?nmc^Oo_LkW00;o_LkW0_l00003okk>iP04o`00
0?o4cn?oa<oSolC?h`;o00001Oo5cn800ol0003obm3Mo`000006olc>f`04o`000?o<cM[oc<gJo`00
00?odlcC00?o0000om79d_oAbM801OoAbM800ol0003oeLG:omG5bP05omG5bP04o`000?oBa<cod/C<
o`0000?oekk100?o0000om>naOoC_/D01?oC_/D00ol0003oe[Njo`000007om:i`@03o`000?o?/kko
ck>n00Gock>n0_l00008olZ__`;o00001oo4[<800ol0003o`::kol2R^`02o`0000?o_:_800?o0000
okNQ`_ngXL801?ngXL800ol0003o/YRlok:H_002o`000003ojnSbol0003oZi_700GoZi_700?o0000
ojJEa?nVUL@01?nVUL@00ol0003oX974oj2Aa003oj2Aa0?o00001OnQW]400ol0003oWioDoinOe004
oinOe003o`000?nOXmSoWj?H00?oWj?H0ol00006ojbni`04o`000?n`c>ko0000o`0000Co_n7`00Co
0000oloajOo?lNWo00000_oMnMX01ol0003oj_W6o`000?odl[Co0000oo_WZ?l000000_olfZ001?l0
003onLjLooW>W?l00003ooC3V`05o`000?o^^Ycok[ZLonjjW?l000001?oW]9h00ol0003ohjVFon>Y
UP02on>YUP03o`000?oLYI_og:FK00;og:FK00?o0000ombOTol000001_oEW9T2o`0000Kobi>J00Co
0000olF;Uoo5RiOo00000onoRYh00ol0003o]h:KokN2V`04okN2V`03o`000?n]N9Wo[GRI00?o[GRI
00?o0000oimbWonOLYl01?nOLYl00ol0003oTfVOoi=YW`03oi=YW`03o`000?n7HIooQf6O00;oQf6O
00Co0000ogaKXOmlFj7o00000_maCIP00ol0003oI4JIofA6V@02ofA6V@03o`000?mKA9goFdBM00;o
FdBM0_l00003oclaV005o`000?ll>:;o0000oahNUOl000000_lR;J<2o`000005o`XYZ_l0003o0000
o`000?l06ZP00_l000000ol0@/Co0000o`000003o`0000?oAIOb1ol000000omV[?So0000ogVcm`04
ogVcm`03o`000?n5]oKoQKOf00CoQKOf0_l00003ohfjm0Co0000;?oonfX00ol0003ooo]ZoookJP0?
oookJP003?oonfX3o`00O`?ooo]Z0ol007l7oookJPKo00001OoonfX2o`0000KoYlC^00?o0000ojO4
k_nWa>h01?nWa>h3o`0000OoYlC^00?o0000ojS5k_nXaNh00ol00002ojS5kP03o`000?nXaNkoZ<G^
00GoZ<G^0_l00007ojW5kP03o`000?nYa^koZLK^00?oZLK^0ol00007oj[6kP04o`000?n[anko0000
o`0000Go[<O^00?o0000ojg8k_n]b>h00_n]b>h2o`0000;o[LS]00?o0000ojk9kOn^bNd01On^bNd3
o`0000Oo/L[/00?o0000ok?;k?l000001_ndbn/01?l0003o]lgZo`000?l00006okW=j@04o`000?nm
c^Oo0000o`0000Ko_/kV00?o0000olC?hol000001oo5cn83o`0000Goc<kK00?o0000olc=f_o<cMX0
0_o<cMX00ol0003odlcCo`000007om79dP03o`000?o?b=?o000000GoeLG:00?o0000om;4c?oBa<`0
0_oBa<`00ol0003oekk1o`000008om>na@03o`000?oB^L7od[W100God[W100?o0000olnlbOl00000
1Oo?/kh01?l0003obkW8ol^ib?l00006olZ__`03o`000?o6]l_o000000Ooa:c200?o0000ol2R^ol0
00001OnlZlP00ol0003o]j72okNQ`P04okNQ`P03o`000?nbV;co000000Co[j?;00?o0000oj^Kaon[
VlL01?n[VlL00ol0003oYYG4ojJEa003ojJEa003o`000?nPTLCoX97400?o000000?oXioAo`000?nQ
W]401OnQW]400ol0003oWioDoinOe004oinOe003o`000?nOXmSoWj?H00?o000000?oZKGRo`000?n/
_^L01_n/_^L3o`0000?o_n7`0_l00002oloaj@08o`000?oMnM[ogOWJo`000?oZnLKo0000ooCb]?l0
0002oo_WZ003o`000?olfZ3o000000?onLjL00Co0000ooC3Vood`i_o00000oo^^Y`00ol0003oikBN
onNdWP03onNdWP03o`000?oSZIKohjVF00;ohjVF00?o0000ombUVooLYI/00ooLYI/2o`0000KoeIbI
00?o0000ol^CV_o;TiX01Oo;TiX01?l0003oaH^GolF;Uol00004okn:WP03o`000?ngPY_o]h:K00?o
]h:K00?o0000ojehVOn]N9T00on]N9T00ol0003oWg:OoimbW`04oimbW`03o`000?nCJIooTfVO00?o
TfVO00?o0000ohMQWon7HIl00on7HIl01_l0003oO5^QogaKXOl0003oLDfHo`0000GoI4JI00Oo0000
oe]4WOmKA9goFdBMo`000?mEAZCo000000;o?c6H00?o0000oc`hX_ll>:800_l00003ob8]X`05o`00
0?l::J[o2RVZo`000?l0=;P00_l000001?l9Clco0000o`12a?l00002oaMbh@;o00001Om5Uo801?l0
003oIJOfofFWm_mUYoHCo`0000?oSKWc00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0>
oookJP003?oonfX3o`00O`?ooo]Z0ol007l=oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000ojO4
k_nWa>h01?nWa>h00ol0003oYlC^ojO4kP03o`0000?oYlC^00?o0000ojO4k_nWa>h01?nWa>h3o`00
00KoZ<G^00?o0000ojS5k_nXaNh00_nXaNh2o`0000;oZ<G^00?o0000ojW5k_nYaNh01OnYaNh00ol0
003oZLK^o`000002o`0000?oZ/K^00?o0000oj[6k_nZa^h01?nZa^h3o`0000Oo[<O^00Co0000ojg8
k_l0003o00001On]b>d00ol0003o[/W]ojk9k@02ojk9k@;o00000on_bNd00ol0003o/L[/ok7:k004
ok7:k0?o00001_ndbn/3o`0000Oo^LgY0ol00007okk>iP?o00001_o5cn801Ol0003oaLkQolG>hOo5
c^7o000000?oc<kK00?o0000olc=f_o<cMX00oo<cMX2o`0000OodLWB00Go0000olo8doo?b=?oclSC
o`000003omG5bP03o`000?oBa<cod/C<00Cod/C<00?o0000om>naOoC_/D01_oC_/D2o`0000Kod[W1
00Co0000olnlbOo?_<Wo00001?o?/kh00ol0003obkW8ol^ib002ol^ib003o`000?o:[koobZno00;o
bZno00Go0000olJgboo6]l_oa[O;o`000006olB/`P;o00001onlZlP00ol0003o]j72okNQ`P03okNQ
`P;o00001On_Xl/00ol0003oZi_7oj^Ka`04oj^Ka`03o`000?nVULCoYYG400?oYYG40ol00005oj>O
d@03o`000?nQW]7oXIkA00CoXIkA00?o0000oinOe?nOWm@00onOWm@3o`0000GoZKGR00?o0000ojbn
ion/_^L00_n/_^L2o`0000?o^M7/00?o0000okoQl?l000000oo?lNT01_l0003ogOWJomgif_l0003o
j_W6o`0000;om?:d2Ol00003ooC3V`05o`000?o^^Ycok[ZLonjjW?l000001?oW]9h00ol0003ohJjR
o`000003on>YUP03o`000?oLYI_og:FK00?og:FK00?o0000omFLVOoEW9T01OoEW9T00ol0003obi>J
ol^CVP05ol^CVP03o`000?o5RiOo000000Go_hZN00?o0000okN2VongPY/00ongPY/00ol0003o[GRI
ojehV@02ojehV@;o00001_nOLYl00ol0003oTfVOoi=YW`03oi=YW`03o`000?n7HIooQf6O00?oQf6O
00Co0000ogaKXOmlFj7oO5^Q0_l00005ofA6V@03o`000?mKA9goFdBM00;oFdBM0_l00002oclaV005
o`000?ll>:;o?3RRoc`hX_l000000olR;J<2o`000004o`XYZ_l0003o0000o`0d^0;o000000?o2Do<
o`000?l0@/@00_l00002oaMbh@Go000000?oAIObo`000?mUYoH00omUYoH00ol0003oNK3fogV`mP04
ogV`mP03o`000?n5]OGoQKGe00CoQKGe0_l00005ohfil`03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX03_oonfX000cooo]Z0ol007l3oookJP?o001o3_oonfX2o`0000Gooo]Z00?o0000ojO4
k_nWa>h00onWa>h3o`0000OoYlC^00?o0000ojO4k_nWa>h00ol00002ojO5kP03o`000?nXaNkoZ<G^
00GoZ<G^00Co0000ojS5k_l0003o00001OnXaNh00ol0003oZLG^ojW5kP04ojW5kP?o00001_nZa^h0
0ol0003oZ/K^oj[6kP03o`0000?oZlK^00?o0000ojc7k_n/anh01?n/anh3o`0000Oo[LS]00Co0000
ojk9kOl0003o00001_n_bNd00ol0003o/L[/ok7:k003o`0000?o//[/00Co0000okC;jondbn_o]<_[
0_l00003okG;j`03o`000?nicNWo^LgY00;o^LgY0_l00003ok[<j003o`000?nnc^Ko_/kV00;o_/kV
0_l00003oko=i@04o`000?o5cn;oaLoRolG?hP;o00001Oo5c^400ol0003oc<kKo`000005olc=fP04
o`000?o;bm[obl_Jo`0000GodLWB00?o0000olo8doo?b=<00oo?b=<00ol0003oeLG:o`000006om;4
c0;o00001ooC_/D01?l0003od<7;om31bol00004om:i`@03o`000?o?_<Wockc900;ockc900Co0000
olnc__o?/kko00001Oo;^LP01Ol0003obZnoolZ__oo:[koo000000Coa[O;00?o0000olB/`_o4[<80
0oo4[<800ol0003o_kKAo`000007okb[b004o`000?ngXL;o]j72okNQ`P;o000000?o/jcAo`000?n_
Xl/01On_Xl/00ol0003oZi_7oj^Ka`03oj^Ka`03o`000?nVULCoYYG400?o000000?oYZ;Bo`000?nS
Wm401OnSWm400ol0003oXIkAoj6Nd@04oj6Nd@03o`000?nOWmCoWioD00?o000000?oYk3No`000?nY
]N801_nY]N801?l0003o[;kWo`000?l00005okWAk0Co000000Goco7Yo`000?oMnM[ogOWJo`000002
on[iaPCo000000Gol>C2o`000?oafkSolM^ho`000002oo3@/P05o`000?od`i_om<>KooC3Vol00000
0oo^^Y`00ol0003oikBNonNdWP02onNdWP03o`000?oQ[Z;o000000;ohjVF00?o0000ombUVooLYI/0
1?oLYI/00ol0003oeIbIomFLV@05omFLV@03o`000?o;Ti[obi>J00Gobi>J00?o0000olF;Uol00000
1OnoRYh00ol0003o]h:KokN2V`03okN2V`07o`000?n]N9Wo[GRIojehVOl0003oZW^Po`000006oimb
W`03o`000?nCJIooTfVO00?oTfVO00?o0000ohMQWon7HIl00on7HIl00ol0003oO5^QogaKX@02ogaK
X@;o00001?mTAYT00ol0003oFdBMoe]4W@02oe]4W@03o`000?mEAZCo000000;o?c6H00?o0000oc`h
X_ll>:800_l00003ob8]X`04o`000?l::J[o2RVZo`0000;o03Bh0_l000001?l9Clco0000o`000?lW
Ln43o`0000CoBI;`1_l000000omUYoKo0000ogV`mP05ogV`mP03o`000?n5]OGoQKGe00CoQKGe0_l0
0002ohfil`Co0000:ooonfX00ol0003ooo]ZoookJP0>oookJP003?oonfX3o`00O`?ooo]Z0ol007l@
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000ojO4k_l000000_l00003ojO4kP;o00001OnWa>h3
o`0000KoYlG^00?o0000ojS5k_nXaNh01?nXaNh3o`0000OoZ<G^00?o0000ojW5k_nYaNh00ol00003
ojW6kP03o`000?nZa^koZ/K^00?oZ/K^0ol00007oj_6kP03o`000?n/anko[<O^00?o00000on/anh0
0ol0003o[LS]ojg8k@04ojg8k@?o00001on_bNd3o`0000Oo//[/00?o0000okC;jol000001_nebn/0
1?l0003o^LgYo`000?l00006ok[<j004o`000?nnc^Ko0000o`0000Ko_lgU00?o0000olG?h_l00000
1oo5c^42o`0000Goc<gJ00?o0000ol_;f_o;bmX00_o;bmX01Ol0003odLWBom79d_oAbM;o000000Ko
clSC0_l00006om;4c004o`000?o?aM3oclG@o`0000Godkk500?o0000om31boo@`L/00_o@`L/01?l0
003od[W1om:i`Ol00005olnlb@03o`000?o?/kko000000OobkW800?o0000olZ__ol000001_o6]l/0
0ol0003oa:c2olB/`P02o`0000?o_kKA00?o0000okb[b?nlZlP01?nlZlP01?l0003o]j72o`000?l0
0004ok>/d@03o`000?n_Xl_o[j?;00Co[j?;00?o0000oj^Kaon[VlL00_n[VlL3o`0000GoYZ;B00?o
0000oj>OdOnSWm401?nSWm400ol0003oXIkAoj6Nd@03oj6Nd@?o00001OnW/=h00ol0003oZKGRojVe
hP04ojVehP;o00001_nidN`00ol0003oa^3[olKPj`02olKPj`So000000Coj^_=o`000?o`i<;o0000
0_oafkP01?l0003ol=2boo3@/_o`d;82o`0000;om<>K00Go0000onjjW?o^^Ycok[ZLo`000004onNd
WP03o`000?oQ[Z;o000000;ohjVF00?o0000ombUVooLYI/01?oLYI/00ol0003oeIbIomFLV@05omFL
V@03o`000?o;Ti[obi>J00Kobi>J0_l00005okn:WP03o`000?ngPY_o]h:K00Co]h:K00?o0000ojeh
VOl000000onZNj000ol0003oWg:OoimbW`03oimbW`03o`000?nCJIooTfVO00CoTfVO00?o0000ohMQ
Won7HIl00_n7HIl00ol0003oO5^QogaKX@02ogaKX@03o`000?mbEj?o000000?oI4JI00?o0000oe]4
WOmKA9d00_mKA9d01_l0003oEDJToeE6Y?l0003o?c6Ho`0000?o?3RR00Go0000ob8]XolR;J?o8RfS
o`000003o`XYZP04o`000?l0=;So03Bho`0000;o2Do<0_l00002obMch@;o00001Om9T_001?l0003o
IjCcofNTlomWY?<Co`0000?oSKOc00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0>oook
JP003?oonfX3o`00O`?ooo]Z0ol007lAoookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00007ojO4kP03
o`000?nWa>ko000000;o00000onWa>h00ol0003oYlG^ojO5kP04ojO5kP03o`000?nXaNkoZ<G^00?o
00000onXaNh00ol0003oZ<G^ojS5kP04ojS5kP?o00001onYa^h00ol0003oZ/K^o`000002o`0000?o
Z/K^0_l00005oj_6kP?o00001on/anh00ol0003o[LS]ojg8k@03o`0000?o[/S]00?o0000ojo9kOn_
bNd00_n_bNd2o`0000;o/<W/00?o0000ok;:k?nbb^`01Onbb^`3o`0000Ko]L_[0ol00007ok[<j0?o
00001onocND3o`0000KoaLkQ00Co0000olG=h?o5cN3o00000oo<cMX00ol0003obl_Jol_;fP04ol_;
fP03o`000?oAbM;o000000KoclSC00?o0000olg8eOl000001OoBa<`00ol0003oclG@olo5d002olo5
d005o`000?oC_/Godkk5om>naOl000001Oo@`L/00ol0003od[W1o`000007olnlb@03o`000?o;^LSo
bkW800KobkW80_l00007olJgb`03o`000?o4[<;o000000Go_kKA00?o0000okb[b?nlZlP01?nlZlP2
o`0000Ko/jcA00?o0000ojnSbon_Xl/01?n_Xl/00ol0003oZi_7o`000002o`000003ojVXeOl0003o
YZ;B00KoYZ;B00?o0000oj>OdOnSWm400onSWm400ol0003oXIkAoj6Nd@03o`000003ojJ]g?l0003o
Yk3N00KoYk3N00Co0000ojVeh_nY]N;oZKGR0_l00002ok?5j004o`000?nidNco^M7/okWAk0;o0000
1?o6h>/01Ol0003oe>[UomCZiOoDj^Go000000;oh>kJ00?o0000on[[cOl000000_o`i<801?l0003o
lM^hoo7K^?l00002oo3@/P03o`000?o/ajkok<N^00;o00001?o^^Y`01Ol0003oikBNonNdW_oW]9ko
000000?ohJjR00?o0000on>YU_l000001_oLYI/00ol0003oeIbIomFLV@04omFLV@03o`000?o>VZ3o
000000Oobi>J00?o0000okn:W_noRYh01?noRYh00ol0003o]h:KokN2V`04okN2V`03o`000?n]N9Wo
000000?oZW^P00?o0000oimbWonOLYl01?nOLYl00ol0003oTfVOoi=YW`03oi=YW`03o`000?n7HIoo
Qf6O00;oQf6O00?o0000ogaKXOmlFj400_mlFj401?l0003oLUNSog9GXol00002ofA6V@03o`000?mK
A9goFdBM00;oFdBM00Co0000oeE6Y?mEAZCoEDJT0_l00003oc`hXP04o`000?lR;J?o8RfSob8]X`;o
00000_l::JX2o`0000;o03Bh0_l000000ol9Clco0000obMch@03obMch@?o00000om9T_000ol0003o
IjCcofNTl`02ofNTl`03o`000?mi[OCoNJgd00CoNJgd00?o0000ohFclon5/o<01?n5/o<2o`0000Go
SKOc00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0>oookJP003?oonfX3o`00O`?ooo]Z
0ol007lBoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000ojO4k_nWa>h01?nWa>h2o`0000OoYlC^
00?o0000ojO5k_nWaNh00onWaNh3o`0000OoZ<G^00?o0000ojS5k_nXaNh00ol00003ojW5kP03o`00
0?nYa^koZLK^00CoZLK^0ol00007oj[6kP03o`000?n[a^ko000000;o00000on[anh00ol0003o[<O^
ojc7kP04ojc7kP?o00001on^b>d01?l0003o[lW]o`000?l00005ok39k003o`000?nbb^co//[/00;o
//[/0_l00003ok?:k004o`000?nebn_o]L_[okG;j`;o00000onfbnX00ol0003o^/cXok[<j002ok[<
j0;o00000onjc>P00ol0003o_lgUoko=i@02oko=i@;o00000onocN@01?l0003oaLkQolG>hOo5c^42
o`0000CoaLgP00?o0000olc=f_l000001oo;bmX3o`0000GoclSC00Go0000olg8eOo=b=GocLSEo`00
0003om;4c003o`000?o?aM3oclG@00CoclG@00?o0000om>naOl000001_o@`L/2o`0000Oockc90_l0
0007ol^ib003o`000?o7`]Go000000Ooa[O;0_l00007oknfd@04o`000?nlZlSo_:_8okb[b0;o0000
00?o]kOIo`000?nc[=401_nc[=400ol0003o[j?;ojnSb`03ojnSb`;o00001OnYZ=D00ol0003oYZ;B
ojJRdP04ojJRdP03o`000?nSWm7oXioA00?oXioA0ol00005ojJ]g003o`000?nW/=koYk3N00CoYk3N
00Co0000ojVeh_l0003o00001OncaNP00ol0003o^M7/o`000005olKPj`05o`000?oDj^Goe>[UomCZ
iOl000000_oPk]X01_l0003oj^_=on[[cOl0003ol>C2o`0000;olM^h00Go0000oo3@/_o`d;;ol=2b
o`000003onc7[P05o`000?o^^Ycok[ZLonjjW?l000001?oW]9h01ol0003ohJjRon6^X_oQ[Z;o0000
on>YU_l000001OoLYI/00ol0003oeJ:Qo`000005omFLV@03o`000?o>VZ3o000000Oobi>J00?o0000
okn:W_noRYh01?noRYh00ol0003o]h:KokN2V`04okN2V`;o00001?nZNj000ol0003oWg:OoimbW`04
oimbW`03o`000?nCJIooTfVO00?oTfVO00?o0000ohMQWon7HIl00_n7HIl00ol0003oO5^QogaKX@03
ogaKX@06o`000?mbEj?oLUNSo`000?mTAYWo00001?mKA9d01?l0003oEDJToeE6Y?mEAZ@2o`0000?o
?3RR0_l00003ob8]X`;o00000_l::JX2o`000005o`0d^?l0003o9ecAo`000?l9Cl`00_l00002obMc
h@03o`000?m@T>goD93]00Co00001OmWY?<00ol0003oNJgdogV]m004ogV]m003o`000?n5/o?oQK?c
00CoQK?c0_l00005ohfgl`03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX03_oonfX000go
oo]Z0ol007l01?oonf[o001oo`00Ool007lDoookJP;o00001OoonfX00ol0003oYlC^ojO4kP03o`00
00;oYlC^00?o0000ojO4k_nWa>h01OnWa>h00ol0003oYlG^o`000002o`0000?oZ<G^00?o0000ojS5
k_nXaNh01?nXaNh3o`0000OoZLG^00?o0000ojW6k_nYa^h00ol00003ojW6kP03o`000?nZa^koZ/K^
00CoZ/K^0_l00007oj_7kP03o`000?n/anko[<O^00?o00000on]and00ol0003o[/S]ojk8k@04ojk8
k@?o00001on`bN`01?l0003o//[/o`000?l00006ok?:k003o`000?nebn_o000000Ko]/_Z00Co0000
ok[<j?l0003o00001_njc>P01?l0003o_lgUo`000?l00006oko=i003o`000?o5c^7o000000KoaLgP
0ol00006ol_;fP05o`000?o9bm_obL_KolW;fol000000oo?b=<00ol0003ocLSEolg8e@03olg8e@03
o`000?oBa<co000000OoclG@0_l00006om31b`04o`000?o=a=;ocLCBo`0000Gockc900Co0000ol_3
d_o;`m;o00001Oo;^LP01Ol0003oal;EolO2eOo7`]Go000000Goa[O;00?o0000ol73fol000001ono
]]401?l0003o_:_8o`000?l00004okNgf@03o`000?nc[=7o/jcA00Co/jcA00?o0000ojnSbon_Xl/0
0ol000000on[[m[o0000ojVXe@05ojVXe@03o`000?nVX];oYZ;B00CoYZ;B00?o0000oj>OdOl00000
0_l000000onU[Mco0000ojJ]g006ojJ]g003o`000?nW/=koYk3N00?oYk3N0ol00006ok?5j0?o0000
1?o6h>/01Ol0003oe>[UomCZiOoDj^Go000000;oh>kJ00Co0000on[[cOoZjlgo00000_o`i<801?l0
003olM^hoo7K^?l00002oo3@/P03o`000?o/ajkok<N^00;ok<N^00Go0000onjjW?o^^Ycok[ZLo`00
0004onNdWP07o`000?oQ[Z;ohJjRon6^X_l0003ohjVFo`000005ombUV`03o`000?oEXZ7o000000Go
eIbI00?o0000oljJX?l000001oo;TiX00ol0003o_hZNokn:WP04okn:WP03o`000?ngPY_o]h:K00Co
]h:K00?o0000ojYkX?nZNj000onZNj000ol0003oWg:OoimbW`04oimbW`03o`000?nCJIooTfVO00?o
TfVO00?o0000ohMQWon7HIl00on7HIl00ol0003oO5^QogaKX@02ogaKX@07o`000?mbEj?oLUNSog9G
Xol0003oI4JIo`000003oe]4W@03o`000?mEAZCoEDJT00;oEDJT0_l00003oc`hXP;o00000_lR;J<0
2_l0003o;d:eo`000?l::J[o0000obE:`Ol0003o03Bho`000?lWG=42o`000003ocQghOl0003o0000
00;o00001?m@T>d6o`000003ofNTlol0003oNJgd00CoNJgd00?o0000ohFclon5/o<01?n5/o<2o`00
00?oSKOc1?l0000XoookJP03o`000?oonf[ooo]Z00kooo]Z000=oookJPOo001o5_oonfX00ol0003o
oo]ZoookJP03oookJP;o00001_nWa>h00ol0003oYlC^ojO4kP04ojO4kP?o00001_nXaNh00ol0003o
Z<G^ojS5kP03o`0000?oZ<G^00?o0000ojW5k_nYaNh01?nYaNh3o`0000OoZLK^00?o0000oj[6k_nZ
a^h00ol00002oj[6kP03o`000?n[ankoZlO^00CoZlO^0ol00007ojg7k@03o`000?n^b>go[/S]00?o
00000on^b>d00ol0003o/<W/ok39k004ok39k0?o00001oncb^`2o`0000Oo]/_Z0_l00008ok[<j0?o
00001onocN@3o`0000GoaLgP00Go0000olG<h?o5c>3oaLcPo`000003ol_;fP;o00001Oo9bm/00ol0
003oclSCo`000006olg8e@;o00001oo?aM000ol0003ocLOEo`000005om31b`03o`000?o=a=;ocLCB
00;ocLCB00Go0000olnlbOo?_<Wockc9o`000004ol_3dP05o`000?o;^LSobkW8ol^ib?l000001Oo7
`]D00ol0003oa[O;olJgb`02o`0000?o`L?K00?o0000oknfdOno]]401?no]]42o`0000Ko]kOI00?o
0000ok>/dOnc[=401?nc[=43o`0000GoZjoJ00?o0000ojVXeOnYZ=D00onYZ=D00ol0003oYZ;BojJR
dP04ojJRdP;o00001OnU[M`00ol0003oYZgLojJ]g004ojJ]g003o`000?nW/=koYk3N00?o00000on^
_^D01?l0003o/lGXok?5j?ncaNP2o`0000?o_M;Z0_l000000oo6h>_o0000omCZi@02omCZi@04o`00
0?oPk][oh>kJo`0000;oj^_=00Co0000oo3T`_o`i<;o00000_oafkP01Ol0003ol=2boo3@/_o`d;;o
000000?ok<N^00?o0000onNo[?l000000_o^^Y`00ol0003oikBNonNdWP02onNdWP03o`000?oQ[Z;o
hJjR00;ohJjR00?o0000ombUVooLYI/01?oLYI/00ol0003oeJ:Qo`000004omFLV@04o`000?o>VZ3o
cYZPo`0000Kobi>J0_l00007okn:WP03o`000?ngPY_o]h:K00?o]h:K00?o0000ojYkX?nZNj000onZ
Nj000ol0003oWg:OoimbW`04oimbW`03o`000?nCJIooTfVO00?oTfVO00?o0000ohMQWon7HIl00on7
HIl00ol0003oO5^QogaKX@02ogaKX@03o`000?mbEj?oLUNS00;oLUNS0_l00004oe]4W@03o`000?mE
AZCoEDJT00;oEDJT00Wo0000oc`hX_ll>:;o?3RRo`000?m1AJoo0000ob8]Xol000000_l_@[D01?l0
003o2RVZo`000?lUB/42o`0000?o9ecA00Co0000ocQghOlhMn7o>7OQ0_l00004oe2@k@03o`000?mZ
XO7oJZ7a00;oJZ7a4ol00003ohfflP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX03_oo
nfX000kooo]Z1Ol007lHoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000ojO4k_nWa>h01OnWa>h0
0ol0003oYlC^ojO4kP03o`0000?oYlC^00?o0000ojS5k_nXaNh00onXaNh3o`0000OoZ<G^00?o0000
ojW5k_nYaNh00ol00002ojW5kP03o`000?nYa^koZLK^00GoZLK^0ol00006oj[6kP04o`000?n[anko
ZlO^oj_7kP;o00000_n/anh00ol0003o[LO]ojg7k@05ojg7k@?o00001on^b>d00ol0003o/<W/ok39
k003o`0000?o/LW/00?o0000ok?:k?ncb^`00_ncb^`2o`0000;o/l[[00?o0000okK;j_nfbnX00_nf
bnX2o`0000;o]l_Y00?o0000ok[<j?njc>P01?njc>P01Ol0003o^lcWok_<ionkc>Oo000000Co_lgT
0_l00003oko=i005o`000?o5cN3oaLgPolG=h?l000001Oo5c>000ol0003obl_Jo`000007olW;f`;o
00001_o=b=D01?l0003oblWHol_9f?l00005olo5d005o`000?o=amGocLOEolg7eOl000000oo@`L/0
0ol0003ocLCBolg4dP04olg4dP03o`000?o?_<Wo000000Kobl?B00?o0000ol^ib?l000001_o7`]D0
0ol0003oa[O;o`000006ol73f`04o`000?no]]7o_kKAoknfd@;o000000?o^<CSo`000?ng]mT01_ng
]mT01?l0003o/jcAok>/dOnc[=42o`000003ojfih_l0003oZjoJ00GoZjoJ00?o0000ojVXeOnYZ=D0
1?nYZ=D00ol0003oYZ;BojJRdP03o`000003ojF_g_l0003oYJgL00GoYJgL00?o0000ojJ]g?nV[M`0
0onV[M`3o`0000Oo[[kU00?o0000ok?5j?l000001_nmd^X4o`000003omCZiOl0003oh>kJ00;oh>kJ
00Co0000on[[cOoZjlgo00000_o`i<801?l0003olM^hoo7K^?l00003oo3@/P05o`000?o/ajkok<N^
onc7[_l000000_oW_j`00ol0003ok[ZLo`000003onNdWP03o`000?oQ[Z;ohJjR00?ohJjR00?o0000
ombUVooLYI/00ooLYI/01?l0003oeJ:QomFRXOl00004omFLV@04o`000?o>VZ3ocYZPo`0000Kobi>J
0_l00007okn:WP03o`000?ngPY_o]h:K00;o]h:K0_l00005ojYkX003o`000?nOLYooWg:O00CoWg:O
00?o0000oi=YWonCJIl00onCJIl00ol0003oQf6OohMQW`03ohMQW`03o`000?mlFj7oO5^Q00;oO5^Q
00?o0000og9GXombEj<00ombEj<00ol0003oFdBMoe]4W@02oe]4W@03o`000?mEAZCoEDJT00;oEDJT
00Go0000oc`hX_ll>:;o?3RRo`000002od55[`03o`000?lR;J?o000000;o;d:e0_l00002obE:`@;o
00000olWG=400ol0003o>7OQocQgh@02ocQgh@?o00000_m@T>d00ol0003oJZ7aofZQl@03ofZQl@03
o`000?mkZo;oNj_b00CoNj_b00?o0000ohJbl_n6/_801?n6/_82o`0000GoSKKb00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0=oookJP00;?oonfX00ol0003ooo]ZoookJP03oookJP03o`00
0?nWa>koYlC^00CoYlC^0ol00007ojO4kP03o`000?nXaNko000000;o00000onXaNh2o`0000GoZ<G^
0ol00006ojW5kP03o`000?nYa^koZLK^00;oZLK^0_l00002oj[6kP03o`000?nZa^koZ/K^00GoZ/K^
00?o0000oj_7k_l000001On/anh00ol0003o[LO]ojg7k@02ojg7k@;o00000_n]b>d00ol0003o[/S]
ojk8k@05ojk8k@?o00001onabN`01?l0003o/l[/o`000?l00005ok?:j`04o`000?nfbn[o0000o`00
00Go]l_Y00Co0000ok[<j?njc>So^/cX0_l00005ok_<i`04o`000?nocNCo0000o`0000Ko_lgT00?o
0000olG=h?l000001_o5c>02o`0000OobL_K00?o0000olS;g?l000001Oo=b=D00ol0003oblWHol_9
f002ol_9f005o`000?o?aM3oclG@olo5d?l000001Oo=amD00ol0003od<7;o`000007olg4dP;o0000
1oo;`m82o`0000Ooal;E0_l00007ol73f`04o`000?no]]7o0000o`0000Co^<CS00?o0000okNgfOng
]mT01?ng]mT01?l0003o/jcAo`000?l00004ojfihP03o`000?n[[m[oZjoJ00CoZjoJ00?o0000ojVX
eOnYZ=D00onYZ=D3o`0000GoYJoN00?o0000ojF]g?nU[M`01?nU[M`00ol0003oYZgLo`000002o`00
00;oZ[[U00?o0000ojjniOn^_^D01On^_^D2o`0000Ko_M;Z00Co0000olOLj?o7g>SoamcX1?l00000
1OoPk][o0000on[[cOoZjlgo000000?ol>C200?o0000oo7K^?l000000oo`d;801Ol0003ok<N^onc7
[_o/ajko000000?oikn/0_l00004onNdWP03o`000?oQ[Z;ohJjR00?ohJjR00?o0000ombUVooLYI/0
0ooLYI/01?l0003oeJ:QomFRXOl00004omFLV@05o`000?o>VZ3ocYZPoljJX?l000001Oo;TiX00ol0
003oa9:Ro`000006okn:WP03o`000?ngPY_o]h:K00;o]h:K0_l00006ojYkX003o`000?nOLYooWg:O
00?oWg:O00?o0000oi=YWonCJIl00onCJIl00ol0003oQf6OohMQW`03ohMQW`03o`000?mlFj7oO5^Q
00;oO5^Q00?o0000og9GXombEj<00ombEj<00ol0003oFdBMoe]4W@02oe]4W@03o`000?mEAZCoEDJT
00;oEDJT0_l00002oc`hXP06o`000?m1AJoo@DF_o`000?lR;J?o00000ol_@[D01Ol0003o9D[1obE:
`OlUB/7o000000Co9ecA0_l00002ocQgh@03o`000?mIT>_oFI3[00Co00001OmZXO400ol0003oNj_b
og^[lP04og^[lP03o`000?n6/_;oQ[;b00CoQ[;b0_l00002ohfflPCo00009ooonfX00ol0003ooo]Z
oookJP0=oookJP00;OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?nWa>koYlC^00?o00000onW
a>h00ol0003oYlC^ojO4kP04ojO4kP?o00001onXaNh00ol0003oZ<G^o`000002o`0000?oZ<G^00?o
0000ojW5k_nYaNh01?nYaNh01?l0003oZLK^o`000?l00005oj[6kP03o`000?nZa^koZ/K^00CoZ/K^
0ol00006ojc7kP04o`000?n]ango0000o`0000Go[LS]00?o0000ojk8kOn^b>d00_n^b>d2o`0000?o
[lS]00?o0000ok79k?nabN`01?nabN`3o`0000Ko/l[[0ol00007okO;j@03o`000?njc>So000000Oo
^lcW0_l00008oko=i0;o00001_o5c>001?l0003oa<cQolC<hOl00005olW;f`05o`000?o8bmcob<_L
olS;g?l000000oo=b=D00ol0003oblWHol_9f004ol_9f003o`000?o?aM3o000000KocLOE0ol00006
olg4dP03o`000?o9bmco000000Kobl?B00?o0000olO=gol000001_o7`]D00ol0003o`M3Uo`000007
ol73f`;o00001onha><00ol0003o]kOIokNgf@03okNgf@;o00001on]^N800ol0003oZjoJoj^_fP03
oj^_fP03o`000?nYZ=GoZJSE00?o000000?oYKCSo`000?nU[mh01_nU[mh00ol0003oYJgLojF]g003
ojF]g0;o00001_nZ^^D00ol0003o[[kUojjni@02ojjni@;o00000_nebNX01?l0003o_M;ZokgBj_nm
d^X2o`0000?oamcX00?o0000om7QhooAhN<00_oAhN<3o`000005on[[cOl0003ol>C2oo3T`_l00000
0_oafkP01Ol0003ol=2boo3@/_o`d;;o000000?ok<N^00?o0000onNo[?oW_j`00_oW_j`00ol0003o
ikBNonNdWP02onNdWP03o`000?oQ[Z;ohJjR00?ohJjR00?o0000ombUVooLYI/00ooLYI/01Ol0003o
eJ:QomFRXOoEXZ7o000000;oeIbI00?o0000oljJX?o>VZ000_o>VZ000ol0003obi>Jol^CVP02ol^C
VP04o`000?o4TZ;oa9:Ro`0000Ko_hZN00Go0000okN2VongPY_o]h:Ko`000002ok>4XP03o`000?nZ
Nj3oZW^P00?oZW^P00?o0000oimbWonOLYl00onOLYl00ol0003oTfVOoi=YW`04oi=YW`03o`000?n7
HIooQf6O00;oQf6O00?o0000ogaKXOmlFj400omlFj400ol0003oLUNSog9GX`02og9GX`;o00000omK
A9d00ol0003oEDJToeE6Y003oeE6Y0;o00000_ll>:800ol0003o@DF_od55[`02o`0000Co;d:e0_l0
0002obE:`@;o00000_lWG=400ol0003oBGcPo`000003o`0000CoFI3[6?l00003ohjel@03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX03OoonfX002kooo]Z0_l00004oookJP;o00001onWa>h0
0ol0003oYlC^ojO4kP03o`0000?oZ<G^00?o0000ojS5k_nXaNh01?nXaNh2o`0000OoZ<G^00?o0000
ojW5k_nYaNh00onYaNh3o`0000OoZ/K^00?o0000oj[6k_nZa^h00ol00003oj_6kP03o`000?n/anko
[<O^00?o[<O^0ol00007ojg8k@04o`000?n^b>go0000o`0000Ko[lS]00?o0000ok79k?nabN`00ol0
0003ok79k004o`000?ncb^_o/l[[ok?:j`;o00000ondb^/00ol0003o]l_YokO;j@04okO;j@?o0000
1_nkc>L01?l0003o^lcWok_<iol00006oko=i004o`000?noc>Co_lcTo`0000?oaLcP0_l00004olC<
h@05o`000?o9bm_obL_KolW;fol000001Oo8bm`00ol0003ocLSEo`000007ol_9f0;o00001_o=amD0
1Ol0003obL_KolW;foo9bm_o000000?ocLCB0_l00003olW;g004o`000?o;`m;obl?Bol_3dP;o0000
0oo7cMl01?l0003oal;EolO2eOo7`]D2o`0000?o`M3U00?o0000ol73foo1`m/00_o1`m/2o`0000;o
]m?_00?o0000okS4honha><01?nha><00ol0003o]kOIokNgf@03o`000003ojc6kOl0003o[KWR00Ko
[KWR00Co0000oj^_f_n[[m[oZjoJ1Ol00005ojFdh`03o`000?nU[mkoYJoN00CoYJoN00?o0000ojF]
g?nU[M`00ol000000onV^>Ko0000ojZji@06ojZji@04o`000?n^_^Go0000o`0000Go]LWZ00?o0000
okgBj_l000001?o7g>P00ol0003odN7Som7Qh`02om7Qh`04o`000?oJh]cof^;Lom[Rg0?o000000Co
l>C2o`000?oafkSo00000oo`d;800ol0003ok<N^onc7[P02onc7[P03o`000?oW_jcoikn/00;oikn/
00?o0000onNdW_oW]9h00_oW]9h00ol0003ohJjRon6^XP02on6^XP03o`000?oJZjKo000000?og:FK
00?o0000omFRXOoEXZ400_oEXZ401?l0003oeIbIomFLVOl00004oljJX003o`000?o;Ti[obi>J00;o
bi>J00Co0000olBBX_o4TZ;o00001_noRYh01?l0003o]h:KokN2Vol00003ok>4XP03o`000?nZNj3o
ZW^P00?oZW^P00?o0000oimbWonOLYl01?nOLYl00ol0003oTfVOoi=YW`03oi=YW`03o`000?n7HIoo
Qf6O00?oQf6O00?o0000ogaKXOmlFj400_mlFj400ol0003oLUNSog9GX`02og9GX`03o`000?m[EjSo
000000;oFdBM00?o0000oeE6Y?mEAZ@00omEAZ@01Ol0003oE4j^o`000?ll>:;o000000?o@DF_0_l0
0003obm2]@06o`000?m1G<Oo0000obE:`Ol0003o@FWC0_l000000olWG=7o0000odUlh002odUlh0;o
00001?mIT>/00ol0003oKj3_ofnPk`03ofnPk`03o`000?mmZ_3oOJ[`00CoOJ[`00?o0000ohNalOn7
/O401?n7/O42o`0000GoS[Ga00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0=oookJP00
<?oonfX00ol0003ooo]ZoookJP03oookJP;o00001OnWa>h3o`0000OoZ<G^00?o0000ojS5k_nXaNh0
0ol00002ojS5kP03o`000?nXaNkoZ<G^00GoZ<G^00?o0000ojW5k_l000000_l00003ojW5kP03o`00
0?nZa^koZ/K^00CoZ/K^0ol00007oj_6kP03o`000?n/anko000000;o00000on/and2o`0000Go[LS]
0ol00007ojo8k@?o00001onabN`00ol0003o/l[[o`000006okC:j`03o`000?ngbnWo]l_Y00?o0000
0ongbnT01?l0003o^lcWok_<ionkc>L2o`0000Co^lcW00Co0000oko=i?nocNCo_lgT0_l00004oko<
i003o`000?o5c>3o000000Ooa<cQ00?o0000olW;fol000001_o8bm`3o`0000KoblWH00Co0000olS<
g?o8c=co00000oo=amD2o`0000GobL_K00?o0000olg4d_l000001_o9bm`00ol0003obl?Bo`000006
olO=g`03o`000?o7`]Go000000Ko`M3U00Co0000ol73fol0003o00001Ongdnl00ol0003o^<CSokS4
h`03okS4h`?o00001On/a^d00ol0003o[KWRojfihP04ojfihPCo00000onS^nX00ol0003oYKCSojFd
h`05ojFdh`04o`000?nU[mkoYJoNojF_gPGo00001OnV^>H00ol0003oZ[[UojZji@04ojZji@;o0000
1onebNX3o`0000?oamcX00?o0000om7QhooAhN<00_oAhN<00ol0003of^;Lom[Rg002om[Rg003o`00
0?oPgm?oh=oC00;o000000?olM^ho`000?o`d;800_o`d;801Ol0003ok<N^onc7[_o/ajko000000Co
ikn/00?o0000on:i[Ol000000_oW]9h00ol0003ohJjRon6^XP03on6^XP03o`000?oJZjKo000000?o
g:FK00?o0000omFRXOoEXZ400_oEXZ401?l0003oeIbIomFLVOl00004oljJX003o`000?o;Ti[obi>J
00;obi>J00Co0000olBBX_o4TZ;o00001_noRYh01?l0003o]h:KokN2Vol00003ok>4XP03o`000?nZ
Nj3oZW^P00?oZW^P00?o0000oimbWonOLYl01?nOLYl00ol0003oTfVOoi=YW`03oi=YW`03o`000?n7
HIooQf6O00?oQf6O00?o0000ogaKXOmlFj400_mlFj400ol0003oLUNSog9GX`03og9GX`05o`000?m[
EjSo0000oe]4WOl000001OmEAZ@01Ol0003oE4j^o`000?ll>:;o000000Co@DF_0_l00003obm2]@03
o`000?m1G<Oo000000;o00000_m1JM<00ol0003o9ecAo`000004odUlh0Co000000?oFI3[o`000?m_
X>l01?m_X>l00ol0003oOJ[`ogfZl004ogfZl003o`000?n7/O7oQk7a00CoQk7a0_l00005ohjel@03
o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX03OoonfX0037ooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003oYlC^o`000002o`0000?oYlC^0_l00005ojS5kP?o00001_nXaNh00ol0003oZ<G^
ojS5kP04ojS5kP?o00001_nYaNh00ol0003oZ/K^oj[6kP03o`0000?oZ/K^00?o0000oj_6k_n[a^h0
1?n[a^h3o`0000Oo[<O]00?o0000ojg8kOl000000_l00003ojk8k@03o`000?n_b>go[lS]00;o[lS]
0_l00002ojo9k@03o`000?nabNco/LW/00Go/LW/0ol00006okC:j`?o00001ongbnT00ol0003o^lcW
o`000007ok_<i`03o`000?nocNCo000000Ko_lcT0ol00007olC<h@;o00001_o8bm`01Ol0003oa/cO
olK<goo6c=oo000000?oblWH0_l00004olS<g003o`000?o=amGo000000OobL_K0_l00007olW;g0;o
00001oo7cMl3o`0000Ko`M3U0ol00007okOCk`03o`000?nha>?o000000;o00000onVe_P00ol0003o
[<K]ojc6k@03ojc6k@03o`000?n]^N;o[KWR00?o000000?oWLKdo`000?nS^nX01OnS^nX00ol0003o
YKCSojFdh`04ojFdh`Co00000onR^^T00ol0003oY[SVojJhiP05ojJhiP03o`000?nZ^^GoZ[[U00?o
00000_n]a>/00ol0003o]LWZokG9jP02okG9jP;o00000onld^/00ol0003oamcXo`000004om7Qh`03
o`000?oJh]cof^;L00;of^;L00Oo0000on3OdooPgm?oh=oCo`000?oSf<_o000000?ol=2b00?o0000
onc7[_o/ajh00_o/ajh00ol0003oikn/onNo[002onNo[003o`000?oR^Jgo000000;oikBN00?o0000
on6^X_oQ[Z800ooQ[Z800ol0003ofZ^Vo`000003ombUV`03o`000?oEXZ7oeJ:Q00;oeJ:Q00?o0000
omFLVOl000001_o>VZ001?l0003obi>Jol^CV_l00003olBBXP03o`000?noRYko_hZN00Go_hZN0_l0
0004ok>4XP03o`000?nZNj3oZW^P00?oZW^P00?o0000oimbWonOLYl01?nOLYl00ol0003oTfVOoi=Y
W`03oi=YW`03o`000?n7HIooQf6O00?oQf6O00?o0000ogaKXOmlFj400_mlFj400ol0003oLUNSog9G
X`03og9GX`06o`000?m[EjSoJeNXo`000?mKA9go00001?mEAZ@00ol0003oE4j^oeA>[P02o`0000Co
@DF_00?o0000odYG__l000000_l_@[D01?l0003o@Ec7od5Laom1G<L2o`0000;o@FWC0_l00004odUl
h004o`000?mST^SoHi;Xof>Bj0Oo000000?oKj3_o`000?mmZ_001OmmZ_000ol0003oQk7aohNal@03
ohNal@03o`000?n>]O7o000000;oS[Ga1?l0000ToookJP03o`000?oonf[ooo]Z00gooo]Z000boook
JP03o`000?oonf[ooo]Z00Cooo]Z0_l00007ojO4kP03o`000?nXaNko000000;o00000_nXaNh00ol0
003oZ<G^ojS5kP05ojS5kP03o`000?nXaNkoZ<G^00?o00000onYaNh00ol0003oZLG^ojW5kP03ojW5
kP?o00001onZa^h00ol0003oZlK^oj_6kP03o`0000?oZlO^00?o0000ojc7kOn/and01?n/and3o`00
00Ko[/S]00Co0000ojo8kOl0003o00001On_bNd00ol0003o/LW/ok79k002ok79k0;o00000onbbN`0
1?l0003o]<[[okC:jondb^/2o`0000;o]<_[00?o0000okO;jOngbnT01OngbnT3o`0000Oo^lcW0_l0
0006oko<i005o`000?nocNGo_lgUoko=iOl000001?o4c>42o`0000;o`lgR00Co0000olS;g?o8bmco
b<_L0_l00005olK<g`03o`000?o;bMSo000000Kob<cL0ol00006olW;f`03o`000?o6d^?o000000Ko
bL_L00Co0000olGGioo5enOo00001?o7cMl2o`0000?o_mc^00Co0000ol7@iOo1d>Go`M3U0_l00003
ok7Sn0;o00000ongdnl5o`0000KoY]Kh00Co0000ojc6kOn/a^go[<K]1?l00005oig6m003o`000?nS
^n[oXk_Z00CoXk_Z00?o0000ojFdhonU]><00ol000000onL__3o0000oj:jj@05oj:jj@03o`000?nV
^>KoY[SV00CoY[SV0ol00006ojg4j`04o`000?nebN[o0000o`0000Go_=;[0ol00003om7Qh`03o`00
0?oJh]cof^;L00;of^;L00Go0000on3OdooPgm?oh=oCo`000002on?Hb`;o00000_o`d;801Ol0003o
k<N^onc7[_o/ajko000000Coikn/00Oo0000on:i[OoR^Jgoh[V]o`000?oW]9ko000000CohJjR00Go
0000omZ[Y_oJZjKofZ^Vo`000002ombUV`03o`000?oEXZ7oeJ:Q00;oeJ:Q00?o0000omFLVOl00000
1_o>VZ001?l0003obi>Jol^CV_l00003olBBXP03o`000?noRYko_hZN00Go_hZN0_l00004ok>4XP03
o`000?nZNj3oZW^P00CoZW^P00?o0000oimbWonOLYl00onOLYl00ol0003oTfVOoi=YW`03oi=YW`03
o`000?n7HIooQf6O00?oQf6O00?o0000ogaKXOmlFj400_mlFj400ol0003oLUNSog9GX`03og9GX`04
o`000?m[EjSoJeNXof]GZ0;o00001OmEAZ@00ol0003oE4j^oeA>[P02o`0000Co@DF_00Ko0000odYG
__l0003o0000obm2]Ol00003od5La`03o`000?m1JM?o@FWC00;o@FWC0ol00002odUlh003o`000?mS
T^SoHi;X00;oHi;X00?o0000ogBPkOmdX>d00_mdX>dCo`0000?oT;C`00?o0000oookJ_oonfX08_oo
nfX00ol0003ooo]ZoookJP0=oookJP00<ooonfX2o`0000Kooo]Z00?o0000ojO4k_nWa>h01?nWa>h2
o`0000KoZ<G^00?o0000ojS5k_nXaNh01?nXaNh3o`0000OoZLG^00?o0000ojW5k_l000000_l00003
ojW6kP03o`000?nZa^koZ/K^00CoZ/K^0ol00007oj_7kP03o`000?n/ango[<O]00?o00000on/and0
0ol0003o[/S]ojk8k@03ojk8k@?o00001on_bNd01?l0003o/LW/o`000?l00006ok;9k003o`000?nd
b^_o000000Go]<_[00?o0000okO;jOngbnT00_ngbnT2o`0000?o^<_Y00?o0000ok_<ionkc>L00_nk
c>L2o`0000;o^lcW00Co0000oko<i?noc>Co_lcT0_l00005oko=i@04o`000?o4c>7o0000o`0000Go
`lgR00?o0000olS;g?l000001oo6c=l3o`0000Gob<cL00Go0000olK@h_o6d>;oa]3Ro`000003olW;
f`;o00000oo6d^<01?l0003obL_LolW;g?o9bm`2o`0000CoaMOW00Co0000olO=gol0003o00001_no
g>h00ol0003o`M3Uo`000006ok7Sn0Co00001OnDhod01?l0003oY]KhojKFn?nVe_P6o`0000CoS];n
0_l00004oig6m004o`000?nS^n[oXk_Zoj>kjPGo00001OnL__000ol0003oX[[Yoj:jj@04oj:jj@03
o`000?nV^>KoY[SV00?o00000_nV`^d00ol0003o[LC[ojg4j`04ojg4j`;o00001_nld^/01ol0003o
`mSYol?HjOo3f>Wo0000om7Qhol000001?oJh]`01Ol0003oh=oCon3OdooPgm?o000000;ohmS;00Ko
0000onCAa?oTdLCo0000oo3@/_l00003onc7[P03o`000?oW_jcoikn/00;oikn/00Co0000on:i[OoR
^Jgoh[V]0_l00005on6^XP07o`000?oJZjKofZ^VomZ[Y_l0003og:FKo`000006omFRX@;o00001_o>
VZ001?l0003obi>Jol^CV_l00003olBBXP03o`000?noRYko_hZN00Go_hZN00?o0000ok>4X_ncQ:80
1?ncQ:800ol0003oZW^PojYkX003ojYkX003o`000?nOLYooWg:O00?oWg:O00?o0000oi=YWonCJIl0
0onCJIl00ol0003oQf6OohMQW`03ohMQW`03o`000?mlFj7oO5^Q00?oO5^Q00?o0000og9GXombEj<0
0_mbEj<00ol0003oJeNXof]GZ002of]GZ0;o00001?mEAZ@01?l0003oE4j^oeA>[_mDCZh2o`0000?o
@DF_00Co0000odYG__m:EkkoBUNn0_l00004od5La`;o00000_m1JM<00ol0003oFH;OoeV2g`03o`00
00GoHi;X00?o0000ogBPkOmdX>d00omdX>d00ol0003oPJW^oh6YkP04oh6YkP03o`000?n9/>ooRK3_
00CoRK3_0_l00005oi2dl003o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX03?oonfX003Go
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003oYlC^ojO4kP03o`0000;oZ<C^00?o0000ojS5k_nX
aNh01?nXaNh00ol0003oZ<G^ojS5kP03o`0000?oZ<G^00?o0000ojW5k_nYaNh01?nYaNh3o`0000Ko
ZLK^00?o0000oj[6k_nZa^h00ol00003oj[6kP03o`000?n[ankoZlO^00CoZlO^0ol00007ojc7k@03
o`000?n^b>go000000;o00000on^b>d00ol0003o[lW]ojo9k@04ojo9k@?o00001onbbN`2o`0000Oo
]<_[00Co0000okO;jOl0003o00001_nhbnT01?l0003o^lcWo`000?l00005ok_<i`03o`000?noc>Co
000000Oo_lgU0ol00006ol?=hP?o00001_o6c=l01Ol0003oa<oSolC?hoo4cn?o000000?ob<cL00?o
0000olK@h_o6d>800oo6d>800ol0003obL_Ko`000006olKBh`03o`000?o9bmco000000KoaMOW0ol0
0007okoLkPCo00000_nahoP3o`0000?oK=gX00Co0000oiCSoOnDhogoU>?m1_l00005ofGCm@04o`00
0?n>d_koS];nohkBoP_o00001?nAaOT00ol0003oW;k`oibnl004oibnl004o`000?nR^^WoX[[Yoj:j
j@Go00001_nV`^d00ol0003o[LC[ojg4j`03o`0000;o/Lc^00Co0000okcBjonld^_o_=;[0_l00004
ol?Hj@?o00000ooJh]`01Ol0003oh=oCon3OdooPgm?o000000?ohmS;00Go0000onCAa?oTdLCoi=74
o`000003onc7[P03o`000?oW_jcoikn/00;oikn/00?o0000on:i[OoR^Jd00ooR^Jd00ol0003ohJjR
on6^XP03on6^XP07o`000?oJZjKofZ^VomZ[Y_l0003og:FKo`000006omFRX@03o`000?o>VZ3ocYZP
00GocYZP00?o0000ol^CV_l000001Oo4TZ800ol0003o_hZNokn:WP04okn:WP03o`000?ncQ:;o/hBR
00Co/hBR00?o0000ojYkX?nZNj000onZNj000ol0003oWg:OoimbW`03oimbW`03o`000?nCJIooTfVO
00CoTfVO00?o0000ohMQWon7HIl00_n7HIl00ol0003oO5^QogaKX@03ogaKX@03o`000?mbEj?oLUNS
00;oLUNS00?o0000of]GZ?m[EjP00_m[EjP00ol0003oIeZ_o`000003oeE6Y007o`000?mDCZkoE4j^
oeA>[_l0003oF5Zio`000002od55[`03o`000?m:EkkoBUNn00;oBUNn00?o0000od5Laom1G<L00_m1
G<L00ol0003oE7CEo`000002od5Yd`03o`000?mIP]ooFH;O00;oFH;O1Ol000000omST^So0000ogBP
k@04ogBPk@03o`000?n1ZNkoPJW^00CoPJW^00?o0000ohV`kon9/>l01?n9/>l2o`0000CoT;C`00?o
0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0<oookJP00=_oonfX00ol0003ooo]ZoookJP04
oookJP;o00001_nXa>h00ol0003oZ<G^ojS5kP03ojS5kP?o00001onXaNh00ol0003oZLG^ojW5kP03
o`0000?oZLG^00?o0000ojW6k_nYa^h00onYa^h3o`0000OoZ/K^00?o0000oj_7k_n[anh00ol00003
ojc7kP03o`000?n/ango[<O]00Co[<O]0ol00006ojk8k@03o`000?n_bNgo[lW]00?o00000on`bN`0
0ol0003o//W/ok;9k002ok;9k0;o00000_nbb^`00ol0003o]<_[okC;j`04okC;j`?o00001onhbnT3
o`0000Ko^lcW0ol00006oko=i@05o`000?nnc^Ko_/kVokk>i_l000000oo3cN82o`0000?o`/kT00Co
0000olK<goo6c=ooa/cO0_l00005olC?h`03o`000?o8c=co000000Koa]3R0_l00007olKBh`?o0000
1?o5enL2o`0000?o^^Kd0_l00002okoLkP?o00000onTkOT=o`0000Go^H:I3_l000000oli^NKo0000
ogS;o`03ogS;o`;o00001?nAaOT01?l0003oW;k`oibnl?nL__06o`0000CoWL;b00?o0000ojK2kOnV
`^d01?nV`^d3o`0000Ko/Lc^00?o0000okcBjol000001Oo3f>T01ol0003ob][Uol[JiOo:f^Go0000
om[Rg?l000000ooPgm<01Ol0003ohmS;on?HbooSf<_o000000Coi=740_l00002onc7[P03o`000?oW
_jcoikn/00;oikn/00?o0000on:i[OoR^Jd00ooR^Jd00ol0003ohJjRon6^XP02on6^XP03o`000?oJ
ZjKofZ^V00;ofZ^V00?o0000ombUVol000001_oEXZ400ol0003ocYZPoljJX005oljJX003o`000?o;
Ti[o000000Goa9:R00?o0000okn:W_noRYh00onoRYh2o`0000Ko/hBR00?o0000ojYkX?nZNj000onZ
Nj000ol0003oWg:OoimbW`04oimbW`03o`000?nCJIooTfVO00?oTfVO00?o0000ohMQWon7HIl00on7
HIl00ol0003oO5^QogaKX@02ogaKX@03o`000?mbEj?oLUNS00?oLUNS00Go0000of]GZ?m[EjSoJeNX
o`000002ofMJ[`;o000000?oEDJTo`000?mDCZh00omDCZh01_l0003oF5Zio`000?l0003o@DF_o`00
00CoBUNn0_l00003od5La`03o`000?mDM=Go000000;o00001?mIP]l00ol0003oK9CWofbDi`02ofbD
i`Oo000000?oM:3]o`000?n1ZNh01?n1ZNh00ol0003oRK3_ohV`k`02ohV`k`[o00008ooonfX00ol0
003ooo]ZoookJP0<oookJP00=ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?nXa>koZ<C^00Go
Z<C^00?o0000ojS5k_l000000_l00003ojS5kP03o`000?nXaNkoZ<G^00CoZ<G^0ol00007ojW5kP03
o`000?nYa^ko000000;o00000onZa^h2o`0000GoZ/K^0ol00007ojc7kP03o`000?n/ango[<O]00?o
00000on]and00ol0003o[/S]ojk8k@03ojk8k@?o00001on`bN`01?l0003o//W/o`000?l00005ok;:
k003o`000?ndbn_o]<_[00?o00000onebn/00ol0003o^<_YokS;j@02okS;j@;o00000onhc>T01?l0
003o^lcWok_<ionkc>L2o`0000?o^lgX00Co0000oko=iOnocNGo_lgU0_l00005okk>iP03o`000?o3
cN;o000000Ko`/kT00?o0000olK<gol000001oo4cn<2o`0000Koa]3R00Co0000ol?HjOo3f>Wo0000
1?o6d^<2o`0000?o`]k]0_l000000oo5enOo0000ok[Vm005ok[Vm0Co00000_nTkOT5o`0000;odIVJ
00?o0000okR2V_nhPYX00_nhPYX01?l0003oai2KolN@Vol00005okV2V@04o`000?nDIISoU6FHo`00
00;o/WjK00?o0000ojMdV_nWM9X00onWM9X00ol0003oV6NHo`00000?o`0000CoS/Gj00?o0000oig2
l_nM`_801?nM`_800ol0003oY/;]ojK2k@03o`0000;oYLWb00?o0000ok7<k_nac>h01?nac>h3o`00
00?o`mSY0_l00004ol[Ji@Co000000?oh=oCo`000?oSf</00_oSf</00ol0003oi=74onCAa002onCA
a006o`000?oRbL3oh/W0o`000?o/ajko00001?oW_j`00ol0003oh[V]on:i[@02on:i[@03o`000?oL
/joo000000?ohJjR00?o0000omZ[Y_oJZjH00ooJZjH00ol0003oeJ:QomFRX@05omFRX@03o`000?o>
VZ3ocYZP00KocYZP0_l00005olBBXP03o`000?noRYko_hZN00;o_hZN00?o0000okZ<Y_l000001_nc
Q:800ol0003oZW^PojYkX003ojYkX003o`000?nOLYooWg:O00CoWg:O00?o0000oi=YWonCJIl01ol0
0002ohMQW`03o`000?mlFj7oO5^Q00;oO5^Q00?o0000og9GXombEj<00ombEj<00ol0003oJeNXof]G
Z002of]GZ004o`000?mWFZooIeZ_ofMJ[`;o00001?mDCZh01?l0003oF5ZioeQJ^OmHF[T2o`0000Co
BUNn00Ko0000oeM[c?l0003o0000od5Laol00003oeAde@03o`000?mIP]ooFH;O00?oFH;O00?o0000
ofbDiom/U>L00om/U>L00ol0003oNZ7[ogZQj`02ogZQj`co00000on</>h2o`0000GoTKC_00?o0000
oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0<oookJP00>?oonfX2o`0000Gooo]Z00?o0000ojS4
k_nXa>h01?nXa>h3o`0000KoZ<G^00?o0000ojS5k_nXaNh00ol00003ojS5kP03o`000?nYaNkoZLG^
00CoZLG^0_l00008oj[6kP03o`000?nZa^ko000000;o00000_n[a^h00ol0003o[<O^ojc7kP05ojc7
kP?o00001on]and00ol0003o[/S]o`000002o`0000?o[/S]00?o0000ok39k?n`bN`01?n`bN`3o`00
00Ko//[/0ol00007okG;j`04o`000?nhbnWo0000o`0000Ko^<cY00?o0000ok_<iol000001_nkcNP0
0ol0003o_lgUo`000007okk>iP;o00001oo2c^@3o`0000Koa<oS00Co0000ol;Dioo2e>Oo00000oo6
d>82o`0000Co`mSY00Co0000olKBhol0003o00001_o2g^d4o`0000;o^^Kd0ol00003oi7^k`?o0000
0oo=UIX01Ol0003odIVJom6IV_oAVI[o000000Co^8:J00Co0000olN@Voo7T9_o00001OniPYT01?l0
003oU6FHoiAUV?l00002ok9nV`03o`000?nWM9[oYgBJ00?oYgBJ00?o0000oiQWV?nHIiP00onHIiP5
o`000003obR/hol0003oL<Go00?oL<Go00?o0000ohk5n_n>aOX00on>aOX01?l0003oWL;boig2l_nM
`_85o`0000KoYLWb00?o0000ok7<k_nac>h00ol00003okCAk`03o`000?o3f>Wo000000Gob][U00?o
0000oloIh?o?fN000_o?fN000ol0003ohmS;on?Hb`02on?Hb`05o`000?oTdLCoi=74onCAa?l00000
1?oRbL000ol0003oikn/onNo[002onNo[003o`000?oR^Jgoh[V]00?oh[V]00?o0000ombc[ol00000
0ooQ[Z800ol0003ofZ^VomZ[YP03omZ[YP03o`000?oEXZ7oeJ:Q00CoeJ:Q0_l00008oljJX003o`00
0?o4TZ;oa9:R00Coa9:R00?o0000okn:W_noRYh00_noRYh01?l0003o^XbVokZ<Y_l00005ok>4XP03
o`000?nZNj3oZW^P00?oZW^P00?o0000oimbWonOLYl00onOLYl4o`0000?oUg:X00Co0000ohe]Z?n=
KJSoSFfX1Ol00002ogaKX@03o`000?mbEj?oLUNS00?oLUNS00?o0000of]GZ?m[EjP00_m[EjP00ol0
003oIeZ_ofMJ[`02ofMJ[`;o00000omDCZh00ol0003oF5ZioeQJ^@02oeQJ^@03o`000?m:EkkoBUNn
00?oBUNn00Ko0000oeM[c?mGJlco0000od5Laol00003oeAde@Go000000?oFH;Oo`000?m/U>L01?m/
U>L00ol0003oNZ7[ogZQj`03ogZQj`03o`000?n4ZNgoQ:W]00?oQ:W]00?o0000ohb`k_n</>h01On<
/>h2o`0000GoTKC_00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0<oookJP00>_oonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?nXa>koZ<C^00?o00000onXaNh00ol0003oZ<G^ojS5kP03
ojS5kP?o00001onXaNh00ol0003oZLG^ojW5kP03o`0000;oZLG^00?o0000oj[6k_nZa^h01OnZa^h2
o`0000KoZlK^00?o0000ojc7k_n/anh00_n/anh2o`0000;o[<O]00?o0000ojg7kOn]and01On]and2
o`0000Oo[/S]00?o0000ok39k?n`bN`00ol00003ok39k004o`000?nbb^co//[/ok;:k0;o00000onb
b^`00ol0003o]L_[okG;j`04okG;j`?o00001onhc>T2o`0000Oo^lgX0ol00006okk>iP04o`000?nm
cnOo_LoWo`0000Co`/kT0_l00003ol3Ai`04o`000?o4cn?oa<oSolC?h`;o00001?o2e>L00ol0003o
a]3Ro`000006ol?Hj@?o00001Oo2g^d2o`0000?o]>gf1?l00002oi7^k`?o000000?ofJ6Ko`000?o=
UIX00oo=UIX01Ol0003odIVJom6IV_oAVI[o000000?o^8:J00Go0000olN@Voo7T9_oai2Ko`000006
okV2V@03o`000?nDIISo000000?o/WjK00?o0000ojMdV_nWM9X00onWM9X00ol0003oV6NHoiQWV002
oiQWV003o`000?n6FYKoQUZF00;oQUZF1_l000000om`aOoo0000ohk5nP02ohk5nPGo00001?nEaoT0
0ol0003oYLWbojG9lP04ojG9lP?o00001_nddNl3o`0000?ob][U0_l00004oloIh003o`000?oCeM[o
000000;ohmS;00?o0000onCAa?oTdL@00_oTdL@00ol0003oh/W0on;9`002on;9`003o`000?oW_jco
ikn/00;oikn/00?o0000on:i[OoR^Jd00_oR^Jd01?l0003og;>_ombc[ol00002on6^XP03o`000?oJ
ZjKofZ^V00CofZ^V00?o0000omFRXOoEXZ401?oEXZ400ol0003ocZ2Xo`000007oljJX003o`000?o4
TZ;oa9:R00Coa9:R00Go0000okn:W_noRYko_hZNo`000003okZ<YP03o`000?ncQ:;o/hBR00Co/hBR
00?o0000ojYkX?nZNj000onZNj000ol0003oWg:OoimbW`02o`000003oj1iZ?l0003oUg:X00CoUg:X
00?o0000ohe]Z?n=KJP00on=KJP00ol0003oQFR[ohEXZ`04o`0000CoLUNS00?o0000of]GZ?m[EjP0
0_m[EjP00ol0003oIeZ_ofMJ[`03ofMJ[`;o00000omDCZh00ol0003oF5ZioeQJ^@02oeQJ^@;o0000
0om:Ekh01?l0003oEf_<oeM[c?mGJl`2o`0000?oE7CE00?o0000ofJ8gomVR=l00_mVR=l7o`000003
ofbDiol0003oNZ7[00CoNZ7[00?o0000ohBYkOn4ZNd00on4ZNd00ol0003oS;3^ohb`kP04ohb`kP03
o`000?nA]>oo000000;oTKC_1?l0000PoookJP03o`000?oonf[ooo]Z00cooo]Z000koookJP03o`00
0?oonf[ooo]Z00?ooo]Z0_l00007ojS5kP03o`000?nXaNko000000;o00000onXaNh2o`0000GoZ<G^
0ol00006ojW5kP03o`000?nZa^koZ/K^00;oZ/K^0_l00002oj[6kP03o`000?n[a^koZlK^00CoZlK^
00Co0000ojc7k_l0003o00001On/and00ol0003o[LO]ojg7k@02ojg7k@;o00000_n]b>d00ol0003o
[/S]ojk8k@04ojk8k@?o00001on`bN`00ol0003o//[/o`000006ok;:k003o`000?nebn_o]L_[00?o
00000onebn/00ol0003o^<cYokS<j@02okS<j@;o00000_nhc>X00ol0003o^lgXok_=j002ok_=j0;o
00000onkc^P01?l0003o_/kVokk>i_nnc^H2o`0000Co_LoW00Co0000ol;>i?l0003o00001_o0dNL0
0ol0003oa<oSo`000006ol;Di`?o00001?o3f>T2o`0000?o_^?a0_l000000oo2g^go0000o`000003
okC]mP;o00001?n1j>02o`0000;ogjFH00?o0000omVQVol000001?o=UIX01Ol0003odIVJom6IV_oA
VI[o000000?o^8:J00Go0000olN@Voo7T9_oai2Ko`000006okV2V@;o00001?nbOY/00ol0003oYgBJ
ojMdVP03ojMdVP03o`000?nHIiSoV6NH00;oV6NH00?o0000ohIJU_n6FYH00_n6FYH00ol0003oM4fE
ogA=U@02o`000003ocN`l?l0003o000000?o00000omhaOh00ol0003oULOioiG7n@04oiG7n@03o`00
0?nUbO;oYLWb00?o00000_nTcOD00ol0003o]=7_okCAk`02okCAk`;o00000onidnh00ol0003ob][U
o`000005oloIh007o`000?oCeM[odmGJom?Ef_l0003ohmS;o`000003onCAa003o`000?oRbL3oh/W0
00;oh/W000?o0000omk2_Ol000000_oW_j`00ol0003oh[V]on:i[@03on:i[@07o`000?oL/joog;>_
ombc[ol0003ohJjRo`000005omZ[YP;o00001_oEXZ400ol0003ocZ2Xo`000006oljJX0;o00001_o4
TZ801Ol0003o_hZNokn:W_noRYko000000?o^XbV00?o0000ok>4X_ncQ:801?ncQ:800ol0003oZW^P
ojYkX003ojYkX0?o00000onPNJP00ol0003oUg:XoiMbZ003oiMbZ003o`000?n=KJSoSFfX00?oSFfX
00?o0000ohEXZon5J:/00on5J:/2o`0000?oLUNS00?o0000of]GZ?m[EjP00om[EjP00ol0003oIeZ_
ofMJ[`02ofMJ[`03o`000?mWHKSo000000;oE4j^00?o0000oeQJ^OmHF[T00_mHF[T01?l0003oGfS5
o`000?l00002odYG_P03o`000?mGJlcoEf_<00;oEf_<0_l00002oeAde@03o`000?mVR=ooIXSO00?o
IXSO00?o0000ogBGi_mdUnH00_mdUnH6o`000003ogZQjol0003oQ:W]00GoQ:W]00Co0000ohb`k_n<
/>koS;3^1ol00003oi>dkP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX03?oonfX003co
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003oZ<G^ojS5kP04ojS5kP?o00001onXaNh00ol0003o
Z<G^o`000002o`0000;oZLG^00?o0000ojW5k_nYaNh01OnYaNh01?l0003oZ/K^o`000?l00005oj[6
kP03o`000?n[a^koZlK^00?oZlK^0ol00007ojc7k@04o`000?n]ango0000o`0000Go[LS]00?o0000
ojk8kOn^b>d00ol00003ojo8k@03o`000?n`bNco/<W/00Co/<W/0ol00006ok;:k0?o00001onebn/0
1?l0003o^<cYo`000?l00005okS<jP04o`000?nkcNSo0000o`0000Ko^lkX00?o0000okk>i_l00000
1_nmcnL3o`0000Oo`=7W0ol00004ol;Di`;o00000oo0fnd2o`000003ol?HjOl0003o_^?a00Go_^?a
1?l00002okC]mP04o`000?n1j>3oPNSPoh7Xh0?o00000ooOYIP01?l0003ofJ6KomVQVol00004olfE
VP05o`000?oAVI[odIVJom6IV_l000000onhPYX01Ol0003oai2KolN@Voo7T9_o000000Ko^H:I0_l0
0004ok9nV`03o`000?nWM9[oYgBJ00?oYgBJ00?o0000oiQWV?nHIiP00_nHIiP00ol0003oQUZFohIJ
UP02ohIJUP03o`000?mdCIGoM4fE00;oM4fE1?l000000olg/?3o0000ogS5oP03ogS5oP04o`000?nE
aoWoULOioiG7n@Go00001_nTcOD01?l0003o]=7_o`000?l00005okWCkP;o00001Oo?fN000ol0003o
dmGJom?EfP02om?EfP?o00000ooTdL@01Ol0003oh/W0on;9`?oRbL3o000000?og/:m00?o0000onNo
[?l000001?oR^Jd00ol0003og;>_ombc[`02ombc[`03o`000?oQ[Z;o000000GofZ^V00?o0000om>X
Zol000001?oEXZ401?l0003ocZ2XoljPZ?l00006oljJX003o`000?o7VJSo000000Goa9:R00Co0000
okn:W_noRYko00001?njS:H00ol0003o/hBRok>4XP04ok>4XP03o`000?nZNj3oZW^P00?oZW^P00?o
0000oj1iZ?nPNJP01?nPNJP00ol0003oUg:XoiMbZ003oiMbZ003o`000?n=KJSoSFfX00;oSFfX00?o
0000ohEXZon5J:/00on5J:/00ol0003oOVN^o`000002og9GX`03o`000?m[EjSoJeNX00?oJeNX00?o
0000ofMJ[omWFZl00_mWFZl00ol0003oIf6hofMQ^002o`000003oeA>[_l0003oF5Zi00?oF5Zi00Ko
0000oemXaOmOJ<Go0000odYG__l00004oeM[c006o`000?mUO]Oo0000o`000?mDM=Go00001OmVR=l0
0ol0003oM9OVogBGiP03ogBGiP04o`000?moX^WoOj;YognRj@co00000on>/>d00ol0003oTkC^o`00
0005oi>dkP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX03?oonfX003gooo]Z0_l00005
oookJP03o`000?nXaNkoZ<G^00?o00000onXaNh00ol0003oZ<G^ojS5kP04ojS5kP;o00001_nYaNh0
0ol0003oZLG^ojW5kP04ojW5kP?o00001onZa^h00ol0003oZlK^o`000002o`0000?oZlK^00?o0000
ojc7kOn/and01?n/and3o`0000Ko[LS]0ol00007ojo8k@03o`000?n`bNco/<W/00?o00000onabN`0
1?l0003o//[/ok;:k?nbb^`2o`0000?o/l_/00?o0000okG;jonebn/01?nebn/3o`0000Ko^<cZ0ol0
0007ok_>j0?o00001?nmcnL2o`0000?o_M;Z00?o0000ol3Aioo0dNL00_o0dNL2o`0000?o_mK[00Co
0000ol;Diol0003o00001_o0fnd3o`0000Co_^?a0_l00004ok3`mPKo000000?ohjVFo`000?oOYIP0
0ooOYIP01?l0003ofJ6KomVQVol00003olfEVP03o`000?oAVI[odIVJ00;odIVJ00Go0000okR2V_nh
PY[o^8:Jo`000003olN@V`03o`000?niPYWo^H:I00Co^H:I0_l00004ok9nV`03o`000?nWM9[oYgBJ
00?oYgBJ00?o0000oiQWV?nHIiP00_nHIiP00ol0003oQUZFohIJUP02ohIJUP03o`000?mdCIGoM4fE
00;oM4fE00?o0000ofA3UOmT@iD02ol00004ohc9o003o`000?nTcOGoY<ge00CoY<ge0ol00004okWC
kP;o00000_nldn/01Ol0003ocmWPoloIh?o?fN3o000000CodmGJ00Oo0000omC?e?oDcmCoe<oDo`00
0?oTdLCo000000Coh/W000?o0000omk2_OoN`[d00_oN`[d00ol0003oh[V]on:i[@03on:i[@03o`00
0?oL/joog;>_00;og;>_0_l00006omZ[YP03o`000?oCZ:_o000000CoeJ:Q00Go0000oljPZ?o>X:So
cZ2Xo`000005oljJX003o`000?o7VJSo000000Koa9:R0_l00005okZ<YP03o`000?ncQ:;o/hBR00Co
/hBR00?o0000ojYkX?nZNj000_nZNj02o`0000KoX7VX00?o0000oiMbZ?nGLZP00onGLZP00ol0003o
SFfXohe]Z003ohe]Z003o`000?n5J:_oQFR[00;oQFR[00?o0000ogiW[_mnIjh00_l000000ombEj?o
0000of]GZ003of]GZ003o`000?mWFZooIeZ_00?oIeZ_00Co0000ofMQ^?mWHKSoIf6h0_l00004oeQJ
^@04o`000?mOJ<GoGfS5oemXa@;o00001OmGJl`00ol0003oIGkGofEne`02o`0000KoIXSO00?o0000
ogBGi_mdUnH00omdUnH00ol0003oOj;YognRj@02ognRj@03o`000?n8Z^coR:[/00CoR:[/00?o0000
ohj`kOn>/>d01?n>/>d00ol0003oTkC^o`000004oi>dkP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX02ooonfX003oooo]Z00?o0000oookJ_oonfX00ooonfX2o`0000OoZ<G^00?o0000ojS5
k_nXaNh00ol00002ojS5kP03o`000?nYaNkoZLG^00CoZLG^00?o0000ojW5k_nYaNh00ol00003ojW6
kP03o`000?nZa^koZ/K^00CoZ/K^0ol00006oj_6kP03o`000?n/ango[<O]00?o00000on/and01?l0
003o[LS]ojg8kOn]b>d2o`0000;o[/S]00?o0000ojo8kOn_b>d01On_b>d3o`0000Oo/LW/00?o0000
ok;:k?l000001_ncbn`00ol0003o]L_[okG;j`03o`0000?o]Lc[00Co0000okS<j_nhc>[o^<cZ0_l0
0003okS=j`03o`000?nkc^So^lkX00;o^lkX0_l00003ok[?jP;o000000?o_LoWo`000?nmd^X01Onm
d^X01?l0003o`=7Wo`000?l00005okoFj`?o00001Oo0fnd2o`0000?o^nKc00Co0000okkSlOl0003o
00001?n`l?H5o`000004onB^WOl0003ohjVFo`0000GogjFH00Co0000omVQVooIXI_o00000oo=UIX0
0ol0003odIVJom6IVP02om6IVP05o`000?nhPY[o^8:JokR2V_l000000oo7T9/00ol0003o^H:IokV2
V@04okV2V@03o`000?nbOY_o/WjK00?o/WjK00?o0000ojMdV_nWM9X00onWM9X00ol0003oV6NHoiQW
V002oiQWV003o`000?n6FYKoQUZF00;oQUZF00?o0000ogA=UOmdCID00_mdCID01?l0003oI4>EofA3
UOmT@iD5o`0000CoFkcl0_l00004ohc9o003o`000?nTcOGoY<ge00?o00000onTc_H01?l0003o^M?^
o`000?l00005okcCj`03o`000?o?fN3o000000CodmGJ00?o0000omC?e?oDcm@00ooDcm@00ol0003o
h/W0on;9`002on;9`003o`000?oN`[gog/:m00?og/:m00?o0000on:i[OoR^Jd00_oR^Jd00ol0003o
g;>_ombc[`04ombc[`03o`000?oJZjKofZ^V00?ofZ^V00Co0000om>XZooCZ:_o00000ooEXZ400ol0
003ocZ2XoljPZ002oljPZ003o`000?o>VZ3ocYZP00;ocYZP00Co0000olNIZ?o7VJSo00001_o4TZ82
o`0000Go^XbV00?o0000ok>4X_ncQ:801?ncQ:801ol0003oZW^PojYkX?nZNj3o0000ojR1ZOl00000
1_nPNJP00ol0003oUg:XoiMbZ003oiMbZ003o`000?n=KJSoSFfX00?oSFfX00?o0000ohEXZon5J:/0
0on5J:/01?l0003oOVN^ogiW[_mnIjh2o`0000GoJeNX00?o0000ofMJ[omWFZl00_mWFZl00ol0003o
If6hofMQ^002ofMQ^003o`000?mHF[WoF5Zi00;oF5Zi00?o0000oemXaOmOJ<D00omOJ<D2o`0000?o
Ef_<00?o0000ofEneomUO]L00_mUO]L5o`000003ofJ8gol0003oM9OV00CoM9OV00?o0000ognRjOmo
X^T00omoX^T00ol0003oR:[/ohRZk004ohRZk003o`000?n>/>goS[3]00CoS[3]00Co0000oi>dk_l0
003oTkC^1?l0000OoookJP03o`000?oonf[ooo]Z00_ooo]Z0010oookJP03o`000?oonf[ooo]Z00Co
oo]Z0_l00005ojS5kP?o00001_nXaNh00ol0003oZLG^ojW5kP03ojW5kP?o00001onYa^h00ol0003o
Z/K^oj[6kP03o`0000?oZ/K^00?o0000oj_6k_n[a^h00on[a^h3o`0000Oo[<O]00?o0000ojg8kOl0
00001On^b>d00ol0003o[lS]ojo8k@02ojo8k@;o00000on_bNd00ol0003o/LW/ok79k004ok79k0;o
00001oncbn`3o`0000Oo]Lc[00?o0000okS<j_l000001_nhcN/01?l0003o^lkXo`000?l00006ok[?
jP;o00001onmd^X3o`0000Co_mK[0_l00003okgLl0;o000000?o`=_]o`000?l000001Onki_<4o`00
00;o/?3f1?l00002onVdV`05o`000?oT[Ygo0000on>YU_l000001OoOYIP01Ol0003ofJ6KomVQVooI
XI_o000000;ocIFJ00?o0000om6IV_oAVIX00_oAVIX01?l0003o^8:JokR2V_l00004olN@V`03o`00
0?niPYWo^H:I00Co^H:I00?o0000ok9nVonbOY/00onbOY/00ol0003oYgBJojMdVP03ojMdVP03o`00
0?nHIiSoV6NH00;oV6NH00?o0000ohIJU_n6FYH00_n6FYH00ol0003oM4fEogA=U@02ogA=U@04o`00
0?mT@iGoI4>EofA3U@;o00000_lm9HT>o`0000KoY<kf0_l00007okcCj`?o00000ooCeMX00ol0003o
e<oDomC?e003omC?e003o`000?oCbM3o000000?oh/W000?o0000omk2_OoN`[d00_oN`[d00ol0003o
fKblo`000003on:i[@03o`000?oL/joog;>_00Cog;>_00?o0000omZ[Y_oJZjH00ooJZjH01Ol0003o
djR[om>XZooCZ:_o000000;oeJ:Q00?o0000oljPZ?o>X:P00_o>X:P00ol0003ocYZPoljJX002oljJ
X004o`000?o7VJSoaiVXo`0000Koa9:R00?o0000okZ<Y_njS:H01OnjS:H00ol0003o/hBRok>4XP04
ok>4XP03o`000?nZNj3o000000?oZ86Y00?o0000oj1iZ?nPNJP00onPNJP00ol0003oUg:XoiMbZ003
oiMbZ003o`000?n=KJSoSFfX00?oSFfX00?o0000ohEXZon5J:/00on5J:/00ol0003oOVN^ogiW[P02
ogiW[P;o00001?m[EjP00ol0003oIeZ_ofMJ[`02ofMJ[`03o`000?mWHKSoIf6h00?oIf6h0_l00003
oeQJ^@03o`000?mOJ<GoGfS500;oGfS500Ko0000ofQid?l0003o0000oeM[c?l00004ofEne`03o`00
0?maS]ooLHkO00;oLHkO1_l000000omdUnKo0000ognRj@05ognRj@04o`000?n8Z^coR:[/ohRZk0go
00000onD]>d00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00_ooo]Z0011oookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000ojS5k_l000000_l00002ojS5kP03o`000?nXaNkoZ<G^00GoZ<G^
00?o0000ojW5k_l000000_l00003ojW5kP03o`000?nYa^koZLK^00CoZLK^0ol00007oj[6kP03o`00
0?n[a^ko000000;o00000on[anh00ol0003o[<O]ojc7k@04ojc7k@?o00001_n^b>d01?l0003o[lS]
o`000?l00006ojo9k@03o`000?nabNco/LW/00?o00000_nab^`00ol0003o/l_/ok?;k002ok?;k0;o
00000oncbn`00ol0003o]Lc[okG<j`04okG<j`?o00001_nhcN/3o`0000Go^/oZ0_l00002ok[Bk003
o`000?nmd^[o_M;Z00;o_M;Z0_l00003okcFk@;o000000?o_mK[o`000?nmg?001Onmg?03o`0000Co
^nKc0_l00004ojkbm@Co00001?oY]9/01Ol0003oi:jMo`000?oSZIKo000000GogjFH00Go0000omVQ
VooIXI_ofJ6Ko`000002olfEVP03o`000?oAVI[odIVJ00;odIVJ00Co0000okR2V_nhPY[o00001?o7
T9/00ol0003o^H:IokV2V@04okV2V@03o`000?nbOY_o/WjK00?o/WjK00?o0000ojMdV_nWM9X00onW
M9X00ol0003oV6NHoiQWV002oiQWV003o`000?n6FYKoQUZF00;oQUZF00?o0000ogA=UOmdCID00_md
CID01?l0003oI4>EofA3UOmT@iD2o`0000;o?BF900Co0000oc0QSOl`8Hgo<26=1?l000000olk[OCo
0000oh;7oP03oh;7oP03o`000?nTc_KoY<kf00?o00000_nTcOD00ol0003o_=?[okcCj`02okcCj`;o
00000onod>L00ol0003odmGJo`000005omC?e007o`000?oCbM3odlW@om?9d?l0003oh/W0o`000004
omk2_@07o`000?oI_;cofKblomVl_?l0003oh[V]o`000006ombc[`03o`000?oF/;;o000000?ofZ^V
00?o0000om>XZooCZ:/00_oCZ:/01?l0003oeJ:QomFRXOl00004oljPZ005o`000?o>VZ3ocYZPoljJ
X?l000000oo7VJP00ol0003oa9:RolBBXP04olBBXP03o`000?njS:Ko^XbV00Go^XbV00?o0000ok>4
X_ncQ:801?ncQ:82o`0000CoZ86Y00?o0000oj1iZ?nPNJP01?nPNJP00ol0003oUg:XoiMbZ002oiMb
Z003o`000?n=KJSoSFfX00?oSFfX00?o0000ohEXZon5J:/00on5J:/00ol0003oOVN^ogiW[P02ogiW
[P03o`000?miIk?o000000;o000000?oJeNXo`000?mWFZl01?mWFZl00ol0003oIf6hofMQ^002ofMQ
^006o`000?mZJl;o0000o`000?mHF[Wo00001OmOJ<D00ol0003oJ7W@ofQid003o`0000CoIGkG00?o
0000og6>gomaS]l00omaS]l01?l0003oO9_UogbKiOmlVnD<o`0000?oRj_[00?o0000oi2ak?n@/N`0
1?n@/N`00ol0003oU;C]o`000004oiBdk@03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0
2ooonfX004;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003oZ<G^ojS5kP04ojS5kP03o`000?nX
aNkoZ<G^00CoZ<G^0ol00006ojW5kP03o`000?nYa^koZLK^00?o00000onZa^h00ol0003oZ/K^oj[6
kP04oj[6kP?o00001_n[anh00ol0003o[<O]ojc7k@03o`0000?o[LO]00?o0000ojk8kOn^b>d00on^
b>d3o`0000Oo[lW]0ol00006ok7:k004o`000?ncbnco0000o`0000Ko/l_/00?o0000okG<jonec>/0
0ol00003okG=k003o`000?nhcN_o^<g[00?o00000onhcn`2o`000003ok[?j_l0003o000000Go^];/
00Co0000okgBj_l0003o00001_nle^d3o`0000Co_Mc`0_l00003ok[Vm0;o000000?o^nKco`000?n^
l_D00_n^l_D3o`0000?okkbK00Go0000onVdVooY]9_ojKBKo`000002onB^W@03o`000?oSZIKo0000
00CogjFH00?o0000omVQVooIXI/00_oIXI/01?l0003ocIFJolfEV_l00004om6IVP04o`000?nhPY[o
^8:Jo`0000Coai2K00?o0000okV2VOniPYT00oniPYT2o`0000Go/WjK00?o0000ojMdV_nWM9X00onW
M9X00ol0003oV6NHoiQWV002oiQWV003o`000?n6FYKoQUZF00;oQUZF00?o0000ogA=UOmdCID00_md
CID00ol0003oI4>EofA3U@02ofA3U@;o000000?o?BF9o`000?l`8Hd00_l`8Hd01?l0003o0020o`00
0?lQV^/9o`0000KoY<ge00Co0000okcCjol0003o00001Onod>L2o`0000Goe<oD00?o0000om?9d?oC
bM000ooCbM000ol0003og/:momk2_@03omk2_@07o`000?oI_;cofKblomVl_?l0003oh[V]o`000005
ombc[`04o`000?oF/;;oe[2bo`0000?ofZ^V00?o0000om>XZooCZ:/00_oCZ:/00ol0003oeJ:Qo`00
0006oljPZ004o`000?o>VZ3ocYZPo`0000CoaiVX00?o0000olBBX_o4TZ800_o4TZ82o`0000Oo^XbV
00?o0000ok>4X_ncQ:801?ncQ:800ol0003oZ86YojR1Z@03ojR1Z@03o`000?nPNJSoX7VX00CoX7VX
00?o0000oiMbZ?nGLZP00onGLZP00ol0003oSFfXohe]Z002ohe]Z003o`000?n5J:_oQFR[00?oQFR[
00?o0000ogiW[_mnIjh00omnIjh01?l0003oNFNcogUW/omiIk<3o`0000CoIeZ_00?o0000ofMQ^?mW
HKP00omWHKP00ol0003oJV_2ofY[`P02o`0000GoGfS500?o0000ofQid?mXNM000_mXNM03o`0000?o
IGkG00?o0000og6>gomaS]l00omaS]l00ol0003oO9_UogbKi@02ogbKi@03o`000?n5Y>WoQJCY00Co
QJCY00?o0000oh^[jon;Zn/01?n;Zn/00ol0003oT;7/oi2ak004oi2ak003o`000?nD]>go000000Co
U;C]00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0;oookJP00@ooonfX2o`0000Kooo]Z
00?o0000ojS5k_nXaNh01?nXaNh00ol0003oZ<G^ojS5kP03o`0000?oZLG^00?o0000ojW5k_nYaNh0
0onYaNh3o`0000OoZ/K^00?o0000oj[6k_nZa^h00ol00003oj_6kP03o`000?n[ankoZlO^00?oZlO^
0ol00007ojg7k@03o`000?n^b>go000000;o00000on^b>d00ol0003o[lW]ojo9k@02ojo9k@;o0000
0on_bNd00ol0003o/L[/ok7:k003ok7:k0?o00001oncbn`3o`0000Ko]Lg/0ol00007okS?k0?o0000
1_njd^`3o`0000Go_=K]0_l00003ok_Ml@04o`000?nmg?3o0000o`0000Ko^^Kd1ol000000ooeaYco
0000onnlV`02onnlV`05o`000?oY]9_ojKBKonVdVol000000_oT[Yd00ol0003ohjVFo`000004omnU
V003o`000?oIXI_ofJ6K00;ofJ6K00?o0000olfEV_l000001_oAVIX00ol0003o^8:Jo`000004olN@
V`03o`000?niPYWo^H:I00?o^H:I0_l00005ok9nV`03o`000?nWM9[oYgBJ00?oYgBJ00?o0000oiQW
V?nHIiP00_nHIiP00ol0003oQUZFohIJUP02ohIJUP03o`000?mdCIGoM4fE00;oM4fE00?o0000ofA3
UOmT@iD00_mT@iD2o`000003ocdUROl0003o<26=00;o<26=0_l000001_l0083o0000o`000?l0003o
8I[[o`0000GoNl;m00?o0000ojC=mOnTcOD00onTcOD2o`0000Ko_m3W00Co0000ol7<hoo1c>?o0000
0ooDcm@00ol0003odlW@om?9d003om?9d0;o00001?oN`[d00ol0003ofKblomVl_003omVl_003o`00
0?oL/joog;>_00Cog;>_00Co0000omJ`/_oF/;;o00000ooJZjH00ol0003odjR[om>XZ`02om>XZ`03
o`000?oEXZ7o000000KocZ2X00?o0000oljJX?l000001Oo7VJP00ol0003oa9:RolBBXP02olBBXP03
o`000?nnTj[o000000Ko^XbV00?o0000ok>4X_ncQ:800oncQ:82o`0000GoZ86Y00?o0000oj1iZ?nP
NJP01?nPNJP00ol0003oUg:XoiMbZ003oiMbZ003o`000?n=KJSoSFfX00?oSFfX00?o0000ohEXZon5
J:/00on5J:/00ol0003oOVN^ogiW[P02ogiW[P03o`000?miIk?oNFNc00?oNFNc0_l00003ofMJ[`03
o`000?mWHKSoIf6h00?oIf6h00?o0000ofY[`_mZJl800_mZJl82o`0000CoGfS500Go0000ofQid?mX
NM3oJ7W@o`000002og:7f@Co00001OmaS]l00ol0003oO9_UogbKi@03ogbKi@03o`000?n5Y>WoQJCY
00CoQJCY00?o0000oh^[jon;Zn/01?n;Zn/01?l0003oT;7/oi2ak?n@/N`;o`0001cooo]Z00?o0000
oookJ_oonfX02ooonfX004Gooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003oZ<G^ojS5kP03ojS5
kP?o00001onYaNh00ol0003oZLG^o`000002o`0000?oZLG^00?o0000oj[6k_nZa^h01?nZa^h3o`00
00OoZlK^00?o0000oj_7k_l000000_l00003ojc7kP03o`000?n]ango[LO]00Co[LO]0ol00006ojk8
k@04o`000?n_bNgo0000o`0000Ko[lW]00?o0000ok7:k?l000000_l00003ok7;k@03o`000?ncbnco
/l_/00;o/l_/0_l00003ok?<k@04o`000?necNco]Lg/okG=k0;o00000onecnd00ol0003o^<o/okS?
k002okS?k0;o00000onhd^d01?l0003o^];/ok[Bk?njd^`2o`0000?o^]K^0_l000000onle^go0000
o`000005ok_Ml@?o00001Onji_@2o`000003ojobmOl0003o000000;o00000ooeaY`01?l0003okkbK
onnlVol00004onVdV`05o`000?oT[Ygoi:jMonB^WOl000001OoOYIP00ol0003ofJ6KomVQV`02omVQ
V`03o`000?o=UI[o000000KodIVJ0_l00005olN@V`03o`000?niPYWo^H:I00?o^H:I0_l00005ok9n
V`03o`000?nWM9[oYgBJ00?oYgBJ00?o0000oiQWV?nHIiP00_nHIiP00ol0003oQUZFohIJUP03ohIJ
UP05o`000?mdCIGoM4fEogA=UOl000001?mT@iD01?l0003oEcfGo`000?l00003oc0QS@;o000000?o
0020o`000?l000001?l00005og_2o@03o`000?nTcOGo000000;o00000_nUb_<01?l0003o_m3Woko@
ionod>L2o`0000Co`LcS00?o0000omC?e?l000001OoCbM001?l0003odL?=om73cOl00003omk2_@03
o`000?oI_;cofKbl00?ofKbl00?o0000ombc[ooL/jl00ooL/jl00ol0003oe[2bomJ`/P02omJ`/P03
o`000?oJZjKo000000KodjR[0_l00006oljPZ003o`000?o>VZ3o000000GoaiVX00Go0000olBBX_o4
TZ;oa9:Ro`000002okjCZP03o`000?njS:Ko^XbV00Co^XbV00?o0000ok>4X_ncQ:800_ncQ:800ol0
003o/8R[o`000006ojR1Z@03o`000?nPNJSoX7VX00?oX7VX00?o0000oiMbZ?nGLZP00onGLZP00ol0
003oSFfXohe]Z003ohe]Z003o`000?n5J:_oQFR[00?oQFR[00?o0000ogiW[_mnIjh00_mnIjh00ol0
003oNFNcogUW/`03ogUW/`06o`000?mfJkWo0000o`000?mWFZoo00001OmWHKP00ol0003oJV_2ofY[
`P02ofY[`P03o`000?m_N<_o000000;o000000?oGfS5o`000?mXNM000omXNM000ol0003oLXOIog:7
f@02og:7f@co000000?oO9_Uo`000?n5Y>T01?n5Y>T00ol0003oRj_[oh^[j`02oh^[j`Ko00000onC
/N`00ol0003oU[G]o`000004oiJek@03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX02ooo
nfX004Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003oZ<G^o`000002o`0000?oZ<G^00?o0000
ojW5k_nYaNh01?nYaNh3o`0000KoZLG^00?o0000oj[6k_nZa^h00ol00003oj[6kP03o`000?n[a^ko
ZlK^00CoZlK^0ol00006ojc7kP03o`000?n]ango[LO]00?o00000on]b>d00ol0003o[/S]ojk8k@03
ojk8k@?o00001on_bNd3o`0000Ko/L_]00Co0000ok?;k?l0003o00001_ncc>d00ol0003o]Lg/o`00
0006okG?k@04o`000?nhcnco0000o`0000Ko^=;]00?o0000ok[Bk?l000001_nje^h3o`0000Co^mga
0_l00003okWVm@;o000000?o^^Kdo`000?l000000_n_l_D5o`0000;omLJL00Go0000onnlVoo__9_o
kkbKo`000004onVdV`05o`000?oT[Ygoi:jMonB^WOl000001OoOYIP00ol0003ofJ6KomVQV`02omVQ
V`03o`000?o=UI[o000000KodIVJ0_l00005olN@V`03o`000?niPYWo^H:I00;o^H:I00?o0000ok^7
W_l000001OnbOY/00ol0003oYgBJojMdVP03ojMdVP03o`000?nHIiSoV6NH00?oV6NH00?o0000ohIJ
U_n6FYH00_n6FYH01Ol0003oM4fEogA=UOmdCIGo000000CoI4>E00Co0000oeLmUol0003o00000ol`
8Hd2o`000003o`00P?l0003o000000co00001OnUb_<00ol0003o_m3Wo`000006ol7<h`;o00001OoC
bM000ol0003odL?=om73c@02om73c@03o`000?oN`[go000000GofKbl00?o0000omBg_Ol000001?oL
/jl00ol0003oe[2bomJ`/P02omJ`/P03o`000?oJZjKo000000KodjR[00?o0000oljPZ?o>X:P01_o>
X:P2o`0000GoaiVX00Co0000olBBX_o4TZ;o00000onnTjX00ol0003o^XbVokZ<YP04okZ<YP05o`00
0?ncQ:;o/hBRok>4X_l000000on`R:/00ol0003oZ86YojR1Z@03ojR1Z@03o`000?nPNJSoX7VX00?o
X7VX00?o0000oiMbZ?nGLZP00onGLZP00ol0003oSFfXohe]Z003ohe]Z003o`000?n5J:_oQFR[00?o
QFR[00?o0000ogiW[_mnIjh00omnIjh00ol0003oNFNcogUW/`02ogUW/`04o`000?mfJkWoMV^iogI[
^@?o00001OmWHKP00ol0003oJV_2ofY[`P02ofY[`P04o`000?m_N<_oKgS;ofmhb`;o00001?mXNM00
0ol0003oLXOIog:7f@03og:7f@03o`000?mkU>3oNiCP00?oNiCP00?o0000oh>OiOn3WnD00_n3WnD<
o`0000?oSjgZ00?o0000oi>ak?nC/N`01?nC/N`00ol0003oU[G]o`000004oiJek@03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX02_oonfX004Oooo]Z00?o0000oookJ_oonfX01?oonfX2o`00
00KoZ<G^00?o0000ojW5k_nYaNh00ol00003ojW5kP03o`000?nYaNkoZLG^00?oZLG^0ol00007oj[6
kP03o`000?n[a^koZlK^00?o00000on[anh00ol0003o[<O^ojc7kP03ojc7kP?o00001on]b>d00ol0
003o[/S]o`000002o`0000?o[/W]00?o0000ojo9kOn_bNd00_n_bNd2o`0000?o/<[]00?o0000ok7;
kOnabnd00onabnd3o`0000Oo/lc]0_l00007okG?k@?o00001onhd^d3o`0000Co^]K^0_l00003okWL
l@;o000000?o^mgao`000?nii_D01Onii_D9o`000005oo[BW_l0003omLJLooG6W?l000000oo__9/0
1Ol0003ojKBKonVdVooY]9_o000000Coi:jM00?o0000omnUV?oOYIP00ooOYIP00ol0003ofJ6KomVQ
V`02omVQV`03o`000?o=UI[o000000KodIVJ0_l00005olN@V`03o`000?niPYWo^H:I00;o^H:I00?o
0000ok^7W_l000001OnbOY/00ol0003oYgBJojMdVP03ojMdVP03o`000?nHIiSoV6NH00?oV6NH00?o
0000ohIJU_n6FYH00_n6FYH01Ol0003oM4fEogA=UOmdCIGo000000CoI4>E00?o0000oeLmUomG?IL0
0_l00003oc0QS@Oo000000Co587Vo`000?l0003o00001Omg_?`01?l0003oYL[cojG:lonUb_<3o`00
00Ko`LcS00Co0000ol76g_o1a]ko00000ooCbM000ol0003odL?=om73c@04om73c@03o`000?oI_;co
fKbl00?ofKbl00Co0000omBg_OoD]kgo00000ooL/jl00ol0003oe[2bomJ`/P03omJ`/P03o`000?oJ
ZjKo000000KodjR[00?o0000oljPZ?o>X:P01_o>X:P00ol0003oaiVXolNIZ004olNIZ004o`000?o4
TZ;oa9:Ro`0000Co_Y>Z00?o0000okZ<Y_njS:H01?njS:H00ol0003o/hBRo`000004ok28Z`03o`00
0?nXPJWoZ86Y00?oZ86Y00?o0000oj1iZ?nPNJP01?nPNJP00ol0003oUg:XoiMbZ002oiMbZ003o`00
0?n=KJSoSFfX00?oSFfX00?o0000ohEXZon5J:/01?n5J:/00ol0003oOVN^ogiW[P02ogiW[P03o`00
0?miIk?oNFNc00?oNFNc00?o0000ogI[^OmfJkT00_mfJkT2o`0000CoIf6h00?o0000ofY[`_mZJl80
0_mZJl800ol0003oKgS;ofmhb`03ofmhb`?o00000_mXNM000ol0003oLXOIog:7f@03og:7f@03o`00
0?mkU>3oNiCP00?oNiCP00?o0000oh>OiOn3WnD00on3WnD00ol0003oRJOXohVWj003ohVWj003o`00
0?n?[N[oSjgZ00GoSjgZ00?o0000oi>ak?nC/N`01?nC/N`01?l0003oU[G]o`000?nF]Nd4o`0001_o
oo]Z00?o0000oookJ_oonfX02_oonfX004Sooo]Z0_l00006oookJP03o`000?nXaNkoZ<G^00?oZ<G^
0ol00007ojW5kP03o`000?nYaNko000000;o00000onYa^h00ol0003oZ/K^oj[6kP04oj[6kP?o0000
1on[anh00ol0003o[<O^o`000002o`0000?o[<O^00?o0000ojg8kOn]b>d01?n]b>d3o`0000Ko[/W]
00Co0000ojo9kOl0003o00001_n`b^d00ol0003o/L_]o`000002o`0000?o//c]00?o0000ok?<kOnc
c>d00_ncc>d2o`0000;o/lk]00?o0000okG?kOnecnd00_necnd2o`0000?o]]7^00?o0000okSBkOnh
d^d00_nhd^d2o`0000?o^=G_00Co0000ok[Fk_l0003o00001_nig?43o`0000Co^NKe0_l00002ok?a
m@;o000000CoWOCTo`000?l0003o00000_ojdYh01?l0003omLJLooG6W?l00003onnlV`05o`000?oY
]9_ojKBKonVdVol000001?oT[Yd00ol0003ogjFHomnUV002omnUV003o`000?oIXI_ofJ6K00CofJ6K
0_l00006om6IVP;o00001Oo7T9/00ol0003o^H:IokV2V@02okV2V@03o`000?nkQiko000000Go/WjK
00?o0000ojMdV_nWM9X00onWM9X00ol0003oV6NHoiQWV003oiQWV003o`000?n6FYKoQUZF00;oQUZF
00Go0000ogA=UOmdCIGoM4fEo`000004ofA3U@03o`000?mG?IOoEcfG00;o00000ol`8Hd2o`000003
o`00P?l0003o000000?o00000olDPNH9o`0000?oY/G_00Co0000ol7<hoo1c>?o`LcS0_l00004ol76
gP03o`000?oCbM3o000000KodL?=0_l00005omVl_007o`000?oD]kgoe;NmomBg_Ol0003og;>_o`00
0007omJ`/P03o`000?oCZ:_odjR[00CodjR[0_l00008oljPZ003o`000?o7VJSoaiVX00GoaiVX0_l0
0005okjCZP03o`000?njS:Ko^XbV00Co^XbV0_l00005ok28Z`03o`000?nXPJWoZ86Y00?oZ86Y00?o
0000oj1iZ?nPNJP01?nPNJP00ol0003oUg:XoiMbZ002oiMbZ003o`000?n=KJSoSFfX00?oSFfX00?o
0000ohEXZon5J:/01?n5J:/00ol0003oOVN^ogiW[P02ogiW[P03o`000?miIk?oNFNc00?oNFNc00?o
0000ogI[^OmfJkT00_mfJkT00ol0003oMW;1o`000002o`000003ofMQ^?l0003oJV_200?oJV_200?o
0000ofmhbom_N</00om_N</00ol0003oMXCDogJ4e003o`0000GoLXOI00?o0000og^Dh?mkU>001?mk
U>000ol0003oPioUoh>Oi@03oh>Oi@03o`000?n9YnSoRJOX00?oRJOX00?o0000ohn]j_n?[NX01?n?
[NX00ol0003oTk7/oi>ak002oi>ak0Ko00000onH]^`00ol0003ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z00[ooo]Z001:oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000ojS5k_l000000_l00003
ojS5kP03o`000?nYaNkoZLG^00CoZLG^0ol00006ojW6kP03o`000?nZa^koZ/K^00?o00000onZa^h0
0ol0003oZlO^oj_7kP04oj_7kP;o00001on/anh00ol0003o[LS]ojg8k@03o`0000?o[LS^00?o0000
ojk9kOn^bNd00on^bNd3o`0000Oo/<[]0_l00007ok;<k@04o`000?ncc>go0000o`0000Go/lk]00Co
0000okG?kOl0003o00001_nfdNh01?l0003o^=;]o`000?l00005okSEk`?o00001Onig?42o`0000?o
^NCd00Co0000okWVmOl0003o00000_nclOD2o`0000;oWOCT0_l000001?olgj?o0000oo[BW_l00003
ooG6W005o`000?o__9_okkbKonnlVol000000ooY]9/00ol0003oi:jMonB^W@02onB^W@03o`000?oO
YISogjFH00;ogjFH00?o0000omVQVooIXI/01?oIXI/00ol0003odIVJom6IVP05om6IVP03o`000?o7
T9_oai2K00Coai2K00Go0000okV2VOniPYWo^H:Io`000003ok^7WP03o`000?nbOY_o/WjK00;o/WjK
00?o0000ojMdV_nWM9X01?nWM9X00ol0003oV6NHoiQWV002oiQWV003o`000?n6FYKoQUZF00;oQUZF
00Go0000ogA=UOmdCIGoM4fEo`000004ofA3U@03o`000?mG?IOoEcfG00;o00000ol`8Hd00ol0003o
:bFFo`000008o`000003oaB1i_l0003oMkCi00CoMkCi00?o0000ojK5konVaNl00onVaNl00ol0003o
`LcSo`000006ol76gP;o00001_oA`ld01?l0003ocKg;olfmbol00003omVl_003o`000?oD]kgoe;Nm
00;oe;Nm00?o0000ombc[ol000001ooF/;800ol0003odjR[om>XZ`04om>XZ`03o`000?o=Y[7o0000
00KocZ2X0_l00007olNIZ0;o00001OnnTjX00ol0003o^XbVokZ<YP04okZ<YP03o`000?n`R:_o/8R[
00Co/8R[00?o0000ojR1ZOnXPJT00onXPJT00ol0003oX7VXoj1iZ004oj1iZ003o`000?nGLZSoUg:X
00?oUg:X00?o0000ohe]Z?n=KJP00on=KJP00ol0003oQFR[ohEXZ`03ohEXZ`03o`000?mnIjkoOVN^
00?oOVN^00?o0000ogUW/omiIk<00_miIk<00ol0003oMV^iogI[^@03ogI[^@04o`000?mfL/7oMW;1
ogIb`@?o00001?mZJl800ol0003oKgS;ofmhb`03ofmhb`03o`000?mfQ=CoMXCD00;oMXCD1?l00000
0ombQmWo0000og^Dh005og^Dh003o`000?n3WnGoPioU00?oPioU00?o0000ohVWj?n9YnP01?n9YnP0
1?l0003oSjgZohn]j_n?[NX7o`0000?oUK;[00?o0000oiRfk?l000001?nH]^`00ol0003ooo]Zoook
JP0HoookJP03o`000?oonf[ooo]Z00[ooo]Z001;oookJP03o`000?oonf[ooo]Z00Cooo]Z0_l00006
ojS5kP03o`000?nYaNkoZLG^00?o00000onYaNh00ol0003oZLK^ojW6kP03ojW6kP?o00001onZa^h0
0ol0003oZlO^oj_7kP03o`0000;oZlO^00?o0000ojc7k_n/anh01?n/anh3o`0000Oo[LS^00?o0000
ojk9kOl000000_l00003ojo9k@03o`000?n`b^go/<[]00;o/<[]0_l00002ok3;k@03o`000?nbc>go
//c]00Co//c]0ol00006ok?>k@?o00001onfdNh3o`0000Co^=G_0_l00003okSJl@;o000000?o^Mca
o`000?l000001Onii?@;o`0000;oo=nS00?o0000oo[BW_l000000ooeaY`01?l0003okkbKonnlVol0
0003onVdV`03o`000?oT[Ygoi:jM00;oi:jM00?o0000omjZWol000000ooOYIP00ol0003ofJ6KomVQ
V`04omVQV`03o`000?oAVI[odIVJ00GodIVJ00?o0000olN@Voo7T9/01Oo7T9/01?l0003o^H:IokV2
VOl00003ok^7WP03o`000?nbOY_o/WjK00;o/WjK00?o0000ojMdV_nWM9X01?nWM9X00ol0003oV6NH
oiQWV002oiQWV003o`000?n6FYKoQUZF00;oQUZF00?o0000ogA=UOmdCID00_mdCID01Ol0003oI4>E
ofA3UOmT@iGo000000?oEcfG00Ko0000oc0QSOl`8Hgo<26=o`000?l[9IH8o`000004ob5miol0003o
0000o`0000GoMkCi00Co0000ojK5konVaNooY/G_0ol00006ol76gP03o`000?no`=[o000000GodL?=
00?o0000olfmboo=_L/00_o=_L/01?l0003ofKblomVl_?l00005omBg_@03o`000?oF/;;oe[2b00Go
e[2b00?o0000om2]]_l000001?oCZ:/01?l0003ocJJaolfV/Ol00005oljPZ004o`000?o8X:oob:2_
o`0000KoaiVX00?o0000okjCZ_nnTjX01?nnTjX00ol0003o^XbVokZ<YP04okZ<YP03o`000?n`R:_o
/8R[00Co/8R[00?o0000ojR1ZOnXPJT01?nXPJT00ol0003oX7VXoj1iZ003oj1iZ003o`000?nGLZSo
Ug:X00?oUg:X00?o0000ohe]Z?n=KJP00on=KJP00ol0003oQFR[ohEXZ`03ohEXZ`03o`000?mnIjko
OVN^00?oOVN^00?o0000ogUW/omiIk<00omiIk<00ol0003oMV^iogI[^@02ogI[^@03o`000?mfL/7o
MW;100?oMW;10ol00002ofY[`P03o`000?m_N<_oKgS;00?oKgS;00?o0000ogJ4e?mfQ=@00_mfQ=@0
1?l0003oO93Kogb@fomlT=/Io`0000?oTZkZ00?o0000oiFbjonE/^/01OnE/^/00ol0003oV;K/o`00
0004oiRfk003o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX02_oonfX004cooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003oZ<G^ojS5kP03ojS5kP?o00001onYaNh00ol0003oZLK^o`000002
o`0000?oZ/K^00?o0000oj[6k_nZa^h01?nZa^h3o`0000KoZlO^00?o0000ojc7k_n/anh00ol00003
ojc8kP03o`000?n]b>ko[LS^00Co[LS^0_l00007ojo9k@04o`000?n`b^go0000o`0000Go/<_]00?o
0000ok;<kOnbc>d00ol00003ok;=kP;o000000Co/lk]o`000?l0003o00000ondd>h2o`0000;o]]7^
0ol00003okKDk`;o000000?o^=G_o`000?nhf_401Onhf_43o`0000Co^NCd0_l00003okK^mP03o`00
0?n/mngo[?O]00?o000000Cohnj>o`000?olgj?o00000_ojdYh01?l0003omLJLooG6W?l00003onnl
V`05o`000?oY]9_ojKBKonVdVol000001?oT[Yd00ol0003ogZZOo`000003omnUV003o`000?oIXI_o
fJ6K00CofJ6K00?o0000om6IV_oAVIX01OoAVIX00ol0003oai2KolN@V`05olN@V`03o`000?niPYWo
000000Co^hNN00?o0000ok9nVonbOY/00_nbOY/00ol0003oYgBJojMdVP04ojMdVP03o`000?nHIiSo
V6NH00;oV6NH00?o0000ohIJU_n6FYH00_n6FYH00ol0003oM4fEogA=U@02ogA=U@03o`000?mT@iGo
I4>E00;oI4>E00Co0000oeLmUomG?IOo00000ol`8Hd01ol0003o:bFFo`000?l0003o0`n@o`000?l0
0Xl01?l00003ob5mi`Wo00000onV_^/01?l0003o`LKNol76g_o1a]h2o`0000?o_l3J00Go0000om73
cOoA`lgodL?=o`000005olfmb`03o`000?oI_;co000000Koe;Nm00?o0000omJ`/_oF/;801?oF/;80
1?l0003od:ffom2]]_l00004om>XZ`04o`000?o=Y[7ocJJao`0000GocZ2X00Co0000olRP[oo8X:oo
00001_o7VJP00ol0003o_Y>ZokjCZP05okjCZP03o`000?njS:Ko^XbV00;o^XbV0_l00007ok28Z`03
o`000?nXPJWoZ86Y00?oZ86Y00?o0000oj1iZ?nPNJP01?nPNJP00ol0003oUg:XoiMbZ00=o`0000;o
QFR[00?o0000ogiW[_mnIjh00_mnIjh00ol0003oNFNcogUW/`03ogUW/`03o`000?mfJkWoMV^i00;o
MV^i00?o0000ogIb`OmfL/400omfL/400ol0003oN7_9ogQkb@03o`0000GoKgS;00?o0000ogJ4e?mf
Q=@00omfQ=@00ol0003oO93Kogb@f`02ogb@f`03o`000?n3V^7oPi[Q00CoPi[Q00?o0000ohVSiOn9
XnD00on9XnD00ol0003oSZWXohjYj004ohjYj003o`000?nB[^[oTZkZ00CoTZkZ00?o0000oiFbjonE
/^/01?nE/^/01Ol0003oV;K/oiRfk?l0003oV;K/00Co00006?oonfX00ol0003ooo]ZoookJP0:oook
JP00COoonfX2o`0000Kooo]Z00?o0000ojS5k_l000000_l00003ojW5kP03o`000?nYaNkoZLG^00Co
ZLG^0ol00006oj[6kP03o`000?nZa^koZ/K^00?o00000on[a^h00ol0003oZlO^oj_7kP03oj_7kP?o
00001on/b>h00ol0003o[LS^ojg8kP03o`0000;o[/W^00?o0000ojo9kOn_bNd01?n_bNd3o`0000Ko
/<_]0ol00007ok;=kP?o00001_ndd>h3o`0000Oo]]C_0ol00004okSJl@;o00000onih_@2o`000003
okWTm?l0003o]^kf00;o]^kf0_l000000on/mngo0000o`000005o`000005oocOXol0003on]:Noo[B
W_l000000_oeaY`01Ol0003okkbKonnlVoo__9_o000000?ojKBK00?o0000onB^WOoT[Yd00_oT[Yd0
0ol0003ogZZOo`000003omnUV003o`000?oIXI_ofJ6K00CofJ6K00?o0000om6IV_oAVIX01OoAVIX0
0ol0003oai2KolN@V`05olN@V`03o`000?niPYWo000000Co^hNN00?o0000ok9nVonbOY/00_nbOY/0
0ol0003oYgBJojMdVP04ojMdVP04o`000?nHIiSoV6NHoiQWV0Go000000?oQUZFo`000?mdCID00omd
CID00ol0003oI4>EofA3U@02ofA3U@03o`000?mG?IOoEcfG00;o00000_l`8Hd01ol0003o:bFFob/U
U_l0003o0`n@o`000?l00Xl01ol000000olQONOo0000ogZ]l`03ogZ]l`03o`000?nV_^_oY[k[00Co
Y[k[00?o0000ol76g_l000001_no`=X00ol0003odL?=o`000006olfmb`;o00001_oD]kd00ol0003o
ck>no`000004omJ`/P05o`000?o@[KKod:ffom2]]_l000000ooCZ:/00ol0003ocJJaolfV/@02olfV
/@05o`000?o>X:SocZ2XoljPZ?l000000oo8X:l00ol0003oaiVXolNIZ003olNIZ0;o00001onnTjX0
1Ol0003o^XbVokZ<Y_njS:Ko000000;o]Xn^00?o0000ok28Zon`R:/01?n`R:/00ol0003oZ86YojR1
Z@03ojR1Z@03o`000?nPNJSoX7VX00?oX7VX1?l00002oiYm/@03o`000?nCNK;oTgVb00?oTgVb00?o
0000ohef]On=M[D00_n=M[D6o`0000;oOVN^00?o0000ogUW/omiIk<00_miIk<00ol0003oMV^iogI[
^@03ogI[^@03o`000?mfL/7oMW;100;oMW;100?o0000ogQkbOmhNlT00omhNlT4o`0000;oKgS;00?o
0000ogJ4e?mfQ=@00omfQ=@00ol0003oO93Kogb@f`02ogb@f`03o`000?n3V^7oPi[Q00CoPi[Q00?o
0000ohVSiOn9XnD00on9XnD00ol0003oSZWXohjYj004ohjYj003o`000?nB[^[oTZkZ00CoTZkZ00Co
0000oiFbjonE/^_oUK;[1ol00003oiVgk003o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
2_oonfX004oooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000KoZLG^00?o0000ojW5k_nYaNh00ol0
0003ojW5kP03o`000?nZa^koZ/K^00?oZ/K^0ol00007oj_6kP03o`000?n[anko000000;o00000on/
anh00ol0003o[<S^ojc8kP04ojc8kP?o00001_n^bNh00ol0003o[lW]ojo9k@03o`0000?o[l[^00Co
0000ok3;kOn`bngo/<_]0_l00003ok7<kP03o`000?nbcNko//g^00;o//g^0_l00003ok??kP04o`00
0?ndd>ko]=3^okC@kP;o00000onednl00ol0003o]]C_okKDk`02okKDk`;o00000ongfO401?l0003o
^=[ao`000?l00006okWRm0Co000000?o]^kfo`000?l000001_l000001ooSkXko0000oocOXoolgj?o
0000oo[BW_l000000ooeaY`01Ol0003okkbKonnlVoo__9_o000000?ojKBK00?o0000onB^WOoT[Yd0
0_oT[Yd00ol0003ogZZOo`000002omnUV003o`000?oIXI_ofJ6K00GofJ6K00?o0000om6IV_oAVIX0
1?oAVIX2o`0000Ooai2K00?o0000okV2VOl000001?nkQih00ol0003o/WjKok9nV`03ok9nV`03o`00
0?nWM9[oYgBJ00?oYgBJ1?l000000onJKYoo0000oheTWP02oheTWP?o00000omdCID00ol0003oI4>E
ofA3U@02ofA3U@03o`000?mG?IOoEcfG00;o00000_l`8Hd00ol0003o:bFFob/UUP04o`000003o`02
Sol0003o00fM00;o00000_lfOND3o`0000CoNZgc00?o0000ojJnjonV_^/00onV_^/2o`0000Oo_l3J
0_l00006olfmb`03o`000?o9^<[o000000Goe;Nm00Co0000olnc__o?/kko00001?oF/;800ol0003o
d:ffom2]]P02om2]]P04o`000?oCZ:_odjR[o`0000CocJJa00Co0000oljPZ?o>X:So00001Oo8X:l0
1Ol0003oaiVXolNIZ?o7VJSo000000;o`IZ`00?o0000okjCZ_nnTjX01?nnTjX01?l0003o^XbVokZ<
Y_l00003okJ?[P03o`000?n`R:_o/8R[00Co/8R[00?o0000ojR1ZOnXPJT00onXPJT01?l0003oX7VX
oj1iZ?nPNJP2o`000003oj62/Ol0003oVWfa00CoVWfa00?o0000oi=i/_nCNK800onCNK800ol0003o
SGJeohef]@03ohef]@04o`000?n8M[SoR7JhohQf^0Ko00000_miIk<00ol0003oMV^iogI[^@02ogI[
^@03o`000?mfL/7oMW;100?oMW;100?o0000ogQkbOmhNlT00_mhNlT01?l0003oNhCAog^4dOmkQ=47
o`000003ogJ4e?l0003oO93K00CoO93K00?o0000oh>JhOn3V^400on3V^400ol0003oRJ?UohVSi@04
ohVSi@03o`000?n>ZNSoSZWX00?oSZWX00?o0000oi:^j_nB[^X00_nB[^X6o`0000?oUkC[00Co0000
oiVgk?nI]nco00001?nI]n`00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00[ooo]Z001@
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000ojW5k_nYaNh00onYaNh3o`0000OoZLG^00?o0000
oj[6k_l000000_l00002oj[6kP03o`000?n[a^koZlK^00GoZlK^0_l00007ojc7kP03o`000?n/b>ko
[<S^00?o00000on]b>h00ol0003o[/W^ojk9kP03ojk9kP?o00001on_b^h00ol0003o/<_]o`000006
ok7<kP04o`000?nbcNko0000o`0000Ko/lo^00?o0000okC@k_l000001_nednl01?l0003o]]C_o`00
0?l00005okOIl@?o00001Onih_@2o`0000?o^N_e1?l000000on[nMoo0000o`000005o`0000;oo=nS
00?o0000oo[BW_l000000ooeaY`01?l0003okkbKonnlVol00003onVdV`03o`000?oT[Ygoi:jM00;o
i:jM00Oo0000omjZWooNZYoogZZOo`000?oOYISo000000KofJ6K0_l00006om6IVP;o00001oo7T9/2
o`0000Go^hNN00?o0000ok9nVonbOY/00onbOY/00ol0003oYgBJojMdVP03ojMdVP03o`000?nJKYoo
VVjO00;oVVjO00?o0000oheTW_n=I9h00_n=I9h00ol0003oOebOo`000002ogA=U@03o`000?mT@iGo
I4>E00;oI4>E00Co0000oeLmUomG?IOoEcfG0_l000001?l`8Hgo0000ob/UU_l[9IH2o`000005o`<?
T?l0003o00:?o`000?l03Id00ol00004ocImi@Co000000?oNZgco`000?nV_^/00ol000000onV^>Ko
0000oko0fP05oko0fP03o`000?nm^]Oo000000GocKg;00Go0000olVhb_o9^<[obKS:o`000003omBg
_@03o`000?o?/kkock>n00;ock>n00Co0000omJ`/_oF/;;o00001Oo@[KH00ol0003odjR[o`000005
olfV/@04o`000?o>X:SocZ2Xo`0000Gob:2_00Go0000olNIZ?o7VJSoaiVXo`000002ol6J/003o`00
0?nnTj[o_Y>Z00Go_Y>Z0_l00004okJ?[P03o`000?n`R:_o/8R[00Co/8R[00?o0000ojR1ZOnXPJT0
1?nXPJT3o`0000?oXH:a00?o0000oiYm/OnJOK400onJOK400ol0003oTgVboi=i/P03oi=i/P03o`00
0?n=M[GoSGJe00?oSGJe00?o0000ohQf^?n8M[P00on8M[P01?l0003oQ7NmohAg_On4Mkd5o`0000;o
MV^i00?o0000ogIb`OmfL/400omfL/400ol0003oN7_9ogQkb@03ogQkb@03o`000?mkQ=7oNhCA00;o
NhCA00?o0000oh2>f?n0S]P00_n0S]POo`0000?oUK3Z00?o0000oiNdjonG]>/01?nG]>/01?l0003o
VKO/oiVgk?l00003oiVgk0;o00005ooonfX00ol0003ooo]ZoookJP09oookJP00DOoonfX00ol0003o
oo]ZoookJP05oookJP03o`000?nYaNko000000;o00000onYaNh00ol0003oZLG^ojW5kP04ojW5kP;o
00001_nZa^h00ol0003oZlK^oj_6kP02oj_6kP;o00000_n[anh00ol0003o[<O^ojc7kP04ojc7kP?o
00001on]b>h00ol0003o[/W^o`000002o`0000?o[/W^00?o0000ojo:k_n_b^h01?n_b^h3o`0000Ko
/Lc^0ol00007ok??kP;o00001onednl3o`0000Co]mWa0_l00003okWNl`;o000000?o^N;do`000?l0
00000onijoD2o`000004okOel_l0003o0000oj_ig`;o000000?oZ?2]o`000?l000000_l00002oocO
X`04o`000?ojdYkon]:No`0000?omLJL00Co0000onnlVoo__9_o00000ooY]9/00ol0003oi:jMonB^
W@02onB^W@07o`000?oNZYoogZZOomjZWol0003ogjFHo`000006omVQV`;o00001_oAVIX2o`0000Oo
ai2K0_l00005ok^7WP03o`000?nbOY_o/WjK00?o/WjK00?o0000ojMdV_nWM9X00onWM9X00ol0003o
VVjOoiY^W`02oiY^W`03o`000?n=I9koSFBN00;oSFBN00Ko0000ogmLWomoG9oo0000ogA=UOl00004
ofA3U@04o`000?mG?IOoEcfGoeLmU`;o000000?o<26=o`000?l[9IH00_l[9IH00ol0003o0`n@o`00
0002o`02S`05o`000?l03Igo0000o`0k_ol000000olfOND01?l0003oOZO]ogjWkOmnYnd3o`0000Go
Y[SV00Co0000oko0f_no`=[o_l3J0_l00003okfje`05o`000?o=_L_ocKg;olfmbol000001Oo9^<X0
1?l0003oe;NmomBg_Ol00004olnc_P03o`000?oF/;;o000000Kod:ff00?o0000om>XZol000001_o=
Y[42o`0000Kob:2_00Co0000olNIZ?o7VJSo00000oo1V[000ol0003o_Y>ZokjCZP05okjCZP03o`00
0?nfSjko]Xn^00?o]Xn^00?o0000ok28Zon`R:/01?n`R:/00ol0003oZ86YojR1Z@03ojR1Z@;o0000
1_nQP[400ol0003oVWfaoiYm/@02oiYm/@03o`000?nCNK;oTgVb00?oTgVb00?o0000ohef]On=M[D0
1?n=M[D00ol0003oR7JhohQf^003ohQf^003o`000?n4MkgoQ7Nm00;oQ7Nm00?o0000oh9k`on2Nl<0
1?l00004ogIb`@03o`000?mhNlWoN7_900?oN7_900?o0000og^4dOmkQ=400omkQ=400ol0003oP8kH
oh2>f003oh2>f003o`000?n5UmgoQIOM00?oQIOM00?o0000ohVOh_n9Wn800on9Wn800ol0003oSZKV
ohjViP04ohjViP03o`000?nA[>SoTJcX00CoTJcX00?o0000oiF`j_nE/>X01?nE/>X00ol0003oUkC[
oiNdj`04oiNdj`03o`000?nI]nco000000?o000000?oVkO/o`000?oonfX05_oonfX00ol0003ooo]Z
oookJP09oookJP00D_oonfX2o`0000Kooo]Z0_l00006ojW5kP03o`000?nYaNkoZLG^00?o00000_nY
a^h00ol0003oZ/K^oj[6kP04oj[6kP04o`000?n[a^ko0000o`0000GoZlO^00Co0000ojc7k_n/anko
[<O^0_l00003ojc8kP03o`000?n]b>ko[LS^00Co[LS^0ol00006ojk9kP03o`000?n_b^ko[l[^00?o
00000on`bnh2o`000004ok7<k_l0003o0000o`0000?o/Lk^00?o0000ok??k_nccnh00_nccnh2o`00
00;o]=7_00?o0000okGCkonednl00_nednl2o`0000?o]]Ka0_l000000ongfO7o0000okWNl`05okWN
l`Co00000_nijoD00ol0003o]oGbokOelP05o`000003ojS`[Ol0003o000000?o00000_olgj<00ol0
003on]:No`000003ooG6W005o`000?o__9_okkbKonnlVol000000ooY]9/00ol0003oi:jMonB^W@02
onB^W@07o`000?oNZYoogZZOomjZWol0003ogjFHo`000006omVQV`03o`000?oCWZ3o000000CodIVJ
00Co0000ol^GWoo;Uioo00001_o7T9/2o`0000Go^hNN00?o0000ok9nVonbOY/00onbOY/00ol0003o
YgBJojMdVP02ojMdVP;o00001?nJKYl00ol0003oSFBNoheTWP02oheTWP04o`000?moG9ooOebOogmL
W`;o00001?mT@iD02Ol0003oEcfGoeLmUomG?IOo0000odhlW?l0003o<26=o`000002ob/UUP06o`00
0?l33i3o0000o`000?l00Xoo00000_l03Id5o`000003ocImiOl0003oOZO]00CoOZO]00?o0000ojJh
i_nV^>H00onV^>H00ol0003o_l3Jo`000006okfje`03o`000?o=_L_o000000KobKS:00?o0000omBg
_Ol000001_o?/kh00ol0003od:ffom2]]P06om2]]P03o`000?o=Y[7ocJJa00GocJJa00?o0000olRP
[oo8X:l01Oo8X:l01?l0003oaiVXolNIZ?l00003ol6J/003o`000?nnTj[o_Y>Z00Go_Y>Z00?o0000
okJ?[_nfSjh01?nfSjh00ol0003o/8R[ok28Z`04ok28Z`03o`000?nXPJWoZ86Y00;o000000?oZ8Rb
o`000?nQP[401OnQP[400ol0003oVWfaoiYm/@03oiYm/@03o`000?nCNK;oTgVb00?oTgVb00?o0000
ohef]On=M[D00on=M[D00ol0003oR7JhohQf^003ohQf^003o`000?n4MkgoQ7Nm00?oQ7Nm00?o0000
oh9k`on2Nl<00_n2Nl<4o`0000;oMW;100?o0000ogQkbOmhNlT00omhNlT00ol0003oNhCAog^4d@02
og^4d@03o`000?n0S]SoP8kH00CoP8kH00?o0000ohFGgOn5Umd00on5Umd00ol0003oRIoRohVOhP03
ohVOhP03o`000?n>Y^KoSZKV00CoSZKV00?o0000oi6/j?nA[>P01?nA[>P00ol0003oUK3ZoiF`jP03
oiF`jP03o`000?nG]>_oUkC[00;oUkC[1_l00004oi^gk003o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX02OoonfX005Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003oZLG^ojW5kP03ojW5
kP?o00001_nYa^h00ol0003oZ/K^oj[6kP03oj[6kP?o00001on[anh00ol0003o[<O^o`000006ojc8
kP03o`000?n]b>ko[LS^00?o00000on]bNh00ol0003o[/W^ojk9kP03ojk9kP?o00001on`bnh2o`00
00Oo/Lk^00Co0000ok??k_l0003o00001OnddNl01?l0003o]M?_o`000?l00006okKFl@?o00001?ni
g_<2o`0000Co^^Kd1ol000000ongo=Ko0000o`000003o`000003oo7e]ol0003o000000;oo=nS2?l0
0002onnlV`05o`000?oY]9_ojKBKonVdVol000001?oT[Yd01ol0003ogZZOomjZWooNZYoo0000omnU
V?l000001OoIXI/01?l0003odijPom>NX?l00004om6IVP04o`000?o;UioobiNOo`0000Koai2K00?o
0000ok^7W_nkQih01?nkQih00ol0003o/WjKok9nV`03ok9nV`07o`000?nWM9[oYgBJojMdV_l0003o
YWRPo`000005oiY^W`05o`000?n=I9koSFBNoheTW_l000001?moG9l00ol0003oI4>EofA3U@02ofA3
U@09o`000?mG?IOoEcfGoeLmUol0003oCSbLo`000?l`8Hgo000000;o:bFF0_l000002Ol33i3o0000
o`000?l00Xoo0000o`0=WOl0003o7E79o`000002od]ohP?o00001OmnYnd01?l0003oY[SVojJhi_nV
^>H3o`0000Oo_K[G0_l00007olVhbP;o00001oo?/kh00ol0003od:ffom2]]P06om2]]P03o`000?o=
Y[7ocJJa00GocJJa00?o0000olRP[oo8X:l01_o8X:l2o`0000Go`IZ`00?o0000okjCZ_nnTjX00onn
TjX2o`0000Ko]Xn^00?o0000ok28Zon`R:/01?n`R:/3o`0000?oZ8Rb00?o0000oj62/OnQP[401?nQ
P[400ol0003oVWfaoiYm/@03oiYm/@03o`000?nCNK;oTgVb00?oTgVb00?o0000ohef]On=M[D00on=
M[D00ol0003oR7JhohQf^003ohQf^003o`000?n4MkgoQ7Nm00?oQ7Nm00?o0000oh9k`on2Nl<00_n2
Nl<01?l0003oPX79oh:1bOn2PLT7o`000003ogQkbOl0003oNhCA00CoNhCA00?o0000oh2>f?n0S]P0
0on0S]P00ol0003oQIOMohFGg@04ohFGg@03o`000?n9Wn;oRIoR00?oRIoR00?o0000ohjVi_n>Y^H0
0on>Y^H00ol0003oTJcXoi6/j002oi6/j0go00000onI]N/01?l0003oVkO/oi^gk?l00003oi^gk003
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX02OoonfX005Gooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003oZLG^o`000002o`0000;oZLG^00?o0000ojW6k_nYa^h01OnYa^h00ol0003oZ/K^
o`000002o`0000?oZ/K^00?o0000oj_7k_n[anh01?n[anh3o`0000Ko[<S^0ol00007ojg9kP03o`00
0?n^bNko000000;o00000on_b^h00ol0003o/<_^ok3;kP02ok3;kP;o00000_n`c>h00ol0003o/Lk^
ok7>kP04ok7>kP?o00001_nddNl3o`0000Go]]Ka0_l00003okSKlP04o`000?nig_?o0000o`0000Co
^^Kd0_l00002okc`l`05o`000?nlnNco_?W/o`000?ngo=H02?l00002oocOX`;o000000?olm:_o`00
0?o_b:X00_o_b:X01?l0003ojknWo`000?l00003onVdV`03o`000?oT[Ygoi:jM00;oi:jM00?o0000
omjZWooNZYl00ooNZYl00ol0003ofJ6KomVQV`04omVQV`04o`000?oCWZ3odijPo`0000CodIVJ00Co
0000ol^GWoo;Uioo00001_o7T9/00ol0003o^hNNok^7WP04ok^7WP03o`000?nbOY_o/WjK00?o/WjK
00Co0000ojMdV_nWM9[o00000_nVN:000ol0003oVVjOoiY^W`03oiY^W`03o`000?n=I9koSFBN00;o
SFBN00Co0000ogmLWomoG9ooOebO0_l00003ofA3U@05o`000?mG?IOoEcfGoeLmUol000000_m>?9`2
o`0000?o:bFF00Go0000o`<?T?l0003o0000o`02S`02o`000004o`0=WOl0003o7E79o`0000CoBgoR
2Ol00002ojJch@03o`000?nm^]Oo_K[G00Co_K[G00?o0000okZfeOl000001_o9^<X00ol0003oaKC:
o`000006olnc_P03o`000?o9/<7o000000Kod:ff00?o0000olV[^ol000001Oo=Y[400ol0003oajFg
o`000007olRP[`03o`000?o1V[3o`IZ`00Co`IZ`00?o0000okjCZ_nnTjX00_nnTjX01?l0003o^YJc
okZF/ol00005okJ?[P03o`000?n`R:_o/8R[00?o/8R[0_l00006ojR8/P03o`000?nQP[7oXH:a00?o
XH:a00?o0000oiYm/OnJOK400onJOK400ol0003oTgVboi=i/P03oi=i/P03o`000?n=M[GoSGJe00Co
SGJe00?o0000ohQf^?n8M[P00on8M[P00ol0003oQ7NmohAg_@02ohAg_@03o`000?n2Nl?oPW_300?o
PW_300?o0000oh:1bOn2PLT00_n2PLT00ol0003oPhO?oh>7c`02oh>7c`Ko000000?oNhCAo`000?n0
S]P01?n0S]P00ol0003oQIOMohFGg@04ohFGg@03o`000?n9Wn;oRIoR00?oRIoR00Co0000ohjVi_n>
Y^KoSZKV1ol00003oiF^j003o`000?nG/^[oUk;Z00CoUk;Z00?o0000oiVejonI]N/01?nI]N/00ol0
003oVkO/oi^gk005o`0001Gooo]Z00?o0000oookJ_oonfX02OoonfX005Kooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003oZLG^ojW5kP04ojW5kP03o`000?nYa^koZLK^00CoZLK^0ol00006oj[6kP03
o`000?n[ankoZlO^00?o00000on[anh01?l0003o[<S^ojc8k_n/b>h2o`0000?o[LS^00?o0000ojg9
k_n]bNh01?n]bNh2o`0000Oo[l[^00Co0000ok3;k_l0003o00001On`c>h00ol0003o/Lk^ok7>kP03
o`0000?o/]3_0_l000001?nddNoo0000o`000?l00003okGDl0;o000000?o]]Kao`000?l000001Onh
fo84o`0000;o^^Kd0_l00003okc`l`03o`000?nlnNco_?W/00?o000000?obooEo`000?o?oK/00_l0
00001?oamKOo0000o`000?olgj<2o`000003oo?B[ol0003oklRZ00;oklRZ00Go0000on^oYoo[_jOo
jknWo`000003onVdV`03o`000?oT[Ygoi:jM00;oi:jM00?o0000omjZWooNZYl00ooNZYl00ol0003o
fJ6KomVQV`04omVQV`04o`000?oCWZ3odijPo`0000?odIVJ00Go0000ol^GWoo;UioobiNOo`000005
olN@V`;o00001_nkQih00ol0003o/WjKok9nV`03ok9nV`03o`000?nWM9[o000000?oYWRP00?o0000
oiY^WonJKYl00onJKYl00ol0003oSFBNoheTWP02oheTWP07o`000?moG9ooOebOogmLWol0003oM5FP
o`000002ofA3U@05o`000?mG?IOoEcfGoeLmUol000000_m>?9`2o`0000?o:bFF0ol000001?lG:jKo
0000o`000?l<<[82o`0000;o7E7900Go0000od]oh_m;On;oBgoRo`000005ohBRi`03o`000?nV/n7o
Y[?Q00?oY[?Q00Co0000okfjeonm^]Oo_K[G0_l00003okZfe@03o`000?o9^<[obKS:00;obKS:00Go
0000olFdb_o5]<[oaKC:o`000004olnc_P04o`000?o9/<7obK31o`0000God:ff00Co0000olV[^oo9
Zk_o00001?o=Y[401?l0003oajFgolNU]ol00007olRP[`03o`000?o1V[3o`IZ`00Co`IZ`00Go0000
okjCZ_nnTj[o_Y>Zo`000003okZF/`03o`000?nfSjko]Xn^00?o]Xn^00?o0000ok28Zon`R:/00_n`
R:/00ol0003o[Xjdo`000006ojR8/P03o`000?nQP[7oXH:a00CoXH:a00?o0000oiYm/OnJOK400onJ
OK400ol0003oTgVboi=i/P03oi=i/P03o`000?n=M[GoSGJe00?oSGJe00?o0000ohQf^?n8M[P00on8
M[P00ol0003oQ7NmohAg_@03ohAg_@03o`000?n2Nl?oPW_300;oPW_300?o0000oh:1bOn2PLT00on2
PLT00ol0003oPhO?oh>7c`03oh>7c`04o`000?n5SmKoQHoFohF?eQSo00000onBZ^H00ol0003oUJkX
oiF^j005oiF^j003o`000?nG/^[oUk;Z00CoUk;Z00Co0000oiVejonI]N_oVKG[1_l00004oibhk003
o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX02OoonfX005Oooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003oZLG^ojW5kP04ojW5kP03o`000?nYa^koZLK^00?o00000onZa^h00ol0003oZ/K^
oj[6kP03oj[6kP?o00001on[anh00ol0003o[<S^o`000006ojg8kP03o`000?n]bNko[LW^00?o0000
0_n^bNh00ol0003o[l[^ojo:kP04ojo:kP?o00001_n`c>h3o`0000Oo/]3_0ol00006okGDl0?o0000
1?nhfo82o`0000Co^^;c1?l00002okc`l`03o`000?nlnNco_?W/00;o00000_o;omD01ol0003ocofk
o`000?l0003olOFgo`000?oik:/00_l000001?odgKKo0000oo?B[ol00003ono8ZP05o`000?o[_jOo
jknWon^oYol000000ooY]9/00ol0003oi:jMonB^W@02onB^W@03o`000?oNZYoogZZO00?ogZZO00?o
0000omVQVooIXI/01?oIXI/01?l0003odijPom>NX?l00003om6IVP05o`000?o;UioobiNOol^GWol0
00001Oo7T9/2o`0000Ko^hNN00?o0000ok9nVonbOY/00onbOY/2o`0000CoYWRP00?o0000oiY^WonJ
KYl00onJKYl00ol0003oSFBNoheTWP02oheTWP05o`000?moG9ooOebOogmLWol000000_mdEJ001?l0
003oI4>EofA3UOl00003oeLmU`04o`000?m>?9coCSbLo`0000?o:bFF00Go0000oc0cXol0003o0000
oaL[YP02o`000003o``b/_l0003o000000;o7E790ol000000om;On;o0000ohBRi`04ohBRi`03o`00
0?nV/n7oY[?Q00?oY[?Q00?o0000okfjeol000001_nj]]D01?l0003obKS:olVhb_l00005olFdbP04
o`000?o?/kkock>no`0000CobK3100Go0000om2]]_o@[KKod:ffo`000004olV[^`04o`000?o=Y[7o
cJJao`0000?oajFg00?o0000olRP[oo8X:l01?o8X:l00ol0003o`Z6go`000005ol6J/004o`000?nn
Tj[o_Y>Zo`0000Co^YJc00?o0000okJ?[_nfSjh00onfSjh00ol0003o/8R[ok28Z`02o`0000;o[Xjd
00?o0000ojR8/_nXR;801?nXR;800ol0003oXH:aoj62/@04oj62/@03o`000?nJOK7oVWfa00?oVWfa
00?o0000oi=i/_nCNK800onCNK800ol0003oSGJeohef]@03ohef]@03o`000?n8M[SoR7Jh00?oR7Jh
00?o0000ohAg_On4Mkd00on4Mkd00ol0003oPW_3oh9k``03oh9k``03o`000?n2PLWoPX7900;oPX79
00?o0000oh>7con3Qll01?n3Qll00ol0003oQHoFohF?eP02ohF?eP03o`000?n8Um_oR9OK00?oR9OK
00?o0000ohbNgon<W]l01?n<W]l00ol0003oSjCSohnTh`03ohnTh`03o`000?nBZ^KoTZ[V00CoTZ[V
00?o0000oiF^j?nE[^P01?nE[^P00ol0003oUk;ZoiNbjP02oiNbjPKo00000onK]^/01?l0003oW;S/
oibhk?l00004oibhk003o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX02OoonfX005Sooo]Z
0_l00006oookJP03o`000?nYaNkoZLG^00?oZLG^0ol00007oj[6kP03o`000?nZa^ko000000;o0000
0on[anh00ol0003oZlO^oj_7kP04oj_7kP?o00001_n]b>h3o`0000Ko[/W^00?o0000ojo:k_n_b^h0
0ol00003ojo;kP;o000000Co/<c^o`000?l0003o00000onac^l00ol0003o/]3_ok;@k`02ok;@k`;o
00000ondd_000ol0003o]MC`okGDl003o`0000?o]mSa0_l000000onhfo;o0000ok[Rl`03ok[Rl`;o
00001?nnjO<6o`0000;obooE0ol000000ooWnlOo0000oo7e]`02o`0000;om=ff00Co0000oo?B[ooc
dZoo00000oo_b:X01_l0003ojknWon^oYol0003oi[VVo`0000;ojKBK00Go0000onB^WOoT[Ygoi:jM
o`000006omjZW`03o`000?oIXI_ofJ6K00?ofJ6K00Go0000om>NX?oCWZ3odijPo`000003om6IVP05
o`000?o;UioobiNOol^GWol000001Oo7T9/2o`0000Ko^hNN00?o0000ok9nVonbOY/00onbOY/00ol0
003oYWRPojIhX004ojIhX003o`000?nJKYooVVjO00;oVVjO00?o0000oheTW_n=I9h00_n=I9h00ol0
003oOebOogmLW`02ogmLW`06o`000?mdEJ3oM5FPo`000?mT@iGo00000omG?IL01?l0003oCSbLodhl
W?l00003ob/UUP05o`000?l`<j?o0000o`000?lG:jH00_l00002o``b/P04o`000?lMDLWo7E79o`00
00;oGH;N0ol00005ohBRi`04o`000?nV/n7oY[?QojJch@?o00001onj]]D00ol0003obKS:o`000006
olFdbP03o`000?o?/kko000000GobK3100Co0000om2]]_o@[KKo00001Oo9Zk/01?l0003ocJJaolfV
/Ol00004olNU]`03o`000?o8X:oob:2_00;ob:2_00Co0000ol:Q]oo2XKOo00001_o1V[02o`0000Go
^YJc00?o0000okJ?[_nfSjh01?nfSjh2o`0000Go[Xjd00?o0000ojR8/_nXR;801?nXR;800ol0003o
XH:aoj62/@03oj62/@03o`000?nJOK7oVWfa00?oVWfa00?o0000oi=i/_nCNK800onCNK800ol0003o
SGJeohef]@04ohef]@03o`000?n8M[SoR7Jh00?oR7Jh00?o0000ohAg_On4Mkd00_n4Mkd00ol0003o
PW_3oh9k``03oh9k``03o`000?n2PLWoPX7900?oPX7900?o0000oh>7con3Qll00on3Qll00ol0003o
QHoFohF?eP03ohF?eP03o`000?n8Um_oR9OK00?oR9OK00?o0000ohbNgon<W]l01?n<W]l00ol0003o
SjCSohnTh`03ohnTh`03o`000?nBZ^KoTZ[V00CoTZ[V00Co0000oiF^j?nE[^SoUJkX1ol00003oiVd
jP03o`000?nK]^_oVkK[00CoVkK[00Co0000oibhk?nL^>co00000_nL^>`3o`0001?ooo]Z00?o0000
oookJ_oonfX02?oonfX005[ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003oZLG^o`000002o`00
00?oZLK^00?o0000oj[6k_nZa^h01?nZa^h3o`0000KoZlO^00?o0000oj_7k_n[anh00ol00003ojc7
kP;o000000Co[LS^o`000?l0003o00000on]bNh00ol0003o[/W^ojk9kP03ojk9kP?o00001on_bnh3
o`0000Ko/Lk_00Co0000ok;@kol0003o00001Ondd_03o`0000Oo]mSa1?l000000onjh_?o0000o`00
0004okkYl`;o00000_o2lo000ol0003oao_Wo`000002ol_oe@;o000000CogOcGo`000?l0003olOFg
0ol00002ooCM]P03o`000?ocdZoo000000?oklRZ00Go0000on^oYoo[_jOojknWo`000002onJiYP;o
00001?oT[Yd00ol0003ogZZOomjZW`03omjZW`03o`000?oIYZ?o000000CofJ6K00Go0000om>NX?oC
WZ3odijPo`000002om6IVP03o`000?o;UioobiNO00;obiNO00?o0000olN@Voo7T9/00_o7T9/01?l0
003o`XnQol:?XOl00005ok^7WP03o`000?nbOY_o/WjK00?o/WjK00?o0000ojIhX?nVN:001?nVN:00
0ol0003oVVjOoiY^W`02oiY^W`03o`000?n=I9koSFBN00;oSFBN00?o0000ogmLWomoG9l00_moG9l0
1?l0003oM5FPogAEX?mdEJ02o`0000?oEcfG00?o0000odhlW?m>?9`00_l00003ob/UUP03o`000?l`
<j?o000000;o5b^V00Co0000o``b/_l<<[;o33:b0_l000000olMDLWo0000oef2gP03oef2gPWo0000
0_nV[]d00ol0003o^[KEokZfe@05okZfe@;o00001oo5]<X2o`0000KobK3100?o0000om2]]_l00000
1_o9Zk/00ol0003ocJJao`000005olNU]`05o`000?o8X:oob:2_olRP[ol000000oo2XKL00ol0003o
`IZ`ol6J/004ol6J/003o`000?njU[?o^YJc00Go^YJc00?o0000okJ?[_nfSjh00onfSjh00ol0003o
[Xjdojj>]004ojj>]003o`000?nXR;;oZ8Rb00CoZ8Rb00?o0000oj62/OnQP[400onQP[400ol0003o
VWfaoiYm/@04oiYm/@03o`000?nCNK;oTgVb01?o00000_n4Mkd00ol0003oPW_3oh9k``02oh9k``03
o`000?n2PLWoPX7900?oPX7900?o0000oh>7con3Qll01?n3Qll00ol0003oQHoFohF?eP03ohF?eP03
o`000?n8Um_oR9OK00?oR9OK00?o0000ohbNgon<W]l00on<W]l00ol0003oSjCSohnTh`04ohnTh`04
o`000?nBZ^KoTZ[Voi:ZiPKo00000onH/NP00ol0003oVKCZoiVdjP05oiVdjP03o`000?nK]^_oVkK[
00?oVkK[00?o0000oibhk?nL^>`00ol00002oifik003o`000?oonf[ooo]Z017ooo]Z00?o0000oook
J_oonfX02?oonfX005_ooo]Z00?o0000oookJ_oonfX01?oonfX2o`0000KoZLK^00?o0000oj[6k_nZ
a^h00ol00003oj[6kP03o`000?n[ankoZlO^00?oZlO^0ol00007ojc7kP;o00001on]bNh00ol0003o
[/W^o`000002o`0000?o[l[^00?o0000ojo;k_n_bnh00_n_bnh2o`0000?o/<g^00?o0000ok7>kona
c^l00onac^l3o`0000Co]=;`0_l00003okKEl003o`000?ngf?7o]mSa00;o]mSa0_l00003ok[MlPCo
00000_nnjO<2o`0000?o`_?`00?o0000olOkiol000000ol00002omgle`04o`000?oWnlOo0000oo7e
]`;o00000_odgKH01?l0003olm:_oo?B[ol00003ono8ZP05o`000?o[_jOojknWon^oYol000000ooV
^JH00ol0003oi:jMonB^W@02onB^W@03o`000?oNZYoogZZO00?ogZZO00?o0000omVVXol000001?oI
XI/01Ol0003odijPom>NX?oCWZ3o000000;odIVJ00?o0000ol^GWoo;Uil00_o;Uil00ol0003oai2K
olN@V`02olN@V`04o`000?o2Sj7o`XnQo`0000Ko^hNN00Co0000ok9nVonbOY_o/WjK0_l00006ojIh
X003o`000?nJKYooVVjO00;oVVjO00?o0000oheTW_n=I9h00_n=I9h00ol0003oOebOogmLW`02ogmL
W`03o`000?mdEJ3oM5FP00;oM5FP00Go0000oeLmUomG?IOoEcfGo`000003odhlW0;o00000_l[9IH0
1?l0003o<3>So`000?l00002oaL[YP;o000000?o33:bo`000?m0H/h00ol00003oef2gP03o`000?n9
Wn;oRIoR00?oRIoR00?o0000ojJ^gOnV[]d00onV[]d00ol0003o^[KEokZfe@02okZfe@;o000000?o
]k;Do`000?o5]<X01Oo5]<X00ol0003o`;7;o`000006olV``@;o00002?o9Zk/00ol0003oajFgolNU
]`04olNU]`04o`000?o8X:oob:2_o`0000Go`Z6g00?o0000ol6J/?o1V[000_o1V[02o`0000Oo^YJc
00?o0000okJ?[_nfSjh00_nfSjh2o`0000Ko[Xjd00?o0000ojR8/_nXR;801?nXR;800ol0003oXH:a
oj62/@04oj62/@03o`000?nJOK7oVWfa00Ko00000onHQ;d00ol0003oTh>ooi>3_`03oi>3_`03o`00
0?n?Pl;oSh?200?oSh?200Co0000ohf5a_n=QLKoSHG63?l000000on2PLWo0000oh>7c`05oh>7c`03
o`000?n5SmKoQHoF00?oQHoF00?o0000ohRGfon8Um/00on8Um/01?l0003oS9kOohbNgon<W]l=o`00
00?oUZgW00?o0000oiRaj?nH/NP01?nH/NP00ol0003oVKCZoiVdjP04oiVdjP04o`000?nK]^_oVkK[
oi^fj`Go000000?oWKW/o`000?nM^N`00onM^N`00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z00Sooo]Z001LoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000ojW6k_nYa^h00onYa^h3o`00
00OoZ/K^00?o0000oj_7k_l000000_l00003oj_7kP03o`000?n/anko[<O^00;o[<O^0_l00002ojc8
kP03o`000?n]bNko[LW^00Co[LW^0ol00006ojo:kP04o`000?n_bnko0000o`0000Ko/<g^00?o0000
ok7>kol000000_l00003ok?@k`;o000000?o]=;`o`000?nfeO001OnfeO001?l0003o]mSao`000?l0
0003ok[MlP;o00001?nnho84o`0000;o`_?`1?l000001_oCnNCo0000omgleooMo=Oo0000onOka`?o
000000Gol^Noo`000?odgKKom=ffo`000002oo?B[`05o`000?o_b:[oklRZono8Z_l000000_o[_jL0
0ol0003oi[VVonJiYP02onJiYP03o`000?oT[Ygoi:jM00;oi:jM00?o0000omjZWooNZYl00ooNZYl0
0ol0003ofJJSo`000003omVQV`03o`000?oCWZ3odijP00;odijP00Co0000om6IV_oAVI[o00001?o;
Uil01Ol0003oai2KolN@Voo7T9_o000000?o`XnQ00?o0000ok^7W_nkQih01?nkQih01_l0003o/WjK
ok9nVol0003o[h6Ro`0000KoYWRP00?o0000oiY^WonJKYl00_nJKYl00ol0003oSFBNoheTWP02oheT
WP03o`000?moG9ooOebO00;oOebO00?o0000ogAEX?mdEJ000_mdEJ001Ol0003oEcfGoeLmUomG?IOo
000000?oCSbL00Go0000oda2YOl0003o:bFFo`000002oc0cX`08o`000?lG:jKo5b^Vo`000?lgC[ko
0000o``b/_l00002od1RcP03o`000?mMP]koGH;N00;oGH;N00?o0000ohVOh_n9Wn800on9Wn800ol0
003oYZkMojJ^g@03ojJ^g@04o`000?nj]]Go0000o`0000Co]k;D00?o0000olFdb_o5]<X00_o5]<X0
1Ol0003o`;7;ol2aboo0/L_o000000CobK3100?o0000olB^a?l000001oo9Zk/2o`0000OoajFg0_l0
0006ol:Q]`05o`000?o1V[3o`IZ`ol6J/?l000000_nlW;P00ol0003o^YJcokZF/`04okZF/`05o`00
0?nfSjko]Xn^okJ?[_l000000_nbU;P00ol0003o[Xjdojj>]004ojj>]003o`000?nXR;;oZ8Rb00?o
Z8Rb00?o0000oj62/OnQP[400onQP[44o`0000?oWHNk00?o0000oiR4_OnHQ;d01?nHQ;d00ol0003o
Th>ooi>3_`03oi>3_`03o`000?n?Pl;oSh?200?oSh?200?o0000ohf5a_n=QLH00_n=QLH00ol0003o
RhS;oh^8b`03oh^8b`04o`000?n;SM3oRhg@oh^=d1So00000onAY>800ol0003oTjWToi>Yi004oi>Y
i003o`000?nF[NOoUZgW00CoUZgW00?o0000oiRaj?nH/NP01?nH/NP01?l0003oVKCZoiVdj_nI]>X6
o`0000CoW;O[00Co0000oifik?nM^Nco00000onM^N`00ol0003ooo]ZoookJP0@oookJP03o`000?oo
nf[ooo]Z00Sooo]Z001MoookJP;o00001_oonfX00ol0003oZLK^o`000002o`0000?oZ/K^00?o0000
oj[6k_nZa^h01?nZa^h3o`0000KoZlO^00Co0000ojc7k_l0003o00001On/b>h00ol0003o[LW^ojg9
kP03o`0000?o[/W^00?o0000ojo:k_n_b^h00on_b^h3o`0000Oo/<g^0_l00007ok?@k`?o00001_nf
eO04o`0000;o^]gb00?o0000okkSl_nnho800onnho800ol0003o`n_`ol?[l002ol?[l0Co00000_oC
nN@01Ol0003ogOcGomgleol0003oio_700;o000000?ok>k;o`000?l000000oodgKH00ol0003olm:_
o`000003ono8ZP05o`000?o[_jOojknWon^oYol000000ooV^JH00ol0003ohK>Wo`000002onB^W@03
o`000?oNZYoogZZO00?ogZZO00Co0000omVVXooIYZ?o00000ooIXI/00ol0003odijPom>NX003om>N
X0;o00001Oo;Uil01Ol0003oai2KolN@Voo7T9_o000000?o`XnQ00?o0000ok^7W_nkQih01?nkQih0
1_l0003o/WjKok9nVol0003o[h6Ro`0000KoYWRP00?o0000oiY^WonJKYl00onJKYl00ol0003oSFBN
oheTWP02oheTWP05o`000?moG9ooOebOogmLWol000001?mdEJ02o`0000;oEcfG00Wo0000odhlW?m>
?9coCSbLo`000?m<@ZGo0000ob/UU_l000000_l`<j<2o`0000;o5b^V00Co0000ocM>__l0003o0000
0om0H/h3o`0000;oGH;N00?o0000ohVOh_n9Wn800on9Wn800ol0003oYZkMojJ^g@02ojJ^g@;o0000
1ong/]@01?l0003oaKC:olFdb_l00004ol2ab`05o`000?o9/<7obK31olV``Ol000000oo4[/@00ol0
003obJ^kolV[^`03olV[^`04o`000?o4Z/3oa:[0o`0000KoajFg00?o0000ol:Q]oo2XKL01Oo2XKL0
1?l0003o`IZ`ol6J/?l00003okbL^003o`000?njU[?o^YJc00Co^YJc00Co0000okJ?[_nfSjko0000
0onbU;P00ol0003o[Xjdojj>]004ojj>]003o`000?nXR;;oZ8Rb00CoZ8Rb00?o0000oj62/Ol00000
0_l000000onSRk_o0000oif7^`05oif7^`03o`000?nHQ;goV8Bm00?oV8Bm00?o0000oi>3_onCPkl0
0onCPkl00ol0003oSh?2ohn3`P03ohn3`P03o`000?n=QLKoSHG600?oSHG600?o0000oh^8bon;R</0
0on;R</00ol0003oRhg@oh^=d002oh^=d003o`000?n;T]GoRi;E00CoRi;E00?o0000ohfHf_n=V=X0
0on=V=X00ol0003oSikNohnNgP03ohnNgP03o`000?nAY>;oTJCR00CoTJCR00?o0000oi>Yi?nCZN@0
1?nCZN@00ol0003oUZgWoiJ]i`03oiJ]i`03o`000?nH/NSoV;7X00;oV;7X1_l00003oi^ejP03o`00
0?nL]n_oW;O[00GoW;O[00?o0000oifik?nM^N`01Ol0000AoookJP03o`000?oonf[ooo]Z00Sooo]Z
001OoookJP03o`000?oonf[ooo]Z00Cooo]Z0_l00006oj[6kP03o`000?nZa^koZ/K^00?o00000on[
a^h00ol0003oZlO^oj_7kP03oj_7kP?o00001_n/b>h3o`0000Oo[/W^00?o0000ojo:k_l000000_l0
0003ojo;kP;o00000_n`cNh3o`0000;o//k_00?o0000ok?@koncd>l00_ncd>l2o`0000?o]M;_0_l0
00001?nfeO3o0000o`000?l00004okWIl0?o00000onnho82o`0000Co`n_`00Co0000ol[bk?o:l^co
00000_oCnN@01?l0003ogOcGomgleol00002onOka`05o`000?o/k/_o0000oo;W_ol000000_odgKH0
1?l0003olm:_oo?B[ol00003ono8ZP05o`000?o[_jOojknWon^oYol000000ooV^JH00ol0003ohK>W
o`000002onB^W@03o`000?oNZYoogZZO00?ogZZO00Go0000omVVXooIYZ?ofJJSo`000002omVQV`03
o`000?oCWZ3odijP00?odijP0_l00005ol^GW`05o`000?o7T9_oai2KolN@Vol000000oo2Sj400ol0
003o^hNNok^7WP04ok^7WP03o`000?nbOY_o000000?o[h6R00?o0000ojIhX?nVN:000onVN:000ol0
003oVVjOoiY^W`03oiY^W`03o`000?n=I9koSFBN00;oSFBN00Go0000ogmLWomoG9ooOebOo`000004
ogAEX005o`000?mZDZCo0000oeLmUol000000om>?9`00ol0003oC4:Uoda2Y@02o`0000;o<3>S00Go
0000ocm9]Ol0003o5b^Vo`000002ocM>_P;o00000_m0H/h00ol0003oKHOKoff7f`03o`0000GoRIoR
00?o0000ojJ^gOl000000_l000000onVZm_o0000okNbe006okNbe003o`000?o5]<[o000000Go`;7;
00Co0000olV``Oo9/<7o00001?o4[/@00ol0003obJ^kolV[^`02olV[^`05o`000?o4Z/3oa:[0olBZ
`?l000001Oo7YKL2o`0000So`Z6g0_l00004okbL^003o`000?njU[?o^YJc00Go^YJc0_l00004ok:D
^003o`000?n^S[Co[Xjd00Co[Xjd00?o0000ojR8/_nXR;800onXR;83o`0000CoXh^k00?o0000oif7
^onMQk/01?nMQk/00ol0003oV8BmoiR4_@03oiR4_@03o`000?nCPkooTh>o00?oTh>o00?o0000ohn3
`_n?Pl800on?Pl800ol0003oSHG6ohf5aP03ohf5aP03o`000?n;R<_oRhS;00?oRhS;00?o0000oh^=
d?n;SM000on;SM000ol0003oRi;Eoh^Be@04oh^Be@03o`000?n=V=[oSISJ00?oSISJ00?o0000ohnN
g_n?W]h00on?W]h00ol0003oTJCRoi6ThP04oi6ThP03o`000?nCZNCoTjWT00?oTjWT00Co0000oiJ]
ionF[NOoUZgW1ol00003oiZcj@03o`000?nK]N[oVkGZ00CoVkGZ00?o0000oibgjonL]n/00onL]n/5
o`0000?oW[[/00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP08oookJP00H?oonfX00ol0
003ooo]ZoookJP05oookJP03o`000?nZa^koZ/K^00?oZ/K^0ol00007oj_6kP03o`000?n[anko0000
00;o00000on/anh01?l0003o[<S^ojc8k_n/b>h2o`0000?o[LS^00?o0000ojk9k_n^bNh01?n^bNh2
o`0000Oo[l_^0ol00006ok;>k`04o`000?ncd>oo0000o`0000Ko]M;_0ol00004okWIl0;o00000onl
g_000ol0003o_^?bo`000004ol?[l0;o00000_o:l^`01?l0003odoWTom?ii?l00002omgle`Co0000
00Cok>k;o`000?obikoo00000oodgKH00ol0003olm:_o`000004ono8ZP04o`000?o[_jOojknWo`00
00Coi[VV00Ko0000on6cYooQ/jOo0000onB^WOl00005omjZW`05o`000?oIYZ?ofJJSomVVXol00000
0_oIXI/00ol0003odijPom>NX003om>NX0;o00001_o;Uil00ol0003oai2Ko`000004ol:?X@03o`00
0?nkQiko^hNN00Co^hNN00?o0000ok9nVol000000on_PJ800ol0003oYWRPojIhX003ojIhX003o`00
0?nJKYooVVjO00?oVVjO00?o0000oheTW_n=I9h00_n=I9h01Ol0003oOebOogmLWomoG9oo000000Go
M5FP00Go0000ofYBY?l0003oEcfGo`000002odhlW004o`000?m<@ZGoC4:Uoda2Y@;o00000_l`<j<0
1Ol0003o?dVeo`000?lG:jKo000000;o=djn00Go0000od1Rc_m0H/ko@6;>o`000004off7f`Oo0000
1OnVZm/00ol0003o]k;DokNbe004okNbe0;o00001oo0/L/2o`0000Koa:k400Co0000olV[^oo9Zk_o
00001Oo4Z/001Ol0003oajFgolNU]oo7YKOo000000;o`JJn00?o0000ol:Q]oo2XKL01?o2XKL2o`00
00Ko_9bh00?o0000okZF/onjU[<00onjU[<2o`0000Ko/YBh00?o0000ojj>]?n^S[@00on^S[@01?l0
003oZ8RbojR8/_nXR;82o`000003ojR@_?l0003oXh^k00GoXh^k00?o0000oif7^onMQk/00onMQk/0
0ol0003oV8BmoiR4_@04oiR4_@03o`000?nCPkooTh>o00?oTh>o00?o0000ohn3`_n?Pl800on?Pl80
0ol0003oSHG6ohf5aP03ohf5aP03o`000?n;R<_oRhS;00?oRhS;00?o0000oh^=d?n;SM000on;SM00
0ol0003oRi;Eoh^Be@03oh^Be@03o`000?n=V=[oSISJ00?oSISJ00?o0000ohnNg_n?W]h01?n?W]h0
0ol0003oTJCRoi6ThP03oi6ThP04o`000?nCZNCoTjWToi>Yi0Ko00000onH/>L00ol0003oV[?YoiZc
j@05oiZcj@03o`000?nK]N[oVkGZ00?oVkGZ00?o0000oibgjonL]n/00ol00002oijij`04o`000?nN
^^coW[[/o`0000?oW[[/00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP08oookJP00HOoo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?nZa^ko000000;o00000onZa^h00ol0003oZlK^oj_6
kP04oj_6kP;o00001on/anh00ol0003o[<S^o`000006ojg8kP03o`000?n^bNko[/W^00?o00000_n_
b^h00ol0003o[l_^ojo;kP02ojo;kP;o00000onacNh00ol0003o//k_ok;>k`03ok;>k`?o00001One
d^l2o`0000?o]mK_00Co0000okWIl?l0003o00001Onlg_04o`0000;o`n_`00Go0000ol[bk?o:l^co
b_;/o`000002om?ii0Go00000_oSl]H01Ol0003ok>k;o`000?obikoo000000;om=ff00Co0000oo?B
[oocdZoo00000oo_b:X01Ol0003ojknWon^oYoo[_jOo000000?oi[VV00Oo0000on6cYooQ/jOohK>W
o`000?oT[Ygo000000CogZZO00?o0000omVVXooIYZ<00_oIYZ<00ol0003ofJ6Ko`000006om>NX003
o`000?o;UioobiNO00GobiNO00?o0000olN@Vol000001?o2Sj400ol0003o^hNNok^7WP04ok^7WP;o
00001?n_PJ800ol0003oYWRPojIhX003ojIhX003o`000?nJKYooVVjO00?oVVjO00?o0000oheTW_n=
I9h00_n=I9h00ol0003oOebOogmLW`02ogmLW`03o`000?mdEJ3oM5FP00;oM5FP00?o0000ofYBY?mZ
DZ@00_l00003odhlW005o`000?m<@ZGoC4:Uoda2YOl000000_l`<j<00ol0003o?dVeocm9]@02o`00
00?o=djn0_l000000om0H/ko0000off7f`03off7f`03o`000?n>W]koSYkN00?oSYkN00?o0000ojJ[
fonVZm/01?nVZm/01?l0003o]k;DokNbe?ng/]@2o`000003okB_dol0003o`;7;00Go`;7;0_l00007
olB^a003o`000?o9Zk_o000000Koa:[000Co0000olNU]oo7YKOo00000oo1Y[h00ol0003o`Z6gol:Q
]`03ol:Q]`03o`000?nmX[ko000000Ko_9bh00?o0000okZF/onjU[<00_njU[<00ol0003o]YZko`00
0006ok:D^003o`000?n^S[Co[Xjd00Co[Xjd0ol00004ojR@_003o`000?nSRk_oXh^k00?oXh^k00?o
0000oif7^onMQk/01?nMQk/00ol0003oV8BmoiR4_@03oiR4_@03o`000?nCPkooTh>o00?oTh>o00?o
0000ohn3`_n?Pl800on?Pl800ol0003oSHG6ohf5aP03ohf5aP03o`000?n;R<_oRhS;00?oRhS;00?o
0000oh^=d?n;SM000on;SM000ol0003oRi;Eoh^Be@03oh^Be@03o`000?n=V=[oSISJ00?oSISJ00?o
0000ohnNg_n?W]h00_n?W]h<o`0000?oUjcV00?o0000oiR`ionH/>L01?nH/>L00ol0003oV[?YoiZc
j@04oiZcj@04o`000?nK]N[oVkGZoi^ejPGo00001_nN^N/01?l0003oW[[/oijjk?l00002oijjk0;o
00003ooonfX00ol0003ooo]ZoookJP08oookJP00H_oonfX2o`0000Kooo]Z0_l00006oj[6kP03o`00
0?n[a^koZlK^00?o00000_n[anh00ol0003o[<O^ojc7kP04ojc7kP?o00001_n]b>h3o`0000Ko[l[^
00Co0000ojo;k_l0003o00001_nacNh00ol0003o//k_o`000002o`0000?o/m3_0_l000000oned^oo
0000o`000005okOFk`?o00001?nlg_02o`0000Co`^?_2_l00002om[ah@08o`000?oSl]Koho;Fo`00
0?o/k/_o0000oo;W_ol00003ooCM]P04o`000?ocdZoolm:_o`0000?oklRZ00Go0000on^oYoo[_jOo
jknWo`000003onJiYP04o`000?oQ/jOohK>Won6cY`;o00001OoNZYl00ol0003ofJJSomVVX`02omVV
X`03o`000?oIXI_o000000KodijP00?o0000ol^GWoo;Uil01Oo;Uil2o`0000Ko`XnQ00?o0000ok^7
W_nkQih00onkQih00ol0003o[h6Rojn1XP03ojn1XP03o`000?nVN:3oYWRP00?oYWRP00?o0000oiY^
WonJKYl00onJKYl00ol0003oSFBNoheTWP02oheTWP03o`000?moG9ooOebO00;oOebO00?o0000ogAE
X?mdEJ000_mdEJ001Ol0003oJU:TofYBY?mZDZCo000000?oCSbL00Go0000oda2YOm<@ZGoC4:Uo`00
0002oc0cX`05o`000?loBKGo?dVeocm9]Ol000000olgC[h00ol0003oFW7@o`000002o`0000CoKHOK
00?o0000ohjNg_n>W]h00on>W]h00ol0003oYZ_KojJ[f`03ojJ[f`04o`000?ng/]Co0000o`0000Co
]:oC00?o0000ol2aboo0/L/00_o0/L/00ol0003o_:o=o`000007olB^a0;o00001oo4Z/000ol0003o
ajFgo`000005ol6V_P05o`000?o2XKOo`Z6gol:Q]ol000000onmX[h00ol0003o_9bhokbL^003okbL
^003o`000?njU[?o^YJc00;o00000onfV[/00ol0003o/YBhok:D^004ok:D^003o`000?n^S[Co[Xjd
00;o[Xjd0_l00006ojR@_003o`000?nSRk_oXh^k00?oXh^k00?o0000oif7^onMQk/01?nMQk/00ol0
003oV8BmoiR4_@03oiR4_@03o`000?nCPkooTh>o00?oTh>o00?o0000ohn3`_n?Pl800on?Pl800ol0
003oSHG6ohf5aP03ohf5aP03o`000?n;R<_oRhS;00?oRhS;00Co0000oh^=d?n;SM3oRhg@4ol00003
oiBTh003o`000?nEZ>?oUJSS00?oUJSS00?o0000oiN/i_nG[>H01?nG[>H00ol0003oV;3WoiR`i`04
oiR`i`04o`000?nJ/nWoV[?YoiZcj@Ko00001?nM]n/00ol0003oW[W[oijij`04oijij`03o`000?nN
^^coW[[/00?o000000?oWk_/o`000?oonfX03ooonfX00ol0003ooo]ZoookJP07oookJP00I?oonfX0
0ol0003ooo]ZoookJP05oookJP03o`000?nZa^koZ/K^00?oZ/K^0ol00006oj_7kP03o`000?n/anko
[<O^00?o00000on/b>h2o`000004ojg8k_l0003o0000o`0000?o[/W^00?o0000ojo:k_n_b^h00on_
b^h3o`0000Oo/Lg^0_l00007ok?@k`?o00001?nge^l2o`0000?o^mW_0_l000000onlg_3o0000ol;S
k`03ol;Sk`;o00000oo8jNd01Ol0003od>kXom3^j?o@k^So000000?of_7Q00Co0000on?be_oSl]Ko
00000_o/k//00ol0003ol^Noo`000002ooCM]P04o`000?ocdZoolm:_o`0000CoklRZ00Co0000on^o
Yoo[_jOo00001?oV^JH00ol0003ohK>Won6cY`02on6cY`03o`000?oNZYoogZZO00?ogZZO00?o0000
omVVXooIYZ<00_oIYZ<00ol0003ofJ6Ko`000006om>NX003o`000?o;UioobiNO00GobiNO0_l00006
ol:?X@03o`000?nkQiko^hNN00?o^hNN00?o0000ojn1X_n_PJ800on_PJ800ol0003oYWRPojIhX003
ojIhX003o`000?nJKYooVVjO00?oVVjO00?o0000oheTW_n=I9h00_n=I9h00ol0003oOebOogmLW`02
ogmLW`03o`000?mdEJ3oM5FP00;oM5FP00Go0000ofYBY?mZDZCoJU:To`000003odhlW004o`000?m<
@ZGoC4:Uoda2Y@;o00000_l`<j<01?l0003o?dVeocm9]OloBKD2o`0000;o=djn00Co0000oeYad?mJ
LM3o00001Om]Qm/00ol0003oSYkNohjNgP03ohjNgP04o`000?nVZm_oYZ_KojJ[f`?o00001ond[m<0
1?l0003o`;7;ol2abol00003okb_c@03o`000?o4[/Coa:k400?oa:k400?o0000okn]b?l000001oo4
Z/02o`0000Ko`JJn00Co0000ol:Q]oo2XKOo00001?nmX[h00ol0003o_9bhokbL^004okbL^0;o0000
1OnfV[/00ol0003o/YBhok:D^004ok:D^003o`000?n^S[Co[Xjd00;o000000?o[9Bno`000?nXT;`0
1OnXT;`00ol0003oXh^koj>;^`04oj>;^`03o`000?nMQk_oWHNk00?oWHNk00?o0000oiR4_OnHQ;d0
1?nHQ;d00ol0003oTh>ooi>3_`0Ho`0000?oTIOE00?o0000oi:KfOnBVmT00onBVmT00ol0003oTZ3M
oi:Pg@03oi:Pg@03o`000?nDY>3oU:CP00GoU:CP00?o0000oiFXhonEZ><00onEZ><00ol0003oUjcV
oiN/iP04oiN/iP04o`000?nH/>OoV;3WoiR`i`Ko00001?nL]NT00ol0003oWKO[oifgj`04oifgj`04
o`000?nN^N_oW[W[oijij`Go000000?oWk_/o`000?nO^n`00_nO^n`00ol0003ooo]ZoookJP0=oook
JP03o`000?oonf[ooo]Z00Oooo]Z001UoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oj[6k_l0
00000_l00003oj_6kP03o`000?n[ankoZlO^00?oZlO^0ol00007ojc8kP;o00001on^bNh00ol0003o
[l[^o`000002o`0000?o/<_^0_l00002ok7=kP?o00000_nbc^h00ol0003o/m3_ok?@k`02ok?@k`;o
00000onfd^l2o`000003okOFkol0003o^mW_00Go^mW_1?l00002ol;Sk`03o`000?o8jNgob>W]00;o
b>W]00Go0000om3^j?o@k^Sod>kXo`000003om[ah@04o`000?oSl]Koho;Fo`0000;ok>k;00?o0000
oo;W_ol000000oodgKH01?l0003olm:_oo?B[ol00003ono8ZP05o`000?o[_jOojknWon^oYol00000
0ooV^JH00ol0003ohK>Won6cY`03on6cY`03o`000?oNZYoogZZO00;ogZZO00?o0000omVVXooIYZ<0
1?oIYZ<00ol0003odijPom>NX004om>NX0;o00001oo;Uil2o`0000Ko`XnQ00?o0000ok^7W_nkQih0
0_nkQih2o`0000Go[h6R00?o0000ojIhX?nVN:000onVN:000ol0003oVVjOoiY^W`03oiY^W`03o`00
0?n=I9koSFBN00;oSFBN00?o0000ogmLWomoG9l00_moG9l00ol0003oM5FPogAEX002ogAEX004o`00
0?mZDZCoJU:TofYBY0;o00000_m>?9`00ol0003oC4:Uoda2Y@02oda2Y@;o000000?o<3>So`000?lo
BKD00_loBKD01Ol0003oEFC5o`000?lgC[ko000000?oFW7@1?l000000om]Qm_o0000ohjNgP02ohjN
gPKo00000_nVZMT00ol0003o]:oCokB_d`05okB_d`03o`000?o0/L_o000000Go_:o=00?o0000olB^
a?o4[/@00_l00003okn]b003o`000?o4Z/3oa:[000?oa:[000?o0000okjZaOl000001_o1Y[h00ol0
003o`Z6go`000005okfR_P03o`000?nlW;So_9bh00?o_9bh0_l00006okJJ^`03o`000?nbU;So/YBh
00Co/YBh00?o0000ojj>]?l000001?n/U;h00ol0003oZ92lojR@_004ojR@_003o`000?nSRk_oXh^k
00?oXh^k00?o0000oif7^onMQk/01?nMQk/00ol0003oV8BmoiR4_@06o`0000?oV8o800?o0000oiF?
b_nESlX00onESlX00ol0003oTi7>oi>AcP03oi>AcP03o`000?nBTm7oTY?A00?oTY?A00?o0000oi6G
eOnAUmD01?nAUmD00ol0003oTY_Ioi:Kf@03oi:Kf@03o`000?nBX=goTZ3M00?oTZ3M00?o0000oiBT
h?nDY>001?nDY>000ol0003oUJSSoiFXh`03oiFXh`03o`000?nG[>KoUjcV00;oUjcV1_l00003oi^b
j003o`000?nL]NWoW;GY00GoW;GY00Co0000oifgjonM]n_oWKO[1_l00003oinjk005o`000?nO^nco
Wk_/oinkk?l000000onO^n`00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00Oooo]Z001V
oookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00006oj_6kP03o`000?n[anko000000;o00000on/anh0
0ol0003o[<S^ojc8kP02ojc8kP;o00000_n]b>h00ol0003o[/W^ojk9kP04ojk9kP?o00001_n`bnh3
o`0000Ko//k^00Co0000ok?@kol0003o00001_nfd^l3o`0000Co^mW_0_l00004okoMkP?o00000oo8
jNd01Ol0003od>kXom3^j?o@k^So000000?of_7Q00Co0000on?be_oSl]Ko00000_o/k//01?l0003o
l^Nooo;W_ol00003ooCM]P04o`000?ocdZoolm:_o`0000?oklRZ00Go0000on^oYoo[_jOojknWo`00
0003onJiYP03o`000?oQ/jOohK>W00;ohK>W00?o0000omb_ZOl000000ooNZYl00ol0003ofJJSomVV
X`04omVVX`03o`000?oCWZ3odijP00CodijP00?o0000olfMYOl000001_o;Uil00ol0003o`XnQol:?
X@05ol:?X@03o`000?nkQiko^hNN00;o^hNN0_l00005ojn1XP03o`000?nVN:3oYWRP00?oYWRP00?o
0000oiY^WonJKYl00onJKYl00ol0003oSFBNoheTWP02oheTWP03o`000?moG9ooOebO00;oOebO00?o
0000ogAEX?mdEJ000omdEJ001?l0003oJU:TofYBY?mZDZ@2o`000003odhlW?l0003oC4:U00?oC4:U
00Co0000oe1?/Ol0003o00001?loBKD00ol0003oEFC5o`000002o`0000;oFW7@00Co0000ogV<fOmi
S=WoNHcI1Ol00003oi:Ng003o`000?nVZMWoYZWI00?oYZWI00?o0000okB_dond[m<01?nd[m<2o`00
00Ko_:o=00?o0000olB^a?l000001Ono[LP00ol0003oa:[0olBZ`002olBZ`004o`000?nnZ/Go_Z[5
o`0000Ko`JJn0_l00007okfR_P07o`000?nlW;So_9bhokbL^?l0003o^:30o`000007okJJ^`03o`00
0?nbU;So/YBh00?o/YBh0_l00005ojbD_P03o`000?nXT;coZ92l00CoZ92l00?o0000oj>;^onSRk/0
0onSRk/00ol0003oWHNkoif7^`03oif7^`Co00000onLSlH00ol0003oV8o8oiR?b003oiR?b003o`00
0?nESl[oUHo:00CoUHo:00?o0000oi>Ac_nCTLh00onCTLh00ol0003oTY?Aoi:Cd@03oi:Cd@03o`00
0?nAUmGoTIOE00?oTIOE00?o0000oi:KfOnBVmT01?nBVmT00ol0003oTZ3Moi:Pg@03oi:Pg@03o`00
0?nDY>3oU:CP00?oU:CP00Co0000oiFXhonEZ>?oUJSS1ol00003oiZ`i`03o`000?nK/^SoVk;X00Co
Vk;X00?o0000oibejOnL]NT00onL]NT5o`0000?oW[S[00?o0000oinjk?nO^^`01?nO^^`01?l0003o
Wk_/oinkk?nO^n`5o`0000gooo]Z00?o0000oookJ_oonfX01ooonfX006Oooo]Z0_l00007oookJP03
o`000?n[a^koZlK^00?oZlK^0ol00006ojc7kP04o`000?n/b>ko0000o`0000Go[LS^00?o0000ojk9
k_n^bNh00ol00003ojo:kP04o`000?n`bnko/<_^ok3;kP;o00000onac>h00ol0003o//k^ok;>kP03
ok;>kP?o00001Onfd^l2o`0000?o^MG^00Co0000ok_Ikol0003o00001OnogNh01ol0003oaN7]olGQ
kOo5hNgo0000olSYkOl000000oo@k^P01Ol0003of_7Qom[ahOoJlN7o000000;oho;F00Co0000onc^
boo/k/_ok>k;3?l00002ono8ZP04o`000?o[_jOojknWo`0000Coi[VV00?o0000on6cYooQ/jL00_oQ
/jL00ol0003og:nYo`000003omjZW`03o`000?oIYZ?ofJJS00CofJJS00?o0000om>NX?oCWZ001?oC
WZ000ol0003ocIfUo`000006ol^GW`03o`000?o2Sj7o`XnQ00Go`XnQ00Go0000ok^7W_nkQiko^hNN
o`000002okN9Y@03o`000?n_PJ;o[h6R00?o[h6R00?o0000ojIhX?nVN:000onVN:000ol0003oVVjO
oiY^W`03oiY^W`03o`000?n=I9koSFBN00;oSFBN00Go0000ogmLWomoG9ooOebOo`000005ogAEX009
o`000?mZDZCoJU:TofYBY?l0003oIEBZo`000?m>?9co000000?oC4:U00?o0000oe1?/Om@Ck400_l0
0003ocm9]@05o`000?mEI<GoEFC5oeETaOl000000omJLM000ol0003oNHcIogV<f@02ogV<f@03o`00
0?nBW]coTYkL00CoTYkL00?o0000ojJYfOnVZMT00onVZMT00ol0003o]:oCokB_d`03o`000003ok:]
e?l0003o_:o=00Go_:o=0_l00007okn]b004o`000?o4Z/3oa:[0o`0000Co_Z[500?o0000ol6V__o1
Y[h00_o1Y[h00ol0003o_:O4o`000007okfR_P04o`000?nlW;So_9bho`0000?o^:3000?o0000okJJ
^onfV[/01?nfV[/01?l0003o/YBhok:D^?nbU;P2o`000003ok2J`?l0003o[9Bn00Co[9Bn00?o0000
ojR@_?nXT;`01?nXT;`00ol0003oXh^koj>;^`04oj>;^`03o`000?nMQk_o000000;o000000?oX975
o`000?nLSlH01OnLSlH00ol0003oV8o8oiR?b003oiR?b003o`000?nESl[oUHo:00?oUHo:00?o0000
oi>Ac_nCTLh00onCTLh00ol0003oTY?Aoi:Cd@04oi:Cd@03o`000?nAUmGoTIOE00?oTIOE00?o0000
oi:KfOnBVmT00onBVmT01?l0003oTZ3Moi:PgOnBX=d<o`0000?oVJgU00?o0000oiZ`ionJ/>L01OnJ
/>L00ol0003oVk;Xoi^bj003oi^bj003o`000?nL]NWoW;GY00?o00000_nM]^X00ol0003oW[S[oijh
j`04oijhj`03o`000?nO^^coWk[/00?oWk[/1_l00002oj2lk003o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX01ooonfX006Wooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003oZlK^o`000002
o`0000?oZlO^00?o0000ojc7k_n/anh00on/anh3o`0000Ko[LS^0ol00007ojo:kP03o`000?n`bnko
000000Ko/Lc^00?o0000ok;>k_l000000_l00003okC@kP;o000000?o]];_o`000?l000001OnieNh3
o`0000Co_mg^0_l00004olGQkA;o000000?oin7<o`000?oZf/@00_oZf/@01?l0003oj]:mon[B_Ol0
0002onS:]`?o00000_o[_jL01Ol0003oi[VVonJiY_oV^JKo000000GohK>W00?o0000omb_ZOl00000
0_oNZYl00ol0003ofJJSomVVX`04omVVX`;o00001OoCWZ001?l0003ocIfUolfMYOl00005ol^GW`;o
00001oo2Sj401Ol0003o^hNNok^7W_nkQiko000000;o]hVU00?o0000ojn1X_n_PJ800on_PJ800ol0
003oYWRPojIhX003ojIhX003o`000?nJKYooVVjO00?oVVjO00?o0000oheTW_n=I9h00_n=I9h01Ol0
003oOebOogmLWomoG9oo000000GoM5FP00Go0000ofYBY?mZDZCoJU:To`000002ofEDZP;o00001?m<
@ZD00ol0003oD4naoe1?/@02o`0000;o?dVe00?o0000oeETaOmEI<D00_mEI<D2o`0000;oFW7@00?o
0000ogV<fOmiS=T00_miS=T00ol0003oTYkLoi:Ng003oi:Ng003o`000?nVZMWoYZWI00?oYZWI0ol0
0005ok:]e003o`000?nl[lgo_:o=00;o_:o=00?o0000okR^col000001ono[LP00ol0003oa:[0o`00
0005okjZa@05o`000?o1Y[ko`JJnol6V__l000000onlYl@00ol0003o_J:nokfR_P04okfR_P03o`00
0?nlW;So000000Co^:3000?o0000okJJ^onfV[/01?nfV[/01?l0003o/YBho`000?l00003ok2J`003
o`000?n/U;ko[9Bn00Co[9Bn00?o0000ojR@_?nXT;`01?nXT;`00ol0003oXh^koj>;^`05o`0000Go
X97500?o0000oib?a_nLSlH00onLSlH00ol0003oV8o8oiR?b003oiR?b003o`000?nESl[oUHo:00?o
UHo:00?o0000oi>Ac_nCTLh01?nCTLh00ol0003oTY?Aoi:Cd@03oi:Cd@03o`000?nAUmGoTIOE00?o
TIOE00Co0000oi:KfOnBVmWoTY_I1_l00003oiNVh003o`000?nHZN?oV:WS00?oV:WS00?o0000oiV]
iOnI[ND01?nI[ND00ol0003oV[3WoiZ`i`04oiZ`i`04o`000?nK/^SoVk;Xoi^bj0Go00001_nM]^X0
0ol0003oW[S[oijhj`03oijhj`03o`000?nO^^coWk[/00?o000000?oX;[/o`000?nP_>`00_nP_>`0
1Ol0003oX;c/oj2lk?nP_>co000000cooo]Z00?o0000oookJ_oonfX01ooonfX006[ooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003oZlO^oj_7kP05oj_7kP03o`000?n/anko000000;o00000on/b>h2
o`000004ojg8k_l0003o0000o`0000?o[/W^00?o0000ojo:k_n_b^h01?n_b^h3o`0000Ko/Lc^0ol0
0006okC@kP?o00001?nieNh2o`0000?o_=S^0_l000000onogNko0000olGQk@03olGQk@;o00000oo<
i>T00ol0003odnOTom?Wi002om?Wi005o`000?oKimgofnOMom_WgOl000000ooRiMD00ol0003oin7<
o`000003on[Ja004o`000?oZd[goj]:mo`0000Coj<Zg00Go0000onG3]?l0003ojknWo`000003onJi
YP03o`000?oQ/jOohK>W00;ohK>W00Oo0000omb_ZOoL[jWog:nYo`000?oNZYoo000000KofJJS00?o
0000om>TYol000001?oCWZ001?l0003ocIfUolfMYOl00005ol^GW`;o00001oo2Sj401?l0003o^hNN
ok^7W_l00003okN9Y@03o`000?n_PJ;o[h6R00?o[h6R00?o0000ojIhX?nVN:000onVN:000ol0003o
VVjOoiY^W`03oiY^W`03o`000?n=I9koSFBN00;oSFBN00?o0000ogmLWomoG9l00_moG9l00ol0003o
M5FPogAEX002ogAEX005o`000?mZDZCoJU:TofYBY?l000000omUE:X2o`0000?oC4:U00Ko0000oe1?
/Om@Ck7o0000oe]Q_ol00002ocm9]@06o`000?mEI<GoEFC5oeETaOl0003oKGgB0ol00005ogV<f@03
o`000?nBW]coTYkL00;oTYkL00?o0000ojJYfOnVZMT00ol000000onUZ=So0000ok:]e006ok:]e004
o`000?nl[lgo_:o=o`0000?o^:k?00?o0000okn]b?no[LP01?no[LP2o`0000Ko_Z[500Co0000ol6V
__o1Y[ko00001?nlYl@00ol0003o_J:nokfR_P04okfR_P;o00001OnhX<000ol0003o]YZkokJJ^`04
okJJ^`;o00001_n`V/000ol0003o[9BnojbD_P03ojbD_P03o`000?nXT;coZ92l00?oZ92l1?l00003
ojBDa003o`000?nPTLGoX97500CoX97500?o0000oib?a_nLSlH01?nLSlH00ol0003oV8o8oiR?b002
oiR?b003o`000?nESl[oUHo:00CoUHo:00?o0000oi>Ac_nCTLh00onCTLh01?l0003oTY?Aoi:CdOnB
Tm4<o`0000?oUj;M00?o0000oiNVh?nGY^001?nGY^000ol0003oV:WSoiRYh`03oiRYh`03o`000?nI
[NGoVJgU00CoVJgU00Co0000oiZ`ionJ/>OoV[3W1_l00004oifdj@03o`000?nM]^[oWKKZ00CoWKKZ
00Co0000oijhjonN^>_oW[S[1Ol00005oj2jk005o`000?nP_>coX;c/oj2lk?l000000_nP_>`2o`00
00_ooo]Z00?o0000oookJ_oonfX01ooonfX006_ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
ZlO^oj_7kP04oj_7kP?o00001_n/b>h3o`0000Ko[/W^00?o0000ojo:k_n_b^h00ol00003ok3;kP03
o`000?nac>ko/Lc^00?o00000oncc^h01?l0003o]=3^okC@k_ndd>h2o`0000?o]m;^0_l000000oni
eNko0000okcHkP05okcHkPCo00000_o5hNd00ol0003oc>CYolcTj@02olcTj@03o`000?oCinCodnOT
00;odnOT00Go0000om_WgOoKimgofnOMo`000003on;Ue@04o`000?oWhLcoin7<o`0000;oj][400Go
0000on[B_OoZd[goj]:mo`000003onS:]`05o`000?oU`kCoiL>donG3]?l000001?oV^JH00ol0003o
hK>Won6cY`02on6cY`07o`000?oL[jWog:nYomb_ZOl0003ogZZOo`000006omVVX`03o`000?oCY:Oo
000000CodijP00Co0000olfMYOo=WJGo00001Oo;Uil00ol0003oaYJVo`000007ol:?X@03o`000?nk
Qiko000000?o]hVU00?o0000ojn1X_n_PJ800on_PJ800ol0003oYWRPojIhX003ojIhX003o`000?nJ
KYooVVjO00;oVVjO2?l00003ogmLW`03o`000?mdEJ3oM5FP00;oM5FP00Go0000ofYBY?mZDZCoJU:T
o`000003ofEDZP03o`000?mTF[;o000000;oC4:U00Ko0000oe1?/Om@Ck7oD4nao`000?mKHKl3o`00
00CoEFC500Co0000ofemd_m]OM;oKGgB1?l000000omiS=Wo0000oi:Ng002oi:Ng0Co00001OnUZ=P0
0ol0003o/ZgDok:]e004ok:]e003o`000?nl[lgo000000Co^:k?00?o0000okn]b?no[LP00ono[LP0
0ol0003o^Zg<o`000007okjZa@;o00001_nlYl@00ol0003o_J:nokfR_P02okfR_P03o`000?nhYLGo
000000Ko^:3000?o0000okJJ^onfV[/00_nfV[/00ol0003o/io4o`000006ok2J`003o`000?n/U;ko
[9Bn00?o[9Bn00Co0000ojR@_?nXT;coZ92l0_l000000onXUlGo0000ojBDa005ojBDa003o`000?nP
TLGoX97500CoX97500?o0000oib?a_nLSlH00onLSlH00ol0003oV8o8oiR?b003oiR?b003o`000?nE
Sl[oUHo:00go00000onGW=L00ol0003oUioJoiNOfP03oiNOfP03o`000?nGX]goUj;M00CoUj;M00?o
0000oiNVh?nGY^001?nGY^000ol0003oV:WSoiRYh`03oiRYh`04o`000?nI[NGoVJgUoiV]i@Ko0000
1?nL/^L00ol0003oWKCYoifdj@04oifdj@04o`000?nM]^[oWKKZoiffjPKo00001?nO^N/00ol0003o
X;[/oj2jk004oj2jk003o`000?nP_>coX;c/00?o000000?oXKc/o`000?oonfX02_oonfX00ol0003o
oo]ZoookJP07oookJP00K?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?n[ankoZlO^00?o0000
0on/anh2o`000004ojc8k_l0003o0000o`0000?o[LS^00?o0000ojk9k_n^bNh00on^bNh3o`0000Ko
/<_^0ol00007ok?>kP03o`000?ndd>ko000000Ko]m;^0ol00004okcHkP;o00001?o1f^`3o`0000?o
c>CY00?o0000om?Wi?oCin@00_oCin@01Ol0003ofnOMom_WgOoKimgo000000?oh^GE00Co0000onOQ
c?oWhLco00000ooZf/@01?l0003oj]:mon[B_Ol00004onS:]`05o`000?oU`kCoiL>donG3]?l00000
0ooV^JH00ol0003ohK>Won6cY`02on6cY`03o`000?oL[jWog:nY00;og:nY0_l00006omVVX`04o`00
0?oCY:OodjBWo`0000?odijP00?o0000olfMYOo=WJD00_o=WJD01Ol0003obiNOol^GWoo;Uioo0000
00;oaYJV00?o0000ol:?XOo2Sj401Oo2Sj42o`0000Co]hVU00?o0000ojn1X_n_PJ800on_PJ800ol0
003oYWRPojIhX003ojIhX003o`000?nJKYoo000000;o000000?oW7NXo`000?nCL:P00onCL:P00ol0
003oRFZYo`000003o`0000CoM5FP00?o0000ofYBY?mZDZ@00_mZDZ@01?l0003oIEBZofEDZ_l00002
ofAJ/P?o00000om@Ck401Ol0003oFf6ooe]Q_omKHKoo000000CoEFC500Go0000ofemd_m]OM;oKGgB
o`000003oh>Af0Go00000_nFWmX00ol0003oYJSHojFXf005ojFXf003o`000?nb[MCo/ZgD00?o/ZgD
0_l00006okR^c`03o`000?no[LSo_jg800;o00000onj[L`00ol0003o_Z[5okjZa@03okjZa@;o0000
1onlYl@00ol0003o_J:nokfR_P02o`0000?o^:G500?o0000okRP`?nhX<000onhX<000ol0003o]YZk
okJJ^`02o`0000?o/io400?o0000ok2J`?n`V/000on`V/000ol0003o[9BnojbD_P04ojbD_P?o0000
1?nXUlD00ol0003oY9C4ojBDa003ojBDa003o`000?nPTLGoX97500CoX97500?o0000oib?a_nLSlH0
0onLSlH01?l0003oV8o8oiR?b?nHSlP5o`0000?oVYWA00?o0000oiRJe?nHV]@01?nHV]@00ol0003o
UicGoiNLe`04oiNLe`03o`000?nGWm[oUioJ00?oUioJ00?o0000oiNRgOnGX]d00onGX]d00ol0003o
UjKPoiNVh004oiNVh004o`000?nHZN?oV:WSoiRYh`Ko00000onK/>H00ol0003oW;;Woibbi`05oibb
i`04o`000?nM]>WoWKCYoifdj@Ko00000onO^>X00ol0003oWkW[oinij`05oinij`04o`000?nP^^co
X;[/oj2jk0Go000000?oXKc/o`000?nQ_>`00_nQ_>`00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00Kooo]Z001]oookJP;o00001_oonfX2o`0000Oo[<O^0_l00007ojg8kP03o`000?n^bNko
000000;o00000on_bNh01?l0003o/<_^ok3;k_n`bnh2o`0000?o/Lc]00?o0000ok?>k_ncc^h01?nc
c^h3o`0000Co]m;^0_l00003ok[Ck@04o`000?nlf>ko0000o`0000Go`M[/00Oo0000olKMj_o6gN[o
a]gZo`000?o<i>Wo000000CodnOT00Go0000om_WgOoKimgofnOMo`000003on;Ue@04o`000?oWhLco
in7<o`0000?oj][400Go0000on[B_OoZd[goj]:mo`000003onS:]`07o`000?oU`kCoiL>donG3]?l0
003oh[fbo`000002onJiYP03o`000?oQ/jOohK>W00;ohK>W00?o0000omb_ZOoL[jT00ooL[jT00ol0
003ofJJSomVVX`04omVVX`04o`000?oCY:OodjBWo`0000?odijP00?o0000olfMYOo=WJD00_o=WJD0
1Ol0003obiNOol^GWoo;Uioo000000;oaYJV00?o0000ol:?XOo2Sj401Oo2Sj42o`0000Co]hVU00?o
0000ojn1X_n_PJ800on_PJ800ol0003oYWRPojIhX003ojIhX0;o00001?nLMjP00ol0003oTg2Xoi=`
Z002oi=`Z003o`000?n9JZWoRFZY00;oRFZY0ol00003ogAEX005o`000?mZDZCoJU:TofYBY?l00000
0omUE:X01?l0003oI5ZbofAJ/_mTF[82o`0000;oD4na00?o0000oe]Q_omKHKl00_mKHKl3o`0000;o
EFC500Go0000ofemd_m]OM;oKGgBo`000004oh>Af003o`000?nFWm[oUYoJ00?oUYoJ00?o0000ojFX
f?nUZ=P01?nUZ=P00ol0003o/ZgDok:]e003o`000003ok2]eOl0003o^:k?00Go^:k?00?o0000okn]
b?l000001Onj[L`00ol0003o_Z[5okjZa@02okjZa@03o`000?njZl[o000000Oo_:O400?o0000okfR
__l000001OnhYLD00ol0003o^:30okRP`003okRP`003o`000?nfV[_o000000Go/io400?o0000ok2J
`?n`V/000on`V/000ol0003o[9BnojbD_P03ojbD_P;o00001_nXUlD00ol0003oY9C4ojBDa004ojBD
a003o`000?nPTLGoX97500?oX97500Co0000oib?a_nLSlKoW8o61_l00002oibHc`03o`000?nJVM7o
VYWA00CoVYWA00?o0000oiRJe?nHV]@01?nHV]@00ol0003oUicGoiNLe`03oiNLe`03o`000?nGWm[o
UioJ00?oUioJ00?o0000oiNRgOnGX]d00onGX]d00ol0003oUjKPoiNVh002oiNVh0Ko00000onK[N@0
0ol0003oVk3Voi^`iP04oi^`iP03o`000?nL/^OoW;;W00?oW;;W1Ol00003oijfj@03o`000?nO^>[o
WkSZ00CoWkSZ00?o0000oinijonO^N/00_nO^N/6o`0000?oXK_/00Go0000oj6lk?nQ_>coXKc/o`00
0002oj6lk003o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX01_oonfX006oooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003o[<O^ojc7kP02ojc7kP;o00000_n/anh00ol0003o[LS^ojg8kP04
ojg8kP?o00001_n_bNh00ol0003o/<_^o`000006ok7<k@03o`000?ncc^ko/lk^00?o00000onecnd0
1?l0003o]m;^o`000?l00005ok[Ck@?o00001?o1f^`2o`0000Coa]gZ1?l00002om?Wi005o`000?oK
imgofnOMom_WgOl000000ooRiMD01Ol0003oin7<onOQc?oWhLco000000?oj][400Co0000on[B_OoZ
d[go00001?oXb[L01Ol0003oiL>donG3]?oU`kCo000000;oh[fb00?o0000onJiY_l000001?oQ/jL0
0ol0003og:nYomb_Z@03omb_Z@03o`000?oIYZ?ofJJS00?ofJJS00?o0000om>TYooCY:L00_oCY:L0
1?l0003odijPom>NX?l00004olfMY@04o`000?o;UioobiNOo`0000?oaYJV00?o0000ol:?XOo2Sj40
1Oo2Sj400ol0003o]hVUokN9Y@04okN9Y@03o`000?n_PJ;o[h6R00;o[h6R00?o0000ojIhX?nVN:00
0_nVN:02o`0000GoW7NX00?o0000oi=`Z?nCL:P00_nCL:P00ol0003oRFZYohUZZ@02ohUZZ@03o`00
0?n1IZ_oPFJ[00Co00000omZDZ@01Ol0003oIEBZofEDZ_mUE:[o000000CoI5Zb0_l00002oe1?/@05
o`000?mKHKooFf6ooe]Q_ol000000_m[M</3o`0000CoKGgB00?o0000oh>Af?n3TMP00_n3TMP00ol0
003oUYoJoiJOfP03oiJOfP03o`000?nUZ=SoYJSH00?oYJSH0ol00005ok2]e@03o`000?nh[/oo^:k?
00?o^:k?0_l00007okZ]c004o`000?nnZ/Go_Z[5o`0000?o^Z_:00?o0000okbWa?nlYl@01?nlYl@2
o`0000Oo^:G500?o0000okRP`?nhX<000_nhX<02o`0000Ko/io400?o0000ok2J`?n`V/001?n`V/00
0ol0003o[9Bno`000002o`000003oj^Ka_l0003oZ9O500GoZ9O500?o0000ojBDa?nTU<@01?nTU<@0
0ol0003oX975oj2Aa@03oj2Aa@Co00000onOVLh00ol0003oW9S?oibHc`03oibHc`03o`000?nJVM7o
VYWA00?oVYWA00?o0000oiRJe?nHV]@01?nHV]@00ol0003oUicGoiNLe`03oiNLe`04o`000?nGWm[o
UioJoiNOfPgo00000onJZn800ol0003oVjgToi^]i004oi^]i003o`000?nK/>KoVk3V00?oVk3V00?o
0000oibbionL/^L00ol00002oijej003o`000?nN]^WoW[KY00CoW[KY00?o0000oinhj_nO^>X00onO
^>X5o`0000?oX;[[00?o0000oj6kk?nQ^n`01?nQ^n`01?l0003oXKc/oj6lk?nQ_>`4o`0000[ooo]Z
00?o0000oookJ_oonfX01_oonfX0073ooo]Z00?o0000oookJ_oonfX01OoonfX01?l0003o[<O^o`00
0?l00005ojc7kP03o`000?n]b>ko[LS^00?o00000on^b>d00ol0003o[lW^ojo9kP03ojo9kP?o0000
1_nac>d3o`0000Ko]Lo]0ol00004ok[Ck@;o00000onme^`2o`000003ol7Jk?l0003oa]gZ00Coa]gZ
00?o0000olcNi_o<g^H00_o<g^H4o`000003om_WgOl0003oh^GE00;oh^GE00Go0000onOQc?oWhLco
in7<o`000003on[Ja005o`000?oZd[goj]:mon[B_Ol000000ooXb[L01Ol0003oiL>donG3]?oU`kCo
000000Coh[fb00?o0000on6cYooQ/jL00_oQ/jL00ol0003og:nYomb_Z@03omb_Z@03o`000?oG[:co
000000CofJJS00?o0000om>TYooCY:L00_oCY:L00ol0003odijPo`000005olfMY@04o`000?o;Uioo
biNOo`0000?oaYJV00?o0000ol:?XOo2Sj401Oo2Sj400ol0003o]hVUokN9Y@04okN9Y@03o`000?n_
PJ;o[h6R00?o[h6R00Ko0000ojIhX?nVN:3o0000ojInZ?l00005oiagZ003o`000?nCL:SoTg2X00?o
Tg2X00Go0000ohUZZOn9JZWoRFZYo`000005oh5VZ`;o00000_mZDZ@01Ol0003oIEBZofEDZ_mUE:[o
000000CoI5Zb00Go0000ofQU_?l0003oD4nao`000004oe]Q_`03o`000?m[M<_oJgC;00;oJgC;1Ol0
0005oh>Af003o`000?nFWm[oUYoJ00;oUYoJ00?o0000ojFXf?nUZ=P00ol000000onUZ=So0000ok2]
e@06ok2]e@03o`000?nh[/oo^:k?00;o000000?o]JkBo`000?nj[L`01_nj[L`00ol0003o_Z[5o`00
0004okZ[bP03o`000?nlYlCo_:O400?o_:O400?o0000okRYb_l000001onhYLD00ol0003o^:30okRP
`002o`000003okBSaol0003o/io400Ko/io400?o0000ok2J`?n`V/000_n`V/03o`0000GoZi_600?o
0000ojRGaOnXUlD01?nXUlD00ol0003oY9C4ojBDa003ojBDa003o`000?nPTLGoX97500?o000000?o
XY[=o`000?nOVLh01OnOVLh00ol0003oW9S?oibHc`02oibHc`03o`000?nJVM7oVYWA00CoVYWA00?o
0000oiRJe?nHV]@00onHV]@01?l0003oUicGoiNLeonGW=L6o`0000?oVZKN00?o0000oiZXh?nJZ>00
0onJZ>000ol0003oVZ_RoiZ[hP05oiZ[hP03o`000?nK[NCoVjgT00?oVjgT00Co0000oi^`i_nK/>Ko
Vk3V1Ol00006oijej003o`000?nN]^WoW[KY00?oW[KY00?o0000oinhj_nO^>X00ol000000onP^N_o
0000oj2jj`06oj2jj`04o`000?nQ^ncoXK_/oj6kk0Ko000000GoXKg/o`000?nQ_NcoXKg/o`000009
oookJP03o`000?oonf[ooo]Z00Kooo]Z001aoookJP03o`000?oonf[ooo]Z00Gooo]Z0_l00006ojc7
kP?o00001on^b>d00ol0003o[lW^o`000002o`0000?o/<[]0_l000001?nac>go0000o`000?l00003
ok?=k@04o`000?necngo]Lo]okG?k@;o00000ongd>d2o`000003ok[CkOl0003o_MK/00Go_MK/0ol0
0004olKMjP03o`000?o<g^Koc=kV00;oc=kV00?o0000om;OhOoBgn400_oBgn47o`0000;oin7<00Co
0000on[Ja?oZf/Co00001?oZd[d01Ol0003oj<ZgonS:]ooXb[Oo000000?oiL>d00?o0000on:m/_oR
_K800_oR_K800ol0003ohK>Won6cY`02on6cY`03o`000?oL[jWog:nY00?og:nY00?o0000omN/[?l0
00001?oIYZ<00ol0003odjBWom>TY`02om>TY`03o`000?oCWZ3o000000GocIfU00?o0000ol^GWol0
00001Oo6UZH00ol0003o`XnQol:?X@03ol:?X@;o00001_ngRJD00ol0003o[h6Rojn1XP03ojn1XP03
o`000?nVN:3o000000;oYWjX00?o0000oiagZ?nLMjP01?nLMjP00ol0003oTg2Xoi=`Z002oi=`Z003
o`000?n9JZWoRFZY00;oRFZY00?o0000oh5VZon1IZ/00_n1IZ/00ol0003oNVJ`o`000002o`0000Co
IEBZ00?o0000ofAJ/_mTF[800_mTF[801?l0003oJ6Flo`000?l00004oe]Q_`03o`000?m[M<_oJgC;
00;oJgC;00Co0000og^7domkQm?oNhOC1Ol000000on3TMSo0000oiJOfP02oiJOfPCo00001OnUZ=P0
0ol0003o/:gEok2]e@04ok2]e@03o`000?nh[/oo000000Co]JkB00?o0000okZ]c?nj[L`01?nj[L`2
o`0000Ko^Z_:00?o0000okbWa?nlYl@00_l00003okRYbP03o`000?nhYLGo^:G500Co^:G500?o0000
okRP`?l000001?ndXlL00ol0003o/io4ok>Oa004ok>Oa003o`000?n`V/3o/9[000;o000000?o[Yo8
o`000?n[VlH01On[VlH00ol0003oZ9O5ojRGa@04ojRGa@03o`000?nTU<CoY9C400?oY9C40ol00005
oj:Jc@03o`000?nOVLkoWiW>00?oWiW>00?o0000oibHconLV<l00onLV<l00ol0003oVYWAoiZId@03
oiZId@04o`000?nHV]CoV9[DoiRJe0Ko00000onKY=/00ol0003oVZKNoiZVgP04oiZVgP03o`000?nJ
Z>3oVZSP00?oVZSP00?o0000oiZ[h_nJZn801?nJZn801?l0003oVjgToi^]i?nK[N@6o`0000CoWK?W
00?o0000oijej?nN]NP01?nN]NP01?l0003oW[KYoijfjOnN]^T5o`0000GoX;W[00?o0000oj2jjonP
^^/01?nP^^/4o`0000?oXKc/00Go0000oj6mk?nQ_NcoXKg/o`000003oj6mk003o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX01_oonfX007;ooo]Z0_l00007oookJP;o000000Co[<O^o`000?l0
003o00000on]b>d00ol0003o[/S]ojk8k@04ojk8k@;o00001on`b^d2o`0000Oo/lg]00?o0000okG?
kOl000001_ngd>d3o`0000Co_MK/0_l00003ol7GjP;o000000?oa]gZo`000?o<g^H00_o<g^H2o`00
00Cod]oQ00Go0000omSNfooHg]_of=kKo`000003omcKe@Co000000?oj][4o`000?oZd[d00_oZd[d0
1Ol0003oj<ZgonS:]ooXb[Oo000000?oiL>d00?o0000on:m/_oR_K800_oR_K800ol0003og[Rbo`00
0002on6cY`03o`000?oL[jWog:nY00?og:nY00Co0000omN/[?oG[:co00000ooIYZ<00ol0003odjBW
om>TY`03om>TY`03o`000?oCWZ3o000000KocIfU0_l00005olJFYP03o`000?o2Sj7o`XnQ00;o`XnQ
00?o0000okfAZ?l000001_ngRJD00ol0003o[h6Rojn1XP03ojn1XP;o00001?nVOZP00ol0003oW7NX
oiagZ003oiagZ003o`000?nCL:SoTg2X00;oTg2X00?o0000ohUZZOn9JZT00_n9JZT00ol0003oPFJ[
oh5VZ`02oh5VZ`04o`000?mjI[3oNVJ`ogYV/0;o00000omUE:X00ol0003oI5ZbofAJ/P02ofAJ/P03
o`000?mXIKcoJ6Fl00;o00001?mKHKl00ol0003oJgC;of]db`02of]db`05o`000?mkQm?oNhOCog^7
dol000000on;U]P5o`0000;oVJ7J00?o0000ojFXf?nUZ=P01OnUZ=P00ol0003o/:gEok2]e@03ok2]
e@;o00001_ne[]801?l0003o^Zg<okZ]c?nj[L`2o`000003okJ]d?l0003o^Z_:00Go^Z_:00?o0000
okbWa?l000001OnhZLX00ol0003o^:G5okRUa@04okRUa@;o00001OndXlL00ol0003o/io4ok>Oa004
ok>Oa003o`000?n`V/3o000000Co[Yo800?o0000oj^Ka_n[VlH01?n[VlH00ol0003oZ9O5ojRGa@03
ojRGa@03o`000?nTU<CoY9C400?o000000?oYIc=o`000?nRV/d01OnRV/d00ol0003oWiW>oinIcP03
oinIcP03o`000?nLV<ooW9S?00?oW9S?00Co0000oiZIdOnJVM7oVYWA1_l00003oibRf@03o`000?nK
Y=_oVjCK00CoVjCK00?o0000oiZVg_nJY]h01?nJY]h00ol0003oVZSPoiZXh003oiZXh004o`000?nJ
Zn;oVZ_RoiZ[hPKo00001?nM/NH00ol0003oWK?Woifci`04oifci`04o`000?nN]NSoW[GXoijej0Ko
00000onO^>X00ol0003oX;W[oj2ij`05oj2ij`03o`000?nP^^_oX;[[00?o000000?oXK_/o`000?nQ
_>`01OnQ_>`01?l0003oXKg/oj6mk?nQ_N`5o`0000Oooo]Z00?o0000oookJ_oonfX01_oonfX007Co
oo]Z00?o0000oookJ_oonfX01_oonfX2o`0000Ko[LS]00?o0000ojk8kOn^b>d00ol00002ojo9k@03
o`000?n`b^go/<[]00;o/<[]0_l00002ok7;k@03o`000?nccNgo/lg]00Co/lg]0ol00004okO@k@;o
00000onjd^`2o`000003okgFk?l0003o`MOZ00Go`MOZ1?l000000oo<g^Ko0000om;Oh@04om;Oh@05
o`000?oHg]_of=kKomSNfol000001OoLfmD00ol0003ogmK>omoFcP03o`0000;oj]:m00Go0000onS:
]ooXb[Ooj<Zgo`000003onG3]003o`000?oR_K;oh[fb00;oh[fb00Ko0000omjh/_oN^;;o0000on6c
Yol00005omb_Z@05o`000?oG[:coejb/omN/[?l000000_oIYZ<00ol0003odjBWom>TY`04om>TY`03
o`000?o=WJGocIfU00GocIfU0_l00005olJFYP03o`000?o2Sj7o`XnQ00;o`XnQ00?o0000okfAZ?l0
00001_ngRJD00ol0003o[h6Rojn1XP03ojn1XP03o`000?nVOZSoYWjX00?oYWjX00?o0000oiagZ?nL
MjP00onLMjP00ol0003oTg2Xoi=`Z002oi=`Z003o`000?n9JZWoRFZY00;oRFZY00?o0000oh5VZon1
IZ/00_n1IZ/00ol0003oNVJ`ogYV/002ogYV/0;o00000_mUE:X00ol0003oI5ZbofAJ/P02ofAJ/P04
o`000?mXIKcoJ6FlofQU_0?o00000_mKHKl00ol0003oJgC;of]db`02of]db`03o`000?mkQm?oNhOC
00;oNhOC00?o0000oh^Ff?n;U]P00_n;U]P00ol0003oVJ7JoiVQfP03oiVQfP03o`000?nUZ=SoYJSH
00CoYJSH00?o0000ok2]eOn`[MD00ol000000on^[=Ko0000okF^dP05okF^dP04o`000?nj[Lco0000
o`0000Co]Zg@00?o0000okZ[b_njZlX00onjZlX2o`0000Oo^:W:00?o0000okRUaOnhYLD00_nhYLD0
0ol0003o]:O;o`000006okBSa`03o`000?ncWlCo/io400?o/io40_l00005ojjOb003o`000?n[VlKo
Zi_600CoZi_600?o0000ojRGaOnXUlD00onXUlD3o`0000GoYIc=00?o0000oj:JcOnRV/d00onRV/d0
0ol0003oWiW>oinIcP04oinIcP03o`000?nLV<ooW9S?00Ko00000onMXML00ol0003oW:;IoibRf@04
oibRf@03o`000?nKY=_oVjCK00CoVjCK00?o0000oiZVg_nJY]h00onJY]h01?l0003oVZSPoiZXh?nJ
Z>06o`0000?oWJoT00?o0000oifai_nM/NH01OnM/NH01?l0003oWK?WoifcionM/nL6o`0000?oWkOY
00?o0000oinhj_nO^>X01?nO^>X00ol0003oX;W[oj2ij`02oj2ij`Go00001OnQ^n`00ol0003oXKc/
oj6lk003oj6lk0Ko00000_nR_Nd00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z00Kooo]Z
001eoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000ojg8kOn]b>d00on]b>d3o`0000Ko[lW]00Co
0000ok3:kOl0003o00001Onabnd00ol0003o/lg]ok?=k@03o`0000?o]Lk]0_l000000ongd>go0000
ok[Bk005ok[Bk0?o00001?o1enX2o`0000?oa]SW0ol00004om;Oh@05o`000?oHg]_of=kKomSNfol0
00001OoLfmD01Ol0003ogmK>omoFc_oOe/ko000000;ohM780ol00002onS:]`05o`000?oU`kCoiL>d
onG3]?l000001?oR_K801ol0003og[Rbomjh/_oN^;;o0000on6cYol000001?oL[jT00ol0003oejb/
omN/[002omN/[003o`000?oIYZ?o000000OodjBW00?o0000olfMYOo=WJD01Oo=WJD00ol0003oaYJV
olJFYP04olJFYP05o`000?o2Sj7o`XnQol:?XOl000000onmTJP00ol0003o]hVUokN9Y@03okN9Y@03
o`000?n_PJ;o[h6R00;o[h6R0_l00005ojInZ003o`000?nLMjSoW7NX00?oW7NX00?o0000oi=`Z?nC
L:P00_nCL:P00ol0003oRFZYohUZZ@02ohUZZ@03o`000?n1IZ_oPFJ[00?oPFJ[00Ko0000ogYV/?mj
I[3oNVJ`o`000?mgJ;H3o`0000GoI5Zb00Co0000ofQU_?mXIKco00000_m`LlH3o`0000CoJgC;00?o
0000og^7domkQm<00_mkQm<00ol0003oRiKHoh^Ff003oh^Ff003o`000?nIXM[oVJ7J00?oVJ7J00?o
0000ojFXf?nUZ=P00onUZ=P3o`0000Go[ZcF00?o0000okF^d_ne[]800one[]82o`0000Oo]Zg@00?o
0000okZ[b_njZlX00_l000000onf[<oo0000okRYbP06okRYbP03o`000?nhYLGo^:G500;o00000ond
Yl/00ol0003o]:?7okBSa`03okBSa`04o`000?ncWlCo/io4ok>Oa0;o000000?o/:?;o`000?n^WlP0
1On^WlP00ol0003oZi_6oj^KaP03oj^KaP03o`000?nXUlGoZ9O500?o000000?oZ9k=o`000?nUW<d0
1OnUW<d00ol0003oXY[=oj:Jc@04oj:Jc@03o`000?nOVLkoWiW>00Ko00000onOXMH00ol0003oWJ7G
oifQe`04oifQe`03o`000?nLX]WoW:;I00CoW:;I00?o0000oi^TfonKY=/00onKY=/01?l0003oVZKN
oiZVg_nJY]h6o`0000?oWJgS00?o0000oif_i?nM[n@01?nM[n@00ol0003oWK7VoifaiP04oifaiPCo
00000onO]NP00ol0003oWkOYoingj@04oingj@04o`000?nO^>[oWkSZoinhjPOo00000onQ^^/00ol0
003oXK_/oj6kk004oj6kk003o`000?nQ_>coXKc/00?o000000?oX[g/o`000?nR_Nd00onR_Nd01?l0
003oX[g]oj:mkOl00007oookJP03o`000?oonf[ooo]Z00Gooo]Z001foookJP03o`000?oonf[ooo]Z
00Oooo]Z00?o0000ojg8kOl000000_l00003ojk8k@03o`000?n_bNgo[lW]00?o[lW]0ol00006ok7;
k@?o00001onec^d3o`0000Co^];/0_l00003okgCjP04o`000?o1en[o0000o`0000Coa]SW00Co0000
ol_Ii?o;fNCobmWT0_l000000ooBgn7o0000omSNf`02omSNf`03o`000?oLfmGog=_E00?og=_E00Go
0000omoFc_oOe/kogmK>o`000004on7Ab005o`000?oPbl?o0000onS:]ol000000ooU`k@00ol0003o
h[fbon:m/P02on:m/P03o`000?oN^;;og[Rb00;og[Rb00?o0000omb_ZOoL[jT00ooL[jT00ol0003o
ejb/omN/[002omN/[003o`000?oIYZ?o000000OodjBW00?o0000olfMYOo=WJD01Oo=WJD00ol0003o
aYJVolJFYP04olJFYP04o`000?o2Sj7o`XnQo`0000Co_I6X00?o0000okN9YOngRJD00ongRJD01ol0
003o[h6Rojn1X_n_PJ;o0000ojj6Z_l000001OnVOZP00ol0003oW7NXoiagZ003oiagZ003o`000?nC
L:SoTg2X00?oTg2X00Go0000ohUZZOn9JZWoRFZYo`000005oh5VZ`05o`000?mjI[3oNVJ`ogYV/?l0
00000omgJ;H2o`0000CoI5Zb00Go0000ofQU_?mXIKcoJ6Flo`000004og1caPCo000000?oJgC;o`00
0?mkQm<00omkQm<00ol0003oRiKHoh^Ff003oh^Ff003o`000?nIXM[oVJ7J00;oVJ7J00?o0000ojFX
f?nUZ=P00ol000000onVZMWo0000ojj/eP06ojj/eP03o`000?ne[];o]JkB00;o000000?o/ZkDo`00
0?nf[M001_nf[M000ol0003o^Z_:o`000004okJ/c`03o`000?nhZL[o^:W:00Co^:W:00?o0000okRU
aOl000001OndYl/00ol0003o]:?7okBSa`03okBSa`04o`000?ncWlCo0000o`0000Co/:?;00?o0000
ojjOb?n^WlP00on^WlP00ol0003oZi_6oj^KaP03oj^KaP?o00001OnXW/d00ol0003oYIc=ojFLc@04
ojFLc@03o`000?nRV/goXY[=00;oXY[=1?l00003oj6Qe003o`000?nOXMKoWj7F00CoWj7F00?o0000
oifQeonMXML01?nMXML00ol0003oW:;IoibRf@03oibRf@04o`000?nKY=_oVjCKoi^Tf`Ko00000onM
Zn400ol0003oWJgSoif]h`04oif]h`03o`000?nM[nCoWJoT00CoWJoT00?o0000oifai_nM/NH00ol0
00000onN]>Oo0000oinej005oinej003o`000?nO]nWoWkOY00?oWkOY1?l00003oj2ij`03o`000?nQ
^^_oXK[[00GoXK[[00Co0000oj6kk?nQ^ncoXK_/1Ol00005oj:mk005o`000?nR_NgoX[g]oj:mkOl0
00000_nR_Nd2o`0000Kooo]Z00?o0000oookJ_oonfX01OoonfX007Oooo]Z0_l00008oookJP03o`00
0?n^b>go[/S]00Go[/S]00?o0000ojo9kOl000000_l00003ok39k@;o000000Co/L_]o`000?l0003o
00000oncc>`00ol0003o]Lk]okG>k@02okG>k@;o00000ongcn`01?l0003o^];/o`000?l00005okgC
jP?o00001?o6f>L00ol0003obmWTol_Ii003ol_Ii0Co000000?of=kKo`000?oLfmD01?oLfmD01Ol0
003ogmK>omoFc_oOe/ko000000CohM7800Co0000on3;`ooPbl?oh<_30_l00002onG3]003o`000?oR
_K;oh[fb00;oh[fb00?o0000omjh/_oN^;800ooN^;800ol0003og:nYomb_Z@03omb_Z@03o`000?oG
[:coejb/00?oejb/0_l00006om>TY`;o00001_o=WJD2o`0000OoaYJV00?o0000ol:?XOl000001?nm
TJP00ol0003o]hVUokN9Y@04okN9Y@03o`000?n_PJ;o000000?o[XJZ00?o0000ojInZ?nVOZP00_nV
OZP00ol0003oW7NXoiagZ003oiagZ003o`000?nCL:SoTg2X00?oTg2X00?o0000ohUZZOn9JZT00_n9
JZT00ol0003oPFJ[oh5VZ`02oh5VZ`03o`000?mjI[3oNVJ`00;oNVJ`00Co0000ogMX]_mgJ;KoMfRf
0ol00002ofAJ/P05o`000?mXIKcoJ6FlofQU_?l000001?m`LlH01?l0003oNX;?ogZ2comjP/l5o`00
0003og^7dol0003oRiKH00CoRiKH00Co0000oiVQf_nIXM[oVJ7J1?l00005ojJYf@03o`000?n^[=Ko
[ZcF00Co[ZcF00?o0000okF^d_l000001?nb[]@00ol0003o]Zg@okJ]d004okJ]d0;o00001_nf[<l0
0ol0003o^:W:okRYbP03okRYbP;o00001_ndYl/00ol0003o]:?7okBSa`03okBSa`;o00001_n`Xl/0
0ol0003o[Yo8ojjOb003ojjOb003o`000?n[VlKoZi_600?o000000?oZZ;>o`000?nXW/d01OnXW/d0
0ol0003oYIc=ojFLc@04ojFLc@03o`000?nRV/go000000;o000000?oXj;Co`000?nQXM@01OnQXM@0
0ol0003oWj7FoinQeP04oinQeP03o`000?nMXMOoWJ7G00?oWJ7G00Co0000oibRfOnLX]WoW:;I1_l0
0003oifYg`03o`000?nMZn7oWJ_Q00CoWJ_Q00?o0000oif]honM[N<01?nM[N<01?l0003oWJoToif_
i?nM[n@5o`0000GoW[CW00?o0000oinej?nO]NP00onO]NP00ol0003oWkOYoingj@03o`000003oj2h
j_l0003oX;W[00GoX;W[00?o0000oj6jjonQ^^/01?nQ^^/4o`0000?oX[c/00?o0000oj:mk?nR_N`0
1OnR_N`00ol0003oX[g]oj:mk@03o`000003oj:nkOl0003ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
1OoonfX007Wooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o[/S]ojk8k@04ojk8k@?o00001_n`
bNd3o`0000Ko/lc/00Co0000okG>kOl0003o00001Ongcn`3o`0000Go_M?Z00Co0000ol7Cj?o1dnSo
`M?X0_l000000oo6f>Oo0000ol_Ii004ol_Ii003o`000?o?f=oocmSO00;ocmSO0_l00004omcKe@05
o`000?oOe/kogmK>omoFc_l000001?oQdLP00ol0003oh<_3on3;``02on3;``05o`000?oNaL3o0000
onG3]?l000001?oR_K800ol0003og[Rbomjh/P02omjh/P03o`000?oI];?o000000?og:nY00?o0000
omN/[?oG[:`01?oG[:`00ol0003odjBWom>TY`05om>TY`;o00001_o=WJD00ol0003ob9f/o`000006
olJFYP;o00001OnmTJP00ol0003o]hVUokN9Y@04okN9Y@;o00001?n^QZX00ol0003oYWjXojInZ003
ojInZ003o`000?nLMjSoW7NX00;oW7NX00?o0000oi=`Z?nCL:P00onCL:P00ol0003oRFZYohUZZ@02
ohUZZ@03o`000?n1IZ_oPFJ[00;oPFJ[00?o0000ogYV/?mjI[000_mjI[001Ol0003oMfRfogMX]_mg
J;Ko000000;oMVjm1?l00003ofQU_003o`000?m`LlKoL7?600;oL7?600Go0000ogZ2comjP/ooNX;?
o`000003ohJ?e@_o00000_nLXmX00ol0003oYZWIojJYf@05ojJYf@03o`000?n^[=Ko[ZcF00?o[ZcF
0_l00006ok:^e004o`000?nf[M3o]Zg@okJ]d0;o000000?o/jkCo`000?nf[<l01Onf[<l00ol0003o
^:W:okRYbP03o`000003okB[col0003o]:O;00Ko]:O;00?o0000okBSaol000000_l000000onaYlko
0000ok2Sb`06ok2Sb`03o`000?n^WlSo[Yo800;o[Yo80ol00005ojZRcP03o`000?nXW/goZ9k=00Co
Z9k=00?o0000ojFLcOnUW<d00onUW<d2o`0000GoXj;C00?o0000oj6Qe?nQXM@01?nQXM@00ol0003o
Wj7FoinQeP03oinQeP04o`000?nMXMOoWJ7GoifQe`Ko00000onNZ=d00ol0003oWJWOoifYg`04oifY
g`03o`000?nMZn7oWJ_Q00?oWJ_Q00?o0000oif]honM[N<00_nM[N<6o`0000?oW[;V00?o0000oijd
ionN]>L01?nN]>L01?l0003oWkGXoinej?nO]NP5o`0000GoX;SZ00?o0000oj2ijonP^N/01?nP^N/0
0ol0003oXK[[oj6jj`03o`000003oj6kjol0003oX[c/00GoX[c/00?o0000oj:mk?nR_N`00_nR_N`5
o`0000;oX[k]00Co0000oj:nkOnR_^go00001OoonfX00ol0003ooo]ZoookJP05oookJP00N_oonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?n^b>go[/S]00?o00000on_b>d01?l0003o/<W]ok39kOn`
bNd2o`0000?o/L[/00?o0000ok?<k?ncc>`00oncc>`3o`0000Co]lo/0_l00003ok[?j`05o`000?nm
dn[o_M?ZokgCj_l000001Oo1dnP3o`0000?obmWT0_l00004oloHg`03o`000?oCe]_odmKK00;o0000
00?og=_Eo`000?oOe/h00_oOe/h00ol0003ohM78on7Ab002on7Ab003o`000?oPbl?oh<_300;oh<_3
00Go0000omk5`?oNaL3og/G0o`000004on:m/P03o`000?oN^;;og[Rb00?og[Rb00?o0000omVd/ol0
00000ooL[jT00ol0003oejb/omN/[004omN/[003o`000?oCY:OodjBW00CodjBW00Co0000oljS[?o>
Xjco00001?o=WJD01?l0003ob9f/olRM[?l00006olJFYP03o`000?nmTJSo_I6X00Co_I6X00?o0000
okN9YOngRJD01?ngRJD00ol0003o[XJZojj6ZP03ojj6ZP03o`000?nVOZSoYWjX00?oYWjX00?o0000
oiagZ?nLMjP00_nLMjP00ol0003oTg2Xoi=`Z003oi=`Z003o`000?n9JZWoRFZY00;oRFZY00?o0000
oh5VZon1IZ/00_n1IZ/00ol0003oNVJ`ogYV/002ogYV/003o`000?mgJ;KoMfRf00;oMfRf00?o0000
ogI^_OmfK[d00_mfK[d2o`0000;oJ6Fl00?o0000og1ca_m`LlH00_m`LlH00ol0003oNX;?ogZ2c`02
ogZ2c`03o`000?n6SmGoQXoE00;oQXoE00?o0000oi:KfOnBVmT00onBVmT00ol0003oW:?JoibSfP03
oibSfP03o`000?nVZMWoYZWI00CoYZWI00?o0000ojj/e_n^[=H00ol000000on/[MSo0000ok:^e005
ok:^e004o`000?nf[M3o0000o`0000Co/jkC00?o0000okJ/conf[<l00onf[<l3o`0000Go]:_?00?o
0000okBWbondYl/00ondYl/3o`0000Go/JO>00?o0000ok2Sbon`Xl/01?n`Xl/00ol0003o[Yo8o`00
0002o`000003ojbUcol0003oZZ;>00KoZZ;>00?o0000ojRNcOnXW/d00onXW/d00ol0003oYIc=ojFL
c@03o`000003ojFSdol0003oXj;C00CoXj;C00?o0000oj6Qe?nQXM@01?nQXM@01?l0003oWj7FoinQ
e_nOXMH6o`0000?oWjOL00?o0000oijXgOnNZ=d01?nNZ=d00ol0003oWJWOoifYg`03oifYg`04o`00
0?nMZn7oWJ_Qoif[h@Oo00000onN/ND00ol0003oW[;VoijbiP04oijbiP04o`000?nN]>OoW[CWoijd
i`Ko00001?nP]nT00ol0003oX;SZoj2hjP04oj2hjP04o`000?nP^N_oX;W[oj2ij`Go00001OnQ^n/0
1?l0003oX[c/oj:lk?nR_>`7o`0000?oX[g/00Go0000oj:nkOnR_^goX[k]o`000002oj:nk@;o0000
1?oonfX00ol0003ooo]ZoookJP05oookJP00NooonfX00ol0003ooo]ZoookJP06oookJP;o00001on_
b>d00ol0003o/<W]o`000006ok7:k003o`000?ncc>co000000;o00000ondc>`2o`000003okO?k?l0
003o^/o[00Go^/o[00?o0000okgCj_l000001Oo1dnP01ol0003oa=CVolCDi_o4e>Ko0000ol_Ii?l0
00001Oo?f=l00ol0003odmKKom?Ff`02om?Ff`Co000000?ogmK>o`000?oQdLP01?oQdLP01Ol0003o
h<_3on3;`ooPbl?o000000Cog/G000?o0000on:m/_oR_K800_oR_K800ol0003og[Rbomjh/P02omjh
/P07o`000?oI];?ofKBcomVd/ol0003og:nYo`000006omN/[003o`000?oBZ[3o000000GodjBW00Co
0000oljS[?o>Xjco00001?o=WJD01?l0003ob9f/olRM[?l00006olJFYP03o`000?nmTJSo_I6X00Co
_I6X00?o0000okN9YOngRJD00ongRJD2o`0000Go[XJZ00?o0000ojInZ?nVOZP00onVOZP00ol0003o
W7NXoiagZ002oiagZ003o`000?nCL:SoTg2X00?oTg2X00?o0000ohUZZOn9JZT00_n9JZT00ol0003o
PFJ[oh5VZ`02oh5VZ`03o`000?mjI[3oNVJ`00?oNVJ`00Go0000ogMX]_mgJ;KoMfRfo`000004ogI^
_@03o`000?miMlGo000000;o00001Om`LlH01Ol0003oNX;?ogZ2comjP/oo000000GoQXoE00?o0000
oi:KfOnBVmT00onBVmT00ol0003oW:?JoibSfP03oibSfP04o`000?nVZMWoYZWIojJYf@Go00001On/
[MP00ol0003o/ZkDok:^e003ok:^e0;o00001onc[]<00ol0003o]Zc?okJ/c`02o`000003ok:]dol0
003o]:_?00Ko]:_?00?o0000okBWbondYl/00_l000000onaZ]7o0000ok6WcP06ok6WcP03o`000?n`
Xl_o/:?;00?o/:?;0_l00005ojbUc`03o`000?nZX/koZZ;>00CoZZ;>00Co0000ojRNcOnXW/goZ9k=
1Ol00005ojFSd`03o`000?nSX]?oXj;C00?oXj;C00?o0000oj6Qe?nQXM@00onQXM@4o`0000?oXJOK
00?o0000oinWg?nOYm`01?nOYm`00ol0003oWZSMoijXg@03oijXg@04o`000?nMZMooWJWOoifYg`Ko
00000onO[n<00ol0003oW[7Uoijai@05oijai@03o`000?nN/^KoW[;V00?oW[;V1?l00003oj2fj003
o`000?nP]nWoX;OY00GoX;OY00Co0000oj2hj_nP^>[oX;SZ1_l00003oj6kj`03o`000?nQ^n_oXK_[
00CoXK_[1?l00004oj:mk003o`000?nR_NcoX[g/00CoX[g/00?o0000oj:nkOnR_^d00ol000000onS
_^go0000oookJP03oookJP03o`000?oonf[ooo]Z00Gooo]Z001loookJP;o00002?oonfX00ol0003o
[lS]ojo8k@04ojo8k@?o00001_nab^`2o`0000Oo]<c/0ol00006ok[?j`?o00000oo1dnP2o`0000Co
a=CV0ol00004oloHg`03o`000?oCe]_odmKK00;odmKK00?o0000omKCe_oFdmH00_oFdmH2o`0000Co
hM7800Go0000on3;`ooPbl?oh<_3o`000004omk5`003o`000?oL`Kko000000;oh[fb00?o0000omjh
/_oN^;800ooN^;801ol0003ofKBcomVd/ooI];?o0000omb_ZOl000001_oG[:`00ol0003odZZ`o`00
0004om>TY`05o`000?o>XjcocZ>/oljS[?l000000oo=WJD01Ol0003ob9f/olRM[?o8WJco000000Go
aYJV0_l00006okfAZ003o`000?ngRJGo]hVU00;o]hVU00?o0000okB=[Ol000001On^QZX00ol0003o
YWjXojInZ003ojInZ003o`000?nLMjSoW7NX00?oW7NX00?o0000oi=`Z?nCL:P00onCL:P01Ol0003o
RFZYohUZZOn9JZWo000000CoPFJ[00?o0000ogYV/?mjI[000omjI[001Ol0003oMfRfogMX]_mgJ;Ko
000000GoMVjm00Co0000ogUgaOmiMlGoNGO51?l000000om`LlKo0000ogZ2c`03ogZ2c`03o`000?n6
SmGoQXoE00?oQXoE00?o0000oi:KfOnBVmT00onBVmT01?l0003oW:?JoibSf_nLXmX5o`0000?oYZ[J
00?o0000ojb]f?n/[MP01?n/[MP00ol0003o/ZkDok:^e003o`000003ojn^eol0003o/jkC00Ko/jkC
00?o0000okJ/col000001?nb[M<00ol0003o]:_?okB[c`04okB[c`03o`000?ndYl_o000000Co/J[A
00?o0000ok6Wc_naYlh01?naYlh00ol0003o/:?;ok2Sb`03o`000003ojjXdOl0003o[:G?00Go[:G?
00?o0000ojZRc_nZX/h00onZX/h4o`0000?oYjGC00?o0000ojFSdonUXm<01?nUXm<00ol0003oXj;C
oj>Rd`03oj>Rd`03o`000?nQXMCoXJ7D00?o000000?oXZOJo`000?nQYm/01OnQYm/00ol0003oWjOL
oinWg003oinWg003o`000?nNZ=goWZSM00?oWZSM1?l00003oin^hP03o`000?nO[n?oWjoS00CoWjoS
00?o0000oijaiOnN/ND01?nN/ND00ol0003oW[;VoijbiP03o`000003oj2eiol0003oX;KX00GoX;KX
00?o0000oj2gjOnP]nT01?nP]nT4o`0000?oXK[Z00?o0000oj6kjonQ^n/01?nQ^n/00ol0003oXK_[
oj6kj`03o`000003oj:lk?l0003oX[g/00KoX[g/00Co0000oj:mk?nR_NcoX[g/1Ol00002oj>nk@04
o`000?nS_^goXkk]o`0000?ooo]Z00?o0000oookJ_oonfX01OoonfX007kooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003o[lS]ojo8k@03o`0000?o/<W]00?o0000ok7:k?nab^`00ol00002ok;;k003
o`000?ndc>co]<c/00;o]<c/0_l00003okO=j`03o`000?njcn_o^/o[00?o00000onld>T00ol0003o
`M?Xo`000005olCDiP04o`000?o8dn?ob=?SolSCh`;o000000?ocmSOo`000?oCe]/00ooCe]/00ol0
003oe]?FomKCeP03omKCeP06o`000?oGcm7o0000o`000?oQdLSo00001?oPbl<00ol0003og/G0omk5
`002omk5`006o`000?oL`Kkog<6no`000?oR_K;o00001?oN^;800ol0003ofKBcomVd/`03omVd/`03
o`000?oG[:coejb/00Coejb/00Co0000om:Z/?oBZ[3o00001?oCY:L01Ol0003ocZ>/oljS[?o>Xjco
000000;ocIfU00?o0000olRM[?o8WJ`00oo8WJ`00ol0003oaYJVolJFYP02olJFYP03o`000?o1V:go
000000Ko_I6X00Co0000okN9YOngRJGo00000_ndSJd00ol0003o[XJZojj6ZP04ojj6ZP03o`000?nV
OZSoYWjX00;oYWjX00?o0000oiagZ?nLMjP00onLMjP00ol0003oTg2Xoi=`Z003oi=`Z003o`000?n9
JZWoRFZY00;oRFZY00?o0000oh5VZon1IZ/00_n1IZ/00ol0003oNVJ`ogYV/002ogYV/003o`000?mg
J;KoMfRf00;oMfRf00?o0000ogI^_OmfK[d00_mfK[d01Ol0003oNGO5ogUgaOmiMlGo000000?oOh;<
1ol00005ohJ?e@04o`000?nBVmWoTY_Ioi:Kf@Ko00000_nNY]/00ol0003oYZ[JojJZfP04ojJZfP03
o`000?n/[MSo[:gH00?o[:gH0ol00005ojn^e`03o`000?nc[]?o/jkC00Co/jkC0_l00005ok:]d`03
o`000?ndZloo]:_?00Co]:_?0_l00005ok6Zd@03o`000?naYlko/JO>00Co/JO>0ol00005ojjXd@03
o`000?n/YLoo[:G?00?o[:G?00?o0000ojZRc_nZX/h00ol000000onYYmCo0000ojNUd`05ojNUd`03
o`000?nUXm?oYJ?C00?oYJ?C00Co0000oj>RdonSX]?oXj;C1Ol00005oj:WfP03o`000?nQYm_oXJOK
00CoXJOK00?o0000oinWg?nOYm`00_nOYm`00ol0003oWZSMoijXg@03o`000003oj2]hOl0003oWjkR
00GoWjkR00?o0000oin_honO[n<01?nO[n<01?l0003oW[7UoijaiOnN/ND5o`0000GoX;GW00?o0000
oj2fj?nP]^P01?nP]^P00ol0003oX;OYoj2gj@03o`000003oj6ij_l0003oXK[Z00GoXK[Z00Co0000
oj6kjonQ^n_oXK_[1Ol00005oj:lk003o`000?nR_NcoX[g/00CoX[g/1?l00003oj>nk@03o`000?nS
_^goXkk]00;oXkk]00Co0000oj>nkOl0003o00000_oonfX00ol0003ooo]ZoookJP05oookJP00Oooo
nfX00ol0003ooo]ZoookJP06oookJP;o00001_n`bNd3o`0000Ko//_/00Co0000okC<k?l0003o0000
1OngcN/3o`0000Ko_=3Y0ol00004olCDiP03o`000?o8dn?ob=?S00?ob=?S0ol00003om?Ff`03o`00
0?oFdmKoe]?F00?oe]?F00?o0000omO?dOoGcm400_oGcm42o`0000?oh<_300?o0000omk5`?oNaL00
0_oNaL000ol0003og<6nomc1_P02omc1_P03o`000?oN^;;og[Rb00?og[Rb00?o0000omVd/ooI];<0
0ooI];<00ol0003oejb/omN/[004omN/[005o`000?oBZ[3odZZ`om:Z/?l000000_oCY:L00ol0003o
cZ>/oljS[002oljS[004o`000?o=WJGocIfUo`0000Gob9f/00Go0000olJFY_o6UZKoaYJVo`000002
ol6H[@03o`000?nmTJSo_I6X00Co_I6X00?o0000okN9YOl000001?ndSJd00ol0003o[XJZojj6ZP03
ojj6ZP03o`000?nVOZSoYWjX00;oYWjX00?o0000oiagZ?nLMjP00onLMjP00ol0003oTg2Xoi=`Z00<
o`000003oh5VZol0003oNVJ`00?oNVJ`00?o0000ogMX]_mgJ;H00_mgJ;H00ol0003oMVjmogI^_@02
ogI^_@03o`000?miMlGoNGO500;oNGO500?o0000ogn2c?moP/`00_moP/`01?l0003oQXgCohJ=don6
SM<:o`0000?oUioJ00?o0000oijVfonNY]/00onNY]/00ol0003oYZ[JojJZfP04ojJZfP03o`000?n/
[MSo000000;o000000?oZjkJo`000?n_[]L01_n_[]L01?l0003o/jkCok>^donc[]<2o`000003ok2_
eol0003o/ZgC00Go/ZgC00Co0000okB[condZloo]:_?0_l000000ona[MCo0000ok6Zd@05ok6Zd@04
o`000?naYlko/JO>ok6WcP;o000000?o[j_Co`000?n^Z=401On^Z=400ol0003o[:G?ojbUc`03ojbU
c`?o00001OnYYm@00ol0003oYjGCojNUd`03ojNUd`03o`000?nUXm?oYJ?C00?oYJ?C1?l00003ojBX
f@03o`000?nRYm[oXZOJ00GoXZOJ00?o0000oj6WfonQYm/00onQYm/01?l0003oWjOLoinWg?nOYm`4
o`0000GoX:gQ00?o0000oin^h_nO[^801?nO[^801?l0003oWjoSoin_honO[n<6o`0000?oX;CV00?o
0000oj2eionP]NL01?nP]NL00ol0003oX;KXoj2fj002oj2fj0Go00001OnQ^NX00ol0003oXK[Zoj6j
jP03oj6jjPCo00000onR_>/00ol0003oX[c/oj:lk005oj:lk003o`000?nR_NcoX[g/00?o000000?o
Xkg/o`000?nS_^d01OnS_^d00ol0003oXkk]oj>nk@03o`000003oj>okOl0003ooo]Z00;ooo]Z00?o
0000oookJ_oonfX01?oonfX0083ooo]Z00?o0000oookJ_oonfX01ooonfX01?l0003o/<W]ok39kOn`
bNd2o`0000?o/LW/00?o0000ok;;k?nbbn`00onbbn`3o`0000Co]lg[0_l00003okW=j@04o`000?nl
d>Wo_=3Yokc@j@;o00000onod>L2o`000003olCDi_l0003ob=?S00Cob=?S00Oo0000ol_Bgoo;d]oo
bm;Oo`000?oCe]_o000000Goe]?F00?o0000omO?dOoGcm400_oGcm401_l0003of<_=omS;cOl0003o
h<_3o`0000Cog/G000?o0000omc1__oL`Kh00ooL`Kh2o`0000Cog[Rb00?o0000omVd/ooI];<00_oI
];<00ol0003oeK:fo`000004omN/[003o`000?oBZ[3odZZ`00;odZZ`00Co0000om>TYooCY:Oo0000
1Oo>Xj`2o`0000Kob9f/00Co0000olJFY_o6UZKo00000oo1V:d00ol0003o_I6XokfAZ004okfAZ0;o
00001OndSJd00ol0003o[XJZojj6ZP03ojj6ZP03o`000?nVOZSoYWjX00?oYWjX00Co0000oiagZ?nL
MjSoW7NX1?l00003oiQk/P03o`000?nAN;?oTGRc00;oTGRc00Co0000oh]f]_n;M[KoRgJf1Ol00002
ogYV/005o`000?mgJ;KoMfRfogMX]_l000001OmfK[d01Ol0003oNGO5ogUgaOmiMlGo000000GoOh;<
00Go0000ohJ=don6SM?oQXgCo`000005ohjGe`03o`000?nGWm[oUioJ00CoUioJ00?o0000oijVfonN
Y]/00onNY]/00ol0003oYZ[JojJZfP03ojJZfP;o00001On[[]X00ol0003o[jkGojn^e`04ojn^e`04
o`000?nc[]?o0000o`0000Co/:oG00?o0000ok:]donb[M<00onb[M<01?l0003o]:_?o`000?l00004
ok6]e003o`000?naZ]7o/J[A00?o/J[A00Co0000ok6Wc_l0003o00001?n_Zm<00ol0003o[ZSAojjX
d@03ojjXd@03o`000?n/YLoo[:G?00?o000000?oZjWEo`000?nYYm@01OnYYm@00ol0003oYjGCojNU
d`03ojNUd`03o`000?nUXm?oYJ?C00?o000000?oYJWIo`000?nTZ=T01OnTZ=T00ol0003oXZOJoj:W
fP04oj:WfP04o`000?nQYm_oXJOKoj6Wf`Ko00000_nQ[Ml00ol0003oX:gQoj2]h@05oj2]h@04o`00
0?nO[^;oWjkRoin^hPKo00000onP/nD00ol0003oX;CVoj2diP04oj2diP04o`000?nP]NOoX;GWoj2e
i`Oo00000onQ^>T00ol0003oXKWZoj6ijP04oj6ijP03o`000?nQ^^[oXK[Z00?o000000?oX[_[o`00
0?nR_>/01OnR_>/00ol0003oX[c/oj:lk002oj:lk0Go00001OnS_N`01?l0003oXkk]oj>nkOnS_^d5
o`0000;oXko]00Co0000oj>okOnS_ngo00000_oonfX00ol0003ooo]ZoookJP04oookJP00POoonfX0
0ol0003ooo]ZoookJP07oookJP03o`000?n`bNgo000000Ko/LW/00?o0000ok;;k?l000000_l00003
okC;j`;o000000?o]lg[o`000?nicNT01OnicNT00ol0003o_=3Yo`000006oko@i`?o00000oo8dn<2
o`0000Cobm;O0ol00004omKCeP03o`000?oGcm7oeloA00;oeloA00?o0000omS;cOoHbld00_oHbld2
o`0000Cog/G000?o0000omc1__oL`Kh00_oL`Kh01?l0003ofKbmomVl_Ol00002omjh/P03o`000?oI
];?ofKBc00?ofKBc00?o0000omFb]_l000000ooG[:`00ol0003odZZ`om:Z/003om:Z/003o`000?oC
Y:Oo000000KocZ>/0_l00006olRM[004o`000?o6UZKoaYJVo`0000?o`IR]00?o0000okfAZ?nmTJP0
1?nmTJP00ol0003o]8f]okB=[@04okB=[@03o`000?n^QZ[o[XJZ00?o[XJZ00?o0000ojInZ?nVOZP0
0onVOZP4o`000003oin0/Ol0003oV7^b00CoV7^b00?o0000oi5h/onAN;<00_nAN;<00ol0003oRgJf
oh]f]P02oh]f]P04o`000?n6M[[oQWJjohIf^PKo000000?oMfRfo`000?mfK[d00omfK[d00ol0003o
NGO5ogUga@02ogUga@03o`000?moP/coOh;<00;oOh;<00?o0000ohJ=don6SM<00_n6SM<00ol0003o
SYOGohjGe`03ohjGe`03o`000?nGWm[oUioJ00CoUioJ00?o0000oijVfonNY]/00_nNY]/00ol0003o
YZ[JojJZfP03o`000003ojJ/fol0003oZjkJ00GoZjkJ00?o0000ojn^eon_[]L00on_[]L2o`0000Ko
/:oG00?o0000ok:]donb[M<00onb[M<2o`0000Ko/JgD00?o0000ok6ZdOnaZ]400onaZ]42o`0000Oo
[j_C00?o0000ojjXdOn^Z=400_n^Z=43o`0000GoZjWE00?o0000ojVWe?nYYm@01?nYYm@00ol0003o
YjGCojNUd`02ojNUd`?o00001OnUZMT00ol0003oY:SIojBXf@04ojBXf@04o`000?nRYm[oXZOJoj:W
fPKo00000onR[=h00ol0003oXJgOoj6]g`03oj6]g`03o`000?nP[N7oX:gQ00CoX:gQ1?l00003oj6b
i003o`000?nP/nGoX;?U00CoX;?U00?o0000oj2di_nP]>H00onP]>H4o`0000CoXKOX00?o0000oj6h
jOnQ^>T01?nQ^>T01?l0003oXKWZoj6ij_nQ^NX5o`0000GoX[_[00?o0000oj:ljonR_>/00onR_>/5
o`0000?oX[g/00?o0000oj>mk?nS_N`01?nS_N`4o`0000?oXkk]00?o0000oj>okOnS_nd00_nS_nd0
0ol0003oXko]o`000002oookJP03o`000?oonf[ooo]Z00Cooo]Z0022oookJP;o00002?oonfX2o`00
00Ko/LW/0ol00006okC;j`?o00001_nicNT3o`0000Co_m3W0_l00003ol;@i@03o`000?o8dn?o0000
00Gobm;O00Co0000olg@foo=d=_ocM3K0_l000000ooFdmKo0000omO?d@03omO?d@03o`000?oHblgo
f<_=00?of<_=00?o0000omO7b_l000000_oNaL000ol0003og<6nomc1_P02omc1_P03o`000?oI_;go
fKbm00;ofKbm00?o0000omjh/_l000001?oI];<01Ol0003oeK:fomFb]_oE/[Ko000000;oejb/00?o
0000om:Z/?oBZ[001?oBZ[02o`0000KocZ>/00?o0000olRM[?o8WJ`01Oo8WJ`00ol0003oaYJVo`00
0005ol6H[@03o`000?nmTJSo_I6X00?o_I6X00?o0000okB=[OndSJd01?ndSJd00ol0003o[XJZojj6
ZP03ojj6ZP03o`000?nVOZSoYWjX00;oYWjX0_l00004oin0/@03o`000?nHNk;oV7^b00CoV7^b00?o
0000oi5h/onAN;<00_nAN;<00ol0003oRgJfoh]f]P02oh]f]P03o`000?n6M[[oQWJj00;oQWJj00Co
0000ohAi_on4NKooQ7Vo1Ol000000omfK[go0000ogUga@03ogUga@03o`000?moP/coOh;<00?oOh;<
00?o0000ohJ=don6SM<00_n6SM<00ol0003oSYOGohjGe`03ohjGe`03o`000?nGWm[oUioJ00?oUioJ
00Co0000oijVfonNY]_oWZKK1?l00005ojJ/f`03o`000?n[[][oZjkJ00?oZjkJ00?o0000ojn^eon_
[]L00ol000000on][mWo0000ok2_e`05ok2_e`03o`000?nb[M?o/ZgC00?o000000?o/:oGo`000?na
[M@01Ona[M@00ol0003o/J[Aok6Zd@03o`000003ojn]e_l0003o[j_C00Ko[j_C00?o0000ojjXdOl0
00000_l000000on/[=Oo0000oj^Ye@06oj^Ye@03o`000?nYYmCoZJOD00?oZJOD00?o0000ojNUdol0
00000_l000000onWZ]Wo0000ojFYf@06ojFYf@03o`000?nTZ=WoY:SI00?oY:SI1?l00003oj>/gP03
o`000?nR[=koXZcN00CoXZcN00?o0000oj6]gonQ[Ml00onQ[Ml00ol0003oX:gQoj2]h@03o`000003
oj6ahol0003oXK;T00GoXK;T00?o0000oj2ciOnP/nD00onP/nD00ol0003oX;CVoj2diP03o`000003
oj6fiol0003oXKOX00KoXKOX00Co0000oj6hjOnQ^>WoXKSY1_l00003oj:jjP03o`000?nR^n_oX[_[
00CoX[_[00?o0000oj:ljonR_>/00ol00002oj:lk003o`000?nR_NcoX[g/00CoX[g/00?o0000oj>m
k?nS_N`00ol000000onS_^go0000oj>nk@05oj>nk@04o`000?nS_ngoXko]oj>ok@Co000000?ooo]Z
o`000?oonfX01OoonfX008Cooo]Z00?o0000oookJ_oonfX01ooonfX2o`000004ok79k?l0003o0000
o`0000?o//W[00Co0000okC;jondbn_o]<_[0_l00003okK;jP04o`000?nicNWo^LgYokW=j@;o0000
0onkcNP01?l0003o_m3Wo`000?l00005ol;@i@?o00001?o;d]l00ol0003ocM3Kolg@f`03olg@f`?o
00000ooGcm400ol0003of<_=omS;c@03omS;c@07o`000?oGal[oelO:omO7b_l0003og/G0o`000004
omc1_P03o`000?oI_;gofKbm00?ofKbm00?o0000omVd/ooI];<00ooI];<01ol0003oeK:fomFb]_oE
/[Ko0000omN/[?l000001ooBZ[000ol0003ocZ>/oljS[005oljS[003o`000?o8WJcob9f/00Kob9f/
0_l00005ol6H[@03o`000?nmTJSo_I6X00;o_I6X0_l00006okB=[@03o`000?n^QZ[o[XJZ00Co[XJZ
00Ko0000ojInZ?l0003o0000ojJ6/_l00005oin0/@03o`000?nHNk;oV7^b00?oV7^b00?o0000oi5h
/onAN;<00_nAN;<00ol0003oRgJfoh]f]P02oh]f]P03o`000?n6M[[oQWJj00?oQWJj00Go0000ohAi
_on4NKooQ7Voo`000003ohAoa@Oo00001OmoP/`00ol0003oQXgCohJ=d`02ohJ=d`03o`000?n>UmOo
SYOG00?oSYOG00Co0000oiNOf_nGWm[oUioJ1_l00002oj2Xg003o`000?nV[=_oYZcK00GoYZcK00?o
0000oj^^f_n[[]X00_n[[]X3o`0000Go[JoI00?o0000ok2_eon`[mL00on`[mL3o`0000Go/:oG00?o
0000ok6]e?na[M@00ona[M@3o`0000Go[jgF00?o0000ojn[don_Zm<01?n_Zm<2o`0000Go[:cG00?o
0000oj^YeOn[ZMD01?n[ZMD01?l0003oZJODojVWe?nYYm@4o`0000GoYj[I00?o0000ojFYfOnUZMT0
1?nUZMT00ol0003oY:SIojBXf@03o`000003ojB]gOl0003oXjcN00GoXjcN00?o0000oj:/g_nR[=h0
0onR[=h01?l0003oXJgOoj6]gonQ[Ml5o`0000GoXK7S00?o0000oj6bi?nQ/^@00onQ/^@01?l0003o
X;?Uoj2ciOnP/nD5o`0000GoXKKW00?o0000oj6gj?nQ]nP01?nQ]nP4o`0000?oX[[Z00?o0000oj:j
j_nR^^X01?nR^^X01?l0003oX[_[oj:kjonR^n/5o`0000KoX[c/00Co0000oj:mk?nR_NcoX[g/1Ol0
0005oj>nk@03o`000?nS_^goXkk]00?oXkk]1?l000001?nS_ngo0000oj>okOnS_nd2o`0000Kooo]Z
0025oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000ok;9jonbbN/01OnbbN/00ol0003o]<_[o`00
0006okK;jP03o`000?nicNWo000000Go^lgX0ol00005ol;@i@04o`000?o4cn;oa<oRolC?hP;o0000
00?obm;Oo`000?o=d=/01?o=d=/01ol0003oclgHolo=f?o?cMSo0000omO?dOl000001OoHbld00ol0
003oelO:omO7bP03omO7bP03o`000?oL`Kkog<6n00;og<6n00?o0000omVl_OoI_;d01?oI_;d00ol0
003ofKBcomVd/`02omVd/`03o`000?oE/[KoeK:f00;oeK:f00?o0000omN/[?l000001ooBZ[000ol0
003ocZ>/oljS[004oljS[003o`000?o9Xk;o000000Oob9f/00?o0000ol6H[Oo1V:d01?o1V:d01Ol0
003o_I6XokfAZ?nmTJSo000000;o^IB`00?o0000okB=[OndSJd00ondSJd00ol0003o[XJZojj6ZP04
ojj6ZP;o00000onVQ[800ol0003oWh2aoin0/@03oin0/@03o`000?nHNk;oV7^b00?oV7^b00?o0000
oi5h/onAN;<00_nAN;<00ol0003oRgJfoh]f]P02oh]f]P03o`000?n6M[[oQWJj00?oQWJj00?o0000
ohAi_on4NKl00_n4NKl00ol0003oQ7o5ohAoa@02ohAoa@04o`000?n6Q/coQXK<ohJ6c1Go00000onK
Xm/00ol0003oX:SLoj2Xg003oj2Xg003o`000?nV[=_oYZcK00CoYZcK00?o0000oj^^f_l000000_l0
00000onZ[m_o0000ojf_f@06ojf_f@03o`000?n`[mOo000000;o000000?o[[3Jo`000?n`[mL01_n`
[mL00ol0003o/JgDo`000002o`000003ojj_f?l0003o[jgF00Ko[jgF00Co0000ojn[don_Zm?o[j_C
0_l000000on][]So0000ojb/e`05ojb/e`03o`000?n[ZMGoZjWE00?oZjWE1?l00003ojR/f@03o`00
0?nWZ]WoYj[I00CoYj[I00?o0000ojFYfOnUZMT00onUZMT3o`0000GoY:gM00?o0000oj>/g_nS[=h0
0onS[=h01?l0003oXZcNoj:/g_nR[=h6o`0000?oX[7R00?o0000oj6ahonQ/N<01OnQ/N<01?l0003o
XK;Toj6bi?nQ/^@5o`0000CoXKGW00?o0000oj6fionQ]^L01?nQ]^L00ol0003oXKOXoj6gj003o`00
0003oj:ijOl0003oX[[Z00GoX[[Z00Co0000oj:jj_nR^^[oX[[Z1_l00004oj:lj`03o`000?nR_>co
X[c/00CoX[c/1?l00003oj>nk003o`000?nS_^goXkk]00CoXkk]00?o0000oj>nkOnS_^d00ol00002
oj>ok@05o`000?nS_ngoXko]oj>okOl000000_nS_nd00ol0003ooo]ZoookJP04oookJP00Q_oonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?nbbN_o//W[00Co//W[0ol00006okK;jP?o00000onkcNP2
o`0000?o_LgV00Go0000ol;@iOo2d>Go`]3Uo`000005olC?hP;o00001Oo=d=/00ol0003oclgHolo=
f003olo=f0;o00001?oHbld00ol0003oelO:omO7bP03omO7bP03o`000?oE`lSo000000?og<6n00?o
0000omVl_OoI_;d00ooI_;d00ol0003oeKVno`000003omVd/`03o`000?oE/[KoeK:f00?oeK:f00?o
0000om:Z/?oBZ[001OoBZ[000ol0003ocZVdo`000005oljS[003o`000?o9Xk;o000000Oob9f/00?o
0000ol6H[Oo1V:d01?o1V:d01?l0003o_I6XokfAZ?l00003okVD/003o`000?ndSJgo]8f]00?o]8f]
00?o0000ojj6Z_n^QZX00on^QZX2o`0000GoYXJb00?o0000oin0/OnOP;400_nOP;400ol0003oV7^b
oiQk/P04oiQk/P03o`000?nAN;?oTGRc00;oTGRc00?o0000oh]f]_n;M[H00_n;M[H00ol0003oQWJj
ohIf^P02ohIf^P03o`000?n4NKooQ7Vo00;oQ7Vo00?o0000ohAoaOn4OlD00on4OlD01Ol0003oQXK<
ohJ6c?n6Q/co000000GoRXkA00?o0000ohnFe_n?U]H00_n?U]H00ol0003oUIgIoiFMf@03oiFMf@03
o`000?nKXm_oVj?K00CoVj?K00?o0000oj2Xg?nPZ=`00onPZ=`01?l0003oYZcKojJ/fonV[=/4o`00
00GoZZoK00?o0000ojf_fOn][mT01?n][mT2o`0000Go[[3J00?o0000ok2_eon`[mL01?n`[mL2o`00
00Go[ZoH00?o0000ojn]e_n_[MH01?n_[MH01?l0003o[j_Co`000?l00004ojf^f003o`000?n/[=Oo
[:cG00?o[:cG00?o0000oj^YeOn[ZMD00ol000000onZ[M[o0000ojR/f@05ojR/f@03o`000?nWZ]Wo
Yj[I00?oYj[I00?o0000ojFYfOnUZMT00ol000000onV[Mgo0000ojB]g@05ojB]g@03o`000?nS[=ko
XjcN00?oXjcN1?l00003oj>`hP03o`000?nR/N;oX[7R00CoX[7R00?o0000oj6ahonQ/N<01?nQ/N<4
o`0000;oX[GV00?o0000oj6eionQ]NL01OnQ]NL01?l0003oXKKWoj6fionQ]^L5o`0000GoX[WY00?o
0000oj:jj_nR^^X00onR^^X4o`0000CoX[_[00?o0000oj:ljonR_>/01?nR_>/00ol0003oX[c/oj:l
k003o`000003oj>mk?l0003oXkk/00GoXkk/00Co0000oj>nkOnS_^goXkk]1Ol00006oj>ok@04o`00
0?nS_ngoXko]oj>ok@Co00001OoonfX008Oooo]Z0_l00009oookJP03o`000?nbbN_o//W[00?o0000
0oncbN/00ol0003o]/_ZokK;jP03o`0000?o]l_Y00?o0000ok_=j?l000001_nmcNH00ol0003o`]3U
o`000005olC?hP04o`000?o6c^3oa/kPo`0000?ocM3K00?o0000olo=f?o?cMP00oo?cMP01?l0003o
cl_Eolo;eOl00003omS;c@03o`000?oGal[oelO:00;oelO:00Oo0000omG3b?oE`lSoeL?8o`000?oL
`Kko000000GofKbm00Oo0000omFi__oE^KkoeKVno`000?oI];?o000000KoeK:f00?o0000om:Z/?oB
Z[001?oBZ[001?l0003ocZVdoljY]?l00004oljS[004o`000?o9Xk;obJ>bo`0000Kob9f/0_l00006
ol6H[@04o`000?nmTJSo_I6Xo`0000?o^IB`00?o0000okB=[OndSJd01?ndSJd00ol0003o[XJZojj6
ZP02o`000003ojf</ol0003oYXJb00CoYXJb00?o0000oin0/OnOP;400onOP;400ol0003oV7^boiQk
/P03oiQk/P03o`000?nAN;?oTGRc00;oTGRc00?o0000oh]f]_n;M[H00_n;M[H00ol0003oQWJjohIf
^P03ohIf^P05o`000?n4NKooQ7VoohAi_ol000001On4OlD00ol0003oQXK<ohJ6c002ohJ6c003o`00
0?n:S]7oRXkA00?oRXkA00?o0000ohnFe_n?U]H00_n?U]H00ol0003oUIgIoiFMf@03oiFMf@03o`00
0?nKXm_oVj?K00?oVj?K00Co0000oj2Xg?nPZ=coX:SL1_l00003ojJ^g@03o`000?nZ[m_oZZoK00Co
ZZoK00?o0000ojf_fOn][mT00ol000000on//Mco0000ojj`fP05ojj`fP03o`000?n`[mOo/:oG00?o
000000?o[K7Jo`000?n^[mP01On^[mP00ol0003o[jgFojn]eP03ojn]eP;o00001_n][]P00ol0003o
[:cGojb/e`03ojb/e`?o00001OnZ[MX00ol0003oZ:cIojR/f@03ojR/f@04o`000?nWZ]WoYj[IojNZ
f@Go00001OnV[Md00ol0003oY:gMojB]g@03ojB]g@03o`000?nS[=koXjcN00?o000000?oY;3Qo`00
0?nS/>801OnS/>800ol0003oX[7Roj:ahP04oj:ahP03o`000?nQ/N?oXK7S00?o000000?oX[CUo`00
0?nR]NH01?nR]NH00ol0003oXKGWoj6ei`04oj6ei`Co00000onR^>P00ol0003oX[WYoj:ij@04oj:i
j@03o`000?nR^^[oX[[Z00?o000000?oX[_Zo`000?nR^n/01_nR^n/01?l0003oX[c[oj:ljonR_>/5
o`0000GoXkg/00?o0000oj>nk?nS_^`00onS_^`4o`0000?oXkk]00?o0000oj>okOnS_nd01?nS_nd6
o`0000;ooo]Z00?o0000oookJ_oonfX00ooonfX008Wooo]Z00?o0000oookJ_oonfX01ooonfX2o`00
00Ko/lW[0ol00006okO;j@?o00001_nmcNH3o`0000Coa<oR00?o0000olK>h?o6c^000_o6c^000ol0
003ocM3Ko`000005olo=f003o`000?o?bmGocl_E00;ocl_E00?o0000omS;cOl000001?oGalX00ol0
003oeL?8omG3b003omG3b003o`000?oI_;gofKbm00?ofKbm00?o0000omFi__oE^Kh00_oE^Kh00ol0
003ofKBco`000005omFb]P03o`000?o@/;Wo000000CodZZ`00Go0000oljY]?o>ZKCocZVdo`000003
oljS[003o`000?o9Xk;obJ>b00;obJ>b00?o0000olRM[?o8WJ`00_o8WJ`01?l0003o`ijbol>N/_l0
0006ol6H[@;o00001?niU;000ol0003o]8f]okB=[@04okB=[@?o00000on]S;<00ol0003oYXJbojJ6
/P03ojJ6/P03o`000?nOP;7oWh2a00?oWh2a00?o0000oiQk/_nHNk800onHNk800ol0003oTGRcoi5h
/`02oi5h/`03o`000?n;M[KoRgJf00;oRgJf00?o0000ohIf^_n6M[X00on6M[X00ol0003oQ7VoohAi
_`02ohAi_`03o`000?n4OlGoQ7o500?oQ7o500Go0000ohJ6c?n6Q/coQXK<o`000005ohZ>d@03o`00
0?n?U]KoSiKF00?oSiKF00?o0000oiFMfOnEWMT00onEWMT01?l0003oVj?Koi^SfonKXm/5o`0000?o
XZ_M00?o0000ojJ^gOnV[]d01?nV[]d00ol0003oZZoKojZ_f`03ojZ_f`?o00001On//M`00ol0003o
[[3Jojj`fP03ojj`fP?o00001On]/MX00ol0003o[ZoHojj_f003ojj_f003o`000?n_[MKo[jgF00?o
000000?o[K3Jo`000?n][]P01On][]P00ol0003o[:cGojb/e`03o`000003oj^_fol0003oZZgJ00Ko
ZZgJ00?o0000ojR/fOnX[=T00_nX[=T4o`0000?oYjkM00?o0000ojJ]gOnV[Md01OnV[Md01?l0003o
Y:gMojB]gOnT[Md4o`0000GoY;3Q00?o0000oj>`h_nS/>801?nS/>801?l0003oX[7Roj:ah_nR/N85
o`0000GoX[CU00?o0000oj:ei_nR]NH00onR]NH00ol0003oXKGWoj6ei`03o`000003oj:hj?l0003o
X[SX00GoX[SX00Co0000oj:ijOnR^NWoX[WY1Ol00005oj:kjP03o`000?nR^n_oX[_[00CoX[_[1?l0
0003oj>mk003o`000?nS_NcoXkg/00CoXkg/00?o0000oj>nk?nS_^`00ol000000onS_^co0000oj>n
k@05oj>nk@03o`000?nS_ngoXko]00?o00001_oonfX00ol0003ooo]Zo`000005oookJP00R_oonfX0
0ol0003ooo]ZoookJP08oookJP04o`000?ncbN_o/lW[ok?9j`;o00000ondbNX01?l0003o]l_YokO;
jOngbnT2o`0000?o^L_X00Co0000okg=i_nmcNKo_LgV0_l00003oko<i@;o000000?oa<oRo`000?o6
c^001?o6c^03o`0000CoclgH00?o0000olo;eOo?bmD00oo?bmD3o`0000?oelO:00?o0000omG3b?oE
`lP01?oE`lP00ol0003ofKbmomVl_@03omVl_@03o`000?oE^KkoeKVn00?oeKVn00?o0000omFb]_oE
/[H00ooE/[H01?l0003od;2iom2`^Ol00004om:Z/003o`000?o>ZKCocZVd00;ocZVd00Co0000oljS
[?o>Xjco00001?o9Xk801Ol0003ob9f/olRM[?o8WJco000000?o`ijb00?o0000ol6H[Oo1V:d01?o1
V:d00ol0003o^IB`okVD/004okVD/003o`000?ndSJgo]8f]00?o]8f]00?o0000ojf</on]S;<01?n]
S;<00ol0003oYXJbojJ6/P03ojJ6/P03o`000?nOP;7oWh2a00;oWh2a00?o0000oiQk/_nHNk800onH
Nk800ol0003oTGRcoi5h/`03oi5h/`03o`000?n;M[KoRgJf00;oRgJf00?o0000ohIf^_n6M[X00_n6
M[X00ol0003oQ7VoohAi_`02ohAi_`03o`000?n4OlGoQ7o500?oQ7o500?o0000ohJ6c?n6Q/`00_n6
Q/`00ol0003oRXkAohZ>d@03ohZ>d@03o`000?n?U]KoSiKF00;oSiKF00Co0000oiFMfOnEWMWoUIgI
1_l00002oifWg@03o`000?nRZmgoXZ_M00CoXZ_M00?o0000ojJ^gOnV[]d00onV[]d00ol0003oZZoK
ojZ_f`03o`000003ojV`gOl0003o[;7L00Ko[;7L00?o0000ojj`f_l000000_l000000on//]co0000
ojfafP06ojfafP03o`000?n^[mSo[ZoH00;o[ZoH0ol00005ojf`fP03o`000?n][]So[JkH00?o[JkH
0ol00005oj^_f`03o`000?nZ[M[oZZgJ00CoZZgJ00?o0000ojR/fOl000000_l000000onX[mgo0000
ojN^g@05ojN^g@03o`000?nV[MgoYZgM00CoYZgM1?l00002ojF`h@03o`000?nT/>7oY;3Q00GoY;3Q
00Co0000oj>`h_nS/>;oXk3R1_l00003oj>di003o`000?nR]>GoX[CU00CoX[CU00Co0000oj:ei_nR
]NKoX[GV1Ol00005oj:hj003o`000?nR^>SoX[SX00?oX[SX1?l00004oj:jjP03o`000?nR^n[oX[_Z
00CoX[_Z00?o0000oj:kjonR^n/00ol000000onS_>_o0000oj>mk005oj>mk004o`000?nS_NcoXkg/
oj>mk0Go00001OnS_^`01?l0003oXkk]oj>nkOnS_^d5o`0000[ooo]Z0_l00005oookJP00RooonfX0
0ol0003ooo]ZoookJP08oookJP03o`000?ncbN_o000000Ko]<WZ00?o0000okO;jOl000001_nibnP0
0ol0003o_LgVo`000006oko<i@?o00000oo6c^02o`0000?ob<cM0_l000000oo?cMSo0000olo;e@04
olo;e@07o`000?o?am;oclOBolo7d_l0003oelO:o`000006omG3b003o`000?oC_lOo000000?ofKbm
00?o0000omFi__oE^Kh01?oE^Kh00ol0003oeK:fomFb]P03omFb]P05o`000?o@/;Wod;2iom2`^Ol0
00000_oBZ[000ol0003ocZVdoljY]003oljY]003o`000?o>Xjco000000GobJ>b00Co0000olRM[?o8
WJco00001?o3W[800ol0003o`IR]ol6H[@04ol6H[@03o`000?niU;3o^IB`00Co^IB`00?o0000okB=
[OndSJd00_ndSJd2o`0000Ko[Hbc00?o0000ojJ6/_nVQ[800onVQ[800ol0003oWh2aoin0/@02oin0
/@03o`000?nHNk;oV7^b00CoV7^b00?o0000oi5h/onAN;<04_l00005ohAoa@03o`000?n6Q/coQXK<
00;oQXK<00?o0000ohZ>dOn:S]400on:S]401?l0003oSiKFohnFe_n?U]H5o`0000?oVJ?K00?o0000
oifWgOnMYmd00onMYmd00ol0003oXZ_Moj:[g@04oj:[g@04o`000?nV[]goYZkMojJ^g@Co00001OnY
/=d00ol0003o[;7Lojbag004ojbag0;o00001On//]`00ol0003o[K7JojfafP04ojfafP03o`000?n^
[mSo000000;o000000?o[;7Lo`000?n]/=X01_n]/=X00ol0003o[JkHo`000002o`000003oj^`g?l0
003oZjoK00KoZjoK00?o0000ojZ]f_nZ[MX00onZ[MX2o`0000GoZ:oM00?o0000ojN^gOnW[]d01?nW
[]d00ol0003oYZgMojJ]g@03o`000003ojJah?l0003oYK3Q00CoYK3Q00?o0000ojB`hOnT/>401?nT
/>44o`0000?oXk?T00?o0000oj>di?nS]>@01?nS]>@01?l0003oX[CUoj:diOnR]>D6o`0000?oX[OW
00?o0000oj:hj?nR^>P01?nR^>P00ol0003oX[SXoj:hj003o`000003oj>jjOl0003oX[[Z00KoX[[Z
00Co0000oj:kj_nR^n[oX[_Z1Ol00005oj>lj`04o`000?nS_NcoXkg/oj>mk0Ko00000onS_^`00ol0
003oXkk/oj>nk004oj>nk0Co00003_oonfX3o`0000Gooo]Z002<oookJP;o00002OoonfX2o`0000Ko
]<WZ0ol00006okW;j0?o00001?noc>D2o`0000?o`<_S00?o0000olK>h?l000001_o8c=d2o`0000Go
cl_E00?o0000olo7d_o?am800oo?am800ol0003oeL?8omG3b004omG3b007o`000?oC_lOodko7om>o
aol0003ofKbmo`000006omFi_P03o`000?oA]koo000000?oeK:f00?o0000om2`^Oo@/;T00_o@/;T0
0ol0003odZZ`o`000006oljY]003o`000?o>Xjco000000KobJ>b0_l00006ol>N/P03o`000?o1V:go
`IR]00;o`IR]00?o0000okfJ]Ol000001OniU;001ol0003o]8f]okB=[OndSJgo0000ok:B]_l00000
1_n]S;<00ol0003oYXJbojJ6/P03ojJ6/P03o`000?nOP;7oWh2a00?oWh2a00?o0000oiQk/_nHNk80
1_l00002oiN5_@03o`000?nCQ<3oThC000;oThC000?o0000oi25a?n@QL@00on@QL@01?l0003oSXS8
ohj8b?n>R<PEo`0000;oUIgI00?o0000oiVSfonIXm/01?nIXm/00ol0003oWJOMoifWg@03oifWg@03
o`000?nRZmgoXZ_M00?oXZ_M1?l00002ojJ_gP03o`000?nY/=goZK3M00GoZK3M00?o0000ojbag?n/
/M`00ol000000onZ/]ko0000ojbbg005ojbbg003o`000?n]/M[o[K7J00?o[K7J0_l00005ojbag003
o`000?n]/=[o[K3J00Co[K3J0_l00005oj^`g003o`000?n[[m_oZjoK00CoZjoK00?o0000ojZ]f_nZ
[MX00ol000000onY/Mko0000ojR_g@05ojR_g@04o`000?nW[]goYjkMojN^g@Go00001OnV/N000ol0
003oYK3QojF`h@03ojF`h@03o`000?nT/>7oY;3Q00?o000000?oY;?So`000?nS/n@01OnS/n@00ol0
003oXkCToj>di003oj>di0Co00000onS]nL00ol0003oX[OWoj:gi`04oj:gi`04o`000?nR^>SoX[SX
oj:hj0Go00001OnS^^T00ol0003oX[[Zoj:jjP04oj:jjPCo00000onS_>/00ol0003oXkc[oj>lj`04
oj>lj`Co00000onS_N`00ol0003oXkk/oj>nk004oj>nk003o`000?nS_^coXkk/00?o00003_oonfX4
o`0000Sooo]Z002>oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000okC9j_ndbNX00ol00003okK9
j@03o`000?nibnSo^L_X00?o00000onjbnH01?l0003o_lcUo`000?l00005ol3;h`;o00001_o8c=d0
1?l0003ob<WKolS9fol00003olo;e@03o`000?o?am;oclOB00?oclOB0_l00005omG3b003o`000?oC
_lOodko700?odko700?o0000omFi__oE^Kh01?oE^Kh01Ol0003odKNoom6g_ooA]koo000000;oeK:f
00?o0000om2`^Oo@/;T00oo@/;T00ol0003ocZVdoljY]006oljY]003o`000?o9Xk;obJ>b00GobJ>b
00?o0000ol>N/_o3W[801Oo3W[801Ol0003o`IR]ol6H[Oo1V:go000000;o_IZe00?o0000okVD/?ni
U;000oniU;001?l0003o]8f]okB=[Ol00003ok:B]P03o`000?n]S;?o[Hbc00Co[Hbc00?o0000ojJ6
/_nVQ[800_nVQ[800ol0003oWh2aoin0/@02oin0/@Co00000onLQk`00ol0003oUhFmoiN5_@03oiN5
_@03o`000?nCQ<3oThC000;oThC000?o0000oi25a?n@QL@00on@QL@01Ol0003oSXS8ohj8b?n>R<So
000000GoSXc=00?o0000ohnAdOn?TM400_n?TM400ol0003oTYOFoi:GeP03oi:GeP03o`000?nEWMWo
UIgI00?oUIgI00?o0000oiVSfonIXm/01?nIXm/00ol0003oWJOMoifWg@02oifWg@03o`000?nRZmgo
XZ_M00?o000000?oXjgOo`000?nV[mh01?nV[mh00ol0003oZK3MojV`g@04ojV`g@?o00001OnZ/]h0
0ol0003o[;;Lojbbg003ojbbg003o`000?n]/M[o[K7J00?o000000?o[;;Mo`000?n//M`01On//M`0
0ol0003o[K3Jojf`fP03o`000003oj^bgOl0003oZk3L00GoZk3L00Co0000oj^_fon[[m_oZjoK1Ol0
0005ojVagP03o`000?nX[mgoZ:oM00?oZ:oM1?l00003ojJbh003o`000?nV/N3oY[7P00CoY[7P00Co
0000ojF`hOnU/>7oYK3Q1Ol00005ojBch`03o`000?nS/nCoXk?T00?oXk?T00?o0000oj>di?nS]>@0
0ol000000onS]^Ko0000oj>gi`05oj>gi`04o`000?nR]nOoX[OWoj:gi`Ko00001?nS^NT00ol0003o
Xk[Yoj>jj@04oj>jj@03o`000?nR^^[oX[[Z00?o000000?oXk_[o`000?nS_>/01OnS_>/00ol0003o
Xkc[oj>lj`03o`000003oj>mk?l0003oXkg/00GoXkg/00Co0000oj>nk?nS_^coXkk/1Ol0000>oook
JP?o00003?oonfX008oooo]Z00?o0000oookJ_oonfX02?oonfX2o`0000Ko]/WY0ol00006ok[;iP?o
00001Oo0bn<01?l0003o`/[Qol;:hOl00003olS<g@;o00001?o8bM/00ol0003ocl_Eo`000005olo7
dP04o`000?o>a=7oc/CAo`0000?oeL?800?o0000om>oaooC_lL01?oC_lL00ol0003oeKVnomFi_P03
omFi_P03o`000?oA]koodKNo00;odKNo00?o0000omFb]_l000001_o@/;T00ol0003ocZVdoljY]006
oljY]003o`000?o9Xk;obJ>b00GobJ>b00?o0000ol>N/_o3W[801Oo3W[801?l0003o`IR]ol6H[Ol0
0003okfJ]@03o`000?niU;3o^IB`00Co^IB`0_l00004ok:B]P03o`000?n]S;?o[Hbc00Co[Hbc00?o
0000ojJ6/_nVQ[800onVQ[84o`000003oj::^ol0003oW8Nl00GoW8Nl00?o0000oiN5_OnGQKd00_nG
QKd00ol0003oThC0oi>4`002oi>4`003o`000?n@QLCoT8G400?oT8G400?o0000ohj8b?n>R<P00_n>
R<P00ol0003oSXc=ohj<c@03ohj<c@03o`000?n?TM7oSi7A00;oSi7A00?o0000oi:Ge_nBUmH00onB
UmH00ol0003oUIgIoiFMf@03oiFMf@03o`000?nIXm_oVJ?K00?oVJ?K00Co0000oifWgOnMYmgoWJOM
1?l00005oj>]g`03o`000?nV[mkoYZoN00?oYZoN00?o0000ojV`gOnY/=d00ol000000onX/]oo0000
ojZbgP05ojZbgP04o`000?n//]co[;;Lojbbg0Go00001On//]d00ol0003o[;7Lojbag003ojbag0?o
00001On[/]d00ol0003oZk3Loj^`g003oj^`g0Co00000onY/]h00ol0003oZK7NojVagP04ojVagP03
o`000?nX[mgoZ:oM00?o000000?oYk;Po`000?nV/^001OnV/^000ol0003oY[7PojJah003ojJah0Co
00000onU]><00ol0003oY;?SojBch`04ojBch`04o`000?nS/nCoXk?Toj>ci0Go00001OnS]^H00ol0
003oXkOWoj>gi`03oj>gi`Co00001?nS^NP00ol0003oXkWYoj>ij@04oj>ij@04o`000?nS^^WoXk[Y
oj>jj@Go00001OnS^n/01?l0003oXkc[oj>ljonS_>/5o`0000GoXkg/00?o0000oj>mk?nS_N`00onS
_N`4o`0000oooo]Z1?l0000?oookJP00T?oonfX00ol0003ooo]ZoookJP09oookJP04o`000?nfbNWo
]/WYokK9j@;o00000ongbNP01?l0003o^/_Vok[;i_njbnH2o`0000?o_<[U00Go0000ol3;hoo0bn?o
`<_So`000004ol;:h@03o`000?o8c=go000000Kob<WK0ol00004olo7dP03o`000?o>a=7oc/CA00;o
c/CA00?o0000omG3b?l000001_oC_lL00ol0003od;g8o`000003omFi_P03o`000?oA]koodKNo00Co
dKNo00?o0000om2`^Oo@/;T01?o@/;T00ol0003oc:nmo`000006oljY]003o`000?o9ZK[o000000Go
bJ>b00?o0000olFU^Ol000001oo3W[82o`0000Go_IZe00?o0000okVD/?niU;000_niU;02o`0000Go
/Y:f00?o0000ojf</on]S;<01?n]S;<00ol0003oYXJbojJ6/P02ojJ6/P;o00001OnRR[/00ol0003o
W8Nloib7_003oib7_003o`000?nGQKgoUhFm00;oUhFm00?o0000oi>4`?nCQ<000_nCQ<000ol0003o
T8G4oi25a003oi25a003o`000?n>R<SoSXS800;oSXS800?o0000ohj<cOn>S<d00on>S<d00ol0003o
Si7AohnAd@03ohnAd@03o`000?nBUmKoTYOF00?oTYOF00?o0000oiFMfOnEWMT00_nEWMT01?l0003o
VJ?KoiVSfonIXm/6o`0000;oX:_N00?o0000oj>]gonS[Ml01OnS[Ml00ol0003oYZoNojJ_gP02ojJ_
gP?o00001OnX/]l00ol0003oZ[;NojZbgP03ojZbgPCo00000on[/ml00ol0003o[;;Mojbbg@04ojbb
g@03o`000?n//Mco[;7L00?o000000?oZk?No`000?n[/]d01On[/]d00ol0003oZk3Loj^`g003o`00
0003ojVcgol0003oZK;N00GoZK;N00?o0000ojVag_nY/Mh00onY/Mh3o`0000GoYk;P00?o0000ojJb
h?nV/^000onV/^000ol0003oY[7PojJah003o`000003ojFdhol0003oYKCS00GoYKCS00?o0000ojBc
honT/n<00onT/n<4o`0000CoY;KV00?o0000oj>fi_nS]^H01?nS]^H00ol0003oXkOWo`000002o`00
0003oj>ij?l0003oXkWX00KoXkWX00Co0000oj>ijOnS^NWoXkWY1_l00003oj>kjP03o`000?nS^n_o
Xk_[00CoXk_[1?l00003oj>mj`03o`000?nS_NcoXkg/00CoXkg/00?o0000oj>mk?nS_N`00ol0000?
oookJPCo00004ooonfX0097ooo]Z0_l0000:oookJP03o`000?nfbNWo000000Ko]lWX00?o0000ok[;
i_l000001_nlb^D00ol0003o`<_So`000005ol;:h@?o00001Oo8bM/01?l0003ob<OIolS7fOo8amT2
o`000003olo7d_l0003oc/CA00Coc/CA0ol00005om>oa`07o`000?o@_LSod;g8om2mb?l0003oeKVn
o`000006om6g_`;o00001Oo@/;T01?l0003oc:nmolb__Ol00005oljY]004o`000?o9ZK[obJVjo`00
00CobJ>b00Co0000olFU^Oo5YKWo00001_o3W[82o`0000Ko_IZe00Oo0000okVD/?niU;3o^IB`o`00
0?ngV;Wo000000Ko/Y:f00?o0000ojf</on]S;<01?n]S;<4o`000003ojN?^ol0003oXXZk00CoXXZk
00?o0000oib7_?nLQk`00onLQk`00ol0003oUhFmoiN5_@03oiN5_@03o`000?nCQ<3oThC000;oThC0
00?o0000oi25a?n@QL@00on@QL@00ol0003oSXS8ohj8b002ohj8b003o`000?n>S<goSXc=00?oSXc=
00?o0000ohnAdOn?TM400_n?TM400ol0003oTYOFoi:GeP03oi:GeP04o`000?nEWMWoUIgIoiFMf@Go
00000onMYmd00ol0003oX:_Noj2[gP03oj2[gP03o`000?nS[MooXjgO00CoXjgO00?o0000ojJ_g_l0
00000_l000000onV/N3o0000ojRbg`06ojRbg`03o`000?nZ/]ko000000;o000000?oZK?Po`000?n[
/ml01On[/ml00ol0003o[;;Mojbbg@03ojbbg@?o00001On[/mh00ol0003oZk;Moj^bg@03oj^bg@?o
00001OnY/ml00ol0003oZK;NojVbgP03ojVbgP03o`000?nY/MkoZK7N00?o000000?oZ;?Qo`000?nW
/^001_nW/^001?l0003oY[;PojJbh?nV/^04o`0000GoYKCS00?o0000ojFdhonU]><01?nU]><00ol0
003oY;?So`000002o`000003ojBfiOl0003oY;KV00KoY;KV00Co0000oj>fi_nS]^KoXkKV1?l00005
oj>ij003o`000?nS^NSoXkWX00CoXkWX1?l00003oj>kjP03o`000?nS^n[oXk_Z00CoXk_Z00?o0000
oj>kjonS^n/00ol000000onS_>_o0000oj>mj`05oj>mj`04o`000?nS_NcoXkg/oj>mk0Go00003_oo
nfX4o`0001Oooo]Z002CoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000okO9j?ngbNP01OngbNP2
o`0000Oo_<[U0ol00003ol;:h@;o00000oo2bMl01Ol0003ob<WKolS9foo8bM_o000000Gob<OI0_l0
0005olk4d@05o`000?o=`]3ocL;@olg2d?l000000ooC_lL00ol0003od;g8om2mb003om2mb003o`00
0?oA]koodKNo00CodKNo00Co0000olfe`_o=]L;o00000oo@/;T00ol0003oc:nmolb__@02olb__@05
o`000?o>ZKCocZVdoljY]?l000001?o9ZKX01?l0003obJ>bolVS/_l00003olFU^@03o`000?o3W[;o
`ijb00?o`ijb00?o0000oknQ^_l000001_nmV[D01?l0003o^IB`okVD/?l00003okNH^@03o`000?nb
T[Ko/Y:f00?o/Y:f00?o0000ojf</on]S;<00on]S;<2o`0000GoYhnk00?o0000oj::^onRR[/00_nR
R[/00ol0003oW8Nloib7_004oib7_003o`000?nGQKgoUhFm00;oUhFm00?o0000oi>4`?nCQ<000_nC
Q<000ol0003oT8G4oi25a003oi25a003o`000?n>R<SoSXS800;oSXS800?o0000ohj<cOn>S<d00on>
S<d01?l0003oSi7AohnAdOn?TM4;o`0000;oVZ?K00?o0000oifWgOnMYmd01?nMYmd00ol0003oX:_N
oj2[gP03oj2[gP04o`000?nS[MooXjgOoj>]g`Co00001OnV/N000ol0003oZ;;OojRbg`04ojRbg`;o
00001OnY/n000ol0003oZk?Ooj^cg`04oj^cg`03o`000?n//]go000000;o000000?oZ[CPo`000?n[
/mh01_n[/mh00ol0003oZk;Mo`000002o`000003ojZdh?l0003oZK?O00KoZK?O00Co0000ojVbg_nY
/]koZK;N1?l00005ojRch@03o`000?nW/^3oYk;P00CoYk;P1?l00002ojJdh`03o`000?nU]>?oYKCS
00GoYKCS00Co0000ojFdhonU]>?oYKCS1?l00005ojBfi@03o`000?nT]^KoY;KV00CoY;KV1?l00003
ojBhi`03o`000?nS^NSoXkWX00CoXkWX00?o0000oj>ij?nS^NP00ol000000onS^^Wo0000oj>kjP05
oj>kjP04o`000?nS^n[oXk_Zoj>kjPGo00001OnS_>/01?l0003oXkg[oj>mjonS_N/6o`0000oooo]Z
1?l0000KoookJP00U?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?ngbNSo]lWX00;o]lWX0_l0
0002okS8i`03o`000?nlb^Go_<[U00;o_<[U0_l00003okc9i003o`000?o2b^7o000000Ko`/WO00?o
0000olS9fol000001Oo8amT01?l0003ob<GHolS5f?l00003olk4d@03o`000?o=`]3ocL;@00?ocL;@
00?o0000om>oaol000001_o@_LP00ol0003odKNoom6g_`03om6g_`03o`000?o=]L;ocKG200;ocKG2
00Co0000om2`^Oo@/;Wo00001?o<[kd01?l0003ocZVdoljY]?l00005olVY^P04o`000?o9Xk;obJ>b
o`0000CoaJFi00Go0000ol>N/_o3W[;o`ijbo`000002oknQ^P03o`000?nmV[Go_IZe00Go_IZe0_l0
0004okNH^@03o`000?nbT[Ko/Y:f00?o/Y:f00Co0000ojf</on]S;?o[Hbc0_l000000on/Tkco0000
ojN?^`04ojN?^`03o`000?nRR[_oXXZk00?oXXZk00?o0000oib7_?nLQk`00onLQk`00ol0003oUhFm
oiN5_@02oiN5_@03o`000?nCQ<3oThC000;oThC000?o0000oi25a?n@QL@00on@QL@01?l0003oSXS8
ohj8b?n>R<P;o`0000;oUY_F00?o0000oiROfOnHWmT00onHWmT00ol0003oVZ?KoiZSf`03oiZSf`03
o`000?nMYmgoWJOM00CoWJOM00Co0000oj2[g_nPZmkoX:_N1Ol00003ojB`h003o`000?nV/N3oY[7P
00CoY[7P00?o0000ojRbgonX/]l00ol000000onX/n7o0000ojVch005ojVch004o`000?n[/mooZk?O
oj^cg`Co00001OnZ]>000ol0003oZk?Noj^cgP04oj^cgP;o00001OnZ]>000ol0003oZK?OojVcg`04
ojVcg`Co00000_nX]>400ol0003oZ;?QojRch@05ojRch@03o`000?nW/^3oYk;P00?o000000?oYkGS
o`000?nV]><01?nV]><00ol0003oYKCSojFdh`04ojFdh`Co00000onU]^D00ol0003oY;KUojBfi@04
ojBfi@03o`000?nT]^KoY;KV00?o000000?oY;SWo`000?nT^>L01OnT^>L01?l0003oXkWXoj>ij?nS
^NP5o`0000GoXk[Y00?o0000oj>kj_nS^nX00onS^nX4o`0000?oXkc[00?o0000oj>ljonS_>/01?nS
_>/4o`0001;ooo]Z0ol0000OoookJP00UOoonfX00ol0003ooo]ZoookJP08oookJP04o`000?ngbNSo
0000o`0000Go^<SW00Co0000okc:iOl0003o00001OnlbN@2o`0000Oo`/WO0_l00005olS7f@03o`00
0?o8aMSob<GH00;ob<GH00?o0000olk4dOl000001_o=`]02o`0000Kod;g800?o0000olfkbOl00000
0ooA]kl00ol0003ocKG2olfe`P03olfe`P03o`000?o@/;Wo000000Goc:nm00?o0000oljY]?l00000
1_o9ZKX00ol0003obJ>bo`000005olFU^@04o`000?o3W[;o`ijbo`0000Co_j6j00?o0000okfJ]Onm
V[D00onmV[D2o`0000Go]iRi00?o0000ok:B]_nbT[H01?nbT[H3o`0000Co[9>l00?o0000ojN?^onW
Sk/00_nWSk/00ol0003oXXZkoj::^`03oj::^`03o`000?nLQkcoW8Nl00?oW8Nl00?o0000oiN5_OnG
QKd00onGQKd00ol0003oThC0oi>4`00;o`0000;oUY??00?o0000oiFGd_nEUm800onEUm800ol0003o
UY_FoiJKeP03oiJKeP03o`000?nHWmWoV9oI00?oV9oI00?o0000oiZSfonJXm/00onJXm/01?l0003o
WJOMoifWgOnMYmd6o`0000;oXZkP00?o0000ojB`h?nT/>001?nT/>001?l0003oY[7PojJah?nV/N05
o`0000GoZ;?Q00?o0000ojVch?nY/n000onY/n04o`0000?oZKGQ00?o0000ojZdh?nZ]>001?nZ]>00
0ol0003oZk?Noj^cgP03o`000003ojVehOl0003oZ[CP00GoZ[CP00?o0000ojVcgonY/ml00ol00000
0onX]N;o0000ojRdh@04ojRdh@03o`000?nX/n7oZ;?Q00CoZ;?Q0ol00005ojNeh`03o`000?nV]>?o
Y[CS00?oY[CS00?o0000ojFdhonU]><00ol000000onU]^Go0000ojFfi@05ojFfi@04o`000?nT]^Go
Y;KUojBfi@Go00001OnT^>L00ol0003oY;SWojBhi`03ojBhi`Co00000onT^^T00ol0003oXk[Yoj>j
j@04oj>jj@03o`000?nS^n[oXk_Z00?o000000?oY;c[o`000?nS_>/01OnS_>/00ol0003oXkc[oj>l
j`03o`0001;ooo]Z1?l0000RoookJP00U_oonfX00ol0003ooo]ZoookJP08oookJP;o00001_nhb>L3
o`0000Co_<WT0_l00002okg8hP03o`000?o2bMoo`/WO00;o`/WO0_l00002ol;7gP05o`000?o8amWo
b<OIolS7fOl000001Oo8aMP2o`0000KocL;@00?o0000ol^od?l000001Oo@_LP01ol0003ocK_9olfk
bOo=^lWo0000om6g_ol000001oo=]L800ol0003oc:nmolb__@05olb__@03o`000?o9ZK[obJVj00Ko
bJVj00?o0000olFU^Oo5YKT01?o5YKT00ol0003o`ijbo`000005oknQ^P03o`000?nmV[Go_IZe00;o
_IZe00?o0000okZN_Ol000001_ngV;T00ol0003o/Y:fok:B]P02ok:B]P;o00001_n/Tk`00ol0003o
YhnkojN?^`03ojN?^`03o`000?nRR[_oXXZk00;oXXZk00?o0000oib7_?nLQk`01?nLQk`00ol0003o
UhFmoiN5_@05o`0000;oVI3800?o0000oiNAc?nGTL`00onGTL`00ol0003oUY??oiJCc`03oiJCc`03
o`000?nEUm;oUIOB00?oUIOB00?o0000oiJKe_nFVmH00onFVmH00ol0003oV9oIoiROf@02oiROf@04
o`000?nJXm_oVZ?KoiZSf`Ko00000onOZml00ol0003oXZkPoj:^h003oj:^h003o`000?nT/>3oY;3P
00?oY;3P1?l00003ojJch@03o`000?nX/n7oZ;?Q00CoZ;?Q00?o0000ojVch?nY/n000ol000000onX
]N;o0000ojVeh@05ojVeh@04o`000?nZ]>3oZ[CPojZdh0Go00001OnY]N400ol0003oZ[CPojZdh003
ojZdh0?o00001OnX]N800ol0003oZ;CQojRdh@03ojRdh@03o`000?nX/n7oZ;?Q00?o000000?oYkKS
o`000?nW]N<01OnW]N<01?l0003oY[CSojJdhonV]><5o`0000GoYKKU00?o0000ojFfiOnU]^D00onU
]^D4o`0000?oY;SW00?o0000ojBhionT^>L01?nT^>L00ol0003oY;SWojBhi`03o`000003ojBjjOl0
003oY;[Y00GoY;[Y00Co0000oj>jjOnS^^WoXk[Y1Ol00005ojBlj`04o`000?nS_>_oXkc[oj>lj`Go
00004OoonfX4o`0002Kooo]Z002GoookJP;o00002_oonfX2o`000004okS8iol0003o0000o`0000?o
^<SV0_l000000onlbNCo0000okg8hP04okg8hP04o`000?o2bMoo0000o`0000Go`/ON00?o0000olS7
fOl000001Oo8aMP00ol0003oal?Go`000005olg2d005o`000?o;_m3obko@ol^od?l000000oo@_LP0
0ol0003ocK_9olfkb@03olfkb@03o`000?o=]L;ocKG200KocKG200?o0000olb__Oo<[kd01?o<[kd2
o`0000OobJVj0_l00007olFU^@03o`000?noXK[o_j6j00Co_j6j00Go0000okfJ]OnmV[Go_IZeo`00
0003okZN_@03o`000?ngV;Wo]iRi00?o]iRi00Oo0000ok:B]_nbT[Ko/Y:fo`000?naV;ko000000Ko
[9>l00?o0000ojN?^onWSk/00onWSk/00ol0003oXXZkoj::^`03oj::^`03o`000?nLQkcoW8Nl00Ko
00000_nLT<H00ol0003oVI38oiV@b003oiV@b003o`000?nGTLcoUi7<00?oUi7<00?o0000oiJCconF
Tll00_nFTll00ol0003oUIOBoiFGdP03oiFGdP03o`000?nFVmKoUY_F00?oUY_F00Co0000oiROfOnH
WmWoV9oI1Ol00003oifXgP03o`000?nOZmooWj_O00CoWj_O00?o0000oj:^h?nR[^000onR[^000ol0
003oY;3Po`000002o`000003ojBbh_l0003oY[?Q00GoY[?Q00?o0000ojRchOnX/n400onX/n43o`00
00GoZ;GR00?o0000ojVehOnY]N400onY]N44o`0000CoZKKR00?o0000ojVehOnY]N400onY]N400ol0
003oZ[CPojZdh003o`000003ojVfh_l0003oZ;GR00GoZ;GR00Co0000ojRdhOnX]>7oZ;CQ1Ol00005
ojNfh`03o`000?nW]N?oYkGS00?oYkGS1?l00003ojJgi@03o`000?nU]^GoYKKU00CoYKKU00?o0000
ojFfiOnU]^D00ol000000onU^>Oo0000ojBhi`05ojBhi`04o`000?nT^>OoY;SWojBhi`Go00001OnT
^^T00ol0003oY;[YojBjj@03ojBjj@Co00001?nT_>X00ol0003oY;c[ojBlj`03ojBlj`Co00004_oo
nfX4o`0002[ooo]Z002IoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000okS8i_nhb>H01Onhb>H2
o`0000Ko_LSR0ol00006ol;7gP?o00001?o8aMP01Ol0003oal?GolO3eoo7`mOo000000?ocL;@00?o
0000ol^od?o;_m000oo;_m000ol0003od;g8o`000005olfkb@;o00001oo=]L800ol0003obKC5o`00
0004olb__@04o`000?o7[l;oajo2o`0000GobJVj00Co0000olB[_oo4Zkoo00001_o5YKT00ol0003o
_j6joknQ^P04oknQ^P04o`000?nmV[Go_IZeo`0000Co^Yjm00?o0000okNH^OngV;T00ongV;T01?l0
003o/Y:fok:B]_l00003ok6H_P03o`000?n/Tkco[9>l00Co[9>l00?o0000ojN?^onWSk/00_nWSk/0
0ol0003oXXZkoj::^`02oj::^`Co00000onPTLD00ol0003oW936oib@aP03oib@aP03o`000?nIT<So
VI3800;oVI3800?o0000oiNAc?nGTL`01?nGTL`00ol0003oUY??oiJCc`02oiJCc`03o`000?nEUm;o
UIOB00;oUIOB00Co0000oiJKe_nFVmKoUY_F1_l00002oibUg003o`000?nMZ=koWJSN00CoWJSN00?o
0000oin[gonOZml00onOZml01?l0003oXZkPoj:^h?nR[^04o`0000GoY;;R00?o0000ojJchOnV/n40
1?nV/n400ol0003oZ;?Qo`000002o`000003ojNeh_l0003oZ;GR00KoZ;GR00?o0000ojVehOl00000
0_l000000onX]^?o0000ojVfhP06ojVfhP04o`000?nY]N7oZKGQojVeh@Co00001OnY]^800ol0003o
Z;GRojRehP03ojRehPCo00001?nX]^<00ol0003oYkKSojNfh`03ojNfh`03o`000?nW]N?oYkGS00?o
000000?oY[OUo`000?nV]nD01OnV]nD01?l0003oYKKUojFfiOnU]^D5o`0000GoYKSW00?o0000ojBh
ionT^>L00onT^>L4o`0000CoY;[X00?o0000ojBjjOnT^^T00onT^^T00ol0003oY;[YojBjj@03o`00
00;oY;_Z00?o0000ojBlj_nT_>X01?nT_>X00ol0003oY;c[o`000002o`0001?ooo]Z0ol0000^oook
JP00V_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?nhb>Ko^<SV00;o^<SV0_l00002okW7i@04
o`000?nmb>;o_LSRokg8hP;o00000onma^401?l0003o`/ONol;7g_o2amh2o`0000?o`/GM0_l00000
0oo8aMSo0000olO3e`04olO3e`03o`000?o=`]3o000000Kobko@0_l00005olfkb@04o`000?o9^L_o
bKW;o`0000GocKG200Go0000olVdaOo9]<GobKC5o`000002olb__@05o`000?o7[l;oajo2olN_`_l0
00001?o9ZKX01Ol0003oa:^oolB[_oo4Zkoo000000GoaJFi00?o0000ol2W_ol000001_noXKX2o`00
00Go^Yjm00?o0000okNH^OngV;T01?ngV;T2o`0000Co/IRn00?o0000ojbC_?n/Tk`01?n/Tk`00ol0
003oYhnkojN?^`03ojN?^`Co000000?oY9C4o`000?nPTLD01OnPTLD00ol0003oW936oib@aP02oib@
aP03o`000?nIT<SoVI3800?oVI3800?o0000oiNAc?nGTL`00onGTL`00ol0003oUY??oiJCc`02oiJC
c`04o`000?nEUm;oUIOBoiFGdPGo00000onKX]X00ol0003oW:GLoibUg003oibUg003o`000?nMZ=ko
WJSN00CoWJSN00Co0000oin[gonOZmooWj_O1Ol00003oj>`h@03o`000?nT/^;oY;;R00CoY;;R00Co
0000ojJchOnV/n7oY[?Q1?l00005ojNehP03o`000?nX]N;oZ;GR00CoZ;GR0_l00005ojRfh`03o`00
0?nY]^;oZKKR00CoZKKR1?l00003ojRgh`03o`000?nY]^;oZKKR00CoZKKR00?o0000ojReh_l00000
0_l000000onX]nCo0000ojRfh`06ojRfh`04o`000?nW]^?oYkKSojNfh`Co00001OnV]nD00ol0003o
Y[OUojJgi@03ojJgi@Co00001?nU^>H00ol0003oYKSWojFhi`04ojFhi`03o`000?nT^>Oo000000;o
00000_nU^^P00ol0003oY;[XojBjj004ojBjj004o`000?nT^^WoY;[YojBjj@Co00001_nT^nX01?l0
003oY;cZojBlj_nT_>X4o`0001;ooo]Z1?l0000aoookJP00VooonfX00ol0003ooo]ZoookJP09oook
JP04o`000?nhb>Ko0000o`0000Go^LOU00?o0000okg8h_l000001_nma^400ol0003o`/ONo`000006
ol;5g@;o00001_o7`mL2o`0000Kobko@00Co0000olRnd?o8_]3o00000oo=^lT00ol0003obKW;olVi
b`02olVib`05o`000?o=]L;ocKG2olfe`_l000001?o9]<D00ol0003oc:nmo`000005olN_`P04o`00
0?o9ZK[obJVjo`0000Goa:^o00Go0000olFU^Oo5YKWoaJFio`000002ol2W_`03o`000?noXK[o_j6j
00?o_j6j0_l00007okZN_@03o`000?ngV;Wo]iRi00;o]iRi0_l00005ok6H_P03o`000?n/Tkco[9>l
00Co[9>l00?o0000ojN?^onWSk/00_nWSk/2o`0000GoY9C400?o0000oj2AaOnPTLD00onPTLD00ol0
003oW936oib@aP03oib@aP03o`000?nIT<SoVI3800;oVI3800Co0000oiNAc?nGTLcoUi7<2ol00002
oiZOe`03o`000?nKX][oVj;J00CoVj;J00?o0000oibUg?nLYM`00onLYM`00ol0003oWJSNoifXgP03
oifXgPCo00000_nQ[^400ol0003oXk3Qoj>`h@04oj>`h@03o`000?nT/^;oY;;R00?oY;;R1?l00004
ojJdh`03o`000?nW]N;oYkGR00?oYkGR00?o0000ojReh_nX]N800ol000000onX]^?o0000ojRfh`05
ojRfh`03o`000?nY]^;oZKKR00?o000000?oZ;OTo`000?nX]n<01OnX]n<01?l0003oZKKRojVfh_nY
]^84o`0000GoZ;OT00?o0000ojRfhonX]^<01?nX]^<4o`0000?oYkSU00?o0000ojJgiOnV]nD01?nV
]nD00ol0003oY[OUo`000002o`000003ojJii_l0003oYKSV00KoYKSV00Co0000ojFhionU^>OoYKSW
1?l00006ojFjj004o`000?nT^^SoY;[XojBjj0Ko00000onT^nT00ol0003oY;_ZojBkjP04ojBkjPCo
00004_oonfX4o`0003Gooo]Z002LoookJP;o00002_oonfX2o`0000Ko^LOU0ol00006okg6h@;o0000
1_o2aMd00ol0003o`LCLo`000005olO3e`04o`000?o5`MOoaL7Go`0000?obko@0_l00004olRnd003
o`000?o=^lWo000000KobKW;00?o0000olfe`_l000001_o9]<D00ol0003oajo2olN_`P04olN_`P03
o`000?o9ZK[o000000Koa:^o00Co0000olFU^Oo5YKWo00001?o0Ykl01ol0003o_j6joknQ^_noXK[o
0000okbT`Ol000001onjW[d00ol0003o]iRiokNH^@02o`000003okBM`Ol0003o/IRn00Go/IRn00?o
0000ojbC_?n/Tk`01?n/Tk`4o`000003ojRGa?l0003oY9C400CoY9C400?o0000oj2AaOnPTLD00onP
TLD00ol0003oW936oib@aP03oib@aP04o`000?nIT<SoVI38oiV@b0Go00000onLVm800ol0003oVicD
oi^Le002oi^Le003o`000?nJWmOoVYoG00?oVYoG00?o0000oi^Rf_nKX]X01?nKX]X00ol0003oW:GL
oibUg002oibUg003o`000?nMZ=koWJSN00?o000000?oX:cPo`000?nQ[^401?nQ[^400ol0003oXk3Q
oj>`h@04oj>`h@03o`000?nT/^;o000000;o000000?oYKCSo`000?nV]><01_nV]><01?l0003oYkGR
ojNeh_nW]N84o`0000GoZ;KS00?o0000ojRfhonX]^<00onX]^<3o`0000GoZ;OT00?o0000ojRghonX
]n<00onX]n<4o`0000?oZ;ST00?o0000ojRgi?nX]n@01?nX]n@00ol0003oZ;KSojRfh`03o`000003
ojNhiOl0003oYkSU00GoYkSU00Co0000ojJgiOnV]nGoY[OU1?l00005ojJiiP03o`000?nU^>KoYKSV
00CoYKSV1?l00003ojFjj003o`000?nU^^SoYK[X00CoYK[X1?l00003ojBkj@03o`000?nT^nWoY;_Y
00CoY;_Y00?o0000ojBkj_nT^nX00ol0000BoookJPCo0000>OoonfX009kooo]Z00?o0000oookJ_oo
nfX02OoonfX01?l0003o^LOUokW7iOnianD2o`0000?o^LKT00Co0000okg6hOnma^7o_LKQ0_l00002
okg5h@04o`000?o2aMgo`/GMol;5g@;o00000oo1a=`01Ol0003oal?GolO3eoo7`mOo000000CoaL7G
00?o0000ol^od?l000001_o8_]02o`0000OobKW;0_l00006olVda@;o00001_o7[l82o`0000Ooa:^o
00?o0000olFU^Ol000001Oo0Ykl01?l0003o_j6joknQ^_l00003okbT`@03o`000?njW[go^Yjm00Co
^Yjm00?o0000okNH^Ol000001?ndWL400ol0003o/IRnok6H_P03ok6H_P03o`000?n/Tkco[9>l00?o
[9>l0_l00005ojRGa003o`000?nTU<CoY9C400?oY9C400?o0000oj2AaOnPTLD00onPTLD00ol0003o
W936oib@aP06o`0000;oWI[@00?o0000oibKd_nLVm801?nLVm800ol0003oVicDoi^Le002oi^Le003
o`000?nJWmOoVYoG00?oVYoG00?o0000oi^Rf_nKX]X00onKX]X01?l0003oW:GLoibUg?nLYM`4o`00
00GoX:cP00?o0000oj6^hOnQ[^400onQ[^401?l0003oXk3Qoj>`hOnS/>44o`0000GoYKCS00?o0000
ojJdhonV]><01?nV]><4o`0000?oYkKT00?o0000ojRfhonX]^<01?nX]^<00ol0003oZ;KSo`000002
o`000003ojRgi?l0003oZ;OT00GoZ;OT00?o0000ojRghonX]n<00ol000000onX^>Go0000ojRhi005
ojRhi004o`000?nX]nCoZ;OTojRgi0Go00001OnW^>D00ol0003oYkSUojNhi@03ojNhi@Co00000onV
^NH00ol0003oY[WVojJiiP04ojJiiP03o`000?nU^>KoYKSV00?o000000?oYK[Xo`000?nU^^P01OnU
^^P00ol0003oYK[XojFjj003o`000003ojFkjOl0003oY;_Y00GoY;_Y00Co0000ojBkjOnT^nWoY;_Y
1Ol0000AoookJPCo0000?OoonfX009oooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003o^LOUo`00
0006okW6i003o`000?nma^7o000000Go_LGQ00?o0000ol;5gOl000001_o1a=`00ol0003oal?Go`00
0005olG1e`?o00001Oo8_]000ol0003oaKcBo`000006olVib`03o`000?o6^<go000000GobKC500Co
0000olFdbOo5]<Wo00001?o7[l800ol0003o`k36o`000007olB[_`;o00001_o0Ykl00ol0003o_j6j
o`000004okbT`@03o`000?njW[go^Yjm00Co^Yjm0_l00005okBM`@03o`000?naV;ko/IRn00?o/IRn
00?o0000ojbC_?n/Tk`00ol000000on/VlGo0000ojRGa004ojRGa003o`000?nTU<CoY9C400?oY9C4
00?o0000oj2AaOnPTLD00_nPTLD4o`0000?oX9[>00?o0000oifJd?nMV]000onMV]000ol0003oW9_B
oibKdP03oibKdP03o`000?nKW=CoVicD00?oVicD00?o0000oiZOeonJWmL00_nJWmL01?l0003oVj;J
oi^Rf_nKX]X6o`0000;oWj[N00?o0000oj2/h?nP[>001OnP[>001?l0003oXJkQoj6^hOnQ[^45o`00
00?oY;;S00?o0000ojFdhonU]><01?nU]><00ol0003oY[CSojJdh`03o`000003ojJfi?l0003oYkKT
00GoYkKT00Co0000ojRfhonX]^?oZ;KS1?l00005ojRgi003o`000?nX]nCoZ;OT00?oZ;OT0ol00005
ojRhi@03o`000?nX^>CoZ;ST00?oZ;ST1?l00004ojNhi@03o`000?nW^>GoYkSU00?oYkSU00?o0000
ojNhiOnW^>D00ol000000onV^NKo0000ojJiiP05ojJiiP04o`000?nV^NKoY[WVojJiiPGo00001OnU
^^P01?l0003oYK[XojFjj?nU^^P5o`0000GoYK_Y00?o0000ojBkjOnT^nT00onT^nT4o`0001?ooo]Z
0ol00011oookJP00X?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?nia^Co^LKT00Go^LKT0_l0
0006okg5h@?o00001_o1a=`2o`0000GoaL7G00Go0000ol?0eoo3`=Oo`l3Go`000003olRnd005o`00
0?o5_=;oaKcBolFld_l000000oo9^L/2o`0000?oa[S=00Go0000olVdaOo9]<GobKC5o`000004olFd
b@04o`000?o7[l;oajo2o`0000?o`k3600?o0000olB[_oo4Zkl00oo4Zkl00ol0003o`:c5o`000006
ol2W_`;o00001_nlY<400ol0003o^YjmokZN_@02okZN_@03o`000?ngXlCo000000Ko]9g100?o0000
ok6H__naV;h00_naV;h3o`0000Go[9_500?o0000ojRGa?nXUl@00onXUl@00ol0003oY9C4ojBDa002
ojBDa003o`000?nPTLGo000000;o000000?oXi_=o`000?nPV/h01OnPV/h00ol0003oWI[@oifJd002
oifJd003o`000?nLVm;oW9_B00?oW9_B00?o0000oi^Le?nKW=@00onKW=@01?l0003oVYoGoiZOeonJ
WmL5o`0000?oWZSM00?o0000oinZg_nOZ]h00onOZ]h00ol0003oX:cPoj2/h004oj2/h0Co00000_nS
/N800ol0003oY;;SojBbh`04ojBbh`04o`000?nU]>?oYKCSojFdh`Go00001OnV]^@00ol0003oYkKT
ojNfi003ojNfi0Co00000onW^>D00ol0003oZ;OTojRgi004ojRgi003o`000?nX]nCo000000;o0000
00?oZ;SUo`000?nX^>D01_nX^>D00ol0003oZ;STo`000002o`000003ojNii_l0003oYkSU00KoYkSU
00Co0000ojNhiOnW^>GoYkSU1?l00005ojJiiP03o`000?nV^NKoY[WV00?oY[WV1?l00004ojJjj003
o`000?nU^^SoYK[X00?oYK[X1?l00003ojFkj@03o`000?nU^nWoYK_Y00CoYK_Y00?o0000ojBkjOnT
^nT00ol0000CoookJPCo0000A?oonfX00:7ooo]Z0_l0000:oookJP03o`000?nia^Co^LKT00;o^LKT
0_l00002okW5h`04o`000?nmaN7o_LGQokg5h@;o00000onma>001?l0003o`LCLol74g?o1a=`2o`00
00;o`<;L00Go0000olG1eoo5`MOoaL7Go`000005ol?0e`03o`000?o8_]3o000000GoaKcB00?o0000
olVibol000001_o6^<d00ol0003obKC5o`000005olFdb@03o`000?o7[l;o000000Go`k3600Go0000
olB[_oo4Zkooa:^oo`000003ol2/a@03o`000?o0Ykoo`:No00;o`:No00?o0000okbYa_l000001_nl
Y<400ol0003o^YjmokZN_@02o`0000?o]j?400?o0000okBM`OndWL400ondWL400ol0003o/IRnok6H
_P02o`000003ojnOa_l0003o[9_500Go[9_500?o0000ojRGa?nXUl@00onXUl@00ol0003oY9C4ojBD
a002ojBDa0;o00001OnSVld00ol0003oX9[>oj2JcP03oj2JcP03o`000?nMV]3oWI[@00?oWI[@00?o
0000oibKd_nLVm800onLVm800ol0003oVicDoi^Le006o`0000;oWZKK00?o0000oijXgOnNZ=d01?nN
Z=d00ol0003oWj[NoinZgP03oinZgP03o`000?nP[>3oX:cP00?o000000?oX[3Ro`000?nS/N801?nS
/N800ol0003oY;;SojBbh`03ojBbh`Co00001?nU]N@00ol0003oY[KTojJfi003ojJfi003o`000?nW
]^CoYkKT00?o000000?oYkSUo`000?nW^>D01OnW^>D01?l0003oZ;OTojRgi?nX]n@4o`0000GoZ;SU
00?o0000ojRhiOnX^>D01?nX^>D2o`0000GoYkWV00?o0000ojNhiOnW^>D01?nW^>D4o`0000?oYkWW
00?o0000ojJii_nV^NH01?nV^NH00ol0003oY[WVo`000002o`0000;oY[[X00?o0000ojJjj?nV^^P0
1?nV^^P00ol0003oYK[Xo`000002o`000003ojFkjOl0003oYK_Y00GoYK_Y00Co0000ojFkjOnU^nWo
YK_Y1Ol0000BoookJPCo0000B?oonfX00:?ooo]Z00?o0000oookJ_oonfX02?oonfX01?l0003o^LKT
o`000?l00005okW5h`03o`000?nmaN7o000000Ko_LCP00?o0000ol74g?l000001Oo0`]`00ol0003o
aL7Go`000006ol?0e`;o00001_o5_=82o`0000Ooa[S=0_l00006olFdb@;o00001oo3/<H00ol0003o
a:^oo`000005ol2/a@04o`000?o0Ykoo`:Noo`0000?o_:W600?o0000okbT`OnlY<400onlY<400ol0
003o^Yjmo`000005okNSa003o`000?ndWL7o]9g100?o]9g100?o0000ok6H__l000001?n_WlH00ol0
003o[9_5ojbKa@03ojbKa@03o`000?nXUlCoZ9O400?oZ9O400?o0000ojBDa?l000000_l000000onV
W<co0000oj>Kc@04oj>Kc@03o`000?nPV/koX9[>00CoX9[>00?o0000oifJd?nMV]000_nMV]001?l0
003oW9_BoibKd_nLVm85o`0000?oWZCI00?o0000oijVfonNY]/00onNY]/00ol0003oWZSMoijXg@04
oijXg@04o`000?nOZ]koWj[NoinZgPCo00001OnR/>800ol0003oXk7Roj>ahP03oj>ahP03o`000?nT
/^?o000000;o000000?oY;CTo`000?nU]N@01_nU]N@01?l0003oY[KTojJfi?nV]^@4o`0000GoYkSU
00?o0000ojNhiOnW^>D00onW^>D4o`0000?oYkWV00?o0000ojRhiOnX^>D01?nX^>D00ol0003oZ;SU
ojRhi@03o`000003ojNii_l0003oYkWV00GoYkWV00?o0000ojNhiOnW^>D00ol000000onW^^Oo0000
ojNii`05ojNii`04o`000?nV^NKoY[WVojJiiPCo00001_nV^^P01?l0003oY[[XojJjj?nV^^P4o`00
00GoYK_Y00?o0000ojFkjOnU^nT00onU^nT4o`0001?ooo]Z1?l0001<oookJP00Y?oonfX00ol0003o
oo]ZoookJP08oookJP;o00001_niaN<2o`0000Oo_LCP0_l00006ol32g0;o00001_o3`=L00ol0003o
`KkHo`000005olFldP03o`000?o2^m?o000000Koa[S=00?o0000ol>hd?l000001Oo5]<T00ol0003o
`[C=o`000007ol>`aP;o00001_o0[<D00ol0003o`:Noo`000004okbYaP03o`000?nlY<7o_:C100?o
_:C10_l00007okNSa003o`000?ndWL7o]9g100;o]9g10_l00005ojnOaP03o`000?n/VlGo[9_500Co
[9_500?o0000ojRGa?nXUl@01?l00005ojJLc003o`000?nSVlgoXi_=00?oXi_=00?o0000oj2Jc_nP
V/h00onPV/h01?l0003oWI[@oifJd?nMV]05o`0000;oWj?G00?o0000oijTfOnNY=T01?nNY=T00ol0
003oWZKKoijVf`03oijVf`04o`000?nNZ=goWZSMoijXg@Ko00000onQ[^400ol0003oX[3Roj:`hP03
oj:`hP04o`000?nS/N;oXk7Roj>ahPCo00001OnT]>@00ol0003oYKGTojFei004ojFei0Co00000onV
]nD00ol0003oYkSUojNhi@04ojNhi@03o`000?nW^>Go000000;o000000?oYkWVo`000?nW^NH01OnW
^NH01?l0003oZ;SUojRhiOnX^>D5o`0000GoYkWV00Co0000ojNii_nW^NKoYkWV1Ol00005ojNji`03
o`000?nW^NOoYkWW00?oYkWW1?l00003ojJjj003o`000?nV^^SoY[[X00CoY[[X1?l00003ojFkj@03
o`000?nU^nWoYK_Y00CoYK_Y00?o0000ojFkjOl000000_l0000DoookJP?o0000D?oonfX00:Gooo]Z
00?o0000oookJ_oonfX02OoonfX2o`000004okW5hol0003o0000o`0000;o^LCS00?o0000okg4h?nm
a>000_nma>02o`0000;o_<?O00Co0000ol32g?o0`]co`<;L0_l00002okk1g004o`000?o3`=Oo`l3G
ol?0e`;o00000oo1_]P01Ol0003oaKcBolFld_o5_=;o000000?o`[_C00Co0000olJhcOo6^<goa[S=
0_l00003ol>hd005o`000?o5]<WoaKC9olFdbOl000000oo2]<d00ol0003o`k36ol>`aP03ol>`aP03
o`000?no/L_o000000Ko`:c50_l00006okbYaP03o`000?nlY<7o_:C100;o000000?o^:O8o`000?ng
Xl@01_ngXl@00ol0003o]9g1okBM`@02o`000003ok:SbOl0003o[io600Go[io600?o0000ojbKaOn/
VlD00_n/VlD4o`0000?oZIk<00?o0000ojJLc?nVW<`00onVW<`00ol0003oXi_=oj>Kc@03oj>Kc@04
o`000?nPV/koX9[>oj2JcPKo00000_nQX]H00ol0003oWj?GoinSe`03oinSe`03o`000?nNY=WoWZCI
00CoWZCI00Co0000oijVfonNY]_oWZKK1Ol00003oj6]g`03o`000?nQ[^7oXJkQ00CoXJkQ00Co0000
oj:`h_nR/>;oX[3R1Ol00004ojBdi003o`000?nT]>CoY;CT00?oY;CT00?o0000ojFei?nU]N@00ol0
00000onU]nGo0000ojJgi@05ojJgi@04o`000?nW^>GoYkSUojNhi@Co00001OnW^NH00ol0003oYkWV
ojNiiP03ojNiiPCo00001?nW^^H00ol0003oYkWVojNiiP03ojNiiPCo00001?nW^^L00ol0003oYk[W
ojNji`03ojNji`03o`000?nW^NOoYkWW00?o000000?oY[_Xo`000?nV^^P01OnV^^P00ol0003oY[[X
ojJjj003o`000003ojJkjOl0003oYK_Y00GoYK_Y00Co0000ojFkjOnU^nWoYK_Y1?l0000CoookJPCo
0000DooonfX00:Kooo]Z0_l0000;oookJP03o`000?nia>?o^LCS00Co^LCS00Co0000okg4h?l0003o
00001Onl`ml00ol0003o`<;Lo`000005okk1g003o`000?o3`=Oo000000Ko`KkH00?o0000olFld_l0
00001Oo2^m<00ol0003oa[S=o`000006ol>hd003o`000?o5]<Wo000000Go`[C=00?o0000ol>`a_o3
/<H00_l00003oknab`03o`000?o0[<Go`:c500;o`:c500?o0000okb^bol000001_nlZLH00ol0003o
_:C1o`000004okRWb003o`000?ngXlCo]j?400Co]j?400?o0000okBM`Ol000001?nbXlT00ol0003o
[io6ojnOaP03ojnOaP03o`000?n/VlGo[9_500;o000000?o[:7=o`000?nYW/`01OnYW/`00ol0003o
YYc<ojJLc003ojJLc003o`000?nSVlgoXi_=00;oXi_=1?l00003oj:Re003o`000?nQX]KoXJ;F00?o
XJ;F00?o0000oinSeonOXmL00onOXmL01?l0003oWZCIoijTfOnNY=T6o`0000;oXJ_N00?o0000oj6]
gonQ[Ml01?nQ[Ml00ol0003oXJkQoj6^h@03oj6^h@Co00000_nS/^<00ol0003oY;CTojBdi005ojBd
i004o`000?nT]>CoY;CTojBdi0Co00001OnU]nD00ol0003oY[OUojJgi@03ojJgi@Co00000onV^NH0
0ol0003oYkWVojNiiP04ojNiiP03o`000?nW^NKo000000;o00000_nW^^L00ol0003oYk[VojNjiP04
ojNjiP03o`000?nW^NKo000000;o000000?oYk[Wo`000?nW^^L01_nW^^L01?l0003oYk[WojNjionW
^^L4o`0000GoY[_X00Co0000ojJjj?nV^^SoY[[X1Ol00005ojJkj@04o`000?nU^nWoYK_YojFkj@Ko
00004ooonfX4o`0005Oooo]Z002XoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000okW4honia><0
0onia><3o`0000Ko_<?O0_l00006okk1g0?o00001_o1_]P2o`0000Ko`[_C0_l00007ol>hd0;o0000
1_o2]<d00ol0003o`k36o`000006oknab`04o`000?o0[<Go`:c5o`0000?o_:k;00?o0000okbYa_nl
ZLH00onlZLH2o`0000Go^:O800?o0000okNSa?ngXl@01?ngXl@2o`0000Go/Z?900?o0000ojnOa_n_
WlH00on_WlH00ol0003o[9_5o`000004ojbQc@03o`000?nYW/coZIk<00CoZIk<00?o0000ojJLc?nV
W<`00_nVW<`00ol0003oXi_=o`000002o`000003ojFRdol0003oXZ;D00GoXZ;D00?o0000oj6Re_nQ
X]H00onQX]H00ol0003oWj?GoinSe`02oinSe`Co00000onQZ]d00ol0003oXJ_Noj6[gP03oj6[gP03
o`000?nQ[MooXJgO00?oXJgO00?o0000oj6^hOnQ[^400ol000000onS/N?o0000oj>bh`04oj>bh`03
o`000?nT]>CoY;CT00CoY;CT1?l00003ojFfi@03o`000?nU]nGoYKOU00CoYKOU00?o0000ojJgiOl0
00000_l000000onV^NKo0000ojJiiP05ojJiiP04o`000?nW^NKoYkWVojNiiPCo00001_nW^^L01?l0
003oYk[VojNji_nW^^H4o`0000GoYk[W00?o0000ojNjionW^^L01?nW^^L4o`0000?oY[_X00?o0000
ojJkj?nV^nP00onV^nP4o`0000CoY[_Y00?o0000ojJkjOnV^nT00onV^nT4o`0001Gooo]Z1?l0001K
oookJP00ZOoonfX00ol0003ooo]ZoookJP09oookJP03o`000?nia>?o000000;o00000onh`n<01?l0
003o_<?Ookc3gonl`ml2o`0000;o^l;O00Co0000okk1g?nn`Mco_/7L0_l00003okg0g004o`000?o1
_]So`KkHol6nf0;o000000?o_[gIo`000?o2^m<01?o2^m<01?l0003o_k_EoknkeOl00005ol>hd003
o`000?no^=?o000000Ko`[C=0_l00007oknab`03o`000?o0[<Go000000Co_:k;00?o0000okbYa_nl
ZLH00_nlZLH00ol0003o^Jc<o`000006okRWb004o`000?ngXlCo]j?4okNSa0;o000000?o]:O;o`00
0?nbXlT01OnbXlT00ol0003o[io6ojnOaP02ojnOaP;o00001On/XLd00ol0003oZIk<ojVNc004ojVN
c004o`000?nVW<coYYc<ojJLc0?o00001OnUX]<00ol0003oXZ;Doj:Re004oj:Re003o`000?nQX]Ko
XJ;F00;oXJ;F00?o0000oinSeol000000_l000000onRZM_o0000oj6Zg@05oj6Zg@03o`000?nQZmko
XJ_N00?oXJ_N00Co0000oj6]gonQ[MooXJgO1?l00005oj>ah`03o`000?nS/^?oXk;S00?oXk;S00?o
0000ojBdi?nT]>@00ol000000onT]^Go0000ojFfi@05ojFfi@04o`000?nU]nGoYKOUojFgi@Co0000
1OnV^NH00ol0003oY[WVojJiiP03ojJiiPCo00001?nW^^L00ol0003oYk[WojNji`03ojNji`Co0000
0onW^nL00ol0003oYk[WojNji`04ojNji`03o`000?nW^^OoYk[W00?o000000?oY[_Xo`000?nV^nP0
1OnV^nP00ol0003oY[_Xo`000002o`0000;oY[cY00?o0000ojJkjOnV^nT01?nV^nT00ol0003oY[_Y
o`000002o`0001Gooo]Z1?l0001OoookJP00Z_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?nh
`n?o^<?S00Go^<?S00?o0000okc3gol000001Onk`]l00ol0003o_/7Lo`000006okg0g003o`000?o1
_]So000000Co_[gI00Go0000ol:kdoo2^m?o`[_Co`000004oknke@05o`000?o3^=3o`kS@ol>hd?l0
00000ono^=<00ol0003o`[C=ol:dc@02ol:dc@03o`000?nn]=7o000000Oo_k7;0_l00006okb^b`04
o`000?nlZLKo_:W6o`0000?o^Jc<00?o0000okRWb?nhYlP00onhYlP01?l0003o]j?4o`000?l00004
okBWb`03o`000?nbXlWo/Z?900?o/Z?900?o0000ojnOa_l000000_l000000on^YLko0000ojbQc@05
ojbQc@03o`000?nYW/coZIk<00?oZIk<1?l00002ojNSdP03o`000?nUX]?oYJ;C00CoYJ;C00?o0000
oj:Re?nRX]@00onRX]@01?l0003oXJ;Foj6Re_nQX]H3o`0000GoXZWK00?o0000oj6ZgOnQZ]d01?nQ
Z]d01?l0003oXJ_Noj6[g_nQZmh5o`0000?oX[3R00?o0000oj>ahonS/N<01?nS/N<01?l0003oXk;S
oj>bhonS/^<4o`0000GoY;KU00?o0000ojFfiOnU]^D00onU]^D4o`0000?oY[SV00?o0000ojJii_nV
^NH01?nV^NH00ol0003oY[WVo`000002o`0000;oY[[W00?o0000ojNjionW^^L01?nW^^L00ol0003o
Yk[Wo`000002o`000003ojNkj?l0003oYk_W00GoYk_W00Co0000ojNjionW^^OoYk[W1Ol00005ojJk
j004o`000?nV^nSoY[_XojJkj0Co00001_nV_>T01?l0003oY[_YojJkjOnV^nT4o`0001Gooo]Z0ol0
001SoookJP00ZooonfX00ol0003ooo]ZoookJP09oookJP03o`000?nh`n?o^<?S00Co^<?S0_l00006
ok_2g`;o00001onm`=`2o`0000Ko_[gI00?o0000ol:kdol000001_no^mD00ol0003o`kS@o`000005
oknhd`04o`000?o2]<go`[C=o`0000?o_[CA00?o0000oknabono/L/00ono/L/00ol0003o_;;@o`00
0006okb^b`03o`000?nlZLKo000000Co^Jc<00?o0000okRWb?nhYlP00onhYlP2o`0000Oo]:O;00?o
0000ok:SbOnbXlT00_nbXlT2o`0000Go[ZG>00?o0000ojbQcOn/XLd00on/XLd00ol0003oZIk<ojVN
c003o`000003ojVUd_l0003oYj?B00CoYj?B00?o0000ojFRdonUX]<00onUX]<01?l0003oXZ;Doj:R
e?nRX]@6o`0000;oXjSJ00?o0000oj:YfonRZM/01?nRZM/00ol0003oXJ[Moj6Zg@03oj6Zg@Co0000
0_nS[n400ol0003oX[3Roj:`hP04oj:`hP04o`000?nS/N?oXk7Soj>ah`Ko00000onT]ND00ol0003o
Y;KUojBfi@03ojBfi@03o`000?nU]^GoYKKU00?o000000?oYKSVo`000?nV^>H01OnV^>H01?l0003o
Y[WVojJii_nV^NH4o`0000KoY[[W00Co0000ojNjionW^^OoYk[W1?l00005ojNkj003o`000?nW^nOo
Yk_W00?oYk_W1?l00004ojJkj003o`000?nV^nSoY[_X00?oY[_X1?l00003ojJlj@03o`000?nV_>Wo
Y[cY00CoY[cY1?l0000EoookJPCo0000I_oonfX00:cooo]Z0_l0000:oookJP03o`000?nh`n?o^<?S
00?o00000_ng`^<01?l0003o^l;Ook_2gonk`]l2o`0000;o^L7P00?o0000okg0g?nm`=`00_nm`=`2
o`000003ok^ogOl0003o_[gI00Go_[gI0_l00007oknke@;o00001_no^=<00ol0003o`[C=o`000005
okjdd@03o`000?no/L_o_k7;00;o00000onl/]000ol0003o_:k;okb^b`03okb^b`;o00001_ni[<`0
0ol0003o^:O8okRWb002o`000003okF[c_l0003o]:O;00Ko]:O;00?o0000ok:SbOl000000_l00000
0on`Z<oo0000ojjUcP05ojjUcP03o`000?n/XLgo[:7=00;o[:7=0ol00005ojVUdP03o`000?nWXm;o
Yj?B00?oYj?B00?o0000ojFRdonUX]<00_nUX]<4o`0000?oY:SI00?o0000oj>Xf_nSZ=X00onSZ=X0
0ol0003oXZWKoj:Yf`03oj:Yf`03o`000?nQZ]goXJ[M00?o000000?oXjkPo`000?nS[n401?nS[n40
0ol0003oX[3Roj:`hP03oj:`hPCo00000onT]>@00ol0003oY;GUojBei@04ojBei@04o`000?nT]^Go
Y;KUojBfi@Co00001OnU^>H00ol0003oY[SVojJhiP03ojJhiPCo00000onV^^L00ol0003oY[[WojJj
i`04ojJji`Co00000onV^nP00ol0003oYk_XojNkj004ojNkj003o`000?nW^nOo000000;o00000_nV
^nP00ol0003oY[_XojJkj004ojJkj003o`000?nV^nSo000000;o00000_nV_>T00ol0003oY[cYojJl
j@03ojJlj@03o`000?nV_>WoY[cY00?o00005OoonfX4o`0006[ooo]Z002^oookJP03o`000?oonf[o
oo]Z00Sooo]Z0_l00006okO2h`03o`000?nk`]oo000000Go^L7P00Co0000okg0g?l0003o00001?nk
_md01?l0003o_[gIokjmfOnn_MT2o`0000;o_;gJ00?o0000oknkeOno^mD00_no^mD2o`000003okbj
f?l0003o_kSC00Go_kSC0_l00006okjdd@03o`000?no/L_o000000Ko_;;@00?o0000okb^bonl[//0
0_l000000oni/=3o0000okV/c005okV/c003o`000?nhYlSo000000Co]J_>00?o0000okBWbondYl/0
1?ndYl/2o`0000Go/:S?00?o0000ojjUc_n^YLh00on^YLh00ol0003o[:7=o`000002o`000003oj^W
dol0003oZJGB00KoZJGB00?o0000ojNSd_nWXm800_nWXm800ol0003oYJ;Co`000002o`000003ojJX
f?l0003oY:SI00GoY:SI00?o0000oj>Xf_nSZ=X00onSZ=X01?l0003oXZWKoj:YfonRZM/4o`0000Go
XjkP00?o0000oj>_hOnS[n400onS[n400ol0003oX[3Ro`000002o`000003ojBci?l0003oY;CT00Go
Y;CT00?o0000ojBeiOnT]ND00onT]ND4o`0000?oYKOV00?o0000ojFhi_nU^>H01?nU^>H00ol0003o
Y[SVo`000002o`0000;oY[WW00?o0000ojJjionV^^L00onV^^L00ol0003oY[[WojJji`03o`000003
ojJkj?l0003oY[_X00GoY[_X00Co0000ojNkj?nW^nSoYk_X1?l00006ojJkj004o`000?nV^nSoY[_X
ojJkj0Co00001_nV_>T01?l0003oY[cYojJljOnV_>T4o`0001Cooo]Z1?l0001^oookJP00[ooonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?ng`^?o]l;S00?o]l;S0_l00006okW1h0?o00001_nk_md0
0ol0003o_[gIo`000005okbmfP04o`000?no^mGo0000o`0000Co_;[H00Co0000oknhdono^=?o_kSC
0_l000000onl^=Ko0000okjdd@05okjdd@;o00001onl/]000ol0003o_:k;o`000004okV`d003o`00
0?ni[<co^Jc<00?o^Jc<0_l00006okF[cP04o`000?ndYl_o]:O;okBWb`;o000000?o/Z_Bo`000?n`
Z<l01On`Z<l00ol0003o[ZG>ojjUcP02ojjUcP;o00001On[Ym<00ol0003oZJGBojVUdP04ojVUdP04
o`000?nWXm;oYj?BojNSdP?o00001OnVZ=P00ol0003oY:SIojBXf@03ojBXf@04o`000?nSZ=[oXjSJ
oj>XfPKo00000onS[]l00ol0003oXjkPoj>^h003oj>^h004o`000?nS[n7oXjoQoj>_h@Co00001OnT
/n@00ol0003oY;CTojBdi004ojBdi003o`000?nT]NGo000000;o000000?oYKOVo`000?nU]nH01OnU
]nH01?l0003oYKSVojFhi_nU^>H4o`0000KoY[WW00Co0000ojJjionV^^OoY[[W1?l00005ojJkj003
o`000?nV^nSoY[_X00?oY[_X1?l00003ojJlj003o`000?nV^nSoY[_X00CoY[_X1?l00003ojJlj@03
o`000?nV_>WoY[cY00CoY[cY1?l0000EoookJP?o0000L_oonfX00;3ooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003o]l;So`000002o`0000;o]/;S00Co0000okW1h?ni`N3o^L7P0_l00003okS0h@03
o`000?nk_mgo^koM00?o^koM0_l00006okbmfP;o00001onl^]P00ol0003o_kSCo`000004okbheP04
o`000?nn]=7o_[CAokjdd@;o000000?o^kKDo`000?nl/]001_nl/]02o`0000Ko^K3@00?o0000okV/
c?ni[<`00_l000000onf[m;o0000okF[cP05okF[cP04o`000?ndYl_o0000o`0000Co/Z_B00?o0000
ok2Xcon`Z<l00on`Z<l00ol0003o[ZG>o`000002o`000003ojfZe?l0003oZjOC00GoZjOC00?o0000
ojVUd_nYYM800onYYM84o`0000;oYjWH00?o0000ojJXf?nVZ=P01?nVZ=P00ol0003oY:SIojBXf@02
ojBXf@Co00000onT[Mh00ol0003oXjkOoj>^g`04oj>^g`04o`000?nS[^3oXjkPoj>^h0Go00001?nT
/^<00ol0003oY;?TojBci003ojBci004o`000?nT]>CoY;CTojBdi0Co00001OnU]nH00ol0003oYKOV
ojFgiP03ojFgiPCo00000onU^NL00ol0003oY[WWojJii`04ojJii`Co00000onV^nP00ol0003oY[_X
ojJkj004ojJkj003o`000?nV^nSo000000;o00000_nV_>T00ol0003oY[cXojJlj003ojJlj003o`00
0?nV^nSoY[_X00?o000000?oY[cYo`000?nV_>T01OnV_>T00ol0003oY[cYojJlj@03o`0001Gooo]Z
1?l0001eoookJP00/OoonfX2o`0000[ooo]Z00?o0000okK2honf`^<01?nf`^<00ol0003o^L7Po`00
0006okS0h@03o`000?nk_mgo000000;o00000_ni_]h01?l0003o_;gJokbmf_nl_MX2o`000003okZm
g?l0003o_;[H00Ko_;[H0_l00006okbheP03o`000?nn]=7o000000Co^kKD00?o0000okbbd?nl/]00
0_nl/]02o`000003okVce?l0003o^K3@00Go^K3@00?o0000okV/c?l000001?nf[m800ol0003o]J_>
okF[cP03okF[cP;o00001onbZm800ol0003o/:S?ok2Xc`02ok2Xc`;o00001On]Z]@00ol0003oZjOC
oj^Wd`03oj^Wd`03o`000?nYYM;oZJGB00?o000000?oZJ_Ho`000?nWZMP01?nWZMP00ol0003oYZSH
ojJXf003ojJXf003o`000?nTZ=Wo000000;o000000?oYJgMo`000?nT[Mh01OnT[Mh00ol0003oXjkO
oj>^g`03oj>^g`Co00000_nT/^800ol0003oY;;SojBbh`05ojBbh`04o`000?nT/nCoY;?TojBci0Go
00000onT]^D00ol0003oYKOVojFgiP04ojFgiP03o`000?nU]nKo000000;o00000_nU^NL00ol0003o
YKWWojFii`03ojFii`03o`000?nV^NOoY[WW00?o000000?oY[_Xo`000?nV^nP01OnV^nP01?l0003o
Y[_XojJkj?nV^nP4o`0000KoY[cY00Co0000ojJlj?nV_>SoY[cX1?l00005ojJlj@04o`000?nV_>Wo
Y[cYojJlj@Go00005?oonfX4o`0007Wooo]Z002coookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
okK2honf`^<00onf`^<2o`0000Oo^<3Q0_l00006okVngP03o`000?nl_M[o000000Co^[gL00?o0000
okbjf?nl^]P00_nl^]P2o`000003okZjf_l0003o_;SF00Go_;SF0_l00006ok^fe004o`000?nl/]3o
0000o`0000Co^K?D00?o0000okV`d?ni/=000oni/=02o`0000Ko]ZoB00?o0000okF[c_l000000_l0
00000onc[]Co0000ok:[dP06ok:[dP03o`000?n`Z<oo000000;o000000?o[jcEo`000?n]Z]@01On]
Z]@00ol0003oZjOCoj^Wd`02oj^Wd`?o00001OnYZmP00ol0003oYjWHojNYf003ojNYf004o`000?nV
Z=SoYZSHojJXf0?o00001OnU[Md00ol0003oY:gNojB]gP04ojB]gP03o`000?nS[]oo000000;o0000
00?oY;7Qo`000?nT/^801?nT/^800ol0003oY;;SojBbh`04ojBbh`Co00000onT]^D00ol0003oY;KU
ojBfi@03ojBfi@04o`000?nU]nKoYKOVojFgiPCo00001_nU^NL01?l0003oYKWWojFiionU^NL4o`00
00GoY[_X00?o0000ojJkj?nV^nP00onV^nP4o`0000?oY[cY00?o0000ojJljOnV_>T01?nV_>T4o`00
00?oY[cY00?o0000ojJljOnV_>T00onV_>T4o`0001Gooo]Z1?l0001moookJP00]?oonfX00ol0003o
oo]ZoookJP08oookJP03o`000?nf`^?o000000;o00000_ne`N<00ol0003o^<3QokS0h@02okS0h@;o
000000?o]/3Qo`000?ni_]h01Oni_]h2o`0000Ko^[gL00Co0000okbjf?l0003o00001?nj^]X01?l0
003o_;SFokbhe_nl^=H2o`000003okVhfOl0003o^kKD00Go^kKD0_l00007okVce003o`000?ni/=3o
000000;o000000?o][;Eo`000?nf[m801Onf[m82o`0000Go/jkD00?o0000ok:[d_nbZm801?nbZm82
o`0000Go[jcE00?o0000ojfZe?n]Z]@00on]Z]@00ol0003oZjOCo`000002o`000003oj^/f?l0003o
ZJ_H00GoZJ_H00?o0000ojNYf?nWZMP00onWZMP4o`0000;oYZgL00?o0000ojF]gOnU[Md01?nU[Md0
1?l0003oY:gNojB]g_nT[Mh4o`0000GoY;7Q00?o0000ojBbh_nT/^800onT/^800ol0003oY;;SojBb
h`03o`000003ojBeiOl0003oY;KU00GoY;KU00Co0000ojBfiOnT]^GoY;KU1Ol00003ojFhi`03o`00
0?nU^NOoYKWW00CoYKWW1?l00003ojJjj003o`000?nV^nSoY[_X00CoY[_X00?o0000ojJkj?l00000
0_l00002ojJlj@03o`000?nV_>WoY[cY00?oY[cY00?o0000ojJljOnV_>T00ol000000onV_>Wo0000
ojJlj@05ojJlj@03o`000?nV_>Wo000000;o00005OoonfX4o`00087ooo]Z002eoookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000okG1hone`N<01?ne`N<01?l0003o^<3Qo`000?l00004okK0h@04o`00
0?ni_]ko^KkNokVngP;o00000_ng_]l00ol0003o^[gLokZmg003okZmg0?o00001_nj^]X00ol0003o
_;SFo`000004okVhf@04o`000?nk]]Co^kKDok^fe0;o000000?o^;OHo`000?ni/m@01_ni/m@2o`00
00Go][;E00Co0000okJ_d_nf[m;o]ZoB0_l000000onc/MOo0000ok>^e005ok>^e003o`000?nbZm;o
/Z_B00?o000000?o/:oGo`000?n_[=D01On_[=D00ol0003o[J[DojfZe002ojfZe0;o00001On[[=P0
0ol0003oZJ_HojV[f003ojV[f003o`000?nWZMSoYjWH00?o000000?oZ:kLo`000?nV[M`01?nV[M`0
0ol0003oYJgMojF]g@03ojF]g@Co00001?nU/N400ol0003oY;7QojBah@03ojBah@04o`000?nT/^;o
Y;;RojBbhPCo00001OnT]ND00ol0003oY;KUojBfi@03ojBfi@Co00000onU^>L00ol0003oYKSWojFh
i`03ojFhi`03o`000?nU^NOoYKWW00?o00000_nU^^P00ol0003oY[[XojJjj003ojJjj004o`000?nV
^nSoY[_XojJkj0Co00001_nV_>T01?l0003oY[cYojJljOnV_>T4o`0000GoY[cY00Co0000ojJljOnV
_>WoY[cY1?l0000EoookJP?o0000QOoonfX00;Kooo]Z0_l00009oookJP03o`000?ne`N?o]L7S00?o
]L7S0ol00006okK0h@03o`000?ni_]ko000000Go]kkO00?o0000okZmg?l000000_l00003okNlg@03
o`000?nj^][o^[[J00?o^[[J0_l00006okVhf@03o`000?nk]]Co000000Co^;OH00?o0000okVce?ni
/m@00_ni/m@2o`000003okJef?l0003o][;E00Go][;E00?o0000okJ_d_l000001?nc/ML00ol0003o
/jkDok>^e003ok>^e0?o00001On`[mL00ol0003o[jcEojn/e@03ojn/e@03o`000?n]Z]Co000000;o
000000?o[:kIo`000?n[[=P01On[[=P01?l0003oZJ_HojV[f?nYZmP4o`0000GoZ:kL00?o0000ojJ]
g?nV[M`00onV[M`00ol0003oYJgMo`000002o`000003ojJah?l0003oYK7Q00KoYK7Q00Co0000ojBa
hOnT/N7oY;7Q1Ol00003ojFei003o`000?nT]NGoY;GU00?oY;GU00?o0000ojBfiOnT]^D00ol00000
0onU^>Ko0000ojFhi`05ojFhi`04o`000?nU^>OoYKSWojFhi`Co00001_nU^^P01?l0003oY[[XojJj
j?nV^^P5o`0000?oY[_Y00?o0000ojJljOnV_>T01?nV_>T4o`0000?oY[cY00?o0000ojJljOnV_>T0
0onV_>T4o`0001Gooo]Z1?l00028oookJP00^?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?ne
`N?o000000;o00000ond`N@00ol0003o]/3QokK0h@03okK0h@;o00001_ng_]l2o`0000Oo]kcM00?o
0000okZjf_l000000_l00002okNkg003o`000?ni^=Wo^KSI00?o^KSI0_l00006okRgf004o`000?ni
/mCo0000o`0000Co][GH00?o0000okJbeOnf/]D00onf/]D2o`0000Ko/k7G00?o0000ok>^e?nc[]@0
0_l000000ona/MWo0000ok2_e`05ok2_e`03o`000?n_[=Go[jcE00?o[jcE0_l00005ojb^f@03o`00
0?n[[=SoZjcH00?oZjcH1?l00002ojV_g003o`000?nX[]coZ:kL00GoZ:kL00Co0000ojJ]g?nV[Mco
YZgL0ol00005ojJah003o`000?nU/N7oYK7Q00CoYK7Q1?l00003ojFdi003o`000?nU]NCoYKGT00?o
YKGT00Co0000ojBeiOnT]NGoY;GU1?l00005ojFhiP03o`000?nU^>OoYKSW00?oYKSW1?l00003ojFj
j003o`000?nU^^SoYK[X00CoYK[X1?l00003ojJkj@03o`000?nV^nWoY[_Y00?oY[_Y00?o0000ojJl
jOnV_>T00ol000000onV_>Wo0000ojJlj@05ojJlj@03o`000?nV_>Wo000000;o00005OoonfX4o`00
08cooo]Z002ioookJP03o`000?oonf[ooo]Z00Oooo]Z0_l00006okC1i003o`000?nf`>7o000000;o
00000_ne_n801?l0003o]kkOokNngong_]l2o`000003okFnh?l0003o]kcM00Ko]kcM0_l00006okNk
g003o`000?ni^=Wo000000;o00000_nf^M/00ol0003o^;OHokRgf003okRgf0;o00001onf]MP00ol0
003o][;Eo`000002o`000003ok>dfOl0003o/k7G00Go/k7G00?o0000ok>^e?l000001?na/MT00ol0
003o/:oGok2_e`03ok2_e`03o`000?n_[=Go[jcE00?o000000?o[K3Jo`000?n/[]T01On/[]T00ol0
003oZjcHo`000002o`000003ojZ`g?l0003oZJoL00CoZJoL00?o0000ojR^g?nX[]`01?nX[]`4o`00
00?oYk7P00?o0000ojJah?nV/N000onV/N000ol0003oYK7QojFah@03o`000003ojJdhol0003oYKCT
00GoYKCT00Co0000ojFei?nU]NCoYKGT1Ol00003ojFgiP03o`000?nU^>KoYKSV00CoYKSV00?o0000
ojFhiol000000_l00002ojFjj003o`000?nU^^SoYK[X00?oYK[X00?o0000ojFjj?nU^^P00ol00000
0onV^nWo0000ojJkj@05ojJkj@04o`000?nV^nWoY[_YojJkj@Co00001OnV_>T01?l0003oY[cYojJl
jOnV_>T4o`0001Cooo]Z1?l0002@oookJP00^_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?nd
`NCo]<7T00?o]<7T0_l00006okFohP03o`000?ng_]oo000000Co]KkP00?o0000okNlgOng_=d00_ng
_=d2o`000003okFlgol0003o]k_L00Go]k_L0_l00006okJif`03o`000?nh]mSo000000;o000000?o
]KSKo`000?nf]MP01_nf]MP2o`0000Go/kCI00?o0000ok>aeonc/ML00onc/ML2o`0000Ko/K7I00?o
0000ok2_eon`[mL00_n`[mL3o`0000Go[K3J00?o0000ojb^fOn/[]T00on/[]T2o`0000GoZ[3L00?o
0000ojV_g?nY[m`00onY[m`00ol0003oZ:kLojR^g003o`000003ojRbgol0003oYk7P00GoYk7P00Co
0000ojJah?nV/N3oY[7P1?l00005ojJdh`03o`000?nU]>CoYKCT00?oYKCT1?l00003ojFgiP03o`00
0?nU]nKoYKOV00?oYKOV00Co0000ojFhi_nU^>KoYKSV1?l00006ojFjj004o`000?nU^^SoYK[XojFj
j0Co00001OnV^nT00ol0003oY[_YojJkj@03ojJkj@Co00000onV_>T00ol0003oY[cYojJlj@03ojJl
j@Co00005OoonfX3o`0009Cooo]Z002koookJP;o00002OoonfX00ol0003o]<7To`000002o`0000;o
/l3T00?o0000okFoh_ne_n800one_n82o`0000Ko]KkP00Co0000okNlgOl0003o00001?ne_=l01?l0
003o]k_LokNkg?ng^m`2o`000003okFkg_l0003o][WK00Go][WK0_l00005okFhf`03o`000?nf]MSo
][GH00;o][GH0_l000000onc]m_o0000ok>df@05ok>df@03o`000?nc/MOo000000;o000000?o/KCJ
o`000?na/MT01Ona/MT00ol0003o/:oGo`000002o`000003ojjbfol0003o[K3J00Ko[K3J00?o0000
ojb^fOl000000_l000000on[/]go0000ojZ`g005ojZ`g004o`000?nY[mcoZJoLojV_g0Co00001OnX
/]l00ol0003oYk7PojNah003ojNah0Co00000onV]><00ol0003oY[CSojJdh`03ojJdh`03o`000?nU
]>CoYKCT00?o000000?oY[OUo`000?nU]nH01OnU]nH01?l0003oYKOVojFgi_nU]nH5o`0000?oYKWW
00?o0000ojFjj?nU^^P01?nU^^P4o`0000?oYK_X00?o0000ojJkjOnV^nT00onV^nT00ol0003oY[_Y
ojJkj@03o`000003ojJljOl0003oY[cY00GoY[cY00?o0000ojJljOl000000_l0000EoookJPCo0000
UooonfX00;gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o/l3Tok?0i004ok?0i003o`000?ne
_n;o000000;o00000_nc_n<00ol0003o]KkPokFnh003okFnh0?o00001_ne_=l00ol0003o]k_Lo`00
0004okFkgP04o`000?nf^M_o][WKokJif`;o000000?o];[No`000?ne^=/01One^=/01?l0003o][GH
o`000?l00004ok>gf`03o`000?nc]=Wo/kCI00?o/kCI0_l00005ok6dfP03o`000?na/MWo/K7I00?o
/K7I0_l00005ojjbf`03o`000?n]/=[o[K3J00Co[K3J0_l00005oj^bg@03o`000?nZ/=coZ[3L00?o
Z[3L1?l00003ojVbg`03o`000?nX/]ooZ;;O00CoZ;;O00?o0000ojNah?l000000_l000000onW]>;o
0000ojJdh`05ojJdh`04o`000?nV]>?oY[CSojJdh`Co00001OnV]nD00ol0003oYKOVojFgiP03ojFg
iPCo00000onU^NL00ol0003oYKWWojFii`03ojFii`03o`000?nU^^SoYK[X00?o000000?oYK_Xo`00
0?nU^nP01OnU^nP01?l0003oY[_YojJkjOnV^nT4o`0000GoY[cY00Co0000ojJljOnV_>WoY[cY1?l0
000DoookJPCo0000VooonfX00;kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o/l3Tok?0i003
ok?0i0;o00001_nc_n<00ol0003o]KkPo`000002o`0000?o/kkR00?o0000okFlgone_=l00one_=l2
o`0000Ko]K_N00?o0000okJifol000001?nd^]h00ol0003o]KSKokFhf`03okFhf`;o00001onc]m/0
0ol0003o/kCIo`000002o`000003ok6fg?l0003o/KCJ00Go/KCJ00?o0000ok6afOl000000_l00002
ojndg003o`000?n^/]_o[[;K00?o[[;K00?o0000ojf`f_n]/=X00ol000000on//mgo0000oj^bg@05
oj^bg@03o`000?nZ/=co000000;o000000?oZK?Po`000?nY/]l01OnY/]l01?l0003oZ;;OojRbgonX
/]l4o`0000GoYkCR00?o0000ojJdhonV]><00onV]><4o`0000?oY[OU00?o0000ojJgiOnV]nD00onV
]nD00ol0003oYKOVojFgiP03o`000003ojJiiol0003oYKWW00GoYKWW00Co0000ojFiionU^NOoYKWW
1?l00005ojFkj004o`000?nU^nSoYK_XojFkj0Ko00000onV_>T00ol0003oY[cYojJlj@03ojJlj@Co
00005?oonfX4o`0009oooo]Z002ooookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000ok?0i?l00000
0_l00002ok70i@03o`000?nc_n?o/koS00?o/koS0_l00007ok>nhP03o`000?ne_=oo000000;o0000
0_nc_N400ol0003o]K_NokFkgP03okFkgP;o00001_nd^]h00ol0003o]KSKo`000002o`0000;o/[WN
00?o0000ok>gfonc]m/01?nc]m/2o`0000Go/KKL00?o0000ok6df_na]=X00ona]=X2o`0000Ko[kCL
00Co0000ojjbfon^/]_o[[;K1?l00005ojbcg@03o`000?n[/]goZk;M00?oZk;M0_l00005ojVch003
o`000?nY/]ooZK;O00?oZK;O1?l00003ojRehP03o`000?nW]>;oYkCR00CoYkCR00?o0000ojJdhol0
00000_l000000onV]nGo0000ojJgi@05ojJgi@04o`000?nV]nGoY[OUojJgi@Co00001OnV^NL00ol0
003oYKWWojFii`03ojFii`Co00000onU^nP00ol0003oYK_XojFkj003ojFkj0Co00001?nV_>T00ol0
003oY[cYojJlj@03ojJlj@03o`000?nV_>Wo000000;o00005?oonfX4o`000:?ooo]Z0030oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000ok70iOna`>D01?na`>D00ol0003o/koSo`000002o`0000;o
/[oT00?o0000ok>nh_nc_^801?nc_^82o`0000Ko/kgQ00?o0000okFkg_l000000_l00002ok>kh003
o`000?nd^]ko];[N00?o];[N0_l00006ok:igP03o`000?nc]m_o/kOK00?o000000?o/KSNo`000?na
]]`01Ona]]`00ol0003o/KCJo`000002o`0000;o[kKN00?o0000ojndg?n_]=`00on_]=`4o`0000?o
[KGN00?o0000ojbcgOn//md01?n//md00ol0003oZk;Mo`000002o`0000;oZkCP00?o0000ojVch?nY
/n000onY/n000ol0003oZK;Oo`000002o`000003ojRfh_l0003oZ;GR00GoZ;GR00Co0000ojNdh_nW
]>;oYkCR1?l00005ojJgi@03o`000?nV]nGoY[OU00?oY[OU1?l00003ojJii`03o`000?nV^NOoY[WW
00CoY[WW00?o0000ojFiiol000000_l00002ojJjj003o`000?nU^nSoYK_X00?oYK_X00?o0000ojFk
j?l000000_l00002ojJlj@03o`000?nV_>WoY[cY00CoY[cY00Co0000ojJljOnV_>WoY[cY0ol0000D
oookJP?o0000YooonfX00<7ooo]Z0_l00008oookJP03o`000?na`>Go/L3U00?o/L3U0_l00006ok:o
i003o`000?nc_^;o/kkR00?o00000_nb_^<00ol0003o/kgQok>mh@03ok>mh@;o00001_nc^n000ol0
003o];[No`000002o`0000;o/[_P00?o0000ok:ig_nb^Mh00onb^Mh3o`0000Go/KSN00?o0000ok6f
g?na]]`00ona]]`2o`0000Ko[kKN00?o0000ojndg?l000000_l000000on]]]oo0000ojfegP05ojfe
gP04o`000?n//mgo[;?Mojbcg@Co00001_n[]>001?l0003oZK?PojVch?nY/n03o`0000GoZ;KR00?o
0000ojReh_nX]N800onX]N84o`0000?oYkOT00?o0000ojJgiOnV]nD01?nV]nD00ol0003oY[OUo`00
0002o`0000;oY[WV00?o0000ojJiionV^NL00onV^NL01?l0003oY[WWojJiionV^NL4o`0000KoY[[X
00Co0000ojFkj?nU^nSoYK_X0ol00006ojJlj@04o`000?nV_>WoY[cYojJlj@Ko00004ooonfX4o`00
0:[ooo]Z0033oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000ok70iOl000000_l00002ok30i@03
o`000?nb_nCo/[oT00?o/[oT0ol00006ok:nh`03o`000?nc_N7o000000;o00000_na_N800ol0003o
/k_Pok>kh003ok>kh0;o00001_nb^n000ol0003o/[WNo`000002o`000003ok2jh?l0003o/KSN00Ko
/KSN00?o0000ok6fg?l000000_l00002ojnhg`03o`000?n_]]ko[kKN00?o[kKN0_l00005ojffg`03
o`000?n]]Mko[KGN00?o[KGN1?l00003oj^fh@03o`000?n[]>3oZkCP00CoZkCP1?l00003ojVfhP03
o`000?nX]^;oZ;KR00?oZ;KR00?o0000ojReh_l000000_l000000onW]nCo0000ojNgi005ojNgi004
o`000?nV]nGoY[OUojJgi@Co00001_nV^NH01?l0003oY[WWojJiionV^NL5o`0000?oY[[X00?o0000
ojJjj?nV^^P01?nV^^P4o`0000?oY[cY00?o0000ojJljOnV_>T00onV_>T4o`0001Gooo]Z1?l0002^
oookJP00a?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?n``>Go/<3U00Co/<3U00?o0000ok:o
i?l000000_l00003ok2oi@03o`000?nb_^?o/[kS00?o/[kS0_l00006ok6mhP03o`000?nc^n3o0000
00;o00000_na_>800ol0003o/[_Pok:kh003ok:kh0;o00001On`^^000ol0003o/KSNok6hgP04ok6h
gP;o00001_n_^=l00ol0003o[kKNo`000002o`000003ojjhhOl0003o[KKO00Go[KKO00?o0000ojfe
g_l000000_l000000on/]n7o0000oj^fh@05oj^fh@03o`000?n[]>3oZkCP00?o000000?oZ[OSo`00
0?nY]^801OnY]^801?l0003oZ;KRojRfh_nX]^83o`0000GoYkOT00?o0000ojNgi?nW]n@00onW]n@4
o`0000CoY[WV00?o0000ojJii_nV^NH00onV^NH4o`0000?oY[[X00?o0000ojJjj?nV^^P00onV^^P0
0ol0003oY[[XojJjj003o`000003ojJljOl0003oY[cY00GoY[cY00?o0000ojJljOl000000_l0000E
oookJPCo0000/_oonfX00<Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o/<3Uok30i@03ok30
i@;o00001on`_nD00ol0003o/[kSo`000002o`0000;o/;kT00?o0000ok6mh_na_N800ona_N82o`00
00Ko/KcR00?o0000ok:kh?l000000_l000000on`^n;o0000ok2jh005ok2jh003o`000?na^=ko/KSN
00?o00000_n_^N400ol0003o[kSOojnhg`03ojnhg`;o00001On^^>400ol0003o[KKOojffg`03ojff
g`;o00001On/]n400ol0003oZkKQoj^fh@03oj^fh@?o00001OnZ]n<00ol0003oZKKRojVfhP03ojVf
hPCo00000onX^>@00ol0003oYkOTojNgi003ojNgi003o`000?nW]nCo000000;o00000_nW^NH00ol0
003oY[WVojJiiP04ojJiiP03o`000?nV^NKo000000;o00000_nV^^L00ol0003oY[[XojJjj003ojJj
j004o`000?nV^^SoY[[XojJjj0Co00001OnV_>T01?l0003oY[cYojJljOnV_>T4o`0001Cooo]Z1?l0
002foookJP00a_oonfX2o`0000Oooo]Z00?o0000ok30iOl000000_l00002ojo0iP03o`000?n`_nGo
/;oU00Co/;oU0_l00006ok2ni003o`000?na_N;o000000;o00000_n`_N@00ol0003o/KcRok6lhP03
ok6lhP;o00001On`^n800ol0003o/;[Pok2jh003ok2jh0?o00001_n_^N400ol0003o[kSOo`000002
o`000003ojjih_l0003o[[SQ00Go[[SQ00?o0000ojffgol000000_l00002ojbhhP03o`000?n/]n7o
[;OQ00?o[;OQ00?o0000oj^fhOl000000_l00002ojZhh`03o`000?nZ]n?oZ[OS00CoZ[OS00?o0000
ojVfh_l000000_l000000onX^>Co0000ojRhi005ojRhi004o`000?nW]nCoYkOTojNgi0?o00001_nW
^NH01?l0003oY[WVojJii_nV^NH4o`0000KoY[[W00Co0000ojJjj?nV^^SoY[[X1Ol00003ojJkj@03
o`000?nV_>WoY[cY00?oY[cY1?l0000EoookJP?o0000^_oonfX00<Sooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003o[l3Vojo0iP04ojo0iP03o`000?n`_nGo/;oU00?o00000_n__nH00ol0003o/;kT
ok2ni003ok2ni0;o00001_n`_N@00ol0003o/KcRo`000002o`0000;o[kgT00?o0000ok2kh_n`^n80
0on`^n800ol0003o/;[Po`000002o`0000;o[k_R00?o0000ojnihOn_^N401?n_^N42o`0000Go[[WR
00?o0000ojjhhOn^^>400on^^>42o`0000Ko[;SR00Co0000ojbghOn/]n7o[;OQ0ol00006ojZhh`04
o`000?nZ]n?oZ[OSojZgh`Co00001OnX^>@00ol0003oZ;STojRhi003ojRhi0Co00000onW^NH00ol0
003oYkWVojNiiP03ojNiiPCo00000onV^^L00ol0003oY[[WojJji`04ojJji`Co00000onV^nT00ol0
003oY[_YojJkj@03ojJkj@03o`000?nV_>Wo000000;o00005OoonfX4o`000;gooo]Z0039oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?o0000ojo0i_n_`>H00on_`>H3o`0000Ko[koV00?o0000ok2ni?l0
00000_l00002ojnni@03o`000?n`_NCo/;gT00?o/;gT0_l00006ojnmi004o`000?n`^n;o/;_Rok2k
hP?o00001_n_^n800ol0003o[kWQojnih@03o`0000;o[[[S00?o0000ojjih_n^^N800on^^N800ol0
003o[[SQo`000002o`0000;o[;WS00?o0000ojbhh_n/^>800on/^>84o`0000?oZkWT00?o0000ojZh
honZ^><00onZ^><4o`0000?oZKWU00?o0000ojRhi?nX^>@01?nX^>@00ol0003oZ;STo`000002o`00
00;oZ;WV00?o0000ojNii_nW^NH00onW^NH00ol0003oYkWVo`000002o`0000;oYk[W00?o0000ojJj
ionV^^L00onV^^L00ol0003oY[[WojJji`03o`000003ojJkj?l0003oY[_Y00GoY[_Y00Co0000ojJk
jOnV^nWoY[_Y0ol0000DoookJPCo0000`OoonfX00<[ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003o[l3Vo`000002o`0000?o[/3W00?o0000ojnoi_n__nH00on__nH2o`0000Ko[kkU00?o0000ok2m
i?l000000_l00002ojjni@03o`000?n__NCo[kgT00?o[kgT1?l00003ojjli003o`000?n_^n;o[k_R
00?o[k_R0ol00006ojjjh`04o`000?n^^N;o[[WRojjihP?o00001_n/^N<00ol0003o[;SRo`000002
o`000003oj^ji?l0003oZkWT00GoZkWT00?o0000ojZhhol000000_l000000onY^^Go0000ojVii@05
ojVii@04o`000?nX^>CoZ;STojRhi0Co00001_nX^NH01?l0003oYkWVojNii_nW^NH3o`0000KoYk[W
00Co0000ojJjionV^^OoY[[W1?l00005ojJkj004o`000?nV^nWoY[_YojJkj@Ko00004ooonfX4o`00
0<Gooo]Z003;oookJP;o00001_oonfX00ol0003o[/3Wojk0i`05ojk0i`03o`000?n__nKo000000;o
00000_n^_nH00ol0003o[kkUojnni@03ojnni@;o00001_n^_^D00ol0003o[kgTo`000002o`0000;o
[[gU00?o0000ojjli?n^_>@00on^_>@00ol0003o[k_Ro`000002o`0000;o[KcT00?o0000ojjjhon^
^^<01?n^^^<4o`0000?o[;[T00?o0000ojbihon/^N<00on/^N<2o`0000GoZk[T00?o0000oj^ii?n[
^N@00on[^N@2o`0000GoZK[U00?o0000ojViiOnY^ND00onY^ND4o`0000CoZ;[V00?o0000ojRii_nX
^NH00onX^NH4o`0000?oYk_W00?o0000ojNjionW^^L00onW^^L4o`0000?oY[_X00?o0000ojJkj?nV
^nP00onV^nP4o`0001Kooo]Z0ol00039oookJP00cOoonfX00ol0003ooo]ZoookJP04oookJP03o`00
0?n^`>Oo[/3W00Co[/3W0_l00006ojjoiP03o`000?n__^Go000000;o00000_n^_^H00ol0003o[[kU
ojjni@03ojjni@;o00001_n^_ND01?l0003o[[cTojjli?n^_>@3o`0000Ko[KcT00?o0000ojjjhon^
^^<00ol00002ojbki@03o`000?n/^^Co[;[T00?o[;[T00?o0000ojbihol000000_l00002oj^ki@03
o`000?n[^^CoZk[T00?oZk[T00?o0000oj^ii?l000000_l00002ojZji@03o`000?nY^^GoZK[U00?o
ZK[U00?o0000ojViiOl000000_l00002ojRjiP03o`000?nX^^KoZ;[V00CoZ;[V00?o0000ojRii_l0
00000_l00002ojNki`03o`000?nW^nOoYk_W00?oYk_W00?o0000ojNjiol000000_l00002ojNlj003
o`000?nV^nSoY[_X00?oY[_X00?o0000ojJkj?l000000_l0000FoookJPCo0000c?oonfX00<kooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003o[/3Wojk0i`03o`0000;o[L3X00?o0000ojjoi_n^_nH0
0on^_nH2o`0000Ko[[kV00?o0000ojjniOl000000_l00002ojfniP03o`000?n^_NGo[[gU00?o[[gU
1?l00003ojfmi@03o`000?n]_>Co[KcT00?o[KcT0ol00006ojbki@04o`000?n/^^Co[;[Tojbji0?o
00001_n[^nD01?l0003oZk[Toj^ji?n[^^@3o`0000KoZ[[U00Co0000ojVjiOnY^^GoZK[U0ol00006
ojRjiP04o`000?nX^^KoZ;[VojRjiPCo00001_nW^nL01?l0003oYk_WojNkionW^nL3o`0000KoYkcX
00Co0000ojJkj?nV^nSoY[_X0ol0000EoookJPCo0000d?oonfX00<oooo]Z00?o0000oookJ_oonfX0
1?oonfX2o`0000Ko[L3X00?o0000ojjoi_l000000_l00002ojfoi`03o`000?n^_^Ko[[kV00?o[[kV
0_l00006ojfniP03o`000?n^_NGo000000;o00000_n]_^H00ol0003o[KgUojfmi@03ojfmi@03o`00
0?n]_>Co000000;o00000_n/_>H00ol0003o[;_Uojbki@04ojbki@Co00000on[_>D00ol0003oZk_U
oj^ki@03oj^ki@Co00000onZ^nH00ol0003oZ[[UojZji@03ojZji@Co00000onY^nH00ol0003oZ;[V
ojRjiP03ojRjiPCo00000onX^nL00ol0003oYk_WojNki`04ojNki`Co00000onW_>P00ol0003oYkcX
ojNlj003ojNlj0Co00005?oonfX4o`000=Cooo]Z003@oookJP;o00001_oonfX2o`0000?o[L3X1?l0
0005ojfoi`03o`000?n^_^Ko000000;o00000_n]_nL00ol0003o[KkVojfniP03ojfniP;o00001_n]
_^H01?l0003o[KgUojfmiOn]_ND3o`0000Ko[;cV00?o0000ojbkiOn/^nD00ol000000on[_>Ko0000
oj^li@05oj^li@03o`000?n[^nGo000000;o00000_nZ_>H00ol0003oZ[_VojZkiP03ojZkiP03o`00
0?nZ^^Go000000;o00000_nY^nL00ol0003oZK_VojVkiP03ojVkiP03o`000?nX^^Ko000000;o0000
0_nX_>L00ol0003oZ;_WojRki`03ojRki`03o`000?nW^nOoYk_W00?o000000?oYkcXo`000?nW_>P0
1OnW_>P00ol0003oYkcXo`000002o`0001Cooo]Z1?l0003HoookJP00d_oonfX00ol0003ooo]Zoook
JP05oookJP?o00001?n/`>P01?l0003o[KoWojfoion]_nL3o`0000Ko[KoW00?o0000ojfni_l00000
0_l00002ojbni`03o`000?n]_^Ko[KkV00?o[KkV1?l00003ojbmiP03o`000?n/_>Ko[;cV00?o[;cV
0ol00005oj^liP04o`000?n[_>GoZkcUoj^li@Co00001_nZ_>H01?l0003oZ[_VojZki_nZ^nH3o`00
00KoZK_W00Co0000ojVki_nY^nKoZK_V0ol00006ojRli`04o`000?nX^nOoZ;_WojRki`Co00001OnW
_>P01?l0003oYkcXojNlj?nW_>P4o`0001Cooo]Z0ol0003LoookJP00dooonfX00ol0003ooo]Zoook
JP05oookJP03o`000?n/`>So[<3X00?o[<3X1?l00003ojboj003o`000?n]_nOo[KoW00?o[KoW0_l0
0006ojbni`03o`000?n]_^Ko000000;o00000_n/_^L00ol0003o[;gVojbmiP03ojbmiP03o`000?n/
_>Ko000000;o00000_n[_NL00ol0003oZkcVoj^liP03oj^liPCo00001?nZ_>L00ol0003oZ[cVojZl
iP03ojZliPCo00000onY_>L00ol0003oZK_WojVki`03ojVki`Co00000onX_>P00ol0003oZ;cWojRl
i`03ojRli`Co00000onW_>P00ol0003oYkcXojNlj003ojNlj0Co00005?oonfX4o`000=oooo]Z003D
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000ojc0j?l000000_l00002oj_0j@03o`000?n/_nSo
[;oX00?o[;oX00?o0000ojfoiol000000_l00002ojboj003o`000?n/_^Oo[;kW00?o[;kW0_l00006
ojbni`04o`000?n/_NKo[;gVojbmiP?o00001_n[_NL00ol0003oZkcVo`000002o`0000;oZ[gW00?o
0000ojZlionZ_>L01?nZ_>L00ol0003oZ[cVo`000002o`0000;oZKgW00?o0000ojVlionY_>L00onY
_>L00ol0003oZK_Wo`000002o`0000;oZ;cX00?o0000ojRlj?nX_>P00onX_>P00ol0003oZ;cWo`00
0002o`0000;oZ;gX00?o0000ojNlj?nW_>P00onW_>P00ol0003oYkcXo`000002o`0001Cooo]Z1?l0
003SoookJP00eOoonfX00ol0003ooo]ZoookJP05oookJP03o`000?n[`>WoZl3Y00CoZl3Y00Co0000
ojboj?n/_nSo[;oX1?l00005ojboj003o`000?n/_^Oo000000;o00000_n[_nP00ol0003o[;kWojbn
i`03ojbni`Co00000on[_^L00ol0003oZkgWoj^mi`03oj^mi`;o00001_nZ_NL01?l0003oZ[cWojZl
ionZ_>L4o`0000KoZKgW00Co0000ojVlionY_>OoZKcW0ol00006ojRlj004o`000?nX_>SoZ;cXojRl
j0Co00001OnX_NP01?l0003oYkcXojNlj?nW_>P3o`0001?ooo]Z1?l0003WoookJP00e_oonfX2o`00
00Kooo]Z00?o0000oj_0jOn[`>T00on[`>T4o`0000CoZkoY00Co0000ojboj?n/_nSo[;oX0ol00006
oj^oj003o`000?n/_^Oo000000;o00000_n[_^P00ol0003oZkkWoj^ni`03oj^ni`03o`000?n[_NOo
000000;o00000_nZ_^P00ol0003oZ[gWojZmi`03ojZmi`Co00000onY_NP00ol0003oZKgWojVmi`04
ojVmi`Co00000onY_NP00ol0003oZ;cXojRlj003ojRlj0Co00001?nX_NT01?l0003oZ;gXojRmj?nX
_NP5o`0001?ooo]Z0ol0003[oookJP00f?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?n[`>Wo
000000;o00000_n[`>T00ol0003oZkoYoj^oj@03oj^oj@Co00000on[_nT00ol0003oZkoXoj^oj003
oj^oj0;o00001_n[_^P01?l0003oZkkWoj^nion[_^L4o`0000GoZ[kX00?o0000ojZmiol000000_l0
0002ojVnj003o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmionY_NL00ol000000onY_NSo0000ojVm
j005ojVmj003o`000?nX_>So000000;o00000_nX_NT00ol0003oZ;gYojRmj@03ojRmj@Co00005?oo
nfX4o`000>kooo]Z003IoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oj_0jOn[`>T01?n[`>T0
0ol0003oZkoYo`000002o`0000;oZ/3Y00?o0000oj^ojOn[_nT00on[_nT00ol0003oZkoXo`000002
o`0000;oZ[oY00?o0000oj^nj?n[_^P00on[_^P4o`0000CoZ[kX00Co0000ojZnj?nZ_^SoZ[kX0ol0
0006ojVnj004o`000?nY_NSoZKgXojVmj0Co00001OnY_NP01?l0003oZKgXojVmj?nY_NP4o`0000Ko
Z;gY00?o0000ojRmjOl000000_l0000DoookJPCo0000l_oonfX00=[ooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003oZl3Yoj_0j@03oj_0j@;o00001_nZ`>T01?l0003oZkoYoj^ojOn[_nT4o`0000Go
Z[oY00?o0000oj^nj?l000000_l00002ojZoj@03o`000?nZ_^SoZ[kX00?oZ[kX1?l00003ojVnj@03
o`000?nY_^SoZKkX00?oZKkX1?l00003ojVnj@03o`000?nY_NSoZKgX00?oZKgX1?l00004ojRnj@04
o`000?nX_NWoZ;gYojRmj@Co00004ooonfX4o`000?Kooo]Z003KoookJP;o00001OoonfX00ol0003o
Zl3Yo`000002o`0000;oZ/3Z00?o0000oj[0jOnZ`>T00onZ`>T4o`0000CoZ[oY00Co0000ojZojOnZ
_nWoZ[oY0ol00006ojZoj@03o`000?nZ_^So000000;o00000_nY_nT00ol0003oZKkYojVnj@03ojVn
j@03o`000?nY_^So000000;o00000_nY_^T00ol0003oZKkYojVnj@03ojVnj@03o`000?nY_NSo0000
00;o00000_nX_^T00ol0003oZ;kYojRnj@03ojRnj@Co00004ooonfX4o`000?[ooo]Z003MoookJP03
o`000?oonf[ooo]Z00?ooo]Z0_l00005oj[0jP03o`000?nZ`>Wo000000;o00000_nY`>X00ol0003o
Z[oYojZoj@03ojZoj@Co00000onY_nT00ol0003oZ[oYojZoj@03ojZoj@;o00001_nY_nT01?l0003o
ZKkYojVnjOnY_^T3o`0000KoZKkY00Co0000ojVnjOnY_^WoZKkY1?l00005ojRnj@03o`000?nX_^Wo
000000;o00005?oonfX3o`000?kooo]Z003NoookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000oj[0
j_nZ`>[oZ/3Z1?l00005ojW0jP03o`000?nZ_nWo000000;o00000_nY`>X00ol0003oZKoYojVoj@03
ojVoj@03o`000?nZ_nWo000000;o00000_nY_nX00ol0003oZKoYojVoj@03ojVoj@Co00000onY_nT0
0ol0003oZKkYojVnj@03ojVnj@Co00001?nX_^T01?l0003oZ;kYojRnjOnX_^T3o`0001?ooo]Z1?l0
003ooookJP;ooo]Z003OoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00004ojW0jP04o`000?nY`>[o
ZL3ZojW0jP?o00001_nY`>X01?l0003oZKoYojVojOnY_nT4o`0000GoZKoZ00?o0000ojVojOl00000
0_l00002ojVojP03o`000?nY_nWoZKoY00?oZKoY00?o0000ojVnjOl000000_l00002ojRojP03o`00
0?nX_^WoZ;kY00?oZ;kY1?l0000BoookJPCo0000oooonfX6oookJP00h?oonfX2o`0000Gooo]Z00?o
0000ojW0j_nY`>X00onY`>X4o`0000?oZL3Z00?o0000ojW0j_nY`>X00onY`>X4o`0000CoZL3Z00Co
0000ojVoj_nY_n[oZKoZ1?l00005ojVojP04o`000?nY_nWoZKoYojVoj@Co00001OnX_nX00ol0003o
Z;kYo`000002o`0001;ooo]Z1?l0003ooookJP[ooo]Z003RoookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000ojW0j_l000000_l00002ojW1j`03o`000?nY`>[oZL3Z00?oZL3Z00?o0000ojW0j_l00000
0_l00002ojW0j`03o`000?nY`>[oZL3Z00?oZL3Z1?l00004ojRojP04o`000?nY_n[oZKoZojVojPGo
00001?nX_nX01?l0003oZ;oZojRoj_nX_nX3o`0001;ooo]Z0ol0003ooookJPkooo]Z003SoookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000ojW1jonY`N/01?nY`N/01?l0003oZL3ZojW0j_nY`>X4o`00
00GoZL3[00?o0000ojW0j_l000000_l00002ojS0j`03o`000?nX_n[oZ;oZ00?oZ;oZ1?l00003ojRo
j`03o`000?nX_n[oZ;oZ00?oZ;oZ1?l0000AoookJPCo0000oooonfXAoookJP00i?oonfX00ol0003o
oo]ZoookJP03oookJP03o`000?nY`N_oZL7[00?oZL7[1?l00004ojS0j`04o`000?nY`>_oZL3[ojW0
j`Co00001OnX`>/00ol0003oZ;oZo`000002o`0000;oZ<3[00?o0000ojRojonX_n/00onX_n/00ol0
003oZ;oZo`000002o`00017ooo]Z1?l0003ooookJQGooo]Z003UoookJP;o00001?oonfX00ol0003o
ZL7[o`000002o`0000;oZ<7[00?o0000ojS0jonX`>/00onX`>/4o`0000CoZ<3[00Co0000ojS0jonX
`>_oZ<3[0ol00006ojS0j`04o`000?nX_n_oZ;o[ojRoj`?o00004?oonfX4o`000?oooo]Z6OoonfX0
0>Oooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000GoZ<7[00?o0000ojS0jol000000_l00002ojS1
j`03o`000?nX`>_oZ<3[00?oZ<3[1?l00003ojS0j`03o`000?nX`>_oZ<3[00?oZ<3[1?l0000?oook
JPCo0000oooonfXMoookJP00j?oonfX00ol0003ooo]ZoookJP03oookJP04o`000?nX`N_oZ<7[ojS1
j`Co00001OnX`N/00ol0003oZ<3[o`000002o`0000;oZ<7[00?o0000ojS0jonX`>/00onX`>/00ol0
003oZ<3[o`000002o`00013ooo]Z0ol0003ooookJR7ooo]Z003YoookJP03o`000?oonf[ooo]Z00?o
oo]Z0ol00004ojS1k004o`000?nX`N_oZ<7[ojS1j`Co00001OnX`N/01?l0003oZ<3[ojS0jonX`>/3
o`0000oooo]Z1?l0003ooookJRCooo]Z003ZoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000ojS1
k?nX`N`00onX`N`4o`0000CoZ<7/00Co0000ojS1jonX`N_oZ<7[1Ol0000>oookJPCo0000oooonfXX
oookJP00jooonfX2o`0000Cooo]Z00?o0000ojS1k?l000000_l00002ojS1k003o`000?nX`NcoZ<7/
00?oZ<7/1?l0000?oookJPCo0000oooonfX/oookJP00kOoonfX00ol0003ooo]ZoookJP02oookJP;o
00001OnX`N`00ol0003oZ<7/o`000002o`00013ooo]Z0ol0003ooookJS3ooo]Z003^oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00Co0000ojS1k?nX`NcoZ<7/0ol0000?oookJPCo0000oooonfXcoookJP00
kooonfX00ol0003ooo]ZoookJP03oookJP?o00003_oonfX4o`000?oooo]Z=ooonfX00?3ooo]Z0_l0
0003oookJP03o`000?oonf[ooo]Z00[ooo]Z1?l0003ooookJS_ooo]Z003boookJP04o`000?oonf[o
oo]Zo`0000Sooo]Z1?l0003ooookJSoooo]Z003coookJP03o`000?oonf[o000000Gooo]Z0ol0003o
oookJT?ooo]Z003doookJP;o000000?ooo]Zo`000?l000000_l0003ooookJTKooo]Z003eoookJP;o
0000oooonfY:oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {466.188, 0}} -> {-0.0532364, 0.0174672, \
0.00176221, 0.00176221}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "It is no surprise that many of these differential operations already exist \
in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages."
}], "Text"],

Cell["Using the Vector Analysis Package", "Subtitle"],

Cell[BoxData[
    \(<< Calculus`VectorAnalysis`\)], "Input",
  CellTags->"mmtag:13:VectorAnalysis_package"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coordinate Systems", "Section"],

Cell[CellGroupData[{

Cell["Converting between coordinate systems", "Subsection",
  CellTags->"mmtag:13:coordinate_systems__converting_between"],

Cell["\<\
The spherical coordinates expressed in terms of the cartesian x,y,z\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoordinatesFromCartesian[{x, y, z}, 
      Spherical[r, theta, phi]]\)], "Input",
  CellTags->"mmtag:13:CoordinatesFromCartesian[]"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(theta\\)\\\" is similar to existing symbol \
\\\"\\!\\(Ttheta\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({\@\(x\^2 + y\^2 + z\^2\), ArcCos[z\/\@\(x\^2 + y\^2 + z\^2\)], 
      ArcTan[x, y]}\)], "Output"]
}, Open  ]],

Cell["\<\
The cartesian coordinates expressed in terms of the spherical r \
\[Theta] \[Phi]\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoordinatesToCartesian[{r, theta, phi}, 
      Spherical[r, theta, phi]]\)], "Input",
  CellTags->"mmtag:13:CoordinatesToCartesian[]"],

Cell[BoxData[
    \({r\ Cos[phi]\ Sin[theta], r\ Sin[phi]\ Sin[theta], 
      r\ Cos[theta]}\)], "Output",
  CellTags->"mmtag:13:CoordinatesToCartesian[]"]
}, Open  ]],

Cell["\<\
The equation of a line  through the origin in spherical \
coodinates\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      CoordinatesFromCartesian[{a\ t, \ b\ t, \ c\ t}, 
        Spherical[r, theta, phi]], t\  > \ 0]\)], "Input"],

Cell[BoxData[
    \({\@\(a\^2 + b\^2 + c\^2\)\ t, ArcCos[c\/\@\(a\^2 + b\^2 + c\^2\)], 
      ArcTan[a, b]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
An example of calculating the positions of cities in cartesian and \
spherical coordinates.\
\>", "Subsection"],

Cell[BoxData[
    \(<< Miscellaneous`CityData`\)], "Input",
  CellTags->"mmtag:13:MiscellaneousCityData_package"],

Cell["\<\
Boston is located at latitude 42\[Degree] 21' 30\" N  and longitude \
-71\[Degree],-3',-37\" W\
\>", "Text",
  CellTags->"mmtag:13:latitude_and_longitude"],

Cell[CellGroupData[{

Cell[BoxData[
    \(boston\  = \ CityData["\<Boston\>", CityPosition]\)], "Input",
  CellTags->"mmtag:13:CityData[]"],

Cell[BoxData[
    \({{42, 21, 30}, {\(-71\), \(-3\), \(-37\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(paris\  = \ CityData["\<Paris\>", CityPosition]\)], "Input"],

Cell[BoxData[
    \({{48, 52}, {2, 20}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(SphericalCoordinatesofCity[
        cityname_String]\  := \ \[IndentingNewLine]{\[IndentingNewLine]6378.1\
\ , \[IndentingNewLine]\(\(2\ Pi\)\/360\) 
          ToDegrees[\(CityData[cityname, 
                CityPosition]\)[\([1]\)]], \[IndentingNewLine]\
\[IndentingNewLine]\(\(2\ Pi\)\/360\) 
          ToDegrees[\ \(CityData[cityname, 
                CityPosition]\)[\([2]\)]]\[IndentingNewLine]}\)], "Input",
  CellTags->"mmtag:13:SphericalCoordinatesofCity[]__example_function"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SphericalCoordinatesofCity["\<Boston\>"]\)], "Input"],

Cell[BoxData[
    \({6378.1`, \(5083\ \[Pi]\)\/21600, \(-\(\(255817\ \
\[Pi]\)\/648000\)\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(CartesianCoordinatesofCity[cityname_String]\  := \ 
      CoordinatesToCartesian[SphericalCoordinatesofCity[cityname], 
        Spherical[r, theta, phi]]\)], "Input",
  CellTags->{
  "mmtag:13:CartesianCoordinatesofCity[]__example_function", 
    "mmtag:13:distances_from_Boston_to_Paris"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(CartesianCoordinatesofCity["\<Paris\>"]\)], "Input"],

Cell[BoxData[
    \({4799.879597331717`, 195.5801062763877`, 
      4195.6005390346245`}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(MinimumTunnel[city1_String, city2_String]\  := \[IndentingNewLine]Norm[
        CartesianCoordinatesofCity[city1] - 
          CartesianCoordinatesofCity[city2]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinimumTunnel["\<Boston\>", "\<Paris\>"]\)], "Input"],

Cell[BoxData[
    \(5478.338566127883`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Minimum travel distance between Boston and Paris for a round \
earth\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SphericalDistance[boston, paris] // N\)], "Input"],

Cell[BoxData[
    \(5529.743203638526`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SpheroidalDistance[boston, paris] // N\)], "Input"],

Cell[BoxData[
    \(5545.034276030287`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using Vector Derivative Functions", "Section"],

Cell[BoxData[
    \(SimplePot[x_\ , \ y_\ , \ z_, \ n_]\  := 
      1\/\((x^2\  + \ y^2\  + \ z^2)\)\^\(n\/2\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gradsp\  = Grad[SimplePot[x, y, z, 1], Cartesian[x, y, z]]\)], "Input",
  CellTags->"mmtag:13:Grad[]"],

Cell[BoxData[
    \({\(-\(x\/\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\)\), \(-\(y\/\((x\^2 + y\^2 \
+ z\^2)\)\^\(3/2\)\)\), \(-\(z\/\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\)\)}\)], \
"Output",
  CellTags->"mmtag:13:Grad[]"]
}, Open  ]],

Cell[BoxData[
    \(The\ above\ is\ equal\ to\ \(r\& \[Rule] \)\/\((\(||\)\(r\& \[Rule] \
\)\(||\))\)\^3\)], "Text",
  FontFamily->"Helvetica"],

Cell[BoxData[
    \(Examples : \ 
      the\ same\ function\ and\ gradient\ in\ different\ coordinate\ \
systems\)], "Text",
  FontFamily->"Helvetica"],

Cell[BoxData[
    \(SimplePot[r_, \ n_]\  := 1\/r\^n\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gradsphere = 
      Grad[SimplePot[r, 1], \ 
        Spherical[r, \[Theta], \ \[CurlyPhi]]]\)], "Input"],

Cell[BoxData[
    \({\(-\(1\/r\^2\)\), 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Grad[SimplePot[r, 1], \ Cylindrical[r, \[Theta], \ z]]\)], "Input"],

Cell[BoxData[
    \({\(-\(1\/r\^2\)\), 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Grad[SimplePot[r, 1], \ 
      ProlateSpheroidal[r, \[Theta], \[CurlyPhi]]]\)], "Input"],

Cell[BoxData[
    \({\(-\(1\/\(r\^2\ \@\(Sin[\[Theta]]\^2 + Sinh[r]\^2\)\)\)\), 0, 
      0}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(GradSimplePot[x_, \ y_, \ z_, \ n_]\  := 
      Evaluate[Grad[SimplePot[x, y, z, n], Cartesian[x, y, z]]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Div[GradSimplePot[x, y, z, n], Cartesian[x, y, z]] // 
      Simplify\)], "Input",
  CellTags->"mmtag:13:Div[]"],

Cell[BoxData[
    \(\((\(-1\) + 
          n)\)\ n\ \((x\^2 + y\^2 + z\^2)\)\^\(\(-1\) - n\/2\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(The\ above\ is\ equal\ to\ \(n \((n - 1)\) \(r\& \[Rule] \
\)\)\/\((\(||\)\(r\& \[Rule] \)\(||\))\)\^\(2 + n\)\)], "Text",
  FontFamily->"Helvetica"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Div[GradSimplePot[x, y, z, 1], Cartesian[x, y, z]] // 
      Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(This\ makes\ ``sense''\ because\ the\ amount\ of\ stuff\ flowing\ into\ \
a\ sphere\ is\ like\ the\ gradient*4  \[Pi]\ r\^2\ which\ is\ independent\ of\
\ the\ size\ of\ the\ sphere\ for\ n = 1\)], "Text",
  FontFamily->"Helvetica"],

Cell["An example of Curl", "Subtitle"],

Cell[TextData[{
  "There is a very useful free software tool for solving minimal surface (and \
many other) variational problems called ",
  ButtonBox["Surface Evolver",
    ButtonData:>{
      URL[ "http://www.susqu.edu/facstaff/b/brakke/evolver/"], None},
    ButtonStyle->"Hyperlink"],
  " by Ken Brakke.  To use Surface Evolver to greatest possible advantage, a \
user should be adept at using results from vector analysis.  ",
  StyleBox["Mathematica's ",
    FontSlant->"Italic"],
  "Vector Analysis package is very helpful aid for developing powerful \
Evolver codes.  The following example is extracted from the ",
  ButtonBox["Surface Evolver manual",
    ButtonData:>{
      URL[ "http://www.susqu.edu/facstaff/b/brakke/evolver/manual220.pdf"], 
      None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(LeavingKansas[x_, \ y_, \ z_\ , \ n_] := \ 
      z\^n\/\(\((x^2\  + \ y^2)\) \((x^2\  + \ y^2\  + \ z^2)\)\^\(n\/2\)\)\ \
{y, \(-x\), \ 0}\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeavingKansas[x, y, z, 3]\)], "Input"],

Cell[BoxData[
    \({\(y\ z\^3\)\/\(\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\), \
\(-\(\(x\ z\^3\)\/\(\((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\)\)\), 
      0}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(<< Graphics`PlotField3D`\)], "Input"],

Cell["\<\
Visualize the vector field for n=3, note that the function will be \
singular near the z-axis\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlotVectorField3D[
      LeavingKansas[x, y, z, 3], {x, \(-1\), 1}, {y, \(-1\), 
        1}, {z, \(- .5\),  .5}, VectorHeads \[Rule] True, \ 
      ColorFunction \[Rule] \((\((Hue[#* .66])\) &)\), PlotPoints \[Rule] 15, 
      ScaleFactor \[Rule] 0.5]\)], "Input",
  CellTags->"mmtag:13:PlotVectorField3D[]"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\\\ ComplexInfinity\\) encountered. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\\\ ComplexInfinity\\) encountered. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\\\ ComplexInfinity\\) encountered. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(\[Infinity] :: \\\"indet\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Power :: \\\"infy\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89285 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
7.36261e-17 1.05055 -0.0289472 1.05055 [
[ 0 0 0 0 ]
[ 1 .89285 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05221 .25273 m
0 .58221 L
s
0 .58221 m
.39855 .89285 L
s
.39855 .89285 m
.40897 .59485 L
s
.40897 .59485 m
.05221 .25273 L
s
.68389 0 m
.95694 .42575 L
s
.95694 .42575 m
1 .74078 L
s
1 .74078 m
.70392 .345 L
s
.70392 .345 m
.68389 0 L
s
.05221 .25273 m
0 .58221 L
s
0 .58221 m
.70392 .345 L
s
.70392 .345 m
.68389 0 L
s
.68389 0 m
.05221 .25273 L
s
.40897 .59485 m
.95694 .42575 L
s
.95694 .42575 m
1 .74078 L
s
1 .74078 m
.39855 .89285 L
s
.39855 .89285 m
.40897 .59485 L
s
0 0 m
1 0 L
1 .89285 L
0 .89285 L
closepath
clip
newpath
1 .017 0 r
.5 Mabswid
.41326 .60692 m
.41269 .60683 L
s
.41281 .60692 m
.41279 .60689 L
s
.41279 .60689 m
.41281 .60678 L
s
.41279 .60689 m
.41269 .60683 L
s
.41281 .60678 m
.41283 .60681 L
s
.41281 .60678 m
.41269 .60683 L
s
.41269 .60683 m
.41281 .60692 L
s
.41269 .60683 m
.41283 .60681 L
s
.41283 .60681 m
.41281 .60692 L
s
1 .011 0 r
.4127 .62357 m
.41233 .62351 L
s
.4124 .62357 m
.41239 .62355 L
s
.41239 .62355 m
.4124 .62347 L
s
.41239 .62355 m
.41233 .62351 L
s
.4124 .62347 m
.41242 .62349 L
s
.4124 .62347 m
.41233 .62351 L
s
.41233 .62351 m
.4124 .62357 L
s
.41233 .62351 m
.41242 .62349 L
s
.41242 .62349 m
.4124 .62357 L
s
1 .022 0 r
.44767 .59639 m
.44692 .5963 L
s
.44707 .59641 m
.44705 .59638 L
s
.44705 .59638 m
.44708 .59623 L
s
.44705 .59638 m
.44692 .5963 L
s
.44708 .59623 m
.44709 .59626 L
s
.44708 .59623 m
.44692 .5963 L
s
.44692 .5963 m
.44707 .59641 L
s
.44692 .5963 m
.44709 .59626 L
s
.44709 .59626 m
.44707 .59641 L
s
1 .007 0 r
.41214 .64038 m
.41191 .64034 L
s
.41196 .64038 m
.41195 .64037 L
s
.41195 .64037 m
.41196 .64032 L
s
.41195 .64037 m
.41191 .64034 L
s
.41196 .64032 m
.41197 .64033 L
s
.41196 .64032 m
.41191 .64034 L
s
.41191 .64034 m
.41196 .64038 L
s
.41191 .64034 m
.41197 .64033 L
s
.41197 .64033 m
.41196 .64038 L
s
1 .014 0 r
.44729 .61309 m
.44679 .61303 L
s
.44688 .61311 m
.44687 .61308 L
s
.44687 .61308 m
.44689 .61298 L
s
.44687 .61308 m
.44679 .61303 L
s
.44689 .61298 m
.4469 .61301 L
s
.44689 .61298 m
.44679 .61303 L
s
.44679 .61303 m
.44688 .61311 L
s
.44679 .61303 m
.4469 .61301 L
s
.4469 .61301 m
.44688 .61311 L
s
1 .022 0 r
.39277 .58737 m
.39204 .58722 L
s
.39219 .58734 m
.39216 .58731 L
s
.39216 .58731 m
.39219 .58716 L
s
.39216 .58731 m
.39204 .58722 L
s
.39219 .58716 m
.39222 .58719 L
s
.39219 .58716 m
.39204 .58722 L
s
.39204 .58722 m
.39219 .58734 L
s
.39204 .58722 m
.39222 .58719 L
s
.39222 .58719 m
.39219 .58734 L
s
1 .028 0 r
.48175 .58578 m
.48174 .58574 L
s
.48174 .58574 m
.48176 .58555 L
s
.48174 .58574 m
.48156 .58565 L
s
.48176 .58555 m
.48177 .58559 L
s
.48176 .58555 m
.48156 .58565 L
s
.48254 .58572 m
.48156 .58565 L
s
.48156 .58565 m
.48175 .58578 L
s
.48156 .58565 m
.48177 .58559 L
s
.48177 .58559 m
.48175 .58578 L
s
1 .003 0 r
.41157 .65736 m
.41145 .65734 L
s
.41147 .65736 m
.41147 .65736 L
s
.41147 .65736 m
.41147 .65733 L
s
.41147 .65736 m
.41145 .65734 L
s
.41147 .65733 m
.41148 .65734 L
s
.41147 .65733 m
.41145 .65734 L
s
.41145 .65734 m
.41147 .65736 L
s
.41145 .65734 m
.41148 .65734 L
s
.41148 .65734 m
.41147 .65736 L
s
1 .009 0 r
.44689 .62996 m
.44659 .62993 L
s
.44665 .62997 m
.44664 .62996 L
s
.44664 .62996 m
.44665 .6299 L
s
.44664 .62996 m
.44659 .62993 L
s
.44665 .6299 m
.44666 .62991 L
s
.44665 .6299 m
.44659 .62993 L
s
.44659 .62993 m
.44665 .62997 L
s
.44659 .62993 m
.44666 .62991 L
s
.44666 .62991 m
.44665 .62997 L
s
1 .014 0 r
.3921 .60412 m
.39162 .60402 L
s
.39171 .6041 m
.39169 .60408 L
s
.39169 .60408 m
.39172 .60398 L
s
.39169 .60408 m
.39162 .60402 L
s
.39172 .60398 m
.39174 .604 L
s
.39172 .60398 m
.39162 .60402 L
s
.39162 .60402 m
.39171 .6041 L
s
.39162 .60402 m
.39174 .604 L
s
.39174 .604 m
.39171 .6041 L
s
1 .018 0 r
.4818 .60252 m
.48179 .60249 L
s
.48179 .60249 m
.4818 .60236 L
s
.48179 .60249 m
.48166 .60243 L
s
.4818 .60236 m
.48181 .60239 L
s
.4818 .60236 m
.48166 .60243 L
s
.48232 .60248 m
.48166 .60243 L
s
.48166 .60243 m
.4818 .60252 L
s
.48166 .60243 m
.48181 .60239 L
s
.48181 .60239 m
.4818 .60252 L
s
1 .029 0 r
.42747 .57658 m
.42646 .57642 L
s
.42666 .57657 m
.42663 .57653 L
s
.42663 .57653 m
.42667 .57633 L
s
.42663 .57653 m
.42646 .57642 L
s
.42667 .57633 m
.4267 .57637 L
s
.42667 .57633 m
.42646 .57642 L
s
.42646 .57642 m
.42666 .57657 L
s
.42646 .57642 m
.4267 .57637 L
s
.4267 .57637 m
.42666 .57657 L
s
1 .035 0 r
.51686 .57504 m
.51686 .575 L
s
.51686 .575 m
.51686 .57475 L
s
.51686 .575 m
.51661 .57489 L
s
.51686 .57475 m
.51686 .5748 L
s
.51686 .57475 m
.51661 .57489 L
s
.51786 .57491 m
.51661 .57489 L
s
.51661 .57489 m
.51686 .57504 L
s
.51661 .57489 m
.51686 .5748 L
s
.51686 .5748 m
.51686 .57504 L
s
1 .002 0 r
.41099 .67452 m
.41094 .67451 L
s
.41095 .67452 m
.41095 .67451 L
s
.41095 .67451 m
.41095 .6745 L
s
.41095 .67451 m
.41094 .67451 L
s
.41095 .6745 m
.41095 .6745 L
s
.41095 .6745 m
.41094 .67451 L
s
.41094 .67451 m
.41095 .67452 L
s
.41094 .67451 m
.41095 .6745 L
s
.41095 .6745 m
.41095 .67452 L
s
1 .005 0 r
.4465 .647 m
.44633 .64698 L
s
.44636 .64701 m
.44636 .647 L
s
.44636 .647 m
.44637 .64697 L
s
.44636 .647 m
.44633 .64698 L
s
.44637 .64697 m
.44637 .64697 L
s
.44637 .64697 m
.44633 .64698 L
s
.44633 .64698 m
.44636 .64701 L
s
.44633 .64698 m
.44637 .64697 L
s
.44637 .64697 m
.44636 .64701 L
s
1 .009 0 r
.39143 .62104 m
.39113 .62098 L
s
.39119 .62103 m
.39118 .62101 L
s
.39118 .62101 m
.39119 .62095 L
s
.39118 .62101 m
.39113 .62098 L
s
.39119 .62095 m
.39121 .62097 L
s
.39119 .62095 m
.39113 .62098 L
s
.39113 .62098 m
.39119 .62103 L
s
.39113 .62098 m
.39121 .62097 L
s
.39121 .62097 m
.39119 .62103 L
s
1 .011 0 r
.48178 .61943 m
.48178 .61941 L
s
.48178 .61941 m
.48178 .61933 L
s
.48178 .61941 m
.4817 .61938 L
s
.48178 .61933 m
.48179 .61935 L
s
.48178 .61933 m
.4817 .61938 L
s
.4821 .6194 m
.4817 .61938 L
s
.4817 .61938 m
.48178 .61943 L
s
.4817 .61938 m
.48179 .61935 L
s
.48179 .61935 m
.48178 .61943 L
s
1 .019 0 r
.42697 .59339 m
.4263 .59328 L
s
.42643 .59338 m
.42641 .59335 L
s
.42641 .59335 m
.42643 .59321 L
s
.42641 .59335 m
.4263 .59328 L
s
.42643 .59321 m
.42646 .59324 L
s
.42643 .59321 m
.4263 .59328 L
s
.4263 .59328 m
.42643 .59338 L
s
.4263 .59328 m
.42646 .59324 L
s
.42646 .59324 m
.42643 .59338 L
s
1 .028 0 r
.37178 .56734 m
.37087 .56709 L
s
.37104 .56726 m
.37099 .56722 L
s
.37099 .56722 m
.37106 .56703 L
s
.37099 .56722 m
.37087 .56709 L
s
.37106 .56703 m
.37111 .56707 L
s
.37106 .56703 m
.37087 .56709 L
s
.37087 .56709 m
.37104 .56726 L
s
.37087 .56709 m
.37111 .56707 L
s
.37111 .56707 m
.37104 .56726 L
s
1 .023 0 r
.51715 .59181 m
.51714 .59178 L
s
.51714 .59178 m
.51715 .59161 L
s
.51714 .59178 m
.51698 .59171 L
s
.51715 .59161 m
.51715 .59165 L
s
.51715 .59161 m
.51698 .59171 L
s
.51782 .59172 m
.51698 .59171 L
s
.51698 .59171 m
.51715 .59181 L
s
.51698 .59171 m
.51715 .59165 L
s
.51715 .59165 m
.51715 .59181 L
s
1 .039 0 r
.46262 .56565 m
.46124 .56549 L
s
1 0 0 r
.41041 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
1 .039 0 r
.46151 .56569 m
.46148 .56564 L
s
.46148 .56564 m
.46152 .56536 L
s
.46148 .56564 m
.46124 .56549 L
s
.46152 .56536 m
.46155 .56541 L
s
.46152 .56536 m
.46124 .56549 L
s
.46124 .56549 m
.46151 .56569 L
s
.46124 .56549 m
.46155 .56541 L
s
.46155 .56541 m
.46151 .56569 L
s
1 .043 0 r
.55243 .5642 m
.55244 .56414 L
s
.55244 .56414 m
.55242 .56384 L
s
.55244 .56414 m
.55212 .56404 L
s
.55242 .56384 m
.55241 .5639 L
s
.55242 .56384 m
.55212 .56404 L
s
.55212 .56404 m
.55243 .5642 L
s
.55212 .56404 m
.55241 .5639 L
s
.55365 .56396 m
.55212 .56404 L
s
.55241 .5639 m
.55243 .5642 L
s
1 .002 0 r
.44609 .66422 m
.44602 .66421 L
s
.44604 .66422 m
.44604 .66421 L
s
.44604 .66421 m
.44604 .6642 L
s
.44604 .66421 m
.44602 .66421 L
s
.44604 .6642 m
.44604 .6642 L
s
.44604 .6642 m
.44602 .66421 L
s
.44602 .66421 m
.44604 .66422 L
s
.44602 .66421 m
.44604 .6642 L
s
.44604 .6642 m
.44604 .66422 L
s
1 .005 0 r
.39075 .63813 m
.39059 .6381 L
s
.39062 .63812 m
.39061 .63811 L
s
.39061 .63811 m
.39062 .63808 L
s
.39061 .63811 m
.39059 .6381 L
s
.39062 .63808 m
.39063 .63809 L
s
.39062 .63808 m
.39059 .6381 L
s
.39059 .6381 m
.39062 .63812 L
s
.39059 .6381 m
.39063 .63809 L
s
.39063 .63809 m
.39062 .63812 L
s
1 .006 0 r
.48171 .63652 m
.48171 .63651 L
s
.48171 .63651 m
.48171 .63647 L
s
.48171 .63651 m
.48167 .63649 L
s
.48171 .63647 m
.48171 .63648 L
s
.48171 .63647 m
.48167 .63649 L
s
.48188 .6365 m
.48167 .63649 L
s
.48167 .63649 m
.48171 .63652 L
s
.48167 .63649 m
.48171 .63648 L
s
.48171 .63648 m
.48171 .63652 L
s
1 .012 0 r
.42647 .61036 m
.42606 .61029 L
s
.42614 .61036 m
.42612 .61034 L
s
.42612 .61034 m
.42614 .61026 L
s
.42612 .61034 m
.42606 .61029 L
s
.42614 .61026 m
.42615 .61028 L
s
.42614 .61026 m
.42606 .61029 L
s
.42606 .61029 m
.42614 .61036 L
s
.42606 .61029 m
.42615 .61028 L
s
.42615 .61028 m
.42614 .61036 L
s
1 .018 0 r
.371 .58419 m
.37038 .58403 L
s
.3705 .58414 m
.37047 .58411 L
s
.37047 .58411 m
.37051 .58398 L
s
.37047 .58411 m
.37038 .58403 L
s
.37051 .58398 m
.37055 .58401 L
s
.37051 .58398 m
.37038 .58403 L
s
.37038 .58403 m
.3705 .58414 L
s
.37038 .58403 m
.37055 .58401 L
s
.37055 .58401 m
.3705 .58414 L
s
1 .014 0 r
.51737 .60876 m
.51737 .60874 L
s
.51737 .60874 m
.51737 .60864 L
s
.51737 .60874 m
.51726 .6087 L
s
.51737 .60864 m
.51737 .60866 L
s
.51737 .60864 m
.51726 .6087 L
s
.51778 .60871 m
.51726 .6087 L
s
.51726 .6087 m
.51737 .60876 L
s
.51726 .6087 m
.51737 .60866 L
s
.51737 .60866 m
.51737 .60876 L
s
1 0 0 r
.40983 .70935 m
.40982 .70935 L
s
1 .026 0 r
.4623 .58251 m
.46137 .58241 L
s
1 0 0 r
.40982 .70935 m
.40982 .70935 L
s
.40982 .70935 m
.40982 .70935 L
s
.40982 .70935 m
.40982 .70935 L
s
.40982 .70935 m
.40982 .70935 L
s
.40982 .70935 m
.40982 .70935 L
s
.40982 .70935 m
.40982 .70935 L
s
.40982 .70935 m
.40982 .70935 L
s
.40982 .70935 m
.40982 .70935 L
s
1 .026 0 r
.46155 .58254 m
.46153 .5825 L
s
.46153 .5825 m
.46156 .58231 L
s
.46153 .5825 m
.46137 .58241 L
s
.46156 .58231 m
.46158 .58235 L
s
.46156 .58231 m
.46137 .58241 L
s
.46137 .58241 m
.46155 .58254 L
s
.46137 .58241 m
.46158 .58235 L
s
.46158 .58235 m
.46155 .58254 L
s
1 .039 0 r
.40677 .55629 m
.40543 .55599 L
s
.40569 .55622 m
.40563 .55616 L
s
.40563 .55616 m
.40571 .55588 L
s
.40563 .55616 m
.40543 .55599 L
s
.40571 .55588 m
.40577 .55594 L
s
.40571 .55588 m
.40543 .55599 L
s
.40543 .55599 m
.40569 .55622 L
s
.40543 .55599 m
.40577 .55594 L
s
.40577 .55594 m
.40569 .55622 L
s
1 .029 0 r
.55296 .58099 m
.55297 .58095 L
s
.55297 .58095 m
.55296 .58074 L
s
.55297 .58095 m
.55275 .58088 L
s
.55296 .58074 m
.55295 .58078 L
s
.55296 .58074 m
.55275 .58088 L
s
.55275 .58088 m
.55296 .58099 L
s
.55275 .58088 m
.55295 .58078 L
s
.55379 .58083 m
.55275 .58088 L
s
.55295 .58078 m
.55296 .58099 L
s
1 .051 0 r
.49676 .55472 m
.49674 .55465 L
s
.49674 .55465 m
.49676 .55428 L
s
.49674 .55465 m
.49639 .55448 L
s
.49676 .55428 m
.49678 .55435 L
s
.49676 .55428 m
.49639 .55448 L
s
.49825 .55457 m
.49639 .55448 L
s
1 .001 0 r
.44569 .68161 m
.44567 .6816 L
s
.44567 .68161 m
.44567 .68161 L
s
.44567 .68161 m
.44567 .6816 L
s
.44567 .68161 m
.44567 .6816 L
s
.44567 .6816 m
.44567 .6816 L
s
.44567 .6816 m
.44567 .6816 L
s
.44567 .6816 m
.44567 .68161 L
s
.44567 .6816 m
.44567 .6816 L
s
.44567 .6816 m
.44567 .68161 L
s
1 .051 0 r
.49639 .55448 m
.49676 .55472 L
s
.49639 .55448 m
.49678 .55435 L
s
.49678 .55435 m
.49676 .55472 L
s
1 .002 0 r
.39006 .65539 m
.38999 .65538 L
s
.39 .65539 m
.39 .65539 L
s
.39 .65539 m
.39 .65537 L
s
.39 .65539 m
.38999 .65538 L
s
.39 .65537 m
.39001 .65538 L
s
.39 .65537 m
.38999 .65538 L
s
.38999 .65538 m
.39 .65539 L
s
.38999 .65538 m
.39001 .65538 L
s
.39001 .65538 m
.39 .65539 L
s
1 .05 0 r
.5885 .55325 m
.58855 .55318 L
s
.58855 .55318 m
.58849 .55282 L
s
.58855 .55318 m
.58814 .55308 L
s
.58849 .55282 m
.58845 .55289 L
s
.58849 .55282 m
.58814 .55308 L
s
.58814 .55308 m
.5885 .55325 L
s
.58814 .55308 m
.58845 .55289 L
s
.58991 .55286 m
.58814 .55308 L
s
.58845 .55289 m
.5885 .55325 L
s
1 .003 0 r
.48159 .65379 m
.48158 .65378 L
s
.48158 .65378 m
.48159 .65376 L
s
.48158 .65378 m
.48157 .65377 L
s
.48159 .65376 m
.48159 .65377 L
s
.48159 .65376 m
.48157 .65377 L
s
.48166 .65378 m
.48157 .65377 L
s
.48157 .65377 m
.48159 .65379 L
s
.48157 .65377 m
.48159 .65377 L
s
.48159 .65377 m
.48159 .65379 L
s
1 .006 0 r
.42596 .62751 m
.42574 .62748 L
s
.42578 .62751 m
.42578 .6275 L
s
.42578 .6275 m
.42579 .62746 L
s
.42578 .6275 m
.42574 .62748 L
s
.42579 .62746 m
.42579 .62747 L
s
.42579 .62746 m
.42574 .62748 L
s
.42574 .62748 m
.42578 .62751 L
s
.42574 .62748 m
.42579 .62747 L
s
.42579 .62747 m
.42578 .62751 L
s
1 .011 0 r
.37021 .60122 m
.36983 .60112 L
s
.36991 .60119 m
.36988 .60117 L
s
.36988 .60117 m
.36991 .60109 L
s
.36988 .60117 m
.36983 .60112 L
s
.36991 .60109 m
.36993 .60111 L
s
.36991 .60109 m
.36983 .60112 L
s
.36983 .60112 m
.36991 .60119 L
s
.36983 .60112 m
.36993 .60111 L
s
.36993 .60111 m
.36991 .60119 L
s
1 .008 0 r
.51752 .6259 m
.51752 .62589 L
s
.51752 .62589 m
.51752 .62583 L
s
.51752 .62589 m
.51746 .62586 L
s
.51752 .62583 m
.51752 .62584 L
s
.51752 .62583 m
.51746 .62586 L
s
.51774 .62587 m
.51746 .62586 L
s
.51746 .62586 m
.51752 .6259 L
s
.51746 .62586 m
.51752 .62584 L
s
.51752 .62584 m
.51752 .6259 L
s
1 .016 0 r
.46198 .59954 m
.4614 .59948 L
s
1 0 0 r
.40923 .72703 m
.40923 .72703 L
s
1 .016 0 r
.46152 .59956 m
.4615 .59954 L
s
.4615 .59954 m
.46152 .59942 L
s
.4615 .59954 m
.4614 .59948 L
s
.46152 .59942 m
.46153 .59945 L
s
.46152 .59942 m
.4614 .59948 L
s
.4614 .59948 m
.46152 .59956 L
s
.4614 .59948 m
.46153 .59945 L
s
.46153 .59945 m
.46152 .59956 L
s
1 .026 0 r
.40616 .5732 m
.40525 .573 L
s
.40543 .57315 m
.40539 .57311 L
s
.40539 .57311 m
.40544 .57292 L
s
.40539 .57311 m
.40525 .573 L
s
.40544 .57292 m
.40548 .57296 L
s
.40544 .57292 m
.40525 .573 L
s
.40525 .573 m
.40543 .57315 L
s
.40525 .573 m
.40548 .57296 L
s
.40548 .57296 m
.40543 .57315 L
s
1 .018 0 r
.55342 .59797 m
.55343 .59794 L
s
.55343 .59794 m
.55342 .59782 L
s
.55343 .59794 m
.5533 .5979 L
s
.55342 .59782 m
.55342 .59784 L
s
.55342 .59782 m
.5533 .5979 L
s
.5533 .5979 m
.55342 .59797 L
s
.5533 .5979 m
.55342 .59784 L
s
.55394 .59787 m
.5533 .5979 L
s
1 .035 0 r
.35028 .54682 m
.34916 .54644 L
s
1 .018 0 r
.55342 .59784 m
.55342 .59797 L
s
1 .035 0 r
.34937 .54666 m
.3493 .5466 L
s
.3493 .5466 m
.34939 .54636 L
s
.3493 .5466 m
.34916 .54644 L
s
.34939 .54636 m
.34947 .54642 L
s
.34939 .54636 m
.34916 .54644 L
s
.34947 .54642 m
.34937 .54666 L
s
.34916 .54644 m
.34937 .54666 L
s
.34916 .54644 m
.34947 .54642 L
s
.49709 .57159 m
.49708 .57154 L
s
.49708 .57154 m
.49709 .57129 L
s
.49708 .57154 m
.49684 .57142 L
s
.49709 .57129 m
.49711 .57133 L
s
.49709 .57129 m
.49684 .57142 L
s
1 0 0 r
.44528 .69918 m
.44528 .69918 L
s
1 .035 0 r
.49811 .57149 m
.49684 .57142 L
s
1 0 0 r
.44528 .69918 m
.44528 .69918 L
s
.44528 .69918 m
.44528 .69917 L
s
.44528 .69918 m
.44528 .69918 L
s
.44528 .69917 m
.44528 .69917 L
s
.44528 .69917 m
.44528 .69918 L
s
.44528 .69918 m
.44528 .69918 L
s
.44528 .69918 m
.44528 .69917 L
s
.44528 .69917 m
.44528 .69918 L
s
1 .035 0 r
.49684 .57142 m
.49709 .57159 L
s
.49684 .57142 m
.49711 .57133 L
s
.49711 .57133 m
.49709 .57159 L
s
1 .055 0 r
.44222 .54509 m
.44028 .54476 L
s
1 .001 0 r
.38936 .67284 m
.38934 .67283 L
s
.38935 .67284 m
.38934 .67284 L
s
.38934 .67284 m
.38935 .67283 L
s
.38934 .67284 m
.38934 .67283 L
s
.38935 .67283 m
.38935 .67283 L
s
.38935 .67283 m
.38934 .67283 L
s
.38934 .67283 m
.38935 .67284 L
s
.38934 .67283 m
.38935 .67283 L
s
.38935 .67283 m
.38935 .67284 L
s
1 .055 0 r
.44066 .54506 m
.44059 .54498 L
s
.44059 .54498 m
.44067 .54459 L
s
.44059 .54498 m
.44028 .54476 L
s
.44067 .54459 m
.44074 .54467 L
s
.44067 .54459 m
.44028 .54476 L
s
.44028 .54476 m
.44066 .54506 L
s
.44028 .54476 m
.44074 .54467 L
s
.44074 .54467 m
.44066 .54506 L
s
1 .034 0 r
.58928 .57005 m
.58931 .57 L
s
.58931 .57 m
.58928 .56976 L
s
.58931 .57 m
.58904 .56993 L
s
.58928 .56976 m
.58924 .5698 L
s
.58928 .56976 m
.58904 .56993 L
s
.58904 .56993 m
.58928 .57005 L
s
.58904 .56993 m
.58924 .5698 L
s
.59025 .56978 m
.58904 .56993 L
s
.58924 .5698 m
.58928 .57005 L
s
1 .066 0 r
.53243 .54367 m
.53244 .54358 L
s
.53244 .54358 m
.53243 .54311 L
s
.53244 .54358 m
.53195 .54339 L
s
.53243 .54311 m
.53242 .54319 L
s
.53243 .54311 m
.53195 .54339 L
s
.53195 .54339 m
.53243 .54367 L
s
.53195 .54339 m
.53242 .54319 L
s
.53435 .54335 m
.53195 .54339 L
s
1 .001 0 r
.48141 .67123 m
.48141 .67123 L
s
.48141 .67123 m
.48141 .67123 L
s
.48141 .67123 m
.48141 .67123 L
s
.48141 .67123 m
.48141 .67123 L
s
.48141 .67123 m
.48141 .67123 L
s
.48144 .67123 m
.48141 .67123 L
s
.48141 .67123 m
.48141 .67123 L
s
.48141 .67123 m
.48141 .67123 L
s
.48141 .67123 m
.48141 .67123 L
s
1 .066 0 r
.53242 .54319 m
.53243 .54367 L
s
1 .003 0 r
.42545 .64484 m
.42535 .64482 L
s
.42537 .64484 m
.42537 .64483 L
s
.42537 .64483 m
.42537 .64481 L
s
.42537 .64483 m
.42535 .64482 L
s
.42537 .64481 m
.42538 .64482 L
s
.42537 .64481 m
.42535 .64482 L
s
.42535 .64482 m
.42537 .64484 L
s
.42535 .64482 m
.42538 .64482 L
s
.42538 .64482 m
.42537 .64484 L
s
1 .055 0 r
.62515 .54216 m
.62523 .54208 L
s
.62523 .54208 m
.62513 .5417 L
s
.62523 .54208 m
.62476 .54201 L
s
.62513 .5417 m
.62505 .54178 L
s
.62513 .5417 m
.62476 .54201 L
s
.62476 .54201 m
.62515 .54216 L
s
.62476 .54201 m
.62505 .54178 L
s
.62667 .54161 m
.62476 .54201 L
s
.62505 .54178 m
.62515 .54216 L
s
1 .006 0 r
.36941 .61842 m
.36921 .61836 L
s
.36925 .6184 m
.36923 .61839 L
s
.36923 .61839 m
.36925 .61835 L
s
.36923 .61839 m
.36921 .61836 L
s
.36925 .61835 m
.36926 .61836 L
s
.36925 .61835 m
.36921 .61836 L
s
.36921 .61836 m
.36925 .6184 L
s
.36921 .61836 m
.36926 .61836 L
s
.36926 .61836 m
.36925 .6184 L
s
1 .003 0 r
.51761 .64322 m
.51761 .64321 L
s
.51761 .64321 m
.51761 .64319 L
s
.51761 .64321 m
.51758 .6432 L
s
.51761 .64319 m
.51761 .64319 L
s
.51761 .64319 m
.51758 .6432 L
s
.51771 .6432 m
.51758 .6432 L
s
.51758 .6432 m
.51761 .64322 L
s
.51758 .6432 m
.51761 .64319 L
s
.51761 .64319 m
.51761 .64322 L
s
1 0 0 r
.40864 .7449 m
.40864 .7449 L
s
.40864 .7449 m
.40864 .7449 L
s
.40864 .7449 m
.40864 .7449 L
s
.40864 .7449 m
.40864 .7449 L
s
.40864 .7449 m
.40864 .7449 L
s
.40864 .7449 m
.40864 .7449 L
s
.40864 .7449 m
.40864 .7449 L
s
.40863 .7449 m
.40864 .7449 L
s
.40864 .7449 m
.40864 .7449 L
s
1 .009 0 r
.46165 .61675 m
.46134 .61672 L
s
.4614 .61676 m
.46139 .61675 L
s
.46139 .61675 m
.4614 .61669 L
s
.46139 .61675 m
.46134 .61672 L
s
.4614 .61669 m
.46141 .6167 L
s
.4614 .61669 m
.46134 .61672 L
s
.46134 .61672 m
.4614 .61676 L
s
.46134 .61672 m
.46141 .6167 L
s
.46141 .6167 m
.4614 .61676 L
s
1 .016 0 r
.40554 .59028 m
.40498 .59015 L
s
.40509 .59025 m
.40507 .59022 L
s
.40507 .59022 m
.4051 .59011 L
s
.40507 .59022 m
.40498 .59015 L
s
.4051 .59011 m
.40512 .59014 L
s
.4051 .59011 m
.40498 .59015 L
s
.40498 .59015 m
.40509 .59025 L
s
.40498 .59015 m
.40512 .59014 L
s
.40512 .59014 m
.40509 .59025 L
s
1 .01 0 r
.55381 .61514 m
.55381 .61513 L
s
.55381 .61513 m
.55381 .61506 L
s
.55381 .61513 m
.55374 .6151 L
s
.55381 .61506 m
.5538 .61507 L
s
.55381 .61506 m
.55374 .6151 L
s
.55374 .6151 m
.55381 .61514 L
s
.55374 .6151 m
.5538 .61507 L
s
.55409 .61509 m
.55374 .6151 L
s
1 .023 0 r
.34937 .56377 m
.34862 .56352 L
s
1 .01 0 r
.5538 .61507 m
.55381 .61514 L
s
1 .023 0 r
.34876 .56367 m
.34871 .56363 L
s
.34871 .56363 m
.34877 .56347 L
s
.34871 .56363 m
.34862 .56352 L
s
.34877 .56347 m
.34883 .56351 L
s
.34877 .56347 m
.34862 .56352 L
s
.34883 .56351 m
.34876 .56367 L
s
.34862 .56352 m
.34876 .56367 L
s
.34862 .56352 m
.34883 .56351 L
s
1 .022 0 r
.49733 .58864 m
.49732 .58861 L
s
.49732 .58861 m
.49733 .58845 L
s
.49732 .58861 m
.49717 .58854 L
s
.49733 .58845 m
.49734 .58848 L
s
.49733 .58845 m
.49717 .58854 L
s
.49797 .58858 m
.49717 .58854 L
s
1 0 0 r
.44487 .71693 m
.44487 .71693 L
s
1 .022 0 r
.49717 .58854 m
.49733 .58864 L
s
.49717 .58854 m
.49734 .58848 L
s
.49734 .58848 m
.49733 .58864 L
s
1 0 0 r
.38866 .69046 m
.38866 .69046 L
s
1 .038 0 r
.44179 .56205 m
.44046 .56183 L
s
1 0 0 r
.38866 .69046 m
.38866 .69046 L
s
.38866 .69046 m
.38866 .69046 L
s
.38866 .69046 m
.38866 .69046 L
s
.38866 .69046 m
.38866 .69046 L
s
.38866 .69046 m
.38866 .69046 L
s
.38866 .69046 m
.38866 .69046 L
s
.38866 .69046 m
.38866 .69046 L
s
.38866 .69046 m
.38866 .69046 L
s
1 .038 0 r
.44072 .56203 m
.44067 .56198 L
s
.44067 .56198 m
.44073 .56171 L
s
.44067 .56198 m
.44046 .56183 L
s
.44073 .56171 m
.44078 .56176 L
s
.44073 .56171 m
.44046 .56183 L
s
.44046 .56183 m
.44072 .56203 L
s
.44046 .56183 m
.44078 .56176 L
s
.44078 .56176 m
.44072 .56203 L
s
1 .021 0 r
.58998 .58705 m
.59 .58702 L
s
.59 .58702 m
.58998 .58686 L
s
.59 .58702 m
.58983 .58697 L
s
.58998 .58686 m
.58996 .5869 L
s
.58998 .58686 m
.58983 .58697 L
s
.58983 .58697 m
.58998 .58705 L
s
.58983 .58697 m
.58996 .5869 L
s
.59058 .58688 m
.58983 .58697 L
s
.58996 .5869 m
.58998 .58705 L
s
1 .051 0 r
.38555 .53549 m
.38384 .53498 L
s
.38417 .5353 m
.38407 .53522 L
s
.38407 .53522 m
.38419 .53486 L
s
.38407 .53522 m
.38384 .53498 L
s
.38419 .53486 m
.3843 .53494 L
s
.38419 .53486 m
.38384 .53498 L
s
.38384 .53498 m
.38417 .5353 L
s
.38384 .53498 m
.3843 .53494 L
s
.3843 .53494 m
.38417 .5353 L
s
1 .045 0 r
.53307 .56054 m
.53308 .56048 L
s
.53308 .56048 m
.53307 .56015 L
s
.53308 .56048 m
.53274 .56035 L
s
.53307 .56015 m
.53306 .56021 L
s
.53307 .56015 m
.53274 .56035 L
s
.53274 .56035 m
.53307 .56054 L
s
.53274 .56035 m
.53306 .56021 L
s
.53439 .56032 m
.53274 .56035 L
s
1 0 0 r
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
1 .045 0 r
.53306 .56021 m
.53307 .56054 L
s
1 .077 0 r
.47815 .53373 m
.47537 .53344 L
s
1 .001 0 r
.42493 .66234 m
.4249 .66234 L
s
.42491 .66234 m
.42491 .66234 L
s
.42491 .66234 m
.42491 .66234 L
s
.42491 .66234 m
.4249 .66234 L
s
1 .077 0 r
.47592 .53383 m
.47586 .53373 L
s
.47586 .53373 m
.47593 .53317 L
s
.47586 .53373 m
.47537 .53344 L
s
1 .001 0 r
.42491 .66234 m
.42491 .66234 L
s
.42491 .66234 m
.4249 .66234 L
s
.4249 .66234 m
.42491 .66234 L
s
.4249 .66234 m
.42491 .66234 L
s
.42491 .66234 m
.42491 .66234 L
s
1 .077 0 r
.47593 .53317 m
.47599 .53327 L
s
.47593 .53317 m
.47537 .53344 L
s
.47537 .53344 m
.47592 .53383 L
s
.47537 .53344 m
.47599 .53327 L
s
.47599 .53327 m
.47592 .53383 L
s
1 .038 0 r
.62615 .55897 m
.62621 .55891 L
s
.62621 .55891 m
.62614 .55865 L
s
.62621 .55891 m
.62588 .55886 L
s
.62614 .55865 m
.62608 .5587 L
s
.62614 .55865 m
.62588 .55886 L
s
.62588 .55886 m
.62615 .55897 L
s
.62588 .55886 m
.62608 .5587 L
s
.62719 .55859 m
.62588 .55886 L
s
.62608 .5587 m
.62615 .55897 L
s
1 .003 0 r
.3686 .6358 m
.36851 .63577 L
s
.36853 .63579 m
.36852 .63578 L
s
.36852 .63578 m
.36853 .63577 L
s
.36852 .63578 m
.36851 .63577 L
s
.36853 .63577 m
.36853 .63577 L
s
.36853 .63577 m
.36851 .63577 L
s
.36851 .63577 m
.36853 .63579 L
s
.36851 .63577 m
.36853 .63577 L
s
.36853 .63577 m
.36853 .63579 L
s
1 .08 0 r
.56862 .53255 m
.56868 .53245 L
s
.56868 .53245 m
.56861 .53187 L
s
.56868 .53245 m
.56803 .53227 L
s
.56861 .53187 m
.56855 .53197 L
s
.56861 .53187 m
.56803 .53227 L
s
.56803 .53227 m
.56862 .53255 L
s
.56803 .53227 m
.56855 .53197 L
s
.57093 .53197 m
.56803 .53227 L
s
.56855 .53197 m
.56862 .53255 L
s
1 .001 0 r
.51764 .66072 m
.51764 .66072 L
s
.51764 .66072 m
.51764 .66071 L
s
.51764 .66072 m
.51763 .66072 L
s
.51764 .66071 m
.51764 .66071 L
s
.51764 .66071 m
.51763 .66072 L
s
.51767 .66072 m
.51763 .66072 L
s
.51763 .66072 m
.51764 .66072 L
s
.51763 .66072 m
.51764 .66071 L
s
.51764 .66071 m
.51764 .66072 L
s
1 0 0 r
.40804 .76296 m
.40804 .76296 L
s
.40804 .76295 m
.40804 .76296 L
s
.40804 .76296 m
.40804 .76296 L
s
.40804 .76295 m
.40804 .76295 L
s
.40804 .76295 m
.40804 .76296 L
s
.40804 .76296 m
.40804 .76296 L
s
.40804 .76295 m
.40804 .76296 L
s
.40803 .76295 m
.40804 .76296 L
s
.40804 .76296 m
.40804 .76295 L
s
1 .004 0 r
.46132 .63414 m
.46118 .63413 L
s
.46121 .63415 m
.46121 .63414 L
s
.46121 .63414 m
.46121 .63411 L
s
.46121 .63414 m
.46118 .63413 L
s
.46121 .63411 m
.46122 .63412 L
s
.46121 .63411 m
.46118 .63413 L
s
.46118 .63413 m
.46121 .63415 L
s
.46118 .63413 m
.46122 .63412 L
s
.46122 .63412 m
.46121 .63415 L
s
1 .057 0 r
.66241 .53091 m
.66253 .53082 L
s
.66253 .53082 m
.66239 .53043 L
s
.66253 .53082 m
.66203 .53079 L
s
.66239 .53043 m
.66227 .53052 L
s
.66239 .53043 m
.66203 .53079 L
s
.66203 .53079 m
.66241 .53091 L
s
.66203 .53079 m
.66227 .53052 L
s
.66391 .53021 m
.66203 .53079 L
s
.66227 .53052 m
.66241 .53091 L
s
1 .009 0 r
.40492 .60754 m
.40462 .60747 L
s
.40468 .60752 m
.40466 .60751 L
s
.40466 .60751 m
.40468 .60745 L
s
.40466 .60751 m
.40462 .60747 L
s
.40468 .60745 m
.40469 .60746 L
s
.40468 .60745 m
.40462 .60747 L
s
.40462 .60747 m
.40468 .60752 L
s
.40462 .60747 m
.40469 .60746 L
s
.40469 .60746 m
.40468 .60752 L
s
1 .004 0 r
.55411 .63251 m
.55412 .6325 L
s
.55412 .6325 m
.55411 .63247 L
s
.55412 .6325 m
.55408 .63249 L
s
.55411 .63247 m
.55411 .63248 L
s
.55411 .63247 m
.55408 .63249 L
s
.55408 .63249 m
.55411 .63251 L
s
.55408 .63249 m
.55411 .63248 L
s
.55424 .63248 m
.55408 .63249 L
s
1 .014 0 r
.34846 .5809 m
.34799 .58075 L
s
1 .004 0 r
.55411 .63248 m
.55411 .63251 L
s
1 .014 0 r
.34808 .58084 m
.34805 .58081 L
s
.34805 .58081 m
.34809 .58072 L
s
.34805 .58081 m
.34799 .58075 L
s
.34809 .58072 m
.34812 .58074 L
s
.34809 .58072 m
.34799 .58075 L
s
.34812 .58074 m
.34808 .58084 L
s
.34799 .58075 m
.34808 .58084 L
s
.34799 .58075 m
.34812 .58074 L
s
1 .012 0 r
.49748 .60588 m
.49747 .60587 L
s
.49747 .60587 m
.49748 .60578 L
s
.49747 .60587 m
.49739 .60583 L
s
.49748 .60578 m
.49748 .6058 L
s
.49748 .60578 m
.49739 .60583 L
s
1 0 0 r
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
1 .012 0 r
.49782 .60585 m
.49739 .60583 L
s
.49739 .60583 m
.49748 .60588 L
s
.49739 .60583 m
.49748 .6058 L
s
.49748 .6058 m
.49748 .60588 L
s
1 .023 0 r
.44135 .57919 m
.44052 .57905 L
s
1 0 0 r
.38795 .70827 m
.38795 .70827 L
s
1 .023 0 r
.44069 .57918 m
.44066 .57914 L
s
.44066 .57914 m
.44069 .57898 L
s
.44066 .57914 m
.44052 .57905 L
s
.44069 .57898 m
.44072 .57901 L
s
.44069 .57898 m
.44052 .57905 L
s
.44052 .57905 m
.44069 .57918 L
s
.44052 .57905 m
.44072 .57901 L
s
.44072 .57901 m
.44069 .57918 L
s
1 .011 0 r
.59059 .60425 m
.59061 .60423 L
s
.59061 .60423 m
.59059 .60415 L
s
.59061 .60423 m
.59051 .60421 L
s
.59059 .60415 m
.59058 .60417 L
s
.59059 .60415 m
.59051 .60421 L
s
.59051 .60421 m
.59059 .60425 L
s
.59051 .60421 m
.59058 .60417 L
s
.59092 .60416 m
.59051 .60421 L
s
.59058 .60417 m
.59059 .60425 L
s
1 .035 0 r
.38482 .5525 m
.38365 .55215 L
s
.38388 .55237 m
.38381 .55232 L
s
.38381 .55232 m
.38389 .55207 L
s
.38381 .55232 m
.38365 .55215 L
s
.38389 .55207 m
.38397 .55213 L
s
.38389 .55207 m
.38365 .55215 L
s
.38365 .55215 m
.38388 .55237 L
s
.38365 .55215 m
.38397 .55213 L
s
.38397 .55213 m
.38388 .55237 L
s
1 .028 0 r
.53361 .57761 m
.53361 .57757 L
s
.53361 .57757 m
.53361 .57736 L
s
.53361 .57757 m
.5334 .57749 L
s
.53361 .57736 m
.5336 .5774 L
s
.53361 .57736 m
.5334 .57749 L
s
.5334 .57749 m
.53361 .57761 L
s
.5334 .57749 m
.5336 .5774 L
s
.53444 .57747 m
.5334 .57749 L
s
1 0 0 r
.48098 .70668 m
.48098 .70668 L
s
1 .043 0 r
.32823 .52578 m
.32694 .52522 L
s
1 .028 0 r
.5336 .5774 m
.53361 .57761 L
s
1 .043 0 r
.32719 .52551 m
.32707 .52543 L
s
.32707 .52543 m
.32721 .52515 L
s
.32707 .52543 m
.32694 .52522 L
s
.32721 .52515 m
.32732 .52523 L
s
.32721 .52515 m
.32694 .52522 L
s
.32732 .52523 m
.32719 .52551 L
s
.32694 .52522 m
.32719 .52551 L
s
.32694 .52522 m
.32732 .52523 L
s
1 .053 0 r
.4779 .55075 m
.47597 .55055 L
s
1 0 0 r
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
1 .053 0 r
.47635 .55082 m
.47631 .55075 L
s
.47631 .55075 m
.47636 .55036 L
s
.47631 .55075 m
.47597 .55055 L
s
.47636 .55036 m
.4764 .55043 L
s
.47636 .55036 m
.47597 .55055 L
s
.47597 .55055 m
.47635 .55082 L
s
.47597 .55055 m
.4764 .55043 L
s
.4764 .55043 m
.47635 .55082 L
s
1 .023 0 r
.62707 .57598 m
.62711 .57595 L
s
.62711 .57595 m
.62707 .57578 L
s
.62711 .57595 m
.6269 .57591 L
s
.62707 .57578 m
.62703 .57582 L
s
.62707 .57578 m
.6269 .57591 L
s
.6269 .57591 m
.62707 .57598 L
s
.6269 .57591 m
.62703 .57582 L
s
.62772 .57575 m
.6269 .57591 L
s
.62703 .57582 m
.62707 .57598 L
s
1 .077 0 r
.4213 .52401 m
.41865 .52337 L
s
1 .001 0 r
.36778 .65336 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
1 .077 0 r
.41917 .52382 m
.41904 .52371 L
s
.41904 .52371 m
.41919 .52316 L
s
.41904 .52371 m
.41865 .52337 L
s
.41919 .52316 m
.41933 .52328 L
s
.41919 .52316 m
.41865 .52337 L
s
1 .055 0 r
.56956 .5494 m
.5696 .54933 L
s
.5696 .54933 m
.56955 .54892 L
s
.5696 .54933 m
.56915 .5492 L
s
.56955 .54892 m
.56951 .549 L
s
.56955 .54892 m
.56915 .5492 L
s
1 .077 0 r
.41865 .52337 m
.41917 .52382 L
s
.41865 .52337 m
.41933 .52328 L
s
1 .055 0 r
.56915 .5492 m
.56956 .5494 L
s
.56915 .5492 m
.56951 .549 L
s
.57117 .549 m
.56915 .5492 L
s
1 .077 0 r
.41933 .52328 m
.41917 .52382 L
s
1 .055 0 r
.56951 .549 m
.56956 .5494 L
s
1 0 0 r
.51762 .67842 m
.51762 .67842 L
s
.51762 .67842 m
.51762 .67842 L
s
.51762 .67842 m
.51762 .67842 L
s
.51762 .67842 m
.51762 .67842 L
s
.51762 .67842 m
.51762 .67842 L
s
.51763 .67842 m
.51762 .67842 L
s
.51762 .67842 m
.51762 .67842 L
s
.51762 .67842 m
.51762 .67842 L
s
.51762 .67842 m
.51762 .67842 L
s
1 .104 0 r
.51149 .52259 m
.51147 .52247 L
s
.51147 .52247 m
.51149 .5217 L
s
.51147 .52247 m
.51072 .52213 L
s
.51149 .5217 m
.51151 .52183 L
s
.51149 .5217 m
.51072 .52213 L
s
1 .002 0 r
.40746 .7812 m
.40746 .78121 L
s
.40746 .78119 m
.40746 .7812 L
s
.40747 .7812 m
.40746 .7812 L
s
.40746 .7812 m
.40746 .78119 L
s
.40746 .78119 m
.40747 .7812 L
s
.40747 .7812 m
.40746 .78121 L
s
.40746 .7812 m
.40747 .7812 L
s
.40742 .78119 m
.40747 .7812 L
s
.40746 .78121 m
.40746 .7812 L
s
1 .104 0 r
.51456 .52223 m
.51072 .52213 L
s
1 .001 0 r
.46099 .65171 m
.46095 .65171 L
s
.46095 .65171 m
.46095 .65171 L
s
.46095 .65171 m
.46095 .6517 L
s
.46095 .65171 m
.46095 .65171 L
s
.46095 .6517 m
.46096 .6517 L
s
.46095 .6517 m
.46095 .65171 L
s
.46095 .65171 m
.46095 .65171 L
s
.46095 .65171 m
.46096 .6517 L
s
.46096 .6517 m
.46095 .65171 L
s
1 .104 0 r
.51072 .52213 m
.51149 .52259 L
s
.51072 .52213 m
.51151 .52183 L
s
.51151 .52183 m
.51149 .52259 L
s
1 .039 0 r
.66361 .54773 m
.66369 .54766 L
s
.66369 .54766 m
.66359 .54739 L
s
.66369 .54766 m
.66334 .54764 L
s
.66359 .54739 m
.66351 .54745 L
s
.66359 .54739 m
.66334 .54764 L
s
.66334 .54764 m
.66361 .54773 L
s
.66334 .54764 m
.66351 .54745 L
s
.66464 .54724 m
.66334 .54764 L
s
.66351 .54745 m
.66361 .54773 L
s
1 .004 0 r
.40429 .62498 m
.40416 .62495 L
s
.40418 .62497 m
.40418 .62496 L
s
.40418 .62496 m
.40419 .62494 L
s
.40418 .62496 m
.40416 .62495 L
s
.40419 .62494 m
.40419 .62494 L
s
.40419 .62494 m
.40416 .62495 L
s
.40416 .62495 m
.40418 .62497 L
s
.40416 .62495 m
.40419 .62494 L
s
.40419 .62494 m
.40418 .62497 L
s
1 .091 0 r
.60546 .52134 m
.6056 .52121 L
s
.6056 .52121 m
.60544 .52056 L
s
.6056 .52121 m
.60481 .52108 L
s
.60544 .52056 m
.60531 .52069 L
s
.60544 .52056 m
.60481 .52108 L
s
.60481 .52108 m
.60546 .52134 L
s
.60481 .52108 m
.60531 .52069 L
s
.60802 .52044 m
.60481 .52108 L
s
.60531 .52069 m
.60546 .52134 L
s
1 .001 0 r
.55435 .65007 m
.55435 .65007 L
s
.55435 .65007 m
.55435 .65006 L
s
.55435 .65007 m
.55434 .65006 L
s
.55435 .65006 m
.55435 .65006 L
s
.55435 .65006 m
.55434 .65006 L
s
.55434 .65006 m
.55435 .65007 L
s
.55434 .65006 m
.55435 .65006 L
s
.55439 .65006 m
.55434 .65006 L
s
1 .008 0 r
.34754 .59821 m
.34728 .59813 L
s
1 .001 0 r
.55435 .65006 m
.55435 .65007 L
s
1 .008 0 r
.34733 .59818 m
.34731 .59817 L
s
.34731 .59817 m
.34734 .59811 L
s
.34731 .59817 m
.34728 .59813 L
s
.34734 .59811 m
.34735 .59813 L
s
.34734 .59811 m
.34728 .59813 L
s
.34735 .59813 m
.34733 .59818 L
s
.34728 .59813 m
.34733 .59818 L
s
.34728 .59813 m
.34735 .59813 L
s
1 .005 0 r
.49753 .62331 m
.49752 .62331 L
s
.49752 .62331 m
.49753 .62327 L
s
.49752 .62331 m
.49749 .62329 L
s
1 .001 0 r
.44404 .75299 m
.44404 .75299 L
s
.44404 .75298 m
.44404 .75299 L
s
.44405 .75299 m
.44404 .75299 L
s
.44404 .75299 m
.44404 .75298 L
s
.44404 .75298 m
.44405 .75299 L
s
1 .005 0 r
.49753 .62327 m
.49753 .62327 L
s
.49753 .62327 m
.49749 .62329 L
s
1 .001 0 r
.44405 .75299 m
.44404 .75299 L
s
.44404 .75299 m
.44405 .75299 L
s
.44402 .75299 m
.44405 .75299 L
s
.44404 .75299 m
.44404 .75299 L
s
1 .005 0 r
.49768 .6233 m
.49749 .62329 L
s
.49749 .62329 m
.49753 .62331 L
s
.49749 .62329 m
.49753 .62327 L
s
.49753 .62327 m
.49753 .62331 L
s
1 .055 0 r
.69996 .51936 m
.70032 .51946 L
s
.70029 .51898 m
.69996 .51936 L
s
.69996 .51936 m
.70014 .51908 L
s
.70046 .51936 m
.69996 .51936 L
s
.70167 .51865 m
.69996 .51936 L
s
.70032 .51946 m
.70046 .51936 L
s
.70046 .51936 m
.70029 .51898 L
s
.70029 .51898 m
.70014 .51908 L
s
.70014 .51908 m
.70032 .51946 L
s
1 0 0 r
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
1 .013 0 r
.44091 .59651 m
.44046 .59643 L
s
.44055 .5965 m
.44053 .59648 L
s
.44053 .59648 m
.44055 .59639 L
s
.44053 .59648 m
.44046 .59643 L
s
.44055 .59639 m
.44057 .59641 L
s
.44055 .59639 m
.44046 .59643 L
s
.44046 .59643 m
.44055 .5965 L
s
.44046 .59643 m
.44057 .59641 L
s
.44057 .59641 m
.44055 .5965 L
s
1 .005 0 r
.59112 .62166 m
.59112 .62165 L
s
.59112 .62165 m
.59112 .62161 L
s
.59112 .62165 m
.59108 .62164 L
s
.59112 .62161 m
.59111 .62162 L
s
.59112 .62161 m
.59108 .62164 L
s
.59108 .62164 m
.59112 .62166 L
s
.59108 .62164 m
.59111 .62162 L
s
.59127 .62162 m
.59108 .62164 L
s
.59111 .62162 m
.59112 .62166 L
s
1 .022 0 r
.38409 .56969 m
.38336 .56947 L
s
.3835 .56961 m
.38346 .56957 L
s
.38346 .56957 m
.38351 .56942 L
s
.38346 .56957 m
.38336 .56947 L
s
.38351 .56942 m
.38355 .56946 L
s
.38351 .56942 m
.38336 .56947 L
s
.38336 .56947 m
.3835 .56961 L
s
.38336 .56947 m
.38355 .56946 L
s
.38355 .56946 m
.3835 .56961 L
s
1 .015 0 r
.53403 .59487 m
.53403 .59485 L
s
.53403 .59485 m
.53403 .59474 L
s
.53403 .59485 m
.53392 .59481 L
s
.53403 .59474 m
.53403 .59476 L
s
.53403 .59474 m
.53392 .59481 L
s
.53392 .59481 m
.53403 .59487 L
s
.53392 .59481 m
.53403 .59476 L
s
.53449 .5948 m
.53392 .59481 L
s
1 0 0 r
.48075 .72469 m
.48075 .72469 L
s
.48075 .72469 m
.48075 .72469 L
s
.48075 .72469 m
.48075 .72469 L
s
.48075 .72469 m
.48075 .72469 L
s
.48075 .72469 m
.48075 .72469 L
s
.48075 .72469 m
.48075 .72469 L
s
.48075 .72469 m
.48075 .72469 L
s
.48075 .72469 m
.48075 .72469 L
s
1 .029 0 r
.3272 .54284 m
.32632 .54246 L
s
1 0 0 r
.48075 .72469 m
.48075 .72469 L
s
1 .015 0 r
.53403 .59476 m
.53403 .59487 L
s
1 .029 0 r
.32649 .54266 m
.32641 .5426 L
s
.32641 .5426 m
.3265 .54241 L
s
.32641 .5426 m
.32632 .54246 L
s
.3265 .54241 m
.32658 .54247 L
s
.3265 .54241 m
.32632 .54246 L
s
.32658 .54247 m
.32649 .54266 L
s
.32632 .54246 m
.32649 .54266 L
s
.32632 .54246 m
.32658 .54247 L
s
1 .033 0 r
.47765 .56795 m
.47643 .56782 L
s
1 0 0 r
.42388 .69791 m
.42388 .69791 L
s
1 .033 0 r
.47667 .56799 m
.47664 .56795 L
s
.47664 .56795 m
.47667 .5677 L
s
.47664 .56795 m
.47643 .56782 L
s
.47667 .5677 m
.4767 .56775 L
s
.47667 .5677 m
.47643 .56782 L
s
.47643 .56782 m
.47667 .56799 L
s
.47643 .56782 m
.4767 .56775 L
s
.4767 .56775 m
.47667 .56799 L
s
1 .013 0 r
.6279 .59321 m
.62792 .59319 L
s
.62792 .59319 m
.6279 .5931 L
s
.62792 .59319 m
.62781 .59317 L
s
.6279 .5931 m
.62788 .59312 L
s
.6279 .5931 m
.62781 .59317 L
s
.62781 .59317 m
.6279 .59321 L
s
.62781 .59317 m
.62788 .59312 L
s
.62826 .59308 m
.62781 .59317 L
s
.62788 .59312 m
.6279 .59321 L
s
1 0 0 r
.36696 .6711 m
.36695 .6711 L
s
1 .053 0 r
.42076 .54107 m
.41891 .54063 L
s
1 0 0 r
.36696 .6711 m
.36696 .6711 L
s
.36696 .6711 m
.36696 .6711 L
s
.36696 .6711 m
.36695 .6711 L
s
.36696 .6711 m
.36696 .6711 L
s
.36696 .6711 m
.36695 .6711 L
s
.36695 .6711 m
.36696 .6711 L
s
.36695 .6711 m
.36696 .6711 L
s
.36696 .6711 m
.36696 .6711 L
s
1 .053 0 r
.41927 .54095 m
.41918 .54087 L
s
.41918 .54087 m
.41929 .54049 L
s
.41918 .54087 m
.41891 .54063 L
s
.41929 .54049 m
.41938 .54057 L
s
.41929 .54049 m
.41891 .54063 L
s
.41891 .54063 m
.41927 .54095 L
s
.41891 .54063 m
.41938 .54057 L
s
.41938 .54057 m
.41927 .54095 L
s
1 .035 0 r
.57039 .56646 m
.57042 .56641 L
s
.57042 .56641 m
.57038 .56615 L
s
.57042 .56641 m
.57013 .56633 L
s
.57038 .56615 m
.57036 .5662 L
s
.57038 .56615 m
.57013 .56633 L
s
.57013 .56633 m
.57039 .56646 L
s
.57013 .56633 m
.57036 .5662 L
s
.57141 .56621 m
.57013 .56633 L
s
.57036 .5662 m
.57039 .56646 L
s
1 0 0 r
.51759 .6963 m
.51759 .6963 L
s
1 .066 0 r
.3638 .51417 m
.36172 .51335 L
s
.36213 .5138 m
.36196 .51368 L
s
.36196 .51368 m
.36215 .51323 L
s
.36196 .51368 m
.36172 .51335 L
s
.36215 .51323 m
.36232 .51335 L
s
.36215 .51323 m
.36172 .51335 L
s
1 .073 0 r
.51233 .53956 m
.51232 .53947 L
s
.51232 .53947 m
.51234 .53893 L
s
.51232 .53947 m
.51179 .53923 L
s
.51234 .53893 m
.51235 .53902 L
s
.51234 .53893 m
.51179 .53923 L
s
1 .066 0 r
.36232 .51335 m
.36213 .5138 L
s
.36172 .51335 m
.36213 .5138 L
s
.36172 .51335 m
.36232 .51335 L
s
1 .003 0 r
.40689 .79965 m
.4069 .79966 L
s
.4069 .79963 m
.40689 .79965 L
s
.40692 .79965 m
.40689 .79965 L
s
.4069 .79963 m
.4069 .79963 L
s
.4069 .79963 m
.40692 .79965 L
s
.40692 .79965 m
.4069 .79966 L
s
.4069 .79963 m
.40692 .79965 L
s
.4068 .79963 m
.40692 .79965 L
s
.4069 .79966 m
.4069 .79963 L
s
1 .073 0 r
.51451 .5393 m
.51179 .53923 L
s
1 0 0 r
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
1 .073 0 r
.51179 .53923 m
.51233 .53956 L
s
.51179 .53923 m
.51235 .53902 L
s
.51235 .53902 m
.51233 .53956 L
s
1 .024 0 r
.66472 .56476 m
.66478 .56472 L
s
.66478 .56472 m
.66472 .56455 L
s
.66478 .56472 m
.66456 .5647 L
s
.66472 .56455 m
.66466 .56459 L
s
.66472 .56455 m
.66456 .5647 L
s
.66456 .5647 m
.66472 .56476 L
s
.66456 .5647 m
.66466 .56459 L
s
.66537 .56446 m
.66456 .5647 L
s
.66466 .56459 m
.66472 .56476 L
s
1 .115 0 r
.45754 .51237 m
.45343 .51165 L
s
1 .001 0 r
.40366 .6426 m
.40362 .64259 L
s
.40362 .6426 m
.40362 .64259 L
s
.40362 .64259 m
.40362 .64259 L
s
.40362 .64259 m
.40362 .64259 L
s
.40362 .64259 m
.40363 .64259 L
s
.40362 .64259 m
.40362 .64259 L
s
.40362 .64259 m
.40362 .6426 L
s
.40362 .64259 m
.40363 .64259 L
s
.40363 .64259 m
.40362 .6426 L
s
1 .115 0 r
.45424 .51229 m
.45409 .51214 L
s
.45409 .51214 m
.45426 .5113 L
s
.45409 .51214 m
.45343 .51165 L
s
.45426 .5113 m
.45441 .51146 L
s
.45426 .5113 m
.45343 .51165 L
s
1 .063 0 r
.60666 .53815 m
.60675 .53806 L
s
.60675 .53806 m
.60665 .5376 L
s
.60675 .53806 m
.6062 .53797 L
s
.60665 .5376 m
.60655 .53769 L
s
.60665 .5376 m
.6062 .53797 L
s
.6062 .53797 m
.60666 .53815 L
s
.6062 .53797 m
.60655 .53769 L
s
.60845 .53752 m
.6062 .53797 L
s
.60655 .53769 m
.60666 .53815 L
s
1 .115 0 r
.45343 .51165 m
.45424 .51229 L
s
.45343 .51165 m
.45441 .51146 L
s
.45441 .51146 m
.45424 .51229 L
s
1 0 0 r
.55454 .66783 m
.55454 .66783 L
s
.55454 .66783 m
.55454 .66782 L
s
.55454 .66783 m
.55454 .66782 L
s
.55454 .66782 m
.55454 .66782 L
s
.55454 .66782 m
.55454 .66782 L
s
.55454 .66782 m
.55454 .66783 L
s
.55454 .66782 m
.55454 .66782 L
s
.55454 .66782 m
.55454 .66782 L
s
1 .003 0 r
.3466 .6157 m
.34649 .61567 L
s
1 0 0 r
.55454 .66782 m
.55454 .66783 L
s
1 .003 0 r
.34651 .61569 m
.3465 .61568 L
s
.3465 .61568 m
.34651 .61566 L
s
.3465 .61568 m
.34649 .61567 L
s
.34651 .61566 m
.34652 .61567 L
s
.34651 .61566 m
.34649 .61567 L
s
.34652 .61567 m
.34651 .61569 L
s
.34649 .61567 m
.34651 .61569 L
s
.34649 .61567 m
.34652 .61567 L
s
1 .134 0 r
.54752 .51141 m
.54759 .51124 L
s
.54759 .51124 m
.54751 .51026 L
s
.54759 .51124 m
.54653 .5109 L
s
.54751 .51026 m
.54744 .51042 L
s
.54751 .51026 m
.54653 .5109 L
s
.54653 .5109 m
.54752 .51141 L
s
.54653 .5109 m
.54744 .51042 L
s
.55147 .51056 m
.54653 .5109 L
s
1 .002 0 r
.44365 .77131 m
.44366 .77131 L
s
.44366 .7713 m
.44365 .77131 L
s
.44367 .77131 m
.44365 .77131 L
s
.44366 .7713 m
.44366 .7713 L
s
.44366 .7713 m
.44367 .77131 L
s
.44367 .77131 m
.44366 .77131 L
s
.44366 .7713 m
.44367 .77131 L
s
.4436 .7713 m
.44367 .77131 L
s
.44366 .77131 m
.44366 .7713 L
s
.49749 .64093 m
.49749 .64093 L
s
.49749 .64093 m
.49749 .64092 L
s
.49749 .64093 m
.49748 .64093 L
s
.49749 .64092 m
.49749 .64092 L
s
.49749 .64092 m
.49748 .64093 L
s
.49754 .64093 m
.49748 .64093 L
s
.49748 .64093 m
.49749 .64093 L
s
.49748 .64093 m
.49749 .64092 L
s
.49749 .64092 m
.49749 .64093 L
s
1 .134 0 r
.54744 .51042 m
.54752 .51141 L
s
1 .038 0 r
.70142 .53623 m
.70167 .53629 L
s
.70165 .53597 m
.70142 .53623 L
s
.70142 .53623 m
.70155 .53604 L
s
.70177 .53622 m
.70142 .53623 L
s
.7026 .53574 m
.70142 .53623 L
s
.70167 .53629 m
.70177 .53622 L
s
.70177 .53622 m
.70165 .53597 L
s
.70165 .53597 m
.70155 .53604 L
s
.70155 .53604 m
.70167 .53629 L
s
1 .095 0 r
.64308 .50995 m
.64329 .5098 L
s
.64329 .5098 m
.64305 .50913 L
s
.64329 .5098 m
.64243 .50974 L
s
.64305 .50913 m
.64285 .50928 L
s
.64305 .50913 m
.64243 .50974 L
s
.64243 .50974 m
.64308 .50995 L
s
.64243 .50974 m
.64285 .50928 L
s
.64561 .50875 m
.64243 .50974 L
s
1 .001 0 r
.38652 .74445 m
.38652 .74445 L
s
.38652 .74444 m
.38652 .74445 L
s
.38653 .74445 m
.38652 .74445 L
s
.38652 .74445 m
.38652 .74444 L
s
.38652 .74444 m
.38653 .74445 L
s
.38653 .74445 m
.38652 .74445 L
s
.38652 .74445 m
.38653 .74445 L
s
.3865 .74444 m
.38653 .74445 L
s
.38652 .74445 m
.38652 .74445 L
s
1 .006 0 r
.44047 .61401 m
.44027 .61397 L
s
.44031 .61401 m
.4403 .614 L
s
.4403 .614 m
.44031 .61396 L
s
.4403 .614 m
.44027 .61397 L
s
.44031 .61396 m
.44032 .61397 L
s
.44031 .61396 m
.44027 .61397 L
s
.44027 .61397 m
.44031 .61401 L
s
.44027 .61397 m
.44032 .61397 L
s
.44032 .61397 m
.44031 .61401 L
s
1 .095 0 r
.64285 .50928 m
.64308 .50995 L
s
1 .002 0 r
.59157 .63927 m
.59157 .63927 L
s
.59157 .63927 m
.59157 .63926 L
s
.59157 .63927 m
.59156 .63927 L
s
.59157 .63926 m
.59157 .63926 L
s
.59157 .63926 m
.59156 .63927 L
s
.59156 .63927 m
.59157 .63927 L
s
.59156 .63927 m
.59157 .63926 L
s
.59161 .63926 m
.59156 .63927 L
s
.59157 .63926 m
.59157 .63927 L
s
1 .012 0 r
.38335 .58706 m
.38295 .58694 L
s
.38302 .58702 m
.383 .587 L
s
.383 .587 m
.38303 .58691 L
s
.383 .587 m
.38295 .58694 L
s
.38303 .58691 m
.38305 .58693 L
s
.38303 .58691 m
.38295 .58694 L
s
.38295 .58694 m
.38302 .58702 L
s
.38295 .58694 m
.38305 .58693 L
s
.38305 .58693 m
.38302 .58702 L
s
1 .007 0 r
.53433 .61234 m
.53433 .61233 L
s
.53433 .61233 m
.53433 .61228 L
s
.53433 .61233 m
.53428 .61231 L
s
.53433 .61228 m
.53433 .61229 L
s
.53433 .61228 m
.53428 .61231 L
s
.53428 .61231 m
.53433 .61234 L
s
.53428 .61231 m
.53433 .61229 L
s
.53454 .61231 m
.53428 .61231 L
s
1 .001 0 r
.48054 .74288 m
.48054 .74289 L
s
.48054 .74288 m
.48054 .74288 L
s
.48054 .74288 m
.48054 .74288 L
s
.48054 .74288 m
.48054 .74288 L
s
.48054 .74288 m
.48054 .74288 L
s
.48054 .74288 m
.48054 .74289 L
s
.48054 .74288 m
.48054 .74288 L
s
.48051 .74288 m
.48054 .74288 L
s
1 .018 0 r
.32616 .56008 m
.32561 .55984 L
s
1 .001 0 r
.48054 .74289 m
.48054 .74288 L
s
1 .007 0 r
.53433 .61229 m
.53433 .61234 L
s
1 .05 0 r
.73852 .5077 m
.73882 .50776 L
s
.73879 .50733 m
.73852 .5077 L
s
.73852 .5077 m
.73863 .50744 L
s
.73898 .50766 m
.73852 .5077 L
s
.73994 .50694 m
.73852 .5077 L
s
1 .018 0 r
.32572 .55997 m
.32567 .55993 L
s
.32567 .55993 m
.32573 .55981 L
s
.32567 .55993 m
.32561 .55984 L
s
.32573 .55981 m
.32578 .55985 L
s
.32573 .55981 m
.32561 .55984 L
s
1 .05 0 r
.73879 .50733 m
.73863 .50744 L
s
.73898 .50766 m
.73879 .50733 L
s
.73882 .50776 m
.73898 .50766 L
s
1 .018 0 r
.32578 .55985 m
.32572 .55997 L
s
.32561 .55984 m
.32572 .55997 L
s
.32561 .55984 m
.32578 .55985 L
s
1 .05 0 r
.73863 .50744 m
.73882 .50776 L
s
1 0 0 r
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
1 .018 0 r
.4774 .58533 m
.47672 .58526 L
s
.47686 .58535 m
.47684 .58533 L
s
.47684 .58533 m
.47686 .58519 L
s
.47684 .58533 m
.47672 .58526 L
s
.47686 .58519 m
.47687 .58522 L
s
.47686 .58519 m
.47672 .58526 L
s
.47672 .58526 m
.47686 .58535 L
s
.47672 .58526 m
.47687 .58522 L
s
.47687 .58522 m
.47686 .58535 L
s
1 .006 0 r
.62864 .61066 m
.62865 .61065 L
s
.62865 .61065 m
.62864 .61061 L
s
.62865 .61065 m
.6286 .61064 L
s
.62864 .61061 m
.62863 .61062 L
s
.62864 .61061 m
.6286 .61064 L
s
.6286 .61064 m
.62864 .61066 L
s
.6286 .61064 m
.62863 .61062 L
s
.6288 .6106 m
.6286 .61064 L
s
.62863 .61062 m
.62864 .61066 L
s
1 .033 0 r
.4202 .55832 m
.41904 .55804 L
s
1 0 0 r
.36612 .68903 m
.36612 .68903 L
s
1 .033 0 r
.41927 .55824 m
.41921 .55819 L
s
.41921 .55819 m
.41928 .55795 L
s
.41921 .55819 m
.41904 .55804 L
s
.41928 .55795 m
.41933 .558 L
s
.41928 .55795 m
.41904 .55804 L
s
.41904 .55804 m
.41927 .55824 L
s
.41904 .55804 m
.41933 .558 L
s
.41933 .558 m
.41927 .55824 L
s
1 .019 0 r
.57109 .58373 m
.5711 .58371 L
s
.5711 .58371 m
.57109 .58356 L
s
.5711 .58371 m
.57094 .58366 L
s
.57109 .58356 m
.57107 .58359 L
s
.57109 .58356 m
.57094 .58366 L
s
.57094 .58366 m
.57109 .58373 L
s
.57094 .58366 m
.57107 .58359 L
s
.57166 .58359 m
.57094 .58366 L
s
.57107 .58359 m
.57109 .58373 L
s
1 0 0 r
.51755 .71437 m
.51755 .71437 L
s
.51755 .71437 m
.51755 .71437 L
s
.51755 .71437 m
.51755 .71437 L
s
.51755 .71437 m
.51755 .71437 L
s
.51755 .71437 m
.51755 .71437 L
s
.51755 .71437 m
.51755 .71437 L
s
.51755 .71437 m
.51755 .71437 L
s
.51755 .71437 m
.51755 .71437 L
s
1 .045 0 r
.36295 .53128 m
.36151 .53072 L
s
1 0 0 r
.51755 .71437 m
.51755 .71437 L
s
1 .045 0 r
.36179 .53103 m
.36167 .53095 L
s
.36167 .53095 m
.36181 .53064 L
s
.36167 .53095 m
.36151 .53072 L
s
.36181 .53064 m
.36193 .53072 L
s
.36181 .53064 m
.36151 .53072 L
s
.36193 .53072 m
.36179 .53103 L
s
.36151 .53072 m
.36179 .53103 L
s
.36151 .53072 m
.36193 .53072 L
s
1 .047 0 r
.51305 .55672 m
.51304 .55666 L
s
.51304 .55666 m
.51305 .55631 L
s
.51304 .55666 m
.51271 .55651 L
s
.51305 .55631 m
.51306 .55638 L
s
.51305 .55631 m
.51271 .55651 L
s
1 .007 0 r
.40636 .8183 m
.40636 .81831 L
s
.40637 .81825 m
.40636 .8183 L
s
.40641 .81829 m
.40636 .8183 L
s
.40637 .81827 m
.40637 .81825 L
s
.40637 .81825 m
.40641 .81829 L
s
.40641 .81829 m
.40636 .81831 L
s
.40637 .81827 m
.40641 .81829 L
s
.40617 .81825 m
.40641 .81829 L
s
.40636 .81831 m
.40637 .81827 L
s
1 .047 0 r
.51445 .55655 m
.51271 .55651 L
s
1 0 0 r
.46031 .6874 m
.46031 .6874 L
s
1 .05 0 r
.30563 .50421 m
.30423 .50343 L
s
1 .047 0 r
.51271 .55651 m
.51305 .55672 L
s
.51271 .55651 m
.51306 .55638 L
s
.51306 .55638 m
.51305 .55672 L
s
1 .05 0 r
.30453 .50337 m
.30469 .50348 L
s
.30434 .5037 m
.30453 .50337 L
s
.30453 .50337 m
.30423 .50343 L
s
.3045 .5038 m
.30434 .5037 L
s
.30434 .5037 m
.30423 .50343 L
s
.30469 .50348 m
.3045 .5038 L
s
.30423 .50343 m
.30469 .50348 L
s
.30423 .50343 m
.3045 .5038 L
s
1 .013 0 r
.66576 .58202 m
.66578 .582 L
s
.66578 .582 m
.66575 .5819 L
s
.66578 .582 m
.66566 .58199 L
s
.66575 .5819 m
.66572 .58193 L
s
.66575 .5819 m
.66566 .58199 L
s
.66566 .58199 m
.66576 .58202 L
s
.66566 .58199 m
.66572 .58193 L
s
.66611 .58185 m
.66566 .58199 L
s
.66572 .58193 m
.66576 .58202 L
s
1 .081 0 r
.45718 .52949 m
.45426 .52899 L
s
1 0 0 r
.40301 .66041 m
.40301 .66041 L
s
.40301 .66041 m
.40301 .66041 L
s
.40301 .66041 m
.40301 .6604 L
s
.40301 .66041 m
.40301 .66041 L
s
.40301 .6604 m
.40301 .66041 L
s
.40301 .6604 m
.40301 .66041 L
s
.40301 .66041 m
.40301 .66041 L
s
.40301 .66041 m
.40301 .66041 L
s
.40301 .66041 m
.40301 .66041 L
s
1 .081 0 r
.45484 .52944 m
.45473 .52933 L
s
.45473 .52933 m
.45485 .52874 L
s
.45473 .52933 m
.45426 .52899 L
s
.45485 .52874 m
.45496 .52885 L
s
.45485 .52874 m
.45426 .52899 L
s
.45426 .52899 m
.45484 .52944 L
s
.45426 .52899 m
.45496 .52885 L
s
1 .04 0 r
.60775 .55519 m
.60781 .55513 L
s
.60781 .55513 m
.60774 .55483 L
s
.60781 .55513 m
.60746 .55507 L
s
.60774 .55483 m
.60768 .55489 L
s
.60774 .55483 m
.60746 .55507 L
s
1 .081 0 r
.45496 .52885 m
.45484 .52944 L
s
1 .04 0 r
.60746 .55507 m
.60775 .55519 L
s
.60746 .55507 m
.60768 .55489 L
s
.60889 .55479 m
.60746 .55507 L
s
.60768 .55489 m
.60775 .55519 L
s
1 0 0 r
.5547 .68578 m
.5547 .68578 L
s
1 .104 0 r
.39985 .50239 m
.39642 .50123 L
s
1 .001 0 r
.34566 .63338 m
.34562 .63337 L
s
.34563 .63338 m
.34563 .63337 L
s
.34563 .63337 m
.34563 .63337 L
s
.34563 .63337 m
.34562 .63337 L
s
.34563 .63337 m
.34563 .63337 L
s
.34563 .63337 m
.34562 .63337 L
s
.34563 .63337 m
.34563 .63338 L
s
.34562 .63337 m
.34563 .63338 L
s
.34562 .63337 m
.34563 .63337 L
s
1 .095 0 r
.54878 .5283 m
.54883 .52818 L
s
.54883 .52818 m
.54878 .52747 L
s
.54883 .52818 m
.54807 .52793 L
s
.54878 .52747 m
.54872 .52759 L
s
.54878 .52747 m
.54807 .52793 L
s
1 .104 0 r
.39709 .50191 m
.39684 .50174 L
s
.39684 .50174 m
.39712 .50101 L
s
.39684 .50174 m
.39642 .50123 L
s
1 .095 0 r
.54807 .52793 m
.54878 .5283 L
s
.54807 .52793 m
.54872 .52759 L
s
.55161 .52769 m
.54807 .52793 L
s
1 .104 0 r
.39712 .50101 m
.39737 .50118 L
s
.39712 .50101 m
.39642 .50123 L
s
1 .005 0 r
.4433 .78983 m
.4433 .78984 L
s
.4433 .7898 m
.4433 .78983 L
s
.44334 .78982 m
.4433 .78983 L
s
.44331 .78981 m
.4433 .7898 L
s
.4433 .7898 m
.44334 .78982 L
s
.44334 .78982 m
.4433 .78984 L
s
.44331 .78981 m
.44334 .78982 L
s
.44317 .78981 m
.44334 .78982 L
s
.4433 .78984 m
.44331 .78981 L
s
1 0 0 r
.49738 .65875 m
.49738 .65875 L
s
.49738 .65875 m
.49738 .65875 L
s
.49738 .65875 m
.49738 .65875 L
s
.49738 .65875 m
.49738 .65875 L
s
.49738 .65875 m
.49738 .65875 L
s
.49739 .65875 m
.49738 .65875 L
s
.49738 .65875 m
.49738 .65875 L
s
.49738 .65875 m
.49738 .65875 L
s
.49738 .65875 m
.49738 .65875 L
s
1 .095 0 r
.54872 .52759 m
.54878 .5283 L
s
1 .104 0 r
.39642 .50123 m
.39709 .50191 L
s
.39642 .50123 m
.39737 .50118 L
s
.39737 .50118 m
.39709 .50191 L
s
1 .023 0 r
.7028 .55331 m
.70295 .55336 L
s
.70294 .55315 m
.7028 .55331 L
s
.7028 .55331 m
.70288 .5532 L
s
.70302 .55331 m
.7028 .55331 L
s
.70353 .55302 m
.7028 .55331 L
s
.70295 .55336 m
.70302 .55331 L
s
.70302 .55331 m
.70294 .55315 L
s
.70294 .55315 m
.70288 .5532 L
s
.70288 .5532 m
.70295 .55336 L
s
1 .168 0 r
.48929 .50086 m
.48917 .50066 L
s
.48917 .50066 m
.4893 .49941 L
s
.48917 .50066 m
.48805 .50002 L
s
1 .002 0 r
.38582 .76284 m
.38583 .76284 L
s
.38583 .76282 m
.38582 .76284 L
s
.38584 .76283 m
.38582 .76284 L
s
.38583 .76283 m
.38583 .76282 L
s
.38583 .76282 m
.38584 .76283 L
s
.38584 .76283 m
.38583 .76284 L
s
.38583 .76283 m
.38584 .76283 L
s
.38577 .76282 m
.38584 .76283 L
s
.38583 .76284 m
.38583 .76283 L
s
1 .168 0 r
.49427 .50057 m
.48805 .50002 L
s
1 .002 0 r
.44002 .63169 m
.43996 .63168 L
s
.43997 .63169 m
.43997 .63169 L
s
.43997 .63169 m
.43997 .63168 L
s
.43997 .63169 m
.43996 .63168 L
s
.43997 .63168 m
.43997 .63168 L
s
.43997 .63168 m
.43996 .63168 L
s
.43996 .63168 m
.43997 .63169 L
s
.43996 .63168 m
.43997 .63168 L
s
.43997 .63168 m
.43997 .63169 L
s
1 .168 0 r
.4893 .49941 m
.48941 .49961 L
s
.4893 .49941 m
.48805 .50002 L
s
1 .066 0 r
.64447 .52673 m
.64461 .52662 L
s
.64461 .52662 m
.64445 .52615 L
s
.64461 .52662 m
.64401 .52658 L
s
.64445 .52615 m
.6443 .52626 L
s
.64445 .52615 m
.64401 .52658 L
s
.64401 .52658 m
.64447 .52673 L
s
.64401 .52658 m
.6443 .52626 L
s
.64624 .52589 m
.64401 .52658 L
s
.6443 .52626 m
.64447 .52673 L
s
1 .158 0 r
.58435 .50024 m
.58457 .50004 L
s
.58457 .50004 m
.58432 .49888 L
s
.58457 .50004 m
.5832 .49977 L
s
1 .168 0 r
.48805 .50002 m
.48929 .50086 L
s
.48805 .50002 m
.48941 .49961 L
s
1 .158 0 r
.58432 .49888 m
.5841 .49908 L
s
.58432 .49888 m
.5832 .49977 L
s
.5832 .49977 m
.58435 .50024 L
s
.5832 .49977 m
.5841 .49908 L
s
.5889 .49874 m
.5832 .49977 L
s
1 .168 0 r
.48941 .49961 m
.48929 .50086 L
s
1 0 0 r
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
1 .005 0 r
.38259 .60461 m
.38242 .60456 L
s
.38245 .60459 m
.38244 .60458 L
s
.38244 .60458 m
.38245 .60454 L
s
.38244 .60458 m
.38242 .60456 L
s
.38245 .60454 m
.38247 .60455 L
s
.38245 .60454 m
.38242 .60456 L
s
.38242 .60456 m
.38245 .60459 L
s
.38242 .60456 m
.38247 .60455 L
s
.38247 .60455 m
.38245 .60459 L
s
1 .158 0 r
.5841 .49908 m
.58435 .50024 L
s
1 .003 0 r
.48035 .76128 m
.48035 .76128 L
s
.48035 .76126 m
.48035 .76128 L
s
.48037 .76127 m
.48035 .76128 L
s
.48036 .76127 m
.48035 .76126 L
s
.48035 .76126 m
.48037 .76127 L
s
1 .002 0 r
.53452 .63001 m
.53452 .63001 L
s
.53452 .63001 m
.53452 .62999 L
s
.53452 .63001 m
.53451 .63 L
s
1 .003 0 r
.48037 .76127 m
.48035 .76128 L
s
.48036 .76127 m
.48037 .76127 L
s
.48028 .76127 m
.48037 .76127 L
s
1 .002 0 r
.53452 .62999 m
.53452 .63 L
s
.53452 .62999 m
.53451 .63 L
s
.53451 .63 m
.53452 .63001 L
s
.53451 .63 m
.53452 .63 L
s
.53459 .63 m
.53451 .63 L
s
1 .01 0 r
.32511 .5775 m
.32481 .57737 L
s
1 .003 0 r
.48035 .76128 m
.48036 .76127 L
s
1 .002 0 r
.53452 .63 m
.53452 .63001 L
s
1 .01 0 r
.32487 .57744 m
.32484 .57742 L
s
.32484 .57742 m
.32487 .57735 L
s
.32484 .57742 m
.32481 .57737 L
s
.32487 .57735 m
.3249 .57737 L
s
.32487 .57735 m
.32481 .57737 L
s
.3249 .57737 m
.32487 .57744 L
s
.32481 .57737 m
.32487 .57744 L
s
.32481 .57737 m
.3249 .57737 L
s
1 .034 0 r
.74011 .5246 m
.74031 .52465 L
s
.74029 .52435 m
.74011 .5246 L
s
.74011 .5246 m
.74018 .52442 L
s
.74042 .52457 m
.74011 .5246 L
s
.74108 .52409 m
.74011 .5246 L
s
.74029 .52435 m
.74018 .52442 L
s
.74042 .52457 m
.74029 .52435 L
s
.74031 .52465 m
.74042 .52457 L
s
.74018 .52442 m
.74031 .52465 L
s
1 .091 0 r
.68092 .49814 m
.6815 .49828 L
s
.68146 .4975 m
.68092 .49814 L
s
.68092 .49814 m
.6812 .49766 L
s
.68176 .49812 m
.68092 .49814 L
s
.68372 .4969 m
.68092 .49814 L
s
.6815 .49828 m
.68176 .49812 L
s
.68176 .49812 m
.68146 .4975 L
s
.68146 .4975 m
.6812 .49766 L
s
1 .001 0 r
.42283 .73423 m
.42283 .73423 L
s
.42283 .73422 m
.42283 .73423 L
s
.42284 .73423 m
.42283 .73423 L
s
.42284 .73422 m
.42283 .73422 L
s
.42283 .73422 m
.42284 .73423 L
s
.42284 .73423 m
.42283 .73423 L
s
.42284 .73422 m
.42284 .73423 L
s
.42281 .73422 m
.42284 .73423 L
s
.42283 .73423 m
.42284 .73422 L
s
1 .008 0 r
.47715 .60289 m
.47684 .60286 L
s
.4769 .6029 m
.4769 .60289 L
s
.4769 .60289 m
.4769 .60283 L
s
.4769 .60289 m
.47684 .60286 L
s
.4769 .60283 m
.47691 .60284 L
s
.4769 .60283 m
.47684 .60286 L
s
.47684 .60286 m
.4769 .6029 L
s
.47684 .60286 m
.47691 .60284 L
s
.47691 .60284 m
.4769 .6029 L
s
1 .091 0 r
.6812 .49766 m
.6815 .49828 L
s
1 .002 0 r
.6293 .62832 m
.6293 .62832 L
s
.6293 .62832 m
.6293 .62831 L
s
.6293 .62832 m
.62929 .62832 L
s
.6293 .62831 m
.6293 .62831 L
s
.6293 .62831 m
.62929 .62832 L
s
.62929 .62832 m
.6293 .62832 L
s
.62929 .62832 m
.6293 .62831 L
s
.62935 .62831 m
.62929 .62832 L
s
.6293 .62831 m
.6293 .62832 L
s
1 0 0 r
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
1 .018 0 r
.41965 .57575 m
.419 .57559 L
s
.41913 .57571 m
.4191 .57568 L
s
.4191 .57568 m
.41913 .57554 L
s
.4191 .57568 m
.419 .57559 L
s
.41913 .57554 m
.41917 .57557 L
s
.41913 .57554 m
.419 .57559 L
s
.419 .57559 m
.41913 .57571 L
s
.419 .57559 m
.41917 .57557 L
s
.41917 .57557 m
.41913 .57571 L
s
1 .009 0 r
.57165 .60123 m
.57165 .60121 L
s
.57165 .60121 m
.57164 .60115 L
s
.57165 .60121 m
.57158 .60119 L
s
.57164 .60115 m
.57164 .60116 L
s
.57164 .60115 m
.57158 .60119 L
s
.57158 .60119 m
.57165 .60123 L
s
.57158 .60119 m
.57164 .60116 L
s
.5719 .60116 m
.57158 .60119 L
s
.57164 .60116 m
.57165 .60123 L
s
1 .001 0 r
.51754 .73264 m
.51754 .73264 L
s
.51754 .73263 m
.51754 .73264 L
s
.51754 .73264 m
.51754 .73264 L
s
.51754 .73264 m
.51754 .73263 L
s
.51754 .73263 m
.51754 .73264 L
s
.51754 .73264 m
.51754 .73264 L
s
.51754 .73264 m
.51754 .73264 L
s
.51751 .73264 m
.51754 .73264 L
s
1 .028 0 r
.36209 .54857 m
.36119 .54823 L
s
1 .001 0 r
.51754 .73264 m
.51754 .73264 L
s
1 .043 0 r
.77764 .49581 m
.77787 .49584 L
s
.77785 .49547 m
.77764 .49581 L
s
.77764 .49581 m
.77769 .49557 L
s
.77803 .49574 m
.77764 .49581 L
s
.77874 .49506 m
.77764 .49581 L
s
1 .028 0 r
.36136 .54842 m
.36129 .54837 L
s
.36129 .54837 m
.36137 .54817 L
s
.36129 .54837 m
.36119 .54823 L
s
.36137 .54817 m
.36145 .54822 L
s
.36137 .54817 m
.36119 .54823 L
s
1 .043 0 r
.77785 .49547 m
.77769 .49557 L
s
.77803 .49574 m
.77785 .49547 L
s
.77787 .49584 m
.77803 .49574 L
s
1 .028 0 r
.36145 .54822 m
.36136 .54842 L
s
.36119 .54823 m
.36136 .54842 L
s
.36119 .54823 m
.36145 .54822 L
s
1 .043 0 r
.77769 .49557 m
.77787 .49584 L
s
1 .011 0 r
.40585 .83715 m
.40586 .83718 L
s
.40586 .83707 m
.40585 .83715 L
s
.40594 .83713 m
.40585 .83715 L
s
.40588 .8371 m
.40586 .83707 L
s
.40586 .83707 m
.40594 .83713 L
s
.40594 .83713 m
.40586 .83718 L
s
.40588 .8371 m
.40594 .83713 L
s
.40554 .83708 m
.40594 .83713 L
s
1 .026 0 r
.51361 .57409 m
.5136 .57405 L
s
.5136 .57405 m
.51361 .57386 L
s
.5136 .57405 m
.51341 .57397 L
s
.51361 .57386 m
.51361 .57389 L
s
.51361 .57386 m
.51341 .57397 L
s
1 .011 0 r
.40586 .83718 m
.40588 .8371 L
s
1 0 0 r
.45997 .70554 m
.45997 .70554 L
s
.45997 .70553 m
.45997 .70554 L
s
.45997 .70554 m
.45997 .70554 L
s
.45997 .70554 m
.45997 .70553 L
s
.45997 .70553 m
.45997 .70554 L
s
.45997 .70554 m
.45997 .70554 L
s
.45997 .70554 m
.45997 .70554 L
s
.45997 .70554 m
.45997 .70554 L
s
.45997 .70554 m
.45997 .70554 L
s
1 .026 0 r
.51439 .57399 m
.51341 .57397 L
s
1 .034 0 r
.30447 .52137 m
.30351 .52085 L
s
1 .026 0 r
.51341 .57397 m
.51361 .57409 L
s
.51341 .57397 m
.51361 .57389 L
s
.51361 .57389 m
.51361 .57409 L
s
1 .034 0 r
.30371 .5208 m
.30382 .52088 L
s
.30358 .52102 m
.30371 .5208 L
s
.30371 .5208 m
.30351 .52085 L
s
.30369 .5211 m
.30358 .52102 L
s
.30358 .52102 m
.30351 .52085 L
s
.30382 .52088 m
.30369 .5211 L
s
.30351 .52085 m
.30382 .52088 L
s
.30351 .52085 m
.30369 .5211 L
s
1 .006 0 r
.6667 .59951 m
.66671 .5995 L
s
.66671 .5995 m
.6667 .59946 L
s
.66671 .5995 m
.66666 .59949 L
s
.6667 .59946 m
.66668 .59947 L
s
.6667 .59946 m
.66666 .59949 L
s
.66666 .59949 m
.6667 .59951 L
s
.66666 .59949 m
.66668 .59947 L
s
.66686 .59944 m
.66666 .59949 L
s
.66668 .59947 m
.6667 .59951 L
s
1 .052 0 r
.45682 .54679 m
.45494 .54647 L
s
1 0 0 r
.40237 .6784 m
.40237 .6784 L
s
1 .052 0 r
.45531 .54676 m
.45524 .54669 L
s
.45524 .54669 m
.45532 .54631 L
s
.45524 .54669 m
.45494 .54647 L
s
.45532 .54631 m
.45539 .54638 L
s
.45532 .54631 m
.45494 .54647 L
s
.45494 .54647 m
.45531 .54676 L
s
.45494 .54647 m
.45539 .54638 L
s
.45539 .54638 m
.45531 .54676 L
s
1 .022 0 r
.6087 .57246 m
.60873 .57242 L
s
.60873 .57242 m
.60869 .57226 L
s
.60873 .57242 m
.60853 .57239 L
s
.60869 .57226 m
.60866 .57229 L
s
.60869 .57226 m
.60853 .57239 L
s
.60853 .57239 m
.6087 .57246 L
s
.60853 .57239 m
.60866 .57229 L
s
.60933 .57223 m
.60853 .57239 L
s
.60866 .57229 m
.6087 .57246 L
s
1 0 0 r
.55486 .70392 m
.55486 .70392 L
s
.55486 .70392 m
.55486 .70392 L
s
.55486 .70392 m
.55486 .70392 L
s
.55486 .70392 m
.55486 .70392 L
s
.55486 .70392 m
.55486 .70392 L
s
.55485 .70392 m
.55486 .70392 L
s
1 .073 0 r
.39919 .51956 m
.39676 .51874 L
s
1 0 0 r
.34471 .65124 m
.3447 .65124 L
s
.55486 .70392 m
.55486 .70392 L
s
.55486 .70392 m
.55486 .70392 L
s
.55486 .70392 m
.55486 .70392 L
s
.3447 .65124 m
.3447 .65124 L
s
.3447 .65124 m
.3447 .65124 L
s
.3447 .65124 m
.3447 .65124 L
s
.3447 .65124 m
.3447 .65124 L
s
.3447 .65124 m
.3447 .65124 L
s
.3447 .65124 m
.3447 .65124 L
s
.3447 .65124 m
.3447 .65124 L
s
.3447 .65124 m
.3447 .65124 L
s
1 .073 0 r
.39723 .51923 m
.39706 .5191 L
s
.39706 .5191 m
.39726 .51859 L
s
.39706 .5191 m
.39676 .51874 L
s
.39726 .51859 m
.39743 .51871 L
s
.39726 .51859 m
.39676 .51874 L
s
1 .062 0 r
.54991 .5454 m
.54994 .54532 L
s
.54994 .54532 m
.54991 .54485 L
s
.54994 .54532 m
.54945 .54516 L
s
.54991 .54485 m
.54987 .54494 L
s
.54991 .54485 m
.54945 .54516 L
s
.54945 .54516 m
.54991 .5454 L
s
.54945 .54516 m
.54987 .54494 L
s
.55175 .545 m
.54945 .54516 L
s
1 .073 0 r
.39676 .51874 m
.39723 .51923 L
s
.39676 .51874 m
.39743 .51871 L
s
.39743 .51871 m
.39723 .51923 L
s
1 .009 0 r
.44298 .80856 m
.44299 .80858 L
s
.44299 .80849 m
.44298 .80856 L
s
.44305 .80854 m
.44298 .80856 L
s
.44299 .80851 m
.44299 .80849 L
s
.44299 .80849 m
.44305 .80854 L
s
.44305 .80854 m
.44299 .80858 L
s
.44299 .80851 m
.44305 .80854 L
s
.44273 .80851 m
.44305 .80854 L
s
.44299 .80858 m
.44299 .80851 L
s
1 0 0 r
.49724 .67676 m
.49724 .67676 L
s
1 .08 0 r
.34149 .4923 m
.33917 .49108 L
s
1 .062 0 r
.54987 .54494 m
.54991 .5454 L
s
1 .013 0 r
.70408 .57063 m
.70416 .57066 L
s
.70416 .57054 m
.70408 .57063 L
s
.70408 .57063 m
.70412 .57057 L
s
.7042 .57063 m
.70408 .57063 L
s
.70448 .57047 m
.70408 .57063 L
s
.70416 .57066 m
.7042 .57063 L
s
.7042 .57063 m
.70416 .57054 L
s
.70416 .57054 m
.70412 .57057 L
s
1 .08 0 r
.33966 .49098 m
.33991 .49114 L
s
.33936 .49151 m
.33966 .49098 L
s
.33966 .49098 m
.33917 .49108 L
s
.33962 .49167 m
.33936 .49151 L
s
.33936 .49151 m
.33917 .49108 L
s
1 .013 0 r
.70412 .57057 m
.70416 .57066 L
s
1 .121 0 r
.49049 .51796 m
.49041 .51781 L
s
.49041 .51781 m
.4905 .5169 L
s
.49041 .51781 m
.48959 .51735 L
s
1 .005 0 r
.38515 .78143 m
.38516 .78144 L
s
.38516 .78139 m
.38515 .78143 L
s
.38519 .78142 m
.38515 .78143 L
s
.38517 .7814 m
.38516 .78139 L
s
.38516 .78139 m
.38519 .78142 L
s
.38519 .78142 m
.38516 .78144 L
s
.38517 .7814 m
.38519 .78142 L
s
.38503 .78139 m
.38519 .78142 L
s
.38516 .78144 m
.38517 .7814 L
s
1 0 0 r
.43957 .64957 m
.43956 .64956 L
s
1 .121 0 r
.49411 .51774 m
.48959 .51735 L
s
1 0 0 r
.43956 .64957 m
.43956 .64957 L
s
.43956 .64957 m
.43956 .64956 L
s
.43956 .64957 m
.43956 .64956 L
s
.43956 .64956 m
.43956 .64956 L
s
.43956 .64956 m
.43956 .64956 L
s
.43956 .64956 m
.43956 .64957 L
s
.43956 .64956 m
.43956 .64956 L
s
.43956 .64956 m
.43956 .64957 L
s
1 .121 0 r
.4905 .5169 m
.49058 .51705 L
s
.4905 .5169 m
.48959 .51735 L
s
1 .08 0 r
.33991 .49114 m
.33962 .49167 L
s
.33917 .49108 m
.33991 .49114 L
s
.33917 .49108 m
.33962 .49167 L
s
1 .121 0 r
.48959 .51735 m
.49049 .51796 L
s
.48959 .51735 m
.49058 .51705 L
s
1 .042 0 r
.64575 .54375 m
.64584 .54367 L
s
.64584 .54367 m
.64574 .54337 L
s
.64584 .54367 m
.64546 .54365 L
s
.64574 .54337 m
.64565 .54344 L
s
.64574 .54337 m
.64546 .54365 L
s
.64546 .54365 m
.64575 .54375 L
s
.64546 .54365 m
.64565 .54344 L
s
.64689 .54321 m
.64546 .54365 L
s
1 .121 0 r
.49058 .51705 m
.49049 .51796 L
s
1 .042 0 r
.64565 .54344 m
.64575 .54375 L
s
1 .114 0 r
.58594 .51701 m
.5861 .51685 L
s
.5861 .51685 m
.58593 .51601 L
s
.5861 .51685 m
.58511 .51666 L
s
1 0 0 r
.59232 .6751 m
.59232 .6751 L
s
1 .168 0 r
.43641 .49045 m
.43058 .48889 L
s
1 .002 0 r
.38184 .62235 m
.38178 .62233 L
s
.38179 .62234 m
.38179 .62234 L
s
.38179 .62234 m
.38179 .62233 L
s
.38179 .62234 m
.38178 .62233 L
s
.38179 .62233 m
.3818 .62233 L
s
.38179 .62233 m
.38178 .62233 L
s
.38178 .62233 m
.38179 .62234 L
s
.38178 .62233 m
.3818 .62233 L
s
.3818 .62233 m
.38179 .62234 L
s
1 .114 0 r
.58593 .51601 m
.58577 .51617 L
s
.58593 .51601 m
.58511 .51666 L
s
.58511 .51666 m
.58594 .51701 L
s
.58511 .51666 m
.58577 .51617 L
s
.58923 .51592 m
.58511 .51666 L
s
.58577 .51617 m
.58594 .51701 L
s
1 .168 0 r
.43172 .48993 m
.43139 .48969 L
s
.43139 .48969 m
.43177 .48847 L
s
.43139 .48969 m
.43058 .48889 L
s
.43177 .48847 m
.4321 .48871 L
s
.43177 .48847 m
.43058 .48889 L
s
1 .006 0 r
.48021 .77988 m
.48022 .77989 L
s
.48022 .77983 m
.48021 .77988 L
s
.48026 .77986 m
.48021 .77988 L
s
.48022 .77984 m
.48022 .77983 L
s
.48022 .77983 m
.48026 .77986 L
s
.48026 .77986 m
.48022 .77989 L
s
.48022 .77984 m
.48026 .77986 L
s
.48004 .77985 m
.48026 .77986 L
s
1 0 0 r
.53463 .64789 m
.53463 .64789 L
s
.53463 .64789 m
.53463 .64788 L
s
.53463 .64789 m
.53463 .64789 L
s
.53463 .64788 m
.53463 .64788 L
s
.53463 .64788 m
.53463 .64789 L
s
.53463 .64789 m
.53463 .64789 L
s
.53463 .64789 m
.53463 .64788 L
s
.53464 .64789 m
.53463 .64789 L
s
1 .004 0 r
.32404 .5951 m
.32391 .59504 L
s
1 0 0 r
.53463 .64788 m
.53463 .64789 L
s
1 .006 0 r
.48022 .77989 m
.48022 .77984 L
s
1 .004 0 r
.32394 .59507 m
.32392 .59507 L
s
.32392 .59507 m
.32394 .59504 L
s
.32392 .59507 m
.32391 .59504 L
s
.32394 .59504 m
.32395 .59505 L
s
.32394 .59504 m
.32391 .59504 L
s
1 .233 0 r
.5245 .48975 m
.52454 .48948 L
s
.52454 .48948 m
.5245 .48773 L
s
.52454 .48948 m
.52274 .48877 L
s
1 .004 0 r
.32395 .59505 m
.32394 .59507 L
s
.32391 .59504 m
.32394 .59507 L
s
.32391 .59504 m
.32395 .59505 L
s
1 .233 0 r
.5245 .48773 m
.52446 .48799 L
s
.5245 .48773 m
.52274 .48877 L
s
1 .021 0 r
.74162 .54173 m
.74175 .54176 L
s
.74173 .54158 m
.74162 .54173 L
s
.74162 .54173 m
.74167 .54162 L
s
.74181 .54172 m
.74162 .54173 L
s
.74222 .54142 m
.74162 .54173 L
s
.74173 .54158 m
.74167 .54162 L
s
.74181 .54172 m
.74173 .54158 L
s
.74175 .54176 m
.74181 .54172 L
s
1 .168 0 r
.43058 .48889 m
.43172 .48993 L
s
.43058 .48889 m
.4321 .48871 L
s
1 .021 0 r
.74167 .54162 m
.74175 .54176 L
s
1 .168 0 r
.4321 .48871 m
.43172 .48993 L
s
1 .233 0 r
.52274 .48877 m
.5245 .48975 L
s
.52274 .48877 m
.52446 .48799 L
s
.53152 .4886 m
.52274 .48877 L
s
1 .168 0 r
.62232 .48891 m
.6227 .48865 L
s
.6227 .48865 m
.62228 .48745 L
s
.6227 .48865 m
.62117 .48854 L
s
1 .003 0 r
.42234 .75269 m
.42234 .7527 L
s
.42235 .75267 m
.42234 .75269 L
s
.42237 .75269 m
.42234 .75269 L
s
.42235 .75268 m
.42235 .75267 L
s
.42235 .75267 m
.42237 .75269 L
s
.42237 .75269 m
.42234 .7527 L
s
.42235 .75268 m
.42237 .75269 L
s
.42226 .75267 m
.42237 .75269 L
s
.42234 .7527 m
.42235 .75268 L
s
.47689 .62064 m
.4768 .62063 L
s
.47682 .62064 m
.47681 .62064 L
s
.47681 .62064 m
.47682 .62062 L
s
.47681 .62064 m
.4768 .62063 L
s
.47682 .62062 m
.47682 .62062 L
s
.47682 .62062 m
.4768 .62063 L
s
.4768 .62063 m
.47682 .62064 L
s
.4768 .62063 m
.47682 .62062 L
s
.47682 .62062 m
.47682 .62064 L
s
1 .168 0 r
.62228 .48745 m
.6219 .48771 L
s
.62228 .48745 m
.62117 .48854 L
s
1 .063 0 r
.6826 .51495 m
.683 .51506 L
s
.68298 .51451 m
.6826 .51495 L
s
.6826 .51495 m
.6828 .51463 L
s
.68319 .51494 m
.6826 .51495 L
s
.68456 .5141 m
.6826 .51495 L
s
1 .168 0 r
.62117 .48854 m
.62232 .48891 L
s
.62117 .48854 m
.6219 .48771 L
s
.62683 .48675 m
.62117 .48854 L
s
1 .063 0 r
.683 .51506 m
.68319 .51494 L
s
.68319 .51494 m
.68298 .51451 L
s
.68298 .51451 m
.6828 .51463 L
s
.6828 .51463 m
.683 .51506 L
s
1 .233 0 r
.52446 .48799 m
.5245 .48975 L
s
1 .168 0 r
.6219 .48771 m
.62232 .48891 L
s
1 .001 0 r
.36445 .72547 m
.36445 .72547 L
s
.36445 .72546 m
.36445 .72547 L
s
.36446 .72547 m
.36445 .72547 L
s
.36445 .72547 m
.36445 .72546 L
s
.36445 .72546 m
.36446 .72547 L
s
.36446 .72547 m
.36445 .72547 L
s
.36445 .72547 m
.36446 .72547 L
s
.36443 .72546 m
.36446 .72547 L
s
.36445 .72547 m
.36445 .72547 L
s
1 0 0 r
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
1 .008 0 r
.41909 .59336 m
.4188 .59329 L
s
.41885 .59334 m
.41884 .59333 L
s
.41884 .59333 m
.41885 .59327 L
s
.41884 .59333 m
.4188 .59329 L
s
.41885 .59327 m
.41887 .59328 L
s
.41885 .59327 m
.4188 .59329 L
s
.4188 .59329 m
.41885 .59334 L
s
.4188 .59329 m
.41887 .59328 L
s
.41887 .59328 m
.41885 .59334 L
s
1 .003 0 r
.57207 .61894 m
.57207 .61894 L
s
.57207 .61894 m
.57207 .61892 L
s
.57207 .61894 m
.57205 .61893 L
s
.57207 .61892 m
.57207 .61892 L
s
.57207 .61892 m
.57205 .61893 L
s
.51757 .75111 m
.51757 .75111 L
s
.51757 .75108 m
.51757 .75111 L
s
.51759 .7511 m
.51757 .75111 L
s
.57205 .61893 m
.57207 .61894 L
s
.57205 .61893 m
.57207 .61892 L
s
.57215 .61892 m
.57205 .61893 L
s
.51757 .75109 m
.51757 .75108 L
s
.51757 .75108 m
.51759 .7511 L
s
.57207 .61892 m
.57207 .61894 L
s
.51759 .7511 m
.51757 .75111 L
s
.51757 .75109 m
.51759 .7511 L
s
.51746 .7511 m
.51759 .7511 L
s
1 .015 0 r
.36122 .56605 m
.36072 .56586 L
s
1 .003 0 r
.51757 .75111 m
.51757 .75109 L
s
1 .015 0 r
.36082 .56597 m
.36078 .56594 L
s
.36078 .56594 m
.36082 .56583 L
s
.36078 .56594 m
.36072 .56586 L
s
.36082 .56583 m
.36087 .56586 L
s
.36082 .56583 m
.36072 .56586 L
s
.36087 .56586 m
.36082 .56597 L
s
.36072 .56586 m
.36082 .56597 L
s
.36072 .56586 m
.36087 .56586 L
s
1 .029 0 r
.77934 .51277 m
.7795 .51279 L
s
.77948 .51254 m
.77934 .51277 L
s
.77934 .51277 m
.77938 .51261 L
s
.77961 .51272 m
.77934 .51277 L
s
.78009 .51227 m
.77934 .51277 L
s
.77948 .51254 m
.77938 .51261 L
s
.77961 .51272 m
.77948 .51254 L
s
.7795 .51279 m
.77961 .51272 L
s
1 .08 0 r
.72015 .4862 m
.72061 .48628 L
s
.72057 .48559 m
.72015 .4862 L
s
.72015 .4862 m
.72029 .48576 L
s
.72088 .48611 m
.72015 .4862 L
s
.72235 .48489 m
.72015 .4862 L
s
1 .029 0 r
.77938 .51261 m
.7795 .51279 L
s
1 .08 0 r
.72057 .48559 m
.72029 .48576 L
s
.72088 .48611 m
.72057 .48559 L
s
.72061 .48628 m
.72088 .48611 L
s
1 .017 0 r
.40537 .85621 m
.40539 .85625 L
s
.40539 .85609 m
.40537 .85621 L
s
.40551 .85619 m
.40537 .85621 L
s
.40541 .85613 m
.40539 .85609 L
s
.40539 .85609 m
.40551 .85619 L
s
.40551 .85619 m
.40539 .85625 L
s
.40541 .85613 m
.40551 .85619 L
s
.4049 .8561 m
.40551 .85619 L
s
.40539 .85625 m
.40541 .85613 L
s
1 .012 0 r
.51398 .59166 m
.51397 .59164 L
s
.51397 .59164 m
.51398 .59155 L
s
.51397 .59164 m
.51389 .5916 L
s
.51398 .59155 m
.51398 .59157 L
s
.51398 .59155 m
.51389 .5916 L
s
1 .001 0 r
.45965 .72387 m
.45965 .72387 L
s
.45965 .72386 m
.45965 .72387 L
s
.45966 .72386 m
.45965 .72387 L
s
.45965 .72386 m
.45965 .72386 L
s
.45965 .72386 m
.45966 .72386 L
s
.45966 .72386 m
.45965 .72387 L
s
.45965 .72386 m
.45966 .72386 L
s
.45962 .72386 m
.45966 .72386 L
s
.45965 .72387 m
.45965 .72386 L
s
1 .012 0 r
.51433 .59161 m
.51389 .5916 L
s
1 .021 0 r
.30329 .53872 m
.30269 .53839 L
s
1 .012 0 r
.51389 .5916 m
.51398 .59166 L
s
.51389 .5916 m
.51398 .59157 L
s
.51398 .59157 m
.51398 .59166 L
s
1 .08 0 r
.72029 .48576 m
.72061 .48628 L
s
1 .021 0 r
.30282 .53836 m
.30289 .53841 L
s
.30274 .5385 m
.30282 .53836 L
s
.30282 .53836 m
.30269 .53839 L
s
.30281 .53855 m
.30274 .5385 L
s
.30274 .5385 m
.30269 .53839 L
s
.30289 .53841 m
.30281 .53855 L
s
.30269 .53839 m
.30289 .53841 L
s
.30269 .53839 m
.30281 .53855 L
s
1 .002 0 r
.66756 .61723 m
.66757 .61722 L
s
.66757 .61722 m
.66756 .61721 L
s
.66757 .61722 m
.66755 .61722 L
s
.66756 .61721 m
.66756 .61721 L
s
.66756 .61721 m
.66755 .61722 L
s
.66755 .61722 m
.66756 .61723 L
s
.66755 .61722 m
.66756 .61721 L
s
.66761 .6172 m
.66755 .61722 L
s
.66756 .61721 m
.66756 .61723 L
s
1 0 0 r
.40171 .69659 m
.40172 .69659 L
s
.40172 .69659 m
.40171 .69659 L
s
.40172 .69659 m
.40171 .69659 L
s
.40172 .69659 m
.40172 .69659 L
s
.40172 .69659 m
.40172 .69659 L
s
.40172 .69659 m
.40172 .69659 L
s
.40172 .69659 m
.40172 .69659 L
s
.40171 .69659 m
.40172 .69659 L
s
.40172 .69659 m
.40172 .69659 L
s
1 .029 0 r
.45645 .56428 m
.45539 .5641 L
s
.4556 .56426 m
.45556 .56422 L
s
.45556 .56422 m
.45561 .56401 L
s
.45556 .56422 m
.45539 .5641 L
s
.45561 .56401 m
.45565 .56405 L
s
.45561 .56401 m
.45539 .5641 L
s
.45539 .5641 m
.4556 .56426 L
s
.45539 .5641 m
.45565 .56405 L
s
.45565 .56405 m
.4556 .56426 L
s
1 .01 0 r
.60949 .58997 m
.60951 .58995 L
s
.60951 .58995 m
.60949 .58988 L
s
.60951 .58995 m
.60942 .58994 L
s
.60949 .58988 m
.60948 .58989 L
s
.60949 .58988 m
.60942 .58994 L
s
.60942 .58994 m
.60949 .58997 L
s
.60942 .58994 m
.60948 .58989 L
s
.60978 .58987 m
.60942 .58994 L
s
.60948 .58989 m
.60949 .58997 L
s
1 .001 0 r
.55505 .72225 m
.55505 .72226 L
s
.55505 .72224 m
.55505 .72225 L
s
.55506 .72225 m
.55505 .72225 L
s
.55505 .72225 m
.55505 .72224 L
s
.55505 .72224 m
.55506 .72225 L
s
.55501 .72225 m
.55506 .72225 L
s
1 0 0 r
.34374 .6693 m
.34374 .6693 L
s
1 .047 0 r
.39852 .53691 m
.39696 .53639 L
s
1 .001 0 r
.55506 .72225 m
.55505 .72226 L
s
.55505 .72225 m
.55506 .72225 L
s
.55505 .72226 m
.55505 .72225 L
s
1 .035 0 r
.81727 .48369 m
.81745 .48371 L
s
.81742 .48341 m
.81727 .48369 L
s
.81727 .48369 m
.81728 .4835 L
s
.81758 .48362 m
.81727 .48369 L
s
.81808 .48303 m
.81727 .48369 L
s
1 .047 0 r
.39726 .5367 m
.39715 .53662 L
s
.39715 .53662 m
.39728 .53629 L
s
.39715 .53662 m
.39696 .53639 L
s
1 .035 0 r
.81742 .48341 m
.81728 .4835 L
s
.81758 .48362 m
.81742 .48341 L
s
1 .047 0 r
.39728 .53629 m
.39739 .53637 L
s
.39728 .53629 m
.39696 .53639 L
s
1 .035 0 r
.81745 .48371 m
.81758 .48362 L
s
.81728 .4835 m
.81745 .48371 L
s
1 .047 0 r
.39696 .53639 m
.39726 .5367 L
s
.39696 .53639 m
.39739 .53637 L
s
.39739 .53637 m
.39726 .5367 L
s
1 .035 0 r
.55085 .56272 m
.55087 .56267 L
s
.55087 .56267 m
.55084 .56241 L
s
.55087 .56267 m
.55058 .56259 L
s
.55084 .56241 m
.55083 .56246 L
s
.55084 .56241 m
.55058 .56259 L
s
1 .014 0 r
.4427 .82749 m
.44271 .82753 L
s
.44272 .82739 m
.4427 .82749 L
s
.44282 .82747 m
.4427 .82749 L
s
1 .035 0 r
.55058 .56259 m
.55085 .56272 L
s
.55058 .56259 m
.55083 .56246 L
s
.55189 .5625 m
.55058 .56259 L
s
1 .014 0 r
.44273 .82742 m
.44272 .82739 L
s
.44272 .82739 m
.44282 .82747 L
s
.44282 .82747 m
.44271 .82753 L
s
.44273 .82742 m
.44282 .82747 L
s
.44229 .82741 m
.44282 .82747 L
s
.44271 .82753 m
.44273 .82742 L
s
1 0 0 r
.4971 .69496 m
.4971 .69496 L
s
.4971 .69496 m
.4971 .69496 L
s
.4971 .69496 m
.4971 .69496 L
s
.4971 .69496 m
.4971 .69496 L
s
.4971 .69496 m
.4971 .69496 L
s
.4971 .69496 m
.4971 .69496 L
s
.4971 .69496 m
.4971 .69496 L
s
.49709 .69496 m
.4971 .69496 L
s
1 .055 0 r
.34051 .50952 m
.33889 .50868 L
s
1 0 0 r
.4971 .69496 m
.4971 .69496 L
s
1 .035 0 r
.55083 .56246 m
.55085 .56272 L
s
1 .055 0 r
.33923 .5086 m
.33941 .50872 L
s
.33903 .50897 m
.33923 .5086 L
s
.33923 .5086 m
.33889 .50868 L
s
.3392 .50909 m
.33903 .50897 L
s
.33903 .50897 m
.33889 .50868 L
s
.33941 .50872 m
.3392 .50909 L
s
.33889 .50868 m
.33941 .50872 L
s
.33889 .50868 m
.3392 .50909 L
s
1 .009 0 r
.38451 .80023 m
.38453 .80025 L
s
.38453 .80016 m
.38451 .80023 L
s
.38459 .80022 m
.38451 .80023 L
s
.38454 .80018 m
.38453 .80016 L
s
.38453 .80016 m
.38459 .80022 L
s
1 .006 0 r
.70526 .58819 m
.7053 .5882 L
s
.70529 .58815 m
.70526 .58819 L
s
.70526 .58819 m
.70528 .58816 L
s
.70531 .58818 m
.70526 .58819 L
s
.70544 .58811 m
.70526 .58819 L
s
.7053 .5882 m
.70531 .58818 L
s
.70531 .58818 m
.70529 .58815 L
s
.70529 .58815 m
.70528 .58816 L
s
1 .009 0 r
.38459 .80022 m
.38453 .80025 L
s
.38454 .80018 m
.38459 .80022 L
s
.38428 .80016 m
.38459 .80022 L
s
1 .006 0 r
.70528 .58816 m
.7053 .5882 L
s
1 .08 0 r
.49155 .53525 m
.4915 .53514 L
s
.4915 .53514 m
.49156 .53455 L
s
.4915 .53514 m
.49096 .53485 L
s
1 .009 0 r
.38453 .80025 m
.38454 .80018 L
s
1 0 0 r
.43911 .66763 m
.43911 .66763 L
s
1 .08 0 r
.49394 .5351 m
.49096 .53485 L
s
1 .055 0 r
.28245 .48209 m
.28107 .4811 L
s
1 .08 0 r
.49156 .53455 m
.49161 .53465 L
s
.49156 .53455 m
.49096 .53485 L
s
.49096 .53485 m
.49155 .53525 L
s
.49096 .53485 m
.49161 .53465 L
s
.49161 .53465 m
.49155 .53525 L
s
1 .023 0 r
.6469 .56101 m
.64695 .56097 L
s
.64695 .56097 m
.6469 .56081 L
s
.64695 .56097 m
.64674 .56096 L
s
1 .055 0 r
.28137 .48106 m
.28157 .48119 L
s
.28112 .4814 m
.28137 .48106 L
s
.28137 .48106 m
.28107 .4811 L
s
1 .023 0 r
.6469 .56081 m
.64684 .56085 L
s
.6469 .56081 m
.64674 .56096 L
s
.64674 .56096 m
.6469 .56101 L
s
.64674 .56096 m
.64684 .56085 L
s
.64754 .56072 m
.64674 .56096 L
s
1 .055 0 r
.28133 .48153 m
.28112 .4814 L
s
.28112 .4814 m
.28107 .4811 L
s
1 .023 0 r
.64684 .56085 m
.6469 .56101 L
s
1 .055 0 r
.28157 .48119 m
.28133 .48153 L
s
.28107 .4811 m
.28157 .48119 L
s
.28107 .4811 m
.28133 .48153 L
s
1 0 0 r
.59268 .69332 m
.59268 .69331 L
s
.38107 .64028 m
.38106 .64027 L
s
1 .121 0 r
.43593 .50768 m
.4317 .50655 L
s
1 0 0 r
.59268 .69332 m
.59268 .69332 L
s
.59268 .69331 m
.59268 .69332 L
s
.59268 .69331 m
.59268 .69332 L
s
.59268 .69331 m
.59268 .69331 L
s
.59268 .69331 m
.59268 .69331 L
s
.59268 .69331 m
.59268 .69332 L
s
.59268 .69331 m
.59268 .69331 L
s
.38106 .64028 m
.38106 .64028 L
s
.38106 .64028 m
.38106 .64027 L
s
.38106 .64028 m
.38106 .64027 L
s
.59268 .69332 m
.59268 .69331 L
s
.38106 .64027 m
.38106 .64027 L
s
.38106 .64027 m
.38106 .64027 L
s
.38106 .64027 m
.38106 .64028 L
s
.38106 .64027 m
.38106 .64027 L
s
.38106 .64027 m
.38106 .64028 L
s
1 .075 0 r
.58741 .534 m
.58752 .5339 L
s
.58752 .5339 m
.5874 .53335 L
s
.58752 .5339 m
.58686 .53377 L
s
.5874 .53335 m
.5873 .53345 L
s
.5874 .53335 m
.58686 .53377 L
s
.58686 .53377 m
.58741 .534 L
s
.58686 .53377 m
.5873 .53345 L
s
.58958 .53329 m
.58686 .53377 L
s
1 .121 0 r
.43253 .50731 m
.43229 .50713 L
s
.43229 .50713 m
.43256 .50625 L
s
.43229 .50713 m
.4317 .50655 L
s
.43256 .50625 m
.4328 .50643 L
s
.43256 .50625 m
.4317 .50655 L
s
1 .075 0 r
.5873 .53345 m
.58741 .534 L
s
1 .011 0 r
.48013 .79868 m
.48013 .7987 L
s
.48013 .7986 m
.48013 .79868 L
s
.48022 .79865 m
.48013 .79868 L
s
.48014 .79862 m
.48013 .7986 L
s
.48013 .7986 m
.48022 .79865 L
s
.48022 .79865 m
.48013 .7987 L
s
.48014 .79862 m
.48022 .79865 L
s
.4798 .79863 m
.48022 .79865 L
s
1 0 0 r
.53469 .66596 m
.53469 .66596 L
s
1 .134 0 r
.37786 .48022 m
.3738 .47829 L
s
1 .001 0 r
.32297 .61289 m
.32293 .61288 L
s
1 .011 0 r
.48013 .7987 m
.48014 .79862 L
s
1 .001 0 r
.32293 .61288 m
.32293 .61288 L
s
.32293 .61288 m
.32293 .61287 L
s
.32293 .61288 m
.32293 .61288 L
s
.32293 .61287 m
.32294 .61288 L
s
.32293 .61287 m
.32293 .61288 L
s
.32294 .61288 m
.32293 .61288 L
s
.32293 .61288 m
.32293 .61288 L
s
.32293 .61288 m
.32294 .61288 L
s
1 .121 0 r
.4317 .50655 m
.43253 .50731 L
s
.4317 .50655 m
.4328 .50643 L
s
.4328 .50643 m
.43253 .50731 L
s
1 .172 0 r
.52634 .50669 m
.52637 .50648 L
s
.52637 .50648 m
.52634 .50518 L
s
.52637 .50648 m
.52504 .50596 L
s
.52634 .50518 m
.52631 .50539 L
s
.52634 .50518 m
.52504 .50596 L
s
1 .011 0 r
.74306 .5591 m
.74312 .55912 L
s
.74312 .55902 m
.74306 .5591 L
s
.74306 .5591 m
.74308 .55904 L
s
.74316 .55909 m
.74306 .5591 L
s
.74339 .55893 m
.74306 .5591 L
s
.74312 .55902 m
.74308 .55904 L
s
.74316 .55909 m
.74312 .55902 L
s
.74312 .55912 m
.74316 .55909 L
s
1 .172 0 r
.52504 .50596 m
.52634 .50669 L
s
.52504 .50596 m
.52631 .50539 L
s
.53155 .50583 m
.52504 .50596 L
s
1 .011 0 r
.74308 .55904 m
.74312 .55912 L
s
1 .006 0 r
.42189 .77136 m
.4219 .77137 L
s
.4219 .77131 m
.42189 .77136 L
s
.42195 .77135 m
.42189 .77136 L
s
.42191 .77133 m
.4219 .77131 L
s
.4219 .77131 m
.42195 .77135 L
s
.42195 .77135 m
.4219 .77137 L
s
.42191 .77133 m
.42195 .77135 L
s
.42171 .77132 m
.42195 .77135 L
s
.4219 .77137 m
.42191 .77133 L
s
1 0 0 r
.47663 .63858 m
.47662 .63857 L
s
.47662 .63858 m
.47662 .63858 L
s
.47662 .63858 m
.47662 .63857 L
s
.47662 .63858 m
.47662 .63857 L
s
.47662 .63857 m
.47662 .63857 L
s
.47662 .63857 m
.47662 .63857 L
s
.47662 .63857 m
.47662 .63858 L
s
.47662 .63857 m
.47662 .63857 L
s
.47662 .63857 m
.47662 .63858 L
s
1 .134 0 r
.37458 .47926 m
.37417 .47901 L
s
.37417 .47901 m
.37464 .47809 L
s
.37417 .47901 m
.3738 .47829 L
s
.37464 .47809 m
.37504 .47834 L
s
.37464 .47809 m
.3738 .47829 L
s
1 .172 0 r
.52631 .50539 m
.52634 .50669 L
s
1 .04 0 r
.68416 .53202 m
.68442 .53209 L
s
.6844 .53173 m
.68416 .53202 L
s
.68416 .53202 m
.68429 .53181 L
s
.68454 .53201 m
.68416 .53202 L
s
.68541 .53147 m
.68416 .53202 L
s
.68442 .53209 m
.68454 .53201 L
s
.68454 .53201 m
.6844 .53173 L
s
.6844 .53173 m
.68429 .53181 L
s
1 .121 0 r
.6241 .50555 m
.62438 .50536 L
s
.62438 .50536 m
.62407 .50449 L
s
.62438 .50536 m
.62326 .50528 L
s
.62407 .50449 m
.62379 .50468 L
s
.62407 .50449 m
.62326 .50528 L
s
.62326 .50528 m
.6241 .50555 L
s
.62326 .50528 m
.62379 .50468 L
s
.62738 .50399 m
.62326 .50528 L
s
1 .293 0 r
.56067 .47906 m
.56103 .47871 L
s
.56103 .47871 m
.56064 .47652 L
s
.56103 .47871 m
.5585 .47812 L
s
1 .04 0 r
.68429 .53181 m
.68442 .53209 L
s
1 .293 0 r
.56064 .47652 m
.56028 .47688 L
s
.56064 .47652 m
.5585 .47812 L
s
1 .003 0 r
.36364 .744 m
.36364 .744 L
s
.36364 .74398 m
.36364 .744 L
s
.36366 .74399 m
.36364 .744 L
s
.36365 .74398 m
.36364 .74398 L
s
.36364 .74398 m
.36366 .74399 L
s
.36366 .74399 m
.36364 .744 L
s
.36365 .74398 m
.36366 .74399 L
s
.36357 .74397 m
.36366 .74399 L
s
.36364 .744 m
.36365 .74398 L
s
1 .134 0 r
.37504 .47834 m
.37458 .47926 L
s
.3738 .47829 m
.37458 .47926 L
s
1 0 0 r
.63046 .66429 m
.63046 .66429 L
s
1 .271 0 r
.47347 .47835 m
.46358 .4766 L
s
1 .003 0 r
.41852 .61116 m
.41843 .61114 L
s
1 .134 0 r
.3738 .47829 m
.37504 .47834 L
s
1 .003 0 r
.41844 .61116 m
.41844 .61115 L
s
.41844 .61115 m
.41845 .61113 L
s
.41844 .61115 m
.41843 .61114 L
s
.41845 .61113 m
.41845 .61114 L
s
.41845 .61113 m
.41843 .61114 L
s
.41843 .61114 m
.41844 .61116 L
s
.41843 .61114 m
.41845 .61114 L
s
.41845 .61114 m
.41844 .61116 L
s
1 .121 0 r
.62379 .50468 m
.6241 .50555 L
s
1 .293 0 r
.5585 .47812 m
.56067 .47906 L
s
.5585 .47812 m
.56028 .47688 L
s
.56928 .47647 m
.5585 .47812 L
s
1 .271 0 r
.46554 .47813 m
.46517 .47779 L
s
.46517 .47779 m
.46558 .47578 L
s
.46517 .47779 m
.46358 .4766 L
s
.46558 .47578 m
.46595 .47611 L
s
.46558 .47578 m
.46358 .4766 L
s
1 .008 0 r
.51765 .76978 m
.51766 .76979 L
s
.51766 .76972 m
.51765 .76978 L
s
.51771 .76976 m
.51765 .76978 L
s
.51766 .76973 m
.51766 .76972 L
s
.51766 .76972 m
.51771 .76976 L
s
.51771 .76976 m
.51766 .76979 L
s
.51766 .76973 m
.51771 .76976 L
s
.51742 .76975 m
.51771 .76976 L
s
1 0 0 r
.57239 .63687 m
.57239 .63687 L
s
.57239 .63687 m
.57239 .63687 L
s
.57239 .63687 m
.57239 .63687 L
s
.57239 .63687 m
.57239 .63687 L
s
.57239 .63687 m
.57239 .63687 L
s
.57239 .63687 m
.57239 .63687 L
s
.57239 .63687 m
.57239 .63687 L
s
.5724 .63687 m
.57239 .63687 L
s
.57239 .63687 m
.57239 .63687 L
s
1 .007 0 r
.36034 .58372 m
.36012 .58363 L
s
1 .008 0 r
.51766 .76979 m
.51766 .76973 L
s
1 .007 0 r
.36016 .58368 m
.36014 .58367 L
s
.36014 .58367 m
.36016 .58362 L
s
.36014 .58367 m
.36012 .58363 L
s
.36016 .58362 m
.36018 .58363 L
s
.36016 .58362 m
.36012 .58363 L
s
.36018 .58363 m
.36016 .58368 L
s
.36012 .58363 m
.36016 .58368 L
s
.36012 .58363 m
.36018 .58363 L
s
1 .293 0 r
.56028 .47688 m
.56067 .47906 L
s
1 .158 0 r
.66051 .47689 m
.66149 .47712 L
s
.66144 .47574 m
.66051 .47689 L
s
.66051 .47689 m
.66095 .47604 L
s
.66198 .47682 m
.66051 .47689 L
s
.6653 .47459 m
.66051 .47689 L
s
.66149 .47712 m
.66198 .47682 L
s
.66198 .47682 m
.66144 .47574 L
s
.66144 .47574 m
.66095 .47604 L
s
1 .018 0 r
.78099 .52996 m
.78109 .52998 L
s
.78108 .52982 m
.78099 .52996 L
s
.78099 .52996 m
.78101 .52986 L
s
.78116 .52993 m
.78099 .52996 L
s
.78146 .52965 m
.78099 .52996 L
s
.78108 .52982 m
.78101 .52986 L
s
.78116 .52993 m
.78108 .52982 L
s
.78109 .52998 m
.78116 .52993 L
s
.78101 .52986 m
.78109 .52998 L
s
1 .271 0 r
.46358 .4766 m
.46554 .47813 L
s
.46358 .4766 m
.46595 .47611 L
s
1 .004 0 r
.45938 .7424 m
.45938 .74241 L
s
.45938 .74237 m
.45938 .7424 L
s
.45941 .74239 m
.45938 .7424 L
s
.45938 .74238 m
.45938 .74237 L
s
.45938 .74237 m
.45941 .74239 L
s
.45941 .74239 m
.45938 .74241 L
s
.45938 .74238 m
.45941 .74239 L
s
.45927 .74238 m
.45941 .74239 L
s
.51416 .60944 m
.51416 .60943 L
s
.51416 .60943 m
.51416 .60941 L
s
.51416 .60943 m
.51413 .60942 L
s
.51416 .60941 m
.51416 .60941 L
s
.51416 .60941 m
.51413 .60942 L
s
.45938 .74241 m
.45938 .74238 L
s
.51427 .60943 m
.51413 .60942 L
s
1 .011 0 r
.3021 .55624 m
.30178 .55607 L
s
1 .004 0 r
.51413 .60942 m
.51416 .60944 L
s
.51413 .60942 m
.51416 .60941 L
s
.51416 .60941 m
.51416 .60944 L
s
1 .055 0 r
.72187 .50304 m
.72219 .5031 L
s
.72216 .50262 m
.72187 .50304 L
s
.72187 .50304 m
.72197 .50274 L
s
.72238 .50298 m
.72187 .50304 L
s
.72341 .50214 m
.72187 .50304 L
s
.72216 .50262 m
.72197 .50274 L
s
.72238 .50298 m
.72216 .50262 L
s
.72219 .5031 m
.72238 .50298 L
s
1 .011 0 r
.30184 .55605 m
.30188 .55608 L
s
.3018 .55613 m
.30184 .55605 L
s
.30184 .55605 m
.30178 .55607 L
s
.30184 .55615 m
.3018 .55613 L
s
.3018 .55613 m
.30178 .55607 L
s
1 .271 0 r
.46595 .47611 m
.46554 .47813 L
s
1 .011 0 r
.30188 .55608 m
.30184 .55615 L
s
.30178 .55607 m
.30188 .55608 L
s
.30178 .55607 m
.30184 .55615 L
s
1 .055 0 r
.72197 .50274 m
.72219 .5031 L
s
1 .158 0 r
.66095 .47604 m
.66149 .47712 L
s
1 .001 0 r
.40108 .71499 m
.40108 .71499 L
s
.40108 .71498 m
.40108 .71499 L
s
.40109 .71499 m
.40108 .71499 L
s
.40108 .71498 m
.40108 .71498 L
s
.40108 .71498 m
.40109 .71499 L
s
.40109 .71499 m
.40108 .71499 L
s
.40108 .71498 m
.40109 .71499 L
s
.40105 .71498 m
.40109 .71499 L
s
.40108 .71499 m
.40108 .71498 L
s
1 0 0 r
.66837 .63517 m
.66837 .63516 L
s
.66837 .63516 m
.66837 .63516 L
s
.66837 .63516 m
.66837 .63516 L
s
.66837 .63516 m
.66837 .63516 L
s
.66837 .63516 m
.66837 .63516 L
s
.66837 .63516 m
.66837 .63517 L
s
.66837 .63516 m
.66837 .63516 L
s
.66837 .63516 m
.66837 .63516 L
s
.66837 .63516 m
.66837 .63517 L
s
1 .013 0 r
.45609 .58195 m
.4556 .58187 L
s
.4557 .58195 m
.45568 .58193 L
s
.45568 .58193 m
.4557 .58183 L
s
.45568 .58193 m
.4556 .58187 L
s
.4557 .58183 m
.45572 .58185 L
s
.4557 .58183 m
.4556 .58187 L
s
.4556 .58187 m
.4557 .58195 L
s
.4556 .58187 m
.45572 .58185 L
s
.45572 .58185 m
.4557 .58195 L
s
1 .003 0 r
.61015 .60772 m
.61015 .60771 L
s
.61015 .60771 m
.61015 .60769 L
s
.61015 .60771 m
.61012 .60771 L
s
.61015 .60769 m
.61014 .6077 L
s
.61015 .60769 m
.61012 .60771 L
s
.61012 .60771 m
.61015 .60772 L
s
.61012 .60771 m
.61014 .6077 L
s
.61024 .60769 m
.61012 .60771 L
s
.61014 .6077 m
.61015 .60772 L
s
1 .004 0 r
.5553 .74079 m
.5553 .7408 L
s
.5553 .74076 m
.5553 .74079 L
s
.55533 .74078 m
.5553 .74079 L
s
.5553 .74077 m
.5553 .74076 L
s
.5553 .74076 m
.55533 .74078 L
s
1 0 0 r
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
1 .004 0 r
.55517 .74078 m
.55533 .74078 L
s
1 .026 0 r
.39784 .55445 m
.39696 .55416 L
s
1 .004 0 r
.55533 .74078 m
.5553 .7408 L
s
.5553 .74077 m
.55533 .74078 L
s
.5553 .7408 m
.5553 .74077 L
s
1 .026 0 r
.39713 .55434 m
.39707 .55429 L
s
.39707 .55429 m
.39714 .5541 L
s
.39707 .55429 m
.39696 .55416 L
s
.39714 .5541 m
.3972 .55415 L
s
.39714 .5541 m
.39696 .55416 L
s
.39696 .55416 m
.39713 .55434 L
s
.39696 .55416 m
.3972 .55415 L
s
.3972 .55415 m
.39713 .55434 L
s
1 .023 0 r
.8191 .50073 m
.81922 .50074 L
s
.8192 .50054 m
.8191 .50073 L
s
.8191 .50073 m
.81911 .5006 L
s
.81931 .50068 m
.8191 .50073 L
s
.81965 .50028 m
.8191 .50073 L
s
.8192 .50054 m
.81911 .5006 L
s
.81931 .50068 m
.8192 .50054 L
s
.81922 .50074 m
.81931 .50068 L
s
.81911 .5006 m
.81922 .50074 L
s
1 .066 0 r
.75993 .47393 m
.76027 .47397 L
s
.76023 .4734 m
.75993 .47393 L
s
.75993 .47393 m
.75998 .47356 L
s
.76053 .47381 m
.75993 .47393 L
s
.76153 .47271 m
.75993 .47393 L
s
.76023 .4734 m
.75998 .47356 L
s
.76053 .47381 m
.76023 .4734 L
s
.76027 .47397 m
.76053 .47381 L
s
1 .022 0 r
.44247 .84664 m
.44249 .84669 L
s
.44249 .84648 m
.44247 .84664 L
s
.44265 .8466 m
.44247 .84664 L
s
.44251 .84653 m
.44249 .84648 L
s
.44249 .84648 m
.44265 .8466 L
s
.44265 .8466 m
.44249 .84669 L
s
.44251 .84653 m
.44265 .8466 L
s
.44184 .84652 m
.44265 .8466 L
s
1 .016 0 r
.55155 .58029 m
.55156 .58026 L
s
.55156 .58026 m
.55155 .58014 L
s
.55156 .58026 m
.55143 .58022 L
s
.55155 .58014 m
.55155 .58017 L
s
.55155 .58014 m
.55143 .58022 L
s
.55143 .58022 m
.55155 .58029 L
s
.55143 .58022 m
.55155 .58017 L
s
.55204 .58018 m
.55143 .58022 L
s
1 .022 0 r
.44249 .84669 m
.44251 .84653 L
s
1 .002 0 r
.49699 .71336 m
.49699 .71336 L
s
.49699 .71335 m
.49699 .71336 L
s
.497 .71335 m
.49699 .71336 L
s
.49699 .71335 m
.49699 .71335 L
s
.49699 .71335 m
.497 .71335 L
s
.497 .71335 m
.49699 .71336 L
s
.49699 .71335 m
.497 .71335 L
s
.49694 .71335 m
.497 .71335 L
s
1 .035 0 r
.33952 .52692 m
.33849 .52639 L
s
1 .002 0 r
.49699 .71336 m
.49699 .71335 L
s
1 .016 0 r
.55155 .58017 m
.55155 .58029 L
s
1 .066 0 r
.75998 .47356 m
.76027 .47397 L
s
1 .035 0 r
.33871 .52634 m
.33882 .52641 L
s
.33858 .52658 m
.33871 .52634 L
s
.33871 .52634 m
.33849 .52639 L
s
.33869 .52665 m
.33858 .52658 L
s
.33858 .52658 m
.33849 .52639 L
s
.33882 .52641 m
.33869 .52665 L
s
.33849 .52639 m
.33882 .52641 L
s
.33849 .52639 m
.33869 .52665 L
s
1 .014 0 r
.38391 .81924 m
.38393 .81927 L
s
.38394 .81913 m
.38391 .81924 L
s
.38404 .81922 m
.38391 .81924 L
s
.38396 .81917 m
.38394 .81913 L
s
.38394 .81913 m
.38404 .81922 L
s
.38404 .81922 m
.38393 .81927 L
s
.38396 .81917 m
.38404 .81922 L
s
.38352 .81913 m
.38404 .81922 L
s
.38393 .81927 m
.38396 .81917 L
s
1 .046 0 r
.4924 .55274 m
.49237 .55267 L
s
.49237 .55267 m
.4924 .55233 L
s
.49237 .55267 m
.49206 .5525 L
s
1 .002 0 r
.70635 .60597 m
.70636 .60597 L
s
.70636 .60596 m
.70635 .60597 L
s
.70635 .60597 m
.70636 .60596 L
s
.70637 .60597 m
.70635 .60597 L
s
.7064 .60595 m
.70635 .60597 L
s
.70636 .60597 m
.70637 .60597 L
s
.70637 .60597 m
.70636 .60596 L
s
.70636 .60596 m
.70636 .60596 L
s
.70636 .60596 m
.70636 .60597 L
s
1 0 0 r
.43866 .68589 m
.43866 .68589 L
s
.43866 .68589 m
.43866 .68589 L
s
.43866 .68589 m
.43866 .68589 L
s
.43866 .68589 m
.43866 .68589 L
s
.43866 .68589 m
.43866 .68589 L
s
.43866 .68589 m
.43866 .68589 L
s
.43866 .68589 m
.43866 .68589 L
s
.43865 .68589 m
.43866 .68589 L
s
.43866 .68589 m
.43866 .68589 L
s
1 .046 0 r
.49378 .55265 m
.49206 .5525 L
s
1 .038 0 r
.28115 .49935 m
.2802 .49868 L
s
1 .046 0 r
.4924 .55233 m
.49243 .55239 L
s
.4924 .55233 m
.49206 .5525 L
s
.49206 .5525 m
.4924 .55274 L
s
.49206 .5525 m
.49243 .55239 L
s
.49243 .55239 m
.4924 .55274 L
s
1 .038 0 r
.2804 .49865 m
.28054 .49874 L
s
.28024 .49889 m
.2804 .49865 L
s
.2804 .49865 m
.2802 .49868 L
s
.28038 .49898 m
.28024 .49889 L
s
.28024 .49889 m
.2802 .49868 L
s
.28054 .49874 m
.28038 .49898 L
s
.2802 .49868 m
.28054 .49874 L
s
.2802 .49868 m
.28038 .49898 L
s
1 .011 0 r
.64791 .57854 m
.64793 .57853 L
s
.64793 .57853 m
.6479 .57845 L
s
.64793 .57853 m
.64783 .57852 L
s
.6479 .57845 m
.64788 .57847 L
s
.6479 .57845 m
.64783 .57852 L
s
.64783 .57852 m
.64791 .57854 L
s
.64783 .57852 m
.64788 .57847 L
s
.64819 .57841 m
.64783 .57852 L
s
.64788 .57847 m
.64791 .57854 L
s
1 .002 0 r
.59304 .71172 m
.5931 .71172 L
s
1 0 0 r
.3803 .6584 m
.3803 .6584 L
s
1 .08 0 r
.43545 .52509 m
.43266 .52435 L
s
1 .002 0 r
.59309 .71172 m
.59308 .71172 L
s
.59308 .71171 m
.59309 .71172 L
s
.5931 .71172 m
.59309 .71172 L
s
.59308 .71171 m
.59308 .71171 L
s
.59308 .71171 m
.5931 .71172 L
s
.5931 .71172 m
.59308 .71172 L
s
.59308 .71171 m
.5931 .71172 L
s
.59308 .71172 m
.59308 .71171 L
s
1 .08 0 r
.43321 .52485 m
.43305 .52473 L
s
.43305 .52473 m
.43323 .52415 L
s
.43305 .52473 m
.43266 .52435 L
s
1 .028 0 r
.8574 .47139 m
.85752 .47139 L
s
.8575 .47115 m
.8574 .47139 L
s
.8574 .47139 m
.85738 .47123 L
s
.85764 .47131 m
.8574 .47139 L
s
.85796 .47082 m
.8574 .47139 L
s
1 .08 0 r
.43323 .52415 m
.43339 .52427 L
s
.43323 .52415 m
.43266 .52435 L
s
1 .028 0 r
.8575 .47115 m
.85738 .47123 L
s
.85764 .47131 m
.8575 .47115 L
s
.85752 .47139 m
.85764 .47131 L
s
.85738 .47123 m
.85752 .47139 L
s
1 .043 0 r
.58868 .55125 m
.58874 .55119 L
s
.58874 .55119 m
.58867 .55088 L
s
.58874 .55119 m
.58837 .55112 L
s
.58867 .55088 m
.58861 .55094 L
s
.58867 .55088 m
.58837 .55112 L
s
.58837 .55112 m
.58868 .55125 L
s
.58837 .55112 m
.58861 .55094 L
s
.58992 .55085 m
.58837 .55112 L
s
1 .08 0 r
.43266 .52435 m
.43321 .52485 L
s
.43266 .52435 m
.43339 .52427 L
s
.43339 .52427 m
.43321 .52485 L
s
1 .043 0 r
.58861 .55094 m
.58868 .55125 L
s
1 .018 0 r
.4801 .81769 m
.48011 .81773 L
s
.48011 .81756 m
.4801 .81769 L
s
.48025 .81765 m
.4801 .81769 L
s
.48012 .8176 m
.48011 .81756 L
s
.48011 .81756 m
.48025 .81765 L
s
.48025 .81765 m
.48011 .81773 L
s
.48012 .8176 m
.48025 .81765 L
s
.47955 .81761 m
.48025 .81765 L
s
1 0 0 r
.53474 .68423 m
.53474 .68423 L
s
.53474 .68423 m
.53474 .68423 L
s
.53475 .68423 m
.53474 .68423 L
s
.53474 .68423 m
.53474 .68423 L
s
.53474 .68423 m
.53475 .68423 L
s
.53474 .68423 m
.53475 .68423 L
s
1 .095 0 r
.37706 .49749 m
.37416 .49612 L
s
1 0 0 r
.32188 .63088 m
.32187 .63087 L
s
.53475 .68423 m
.53474 .68423 L
s
.53474 .68423 m
.53475 .68423 L
s
.53474 .68423 m
.53474 .68423 L
s
.32187 .63088 m
.32187 .63087 L
s
.32187 .63087 m
.32187 .63087 L
s
.32187 .63087 m
.32187 .63087 L
s
.32187 .63087 m
.32187 .63087 L
s
.32187 .63087 m
.32187 .63087 L
s
.32187 .63087 m
.32187 .63088 L
s
.32187 .63087 m
.32187 .63088 L
s
.32187 .63087 m
.32187 .63087 L
s
1 .018 0 r
.48011 .81773 m
.48012 .8176 L
s
1 .116 0 r
.52807 .52383 m
.52808 .52369 L
s
.52808 .52369 m
.52806 .52281 L
s
.52808 .52369 m
.52718 .52334 L
s
.52806 .52281 m
.52804 .52295 L
s
.52806 .52281 m
.52718 .52334 L
s
1 .012 0 r
.42149 .79024 m
.4215 .79027 L
s
.42151 .79015 m
.42149 .79024 L
s
.42159 .79022 m
.42149 .79024 L
s
.42152 .79018 m
.42151 .79015 L
s
.42151 .79015 m
.42159 .79022 L
s
1 .116 0 r
.52718 .52334 m
.52807 .52383 L
s
.52718 .52334 m
.52804 .52295 L
s
.53159 .52325 m
.52718 .52334 L
s
1 .005 0 r
.74441 .57671 m
.74444 .57672 L
s
.74444 .57667 m
.74441 .57671 L
s
.74441 .57671 m
.74442 .57668 L
s
.74446 .57671 m
.74441 .57671 L
s
.74456 .57663 m
.74441 .57671 L
s
1 .012 0 r
.42159 .79022 m
.4215 .79027 L
s
.42152 .79018 m
.42159 .79022 L
s
.42116 .79016 m
.42159 .79022 L
s
1 .005 0 r
.74444 .57667 m
.74442 .57668 L
s
.74446 .57671 m
.74444 .57667 L
s
.74444 .57672 m
.74446 .57671 L
s
1 .095 0 r
.37472 .49682 m
.37443 .49663 L
s
.37443 .49663 m
.37476 .49598 L
s
.37443 .49663 m
.37416 .49612 L
s
.37476 .49598 m
.37505 .49616 L
s
.37476 .49598 m
.37416 .49612 L
s
1 .005 0 r
.74442 .57668 m
.74444 .57672 L
s
1 .012 0 r
.4215 .79027 m
.42152 .79018 L
s
1 0 0 r
.47637 .65671 m
.47637 .65671 L
s
1 .091 0 r
.31861 .46987 m
.3163 .46823 L
s
1 .116 0 r
.52804 .52295 m
.52807 .52383 L
s
1 .095 0 r
.37505 .49616 m
.37472 .49682 L
s
.37416 .49612 m
.37472 .49682 L
s
.37416 .49612 m
.37505 .49616 L
s
1 .022 0 r
.68558 .54934 m
.68572 .54938 L
s
.68571 .54918 m
.68558 .54934 L
s
.68558 .54934 m
.68565 .54922 L
s
.68579 .54933 m
.68558 .54934 L
s
.68627 .54904 m
.68558 .54934 L
s
.68572 .54938 m
.68579 .54933 L
s
.68579 .54933 m
.68571 .54918 L
s
.68571 .54918 m
.68565 .54922 L
s
.68565 .54922 m
.68572 .54938 L
s
1 .006 0 r
.36285 .76274 m
.36287 .76275 L
s
.36287 .76269 m
.36285 .76274 L
s
.36291 .76273 m
.36285 .76274 L
s
.36288 .76271 m
.36287 .76269 L
s
.36287 .76269 m
.36291 .76273 L
s
.36291 .76273 m
.36287 .76275 L
s
.36288 .76271 m
.36291 .76273 L
s
.3627 .76268 m
.36291 .76273 L
s
.36287 .76275 m
.36288 .76271 L
s
1 0 0 r
.63103 .68257 m
.63104 .68256 L
s
.41794 .62915 m
.41793 .62915 L
s
1 .202 0 r
.47319 .49563 m
.46577 .49433 L
s
1 0 0 r
.63104 .68256 m
.63104 .68257 L
s
.63104 .68256 m
.63104 .68256 L
s
.63104 .68256 m
.63104 .68256 L
s
.63104 .68256 m
.63104 .68256 L
s
.63104 .68256 m
.63104 .68256 L
s
.41793 .62915 m
.41793 .62915 L
s
.41793 .62915 m
.41793 .62915 L
s
.41793 .62915 m
.41793 .62915 L
s
.41793 .62915 m
.41793 .62915 L
s
.41793 .62915 m
.41793 .62915 L
s
.63104 .68256 m
.63104 .68257 L
s
.63104 .68256 m
.63104 .68256 L
s
.63104 .68257 m
.63104 .68256 L
s
.41793 .62915 m
.41793 .62915 L
s
.41793 .62915 m
.41793 .62915 L
s
.41793 .62915 m
.41793 .62915 L
s
1 .08 0 r
.62576 .52244 m
.62595 .52231 L
s
.62595 .52231 m
.62574 .52174 L
s
.62595 .52231 m
.62521 .52226 L
s
.62574 .52174 m
.62556 .52187 L
s
.62574 .52174 m
.62521 .52226 L
s
.62521 .52226 m
.62576 .52244 L
s
.62521 .52226 m
.62556 .52187 L
s
.62793 .52141 m
.62521 .52226 L
s
1 .091 0 r
.31679 .46817 m
.31713 .46838 L
s
.31639 .46874 m
.31679 .46817 L
s
.31679 .46817 m
.3163 .46823 L
s
.31673 .46896 m
.31639 .46874 L
s
.31639 .46874 m
.3163 .46823 L
s
1 .22 0 r
.56301 .49571 m
.56328 .49543 L
s
.56328 .49543 m
.56299 .49378 L
s
.56328 .49543 m
.56137 .49499 L
s
.56299 .49378 m
.56272 .49406 L
s
.56299 .49378 m
.56137 .49499 L
s
1 .202 0 r
.46724 .49548 m
.46696 .49521 L
s
.46696 .49521 m
.46727 .4937 L
s
.46696 .49521 m
.46577 .49433 L
s
1 .08 0 r
.62556 .52187 m
.62576 .52244 L
s
1 .091 0 r
.31713 .46838 m
.31673 .46896 L
s
.3163 .46823 m
.31713 .46838 L
s
1 .202 0 r
.46727 .4937 m
.46755 .49397 L
s
.46727 .4937 m
.46577 .49433 L
s
1 .091 0 r
.3163 .46823 m
.31673 .46896 L
s
1 .22 0 r
.56137 .49499 m
.56301 .49571 L
s
.56137 .49499 m
.56272 .49406 L
s
.56952 .49376 m
.56137 .49499 L
s
1 .014 0 r
.51782 .78865 m
.51782 .78868 L
s
.51782 .78855 m
.51782 .78865 L
s
.51793 .78862 m
.51782 .78865 L
s
.51782 .78858 m
.51782 .78855 L
s
.51782 .78855 m
.51793 .78862 L
s
.51793 .78862 m
.51782 .78868 L
s
.51782 .78858 m
.51793 .78862 L
s
.51738 .78861 m
.51793 .78862 L
s
1 0 0 r
.57265 .65501 m
.57265 .65501 L
s
1 .233 0 r
.41473 .46798 m
.40724 .46491 L
s
1 .002 0 r
.35945 .60157 m
.35938 .60155 L
s
.3594 .60156 m
.35939 .60156 L
s
.35939 .60156 m
.3594 .60154 L
s
.35939 .60156 m
.35938 .60155 L
s
.3594 .60154 m
.3594 .60155 L
s
.3594 .60154 m
.35938 .60155 L
s
.3594 .60155 m
.3594 .60156 L
s
.35938 .60155 m
.3594 .60156 L
s
.35938 .60155 m
.3594 .60155 L
s
1 .014 0 r
.51782 .78868 m
.51782 .78858 L
s
1 .318 0 r
.59895 .46834 m
.5997 .46787 L
s
.5997 .46787 m
.59889 .46557 L
s
.5997 .46787 m
.59676 .46765 L
s
.59889 .46557 m
.59813 .46604 L
s
.59889 .46557 m
.59676 .46765 L
s
.59676 .46765 m
.59895 .46834 L
s
.59676 .46765 m
.59813 .46604 L
s
.60758 .46417 m
.59676 .46765 L
s
1 .202 0 r
.46577 .49433 m
.46724 .49548 L
s
.46577 .49433 m
.46755 .49397 L
s
1 .22 0 r
.56272 .49406 m
.56301 .49571 L
s
1 .202 0 r
.46755 .49397 m
.46724 .49548 L
s
1 .01 0 r
.78258 .54739 m
.78264 .5474 L
s
.78263 .54732 m
.78258 .54739 L
s
.78258 .54739 m
.7826 .54734 L
s
.78267 .54738 m
.78258 .54739 L
s
.78284 .54723 m
.78258 .54739 L
s
.78263 .54732 m
.7826 .54734 L
s
.78267 .54738 m
.78263 .54732 L
s
.78264 .5474 m
.78267 .54738 L
s
.7826 .54734 m
.78264 .5474 L
s
1 .009 0 r
.45916 .76115 m
.45917 .76117 L
s
.45917 .76108 m
.45916 .76115 L
s
.45924 .76113 m
.45916 .76115 L
s
.45918 .7611 m
.45917 .76108 L
s
.45917 .76108 m
.45924 .76113 L
s
.45924 .76113 m
.45917 .76117 L
s
.45918 .7611 m
.45924 .76113 L
s
.45891 .7611 m
.45924 .76113 L
s
.45917 .76117 m
.45918 .7611 L
s
1 0 0 r
.5142 .62743 m
.5142 .62743 L
s
.5142 .62743 m
.5142 .62743 L
s
.5142 .62743 m
.5142 .62743 L
s
.5142 .62743 m
.5142 .62743 L
s
.5142 .62743 m
.5142 .62743 L
s
.51422 .62743 m
.5142 .62743 L
s
1 .005 0 r
.3009 .57396 m
.30075 .57388 L
s
1 0 0 r
.5142 .62743 m
.5142 .62743 L
s
.5142 .62743 m
.5142 .62743 L
s
.5142 .62743 m
.5142 .62743 L
s
1 .005 0 r
.30078 .57388 m
.3008 .57389 L
s
.30076 .57391 m
.30078 .57388 L
s
.30078 .57388 m
.30075 .57388 L
s
.30078 .57392 m
.30076 .57391 L
s
.30076 .57391 m
.30075 .57388 L
s
.3008 .57389 m
.30078 .57392 L
s
.30075 .57388 m
.3008 .57389 L
s
.30075 .57388 m
.30078 .57392 L
s
1 .114 0 r
.66259 .49353 m
.6633 .4937 L
s
.66326 .4927 m
.66259 .49353 L
s
.66259 .49353 m
.66291 .49292 L
s
.66365 .49349 m
.66259 .49353 L
s
.66606 .49189 m
.66259 .49353 L
s
.6633 .4937 m
.66365 .49349 L
s
.66365 .49349 m
.66326 .4927 L
s
1 .417 0 r
.49834 .46719 m
.49816 .46674 L
s
.49816 .46674 m
.49837 .46356 L
s
.49816 .46674 m
.49518 .4652 L
s
1 .114 0 r
.66326 .4927 m
.66291 .49292 L
s
1 .035 0 r
.7235 .52014 m
.72371 .52018 L
s
.72369 .51987 m
.7235 .52014 L
s
.7235 .52014 m
.72357 .51995 L
s
.72383 .5201 m
.7235 .52014 L
s
.72448 .51957 m
.7235 .52014 L
s
.72369 .51987 m
.72357 .51995 L
s
.72383 .5201 m
.72369 .51987 L
s
.72371 .52018 m
.72383 .5201 L
s
.72357 .51995 m
.72371 .52018 L
s
1 .417 0 r
.49837 .46356 m
.49854 .46401 L
s
.49837 .46356 m
.49518 .4652 L
s
1 .318 0 r
.59813 .46604 m
.59895 .46834 L
s
1 .114 0 r
.66291 .49292 m
.6633 .4937 L
s
1 .233 0 r
.40871 .46654 m
.40806 .46615 L
s
.40806 .46615 m
.40878 .46451 L
s
.40806 .46615 m
.40724 .46491 L
s
1 .004 0 r
.40048 .73359 m
.40049 .7336 L
s
.40049 .73356 m
.40048 .73359 L
s
.40052 .73359 m
.40048 .73359 L
s
.4005 .73357 m
.40049 .73356 L
s
.40049 .73356 m
.40052 .73359 L
s
.40052 .73359 m
.40049 .7336 L
s
.4005 .73357 m
.40052 .73359 L
s
.40038 .73356 m
.40052 .73359 L
s
.40049 .7336 m
.4005 .73357 L
s
1 .233 0 r
.40878 .46451 m
.40943 .4649 L
s
.40878 .46451 m
.40724 .46491 L
s
1 0 0 r
.66914 .65331 m
.66914 .65331 L
s
1 .004 0 r
.45571 .59982 m
.45556 .59979 L
s
1 .417 0 r
.51105 .46608 m
.49518 .4652 L
s
1 .004 0 r
.45559 .59982 m
.45558 .59981 L
s
.45558 .59981 m
.45559 .59978 L
s
.45558 .59981 m
.45556 .59979 L
s
.45559 .59978 m
.4556 .59979 L
s
.45559 .59978 m
.45556 .59979 L
s
.45556 .59979 m
.45559 .59982 L
s
.45556 .59979 m
.4556 .59979 L
s
.4556 .59979 m
.45559 .59982 L
s
1 .417 0 r
.49518 .4652 m
.49834 .46719 L
s
.49518 .4652 m
.49854 .46401 L
s
1 .01 0 r
.55563 .75953 m
.55562 .75955 L
s
.55562 .75946 m
.55563 .75953 L
s
.5557 .7595 m
.55563 .75953 L
s
1 .001 0 r
.34181 .706 m
.34181 .706 L
s
.34181 .70599 m
.34181 .706 L
s
.34182 .706 m
.34181 .706 L
s
.34182 .706 m
.34181 .706 L
s
.34181 .70599 m
.34182 .706 L
s
.34181 .706 m
.34182 .706 L
s
.34178 .70599 m
.34182 .706 L
s
.34181 .706 m
.34181 .70599 L
s
.34181 .706 m
.34181 .706 L
s
1 .01 0 r
.55562 .75948 m
.55562 .75946 L
s
.55562 .75946 m
.5557 .7595 L
s
1 0 0 r
.61068 .62571 m
.61068 .62571 L
s
.61068 .62571 m
.61068 .6257 L
s
.61068 .62571 m
.61068 .6257 L
s
.61068 .6257 m
.61068 .6257 L
s
.61068 .6257 m
.61068 .6257 L
s
.61068 .6257 m
.61068 .62571 L
s
.61068 .6257 m
.61068 .6257 L
s
.61069 .6257 m
.61068 .6257 L
s
.61068 .6257 m
.61068 .62571 L
s
1 .01 0 r
.55533 .75952 m
.5557 .7595 L
s
1 .012 0 r
.39715 .57218 m
.39675 .57205 L
s
1 .01 0 r
.5557 .7595 m
.55562 .75955 L
s
.55562 .75948 m
.5557 .7595 L
s
.55562 .75955 m
.55562 .75948 L
s
1 .012 0 r
.39683 .57213 m
.3968 .5721 L
s
.3968 .5721 m
.39683 .57202 L
s
.3968 .5721 m
.39675 .57205 L
s
.39683 .57202 m
.39686 .57204 L
s
.39683 .57202 m
.39675 .57205 L
s
.39675 .57205 m
.39683 .57213 L
s
.39675 .57205 m
.39686 .57204 L
s
.39686 .57204 m
.39683 .57213 L
s
1 .233 0 r
.40943 .4649 m
.40871 .46654 L
s
.40724 .46491 m
.40871 .46654 L
s
.40724 .46491 m
.40943 .4649 L
s
1 .134 0 r
.7008 .46463 m
.70154 .46474 L
s
.70147 .46358 m
.7008 .46463 L
s
.7008 .46463 m
.70097 .46388 L
s
.70204 .46444 m
.7008 .46463 L
s
.70431 .46226 m
.7008 .46463 L
s
.70147 .46358 m
.70097 .46388 L
s
.70204 .46444 m
.70147 .46358 L
s
1 .014 0 r
.8209 .518 m
.82097 .51801 L
s
.82096 .51788 m
.8209 .518 L
s
.8209 .518 m
.82091 .51792 L
s
.82103 .51797 m
.8209 .518 L
s
.82124 .51773 m
.8209 .518 L
s
1 .134 0 r
.70154 .46474 m
.70204 .46444 L
s
1 .014 0 r
.82096 .51788 m
.82091 .51792 L
s
.82103 .51797 m
.82096 .51788 L
s
.82097 .51801 m
.82103 .51797 L
s
.82091 .51792 m
.82097 .51801 L
s
1 .417 0 r
.49854 .46401 m
.49834 .46719 L
s
1 .005 0 r
.55203 .59809 m
.55203 .59808 L
s
.55203 .59808 m
.55203 .59805 L
s
.55203 .59808 m
.55199 .59807 L
s
.49694 .73197 m
.49695 .73198 L
s
.49695 .73193 m
.49694 .73197 L
s
.49699 .73195 m
.49694 .73197 L
s
.55203 .59805 m
.55203 .59805 L
s
.55203 .59805 m
.55199 .59807 L
s
.49695 .73194 m
.49695 .73193 L
s
.49695 .73193 m
.49699 .73195 L
s
.55199 .59807 m
.55203 .59809 L
s
.55199 .59807 m
.55203 .59805 L
s
.55218 .59806 m
.55199 .59807 L
s
.49699 .73195 m
.49695 .73198 L
s
.49695 .73194 m
.49699 .73195 L
s
.49679 .73195 m
.49699 .73195 L
s
1 .019 0 r
.33852 .5445 m
.33795 .54421 L
s
1 .005 0 r
.55203 .59805 m
.55203 .59809 L
s
.49695 .73198 m
.49695 .73194 L
s
1 .045 0 r
.7617 .49085 m
.76194 .49088 L
s
.76191 .49048 m
.7617 .49085 L
s
.7617 .49085 m
.76173 .4906 L
s
.76211 .49077 m
.7617 .49085 L
s
.76281 .49001 m
.7617 .49085 L
s
.76191 .49048 m
.76173 .4906 L
s
.76211 .49077 m
.76191 .49048 L
s
.76194 .49088 m
.76211 .49077 L
s
1 .019 0 r
.33807 .54419 m
.33813 .54423 L
s
.338 .54432 m
.33807 .54419 L
s
.33807 .54419 m
.33795 .54421 L
s
.33806 .54436 m
.338 .54432 L
s
.338 .54432 m
.33795 .54421 L
s
.33813 .54423 m
.33806 .54436 L
s
.33795 .54421 m
.33813 .54423 L
s
.33795 .54421 m
.33806 .54436 L
s
1 .134 0 r
.70097 .46388 m
.70154 .46474 L
s
1 .045 0 r
.76173 .4906 m
.76194 .49088 L
s
1 .022 0 r
.38335 .83847 m
.38338 .83852 L
s
.38339 .83831 m
.38335 .83847 L
s
.38354 .83844 m
.38335 .83847 L
s
.38342 .83836 m
.38339 .83831 L
s
.38339 .83831 m
.38354 .83844 L
s
.38354 .83844 m
.38338 .83852 L
s
.38342 .83836 m
.38354 .83844 L
s
.38276 .8383 m
.38354 .83844 L
s
.38338 .83852 m
.38342 .83836 L
s
1 .002 0 r
.43823 .70436 m
.43823 .70436 L
s
.43823 .70434 m
.43823 .70436 L
s
.43825 .70435 m
.43823 .70436 L
s
.43823 .70435 m
.43823 .70434 L
s
.43823 .70434 m
.43825 .70435 L
s
1 .021 0 r
.49296 .57043 m
.49295 .5704 L
s
.49295 .5704 m
.49297 .57024 L
s
.49295 .5704 m
.49281 .57032 L
s
1 .002 0 r
.43825 .70435 m
.43823 .70436 L
s
.43823 .70435 m
.43825 .70435 L
s
.43818 .70434 m
.43825 .70435 L
s
.43823 .70436 m
.43823 .70435 L
s
1 0 0 r
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
1 .021 0 r
.49361 .57039 m
.49281 .57032 L
s
1 .023 0 r
.27983 .5168 m
.27924 .51638 L
s
1 .021 0 r
.49297 .57024 m
.49298 .57027 L
s
.49297 .57024 m
.49281 .57032 L
s
.49281 .57032 m
.49296 .57043 L
s
.49281 .57032 m
.49298 .57027 L
s
.49298 .57027 m
.49296 .57043 L
s
1 .023 0 r
.27936 .51636 m
.27945 .51642 L
s
.27926 .51651 m
.27936 .51636 L
s
.27936 .51636 m
.27924 .51638 L
s
.27935 .51657 m
.27926 .51651 L
s
.27926 .51651 m
.27924 .51638 L
s
.27945 .51642 m
.27935 .51657 L
s
.27924 .51638 m
.27945 .51642 L
s
.27924 .51638 m
.27935 .51657 L
s
1 .003 0 r
.64877 .59634 m
.64878 .59633 L
s
.64878 .59633 m
.64877 .59631 L
s
.64878 .59633 m
.64874 .59633 L
s
.64877 .59631 m
.64876 .59631 L
s
.64877 .59631 m
.64874 .59633 L
s
.64874 .59633 m
.64877 .59634 L
s
.64874 .59633 m
.64876 .59631 L
s
.64886 .5963 m
.64874 .59633 L
s
.64876 .59631 m
.64877 .59634 L
s
1 0 0 r
.37952 .67672 m
.37952 .67672 L
s
.37952 .67671 m
.37952 .67672 L
s
.37952 .67672 m
.37952 .67672 L
s
.37952 .67672 m
.37952 .67671 L
s
.37952 .67671 m
.37952 .67672 L
s
.37952 .67672 m
.37952 .67672 L
s
.37952 .67672 m
.37952 .67672 L
s
.37951 .67671 m
.37952 .67672 L
s
.37952 .67672 m
.37952 .67672 L
s
1 .005 0 r
.5934 .73033 m
.59359 .73031 L
s
1 .046 0 r
.43497 .54268 m
.43336 .54226 L
s
1 .005 0 r
.59356 .73032 m
.59356 .73033 L
s
.59356 .73029 m
.59356 .73032 L
s
.59359 .73031 m
.59356 .73032 L
s
.59355 .7303 m
.59356 .73029 L
s
.59356 .73029 m
.59359 .73031 L
s
.59359 .73031 m
.59356 .73033 L
s
.59355 .7303 m
.59359 .73031 L
s
.59356 .73033 m
.59355 .7303 L
s
1 .046 0 r
.43367 .54255 m
.43358 .54248 L
s
.43358 .54248 m
.43369 .54214 L
s
.43358 .54248 m
.43336 .54226 L
s
.43369 .54214 m
.43378 .54222 L
s
.43369 .54214 m
.43336 .54226 L
s
.43336 .54226 m
.43367 .54255 L
s
.43336 .54226 m
.43378 .54222 L
s
.43378 .54222 m
.43367 .54255 L
s
1 .018 0 r
.85938 .48851 m
.85947 .48851 L
s
.85945 .48835 m
.85938 .48851 L
s
.85938 .48851 m
.85937 .48841 L
s
.85954 .48846 m
.85938 .48851 L
s
.85976 .48813 m
.85938 .48851 L
s
.85945 .48835 m
.85937 .48841 L
s
.85954 .48846 m
.85945 .48835 L
s
.85947 .48851 m
.85954 .48846 L
s
.85937 .48841 m
.85947 .48851 L
s
1 .02 0 r
.58969 .56878 m
.58972 .56875 L
s
.58972 .56875 m
.58969 .5686 L
s
.58972 .56875 m
.58955 .56872 L
s
.58969 .5686 m
.58966 .56863 L
s
.58969 .5686 m
.58955 .56872 L
s
1 .028 0 r
.48013 .83692 m
.48015 .83698 L
s
.48015 .83671 m
.48013 .83692 L
s
.48036 .83686 m
.48013 .83692 L
s
1 .02 0 r
.58955 .56872 m
.58969 .56878 L
s
.58955 .56872 m
.58966 .56863 L
s
.59027 .56859 m
.58955 .56872 L
s
1 .028 0 r
.48016 .83678 m
.48015 .83671 L
s
.48015 .83671 m
.48036 .83686 L
s
1 .051 0 r
.80018 .4614 m
.80041 .46142 L
s
.80037 .46097 m
.80018 .4614 L
s
.80018 .4614 m
.80016 .46111 L
s
.80063 .46127 m
.80018 .4614 L
s
.80126 .46035 m
.80018 .4614 L
s
1 .028 0 r
.48036 .83686 m
.48015 .83698 L
s
.48016 .83678 m
.48036 .83686 L
s
.4793 .8368 m
.48036 .83686 L
s
1 .02 0 r
.58966 .56863 m
.58969 .56878 L
s
1 .051 0 r
.80037 .46097 m
.80016 .46111 L
s
.80063 .46127 m
.80037 .46097 L
s
1 .002 0 r
.53485 .7027 m
.53485 .7027 L
s
.53485 .70268 m
.53485 .7027 L
s
.53487 .70269 m
.53485 .7027 L
s
.53485 .70269 m
.53485 .70268 L
s
.53485 .70268 m
.53487 .70269 L
s
.53479 .7027 m
.53487 .70269 L
s
1 .062 0 r
.37626 .51495 m
.37437 .51407 L
s
1 0 0 r
.32078 .64905 m
.32078 .64905 L
s
1 .002 0 r
.53487 .70269 m
.53485 .7027 L
s
.53485 .70269 m
.53487 .70269 L
s
1 .028 0 r
.48015 .83698 m
.48016 .83678 L
s
1 .002 0 r
.53485 .7027 m
.53485 .70269 L
s
1 .051 0 r
.80041 .46142 m
.80063 .46127 L
s
.80016 .46111 m
.80041 .46142 L
s
1 .062 0 r
.37474 .51452 m
.37455 .5144 L
s
.37455 .5144 m
.37476 .51397 L
s
.37455 .5144 m
.37437 .51407 L
s
.37476 .51397 m
.37495 .51409 L
s
.37476 .51397 m
.37437 .51407 L
s
1 .068 0 r
.52955 .5412 m
.52956 .54111 L
s
.52956 .54111 m
.52955 .54059 L
s
.52956 .54111 m
.52903 .54091 L
s
.52955 .54059 m
.52954 .54068 L
s
.52955 .54059 m
.52903 .54091 L
s
1 .019 0 r
.42114 .80934 m
.42117 .80939 L
s
.42117 .8092 m
.42114 .80934 L
s
.42131 .80931 m
.42114 .80934 L
s
.4212 .80924 m
.42117 .8092 L
s
.42117 .8092 m
.42131 .80931 L
s
.42131 .80931 m
.42117 .80939 L
s
.4212 .80924 m
.42131 .80931 L
s
.42059 .80921 m
.42131 .80931 L
s
1 .062 0 r
.37495 .51409 m
.37474 .51452 L
s
.37437 .51407 m
.37474 .51452 L
s
.37437 .51407 m
.37495 .51409 L
s
1 .019 0 r
.42117 .80939 m
.4212 .80924 L
s
1 .068 0 r
.52903 .54091 m
.52955 .5412 L
s
.52903 .54091 m
.52954 .54068 L
s
.53162 .54086 m
.52903 .54091 L
s
1 .002 0 r
.7457 .59455 m
.74571 .59455 L
s
.74571 .59454 m
.7457 .59455 L
s
.7457 .59455 m
.7457 .59454 L
s
.74571 .59455 m
.7457 .59455 L
s
.74574 .59453 m
.7457 .59455 L
s
.74571 .59454 m
.7457 .59454 L
s
.74571 .59455 m
.74571 .59454 L
s
.74571 .59455 m
.74571 .59455 L
s
.7457 .59454 m
.74571 .59455 L
s
1 0 0 r
.47612 .67504 m
.47612 .67504 L
s
.47612 .67503 m
.47612 .67504 L
s
.47612 .67504 m
.47612 .67504 L
s
.47612 .67503 m
.47612 .67503 L
s
.47612 .67503 m
.47612 .67504 L
s
.47612 .67504 m
.47612 .67504 L
s
.47612 .67503 m
.47612 .67504 L
s
.47611 .67503 m
.47612 .67504 L
s
.47612 .67504 m
.47612 .67503 L
s
1 .063 0 r
.3175 .48719 m
.31587 .48605 L
s
1 .068 0 r
.52954 .54068 m
.52955 .5412 L
s
1 .063 0 r
.31621 .486 m
.31645 .48615 L
s
.31594 .4864 m
.31621 .486 L
s
.31621 .486 m
.31587 .48605 L
s
.31618 .48656 m
.31594 .4864 L
s
.31594 .4864 m
.31587 .48605 L
s
1 .01 0 r
.68683 .56693 m
.68689 .56695 L
s
.68689 .56686 m
.68683 .56693 L
s
.68683 .56693 m
.68686 .56688 L
s
.68692 .56693 m
.68683 .56693 L
s
.68715 .56679 m
.68683 .56693 L
s
.68689 .56695 m
.68692 .56693 L
s
.68692 .56693 m
.68689 .56686 L
s
.68689 .56686 m
.68686 .56688 L
s
1 .011 0 r
.36211 .78169 m
.36213 .78172 L
s
.36214 .78161 m
.36211 .78169 L
s
.36222 .78169 m
.36211 .78169 L
s
.36216 .78164 m
.36214 .78161 L
s
.36214 .78161 m
.36222 .78169 L
s
.36222 .78169 m
.36213 .78172 L
s
.36216 .78164 m
.36222 .78169 L
s
.36182 .78159 m
.36222 .78169 L
s
1 .01 0 r
.68686 .56688 m
.68689 .56695 L
s
1 .011 0 r
.36213 .78172 m
.36216 .78164 L
s
1 .002 0 r
.6316 .70104 m
.63167 .70103 L
s
1 0 0 r
.41736 .64734 m
.41736 .64734 L
s
1 .137 0 r
.47291 .5131 m
.46784 .51222 L
s
1 .057 0 r
.25867 .4594 m
.25745 .45824 L
s
1 .002 0 r
.63166 .70104 m
.63165 .70104 L
s
.63165 .70103 m
.63166 .70104 L
s
.63167 .70103 m
.63166 .70104 L
s
.63165 .70103 m
.63165 .70103 L
s
.63165 .70103 m
.63167 .70103 L
s
.63167 .70103 m
.63165 .70104 L
s
.63165 .70103 m
.63167 .70103 L
s
.63165 .70104 m
.63165 .70103 L
s
1 .063 0 r
.31645 .48615 m
.31618 .48656 L
s
.31587 .48605 m
.31645 .48615 L
s
.31587 .48605 m
.31618 .48656 L
s
1 .137 0 r
.46884 .513 m
.46865 .51281 L
s
.46865 .51281 m
.46886 .51178 L
s
.46865 .51281 m
.46784 .51222 L
s
.46886 .51178 m
.46905 .51197 L
s
.46886 .51178 m
.46784 .51222 L
s
1 .046 0 r
.62724 .53962 m
.62734 .53954 L
s
.62734 .53954 m
.62723 .53921 L
s
.62734 .53954 m
.62692 .53951 L
s
.62723 .53921 m
.62712 .53929 L
s
.62723 .53921 m
.62692 .53951 L
s
.62692 .53951 m
.62724 .53962 L
s
.62692 .53951 m
.62712 .53929 L
s
.62848 .53903 m
.62692 .53951 L
s
1 .022 0 r
.89802 .4589 m
.89811 .4589 L
s
.89809 .45872 m
.89802 .4589 L
s
.89802 .4589 m
.89799 .45878 L
s
.8982 .45884 m
.89802 .4589 L
s
.89841 .45844 m
.89802 .4589 L
s
.89809 .45872 m
.89799 .45878 L
s
.8982 .45884 m
.89809 .45872 L
s
.89811 .4589 m
.8982 .45884 L
s
.89799 .45878 m
.89811 .4589 L
s
1 .046 0 r
.62712 .53929 m
.62724 .53962 L
s
1 .151 0 r
.56528 .51258 m
.56547 .51238 L
s
.56547 .51238 m
.56526 .51124 L
s
.56547 .51238 m
.56415 .51208 L
s
1 .057 0 r
.25772 .45822 m
.25796 .45838 L
s
.25744 .45856 m
.25772 .45822 L
s
.25772 .45822 m
.25745 .45824 L
s
.25768 .45872 m
.25744 .45856 L
s
.25744 .45856 m
.25745 .45824 L
s
1 .151 0 r
.56526 .51124 m
.56508 .51144 L
s
.56526 .51124 m
.56415 .51208 L
s
1 .023 0 r
.51805 .80774 m
.51805 .80779 L
s
.51806 .80757 m
.51805 .80774 L
s
.51823 .80768 m
.51805 .80774 L
s
.51806 .80762 m
.51806 .80757 L
s
.51806 .80757 m
.51823 .80768 L
s
1 .137 0 r
.46784 .51222 m
.46884 .513 L
s
.46784 .51222 m
.46905 .51197 L
s
1 .023 0 r
.51823 .80768 m
.51805 .80779 L
s
.51806 .80762 m
.51823 .80768 L
s
.51734 .80767 m
.51823 .80768 L
s
1 0 0 r
.57292 .67335 m
.57292 .67335 L
s
.57292 .67335 m
.57292 .67335 L
s
.57292 .67335 m
.57292 .67335 L
s
.57291 .67335 m
.57292 .67335 L
s
1 .172 0 r
.41413 .4853 m
.40857 .48305 L
s
1 0 0 r
.35855 .61962 m
.35855 .61962 L
s
.57292 .67335 m
.57292 .67335 L
s
.57292 .67335 m
.57292 .67335 L
s
.57292 .67335 m
.57292 .67335 L
s
.57292 .67335 m
.57292 .67335 L
s
.57292 .67335 m
.57292 .67335 L
s
.35855 .61962 m
.35855 .61962 L
s
.35855 .61962 m
.35855 .61962 L
s
.35855 .61962 m
.35855 .61962 L
s
.35855 .61962 m
.35855 .61962 L
s
.35855 .61962 m
.35855 .61962 L
s
.35855 .61962 m
.35855 .61962 L
s
.35855 .61962 m
.35855 .61962 L
s
.35855 .61962 m
.35855 .61962 L
s
1 .023 0 r
.51805 .80779 m
.51806 .80762 L
s
1 .057 0 r
.25796 .45838 m
.25768 .45872 L
s
.25745 .45824 m
.25796 .45838 L
s
1 .151 0 r
.56415 .51208 m
.56528 .51258 L
s
.56415 .51208 m
.56508 .51144 L
s
.56976 .51124 m
.56415 .51208 L
s
1 .137 0 r
.46905 .51197 m
.46884 .513 L
s
1 .057 0 r
.25745 .45824 m
.25768 .45872 L
s
1 .151 0 r
.56508 .51144 m
.56528 .51258 L
s
1 .016 0 r
.45902 .78011 m
.45904 .78015 L
s
.45904 .77999 m
.45902 .78011 L
s
.45916 .78008 m
.45902 .78011 L
s
.45905 .78003 m
.45904 .77999 L
s
.45904 .77999 m
.45916 .78008 L
s
1 .004 0 r
.78412 .56506 m
.78414 .56507 L
s
.78414 .56503 m
.78412 .56506 L
s
.78412 .56506 m
.78412 .56504 L
s
.78416 .56506 m
.78412 .56506 L
s
.78423 .56499 m
.78412 .56506 L
s
1 .016 0 r
.45916 .78008 m
.45904 .78015 L
s
.45905 .78003 m
.45916 .78008 L
s
.45855 .78002 m
.45916 .78008 L
s
1 .004 0 r
.78414 .56503 m
.78412 .56504 L
s
.78416 .56506 m
.78414 .56503 L
s
.78414 .56507 m
.78416 .56506 L
s
.78412 .56504 m
.78414 .56507 L
s
1 .016 0 r
.45904 .78015 m
.45905 .78003 L
s
1 0 0 r
.51416 .64563 m
.51416 .64563 L
s
1 .002 0 r
.29968 .59187 m
.29964 .59185 L
s
1 .158 0 r
.35529 .45748 m
.35113 .45465 L
s
1 .002 0 r
.29965 .59185 m
.29965 .59185 L
s
.29964 .59186 m
.29965 .59185 L
s
.29965 .59185 m
.29964 .59185 L
s
.29965 .59186 m
.29964 .59186 L
s
.29964 .59186 m
.29964 .59185 L
s
.29965 .59185 m
.29965 .59186 L
s
.29964 .59185 m
.29965 .59185 L
s
.29964 .59185 m
.29965 .59186 L
s
1 .241 0 r
.60146 .48467 m
.60203 .4843 L
s
.60203 .4843 m
.60141 .48255 L
s
.60203 .4843 m
.59979 .48413 L
s
1 .575 0 r
.53174 .458 m
.53228 .45737 L
s
.53228 .45737 m
.53173 .45298 L
s
.53228 .45737 m
.52739 .45595 L
s
1 .241 0 r
.60141 .48255 m
.60084 .48292 L
s
.60141 .48255 m
.59979 .48413 L
s
.59979 .48413 m
.60146 .48467 L
s
.59979 .48413 m
.60084 .48292 L
s
.60802 .48152 m
.59979 .48413 L
s
1 .172 0 r
.40966 .48426 m
.40918 .48396 L
s
.40918 .48396 m
.40971 .48274 L
s
.40918 .48396 m
.40857 .48305 L
s
1 .323 0 r
.50108 .48429 m
.50094 .48392 L
s
.50094 .48392 m
.5011 .48145 L
s
.50094 .48392 m
.49862 .48274 L
s
1 .172 0 r
.40971 .48274 m
.4102 .48304 L
s
.40971 .48274 m
.40857 .48305 L
s
1 .575 0 r
.53173 .45298 m
.5312 .45361 L
s
.53173 .45298 m
.52739 .45595 L
s
1 .019 0 r
.72502 .53751 m
.72513 .53753 L
s
.72512 .53736 m
.72502 .53751 L
s
.72502 .53751 m
.72505 .5374 L
s
.7252 .53749 m
.72502 .53751 L
s
.72556 .5372 m
.72502 .53751 L
s
.72512 .53736 m
.72505 .5374 L
s
.7252 .53749 m
.72512 .53736 L
s
.72513 .53753 m
.7252 .53749 L
s
1 .323 0 r
.5011 .48145 m
.50123 .48182 L
s
.5011 .48145 m
.49862 .48274 L
s
1 .019 0 r
.72505 .5374 m
.72513 .53753 L
s
1 .075 0 r
.66454 .51044 m
.66501 .51056 L
s
.66498 .5099 m
.66454 .51044 L
s
.66454 .51044 m
.66475 .51005 L
s
.66524 .51041 m
.66454 .51044 L
s
.66682 .50937 m
.66454 .51044 L
s
.66501 .51056 m
.66524 .51041 L
s
.66524 .51041 m
.66498 .5099 L
s
.66498 .5099 m
.66475 .51005 L
s
1 .009 0 r
.39994 .75242 m
.39995 .75244 L
s
.39996 .75235 m
.39994 .75242 L
s
.40002 .75241 m
.39994 .75242 L
s
.39997 .75237 m
.39996 .75235 L
s
.39996 .75235 m
.40002 .75241 L
s
.40002 .75241 m
.39995 .75244 L
s
.39997 .75237 m
.40002 .75241 L
s
.3997 .75234 m
.40002 .75241 L
s
.39995 .75244 m
.39997 .75237 L
s
1 0 0 r
.66992 .67166 m
.66993 .67166 L
s
1 .001 0 r
.45534 .61788 m
.45532 .61787 L
s
1 .323 0 r
.51097 .48341 m
.49862 .48274 L
s
1 .001 0 r
.45532 .61788 m
.45532 .61788 L
s
.45532 .61788 m
.45532 .61787 L
s
.45532 .61788 m
.45532 .61787 L
s
1 0 0 r
.66993 .67166 m
.66993 .67166 L
s
.66993 .67166 m
.66993 .67166 L
s
.66993 .67166 m
.66993 .67166 L
s
.66993 .67166 m
.66993 .67166 L
s
.66993 .67166 m
.66993 .67166 L
s
1 .001 0 r
.45532 .61787 m
.45532 .61787 L
s
.45532 .61787 m
.45532 .61787 L
s
1 0 0 r
.66993 .67166 m
.66993 .67166 L
s
.66993 .67166 m
.66993 .67166 L
s
.66993 .67166 m
.66993 .67166 L
s
1 .001 0 r
.45532 .61787 m
.45532 .61788 L
s
.45532 .61787 m
.45532 .61787 L
s
.45532 .61787 m
.45532 .61788 L
s
1 .293 0 r
.63781 .4563 m
.63958 .45666 L
s
.63948 .4541 m
.63781 .4563 L
s
.63781 .4563 m
.63849 .45466 L
s
.64057 .45609 m
.63781 .4563 L
s
.64641 .4517 m
.63781 .4563 L
s
1 .075 0 r
.66475 .51005 m
.66501 .51056 L
s
1 .172 0 r
.4102 .48304 m
.40966 .48426 L
s
.40857 .48305 m
.40966 .48426 L
s
.40857 .48305 m
.4102 .48304 L
s
1 .241 0 r
.60084 .48292 m
.60146 .48467 L
s
1 .293 0 r
.63958 .45666 m
.64057 .45609 L
s
.64057 .45609 m
.63948 .4541 L
s
.63948 .4541 m
.63849 .45466 L
s
1 .575 0 r
.52739 .45595 m
.53174 .458 L
s
.52739 .45595 m
.5312 .45361 L
s
.54916 .45363 m
.52739 .45595 L
s
1 .323 0 r
.49862 .48274 m
.50108 .48429 L
s
.49862 .48274 m
.50123 .48182 L
s
1 .158 0 r
.352 .45453 m
.3526 .45488 L
s
.35133 .45556 m
.352 .45453 L
s
.352 .45453 m
.35113 .45465 L
s
1 .003 0 r
.34087 .72467 m
.34088 .72468 L
s
.34088 .72465 m
.34087 .72467 L
s
.3409 .72467 m
.34087 .72467 L
s
.3409 .72467 m
.34088 .72468 L
s
.34088 .72465 m
.3409 .72467 L
s
.34089 .72465 m
.3409 .72467 L
s
.34079 .72463 m
.3409 .72467 L
s
.34089 .72465 m
.34088 .72465 L
s
1 .018 0 r
.55604 .77847 m
.55604 .77851 L
s
.55604 .77834 m
.55604 .77847 L
s
.55617 .77842 m
.55604 .77847 L
s
1 .003 0 r
.34088 .72468 m
.34089 .72465 L
s
1 .018 0 r
.55603 .77838 m
.55604 .77834 L
s
.55604 .77834 m
.55617 .77842 L
s
.55549 .77845 m
.55617 .77842 L
s
1 0 0 r
.61116 .64391 m
.61116 .64391 L
s
1 .004 0 r
.39645 .5901 m
.39633 .59005 L
s
1 .417 0 r
.45212 .45556 m
.43773 .45101 L
s
1 .158 0 r
.35192 .45591 m
.35133 .45556 L
s
.35133 .45556 m
.35113 .45465 L
s
1 .004 0 r
.39635 .59008 m
.39634 .59007 L
s
.39634 .59007 m
.39635 .59005 L
s
.39634 .59007 m
.39633 .59005 L
s
.39635 .59005 m
.39636 .59005 L
s
.39635 .59005 m
.39633 .59005 L
s
1 .018 0 r
.55617 .77842 m
.55604 .77851 L
s
.55603 .77838 m
.55617 .77842 L
s
1 .004 0 r
.39633 .59005 m
.39635 .59008 L
s
.39633 .59005 m
.39636 .59005 L
s
.39636 .59005 m
.39635 .59008 L
s
1 .018 0 r
.55604 .77851 m
.55603 .77838 L
s
1 .323 0 r
.50123 .48182 m
.50108 .48429 L
s
1 .158 0 r
.3526 .45488 m
.35192 .45591 L
s
.35113 .45465 m
.3526 .45488 L
s
.35113 .45465 m
.35192 .45591 L
s
1 .008 0 r
.82266 .53551 m
.8227 .53551 L
s
.82269 .53544 m
.82266 .53551 L
s
.82266 .53551 m
.82266 .53546 L
s
.82273 .53549 m
.82266 .53551 L
s
.82284 .53536 m
.82266 .53551 L
s
.82269 .53544 m
.82266 .53546 L
s
.82273 .53549 m
.82269 .53544 L
s
.8227 .53551 m
.82273 .53549 L
s
.82266 .53546 m
.8227 .53551 L
s
1 .293 0 r
.63849 .45466 m
.63958 .45666 L
s
1 .012 0 r
.49699 .75079 m
.49699 .75081 L
s
.49699 .7507 m
.49699 .75079 L
s
.49708 .75076 m
.49699 .75079 L
s
.497 .75072 m
.49699 .7507 L
s
.49699 .7507 m
.49708 .75076 L
s
.49708 .75076 m
.49699 .75081 L
s
.497 .75072 m
.49708 .75076 L
s
.49663 .75074 m
.49708 .75076 L
s
1 .001 0 r
.55231 .61613 m
.55231 .61613 L
s
.55231 .61613 m
.55231 .61613 L
s
.55231 .61613 m
.5523 .61613 L
s
.55231 .61613 m
.55231 .61613 L
s
.55231 .61613 m
.5523 .61613 L
s
.5523 .61613 m
.55231 .61613 L
s
.5523 .61613 m
.55231 .61613 L
s
.55233 .61613 m
.5523 .61613 L
s
1 .009 0 r
.33751 .56228 m
.33725 .56215 L
s
1 .001 0 r
.55231 .61613 m
.55231 .61613 L
s
1 .012 0 r
.49699 .75081 m
.497 .75072 L
s
1 .009 0 r
.3373 .56214 m
.33733 .56216 L
s
.33727 .5622 m
.3373 .56214 L
s
.3373 .56214 m
.33725 .56215 L
s
.3373 .56222 m
.33727 .5622 L
s
.33727 .5622 m
.33725 .56215 L
s
.33733 .56216 m
.3373 .56222 L
s
.33725 .56215 m
.33733 .56216 L
s
.33725 .56215 m
.3373 .56222 L
s
1 .095 0 r
.70277 .4813 m
.7033 .48138 L
s
.70325 .48054 m
.70277 .4813 L
s
.70277 .4813 m
.70289 .48076 L
s
.70365 .48116 m
.70277 .4813 L
s
.70528 .47962 m
.70277 .4813 L
s
.70325 .48054 m
.70289 .48076 L
s
.70365 .48116 m
.70325 .48054 L
s
.7033 .48138 m
.70365 .48116 L
s
1 .028 0 r
.7634 .50803 m
.76355 .50805 L
s
.76353 .5078 m
.7634 .50803 L
s
.7634 .50803 m
.76342 .50787 L
s
.76366 .50797 m
.7634 .50803 L
s
.7641 .5075 m
.7634 .50803 L
s
.76353 .5078 m
.76342 .50787 L
s
.76366 .50797 m
.76353 .5078 L
s
.76355 .50805 m
.76366 .50797 L
s
1 .575 0 r
.5312 .45361 m
.53174 .458 L
s
1 .028 0 r
.76342 .50787 m
.76355 .50805 L
s
1 .095 0 r
.70289 .48076 m
.7033 .48138 L
s
1 .006 0 r
.43787 .72304 m
.43788 .72305 L
s
.43788 .723 m
.43787 .72304 L
s
.43792 .72303 m
.43787 .72304 L
s
.43788 .72301 m
.43788 .723 L
s
.43788 .723 m
.43792 .72303 L
s
.43792 .72303 m
.43788 .72305 L
s
.43788 .72301 m
.43792 .72303 L
s
.43771 .723 m
.43792 .72303 L
s
.43788 .72305 m
.43788 .72301 L
s
1 .007 0 r
.49323 .58833 m
.49322 .58832 L
s
.49322 .58832 m
.49323 .58827 L
s
.49322 .58832 m
.49318 .58829 L
s
1 0 0 r
.70837 .64219 m
.70837 .64219 L
s
1 .007 0 r
.49343 .58831 m
.49318 .58829 L
s
1 .013 0 r
.2785 .53444 m
.27817 .53421 L
s
1 .007 0 r
.49323 .58827 m
.49323 .58828 L
s
.49323 .58827 m
.49318 .58829 L
s
.49318 .58829 m
.49323 .58833 L
s
.49318 .58829 m
.49323 .58828 L
s
.49323 .58828 m
.49323 .58833 L
s
1 .013 0 r
.27824 .5342 m
.27829 .53424 L
s
.27818 .53428 m
.27824 .5342 L
s
.27824 .5342 m
.27817 .53421 L
s
.27823 .53432 m
.27818 .53428 L
s
.27818 .53428 m
.27817 .53421 L
s
.27829 .53424 m
.27823 .53432 L
s
.27817 .53421 m
.27829 .53424 L
s
.27817 .53421 m
.27823 .53432 L
s
1 .417 0 r
.44057 .45375 m
.4396 .45315 L
s
.4396 .45315 m
.44066 .4501 L
s
.4396 .45315 m
.43773 .45101 L
s
.44066 .4501 m
.44163 .45069 L
s
.44066 .4501 m
.43773 .45101 L
s
1 .002 0 r
.37876 .69525 m
.37876 .69525 L
s
.37877 .69523 m
.37876 .69525 L
s
.37878 .69525 m
.37876 .69525 L
s
.37877 .69524 m
.37877 .69523 L
s
.37877 .69523 m
.37878 .69525 L
s
.37878 .69525 m
.37876 .69525 L
s
.37877 .69524 m
.37878 .69525 L
s
.37872 .69523 m
.37878 .69525 L
s
.37876 .69525 m
.37877 .69524 L
s
1 0 0 r
.64952 .61438 m
.64952 .61438 L
s
.64952 .61438 m
.64952 .61438 L
s
.64952 .61438 m
.64951 .61438 L
s
.64952 .61438 m
.64952 .61438 L
s
.64952 .61438 m
.64951 .61438 L
s
.64951 .61438 m
.64952 .61438 L
s
.64951 .61438 m
.64952 .61438 L
s
.64953 .61438 m
.64951 .61438 L
s
.64952 .61438 m
.64952 .61438 L
s
1 .011 0 r
.59377 .74913 m
.5942 .74909 L
s
1 .021 0 r
.43448 .56047 m
.43373 .56028 L
s
1 .011 0 r
.59413 .74913 m
.59412 .74915 L
s
.59412 .74904 m
.59413 .74913 L
s
.5942 .74909 m
.59413 .74913 L
s
.59411 .74906 m
.59412 .74904 L
s
.59412 .74904 m
.5942 .74909 L
s
.5942 .74909 m
.59412 .74915 L
s
.59411 .74906 m
.5942 .74909 L
s
.59412 .74915 m
.59411 .74906 L
s
1 .021 0 r
.43387 .56041 m
.43383 .56038 L
s
.43383 .56038 m
.43388 .56022 L
s
.43383 .56038 m
.43373 .56028 L
s
.43388 .56022 m
.43392 .56026 L
s
.43388 .56022 m
.43373 .56028 L
s
.43373 .56028 m
.43387 .56041 L
s
.43373 .56028 m
.43392 .56026 L
s
.43392 .56026 m
.43387 .56041 L
s
1 .011 0 r
.86135 .50586 m
.8614 .50586 L
s
.86139 .50576 m
.86135 .50586 L
s
.86135 .50586 m
.86134 .5058 L
s
.86145 .50583 m
.86135 .50586 L
s
.86158 .50563 m
.86135 .50586 L
s
.86139 .50576 m
.86134 .5058 L
s
.86145 .50583 m
.86139 .50576 L
s
.8614 .50586 m
.86145 .50583 L
s
.86134 .5058 m
.8614 .50586 L
s
1 .104 0 r
.74158 .45186 m
.74207 .45189 L
s
.74201 .45098 m
.74158 .45186 L
s
.74158 .45186 m
.74157 .45126 L
s
.74251 .45161 m
.74158 .45186 L
s
.74387 .44976 m
.74158 .45186 L
s
1 .006 0 r
.59044 .58659 m
.59045 .58658 L
s
.59045 .58658 m
.59044 .58653 L
s
.59045 .58658 m
.59039 .58657 L
s
.59044 .58653 m
.59043 .58654 L
s
.59044 .58653 m
.59039 .58657 L
s
.59039 .58657 m
.59044 .58659 L
s
.59039 .58657 m
.59043 .58654 L
s
.59062 .58653 m
.59039 .58657 L
s
.59043 .58654 m
.59044 .58659 L
s
1 .007 0 r
.53505 .72138 m
.53505 .72139 L
s
.53505 .72133 m
.53505 .72138 L
s
.5351 .72136 m
.53505 .72138 L
s
.53505 .72134 m
.53505 .72133 L
s
.53505 .72133 m
.5351 .72136 L
s
1 0 0 r
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
1 .007 0 r
.53484 .72136 m
.5351 .72136 L
s
1 .035 0 r
.37545 .5326 m
.37438 .5321 L
s
1 .007 0 r
.5351 .72136 m
.53505 .72139 L
s
.53505 .72134 m
.5351 .72136 L
s
1 .104 0 r
.74201 .45098 m
.74157 .45126 L
s
.74251 .45161 m
.74201 .45098 L
s
1 .007 0 r
.53505 .72139 m
.53505 .72134 L
s
1 .104 0 r
.74207 .45189 m
.74251 .45161 L
s
1 .035 0 r
.80202 .47842 m
.80218 .47844 L
s
.80215 .47813 m
.80202 .47842 L
s
.80202 .47842 m
.802 .47823 L
s
.80233 .47834 m
.80202 .47842 L
s
.80276 .47771 m
.80202 .47842 L
s
.80215 .47813 m
.802 .47823 L
s
.80233 .47834 m
.80215 .47813 L
s
.37458 .53236 m
.37448 .53229 L
s
.37448 .53229 m
.3746 .53204 L
s
.37448 .53229 m
.37438 .5321 L
s
.3746 .53204 m
.37471 .53212 L
s
.3746 .53204 m
.37438 .5321 L
s
.80218 .47844 m
.80233 .47834 L
s
1 .104 0 r
.74157 .45126 m
.74207 .45189 L
s
1 .035 0 r
.802 .47823 m
.80218 .47844 L
s
.37471 .53212 m
.37458 .53236 L
s
.37438 .5321 m
.37458 .53236 L
s
.37438 .5321 m
.37471 .53212 L
s
1 .417 0 r
.43773 .45101 m
.44057 .45375 L
s
.43773 .45101 m
.44163 .45069 L
s
1 .029 0 r
.42085 .82866 m
.42089 .82873 L
s
.4209 .82845 m
.42085 .82866 L
s
.42111 .82862 m
.42085 .82866 L
s
.42093 .82852 m
.4209 .82845 L
s
.4209 .82845 m
.42111 .82862 L
s
.42111 .82862 m
.42089 .82873 L
s
.42093 .82852 m
.42111 .82862 L
s
.42002 .82847 m
.42111 .82862 L
s
1 .417 0 r
.44163 .45069 m
.44057 .45375 L
s
1 .032 0 r
.53067 .55882 m
.53067 .55877 L
s
.53067 .55877 m
.53067 .55853 L
s
.53067 .55877 m
.53042 .55868 L
s
.53067 .55853 m
.53066 .55857 L
s
.53067 .55853 m
.53042 .55868 L
s
1 .029 0 r
.42089 .82873 m
.42093 .82852 L
s
1 .032 0 r
.53042 .55868 m
.53067 .55882 L
s
.53042 .55868 m
.53066 .55857 L
s
.53165 .55866 m
.53042 .55868 L
s
1 .003 0 r
.47591 .69358 m
.47592 .69358 L
s
.47592 .69356 m
.47591 .69358 L
s
.47594 .69357 m
.47591 .69358 L
s
.47592 .69356 m
.47592 .69356 L
s
.47592 .69356 m
.47594 .69357 L
s
.47594 .69357 m
.47592 .69358 L
s
.47592 .69356 m
.47594 .69357 L
s
.47584 .69356 m
.47594 .69357 L
s
1 0 0 r
.74694 .61262 m
.74694 .61262 L
s
.74694 .61262 m
.74694 .61262 L
s
.74694 .61262 m
.74694 .61262 L
s
.74694 .61262 m
.74694 .61262 L
s
.74694 .61262 m
.74694 .61262 L
s
.74694 .61262 m
.74694 .61262 L
s
.74694 .61262 m
.74694 .61262 L
s
.74694 .61262 m
.74694 .61262 L
s
1 .003 0 r
.47592 .69358 m
.47592 .69356 L
s
1 0 0 r
.74694 .61262 m
.74694 .61262 L
s
1 .04 0 r
.31637 .50469 m
.31533 .50398 L
s
1 .032 0 r
.53066 .55857 m
.53067 .55882 L
s
1 .04 0 r
.31555 .50394 m
.3157 .50404 L
s
.31537 .5042 m
.31555 .50394 L
s
.31555 .50394 m
.31533 .50398 L
s
.31552 .5043 m
.31537 .5042 L
s
.31537 .5042 m
.31533 .50398 L
s
.3157 .50404 m
.31552 .5043 L
s
.31533 .50398 m
.3157 .50404 L
s
.31533 .50398 m
.31552 .5043 L
s
1 .018 0 r
.36142 .80088 m
.36145 .80092 L
s
.36146 .80074 m
.36142 .80088 L
s
.36159 .80086 m
.36142 .80088 L
s
.36149 .80079 m
.36146 .80074 L
s
.36146 .80074 m
.36159 .80086 L
s
.36159 .80086 m
.36145 .80092 L
s
.36149 .80079 m
.36159 .80086 L
s
.36093 .80071 m
.36159 .80086 L
s
.36145 .80092 m
.36149 .80079 L
s
1 .003 0 r
.68793 .58478 m
.68795 .58479 L
s
.68795 .58476 m
.68793 .58478 L
s
.68793 .58478 m
.68794 .58477 L
s
.68796 .58478 m
.68793 .58478 L
s
.68803 .58474 m
.68793 .58478 L
s
.68795 .58479 m
.68796 .58478 L
s
.68796 .58478 m
.68795 .58476 L
s
.68795 .58476 m
.68794 .58477 L
s
.68794 .58477 m
.68795 .58479 L
s
1 0 0 r
.41678 .66573 m
.41678 .66573 L
s
.41678 .66573 m
.41678 .66573 L
s
.41679 .66573 m
.41678 .66573 L
s
.41679 .66573 m
.41678 .66573 L
s
.41678 .66573 m
.41679 .66573 L
s
.41679 .66573 m
.41678 .66573 L
s
.41679 .66573 m
.41679 .66573 L
s
.41678 .66573 m
.41679 .66573 L
s
.41678 .66573 m
.41679 .66573 L
s
1 .006 0 r
.63218 .71972 m
.63239 .71968 L
s
1 .081 0 r
.47262 .53075 m
.4696 .53023 L
s
1 .039 0 r
.25722 .47676 m
.25638 .47597 L
s
1 .006 0 r
.63236 .71971 m
.63235 .71972 L
s
.63234 .71966 m
.63236 .71971 L
s
.63239 .71968 m
.63236 .71971 L
s
.63234 .71968 m
.63234 .71966 L
s
.63234 .71966 m
.63239 .71968 L
s
.63239 .71968 m
.63235 .71972 L
s
.63234 .71968 m
.63239 .71968 L
s
.63235 .71972 m
.63234 .71968 L
s
1 .081 0 r
.4702 .5307 m
.47009 .53059 L
s
.47009 .53059 m
.47021 .52997 L
s
.47009 .53059 m
.4696 .53023 L
s
.47021 .52997 m
.47032 .53009 L
s
.47021 .52997 m
.4696 .53023 L
s
.4696 .53023 m
.4702 .5307 L
s
.4696 .53023 m
.47032 .53009 L
s
1 .039 0 r
.25656 .47596 m
.25673 .47607 L
s
.25637 .47619 m
.25656 .47596 L
s
.25656 .47596 m
.25638 .47597 L
s
.25653 .4763 m
.25637 .47619 L
s
.25637 .47619 m
.25638 .47597 L
s
1 .081 0 r
.47032 .53009 m
.4702 .5307 L
s
1 .014 0 r
.90018 .47611 m
.90024 .47611 L
s
.90023 .47599 m
.90018 .47611 L
s
.90018 .47611 m
.90016 .47603 L
s
.9003 .47607 m
.90018 .47611 L
s
.90044 .47581 m
.90018 .47611 L
s
.90023 .47599 m
.90016 .47603 L
s
.9003 .47607 m
.90023 .47599 L
s
1 .039 0 r
.25673 .47607 m
.25653 .4763 L
s
.25638 .47597 m
.25673 .47607 L
s
1 .014 0 r
.90024 .47611 m
.9003 .47607 L
s
1 .021 0 r
.62847 .55711 m
.62851 .55707 L
s
.62851 .55707 m
.62846 .55692 L
s
.62851 .55707 m
.62832 .55706 L
s
.62846 .55692 m
.62841 .55696 L
s
.62846 .55692 m
.62832 .55706 L
s
.62832 .55706 m
.62847 .55711 L
s
.62832 .55706 m
.62841 .55696 L
s
.62905 .55684 m
.62832 .55706 L
s
1 .039 0 r
.25638 .47597 m
.25653 .4763 L
s
1 .014 0 r
.90016 .47603 m
.90024 .47611 L
s
1 .021 0 r
.62841 .55696 m
.62847 .55711 L
s
1 .035 0 r
.51836 .82704 m
.51837 .82712 L
s
.51837 .82678 m
.51836 .82704 L
s
.51864 .82696 m
.51836 .82704 L
s
.51837 .82686 m
.51837 .82678 L
s
.51837 .82678 m
.51864 .82696 L
s
.51864 .82696 m
.51837 .82712 L
s
.51837 .82686 m
.51864 .82696 L
s
.51729 .82694 m
.51864 .82696 L
s
1 .003 0 r
.57325 .69189 m
.57325 .69189 L
s
.57325 .69187 m
.57325 .69189 L
s
.57327 .69188 m
.57325 .69189 L
s
.57317 .69189 m
.57327 .69188 L
s
1 .116 0 r
.41352 .50282 m
.40977 .50131 L
s
1 0 0 r
.35765 .63787 m
.35765 .63787 L
s
1 .003 0 r
.57325 .69187 m
.57325 .69187 L
s
.57325 .69187 m
.57327 .69188 L
s
.57327 .69188 m
.57325 .69189 L
s
.57325 .69187 m
.57327 .69188 L
s
.57325 .69189 m
.57325 .69187 L
s
1 .65 0 r
.57002 .44967 m
.57164 .44874 L
s
.57164 .44874 m
.56994 .44399 L
s
.57164 .44874 m
.56554 .44828 L
s
1 .035 0 r
.51837 .82712 m
.51837 .82686 L
s
1 .039 0 r
.84084 .44867 m
.841 .44867 L
s
.84097 .44833 m
.84084 .44867 L
s
.84084 .44867 m
.84079 .44846 L
s
.84117 .44855 m
.84084 .44867 L
s
.84155 .44782 m
.84084 .44867 L
s
.84097 .44833 m
.84079 .44846 L
s
.84117 .44855 m
.84097 .44833 L
s
.841 .44867 m
.84117 .44855 L
s
1 .09 0 r
.56731 .5297 m
.56743 .52958 L
s
.56743 .52958 m
.5673 .5289 L
s
.56743 .52958 m
.56664 .5294 L
s
.5673 .5289 m
.56719 .52902 L
s
.5673 .5289 m
.56664 .5294 L
s
1 .039 0 r
.84079 .44846 m
.841 .44867 L
s
1 .65 0 r
.56994 .44399 m
.56832 .44491 L
s
.56994 .44399 m
.56554 .44828 L
s
1 .09 0 r
.56664 .5294 m
.56731 .5297 L
s
.56664 .5294 m
.56719 .52902 L
s
.57 .5289 m
.56664 .5294 L
s
1 .65 0 r
.56554 .44828 m
.57002 .44967 L
s
.56554 .44828 m
.56832 .44491 L
s
.58781 .44101 m
.56554 .44828 L
s
1 .09 0 r
.56719 .52902 m
.56731 .5297 L
s
1 .026 0 r
.45896 .7993 m
.45898 .79936 L
s
.45899 .7991 m
.45896 .7993 L
s
.45919 .79925 m
.45896 .7993 L
s
.45901 .79916 m
.45899 .7991 L
s
.45899 .7991 m
.45919 .79925 L
s
.45919 .79925 m
.45898 .79936 L
s
.45901 .79916 m
.45919 .79925 L
s
.45819 .79915 m
.45919 .79925 L
s
1 .116 0 r
.4105 .50213 m
.41018 .50192 L
s
.41018 .50192 m
.41054 .5011 L
s
.41018 .50192 m
.40977 .50131 L
s
1 .026 0 r
.45898 .79936 m
.45901 .79916 L
s
1 .001 0 r
.78561 .58297 m
.78561 .58297 L
s
.78561 .58296 m
.78561 .58297 L
s
.78561 .58297 m
.78561 .58297 L
s
.78562 .58297 m
.78561 .58297 L
s
.78564 .58295 m
.78561 .58297 L
s
.78561 .58296 m
.78561 .58297 L
s
.78562 .58297 m
.78561 .58296 L
s
.78561 .58297 m
.78562 .58297 L
s
.78561 .58297 m
.78561 .58297 L
s
1 .116 0 r
.41054 .5011 m
.41087 .5013 L
s
.41054 .5011 m
.40977 .50131 L
s
1 0 0 r
.51411 .66403 m
.51411 .66403 L
s
.51411 .66402 m
.51411 .66403 L
s
.51411 .66403 m
.51411 .66403 L
s
.51411 .66403 m
.51411 .66402 L
s
.51411 .66402 m
.51411 .66403 L
s
.51411 .66403 m
.51411 .66403 L
s
.51411 .66403 m
.51411 .66403 L
s
.51409 .66403 m
.51411 .66403 L
s
.29845 .60998 m
.29845 .60997 L
s
1 .114 0 r
.35436 .47485 m
.35135 .47283 L
s
1 0 0 r
.51411 .66403 m
.51411 .66403 L
s
.29845 .60997 m
.29845 .60997 L
s
.29845 .60997 m
.29845 .60997 L
s
.29845 .60997 m
.29845 .60997 L
s
.29845 .60997 m
.29845 .60997 L
s
.29845 .60997 m
.29845 .60997 L
s
.29845 .60997 m
.29845 .60997 L
s
.29845 .60997 m
.29845 .60997 L
s
.29845 .60997 m
.29845 .60997 L
s
1 .116 0 r
.41087 .5013 m
.4105 .50213 L
s
.40977 .50131 m
.4105 .50213 L
s
.40977 .50131 m
.41087 .5013 L
s
1 .229 0 r
.50386 .50157 m
.50376 .50129 L
s
.50376 .50129 m
.50387 .49954 L
s
.50376 .50129 m
.50211 .50046 L
s
.50387 .49954 m
.50397 .49981 L
s
.50387 .49954 m
.50211 .50046 L
s
1 .016 0 r
.39946 .77147 m
.39949 .7715 L
s
.39949 .77135 m
.39946 .77147 L
s
.39961 .77145 m
.39946 .77147 L
s
.39952 .77138 m
.39949 .77135 L
s
.39949 .77135 m
.39961 .77145 L
s
1 .009 0 r
.7264 .55515 m
.72646 .55516 L
s
.72645 .55509 m
.7264 .55515 L
s
.7264 .55515 m
.72642 .55511 L
s
.72649 .55514 m
.7264 .55515 L
s
.72665 .55501 m
.7264 .55515 L
s
1 .016 0 r
.39961 .77145 m
.39949 .7715 L
s
.39952 .77138 m
.39961 .77145 L
s
.39902 .77133 m
.39961 .77145 L
s
1 .009 0 r
.72645 .55509 m
.72642 .55511 L
s
.72649 .55514 m
.72645 .55509 L
s
.72646 .55516 m
.72649 .55514 L
s
.72642 .55511 m
.72646 .55516 L
s
1 .459 0 r
.53531 .47452 m
.53574 .47399 L
s
.53574 .47399 m
.5353 .47047 L
s
.53574 .47399 m
.53182 .47286 L
s
1 .016 0 r
.39949 .7715 m
.39952 .77138 L
s
1 .166 0 r
.60392 .50122 m
.60432 .50096 L
s
.60432 .50096 m
.60389 .49975 L
s
.60432 .50096 m
.60277 .50084 L
s
1 .002 0 r
.67071 .69021 m
.67078 .6902 L
s
1 0 0 r
.45495 .63613 m
.45495 .63613 L
s
1 .229 0 r
.51089 .50093 m
.50211 .50046 L
s
1 .095 0 r
.29513 .44685 m
.29314 .44489 L
s
1 .002 0 r
.67077 .6902 m
.67076 .69021 L
s
.67076 .69019 m
.67077 .6902 L
s
.67078 .6902 m
.67077 .6902 L
s
.67076 .69019 m
.67076 .69019 L
s
.67076 .69019 m
.67078 .6902 L
s
.67078 .6902 m
.67076 .69021 L
s
.67076 .69019 m
.67078 .6902 L
s
.67076 .69021 m
.67076 .69019 L
s
1 .166 0 r
.60389 .49975 m
.60349 .50001 L
s
.60389 .49975 m
.60277 .50084 L
s
.60277 .50084 m
.60392 .50122 L
s
.60277 .50084 m
.60349 .50001 L
s
.60847 .49905 m
.60277 .50084 L
s
1 .459 0 r
.5353 .47047 m
.53488 .471 L
s
.5353 .47047 m
.53182 .47286 L
s
1 .043 0 r
.66628 .52765 m
.66655 .52772 L
s
.66654 .52734 m
.66628 .52765 L
s
.66628 .52765 m
.6664 .52743 L
s
.66669 .52764 m
.66628 .52765 L
s
.66759 .52705 m
.66628 .52765 L
s
.66655 .52772 m
.66669 .52764 L
s
.66669 .52764 m
.66654 .52734 L
s
.66654 .52734 m
.6664 .52743 L
s
1 .114 0 r
.35198 .47273 m
.35241 .47299 L
s
.3515 .47347 m
.35198 .47273 L
s
.35198 .47273 m
.35135 .47283 L
s
.35193 .47374 m
.3515 .47347 L
s
.3515 .47347 m
.35135 .47283 L
s
1 .229 0 r
.50211 .50046 m
.50386 .50157 L
s
.50211 .50046 m
.50397 .49981 L
s
1 .043 0 r
.6664 .52743 m
.66655 .52772 L
s
1 .017 0 r
.93917 .44626 m
.93923 .44625 L
s
.93921 .44611 m
.93917 .44626 L
s
.93917 .44626 m
.93914 .44617 L
s
.9393 .4462 m
.93917 .44626 L
s
.93944 .44588 m
.93917 .44626 L
s
.93921 .44611 m
.93914 .44617 L
s
.9393 .4462 m
.93921 .44611 L
s
.93923 .44625 m
.9393 .4462 L
s
.93914 .44617 m
.93923 .44625 L
s
1 .166 0 r
.60349 .50001 m
.60392 .50122 L
s
1 .008 0 r
.33997 .74356 m
.33999 .74358 L
s
.34 .74351 m
.33997 .74356 L
s
.34005 .74356 m
.33997 .74356 L
s
.34005 .74356 m
.33999 .74358 L
s
.34 .74351 m
.34005 .74356 L
s
.34001 .74353 m
.34005 .74356 L
s
.33978 .74348 m
.34005 .74356 L
s
.34001 .74353 m
.34 .74351 L
s
.33999 .74358 m
.34001 .74353 L
s
1 .114 0 r
.35241 .47299 m
.35193 .47374 L
s
.35135 .47283 m
.35241 .47299 L
s
1 .029 0 r
.55656 .79763 m
.55655 .79769 L
s
.55654 .79741 m
.55656 .79763 L
s
.55677 .79754 m
.55656 .79763 L
s
1 .114 0 r
.35135 .47283 m
.35193 .47374 L
s
1 .029 0 r
.55653 .79748 m
.55654 .79741 L
s
.55654 .79741 m
.55677 .79754 L
s
1 .229 0 r
.50397 .49981 m
.50386 .50157 L
s
1 .029 0 r
.55566 .79759 m
.55677 .79754 L
s
1 0 0 r
.61163 .66232 m
.61164 .66232 L
s
.39575 .60821 m
.39573 .6082 L
s
1 .323 0 r
.45172 .47294 m
.44053 .46944 L
s
1 0 0 r
.61164 .66232 m
.61164 .66232 L
s
.61164 .66231 m
.61164 .66232 L
s
.61164 .66232 m
.61164 .66232 L
s
.61164 .66232 m
.61164 .66231 L
s
.61164 .66231 m
.61164 .66232 L
s
.61164 .66232 m
.61164 .66232 L
s
.61164 .66232 m
.61164 .66232 L
s
.39574 .60821 m
.39574 .60821 L
s
.39574 .60821 m
.39574 .6082 L
s
.39574 .60821 m
.39573 .6082 L
s
.39574 .6082 m
.39574 .6082 L
s
.39574 .6082 m
.39573 .6082 L
s
.61164 .66232 m
.61164 .66232 L
s
.39573 .6082 m
.39574 .60821 L
s
.39573 .6082 m
.39574 .6082 L
s
.39574 .6082 m
.39574 .60821 L
s
1 .029 0 r
.55677 .79754 m
.55655 .79769 L
s
.55653 .79748 m
.55677 .79754 L
s
1 .459 0 r
.53182 .47286 m
.53531 .47452 L
s
.53182 .47286 m
.53488 .471 L
s
.54929 .47102 m
.53182 .47286 L
s
1 .029 0 r
.55655 .79769 m
.55653 .79748 L
s
1 .095 0 r
.29357 .44487 m
.29398 .44513 L
s
.2931 .44544 m
.29357 .44487 L
s
.29357 .44487 m
.29314 .44489 L
s
1 .22 0 r
.64057 .47254 m
.6419 .47282 L
s
.64183 .47088 m
.64057 .47254 L
s
.64057 .47254 m
.64109 .47131 L
s
.64265 .47239 m
.64057 .47254 L
s
.64707 .4691 m
.64057 .47254 L
s
1 .095 0 r
.29351 .4457 m
.2931 .44544 L
s
.2931 .44544 m
.29314 .44489 L
s
1 .22 0 r
.6419 .47282 m
.64265 .47239 L
s
.64265 .47239 m
.64183 .47088 L
s
.64183 .47088 m
.64109 .47131 L
s
1 .65 0 r
.56832 .44491 m
.57002 .44967 L
s
1 .095 0 r
.29398 .44513 m
.29351 .4457 L
s
.29314 .44489 m
.29398 .44513 L
s
.29314 .44489 m
.29351 .4457 L
s
1 .022 0 r
.49714 .76983 m
.49714 .76988 L
s
.49715 .76967 m
.49714 .76983 L
s
.49731 .76978 m
.49714 .76983 L
s
.49715 .76971 m
.49715 .76967 L
s
.49715 .76967 m
.49731 .76978 L
s
1 .003 0 r
.82439 .55325 m
.8244 .55325 L
s
.8244 .55322 m
.82439 .55325 L
s
.82439 .55325 m
.82439 .55323 L
s
.82442 .55324 m
.82439 .55325 L
s
.82447 .55319 m
.82439 .55325 L
s
.8244 .55322 m
.82439 .55323 L
s
.82442 .55324 m
.8244 .55322 L
s
.8244 .55325 m
.82442 .55324 L
s
.82439 .55323 m
.8244 .55325 L
s
1 .022 0 r
.49731 .76978 m
.49714 .76988 L
s
.49715 .76971 m
.49731 .76978 L
s
.49648 .76974 m
.49731 .76978 L
s
1 0 0 r
.55247 .63439 m
.55247 .63439 L
s
1 .003 0 r
.33648 .58026 m
.3364 .58022 L
s
1 .293 0 r
.39248 .44491 m
.38445 .43982 L
s
1 .022 0 r
.49714 .76988 m
.49715 .76971 L
s
1 .003 0 r
.33642 .58021 m
.33643 .58022 L
s
.33641 .58023 m
.33642 .58021 L
s
.33642 .58021 m
.3364 .58022 L
s
.33642 .58024 m
.33641 .58023 L
s
.33641 .58023 m
.3364 .58022 L
s
.33643 .58022 m
.33642 .58024 L
s
.3364 .58022 m
.33643 .58022 L
s
.3364 .58022 m
.33642 .58024 L
s
1 .459 0 r
.53488 .471 m
.53531 .47452 L
s
1 .22 0 r
.64109 .47131 m
.6419 .47282 L
s
1 .015 0 r
.76502 .52547 m
.7651 .52548 L
s
.76509 .52535 m
.76502 .52547 L
s
.76502 .52547 m
.76503 .52539 L
s
.76516 .52544 m
.76502 .52547 L
s
.7654 .52519 m
.76502 .52547 L
s
.76509 .52535 m
.76503 .52539 L
s
.76516 .52544 m
.76509 .52535 L
s
.7651 .52548 m
.76516 .52544 L
s
.76503 .52539 m
.7651 .52548 L
s
1 .062 0 r
.70463 .49824 m
.70497 .4983 L
s
.70494 .49775 m
.70463 .49824 L
s
.70463 .49824 m
.70471 .49789 L
s
.70521 .49815 m
.70463 .49824 L
s
.70627 .49716 m
.70463 .49824 L
s
1 .013 0 r
.43759 .74195 m
.43761 .74198 L
s
.43761 .74186 m
.43759 .74195 L
s
.43771 .74193 m
.43759 .74195 L
s
.43763 .74188 m
.43761 .74186 L
s
.43761 .74186 m
.43771 .74193 L
s
.43771 .74193 m
.43761 .74198 L
s
.43763 .74188 m
.43771 .74193 L
s
.43723 .74186 m
.43771 .74193 L
s
1 .062 0 r
.70494 .49775 m
.70471 .49789 L
s
.70521 .49815 m
.70494 .49775 L
s
1 .323 0 r
.44273 .47157 m
.44198 .47108 L
s
.44198 .47108 m
.4428 .46871 L
s
.44198 .47108 m
.44053 .46944 L
s
1 .062 0 r
.70497 .4983 m
.70521 .49815 L
s
1 .013 0 r
.43761 .74198 m
.43763 .74188 L
s
1 .001 0 r
.49323 .60644 m
.49323 .60644 L
s
.49323 .60644 m
.49323 .60643 L
s
.49323 .60644 m
.49323 .60644 L
s
1 0 0 r
.70937 .66061 m
.70938 .66061 L
s
1 .001 0 r
.49326 .60644 m
.49323 .60644 L
s
1 .006 0 r
.27715 .55227 m
.277 .55217 L
s
1 .001 0 r
.49323 .60643 m
.49323 .60643 L
s
.49323 .60643 m
.49323 .60644 L
s
1 0 0 r
.70938 .66061 m
.70938 .66061 L
s
.70938 .6606 m
.70938 .66061 L
s
.70938 .66061 m
.70938 .66061 L
s
.70938 .66061 m
.70938 .6606 L
s
.70938 .6606 m
.70938 .66061 L
s
.70938 .66061 m
.70938 .66061 L
s
.70938 .66061 m
.70938 .66061 L
s
1 .001 0 r
.49323 .60644 m
.49323 .60644 L
s
.49323 .60644 m
.49323 .60643 L
s
1 0 0 r
.70938 .66061 m
.70938 .66061 L
s
1 .001 0 r
.49323 .60643 m
.49323 .60644 L
s
1 .006 0 r
.27704 .55217 m
.27706 .55218 L
s
.27701 .5522 m
.27704 .55217 L
s
.27704 .55217 m
.277 .55217 L
s
.27703 .55222 m
.27701 .5522 L
s
.27701 .5522 m
.277 .55217 L
s
.27706 .55218 m
.27703 .55222 L
s
.277 .55217 m
.27706 .55218 L
s
1 .323 0 r
.4428 .46871 m
.44356 .46919 L
s
.4428 .46871 m
.44053 .46944 L
s
1 .006 0 r
.277 .55217 m
.27703 .55222 L
s
1 .062 0 r
.70471 .49789 m
.70497 .4983 L
s
1 .233 0 r
.68023 .44355 m
.68139 .44368 L
s
.68129 .44163 m
.68023 .44355 L
s
.68023 .44355 m
.68032 .4422 L
s
.68235 .4431 m
.68023 .44355 L
s
.6858 .43905 m
.68023 .44355 L
s
.68129 .44163 m
.68032 .4422 L
s
.68235 .4431 m
.68129 .44163 L
s
.68139 .44368 m
.68235 .4431 L
s
1 .005 0 r
.37805 .714 m
.37807 .71401 L
s
.37807 .71396 m
.37805 .714 L
s
.3781 .714 m
.37805 .714 L
s
.37808 .71397 m
.37807 .71396 L
s
.37807 .71396 m
.3781 .714 L
s
.3781 .714 m
.37807 .71401 L
s
.37808 .71397 m
.3781 .714 L
s
.37792 .71395 m
.3781 .714 L
s
.37807 .71401 m
.37808 .71397 L
s
1 .021 0 r
.59415 .76815 m
.59494 .76806 L
s
1 0 0 r
.65021 .63265 m
.65021 .63265 L
s
1 .007 0 r
.43398 .57845 m
.43374 .57839 L
s
1 .741 0 r
.49004 .44296 m
.46242 .43797 L
s
1 .021 0 r
.59481 .76813 m
.59479 .76818 L
s
.59478 .76798 m
.59481 .76813 L
s
.59494 .76806 m
.59481 .76813 L
s
1 .007 0 r
.43379 .57844 m
.43377 .57842 L
s
.43377 .57842 m
.43379 .57837 L
s
.43377 .57842 m
.43374 .57839 L
s
1 .021 0 r
.59476 .76802 m
.59478 .76798 L
s
.59478 .76798 m
.59494 .76806 L
s
1 .007 0 r
.43379 .57837 m
.4338 .57839 L
s
.43379 .57837 m
.43374 .57839 L
s
.43374 .57839 m
.43379 .57844 L
s
.43374 .57839 m
.4338 .57839 L
s
.4338 .57839 m
.43379 .57844 L
s
1 .021 0 r
.59494 .76806 m
.59479 .76818 L
s
.59476 .76802 m
.59494 .76806 L
s
.59479 .76818 m
.59476 .76802 L
s
1 .323 0 r
.44053 .46944 m
.44273 .47157 L
s
.44053 .46944 m
.44356 .46919 L
s
.44356 .46919 m
.44273 .47157 L
s
1 .233 0 r
.68032 .4422 m
.68139 .44368 L
s
1 .006 0 r
.86329 .52345 m
.86332 .52345 L
s
.86331 .52339 m
.86329 .52345 L
s
.86329 .52345 m
.86329 .52341 L
s
.86335 .52343 m
.86329 .52345 L
s
.86342 .52332 m
.86329 .52345 L
s
.86331 .52339 m
.86329 .52341 L
s
.86335 .52343 m
.86331 .52339 L
s
.86332 .52345 m
.86335 .52343 L
s
.86329 .52341 m
.86332 .52345 L
s
1 .015 0 r
.53537 .74027 m
.53537 .7403 L
s
.53537 .74015 m
.53537 .74027 L
s
.53549 .74022 m
.53537 .74027 L
s
.53537 .74018 m
.53537 .74015 L
s
.53537 .74015 m
.53549 .74022 L
s
1 .001 0 r
.31859 .68602 m
.31858 .68603 L
s
.31858 .68601 m
.31859 .68602 L
s
.31859 .68602 m
.31857 .68602 L
s
.31858 .68602 m
.31859 .68602 L
s
.31854 .68601 m
.31859 .68602 L
s
.31857 .68602 m
.31858 .68603 L
s
.31858 .68601 m
.31857 .68602 L
s
.31858 .68602 m
.31858 .68601 L
s
.31858 .68603 m
.31858 .68602 L
s
.59096 .60467 m
.59096 .60467 L
s
.59096 .60467 m
.59096 .60467 L
s
.59096 .60467 m
.59095 .60467 L
s
.59096 .60467 m
.59096 .60467 L
s
.59096 .60467 m
.59095 .60467 L
s
.59095 .60467 m
.59096 .60467 L
s
.59095 .60467 m
.59096 .60467 L
s
.59098 .60467 m
.59095 .60467 L
s
.59096 .60467 m
.59096 .60467 L
s
1 .015 0 r
.53489 .74023 m
.53549 .74022 L
s
1 .016 0 r
.37463 .55044 m
.37414 .55021 L
s
1 .015 0 r
.53549 .74022 m
.53537 .7403 L
s
.53537 .74018 m
.53549 .74022 L
s
.53537 .7403 m
.53537 .74018 L
s
1 .016 0 r
.37423 .55033 m
.37419 .5503 L
s
.37419 .5503 m
.37424 .55018 L
s
.37419 .5503 m
.37414 .55021 L
s
.37424 .55018 m
.37429 .55022 L
s
.37424 .55018 m
.37414 .55021 L
s
.37429 .55022 m
.37423 .55033 L
s
.37414 .55021 m
.37423 .55033 L
s
.37414 .55021 m
.37429 .55022 L
s
1 .293 0 r
.38611 .43956 m
.3872 .44017 L
s
.38492 .44151 m
.38611 .43956 L
s
.38611 .43956 m
.38445 .43982 L
s
1 .073 0 r
.74345 .46863 m
.74379 .46866 L
s
.74375 .46802 m
.74345 .46863 L
s
.74345 .46863 m
.74344 .46822 L
s
.7441 .46846 m
.74345 .46863 L
s
.74507 .46717 m
.74345 .46863 L
s
1 .293 0 r
.386 .44212 m
.38492 .44151 L
s
.38492 .44151 m
.38445 .43982 L
s
1 .022 0 r
.80381 .4957 m
.80391 .49571 L
s
.8039 .49552 m
.80381 .4957 L
s
.80381 .4957 m
.8038 .49558 L
s
.80401 .49565 m
.80381 .4957 L
s
.80428 .49526 m
.80381 .4957 L
s
.8039 .49552 m
.8038 .49558 L
s
.80401 .49565 m
.8039 .49552 L
s
.80391 .49571 m
.80401 .49565 L
s
1 .073 0 r
.74375 .46802 m
.74344 .46822 L
s
.7441 .46846 m
.74375 .46802 L
s
0 .04 1 r
.43733 .44708 m
.44881 .4414 L
s
.44881 .4414 m
.43829 .41229 L
s
.44881 .4414 m
.41128 .43856 L
s
1 .741 0 r
.4679 .44222 m
.46686 .44137 L
s
.46686 .44137 m
.46801 .43573 L
s
.46686 .44137 m
.46242 .43797 L
s
1 .073 0 r
.74379 .46866 m
.7441 .46846 L
s
1 .022 0 r
.8038 .49558 m
.80391 .49571 L
s
1 .073 0 r
.74344 .46822 m
.74379 .46866 L
s
1 .008 0 r
.47581 .71234 m
.47582 .71235 L
s
.47582 .71228 m
.47581 .71234 L
s
.47588 .71232 m
.47581 .71234 L
s
.47583 .71229 m
.47582 .71228 L
s
.47582 .71228 m
.47588 .71232 L
s
1 .01 0 r
.53137 .5767 m
.53137 .57669 L
s
.53137 .57669 m
.53137 .57661 L
s
.53137 .57669 m
.53129 .57666 L
s
1 .008 0 r
.47588 .71232 m
.47582 .71235 L
s
.47583 .71229 m
.47588 .71232 L
s
.47557 .71229 m
.47588 .71232 L
s
1 .01 0 r
.53137 .57661 m
.53137 .57662 L
s
.53137 .57661 m
.53129 .57666 L
s
.53129 .57666 m
.53137 .5767 L
s
.53129 .57666 m
.53137 .57662 L
s
.53169 .57665 m
.53129 .57666 L
s
1 .008 0 r
.47582 .71235 m
.47583 .71229 L
s
1 0 0 r
.74815 .63091 m
.74815 .63091 L
s
1 .022 0 r
.31522 .52239 m
.31465 .52199 L
s
1 .01 0 r
.53137 .57662 m
.53137 .5767 L
s
1 .741 0 r
.46801 .43573 m
.46905 .43657 L
s
.46801 .43573 m
.46242 .43797 L
s
1 .022 0 r
.31477 .52197 m
.31485 .52203 L
s
.31467 .52212 m
.31477 .52197 L
s
.31477 .52197 m
.31465 .52199 L
s
.31475 .52217 m
.31467 .52212 L
s
.31467 .52212 m
.31465 .52199 L
s
.31485 .52203 m
.31475 .52217 L
s
.31465 .52199 m
.31485 .52203 L
s
.31465 .52199 m
.31475 .52217 L
s
1 .028 0 r
.36076 .82028 m
.36082 .82035 L
s
.36083 .82008 m
.36076 .82028 L
s
.36102 .82026 m
.36076 .82028 L
s
.36088 .82015 m
.36083 .82008 L
s
.36083 .82008 m
.36102 .82026 L
s
.36102 .82026 m
.36082 .82035 L
s
.36088 .82015 m
.36102 .82026 L
s
.36003 .82003 m
.36102 .82026 L
s
.36082 .82035 m
.36088 .82015 L
s
1 .293 0 r
.3872 .44017 m
.386 .44212 L
s
.38445 .43982 m
.3872 .44017 L
s
.38445 .43982 m
.386 .44212 L
s
1 .003 0 r
.41625 .68434 m
.41626 .68435 L
s
.41626 .68432 m
.41625 .68434 L
s
.41627 .68434 m
.41625 .68434 L
s
.41626 .68433 m
.41626 .68432 L
s
.41626 .68432 m
.41627 .68434 L
s
.41627 .68434 m
.41626 .68435 L
s
.41626 .68433 m
.41627 .68434 L
s
.41618 .68432 m
.41627 .68434 L
s
.41626 .68435 m
.41626 .68433 L
s
1 0 0 r
.6889 .60289 m
.68891 .60289 L
s
.68891 .60289 m
.6889 .60289 L
s
.6889 .60289 m
.68891 .60289 L
s
.68891 .60289 m
.6889 .60289 L
s
.68892 .60289 m
.6889 .60289 L
s
.68891 .60289 m
.68891 .60289 L
s
.68891 .60289 m
.68891 .60289 L
s
.68891 .60289 m
.68891 .60289 L
s
.68891 .60289 m
.68891 .60289 L
s
1 .013 0 r
.63277 .7386 m
.63323 .73852 L
s
0 .04 1 r
.63678 .44003 m
.62362 .44095 L
s
.62254 .4061 m
.63678 .44003 L
s
.63678 .44003 m
.60337 .42989 L
s
.64293 .41692 m
.63678 .44003 L
s
.56563 .35383 m
.63678 .44003 L
s
1 .039 0 r
.47233 .5486 m
.47088 .54835 L
s
1 .024 0 r
.25575 .49431 m
.25523 .49383 L
s
1 .013 0 r
.63316 .73857 m
.63314 .7386 L
s
.63314 .73847 m
.63316 .73857 L
s
.63323 .73852 m
.63316 .73857 L
s
.63312 .7385 m
.63314 .73847 L
s
.63314 .73847 m
.63323 .73852 L
s
1 .039 0 r
.47117 .54858 m
.47112 .54852 L
s
.47112 .54852 m
.47118 .54823 L
s
.47112 .54852 m
.47088 .54835 L
s
1 .013 0 r
.63323 .73852 m
.63314 .7386 L
s
.63312 .7385 m
.63323 .73852 L
s
1 .039 0 r
.47118 .54823 m
.47123 .54829 L
s
.47118 .54823 m
.47088 .54835 L
s
1 .013 0 r
.63314 .7386 m
.63312 .7385 L
s
1 .039 0 r
.47088 .54835 m
.47117 .54858 L
s
.47088 .54835 m
.47123 .54829 L
s
.47123 .54829 m
.47117 .54858 L
s
1 .024 0 r
.25534 .49382 m
.25544 .49389 L
s
.25522 .49396 m
.25534 .49382 L
s
.25534 .49382 m
.25523 .49383 L
s
.25532 .49403 m
.25522 .49396 L
s
.25522 .49396 m
.25523 .49383 L
s
.25544 .49389 m
.25532 .49403 L
s
.25523 .49383 m
.25544 .49389 L
s
.25523 .49383 m
.25532 .49403 L
s
0 .04 1 r
.43829 .41229 m
.42667 .41762 L
s
.43829 .41229 m
.41128 .43856 L
s
1 .009 0 r
.90234 .49355 m
.90237 .49355 L
s
.90237 .49347 m
.90234 .49355 L
s
.90234 .49355 m
.90233 .4935 L
s
.90241 .49352 m
.90234 .49355 L
s
.9025 .49336 m
.90234 .49355 L
s
.90237 .49347 m
.90233 .4935 L
s
.90241 .49352 m
.90237 .49347 L
s
.90237 .49355 m
.90241 .49352 L
s
.90233 .4935 m
.90237 .49355 L
s
1 .007 0 r
.62943 .57493 m
.62944 .57491 L
s
.62944 .57491 m
.62943 .57486 L
s
.62944 .57491 m
.62938 .57491 L
s
.62943 .57486 m
.62941 .57488 L
s
.62943 .57486 m
.62938 .57491 L
s
.62938 .57491 m
.62943 .57493 L
s
.62938 .57491 m
.62941 .57488 L
s
.62961 .57484 m
.62938 .57491 L
s
.62941 .57488 m
.62943 .57493 L
s
1 0 0 r
.35674 .65632 m
.35674 .65632 L
s
.35674 .65631 m
.35674 .65632 L
s
.35674 .65632 m
.35674 .65632 L
s
.35674 .65632 m
.35674 .65632 L
s
.35674 .65631 m
.35674 .65632 L
s
.35674 .65632 m
.35674 .65632 L
s
.35673 .65631 m
.35674 .65632 L
s
.35674 .65632 m
.35674 .65631 L
s
.35674 .65632 m
.35674 .65632 L
s
1 .009 0 r
.5737 .71063 m
.5737 .71065 L
s
.5737 .71056 m
.5737 .71063 L
s
.57376 .7106 m
.5737 .71063 L
s
.57343 .71063 m
.57376 .7106 L
s
1 .068 0 r
.41291 .52052 m
.4107 .51964 L
s
1 .009 0 r
.57369 .71058 m
.5737 .71056 L
s
.5737 .71056 m
.57376 .7106 L
s
.57376 .7106 m
.5737 .71065 L
s
.57369 .71058 m
.57376 .7106 L
s
.5737 .71065 m
.57369 .71058 L
s
1 .077 0 r
.7826 .43876 m
.7829 .43876 L
s
.78285 .43809 m
.7826 .43876 L
s
.7826 .43876 m
.7825 .43832 L
s
.78325 .43853 m
.7826 .43876 L
s
.784 .43708 m
.7826 .43876 L
s
1 .026 0 r
.8428 .46581 m
.84291 .46581 L
s
.84288 .46558 m
.8428 .46581 L
s
.8428 .46581 m
.84277 .46566 L
s
.84303 .46573 m
.8428 .46581 L
s
.84328 .46524 m
.8428 .46581 L
s
1 .077 0 r
.78285 .43809 m
.7825 .43832 L
s
.78325 .43853 m
.78285 .43809 L
s
1 .026 0 r
.84288 .46558 m
.84277 .46566 L
s
.84303 .46573 m
.84288 .46558 L
s
.84291 .46581 m
.84303 .46573 L
s
0 .04 1 r
.41128 .43856 m
.43733 .44708 L
s
.41128 .43856 m
.42667 .41762 L
s
.54668 .3928 m
.41128 .43856 L
s
1 .077 0 r
.7829 .43876 m
.78325 .43853 L
s
1 .068 0 r
.41113 .52012 m
.41094 .52 L
s
.41094 .52 m
.41116 .51952 L
s
.41094 .52 m
.4107 .51964 L
s
1 .026 0 r
.84277 .46566 m
.84291 .46581 L
s
1 .068 0 r
.41116 .51952 m
.41135 .51964 L
s
.41116 .51952 m
.4107 .51964 L
s
1 .043 0 r
.56895 .54715 m
.569 .54708 L
s
.569 .54708 m
.56894 .54675 L
s
.569 .54708 m
.56862 .547 L
s
.56894 .54675 m
.56889 .54682 L
s
.56894 .54675 m
.56862 .547 L
s
1 .039 0 r
.45897 .81871 m
.45901 .8188 L
s
.45901 .81841 m
.45897 .81871 L
s
.45931 .81863 m
.45897 .81871 L
s
1 .077 0 r
.7825 .43832 m
.7829 .43876 L
s
1 .043 0 r
.56862 .547 m
.56895 .54715 L
s
.56862 .547 m
.56889 .54682 L
s
.57025 .54676 m
.56862 .547 L
s
1 .039 0 r
.45905 .8185 m
.45901 .81841 L
s
.45901 .81841 m
.45931 .81863 L
s
.45931 .81863 m
.45901 .8188 L
s
.45905 .8185 m
.45931 .81863 L
s
.45782 .81849 m
.45931 .81863 L
s
1 .575 0 r
.61121 .4382 m
.61443 .43873 L
s
.61429 .43368 m
.61121 .4382 L
s
.61121 .4382 m
.6121 .43487 L
s
.61662 .43754 m
.61121 .4382 L
s
.62702 .4282 m
.61121 .4382 L
s
1 .043 0 r
.56889 .54682 m
.56895 .54715 L
s
1 .068 0 r
.41135 .51964 m
.41113 .52012 L
s
.4107 .51964 m
.41113 .52012 L
s
.4107 .51964 m
.41135 .51964 L
s
0 1 .511 r
.55698 .43812 m
.56289 .43773 L
s
.56263 .41566 m
.55698 .43812 L
s
.55698 .43812 m
.54939 .4242 L
s
.5761 .4291 m
.55698 .43812 L
s
.58665 .37929 m
.55698 .43812 L
s
1 .039 0 r
.45901 .8188 m
.45905 .8185 L
s
1 .004 0 r
.51415 .68264 m
.51415 .68265 L
s
.51415 .68261 m
.51415 .68264 L
s
.51418 .68263 m
.51415 .68264 L
s
.51415 .68262 m
.51415 .68261 L
s
.51415 .68261 m
.51418 .68263 L
s
.51418 .68263 m
.51415 .68265 L
s
.51415 .68262 m
.51418 .68263 L
s
.51403 .68262 m
.51418 .68263 L
s
1 0 0 r
.78706 .60111 m
.78706 .60111 L
s
.78706 .60111 m
.78706 .60111 L
s
.78706 .60111 m
.78706 .60111 L
s
.78706 .60111 m
.78706 .60111 L
s
.78707 .60111 m
.78706 .60111 L
s
.78706 .60111 m
.78706 .60111 L
s
.78706 .60111 m
.78706 .60111 L
s
.78706 .60111 m
.78706 .60111 L
s
.78706 .60111 m
.78706 .60111 L
s
.29721 .62828 m
.29721 .62828 L
s
1 .075 0 r
.35343 .49241 m
.35145 .4911 L
s
1 .004 0 r
.51415 .68265 m
.51415 .68262 L
s
1 .741 0 r
.46242 .43797 m
.4679 .44222 L
s
.46242 .43797 m
.46905 .43657 L
s
1 .575 0 r
.61429 .43368 m
.6121 .43487 L
s
.61662 .43754 m
.61429 .43368 L
s
.61443 .43873 m
.61662 .43754 L
s
1 .525 0 r
.5737 .46546 m
.575 .46468 L
s
.575 .46468 m
.57363 .46082 L
s
.575 .46468 m
.57005 .4643 L
s
1 .026 0 r
.39905 .79074 m
.39909 .79081 L
s
.3991 .79055 m
.39905 .79074 L
s
.39929 .79071 m
.39905 .79074 L
s
.39914 .79061 m
.3991 .79055 L
s
.3991 .79055 m
.39929 .79071 L
s
.39929 .79071 m
.39909 .79081 L
s
.39914 .79061 m
.39929 .79071 L
s
.39833 .79053 m
.39929 .79071 L
s
1 .141 0 r
.50645 .51905 m
.50639 .51887 L
s
.50639 .51887 m
.50646 .51778 L
s
.50639 .51887 m
.50537 .51836 L
s
1 .525 0 r
.57363 .46082 m
.57232 .46159 L
s
.57363 .46082 m
.57005 .4643 L
s
1 .026 0 r
.39909 .79081 m
.39914 .79061 L
s
1 .141 0 r
.50646 .51778 m
.50652 .51796 L
s
.50646 .51778 m
.50537 .51836 L
s
1 .075 0 r
.35186 .49103 m
.35214 .4912 L
s
.35154 .49152 m
.35186 .49103 L
s
.35186 .49103 m
.35145 .4911 L
s
.35182 .49169 m
.35154 .49152 L
s
.35154 .49152 m
.35145 .4911 L
s
1 .741 0 r
.46905 .43657 m
.4679 .44222 L
s
1 .003 0 r
.72768 .57307 m
.72769 .57307 L
s
.72769 .57305 m
.72768 .57307 L
s
.72768 .57307 m
.72768 .57305 L
s
.7277 .57307 m
.72768 .57307 L
s
.72775 .57303 m
.72768 .57307 L
s
.72769 .57305 m
.72768 .57305 L
s
.7277 .57307 m
.72769 .57305 L
s
.72769 .57307 m
.7277 .57307 L
s
1 .525 0 r
.57005 .4643 m
.5737 .46546 L
s
.57005 .4643 m
.57232 .46159 L
s
.58815 .45845 m
.57005 .4643 L
s
1 .003 0 r
.72768 .57305 m
.72769 .57307 L
s
1 .001 0 r
.45458 .65459 m
.45459 .65459 L
s
.45459 .65459 m
.45458 .65459 L
s
.45459 .65459 m
.45458 .65459 L
s
.45459 .65459 m
.45459 .65459 L
s
.45459 .65459 m
.45459 .65459 L
s
.45459 .65459 m
.45459 .65459 L
s
.45459 .65459 m
.45459 .65459 L
s
.45457 .65459 m
.45459 .65459 L
s
.45459 .65459 m
.45459 .65459 L
s
1 .006 0 r
.67151 .70897 m
.67171 .70891 L
s
1 .141 0 r
.51081 .51865 m
.50537 .51836 L
s
1 .066 0 r
.29387 .46427 m
.29247 .46291 L
s
1 .006 0 r
.67169 .70894 m
.67167 .70895 L
s
.67167 .70889 m
.67169 .70894 L
s
.67171 .70891 m
.67169 .70894 L
s
.67166 .70891 m
.67167 .70889 L
s
.67167 .70889 m
.67171 .70891 L
s
.67171 .70891 m
.67167 .70895 L
s
.67166 .70891 m
.67171 .70891 L
s
.67167 .70895 m
.67166 .70891 L
s
1 .075 0 r
.35214 .4912 m
.35182 .49169 L
s
.35145 .4911 m
.35214 .4912 L
s
.35145 .4911 m
.35182 .49169 L
s
1 .141 0 r
.50537 .51836 m
.50645 .51905 L
s
.50537 .51836 m
.50652 .51796 L
s
.50652 .51796 m
.50645 .51905 L
s
1 .02 0 r
.66776 .54519 m
.66789 .54523 L
s
.66788 .54505 m
.66776 .54519 L
s
.66776 .54519 m
.66782 .54509 L
s
.66795 .54519 m
.66776 .54519 L
s
.66837 .54491 m
.66776 .54519 L
s
.66789 .54523 m
.66795 .54519 L
s
.66795 .54519 m
.66788 .54505 L
s
.66788 .54505 m
.66782 .54509 L
s
1 .336 0 r
.53914 .49118 m
.53945 .49076 L
s
.53945 .49076 m
.53913 .48818 L
s
.53945 .49076 m
.53656 .48994 L
s
1 .011 0 r
.94153 .46355 m
.94157 .46355 L
s
.94156 .46345 m
.94153 .46355 L
s
.94153 .46355 m
.94151 .46349 L
s
.94162 .46351 m
.94153 .46355 L
s
.94171 .4633 m
.94153 .46355 L
s
.94156 .46345 m
.94151 .46349 L
s
.94162 .46351 m
.94156 .46345 L
s
1 .1 0 r
.60618 .51808 m
.60642 .51791 L
s
.60642 .51791 m
.60616 .51718 L
s
.60642 .51791 m
.60548 .51785 L
s
1 .011 0 r
.94157 .46355 m
.94162 .46351 L
s
1 .02 0 r
.66782 .54509 m
.66789 .54523 L
s
1 .011 0 r
.94151 .46349 m
.94157 .46355 L
s
1 .014 0 r
.33912 .76269 m
.33916 .76272 L
s
.33916 .76259 m
.33912 .76269 L
s
.33926 .76268 m
.33912 .76269 L
s
.33926 .76268 m
.33916 .76272 L
s
.33916 .76259 m
.33926 .76268 L
s
.3392 .76262 m
.33926 .76268 L
s
.33877 .76254 m
.33926 .76268 L
s
.3392 .76262 m
.33916 .76259 L
s
1 .1 0 r
.60616 .51718 m
.60592 .51735 L
s
.60616 .51718 m
.60548 .51785 L
s
.60548 .51785 m
.60618 .51808 L
s
.60548 .51785 m
.60592 .51735 L
s
.60893 .51677 m
.60548 .51785 L
s
1 .014 0 r
.33916 .76272 m
.3392 .76262 L
s
1 .043 0 r
.55716 .817 m
.55714 .81709 L
s
.55714 .81668 m
.55716 .817 L
s
.55747 .81687 m
.55716 .817 L
s
1 .066 0 r
.29277 .46289 m
.29306 .46308 L
s
.29244 .46329 m
.29277 .46289 L
s
.29277 .46289 m
.29247 .46291 L
s
1 .043 0 r
.55712 .81677 m
.55714 .81668 L
s
.55714 .81668 m
.55747 .81687 L
s
.55582 .81694 m
.55747 .81687 L
s
1 .003 0 r
.6121 .68093 m
.61222 .68091 L
s
1 0 0 r
.39504 .62652 m
.39504 .62652 L
s
1 .229 0 r
.45132 .49051 m
.44336 .48805 L
s
1 .055 0 r
.23426 .4361 m
.23332 .43488 L
s
1 .003 0 r
.6122 .68092 m
.61219 .68093 L
s
.61219 .6809 m
.6122 .68092 L
s
.61222 .68091 m
.6122 .68092 L
s
.61219 .6809 m
.61219 .6809 L
s
.61219 .6809 m
.61222 .68091 L
s
1 .066 0 r
.29273 .46348 m
.29244 .46329 L
s
.29244 .46329 m
.29247 .46291 L
s
1 .336 0 r
.53913 .48818 m
.53882 .48859 L
s
.53913 .48818 m
.53656 .48994 L
s
1 .003 0 r
.61222 .68091 m
.61219 .68093 L
s
.61219 .6809 m
.61222 .68091 L
s
.61219 .68093 m
.61219 .6809 L
s
1 .043 0 r
.55747 .81687 m
.55714 .81709 L
s
.55712 .81677 m
.55747 .81687 L
s
.55714 .81709 m
.55712 .81677 L
s
1 .066 0 r
.29306 .46308 m
.29273 .46348 L
s
.29247 .46291 m
.29306 .46308 L
s
.29247 .46291 m
.29273 .46348 L
s
1 .029 0 r
.88196 .43578 m
.88206 .43578 L
s
.88204 .43552 m
.88196 .43578 L
s
.88196 .43578 m
.8819 .43562 L
s
.8822 .43568 m
.88196 .43578 L
s
.88241 .43512 m
.88196 .43578 L
s
1 .1 0 r
.60592 .51735 m
.60618 .51808 L
s
1 .029 0 r
.88204 .43552 m
.8819 .43562 L
s
.8822 .43568 m
.88204 .43552 L
s
.88206 .43578 m
.8822 .43568 L
s
.8819 .43562 m
.88206 .43578 L
s
1 .336 0 r
.53656 .48994 m
.53914 .49118 L
s
.53656 .48994 m
.53882 .48859 L
s
.54942 .4886 m
.53656 .48994 L
s
1 .035 0 r
.49739 .78909 m
.4974 .78917 L
s
.4974 .78883 m
.49739 .78909 L
s
.49767 .78901 m
.49739 .78909 L
s
.49742 .7889 m
.4974 .78883 L
s
.4974 .78883 m
.49767 .78901 L
s
1 .055 0 r
.23353 .43488 m
.23378 .43506 L
s
.23323 .43519 m
.23353 .43488 L
s
.23353 .43488 m
.23332 .43488 L
s
1 .035 0 r
.49767 .78901 m
.4974 .78917 L
s
.49742 .7889 m
.49767 .78901 L
s
.49632 .78895 m
.49767 .78901 L
s
1 .055 0 r
.23348 .43536 m
.23323 .43519 L
s
.23323 .43519 m
.23332 .43488 L
s
1 .001 0 r
.82608 .57123 m
.82609 .57123 L
s
.82609 .57122 m
.82608 .57123 L
s
.82608 .57123 m
.82608 .57122 L
s
.82609 .57122 m
.82608 .57123 L
s
.82611 .57121 m
.82608 .57123 L
s
.82609 .57122 m
.82608 .57122 L
s
.82609 .57122 m
.82609 .57122 L
s
.82609 .57123 m
.82609 .57122 L
s
.82608 .57122 m
.82609 .57123 L
s
.55264 .65286 m
.55264 .65286 L
s
.55264 .65286 m
.55264 .65286 L
s
.55265 .65286 m
.55264 .65286 L
s
.55264 .65286 m
.55264 .65286 L
s
.55264 .65286 m
.55265 .65286 L
s
.55262 .65286 m
.55265 .65286 L
s
1 0 0 r
.33545 .59843 m
.33544 .59842 L
s
1 .22 0 r
.39175 .46234 m
.38569 .45853 L
s
1 .001 0 r
.55265 .65286 m
.55264 .65286 L
s
.55264 .65286 m
.55265 .65286 L
s
.55264 .65286 m
.55264 .65286 L
s
1 0 0 r
.33544 .59842 m
.33544 .59842 L
s
.33544 .59842 m
.33544 .59842 L
s
.33544 .59842 m
.33544 .59842 L
s
.33544 .59842 m
.33544 .59842 L
s
.33544 .59842 m
.33544 .59842 L
s
.33544 .59842 m
.33544 .59842 L
s
.33544 .59842 m
.33544 .59842 L
s
.33544 .59842 m
.33544 .59842 L
s
1 .035 0 r
.4974 .78917 m
.49742 .7889 L
s
1 .055 0 r
.23378 .43506 m
.23348 .43536 L
s
.23332 .43488 m
.23378 .43506 L
s
.23332 .43488 m
.23348 .43536 L
s
.808 1 0 r
.49136 .43617 m
.49171 .43498 L
s
.49171 .43498 m
.49148 .4257 L
s
.49171 .43498 m
.48215 .43111 L
s
.542 1 0 r
.52731 .43699 m
.53115 .43494 L
s
.53115 .43494 m
.52731 .42419 L
s
.53115 .43494 m
.51735 .43389 L
s
1 .575 0 r
.6121 .43487 m
.61443 .43873 L
s
1 .229 0 r
.44493 .48956 m
.44439 .4892 L
s
.44439 .4892 m
.44498 .48752 L
s
.44439 .4892 m
.44336 .48805 L
s
.44498 .48752 m
.44552 .48787 L
s
.44498 .48752 m
.44336 .48805 L
s
1 .525 0 r
.57232 .46159 m
.5737 .46546 L
s
1 .151 0 r
.64326 .48903 m
.64418 .48924 L
s
.64413 .48789 m
.64326 .48903 L
s
.64326 .48903 m
.64362 .4882 L
s
.6447 .48893 m
.64326 .48903 L
s
.64774 .48669 m
.64326 .48903 L
s
.64418 .48924 m
.6447 .48893 L
s
.6447 .48893 m
.64413 .48789 L
s
.64413 .48789 m
.64362 .4882 L
s
1 .336 0 r
.53882 .48859 m
.53914 .49118 L
s
1 .023 0 r
.43742 .76109 m
.43745 .76114 L
s
.43745 .76092 m
.43742 .76109 L
s
.43762 .76106 m
.43742 .76109 L
s
.43748 .76097 m
.43745 .76092 L
s
.43745 .76092 m
.43762 .76106 L
s
.43762 .76106 m
.43745 .76114 L
s
.43748 .76097 m
.43762 .76106 L
s
.43675 .76093 m
.43762 .76106 L
s
1 .007 0 r
.76655 .54319 m
.76658 .5432 L
s
.76658 .54313 m
.76655 .54319 L
s
.76655 .54319 m
.76655 .54315 L
s
.76661 .54318 m
.76655 .54319 L
s
.76672 .54306 m
.76655 .54319 L
s
.76658 .54313 m
.76655 .54315 L
s
.76661 .54318 m
.76658 .54313 L
s
.76658 .5432 m
.76661 .54318 L
s
.76655 .54315 m
.76658 .5432 L
s
.542 1 0 r
.52731 .42419 m
.52345 .4262 L
s
.52731 .42419 m
.51735 .43389 L
s
1 .023 0 r
.43745 .76114 m
.43748 .76097 L
s
1 .002 0 r
.71038 .67923 m
.71044 .67921 L
s
1 0 0 r
.49308 .62476 m
.49308 .62476 L
s
1 .168 0 r
.33212 .43413 m
.32863 .43061 L
s
1 .002 0 r
.27579 .5703 m
.27574 .57027 L
s
.71043 .67922 m
.71043 .67922 L
s
.71043 .6792 m
.71043 .67922 L
s
.71044 .67921 m
.71043 .67922 L
s
.71042 .67921 m
.71043 .6792 L
s
.71043 .6792 m
.71044 .67921 L
s
.27575 .57026 m
.27576 .57027 L
s
.27574 .57028 m
.27575 .57026 L
s
.27575 .57026 m
.27574 .57027 L
s
.27575 .57028 m
.27574 .57028 L
s
.27574 .57028 m
.27574 .57027 L
s
.71043 .67922 m
.71042 .67921 L
s
.71044 .67921 m
.71043 .67922 L
s
.71042 .67921 m
.71044 .67921 L
s
.27576 .57027 m
.27575 .57028 L
s
.27574 .57027 m
.27576 .57027 L
s
.27574 .57027 m
.27575 .57028 L
s
.808 1 0 r
.49148 .4257 m
.49113 .42686 L
s
.49148 .4257 m
.48215 .43111 L
s
.542 1 0 r
.51735 .43389 m
.52731 .43699 L
s
.51735 .43389 m
.52345 .4262 L
s
.56752 .41722 m
.51735 .43389 L
s
1 .035 0 r
.70633 .5155 m
.70652 .51554 L
s
.70651 .51522 m
.70633 .5155 L
s
.70633 .5155 m
.70637 .51531 L
s
.70666 .51545 m
.70633 .5155 L
s
.70726 .51489 m
.70633 .5155 L
s
.70651 .51522 m
.70637 .51531 L
s
.70666 .51545 m
.70651 .51522 L
s
.70652 .51554 m
.70666 .51545 L
s
1 .151 0 r
.64362 .4882 m
.64418 .48924 L
s
1 .035 0 r
.70637 .51531 m
.70652 .51554 L
s
1 .229 0 r
.44336 .48805 m
.44493 .48956 L
s
.44336 .48805 m
.44552 .48787 L
s
.44552 .48787 m
.44493 .48956 L
s
0 .04 1 r
.62254 .4061 m
.60337 .42989 L
s
.64293 .41692 m
.62254 .4061 L
s
1 .012 0 r
.37742 .73299 m
.37744 .73302 L
s
.37745 .7329 m
.37742 .73299 L
s
.37753 .73298 m
.37742 .73299 L
s
.37747 .73293 m
.37745 .7329 L
s
.37745 .7329 m
.37753 .73298 L
s
.37753 .73298 m
.37744 .73302 L
s
.37747 .73293 m
.37753 .73298 L
s
.37711 .73287 m
.37753 .73298 L
s
.37744 .73302 m
.37747 .73293 L
s
1 .034 0 r
.59453 .78737 m
.59582 .78723 L
s
1 0 0 r
.65089 .65113 m
.65091 .65113 L
s
1 .001 0 r
.43348 .59663 m
.43345 .59663 L
s
1 .607 0 r
.48985 .46039 m
.46712 .45633 L
s
1 0 0 r
.65091 .65113 m
.65091 .65113 L
s
.65091 .65112 m
.65091 .65113 L
s
.65091 .65113 m
.65091 .65113 L
s
.6509 .65112 m
.65091 .65112 L
s
.65091 .65112 m
.65091 .65113 L
s
1 .001 0 r
.43345 .59663 m
.43345 .59663 L
s
.43345 .59663 m
.43345 .59662 L
s
.43345 .59663 m
.43345 .59663 L
s
.43345 .59662 m
.43345 .59662 L
s
.43345 .59662 m
.43345 .59663 L
s
1 0 0 r
.65091 .65113 m
.65091 .65113 L
s
.6509 .65112 m
.65091 .65113 L
s
.65091 .65113 m
.6509 .65112 L
s
1 .001 0 r
.43345 .59663 m
.43345 .59663 L
s
.43345 .59663 m
.43345 .59662 L
s
.43345 .59662 m
.43345 .59663 L
s
1 .034 0 r
.5956 .78735 m
.59556 .78742 L
s
.59556 .78709 m
.5956 .78735 L
s
.59582 .78723 m
.5956 .78735 L
s
.59552 .78717 m
.59556 .78709 L
s
.59556 .78709 m
.59582 .78723 L
s
.59582 .78723 m
.59556 .78742 L
s
.59552 .78717 m
.59582 .78723 L
s
0 1 .511 r
.56263 .41566 m
.54939 .4242 L
s
.5761 .4291 m
.56263 .41566 L
s
1 .034 0 r
.59556 .78742 m
.59552 .78717 L
s
1 .22 0 r
.38694 .45832 m
.38776 .4588 L
s
.38604 .45979 m
.38694 .45832 L
s
.38694 .45832 m
.38569 .45853 L
s
1 .172 0 r
.68254 .45982 m
.6834 .45992 L
s
.68333 .45839 m
.68254 .45982 L
s
.68254 .45982 m
.68261 .45882 L
s
.68412 .45948 m
.68254 .45982 L
s
.68668 .4565 m
.68254 .45982 L
s
1 .22 0 r
.38686 .46027 m
.38604 .45979 L
s
.38604 .45979 m
.38569 .45853 L
s
1 .172 0 r
.68333 .45839 m
.68261 .45882 L
s
.68412 .45948 m
.68333 .45839 L
s
1 .028 0 r
.53583 .75938 m
.53582 .75944 L
s
.53582 .75916 m
.53583 .75938 L
s
.53604 .75929 m
.53583 .75938 L
s
1 .004 0 r
.31754 .70484 m
.31752 .70485 L
s
.31752 .70481 m
.31754 .70484 L
s
.31754 .70484 m
.3175 .70484 L
s
.31753 .70482 m
.31754 .70484 L
s
.31741 .70479 m
.31754 .70484 L
s
1 .172 0 r
.6834 .45992 m
.68412 .45948 L
s
1 .004 0 r
.3175 .70484 m
.31752 .70485 L
s
.31752 .70481 m
.3175 .70484 L
s
.31753 .70482 m
.31752 .70481 L
s
1 .003 0 r
.86522 .54126 m
.86523 .54127 L
s
.86523 .54124 m
.86522 .54126 L
s
.86522 .54126 m
.86522 .54125 L
s
.86524 .54126 m
.86522 .54126 L
s
.86528 .54121 m
.86522 .54126 L
s
1 .028 0 r
.53582 .75922 m
.53582 .75916 L
s
.53582 .75916 m
.53604 .75929 L
s
1 .003 0 r
.86523 .54124 m
.86522 .54125 L
s
.86524 .54126 m
.86523 .54124 L
s
.86523 .54127 m
.86524 .54126 L
s
.86522 .54125 m
.86523 .54127 L
s
1 .004 0 r
.31752 .70485 m
.31753 .70482 L
s
1 0 0 r
.59134 .623 m
.59134 .623 L
s
1 .028 0 r
.53494 .75931 m
.53604 .75929 L
s
1 .005 0 r
.37381 .56847 m
.37365 .5684 L
s
1 .575 0 r
.4302 .43216 m
.41329 .42274 L
s
1 .028 0 r
.53604 .75929 m
.53582 .75944 L
s
.53582 .75922 m
.53604 .75929 L
s
1 .005 0 r
.37368 .56844 m
.37366 .56843 L
s
.37366 .56843 m
.37368 .56839 L
s
.37366 .56843 m
.37365 .5684 L
s
.37368 .56839 m
.3737 .5684 L
s
.37368 .56839 m
.37365 .5684 L
s
.3737 .5684 m
.37368 .56844 L
s
.37365 .5684 m
.37368 .56844 L
s
.37365 .5684 m
.3737 .5684 L
s
1 .028 0 r
.53582 .75944 m
.53582 .75922 L
s
1 .607 0 r
.47163 .45984 m
.47077 .4591 L
s
.47077 .4591 m
.47172 .45446 L
s
.47077 .4591 m
.46712 .45633 L
s
1 .168 0 r
.32938 .43058 m
.33012 .43105 L
s
.32854 .43159 m
.32938 .43058 L
s
.32938 .43058 m
.32863 .43061 L
s
.32928 .43206 m
.32854 .43159 L
s
.32854 .43159 m
.32863 .43061 L
s
1 .172 0 r
.68261 .45882 m
.6834 .45992 L
s
1 .22 0 r
.38776 .4588 m
.38686 .46027 L
s
.38569 .45853 m
.38776 .4588 L
s
.38569 .45853 m
.38686 .46027 L
s
1 .012 0 r
.80556 .51324 m
.80561 .51325 L
s
.8056 .51314 m
.80556 .51324 L
s
.80556 .51324 m
.80555 .51318 L
s
.80566 .51321 m
.80556 .51324 L
s
.80581 .513 m
.80556 .51324 L
s
.8056 .51314 m
.80555 .51318 L
s
.80566 .51321 m
.8056 .51314 L
s
.80561 .51325 m
.80566 .51321 L
s
1 .607 0 r
.47172 .45446 m
.47258 .45519 L
s
.47172 .45446 m
.46712 .45633 L
s
1 .012 0 r
.80555 .51318 m
.80561 .51325 L
s
1 .018 0 r
.47585 .73133 m
.47586 .73137 L
s
.47586 .73119 m
.47585 .73133 L
s
.476 .73129 m
.47585 .73133 L
s
.47588 .73123 m
.47586 .73119 L
s
.47586 .73119 m
.476 .73129 L
s
.476 .73129 m
.47586 .73137 L
s
.47588 .73123 m
.476 .73129 L
s
.4753 .73123 m
.476 .73129 L
s
.47586 .73137 m
.47588 .73123 L
s
1 .001 0 r
.53168 .59485 m
.53168 .59484 L
s
.53168 .59484 m
.53168 .59483 L
s
.53168 .59484 m
.53167 .59484 L
s
.53168 .59483 m
.53168 .59483 L
s
.53168 .59483 m
.53167 .59484 L
s
.53167 .59484 m
.53168 .59485 L
s
.53167 .59484 m
.53168 .59483 L
s
.53172 .59484 m
.53167 .59484 L
s
1 0 0 r
.74938 .64939 m
.74939 .64939 L
s
1 .01 0 r
.31407 .54028 m
.31381 .5401 L
s
1 0 0 r
.74938 .64939 m
.74939 .64939 L
s
.74938 .64939 m
.74938 .64939 L
s
.74938 .64939 m
.74939 .64939 L
s
.74939 .64939 m
.74938 .64939 L
s
.74939 .64939 m
.74939 .64939 L
s
1 .001 0 r
.53168 .59483 m
.53168 .59485 L
s
1 0 0 r
.74938 .64939 m
.74938 .64939 L
s
.74938 .64939 m
.74939 .64939 L
s
.74939 .64939 m
.74938 .64939 L
s
1 .047 0 r
.74523 .4857 m
.74546 .48572 L
s
.74543 .4853 m
.74523 .4857 L
s
.74523 .4857 m
.74523 .48543 L
s
.74566 .48559 m
.74523 .4857 L
s
.74628 .48477 m
.74523 .4857 L
s
.808 1 0 r
.48215 .43111 m
.49136 .43617 L
s
.48215 .43111 m
.49113 .42686 L
s
.5285 .43018 m
.48215 .43111 L
s
1 .047 0 r
.74543 .4853 m
.74523 .48543 L
s
.74566 .48559 m
.74543 .4853 L
s
1 .168 0 r
.33012 .43105 m
.32928 .43206 L
s
.32863 .43061 m
.33012 .43105 L
s
1 .01 0 r
.31386 .54009 m
.3139 .54012 L
s
.31382 .54016 m
.31386 .54009 L
s
.31386 .54009 m
.31381 .5401 L
s
.31386 .54019 m
.31382 .54016 L
s
.31382 .54016 m
.31381 .5401 L
s
1 .047 0 r
.74546 .48572 m
.74566 .48559 L
s
1 .01 0 r
.3139 .54012 m
.31386 .54019 L
s
.31381 .5401 m
.3139 .54012 L
s
.31381 .5401 m
.31386 .54019 L
s
1 .168 0 r
.32863 .43061 m
.32928 .43206 L
s
1 .047 0 r
.74523 .48543 m
.74546 .48572 L
s
1 .008 0 r
.41581 .70318 m
.41582 .7032 L
s
.41582 .70312 m
.41581 .70318 L
s
.41588 .70317 m
.41581 .70318 L
s
.41584 .70314 m
.41582 .70312 L
s
.41582 .70312 m
.41588 .70317 L
s
.41588 .70317 m
.41582 .7032 L
s
.41584 .70314 m
.41588 .70317 L
s
.41558 .70311 m
.41588 .70317 L
s
.41582 .7032 m
.41584 .70314 L
s
1 .023 0 r
.63336 .7577 m
.63422 .75754 L
s
1 0 0 r
.68982 .62123 m
.68982 .62123 L
s
1 .013 0 r
.47204 .56665 m
.47157 .56657 L
s
.25427 .51206 m
.25398 .5118 L
s
.47166 .56664 m
.47164 .56662 L
s
.47164 .56662 m
.47166 .56652 L
s
.47164 .56662 m
.47157 .56657 L
s
.47166 .56652 m
.47168 .56654 L
s
.47166 .56652 m
.47157 .56657 L
s
1 .023 0 r
.63409 .75763 m
.63405 .75768 L
s
.63404 .75746 m
.63409 .75763 L
s
.63422 .75754 m
.63409 .75763 L
s
1 .013 0 r
.47157 .56657 m
.47166 .56664 L
s
.47157 .56657 m
.47168 .56654 L
s
1 .023 0 r
.63401 .75751 m
.63404 .75746 L
s
.63404 .75746 m
.63422 .75754 L
s
1 .013 0 r
.47168 .56654 m
.47166 .56664 L
s
.25404 .51179 m
.2541 .51183 L
s
.25398 .51187 m
.25404 .51179 L
s
.25404 .51179 m
.25398 .5118 L
s
1 .023 0 r
.63422 .75754 m
.63405 .75768 L
s
.63401 .75751 m
.63422 .75754 L
s
1 .013 0 r
.25403 .51191 m
.25398 .51187 L
s
.25398 .51187 m
.25398 .5118 L
s
1 .023 0 r
.63405 .75768 m
.63401 .75751 L
s
1 .013 0 r
.2541 .51183 m
.25403 .51191 L
s
.25398 .5118 m
.2541 .51183 L
s
.25398 .5118 m
.25403 .51191 L
s
0 .04 1 r
.60337 .42989 m
.62362 .44095 L
s
1 .168 0 r
.72261 .42987 m
.72328 .42988 L
s
.72319 .4284 m
.72261 .42987 L
s
.72261 .42987 m
.72241 .4289 L
s
.72406 .42938 m
.72261 .42987 L
s
.72575 .42621 m
.72261 .42987 L
s
0 .197 1 r
.44113 .46265 m
.45218 .45697 L
s
.45218 .45697 m
.44202 .42885 L
s
.45218 .45697 m
.4159 .45425 L
s
1 .168 0 r
.72319 .4284 m
.72241 .4289 L
s
.72406 .42938 m
.72319 .4284 L
s
.72328 .42988 m
.72406 .42938 L
s
1 .005 0 r
.90449 .51121 m
.90451 .51121 L
s
.9045 .51117 m
.90449 .51121 L
s
.90449 .51121 m
.90448 .51119 L
s
.90453 .5112 m
.90449 .51121 L
s
.90457 .51112 m
.90449 .51121 L
s
.9045 .51117 m
.90448 .51119 L
s
.90453 .5112 m
.9045 .51117 L
s
.90451 .51121 m
.90453 .5112 L
s
.90448 .51119 m
.90451 .51121 L
s
1 .002 0 r
.35585 .67499 m
.35586 .67499 L
s
.35586 .67497 m
.35585 .67499 L
s
.35587 .67499 m
.35585 .67499 L
s
.35587 .67499 m
.35586 .67499 L
s
.35586 .67497 m
.35587 .67499 L
s
.35586 .67498 m
.35587 .67499 L
s
.3558 .67496 m
.35587 .67499 L
s
.35586 .67498 m
.35586 .67497 L
s
.35586 .67499 m
.35586 .67498 L
s
1 .001 0 r
.63016 .59305 m
.63017 .59305 L
s
.63017 .59305 m
.63016 .59304 L
s
.63017 .59305 m
.63016 .59305 L
s
.63016 .59304 m
.63016 .59304 L
s
.63016 .59304 m
.63016 .59305 L
s
.63016 .59305 m
.63016 .59305 L
s
.63016 .59305 m
.63016 .59304 L
s
.63019 .59304 m
.63016 .59305 L
s
.63016 .59304 m
.63016 .59305 L
s
1 .019 0 r
.57431 .72958 m
.57429 .72962 L
s
.57429 .72943 m
.57431 .72958 L
s
.57444 .72951 m
.57431 .72958 L
s
.5737 .72958 m
.57444 .72951 L
s
1 .032 0 r
.41229 .53842 m
.41124 .53801 L
s
1 .019 0 r
.57427 .72947 m
.57429 .72943 L
s
.57429 .72943 m
.57444 .72951 L
s
.57444 .72951 m
.57429 .72962 L
s
.57427 .72947 m
.57444 .72951 L
s
0 1 .511 r
.56289 .43773 m
.5761 .4291 L
s
1 .019 0 r
.57429 .72962 m
.57427 .72947 L
s
1 .607 0 r
.46712 .45633 m
.47163 .45984 L
s
.46712 .45633 m
.47258 .45519 L
s
1 .032 0 r
.41145 .53824 m
.41136 .53818 L
s
.41136 .53818 m
.41146 .53795 L
s
.41136 .53818 m
.41124 .53801 L
s
.41146 .53795 m
.41155 .53801 L
s
.41146 .53795 m
.41124 .53801 L
s
1 .168 0 r
.72241 .4289 m
.72328 .42988 L
s
1 .032 0 r
.41155 .53801 m
.41145 .53824 L
s
.41124 .53801 m
.41145 .53824 L
s
.41124 .53801 m
.41155 .53801 L
s
1 .016 0 r
.84473 .48319 m
.8448 .4832 L
s
.84479 .48305 m
.84473 .48319 L
s
.84473 .48319 m
.84471 .4831 L
s
.84487 .48314 m
.84473 .48319 L
s
.84503 .48285 m
.84473 .48319 L
s
.84479 .48305 m
.84471 .4831 L
s
.84487 .48314 m
.84479 .48305 L
s
.8448 .4832 m
.84487 .48314 L
s
.84471 .4831 m
.8448 .4832 L
s
1 .053 0 r
.78445 .4557 m
.78466 .4557 L
s
.78462 .45523 m
.78445 .4557 L
s
.78445 .4557 m
.78438 .4554 L
s
.7849 .45554 m
.78445 .4557 L
s
.78542 .45455 m
.78445 .4557 L
s
1 .607 0 r
.47258 .45519 m
.47163 .45984 L
s
1 .014 0 r
.57007 .56494 m
.57008 .56492 L
s
.57008 .56492 m
.57006 .56481 L
s
.57008 .56492 m
.56996 .56489 L
s
.57006 .56481 m
.57005 .56483 L
s
.57006 .56481 m
.56996 .56489 L
s
.56996 .56489 m
.57007 .56494 L
s
.56996 .56489 m
.57005 .56483 L
s
.57049 .56481 m
.56996 .56489 L
s
1 .053 0 r
.78462 .45523 m
.78438 .4554 L
s
.7849 .45554 m
.78462 .45523 L
s
1 .012 0 r
.51434 .70147 m
.51434 .70149 L
s
.51434 .70138 m
.51434 .70147 L
s
.51443 .70144 m
.51434 .70147 L
s
.51434 .7014 m
.51434 .70138 L
s
.51434 .70138 m
.51443 .70144 L
s
1 .014 0 r
.57005 .56483 m
.57007 .56494 L
s
1 .053 0 r
.78466 .4557 m
.7849 .45554 L
s
1 .012 0 r
.51443 .70144 m
.51434 .70149 L
s
.51434 .7014 m
.51443 .70144 L
s
.51397 .70143 m
.51443 .70144 L
s
1 0 0 r
.29596 .64679 m
.29596 .64679 L
s
.29596 .64678 m
.29596 .64679 L
s
.29596 .64679 m
.29596 .64679 L
s
.29596 .64678 m
.29596 .64679 L
s
.29596 .64678 m
.29596 .64679 L
s
.29596 .64678 m
.29596 .64679 L
s
.29596 .64678 m
.29596 .64678 L
s
.29596 .64679 m
.29596 .64679 L
s
.29596 .64679 m
.29596 .64678 L
s
.78851 .61946 m
.78851 .61946 L
s
1 .043 0 r
.35248 .51017 m
.35134 .50942 L
s
1 .012 0 r
.51434 .70149 m
.51434 .7014 L
s
1 .053 0 r
.78438 .4554 m
.78466 .4557 L
s
.808 1 0 r
.49113 .42686 m
.49136 .43617 L
s
0 .197 1 r
.44202 .42885 m
.43083 .4342 L
s
.44202 .42885 m
.4159 .45425 L
s
.808 1 0 r
.5794 .42777 m
.58498 .42833 L
s
.58478 .41784 m
.5794 .42777 L
s
.5794 .42777 m
.5795 .42072 L
s
.59025 .42542 m
.5794 .42777 L
s
.6071 .40407 m
.5794 .42777 L
s
1 .043 0 r
.35158 .50938 m
.35174 .50948 L
s
.3514 .50966 m
.35158 .50938 L
s
.35158 .50938 m
.35134 .50942 L
s
.35156 .50976 m
.3514 .50966 L
s
.3514 .50966 m
.35134 .50942 L
s
1 .039 0 r
.3987 .81025 m
.39877 .81035 L
s
.39878 .80996 m
.3987 .81025 L
s
.39906 .81021 m
.3987 .81025 L
s
.39885 .81006 m
.39878 .80996 L
s
.39878 .80996 m
.39906 .81021 L
s
.39906 .81021 m
.39877 .81035 L
s
.39885 .81006 m
.39906 .81021 L
s
.39763 .80994 m
.39906 .81021 L
s
1 .043 0 r
.35174 .50948 m
.35156 .50976 L
s
.35134 .50942 m
.35174 .50948 L
s
.35134 .50942 m
.35156 .50976 L
s
1 .039 0 r
.39877 .81035 m
.39885 .81006 L
s
1 .07 0 r
.50856 .53676 m
.50852 .53667 L
s
.50852 .53667 m
.50856 .53613 L
s
.50852 .53667 m
.50801 .53642 L
s
.50856 .53613 m
.50859 .53622 L
s
.50856 .53613 m
.50801 .53642 L
s
1 .004 0 r
.4543 .67328 m
.4543 .67329 L
s
.45431 .67325 m
.4543 .67328 L
s
.45434 .67327 m
.4543 .67328 L
s
.45431 .67326 m
.45431 .67325 L
s
.45431 .67325 m
.45434 .67327 L
s
.45434 .67327 m
.4543 .67329 L
s
.45431 .67326 m
.45434 .67327 L
s
.45418 .67325 m
.45434 .67327 L
s
.4543 .67329 m
.45431 .67326 L
s
1 0 0 r
.72886 .59124 m
.72886 .59124 L
s
.72886 .59124 m
.72886 .59124 L
s
.72886 .59124 m
.72886 .59124 L
s
.72886 .59124 m
.72886 .59124 L
s
.72887 .59124 m
.72886 .59124 L
s
.72886 .59124 m
.72886 .59124 L
s
.72886 .59124 m
.72886 .59124 L
s
.72886 .59124 m
.72886 .59124 L
s
.72886 .59124 m
.72886 .59124 L
s
1 .013 0 r
.67231 .72792 m
.67278 .7278 L
s
1 .07 0 r
.51073 .53656 m
.50801 .53642 L
s
1 .042 0 r
.2926 .48188 m
.2917 .48102 L
s
1 .013 0 r
.67272 .72786 m
.67269 .72789 L
s
.67268 .72776 m
.67272 .72786 L
s
.67278 .7278 m
.67272 .72786 L
s
.67265 .72779 m
.67268 .72776 L
s
.67268 .72776 m
.67278 .7278 L
s
.67278 .7278 m
.67269 .72789 L
s
.67265 .72779 m
.67278 .7278 L
s
1 .07 0 r
.50801 .53642 m
.50856 .53676 L
s
.50801 .53642 m
.50859 .53622 L
s
1 .013 0 r
.67269 .72789 m
.67265 .72779 L
s
.542 1 0 r
.52345 .4262 m
.52731 .43699 L
s
0 .197 1 r
.4159 .45425 m
.44113 .46265 L
s
.4159 .45425 m
.43083 .4342 L
s
.5468 .41044 m
.4159 .45425 L
s
1 .07 0 r
.50859 .53622 m
.50856 .53676 L
s
0 .197 1 r
.63469 .45423 m
.62193 .45533 L
s
.62091 .42146 m
.63469 .45423 L
s
.63469 .45423 m
.60236 .4445 L
s
.64061 .43206 m
.63469 .45423 L
s
.56587 .37162 m
.63469 .45423 L
s
1 .042 0 r
.29189 .481 m
.29208 .48113 L
s
.29168 .48126 m
.29189 .481 L
s
.29189 .481 m
.2917 .48102 L
s
.29187 .48138 m
.29168 .48126 L
s
.29168 .48126 m
.2917 .48102 L
s
1 .023 0 r
.33832 .78205 m
.33838 .78211 L
s
.33839 .78188 m
.33832 .78205 L
s
.33855 .78204 m
.33832 .78205 L
s
.33855 .78204 m
.33838 .78211 L
s
.33839 .78188 m
.33855 .78204 L
s
.33845 .78194 m
.33855 .78204 L
s
.33774 .7818 m
.33855 .78204 L
s
.33845 .78194 m
.33839 .78188 L
s
1 .042 0 r
.29208 .48113 m
.29187 .48138 L
s
.2917 .48102 m
.29208 .48113 L
s
1 .023 0 r
.33838 .78211 m
.33845 .78194 L
s
1 .042 0 r
.2917 .48102 m
.29187 .48138 L
s
1 .007 0 r
.94389 .48107 m
.94392 .48107 L
s
.94391 .48101 m
.94389 .48107 L
s
.94389 .48107 m
.94388 .48103 L
s
.94395 .48104 m
.94389 .48107 L
s
.944 .48092 m
.94389 .48107 L
s
.94391 .48101 m
.94388 .48103 L
s
.94395 .48104 m
.94391 .48101 L
s
.94392 .48107 m
.94395 .48104 L
s
.94388 .48103 m
.94392 .48107 L
s
1 .006 0 r
.66897 .56307 m
.66901 .56308 L
s
.66901 .56302 m
.66897 .56307 L
s
.66897 .56307 m
.66899 .56303 L
s
.66903 .56306 m
.66897 .56307 L
s
.66916 .56298 m
.66897 .56307 L
s
.66901 .56308 m
.66903 .56306 L
s
.66903 .56306 m
.66901 .56302 L
s
.66901 .56302 m
.66899 .56303 L
s
1 .459 0 r
.61488 .45365 m
.61747 .45411 L
s
.61735 .45003 m
.61488 .45365 L
s
.61488 .45365 m
.6156 .45101 L
s
.61922 .45313 m
.61488 .45365 L
s
.62758 .4457 m
.61488 .45365 L
s
1 .006 0 r
.66899 .56303 m
.66901 .56308 L
s
1 0 0 r
.39433 .64504 m
.39434 .64504 L
s
.39434 .64504 m
.39433 .64504 L
s
.39434 .64504 m
.39433 .64504 L
s
.39434 .64504 m
.39434 .64504 L
s
.39434 .64504 m
.39434 .64504 L
s
.39434 .64504 m
.39434 .64504 L
s
.39434 .64504 m
.39434 .64504 L
s
.39432 .64504 m
.39434 .64504 L
s
.39434 .64504 m
.39434 .64504 L
s
1 .01 0 r
.61258 .69974 m
.61295 .69968 L
s
1 .141 0 r
.45091 .50827 m
.44598 .50676 L
s
1 .038 0 r
.23265 .45357 m
.23201 .45274 L
s
1 .01 0 r
.61289 .69972 m
.61288 .69974 L
s
.61288 .69964 m
.61289 .69972 L
s
.61295 .69968 m
.61289 .69972 L
s
.61286 .69966 m
.61288 .69964 L
s
.61288 .69964 m
.61295 .69968 L
s
.61295 .69968 m
.61288 .69974 L
s
.61286 .69966 m
.61295 .69968 L
s
.61288 .69974 m
.61286 .69966 L
s
1 .575 0 r
.41678 .4221 m
.4188 .42319 L
s
.41458 .42607 m
.41678 .4221 L
s
.41678 .4221 m
.41329 .42274 L
s
.808 1 0 r
.58478 .41784 m
.5795 .42072 L
s
.59025 .42542 m
.58478 .41784 L
s
1 .575 0 r
.4166 .42716 m
.41458 .42607 L
s
.41458 .42607 m
.41329 .42274 L
s
1 .39 0 r
.57771 .4813 m
.57868 .48069 L
s
.57868 .48069 m
.57765 .47781 L
s
.57868 .48069 m
.57498 .48042 L
s
1 .459 0 r
.61735 .45003 m
.6156 .45101 L
s
.61922 .45313 m
.61735 .45003 L
s
1 .048 0 r
.60805 .53533 m
.60817 .53524 L
s
.60817 .53524 m
.60804 .53489 L
s
.60817 .53524 m
.60771 .53521 L
s
1 .39 0 r
.57765 .47781 m
.57668 .47841 L
s
.57765 .47781 m
.57498 .48042 L
s
1 .048 0 r
.60804 .53489 m
.60793 .53497 L
s
.60804 .53489 m
.60771 .53521 L
s
.60771 .53521 m
.60805 .53533 L
s
.60771 .53521 m
.60793 .53497 L
s
.60939 .53469 m
.60771 .53521 L
s
1 .459 0 r
.61747 .45411 m
.61922 .45313 L
s
1 .39 0 r
.57498 .48042 m
.57771 .4813 L
s
.57498 .48042 m
.57668 .47841 L
s
.5885 .47609 m
.57498 .48042 L
s
1 .215 0 r
.54293 .50803 m
.54313 .50775 L
s
.54313 .50775 m
.54292 .50609 L
s
.54313 .50775 m
.54127 .50723 L
s
1 .019 0 r
.88408 .45303 m
.88415 .45303 L
s
.88413 .45285 m
.88408 .45303 L
s
.88408 .45303 m
.88404 .45292 L
s
.88424 .45296 m
.88408 .45303 L
s
.88438 .45259 m
.88408 .45303 L
s
1 .038 0 r
.23215 .45274 m
.23233 .45286 L
s
.23195 .45295 m
.23215 .45274 L
s
.23215 .45274 m
.23201 .45274 L
s
1 .019 0 r
.88413 .45285 m
.88404 .45292 L
s
.88424 .45296 m
.88413 .45285 L
s
.88415 .45303 m
.88424 .45296 L
s
1 .038 0 r
.23212 .45307 m
.23195 .45295 L
s
.23195 .45295 m
.23201 .45274 L
s
1 .019 0 r
.88404 .45292 m
.88415 .45303 L
s
1 .048 0 r
.60793 .53497 m
.60805 .53533 L
s
1 .038 0 r
.23233 .45286 m
.23212 .45307 L
s
.23201 .45274 m
.23233 .45286 L
s
1 .055 0 r
.82387 .42549 m
.82406 .42548 L
s
.82402 .425 m
.82387 .42549 L
s
.82387 .42549 m
.82375 .42518 L
s
.82432 .42529 m
.82387 .42549 L
s
.8247 .42422 m
.82387 .42549 L
s
1 .051 0 r
.49774 .80858 m
.49776 .8087 L
s
.49776 .80819 m
.49774 .80858 L
s
.49816 .80846 m
.49774 .80858 L
s
1 .215 0 r
.54292 .50609 m
.54273 .50636 L
s
.54292 .50609 m
.54127 .50723 L
s
1 .038 0 r
.23201 .45274 m
.23212 .45307 L
s
1 .051 0 r
.49778 .8083 m
.49776 .80819 L
s
.49776 .80819 m
.49816 .80846 L
s
.808 1 0 r
.58498 .42833 m
.59025 .42542 L
s
1 .141 0 r
.44695 .5077 m
.44661 .50747 L
s
.44661 .50747 m
.44698 .50643 L
s
.44661 .50747 m
.44598 .50676 L
s
1 .055 0 r
.82402 .425 m
.82375 .42518 L
s
.82432 .42529 m
.82402 .425 L
s
1 .051 0 r
.49816 .80846 m
.49776 .8087 L
s
.49778 .8083 m
.49816 .80846 L
s
.49616 .80837 m
.49816 .80846 L
s
1 .141 0 r
.44698 .50643 m
.44731 .50666 L
s
.44698 .50643 m
.44598 .50676 L
s
1 .055 0 r
.82406 .42548 m
.82432 .42529 L
s
1 .005 0 r
.55293 .67154 m
.55293 .67155 L
s
.55293 .6715 m
.55293 .67154 L
s
.55297 .67152 m
.55293 .67154 L
s
1 0 0 r
.82776 .58943 m
.82776 .58943 L
s
.82776 .58943 m
.82776 .58943 L
s
.82776 .58943 m
.82776 .58943 L
s
.82776 .58943 m
.82776 .58943 L
s
.82777 .58943 m
.82776 .58943 L
s
.82776 .58943 m
.82776 .58943 L
s
.82776 .58943 m
.82776 .58943 L
s
.82776 .58943 m
.82776 .58943 L
s
.82776 .58943 m
.82776 .58943 L
s
1 .005 0 r
.55293 .67151 m
.55293 .6715 L
s
.55293 .6715 m
.55297 .67152 L
s
.55277 .67153 m
.55297 .67152 L
s
1 0 0 r
.3344 .6168 m
.3344 .6168 L
s
1 .151 0 r
.39102 .47996 m
.38684 .47737 L
s
1 .005 0 r
.55297 .67152 m
.55293 .67155 L
s
.55293 .67151 m
.55297 .67152 L
s
.55293 .67155 m
.55293 .67151 L
s
1 .055 0 r
.82375 .42518 m
.82406 .42548 L
s
1 .051 0 r
.49776 .8087 m
.49778 .8083 L
s
1 .215 0 r
.54127 .50723 m
.54293 .50803 L
s
.54127 .50723 m
.54273 .50636 L
s
.54955 .50637 m
.54127 .50723 L
s
1 .141 0 r
.44598 .50676 m
.44695 .5077 L
s
.44598 .50676 m
.44731 .50666 L
s
.44731 .50666 m
.44695 .5077 L
s
1 .038 0 r
.43734 .78047 m
.43739 .78055 L
s
.4374 .78019 m
.43734 .78047 L
s
.43768 .78041 m
.43734 .78047 L
s
.43745 .78027 m
.4374 .78019 L
s
.4374 .78019 m
.43768 .78041 L
s
.43768 .78041 m
.43739 .78055 L
s
.43745 .78027 m
.43768 .78041 L
s
.43626 .7802 m
.43768 .78041 L
s
.973 1 0 r
.49636 .45288 m
.49665 .45179 L
s
.49665 .45179 m
.49644 .44376 L
s
.49665 .45179 m
.48838 .44847 L
s
1 .215 0 r
.54273 .50636 m
.54293 .50803 L
s
1 .038 0 r
.43739 .78055 m
.43745 .78027 L
s
1 .002 0 r
.768 .56118 m
.76801 .56118 L
s
.76801 .56116 m
.768 .56118 L
s
.768 .56118 m
.768 .56117 L
s
.76802 .56117 m
.768 .56118 L
s
.76805 .56114 m
.768 .56118 L
s
.76801 .56116 m
.768 .56117 L
s
.76802 .56117 m
.76801 .56116 L
s
.76801 .56118 m
.76802 .56117 L
s
.768 .56117 m
.76801 .56118 L
s
1 .001 0 r
.49293 .64329 m
.49293 .64329 L
s
.49293 .64329 m
.49293 .64329 L
s
.49294 .64329 m
.49293 .64329 L
s
.49293 .64329 m
.49293 .64329 L
s
.49293 .64329 m
.49294 .64329 L
s
.49294 .64329 m
.49293 .64329 L
s
.49293 .64329 m
.49294 .64329 L
s
.49291 .64329 m
.49294 .64329 L
s
.49293 .64329 m
.49293 .64329 L
s
1 .006 0 r
.7114 .69805 m
.71159 .69799 L
s
1 0 0 r
.27441 .58852 m
.2744 .58852 L
s
1 .121 0 r
.33106 .45161 m
.32852 .44908 L
s
1 0 0 r
.27441 .58852 m
.27441 .58852 L
s
.2744 .58852 m
.27441 .58852 L
s
.27441 .58852 m
.2744 .58852 L
s
.27441 .58852 m
.2744 .58852 L
s
.2744 .58852 m
.2744 .58852 L
s
.27441 .58852 m
.27441 .58852 L
s
.2744 .58852 m
.27441 .58852 L
s
.2744 .58852 m
.27441 .58852 L
s
0 1 .511 r
.54939 .4242 m
.56289 .43773 L
s
1 .006 0 r
.71157 .69801 m
.71155 .69803 L
s
.71155 .69797 m
.71157 .69801 L
s
.71159 .69799 m
.71157 .69801 L
s
.71153 .69799 m
.71155 .69797 L
s
.71155 .69797 m
.71159 .69799 L
s
.71155 .69803 m
.71153 .69799 L
s
.71159 .69799 m
.71155 .69803 L
s
.71153 .69799 m
.71159 .69799 L
s
0 1 .331 r
.55922 .45151 m
.56477 .45128 L
s
.56452 .43053 m
.55922 .45151 L
s
.55922 .45151 m
.55214 .43859 L
s
.57712 .44314 m
.55922 .45151 L
s
.587 .39699 m
.55922 .45151 L
s
1 .417 0 r
.65847 .42413 m
.66021 .42419 L
s
.66005 .42052 m
.65847 .42413 L
s
.65847 .42413 m
.65812 .42168 L
s
.66214 .42302 m
.65847 .42413 L
s
.66679 .41521 m
.65847 .42413 L
s
1 .39 0 r
.57668 .47841 m
.57771 .4813 L
s
1 .09 0 r
.64573 .50586 m
.64628 .50599 L
s
.64625 .50518 m
.64573 .50586 L
s
.64573 .50586 m
.64594 .50537 L
s
.64659 .5058 m
.64573 .50586 L
s
.64842 .50447 m
.64573 .50586 L
s
.64628 .50599 m
.64659 .5058 L
s
.64659 .5058 m
.64625 .50518 L
s
.64625 .50518 m
.64594 .50537 L
s
1 .459 0 r
.6156 .45101 m
.61747 .45411 L
s
1 .016 0 r
.70784 .5331 m
.70793 .53311 L
s
.70792 .53297 m
.70784 .5331 L
s
.70784 .5331 m
.70786 .53301 L
s
.70799 .53307 m
.70784 .5331 L
s
.70827 .53282 m
.70784 .5331 L
s
.70792 .53297 m
.70786 .53301 L
s
.70799 .53307 m
.70792 .53297 L
s
.70793 .53311 m
.70799 .53307 L
s
1 .022 0 r
.37686 .75222 m
.3769 .75227 L
s
.37691 .75206 m
.37686 .75222 L
s
.37706 .75221 m
.37686 .75222 L
s
.37696 .75211 m
.37691 .75206 L
s
.37691 .75206 m
.37706 .75221 L
s
.37706 .75221 m
.3769 .75227 L
s
.37696 .75211 m
.37706 .75221 L
s
.37629 .75201 m
.37706 .75221 L
s
.973 1 0 r
.49644 .44376 m
.49616 .44482 L
s
.49644 .44376 m
.48838 .44847 L
s
1 .151 0 r
.38771 .47721 m
.38827 .47755 L
s
.38709 .47822 m
.38771 .47721 L
s
.38771 .47721 m
.38684 .47737 L
s
.38765 .47856 m
.38709 .47822 L
s
.38709 .47822 m
.38684 .47737 L
s
1 .016 0 r
.70786 .53301 m
.70793 .53311 L
s
1 .417 0 r
.66005 .42052 m
.65812 .42168 L
s
.66214 .42302 m
.66005 .42052 L
s
1 .022 0 r
.3769 .75227 m
.37696 .75211 L
s
1 .05 0 r
.59491 .8068 m
.59682 .8066 L
s
1 .003 0 r
.65159 .66981 m
.6517 .66978 L
s
1 .457 0 r
.48965 .47802 m
.47243 .47498 L
s
1 0 0 r
.43297 .61501 m
.43297 .61501 L
s
1 .091 0 r
.27103 .42323 m
.26959 .42116 L
s
1 .003 0 r
.65169 .66979 m
.65168 .6698 L
s
.65168 .66977 m
.65169 .66979 L
s
.6517 .66978 m
.65169 .66979 L
s
.65167 .66978 m
.65168 .66977 L
s
.65168 .66977 m
.6517 .66978 L
s
.6517 .66978 m
.65168 .6698 L
s
.65167 .66978 m
.6517 .66978 L
s
.65168 .6698 m
.65167 .66978 L
s
1 .575 0 r
.4188 .42319 m
.4166 .42716 L
s
.41329 .42274 m
.4188 .42319 L
s
1 .05 0 r
.59649 .80677 m
.59644 .80688 L
s
.59643 .80639 m
.59649 .80677 L
s
.59682 .8066 m
.59649 .80677 L
s
1 .575 0 r
.41329 .42274 m
.4166 .42716 L
s
1 .09 0 r
.64594 .50537 m
.64628 .50599 L
s
1 .05 0 r
.59638 .80651 m
.59643 .80639 L
s
.59643 .80639 m
.59682 .8066 L
s
1 .417 0 r
.66021 .42419 m
.66214 .42302 L
s
1 .05 0 r
.59682 .8066 m
.59644 .80688 L
s
.59638 .80651 m
.59682 .8066 L
s
.717 1 0 r
.53215 .45219 m
.53553 .45031 L
s
.53553 .45031 m
.53213 .44079 L
s
.53553 .45031 m
.52331 .44939 L
s
1 .05 0 r
.59644 .80688 m
.59638 .80651 L
s
1 .022 0 r
.92357 .42274 m
.92364 .42273 L
s
.92362 .42254 m
.92357 .42274 L
s
.92357 .42274 m
.92352 .42262 L
s
.92375 .42265 m
.92357 .42274 L
s
.92386 .42223 m
.92357 .42274 L
s
1 .151 0 r
.38827 .47755 m
.38765 .47856 L
s
.38684 .47737 m
.38827 .47755 L
s
.38684 .47737 m
.38765 .47856 L
s
1 .022 0 r
.92362 .42254 m
.92352 .42262 L
s
.92375 .42265 m
.92362 .42254 L
s
.92364 .42273 m
.92375 .42265 L
s
.92352 .42262 m
.92364 .42273 L
s
1 .121 0 r
.32906 .44905 m
.3296 .44939 L
s
.32846 .44978 m
.32906 .44905 L
s
.32906 .44905 m
.32852 .44908 L
s
1 .01 0 r
.31657 .72389 m
.31651 .72392 L
s
.31651 .72382 m
.31657 .72389 L
s
.31657 .72389 m
.31648 .72389 L
s
.31654 .72385 m
.31657 .72389 L
s
.31626 .72378 m
.31657 .72389 L
s
.31648 .72389 m
.31651 .72392 L
s
.31651 .72382 m
.31648 .72389 L
s
1 .121 0 r
.329 .45012 m
.32846 .44978 L
s
.32846 .44978 m
.32852 .44908 L
s
1 .01 0 r
.31654 .72385 m
.31651 .72382 L
s
1 .045 0 r
.53642 .7787 m
.53641 .7788 L
s
.53641 .77836 m
.53642 .7787 L
s
.53676 .77857 m
.53642 .7787 L
s
1 .01 0 r
.31651 .72392 m
.31654 .72385 L
s
1 .045 0 r
.5364 .77845 m
.53641 .77836 L
s
.53641 .77836 m
.53676 .77857 L
s
.717 1 0 r
.53213 .44079 m
.52873 .44264 L
s
.53213 .44079 m
.52331 .44939 L
s
1 .001 0 r
.86714 .55931 m
.86714 .55931 L
s
.86714 .5593 m
.86714 .55931 L
s
.86714 .55931 m
.86714 .55931 L
s
.86714 .55931 m
.86714 .55931 L
s
.86715 .5593 m
.86714 .55931 L
s
.86714 .5593 m
.86714 .55931 L
s
.86714 .55931 m
.86714 .5593 L
s
.86714 .55931 m
.86714 .55931 L
s
.86714 .55931 m
.86714 .55931 L
s
.59171 .64154 m
.59174 .64153 L
s
1 .045 0 r
.535 .7786 m
.53676 .77857 L
s
1 .001 0 r
.37297 .58671 m
.37295 .5867 L
s
1 .459 0 r
.42968 .44964 m
.41612 .44216 L
s
1 .001 0 r
.59173 .64153 m
.59173 .64154 L
s
.59173 .64153 m
.59173 .64153 L
s
.59174 .64153 m
.59173 .64153 L
s
.59173 .64153 m
.59173 .64153 L
s
.59173 .64153 m
.59174 .64153 L
s
1 .457 0 r
.47584 .47764 m
.47519 .47705 L
s
.47519 .47705 m
.47591 .47354 L
s
.47519 .47705 m
.47243 .47498 L
s
1 .001 0 r
.59174 .64153 m
.59173 .64154 L
s
.59173 .64153 m
.59174 .64153 L
s
.37295 .5867 m
.37295 .5867 L
s
.37295 .5867 m
.37295 .5867 L
s
.37295 .5867 m
.37295 .5867 L
s
.37295 .5867 m
.37296 .5867 L
s
.37295 .5867 m
.37295 .5867 L
s
.59173 .64154 m
.59173 .64153 L
s
.37296 .5867 m
.37295 .5867 L
s
.37295 .5867 m
.37295 .5867 L
s
.37295 .5867 m
.37296 .5867 L
s
1 .045 0 r
.53676 .77857 m
.53641 .7788 L
s
.5364 .77845 m
.53676 .77857 L
s
.53641 .7788 m
.5364 .77845 L
s
1 .121 0 r
.3296 .44939 m
.329 .45012 L
s
.32852 .44908 m
.3296 .44939 L
s
.717 1 0 r
.52331 .44939 m
.53215 .45219 L
s
.52331 .44939 m
.52873 .44264 L
s
.56776 .43477 m
.52331 .44939 L
s
1 .457 0 r
.47591 .47354 m
.47656 .47412 L
s
.47591 .47354 m
.47243 .47498 L
s
1 .121 0 r
.32852 .44908 m
.329 .45012 L
s
1 .091 0 r
.26991 .42117 m
.27034 .42147 L
s
.26941 .42167 m
.26991 .42117 L
s
.26991 .42117 m
.26959 .42116 L
s
1 .417 0 r
.65812 .42168 m
.66021 .42419 L
s
1 .091 0 r
.26984 .42197 m
.26941 .42167 L
s
.26941 .42167 m
.26959 .42116 L
s
1 .116 0 r
.68477 .47636 m
.68536 .47644 L
s
.68531 .4754 m
.68477 .47636 L
s
.68477 .47636 m
.68482 .4757 L
s
.68584 .47614 m
.68477 .47636 L
s
.68757 .47415 m
.68477 .47636 L
s
1 .091 0 r
.27034 .42147 m
.26984 .42197 L
s
.26959 .42116 m
.27034 .42147 L
s
1 .033 0 r
.47602 .75056 m
.47605 .75063 L
s
.47606 .7503 m
.47602 .75056 L
s
.47631 .75049 m
.47602 .75056 L
s
.47608 .75037 m
.47606 .7503 L
s
.47606 .7503 m
.47631 .75049 L
s
.47631 .75049 m
.47605 .75063 L
s
.47608 .75037 m
.47631 .75049 L
s
.47502 .75037 m
.47631 .75049 L
s
1 .116 0 r
.68531 .4754 m
.68482 .4757 L
s
.68584 .47614 m
.68531 .4754 L
s
1 .091 0 r
.26959 .42116 m
.26984 .42197 L
s
1 .005 0 r
.80725 .53105 m
.80727 .53105 L
s
.80727 .531 m
.80725 .53105 L
s
.80725 .53105 m
.80725 .53102 L
s
.80729 .53104 m
.80725 .53105 L
s
.80736 .53094 m
.80725 .53105 L
s
.80727 .531 m
.80725 .53102 L
s
.80729 .53104 m
.80727 .531 L
s
.80727 .53105 m
.80729 .53104 L
s
.80725 .53102 m
.80727 .53105 L
s
1 .116 0 r
.68536 .47644 m
.68584 .47614 L
s
1 .033 0 r
.47605 .75063 m
.47608 .75037 L
s
1 .002 0 r
.75062 .66809 m
.75067 .66806 L
s
1 0 0 r
.53176 .61323 m
.53176 .61323 L
s
1 .003 0 r
.3129 .55837 m
.31282 .55832 L
s
1 .318 0 r
.36964 .42123 m
.36312 .41446 L
s
1 .002 0 r
.75066 .66806 m
.75066 .66807 L
s
.75065 .66806 m
.75066 .66806 L
s
.75066 .66806 m
.75067 .66806 L
s
.75066 .66807 m
.75066 .66808 L
s
.75067 .66806 m
.75066 .66807 L
s
.75066 .66808 m
.75065 .66806 L
s
.75065 .66806 m
.75067 .66806 L
s
.75067 .66806 m
.75066 .66808 L
s
1 .003 0 r
.31284 .55831 m
.31285 .55832 L
s
.31282 .55833 m
.31284 .55831 L
s
.31284 .55831 m
.31282 .55832 L
s
.31284 .55834 m
.31282 .55833 L
s
.31282 .55833 m
.31282 .55832 L
s
.31285 .55832 m
.31284 .55834 L
s
.31282 .55832 m
.31285 .55832 L
s
.31282 .55832 m
.31284 .55834 L
s
.973 1 0 r
.48838 .44847 m
.49636 .45288 L
s
.48838 .44847 m
.49616 .44482 L
s
.52852 .44767 m
.48838 .44847 L
s
1 .116 0 r
.68482 .4757 m
.68536 .47644 L
s
1 .026 0 r
.74691 .50308 m
.74704 .50309 L
s
.74702 .50286 m
.74691 .50308 L
s
.74691 .50308 m
.74691 .50293 L
s
.74715 .50302 m
.74691 .50308 L
s
.7475 .50256 m
.74691 .50308 L
s
.74702 .50286 m
.74691 .50293 L
s
.74715 .50302 m
.74702 .50286 L
s
.808 1 0 r
.5795 .42072 m
.58498 .42833 L
s
1 .026 0 r
.74704 .50309 m
.74715 .50302 L
s
.74691 .50293 m
.74704 .50309 L
s
1 .018 0 r
.41548 .72227 m
.41551 .72231 L
s
.41552 .72214 m
.41548 .72227 L
s
.41565 .72225 m
.41548 .72227 L
s
.41555 .72218 m
.41552 .72214 L
s
.41552 .72214 m
.41565 .72225 L
s
.41565 .72225 m
.41551 .72231 L
s
.41555 .72218 m
.41565 .72225 L
s
.41498 .72211 m
.41565 .72225 L
s
0 .197 1 r
.62091 .42146 m
.60236 .4445 L
s
.64061 .43206 m
.62091 .42146 L
s
1 .018 0 r
.41551 .72231 m
.41555 .72218 L
s
1 .038 0 r
.63395 .777 m
.63535 .77674 L
s
1 0 0 r
.69073 .63978 m
.69074 .63977 L
s
1 .002 0 r
.47175 .58489 m
.47168 .58488 L
s
1 .006 0 r
.25277 .53 m
.25264 .52989 L
s
1 0 0 r
.69074 .63978 m
.69074 .63978 L
s
.69074 .63977 m
.69074 .63978 L
s
.69074 .63977 m
.69074 .63978 L
s
1 .002 0 r
.4717 .58489 m
.47169 .58489 L
s
.47169 .58489 m
.4717 .58488 L
s
.47169 .58489 m
.47168 .58488 L
s
1 0 0 r
.69074 .63977 m
.69074 .63977 L
s
.69074 .63977 m
.69074 .63977 L
s
1 .002 0 r
.4717 .58488 m
.4717 .58488 L
s
.4717 .58488 m
.47168 .58488 L
s
1 0 0 r
.69074 .63978 m
.69074 .63977 L
s
.69074 .63977 m
.69074 .63978 L
s
.69074 .63977 m
.69074 .63977 L
s
1 .002 0 r
.47168 .58488 m
.4717 .58489 L
s
.47168 .58488 m
.4717 .58488 L
s
.4717 .58488 m
.4717 .58489 L
s
1 .006 0 r
.25267 .52988 m
.25269 .5299 L
s
.25264 .52992 m
.25267 .52988 L
s
.25267 .52988 m
.25264 .52989 L
s
.25266 .52994 m
.25264 .52992 L
s
.25264 .52992 m
.25264 .52989 L
s
.25269 .5299 m
.25266 .52994 L
s
.25264 .52989 m
.25269 .5299 L
s
.25264 .52989 m
.25266 .52994 L
s
1 .038 0 r
.63514 .77689 m
.63508 .77698 L
s
.63507 .77661 m
.63514 .77689 L
s
.63535 .77674 m
.63514 .77689 L
s
1 .457 0 r
.47243 .47498 m
.47584 .47764 L
s
.47243 .47498 m
.47656 .47412 L
s
1 .038 0 r
.63501 .7767 m
.63507 .77661 L
s
.63507 .77661 m
.63535 .77674 L
s
.63535 .77674 m
.63508 .77698 L
s
.63501 .7767 m
.63535 .77674 L
s
.63508 .77698 m
.63501 .7767 L
s
0 .04 1 r
.42667 .41762 m
.43733 .44708 L
s
1 .457 0 r
.47656 .47412 m
.47584 .47764 L
s
1 .007 0 r
.35503 .6939 m
.35505 .69391 L
s
.35505 .69385 m
.35503 .6939 L
s
.35509 .6939 m
.35503 .6939 L
s
.35509 .6939 m
.35505 .69391 L
s
.35505 .69385 m
.35509 .6939 L
s
.35507 .69386 m
.35509 .6939 L
s
.35486 .69382 m
.35509 .6939 L
s
.35507 .69386 m
.35505 .69385 L
s
.35505 .69391 m
.35507 .69386 L
s
1 .002 0 r
.90664 .52911 m
.90664 .52911 L
s
.90664 .52909 m
.90664 .52911 L
s
.90664 .52911 m
.90663 .5291 L
s
.90665 .5291 m
.90664 .52911 L
s
.90667 .52906 m
.90664 .52911 L
s
.90664 .52909 m
.90663 .5291 L
s
.90665 .5291 m
.90664 .52909 L
s
.90664 .52911 m
.90665 .5291 L
s
.90663 .5291 m
.90664 .52911 L
s
0 1 .331 r
.56452 .43053 m
.55214 .43859 L
s
.57712 .44314 m
.56452 .43053 L
s
1 .035 0 r
.57508 .74874 m
.57505 .74881 L
s
.57504 .74847 m
.57508 .74874 L
s
.57532 .74861 m
.57508 .74874 L
s
1 0 0 r
.63077 .61144 m
.63077 .61144 L
s
1 .035 0 r
.57396 .74873 m
.57532 .74861 L
s
1 .01 0 r
.41167 .55652 m
.41133 .55639 L
s
.808 1 0 r
.46847 .41923 m
.42936 .40255 L
s
1 .035 0 r
.57502 .74854 m
.57504 .74847 L
s
.57504 .74847 m
.57532 .74861 L
s
1 .01 0 r
.41139 .55646 m
.41136 .55644 L
s
.41136 .55644 m
.4114 .55637 L
s
.41136 .55644 m
.41133 .55639 L
s
.4114 .55637 m
.41143 .55639 L
s
.4114 .55637 m
.41133 .55639 L
s
.41143 .55639 m
.41139 .55646 L
s
.41133 .55639 m
.41139 .55646 L
s
.41133 .55639 m
.41143 .55639 L
s
1 .035 0 r
.57532 .74861 m
.57505 .74881 L
s
.57502 .74854 m
.57532 .74861 L
s
.57505 .74881 m
.57502 .74854 L
s
1 .121 0 r
.72458 .44635 m
.72507 .44636 L
s
.725 .44529 m
.72458 .44635 L
s
.72458 .44635 m
.72444 .44565 L
s
.72563 .446 m
.72458 .44635 L
s
.72686 .44372 m
.72458 .44635 L
s
.725 .44529 m
.72444 .44565 L
s
.72563 .446 m
.725 .44529 L
s
.72507 .44636 m
.72563 .446 L
s
1 .009 0 r
.84664 .50083 m
.84668 .50084 L
s
.84667 .50076 m
.84664 .50083 L
s
.84664 .50083 m
.84663 .50079 L
s
.84672 .50081 m
.84664 .50083 L
s
.8468 .50065 m
.84664 .50083 L
s
.84667 .50076 m
.84663 .50079 L
s
.84672 .50081 m
.84667 .50076 L
s
.84668 .50084 m
.84672 .50081 L
s
.84663 .50079 m
.84668 .50084 L
s
1 .026 0 r
.51472 .72053 m
.51473 .72058 L
s
.51473 .72033 m
.51472 .72053 L
s
.51493 .72046 m
.51472 .72053 L
s
.51473 .72038 m
.51473 .72033 L
s
.51473 .72033 m
.51493 .72046 L
s
.973 1 0 r
.49616 .44482 m
.49636 .45288 L
s
1 .026 0 r
.51493 .72046 m
.51473 .72058 L
s
.51473 .72038 m
.51493 .72046 L
s
.51391 .72044 m
.51493 .72046 L
s
1 .002 0 r
.29473 .66552 m
.29472 .66552 L
s
.29472 .6655 m
.29473 .66552 L
s
.29473 .66552 m
.29472 .66551 L
s
.29473 .66551 m
.29473 .66552 L
s
.29469 .66549 m
.29473 .66552 L
s
.29472 .6655 m
.29472 .66551 L
s
.29473 .66551 m
.29472 .6655 L
s
.29472 .66551 m
.29472 .66552 L
s
.29472 .66552 m
.29473 .66551 L
s
.57069 .58309 m
.57069 .58308 L
s
.57069 .58308 m
.57069 .58307 L
s
.57069 .58308 m
.57067 .58308 L
s
.57069 .58307 m
.57068 .58307 L
s
.57069 .58307 m
.57067 .58308 L
s
.57067 .58308 m
.57069 .58309 L
s
.57067 .58308 m
.57068 .58307 L
s
.57074 .58307 m
.57067 .58308 L
s
.57068 .58307 m
.57069 .58309 L
s
1 0 0 r
.78997 .63802 m
.78997 .63802 L
s
1 .02 0 r
.35152 .52812 m
.351 .52778 L
s
1 0 0 r
.78997 .63801 m
.78997 .63802 L
s
.78997 .63802 m
.78997 .63801 L
s
.78997 .63801 m
.78997 .63802 L
s
.78997 .63802 m
.78997 .63802 L
s
.78997 .63802 m
.78997 .63802 L
s
.78997 .63802 m
.78997 .63802 L
s
.78997 .63802 m
.78997 .63802 L
s
.78997 .63802 m
.78997 .63802 L
s
1 .026 0 r
.51473 .72058 m
.51473 .72038 L
s
1 .121 0 r
.72444 .44565 m
.72507 .44636 L
s
1 .02 0 r
.35111 .52776 m
.35118 .52781 L
s
.35102 .52789 m
.35111 .52776 L
s
.35111 .52776 m
.351 .52778 L
s
.3511 .52794 m
.35102 .52789 L
s
.35102 .52789 m
.351 .52778 L
s
1 .033 0 r
.78624 .47292 m
.78638 .47293 L
s
.78636 .47263 m
.78624 .47292 L
s
.78624 .47292 m
.7862 .47274 L
s
.78653 .47282 m
.78624 .47292 L
s
.78686 .4722 m
.78624 .47292 L
s
.78636 .47263 m
.7862 .47274 L
s
.78653 .47282 m
.78636 .47263 L
s
1 .02 0 r
.35118 .52781 m
.3511 .52794 L
s
.351 .52778 m
.35118 .52781 L
s
.351 .52778 m
.3511 .52794 L
s
1 .033 0 r
.78638 .47293 m
.78653 .47282 L
s
.7862 .47274 m
.78638 .47293 L
s
1 .013 0 r
.45417 .69221 m
.45419 .69224 L
s
.45419 .69211 m
.45417 .69221 L
s
.45429 .69219 m
.45417 .69221 L
s
.45421 .69214 m
.45419 .69211 L
s
.45419 .69211 m
.45429 .69219 L
s
1 .459 0 r
.41891 .44162 m
.42053 .44252 L
s
.41715 .44481 m
.41891 .44162 L
s
.41891 .44162 m
.41612 .44216 L
s
.41877 .44571 m
.41715 .44481 L
s
.41715 .44481 m
.41612 .44216 L
s
1 .013 0 r
.45429 .69219 m
.45419 .69224 L
s
.45421 .69214 m
.45429 .69219 L
s
.45379 .69211 m
.45429 .69219 L
s
.45419 .69224 m
.45421 .69214 L
s
1 .024 0 r
.50992 .55474 m
.5099 .5547 L
s
.5099 .5547 m
.50992 .55452 L
s
.5099 .5547 m
.50973 .55462 L
s
.50992 .55452 m
.50993 .55455 L
s
.50992 .55452 m
.50973 .55462 L
s
.67313 .74709 m
.67399 .74686 L
s
1 0 0 r
.73 .60965 m
.73 .60965 L
s
1 .024 0 r
.51065 .55467 m
.50973 .55462 L
s
1 .023 0 r
.29131 .49969 m
.29081 .49921 L
s
1 .024 0 r
.50973 .55462 m
.50992 .55474 L
s
.50973 .55462 m
.50993 .55455 L
s
.50993 .55455 m
.50992 .55474 L
s
.67387 .74697 m
.67382 .74703 L
s
.67381 .74679 m
.67387 .74697 L
s
.67399 .74686 m
.67387 .74697 L
s
.67376 .74685 m
.67381 .74679 L
s
.67381 .74679 m
.67399 .74686 L
s
0 .197 1 r
.60236 .4445 m
.62193 .45533 L
s
1 .024 0 r
.67399 .74686 m
.67382 .74703 L
s
.67376 .74685 m
.67399 .74686 L
s
.67382 .74703 m
.67376 .74685 L
s
0 .04 1 r
.62362 .44095 m
.64293 .41692 L
s
1 .023 0 r
.29092 .4992 m
.29102 .49927 L
s
.2908 .49934 m
.29092 .4992 L
s
.29092 .4992 m
.29081 .49921 L
s
.2909 .49941 m
.2908 .49934 L
s
.2908 .49934 m
.29081 .49921 L
s
0 .434 1 r
.44721 .47731 m
.45758 .47179 L
s
.45758 .47179 m
.44799 .44525 L
s
.45758 .47179 m
.42334 .46924 L
s
1 .023 0 r
.29102 .49927 m
.2909 .49941 L
s
.29081 .49921 m
.29102 .49927 L
s
.29081 .49921 m
.2909 .49941 L
s
1 .035 0 r
.33757 .80164 m
.33766 .80173 L
s
.33768 .80139 m
.33757 .80164 L
s
.33791 .80163 m
.33757 .80164 L
s
.33791 .80163 m
.33766 .80173 L
s
.33768 .80139 m
.33791 .80163 L
s
.33776 .80148 m
.33791 .80163 L
s
.3367 .80128 m
.33791 .80163 L
s
.33776 .80148 m
.33768 .80139 L
s
1 .318 0 r
.3645 .41442 m
.36595 .41529 L
s
.3629 .41634 m
.3645 .41442 L
s
.3645 .41442 m
.36312 .41446 L
s
1 .035 0 r
.33766 .80173 m
.33776 .80148 L
s
1 .318 0 r
.36435 .41722 m
.3629 .41634 L
s
.3629 .41634 m
.36312 .41446 L
s
1 .003 0 r
.94627 .49881 m
.94628 .49881 L
s
.94627 .49878 m
.94627 .49881 L
s
.94627 .49881 m
.94626 .49879 L
s
.94629 .4988 m
.94627 .49881 L
s
.94632 .49873 m
.94627 .49881 L
s
.94627 .49878 m
.94626 .49879 L
s
.94629 .4988 m
.94627 .49878 L
s
.94628 .49881 m
.94629 .4988 L
s
.94626 .49879 m
.94628 .49881 L
s
1 .004 0 r
.39369 .6638 m
.3937 .66381 L
s
.3937 .66377 m
.39369 .6638 L
s
.39372 .6638 m
.39369 .6638 L
s
.39371 .66378 m
.3937 .66377 L
s
.3937 .66377 m
.39372 .6638 L
s
.39372 .6638 m
.3937 .66381 L
s
.39371 .66378 m
.39372 .6638 L
s
.3936 .66376 m
.39372 .6638 L
s
.3937 .66381 m
.39371 .66378 L
s
1 .001 0 r
.66993 .58126 m
.66994 .58126 L
s
.66994 .58125 m
.66993 .58126 L
s
.66993 .58126 m
.66994 .58125 L
s
.66994 .58126 m
.66993 .58126 L
s
.66996 .58124 m
.66993 .58126 L
s
.66994 .58126 m
.66994 .58126 L
s
.66994 .58126 m
.66994 .58125 L
s
.66994 .58125 m
.66994 .58125 L
s
.66994 .58125 m
.66994 .58126 L
s
1 .022 0 r
.61306 .71877 m
.6139 .71862 L
s
1 .07 0 r
.4505 .52624 m
.44803 .52549 L
s
1 .023 0 r
.23103 .47123 m
.23063 .47071 L
s
1 .022 0 r
.61377 .71871 m
.61373 .71876 L
s
.61373 .71854 m
.61377 .71871 L
s
.6139 .71862 m
.61377 .71871 L
s
.61369 .71859 m
.61373 .71854 L
s
.61373 .71854 m
.6139 .71862 L
s
.6139 .71862 m
.61373 .71876 L
s
.61369 .71859 m
.6139 .71862 L
s
.61373 .71876 m
.61369 .71859 L
s
1 .115 0 r
.76464 .41587 m
.765 .41584 L
s
.76493 .41483 m
.76464 .41587 L
s
.76464 .41587 m
.76436 .41522 L
s
.76557 .41545 m
.76464 .41587 L
s
.76627 .4132 m
.76464 .41587 L
s
1 .023 0 r
.23072 .47071 m
.23083 .47079 L
s
.23059 .47084 m
.23072 .47071 L
s
.23072 .47071 m
.23063 .47071 L
s
.2307 .47092 m
.23059 .47084 L
s
.23059 .47084 m
.23063 .47071 L
s
1 .07 0 r
.44852 .52596 m
.44835 .52584 L
s
.44835 .52584 m
.44853 .52532 L
s
.44835 .52584 m
.44803 .52549 L
s
.717 1 0 r
.52873 .44264 m
.53215 .45219 L
s
1 .023 0 r
.23083 .47079 m
.2307 .47092 L
s
.23063 .47071 m
.23083 .47079 L
s
1 .07 0 r
.44853 .52532 m
.4487 .52544 L
s
.44853 .52532 m
.44803 .52549 L
s
1 .023 0 r
.23063 .47071 m
.2307 .47092 L
s
0 1 .331 r
.56477 .45128 m
.57712 .44314 L
s
1 .115 0 r
.76493 .41483 m
.76436 .41522 L
s
.76557 .41545 m
.76493 .41483 L
s
1 .012 0 r
.88619 .47052 m
.88623 .47052 L
s
.88622 .47041 m
.88619 .47052 L
s
.88619 .47052 m
.88616 .47045 L
s
.88629 .47048 m
.88619 .47052 L
s
.88637 .47025 m
.88619 .47052 L
s
.88622 .47041 m
.88616 .47045 L
s
.88629 .47048 m
.88622 .47041 L
s
1 .115 0 r
.765 .41584 m
.76557 .41545 L
s
1 .012 0 r
.88623 .47052 m
.88629 .47048 L
s
1 .07 0 r
.44803 .52549 m
.44852 .52596 L
s
.44803 .52549 m
.4487 .52544 L
s
1 .012 0 r
.88616 .47045 m
.88623 .47052 L
s
1 .016 0 r
.60941 .55302 m
.60945 .55299 L
s
.60945 .55299 m
.60941 .55287 L
s
.60945 .55299 m
.6093 .55298 L
s
1 .07 0 r
.4487 .52544 m
.44852 .52596 L
s
1 .016 0 r
.60941 .55287 m
.60937 .5529 L
s
.60941 .55287 m
.6093 .55298 L
s
.6093 .55298 m
.60941 .55302 L
s
.6093 .55298 m
.60937 .5529 L
s
.60986 .55281 m
.6093 .55298 L
s
.60937 .5529 m
.60941 .55302 L
s
1 .318 0 r
.36595 .41529 m
.36435 .41722 L
s
.36312 .41446 m
.36595 .41529 L
s
1 .016 0 r
.55344 .69043 m
.55343 .69046 L
s
.55343 .6903 m
.55344 .69043 L
s
.55355 .69037 m
.55344 .69043 L
s
1 .115 0 r
.76436 .41522 m
.765 .41584 L
s
1 0 0 r
.33335 .63537 m
.33335 .63538 L
s
.33335 .63537 m
.33335 .63537 L
s
.33335 .63537 m
.33335 .63537 L
s
.33335 .63537 m
.33335 .63537 L
s
.33334 .63537 m
.33335 .63537 L
s
.33335 .63537 m
.33335 .63537 L
s
.33335 .63537 m
.33335 .63537 L
s
.33335 .63537 m
.33335 .63538 L
s
1 .016 0 r
.55342 .69033 m
.55343 .6903 L
s
.55343 .6903 m
.55355 .69037 L
s
1 0 0 r
.33335 .63538 m
.33335 .63537 L
s
.82944 .60785 m
.82944 .60785 L
s
1 .016 0 r
.55293 .69041 m
.55355 .69037 L
s
1 .09 0 r
.39027 .49777 m
.38777 .49623 L
s
1 .016 0 r
.55355 .69037 m
.55343 .69046 L
s
.55342 .69033 m
.55355 .69037 L
s
.55343 .69046 m
.55342 .69033 L
s
1 .038 0 r
.82579 .4426 m
.82592 .4426 L
s
.82589 .44226 m
.82579 .4426 L
s
.82579 .4426 m
.82571 .44239 L
s
.8261 .44246 m
.82579 .4426 L
s
.82636 .44174 m
.82579 .4426 L
s
1 .318 0 r
.36312 .41446 m
.36435 .41722 L
s
1 .038 0 r
.82589 .44226 m
.82571 .44239 L
s
.8261 .44246 m
.82589 .44226 L
s
1 .459 0 r
.42053 .44252 m
.41877 .44571 L
s
.41612 .44216 m
.42053 .44252 L
s
.41612 .44216 m
.41877 .44571 L
s
0 .434 1 r
.44799 .44525 m
.43751 .45048 L
s
.44799 .44525 m
.42334 .46924 L
s
1 .111 0 r
.54626 .5252 m
.54636 .52505 L
s
.54636 .52505 m
.54625 .52419 L
s
.54636 .52505 m
.5454 .52478 L
s
1 .038 0 r
.82592 .4426 m
.8261 .44246 L
s
.82571 .44239 m
.82592 .4426 L
s
1 .111 0 r
.54625 .52419 m
.54615 .52434 L
s
.54625 .52419 m
.5454 .52478 L
s
1 .055 0 r
.43736 .80008 m
.43743 .80021 L
s
.43744 .79966 m
.43736 .80008 L
s
.43785 .79999 m
.43736 .80008 L
s
1 .111 0 r
.5454 .52478 m
.54626 .5252 L
s
.5454 .52478 m
.54615 .52434 L
s
.54969 .52434 m
.5454 .52478 L
s
1 .055 0 r
.43751 .79979 m
.43744 .79966 L
s
.43744 .79966 m
.43785 .79999 L
s
.43785 .79999 m
.43743 .80021 L
s
.43751 .79979 m
.43785 .79999 L
s
.43577 .79969 m
.43785 .79999 L
s
.973 1 0 r
.58352 .44203 m
.58838 .44257 L
s
.58819 .43343 m
.58352 .44203 L
s
.58352 .44203 m
.58362 .43597 L
s
.59294 .44002 m
.58352 .44203 L
s
.60756 .42167 m
.58352 .44203 L
s
1 .055 0 r
.43743 .80021 m
.43751 .79979 L
s
1 .253 0 r
.58179 .49731 m
.58242 .4969 L
s
.58242 .4969 m
.58175 .49502 L
s
.58242 .4969 m
.58 .49672 L
s
1 .111 0 r
.54615 .52434 m
.54626 .5252 L
s
1 .007 0 r
.49293 .66206 m
.49294 .66207 L
s
.49294 .662 m
.49293 .66206 L
s
.49299 .66204 m
.49293 .66206 L
s
.49294 .66202 m
.49294 .662 L
s
.49294 .662 m
.49299 .66204 L
s
.49299 .66204 m
.49294 .66207 L
s
.49294 .66202 m
.49299 .66204 L
s
.49273 .66202 m
.49299 .66204 L
s
1 0 0 r
.76939 .57942 m
.76939 .57942 L
s
.76939 .57942 m
.76939 .57942 L
s
.76939 .57942 m
.76939 .57942 L
s
.76939 .57942 m
.76939 .57942 L
s
.7694 .57941 m
.76939 .57942 L
s
.76939 .57942 m
.76939 .57942 L
s
.76939 .57942 m
.76939 .57942 L
s
.76939 .57942 m
.76939 .57942 L
s
.76939 .57942 m
.76939 .57942 L
s
1 .007 0 r
.49294 .66207 m
.49294 .66202 L
s
1 .013 0 r
.71243 .71709 m
.71285 .71694 L
s
1 .08 0 r
.32998 .46927 m
.3283 .46762 L
s
1 0 0 r
.27302 .60695 m
.27302 .60695 L
s
1 .253 0 r
.58175 .49502 m
.58112 .49543 L
s
.58175 .49502 m
.58 .49672 L
s
0 .434 1 r
.42334 .46924 m
.44721 .47731 L
s
.42334 .46924 m
.43751 .45048 L
s
.54693 .42829 m
.42334 .46924 L
s
1 .09 0 r
.38829 .49614 m
.38863 .49634 L
s
.38791 .49674 m
.38829 .49614 L
s
.38829 .49614 m
.38777 .49623 L
s
.38825 .49695 m
.38791 .49674 L
s
.38791 .49674 m
.38777 .49623 L
s
1 .336 0 r
.61879 .46919 m
.6207 .46954 L
s
.62061 .46653 m
.61879 .46919 L
s
.61879 .46919 m
.61932 .46726 L
s
.62199 .46881 m
.61879 .46919 L
s
.62815 .46339 m
.61879 .46919 L
s
1 .253 0 r
.58 .49672 m
.58179 .49731 L
s
.58 .49672 m
.58112 .49543 L
s
.58885 .49392 m
.58 .49672 L
s
1 .013 0 r
.71281 .717 m
.71277 .71703 L
s
.71277 .71691 m
.71281 .717 L
s
.71285 .71694 m
.71281 .717 L
s
.71273 .71694 m
.71277 .71691 L
s
.71277 .71691 m
.71285 .71694 L
s
.71277 .71703 m
.71273 .71694 L
s
.71285 .71694 m
.71277 .71703 L
s
.71273 .71694 m
.71285 .71694 L
s
1 .336 0 r
.62061 .46653 m
.61932 .46726 L
s
.62199 .46881 m
.62061 .46653 L
s
.6207 .46954 m
.62199 .46881 L
s
1 .09 0 r
.38863 .49634 m
.38825 .49695 L
s
.38777 .49623 m
.38863 .49634 L
s
.38777 .49623 m
.38825 .49695 L
s
1 .035 0 r
.37638 .77169 m
.37646 .77178 L
s
.37647 .77143 m
.37638 .77169 L
s
.37671 .77167 m
.37638 .77169 L
s
.37655 .77152 m
.37647 .77143 L
s
.37647 .77143 m
.37671 .77167 L
s
.37671 .77167 m
.37646 .77178 L
s
.37655 .77152 m
.37671 .77167 L
s
.37547 .77135 m
.37671 .77167 L
s
1 .825 0 r
.50256 .46958 m
.50278 .46865 L
s
.50278 .46865 m
.50262 .46217 L
s
.50278 .46865 m
.49611 .466 L
s
1 .035 0 r
.37646 .77178 m
.37655 .77152 L
s
1 .005 0 r
.70915 .55104 m
.70917 .55104 L
s
.70917 .55099 m
.70915 .55104 L
s
.70915 .55104 m
.70915 .55101 L
s
.70919 .55103 m
.70915 .55104 L
s
.70928 .55095 m
.70915 .55104 L
s
.70917 .55099 m
.70915 .55101 L
s
.70919 .55103 m
.70917 .55099 L
s
.70917 .55104 m
.70919 .55103 L
s
.70915 .55101 m
.70917 .55104 L
s
1 .001 0 r
.43248 .63361 m
.43248 .63361 L
s
.43248 .6336 m
.43248 .63361 L
s
.43249 .63361 m
.43248 .63361 L
s
.43249 .6336 m
.43248 .6336 L
s
.43248 .6336 m
.43249 .63361 L
s
.43249 .63361 m
.43248 .63361 L
s
.43249 .6336 m
.43249 .63361 L
s
.43246 .6336 m
.43249 .63361 L
s
.43248 .63361 m
.43249 .6336 L
s
1 .011 0 r
.65229 .6887 m
.65266 .6886 L
s
1 .303 0 r
.48945 .49585 m
.47798 .49384 L
s
1 .063 0 r
.26962 .44075 m
.26861 .43931 L
s
1 .011 0 r
.65261 .68864 m
.65259 .68867 L
s
.65259 .68857 m
.65261 .68864 L
s
.65266 .6886 m
.65261 .68864 L
s
.65256 .68859 m
.65259 .68857 L
s
.65259 .68857 m
.65266 .6886 L
s
.65266 .6886 m
.65259 .68867 L
s
.65256 .68859 m
.65266 .6886 L
s
.65259 .68867 m
.65256 .68859 L
s
1 .08 0 r
.32866 .46759 m
.32902 .46782 L
s
.32826 .46808 m
.32866 .46759 L
s
.32866 .46759 m
.3283 .46762 L
s
.973 1 0 r
.58819 .43343 m
.58362 .43597 L
s
.59294 .44002 m
.58819 .43343 L
s
1 .08 0 r
.32862 .46831 m
.32826 .46808 L
s
.32826 .46808 m
.3283 .46762 L
s
1 .043 0 r
.6478 .52312 m
.64807 .52318 L
s
.64805 .52279 m
.6478 .52312 L
s
.6478 .52312 m
.64791 .52288 L
s
.64822 .52309 m
.6478 .52312 L
s
.6491 .52245 m
.6478 .52312 L
s
1 .253 0 r
.58112 .49543 m
.58179 .49731 L
s
1 .043 0 r
.64807 .52318 m
.64822 .52309 L
s
.64822 .52309 m
.64805 .52279 L
s
.64805 .52279 m
.64791 .52288 L
s
1 .825 0 r
.50262 .46217 m
.5024 .46308 L
s
.50262 .46217 m
.49611 .466 L
s
1 .08 0 r
.32902 .46782 m
.32862 .46831 L
s
.3283 .46762 m
.32902 .46782 L
s
1 .043 0 r
.64791 .52288 m
.64807 .52318 L
s
1 .08 0 r
.3283 .46762 m
.32862 .46831 L
s
1 .014 0 r
.92588 .44009 m
.92593 .44009 L
s
.92592 .43996 m
.92588 .44009 L
s
.92588 .44009 m
.92585 .44001 L
s
.926 .44003 m
.92588 .44009 L
s
.92608 .43975 m
.92588 .44009 L
s
1 .303 0 r
.48026 .49561 m
.47982 .49521 L
s
.47982 .49521 m
.4803 .49287 L
s
.47982 .49521 m
.47798 .49384 L
s
1 .014 0 r
.92592 .43996 m
.92585 .44001 L
s
.926 .44003 m
.92592 .43996 L
s
.92593 .44009 m
.926 .44003 L
s
1 .018 0 r
.31568 .74319 m
.31556 .74324 L
s
.31557 .74306 m
.31568 .74319 L
s
.31568 .74319 m
.31551 .74319 L
s
.31562 .74311 m
.31568 .74319 L
s
.3151 .74297 m
.31568 .74319 L
s
.973 1 0 r
.58838 .44257 m
.59294 .44002 L
s
1 .018 0 r
.31551 .74319 m
.31556 .74324 L
s
.31557 .74306 m
.31551 .74319 L
s
1 .014 0 r
.92585 .44001 m
.92593 .44009 L
s
1 .018 0 r
.31562 .74311 m
.31557 .74306 L
s
1 .066 0 r
.53713 .79825 m
.53712 .7984 L
s
.53712 .79775 m
.53713 .79825 L
s
.53763 .79806 m
.53713 .79825 L
s
1 .018 0 r
.31556 .74324 m
.31562 .74311 L
s
1 .066 0 r
.53711 .79789 m
.53712 .79775 L
s
.53712 .79775 m
.53763 .79806 L
s
1 .303 0 r
.4803 .49287 m
.48074 .49327 L
s
.4803 .49287 m
.47798 .49384 L
s
1 .063 0 r
.26883 .43932 m
.26914 .43953 L
s
.26848 .43967 m
.26883 .43932 L
s
.26883 .43932 m
.26861 .43931 L
s
1 0 0 r
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
1 .066 0 r
.53505 .79811 m
.53763 .79806 L
s
1 .006 0 r
.59208 .66028 m
.59231 .66024 L
s
1 0 0 r
.37212 .60515 m
.37212 .60515 L
s
1 .336 0 r
.42915 .46732 m
.41918 .46188 L
s
1 .05 0 r
.2092 .41219 m
.20857 .411 L
s
1 .006 0 r
.59227 .66026 m
.59227 .66028 L
s
.59226 .66022 m
.59227 .66026 L
s
.59231 .66024 m
.59227 .66026 L
s
.59226 .66023 m
.59226 .66022 L
s
.59226 .66022 m
.59231 .66024 L
s
.59231 .66024 m
.59227 .66028 L
s
.59226 .66023 m
.59231 .66024 L
s
.59227 .66028 m
.59226 .66023 L
s
1 .066 0 r
.53763 .79806 m
.53712 .7984 L
s
.53711 .79789 m
.53763 .79806 L
s
1 .336 0 r
.61932 .46726 m
.6207 .46954 L
s
1 .039 0 r
.86551 .41211 m
.86562 .41209 L
s
.86558 .41175 m
.86551 .41211 L
s
.86551 .41211 m
.86539 .4119 L
s
.86581 .41195 m
.86551 .41211 L
s
.86598 .41118 m
.86551 .41211 L
s
1 .063 0 r
.26879 .43988 m
.26848 .43967 L
s
.26848 .43967 m
.26861 .43931 L
s
1 .323 0 r
.66109 .43965 m
.66245 .43972 L
s
.66232 .43684 m
.66109 .43965 L
s
.66109 .43965 m
.66082 .43776 L
s
.66395 .43879 m
.66109 .43965 L
s
.66758 .43276 m
.66109 .43965 L
s
1 .039 0 r
.86558 .41175 m
.86539 .4119 L
s
.86581 .41195 m
.86558 .41175 L
s
1 .066 0 r
.53712 .7984 m
.53711 .79789 L
s
1 .063 0 r
.26914 .43953 m
.26879 .43988 L
s
.26861 .43931 m
.26914 .43953 L
s
1 .039 0 r
.86562 .41209 m
.86581 .41195 L
s
.86539 .4119 m
.86562 .41209 L
s
1 .063 0 r
.26861 .43931 m
.26879 .43988 L
s
0 .434 1 r
.63115 .46696 m
.61905 .46816 L
s
.61811 .43603 m
.63115 .46696 L
s
.63115 .46696 m
.60058 .45783 L
s
.6367 .44617 m
.63115 .46696 L
s
.5661 .38963 m
.63115 .46696 L
s
1 .053 0 r
.47634 .77002 m
.47639 .77014 L
s
.47639 .76962 m
.47634 .77002 L
s
.4768 .76991 m
.47634 .77002 L
s
1 .323 0 r
.66232 .43684 m
.66082 .43776 L
s
.66395 .43879 m
.66232 .43684 L
s
1 .053 0 r
.47644 .76973 m
.47639 .76962 L
s
.47639 .76962 m
.4768 .76991 L
s
.4768 .76991 m
.47639 .77014 L
s
.47644 .76973 m
.4768 .76991 L
s
.47474 .76973 m
.4768 .76991 L
s
1 .05 0 r
.20871 .41102 m
.20896 .4112 L
s
.20843 .41128 m
.20871 .41102 L
s
.20871 .41102 m
.20857 .411 L
s
.20867 .41146 m
.20843 .41128 L
s
.20843 .41128 m
.20857 .411 L
s
1 .053 0 r
.47639 .77014 m
.47644 .76973 L
s
1 .323 0 r
.66245 .43972 m
.66395 .43879 L
s
1 .002 0 r
.80889 .54911 m
.8089 .54911 L
s
.8089 .5491 m
.80889 .54911 L
s
.80889 .54911 m
.80889 .5491 L
s
.80891 .54911 m
.80889 .54911 L
s
.80893 .54908 m
.80889 .54911 L
s
.8089 .5491 m
.80889 .5491 L
s
.80891 .54911 m
.8089 .5491 L
s
.8089 .54911 m
.80891 .54911 L
s
1 .05 0 r
.20896 .4112 m
.20867 .41146 L
s
.20857 .411 m
.20896 .4112 L
s
1 .002 0 r
.80889 .5491 m
.8089 .54911 L
s
1 .001 0 r
.53184 .63183 m
.53184 .63183 L
s
.53184 .63182 m
.53184 .63183 L
s
.53185 .63182 m
.53184 .63183 L
s
.53184 .63182 m
.53184 .63182 L
s
.53184 .63182 m
.53185 .63182 L
s
1 .005 0 r
.75187 .68699 m
.75202 .68691 L
s
1 .001 0 r
.5318 .63182 m
.53185 .63182 L
s
1 0 0 r
.31172 .57666 m
.31171 .57666 L
s
1 .241 0 r
.36878 .43876 m
.36381 .43366 L
s
1 .001 0 r
.53185 .63182 m
.53184 .63183 L
s
.53184 .63182 m
.53185 .63182 L
s
.53184 .63183 m
.53184 .63182 L
s
1 0 0 r
.31171 .57666 m
.31172 .57666 L
s
.31171 .57666 m
.31171 .57666 L
s
.31171 .57666 m
.31171 .57666 L
s
.31171 .57666 m
.31171 .57666 L
s
.31171 .57666 m
.31171 .57666 L
s
.31172 .57666 m
.31171 .57666 L
s
.31171 .57666 m
.31172 .57666 L
s
.31171 .57666 m
.31171 .57666 L
s
1 .005 0 r
.75199 .6869 m
.75201 .68694 L
s
.75197 .68692 m
.75199 .6869 L
s
.75199 .6869 m
.75202 .68691 L
s
.75201 .68694 m
.75199 .68695 L
s
.75202 .68691 m
.75201 .68694 L
s
1 .05 0 r
.20857 .411 m
.20867 .41146 L
s
1 .005 0 r
.75199 .68695 m
.75197 .68692 L
s
.75197 .68692 m
.75202 .68691 L
s
.75202 .68691 m
.75199 .68695 L
s
1 .303 0 r
.47798 .49384 m
.48026 .49561 L
s
.47798 .49384 m
.48074 .49327 L
s
0 1 .331 r
.55214 .43859 m
.56477 .45128 L
s
1 .825 0 r
.49611 .466 m
.50256 .46958 L
s
.49611 .466 m
.5024 .46308 L
s
.52854 .46536 m
.49611 .466 L
s
1 .303 0 r
.48074 .49327 m
.48026 .49561 L
s
1 .033 0 r
.41528 .74162 m
.41534 .74169 L
s
.41535 .74137 m
.41528 .74162 L
s
.41559 .74158 m
.41528 .74162 L
s
1 .068 0 r
.68682 .49328 m
.68717 .49333 L
s
.68714 .49272 m
.68682 .49328 L
s
.68682 .49328 m
.68685 .49289 L
s
.68745 .49315 m
.68682 .49328 L
s
.68848 .49199 m
.68682 .49328 L
s
1 .033 0 r
.41541 .74144 m
.41535 .74137 L
s
.41535 .74137 m
.41559 .74158 L
s
.41559 .74158 m
.41534 .74169 L
s
.41541 .74144 m
.41559 .74158 L
s
.41436 .74132 m
.41559 .74158 L
s
1 .012 0 r
.74847 .52078 m
.74853 .52079 L
s
.74852 .52068 m
.74847 .52078 L
s
.74847 .52078 m
.74847 .52072 L
s
.74858 .52076 m
.74847 .52078 L
s
.74874 .52055 m
.74847 .52078 L
s
1 .068 0 r
.68714 .49272 m
.68685 .49289 L
s
.68745 .49315 m
.68714 .49272 L
s
1 .012 0 r
.74852 .52068 m
.74847 .52072 L
s
.74858 .52076 m
.74852 .52068 L
s
.74853 .52079 m
.74858 .52076 L
s
1 .068 0 r
.68717 .49333 m
.68745 .49315 L
s
1 .012 0 r
.74847 .52072 m
.74853 .52079 L
s
1 .033 0 r
.41534 .74169 m
.41541 .74144 L
s
1 .055 0 r
.63456 .79651 m
.63662 .79615 L
s
1 .003 0 r
.69165 .65853 m
.69175 .65849 L
s
1 0 0 r
.47145 .60334 m
.47145 .60334 L
s
1 .158 0 r
.30834 .41017 m
.30606 .40646 L
s
1 .002 0 r
.25125 .54815 m
.25121 .54811 L
s
1 .323 0 r
.66082 .43776 m
.66245 .43972 L
s
1 .002 0 r
.25122 .54811 m
.25123 .54812 L
s
.25121 .54812 m
.25122 .54811 L
s
.25122 .54811 m
.25121 .54811 L
s
.25122 .54813 m
.25121 .54812 L
s
.25121 .54812 m
.25121 .54811 L
s
1 .003 0 r
.69174 .65851 m
.69173 .65851 L
s
.69173 .65848 m
.69174 .65851 L
s
.69175 .65849 m
.69174 .65851 L
s
.69172 .65849 m
.69173 .65848 L
s
.69173 .65848 m
.69175 .65849 L
s
1 .002 0 r
.25123 .54812 m
.25122 .54813 L
s
.25121 .54811 m
.25123 .54812 L
s
.25121 .54811 m
.25122 .54813 L
s
.939 1 0 r
.53837 .46693 m
.54117 .46532 L
s
.54117 .46532 m
.53833 .4574 L
s
.54117 .46532 m
.53099 .46456 L
s
1 .003 0 r
.69173 .65851 m
.69172 .65849 L
s
.69175 .65849 m
.69173 .65851 L
s
.69172 .65849 m
.69175 .65849 L
s
1 .068 0 r
.68685 .49289 m
.68717 .49333 L
s
1 .055 0 r
.6363 .79636 m
.63621 .79649 L
s
.6362 .79595 m
.6363 .79636 L
s
.63662 .79615 m
.6363 .79636 L
s
.63611 .79608 m
.6362 .79595 L
s
.6362 .79595 m
.63662 .79615 L
s
.63662 .79615 m
.63621 .79649 L
s
.63611 .79608 m
.63662 .79615 L
s
.63621 .79649 m
.63611 .79608 L
s
.939 1 0 r
.53833 .4574 m
.53553 .45899 L
s
.53833 .4574 m
.53099 .46456 L
s
1 .015 0 r
.35429 .71306 m
.35433 .7131 L
s
.35434 .71295 m
.35429 .71306 L
s
.35444 .71306 m
.35429 .71306 L
s
.35444 .71306 m
.35433 .7131 L
s
.35434 .71295 m
.35444 .71306 L
s
.35438 .71299 m
.35444 .71306 L
s
.35392 .71288 m
.35444 .71306 L
s
.35438 .71299 m
.35434 .71295 L
s
.939 1 0 r
.53099 .46456 m
.53837 .46693 L
s
.53099 .46456 m
.53553 .45899 L
s
.56799 .45251 m
.53099 .46456 L
s
.808 1 0 r
.43709 .41119 m
.43356 .40933 L
s
.43356 .40933 m
.43738 .40065 L
s
.43356 .40933 m
.42936 .40255 L
s
1 .015 0 r
.35433 .7131 m
.35438 .71299 L
s
1 .001 0 r
.90878 .54722 m
.90879 .54722 L
s
.90879 .54722 m
.90878 .54722 L
s
.90878 .54722 m
.90878 .54722 L
s
.90879 .54722 m
.90878 .54722 L
s
.9088 .54721 m
.90878 .54722 L
s
.90879 .54722 m
.90878 .54722 L
s
.90879 .54722 m
.90879 .54722 L
s
.90879 .54722 m
.90879 .54722 L
s
.90878 .54722 m
.90879 .54722 L
s
1 .055 0 r
.57601 .76811 m
.57596 .76823 L
s
.57596 .76768 m
.57601 .76811 L
s
.57639 .76792 m
.57601 .76811 L
s
1 .001 0 r
.63136 .63005 m
.63139 .63004 L
s
1 .055 0 r
.57424 .7681 m
.57639 .76792 L
s
1 .001 0 r
.41104 .57482 m
.41099 .57481 L
s
.973 1 0 r
.46816 .43676 m
.43432 .42248 L
s
1 .001 0 r
.63138 .63004 m
.63138 .63004 L
s
.63138 .63003 m
.63138 .63004 L
s
.63139 .63004 m
.63138 .63004 L
s
.63138 .63004 m
.63138 .63003 L
s
.63138 .63003 m
.63139 .63004 L
s
.63139 .63004 m
.63138 .63004 L
s
.63138 .63004 m
.63139 .63004 L
s
.63138 .63004 m
.63138 .63004 L
s
.411 .57482 m
.411 .57481 L
s
.411 .57481 m
.411 .5748 L
s
.411 .57481 m
.41099 .57481 L
s
.411 .5748 m
.411 .57481 L
s
.411 .5748 m
.41099 .57481 L
s
.411 .57481 m
.411 .57482 L
s
.41099 .57481 m
.411 .57482 L
s
.41099 .57481 m
.411 .57481 L
s
1 .055 0 r
.57591 .7678 m
.57596 .76768 L
s
.57596 .76768 m
.57639 .76792 L
s
.808 1 0 r
.43738 .40065 m
.44093 .40248 L
s
.43738 .40065 m
.42936 .40255 L
s
1 .055 0 r
.57639 .76792 m
.57596 .76823 L
s
.57591 .7678 m
.57639 .76792 L
s
.57596 .76823 m
.57591 .7678 L
s
1 .825 0 r
.5024 .46308 m
.50256 .46958 L
s
1 .336 0 r
.42123 .46146 m
.42242 .46214 L
s
.41994 .4638 m
.42123 .46146 L
s
.42123 .46146 m
.41918 .46188 L
s
.42113 .46448 m
.41994 .4638 L
s
.41994 .4638 m
.41918 .46188 L
s
0 .197 1 r
.43083 .4342 m
.44113 .46265 L
s
1 .271 0 r
.70347 .4084 m
.70427 .40833 L
s
.70413 .40594 m
.70347 .4084 L
s
.70347 .4084 m
.70276 .40686 L
s
.70563 .4074 m
.70347 .4084 L
s
.70714 .40203 m
.70347 .4084 L
s
.973 1 0 r
.58362 .43597 m
.58838 .44257 L
s
1 .047 0 r
.51531 .73983 m
.51532 .73992 L
s
.51532 .73947 m
.51531 .73983 L
s
.51569 .7397 m
.51531 .73983 L
s
.51533 .73956 m
.51532 .73947 L
s
.51532 .73947 m
.51569 .7397 L
s
1 .741 0 r
.63778 .40828 m
.63979 .40807 L
s
.63955 .40152 m
.63778 .40828 L
s
.63778 .40828 m
.63571 .40405 L
s
.64362 .40554 m
.63778 .40828 L
s
.64727 .39073 m
.63778 .40828 L
s
1 .005 0 r
.29355 .68448 m
.29352 .68449 L
s
.29352 .68444 m
.29355 .68448 L
s
.29355 .68448 m
.2935 .68448 L
s
.29354 .68446 m
.29355 .68448 L
s
.2934 .68441 m
.29355 .68448 L
s
1 .004 0 r
.84852 .51873 m
.84854 .51873 L
s
.84853 .5187 m
.84852 .51873 L
s
.84852 .51873 m
.84851 .51871 L
s
.84855 .51872 m
.84852 .51873 L
s
.84859 .51865 m
.84852 .51873 L
s
1 .005 0 r
.29352 .68444 m
.2935 .68448 L
s
.29354 .68446 m
.29352 .68444 L
s
.2935 .68448 m
.29352 .68449 L
s
1 .004 0 r
.84853 .5187 m
.84851 .51871 L
s
.84855 .51872 m
.84853 .5187 L
s
.84854 .51873 m
.84855 .51872 L
s
.84851 .51871 m
.84854 .51873 L
s
1 .005 0 r
.29352 .68449 m
.29354 .68446 L
s
1 .047 0 r
.51569 .7397 m
.51532 .73992 L
s
.51533 .73956 m
.51569 .7397 L
s
.51385 .73966 m
.51569 .7397 L
s
0 1 .077 r
.56238 .46342 m
.56739 .46331 L
s
.56714 .4446 m
.56238 .46342 L
s
.56238 .46342 m
.55604 .45189 L
s
.57847 .45595 m
.56238 .46342 L
s
.58735 .41489 m
.56238 .46342 L
s
1 .001 0 r
.79144 .65678 m
.79147 .65676 L
s
1 0 0 r
.571 .60153 m
.571 .60153 L
s
1 .006 0 r
.35056 .54627 m
.35039 .54617 L
s
1 .65 0 r
.40771 .40814 m
.39451 .39405 L
s
1 .001 0 r
.79147 .65676 m
.79147 .65677 L
s
.79146 .65676 m
.79147 .65676 L
s
.79147 .65676 m
.79147 .65676 L
s
.79147 .65677 m
.79147 .65677 L
s
.79147 .65676 m
.79147 .65677 L
s
.79147 .65677 m
.79146 .65676 L
s
.79146 .65676 m
.79147 .65676 L
s
.79147 .65676 m
.79147 .65677 L
s
1 .006 0 r
.35042 .54616 m
.35045 .54617 L
s
.35039 .5462 m
.35042 .54616 L
s
.35042 .54616 m
.35039 .54617 L
s
1 .047 0 r
.51532 .73992 m
.51533 .73956 L
s
1 .006 0 r
.35042 .54622 m
.35039 .5462 L
s
.35039 .5462 m
.35039 .54617 L
s
.35045 .54617 m
.35042 .54622 L
s
.35039 .54617 m
.35045 .54617 L
s
.35039 .54617 m
.35042 .54622 L
s
1 .08 0 r
.72647 .46314 m
.7268 .46316 L
s
.72675 .46244 m
.72647 .46314 L
s
.72647 .46314 m
.72638 .46269 L
s
.72717 .46291 m
.72647 .46314 L
s
.72798 .46142 m
.72647 .46314 L
s
1 .271 0 r
.70413 .40594 m
.70276 .40686 L
s
.70563 .4074 m
.70413 .40594 L
s
1 .08 0 r
.72675 .46244 m
.72638 .46269 L
s
.72717 .46291 m
.72675 .46244 L
s
1 .241 0 r
.36486 .43361 m
.36597 .43429 L
s
.36365 .43508 m
.36486 .43361 L
s
.36486 .43361 m
.36381 .43366 L
s
1 .08 0 r
.7268 .46316 m
.72717 .46291 L
s
1 .158 0 r
.30657 .40651 m
.30735 .40704 L
s
.30569 .40737 m
.30657 .40651 L
s
.30657 .40651 m
.30606 .40646 L
s
1 .018 0 r
.78798 .49045 m
.78805 .49045 L
s
.78804 .49029 m
.78798 .49045 L
s
.78798 .49045 m
.78795 .49035 L
s
.78814 .49039 m
.78798 .49045 L
s
.78832 .49005 m
.78798 .49045 L
s
.78804 .49029 m
.78795 .49035 L
s
.78814 .49039 m
.78804 .49029 L
s
.78805 .49045 m
.78814 .49039 L
s
1 .241 0 r
.36476 .43576 m
.36365 .43508 L
s
.36365 .43508 m
.36381 .43366 L
s
1 .018 0 r
.78795 .49035 m
.78805 .49045 L
s
1 .08 0 r
.72638 .46269 m
.7268 .46316 L
s
1 .271 0 r
.70427 .40833 m
.70563 .4074 L
s
1 .029 0 r
.45423 .71141 m
.45427 .71147 L
s
.45428 .71119 m
.45423 .71141 L
s
.4545 .71136 m
.45423 .71141 L
s
1 .158 0 r
.30647 .40791 m
.30569 .40737 L
s
.30569 .40737 m
.30606 .40646 L
s
1 .029 0 r
.45432 .71125 m
.45428 .71119 L
s
.45428 .71119 m
.4545 .71136 L
s
.4545 .71136 m
.45427 .71147 L
s
.45432 .71125 m
.4545 .71136 L
s
.45339 .71119 m
.4545 .71136 L
s
.45427 .71147 m
.45432 .71125 L
s
1 .003 0 r
.51047 .57299 m
.51047 .57298 L
s
.51047 .57298 m
.51047 .57296 L
s
.51047 .57298 m
.51045 .57297 L
s
.51047 .57296 m
.51047 .57296 L
s
.51047 .57296 m
.51045 .57297 L
s
1 .039 0 r
.67395 .76648 m
.67534 .76611 L
s
1 0 0 r
.73114 .62826 m
.73115 .62826 L
s
1 .003 0 r
.51057 .57298 m
.51045 .57297 L
s
1 .011 0 r
.29001 .51769 m
.28978 .51748 L
s
1 0 0 r
.73114 .62826 m
.73115 .62826 L
s
.73114 .62826 m
.73114 .62826 L
s
.73114 .62826 m
.73115 .62826 L
s
.73115 .62826 m
.73114 .62826 L
s
.73115 .62826 m
.73115 .62826 L
s
.73114 .62826 m
.73114 .62826 L
s
.73114 .62826 m
.73115 .62826 L
s
.73115 .62826 m
.73114 .62826 L
s
1 .003 0 r
.51045 .57297 m
.51047 .57299 L
s
.51045 .57297 m
.51047 .57296 L
s
.51047 .57296 m
.51047 .57299 L
s
1 .158 0 r
.30735 .40704 m
.30647 .40791 L
s
.30606 .40646 m
.30735 .40704 L
s
1 .011 0 r
.28983 .51747 m
.28987 .51751 L
s
.28977 .51754 m
.28983 .51747 L
s
.28983 .51747 m
.28978 .51748 L
s
.28982 .51757 m
.28977 .51754 L
s
.28977 .51754 m
.28978 .51748 L
s
.28987 .51751 m
.28982 .51757 L
s
.28978 .51748 m
.28987 .51751 L
s
.28978 .51748 m
.28982 .51757 L
s
1 .039 0 r
.67516 .76628 m
.67507 .76638 L
s
.67505 .76599 m
.67516 .76628 L
s
.67534 .76611 m
.67516 .76628 L
s
.67497 .76609 m
.67505 .76599 L
s
.67505 .76599 m
.67534 .76611 L
s
1 .271 0 r
.70276 .40686 m
.70427 .40833 L
s
1 .336 0 r
.42242 .46214 m
.42113 .46448 L
s
.41918 .46188 m
.42242 .46214 L
s
.41918 .46188 m
.42113 .46448 L
s
1 .158 0 r
.30606 .40646 m
.30647 .40791 L
s
1 .741 0 r
.63955 .40152 m
.63571 .40405 L
s
.64362 .40554 m
.63955 .40152 L
s
1 .039 0 r
.67534 .76611 m
.67507 .76638 L
s
.67497 .76609 m
.67534 .76611 L
s
.67507 .76638 m
.67497 .76609 L
s
1 .241 0 r
.36597 .43429 m
.36476 .43576 L
s
.36381 .43366 m
.36597 .43429 L
s
.36381 .43366 m
.36476 .43576 L
s
1 .012 0 r
.39316 .68282 m
.39319 .68284 L
s
.39319 .68273 m
.39316 .68282 L
s
.39327 .68281 m
.39316 .68282 L
s
.39322 .68276 m
.39319 .68273 L
s
.39319 .68273 m
.39327 .68281 L
s
.39327 .68281 m
.39319 .68284 L
s
.39322 .68276 m
.39327 .68281 L
s
.39286 .68269 m
.39327 .68281 L
s
.39319 .68284 m
.39322 .68276 L
s
1 .002 0 r
.94864 .51677 m
.94865 .51677 L
s
.94865 .51676 m
.94864 .51677 L
s
.94864 .51677 m
.94864 .51677 L
s
.94866 .51677 m
.94864 .51677 L
s
.94867 .51674 m
.94864 .51677 L
s
.94865 .51676 m
.94864 .51677 L
s
.94866 .51677 m
.94865 .51676 L
s
.94865 .51677 m
.94866 .51677 L
s
.94864 .51677 m
.94865 .51677 L
s
1 .04 0 r
.61355 .738 m
.61507 .73774 L
s
1 0 0 r
.67077 .59971 m
.67077 .59971 L
s
1 .024 0 r
.45008 .5444 m
.44924 .54415 L
s
0 1 .511 r
.50729 .40611 m
.41129 .38839 L
s
1 .013 0 r
.22939 .48908 m
.22917 .4888 L
s
1 .04 0 r
.61483 .7379 m
.61477 .73799 L
s
.61476 .7376 m
.61483 .7379 L
s
.61507 .73774 m
.61483 .7379 L
s
1 .024 0 r
.44941 .54431 m
.44935 .54427 L
s
.44935 .54427 m
.44941 .54409 L
s
.44935 .54427 m
.44924 .54415 L
s
1 .04 0 r
.6147 .73768 m
.61476 .7376 L
s
.61476 .7376 m
.61507 .73774 L
s
1 .024 0 r
.44941 .54409 m
.44947 .54413 L
s
.44941 .54409 m
.44924 .54415 L
s
1 .013 0 r
.22922 .4888 m
.22928 .48884 L
s
.22915 .48887 m
.22922 .4888 L
s
.22922 .4888 m
.22917 .4888 L
s
.22921 .48892 m
.22915 .48887 L
s
.22915 .48887 m
.22917 .4888 L
s
.22928 .48884 m
.22921 .48892 L
s
.22917 .4888 m
.22928 .48884 L
s
.22917 .4888 m
.22921 .48892 L
s
1 .024 0 r
.44924 .54415 m
.44941 .54431 L
s
.44924 .54415 m
.44947 .54413 L
s
.44947 .54413 m
.44941 .54431 L
s
1 .04 0 r
.61507 .73774 m
.61477 .73799 L
s
.6147 .73768 m
.61507 .73774 L
s
.61477 .73799 m
.6147 .73768 L
s
0 .434 1 r
.61811 .43603 m
.60058 .45783 L
s
.6367 .44617 m
.61811 .43603 L
s
1 .741 0 r
.63979 .40807 m
.64362 .40554 L
s
1 .006 0 r
.88829 .48825 m
.88831 .48825 L
s
.8883 .4882 m
.88829 .48825 L
s
.88829 .48825 m
.88827 .48822 L
s
.88834 .48823 m
.88829 .48825 L
s
.88839 .48811 m
.88829 .48825 L
s
.8883 .4882 m
.88827 .48822 L
s
.88834 .48823 m
.8883 .4882 L
s
.88831 .48825 m
.88834 .48823 L
s
.88827 .48822 m
.88831 .48825 L
s
1 .003 0 r
.33235 .65419 m
.33234 .65419 L
s
.33234 .65417 m
.33235 .65419 L
s
.33235 .65419 m
.33233 .65419 L
s
.33235 .65418 m
.33235 .65419 L
s
.33227 .65415 m
.33235 .65419 L
s
.33234 .65417 m
.33233 .65419 L
s
.33235 .65418 m
.33234 .65417 L
s
.33233 .65419 m
.33234 .65419 L
s
1 .035 0 r
.5542 .70953 m
.55418 .7096 L
s
.55418 .70926 m
.5542 .70953 L
s
.55445 .70941 m
.5542 .70953 L
s
1 .003 0 r
.33234 .65419 m
.33235 .65418 L
s
1 .002 0 r
.61027 .57116 m
.61027 .57115 L
s
.61027 .57115 m
.61027 .57114 L
s
.61027 .57115 m
.61025 .57115 L
s
.61027 .57114 m
.61026 .57114 L
s
.61027 .57114 m
.61025 .57115 L
s
.61025 .57115 m
.61027 .57116 L
s
.61025 .57115 m
.61026 .57114 L
s
.61033 .57113 m
.61025 .57115 L
s
.61026 .57114 m
.61027 .57116 L
s
1 .035 0 r
.55416 .70933 m
.55418 .70926 L
s
.55418 .70926 m
.55445 .70941 L
s
1 0 0 r
.83114 .62648 m
.83114 .62647 L
s
1 .035 0 r
.55308 .7095 m
.55445 .70941 L
s
1 .043 0 r
.38952 .51578 m
.38831 .51505 L
s
1 0 0 r
.83114 .62647 m
.83114 .62648 L
s
.83114 .62648 m
.83114 .62647 L
s
.83114 .62647 m
.83114 .62647 L
s
.83114 .62648 m
.83114 .62648 L
s
.83114 .62647 m
.83114 .62648 L
s
.83114 .62648 m
.83114 .62648 L
s
.83114 .62648 m
.83114 .62647 L
s
.83114 .62647 m
.83114 .62648 L
s
1 .035 0 r
.55445 .70941 m
.55418 .7096 L
s
.55416 .70933 m
.55445 .70941 L
s
1 .081 0 r
.76646 .43264 m
.76672 .43262 L
s
.76666 .4319 m
.76646 .43264 L
s
.76646 .43264 m
.76626 .43218 L
s
.76712 .43234 m
.76646 .43264 L
s
.76762 .43076 m
.76646 .43264 L
s
1 .035 0 r
.55418 .7096 m
.55416 .70933 L
s
1 .081 0 r
.76666 .4319 m
.76626 .43218 L
s
.76712 .43234 m
.76666 .4319 L
s
.76672 .43262 m
.76712 .43234 L
s
1 .023 0 r
.82768 .45998 m
.82776 .45998 L
s
.82774 .45977 m
.82768 .45998 L
s
.82768 .45998 m
.82763 .45985 L
s
.82788 .4599 m
.82768 .45998 L
s
.82804 .45945 m
.82768 .45998 L
s
1 .043 0 r
.38856 .515 m
.38872 .5151 L
s
.38838 .51529 m
.38856 .515 L
s
.38856 .515 m
.38831 .51505 L
s
1 .023 0 r
.82774 .45977 m
.82763 .45985 L
s
.82788 .4599 m
.82774 .45977 L
s
1 .043 0 r
.38854 .51539 m
.38838 .51529 L
s
.38838 .51529 m
.38831 .51505 L
s
1 .023 0 r
.82776 .45998 m
.82788 .4599 L
s
1 .081 0 r
.76626 .43218 m
.76672 .43262 L
s
1 .023 0 r
.82763 .45985 m
.82776 .45998 L
s
0 .197 1 r
.62193 .45533 m
.64061 .43206 L
s
1 .043 0 r
.38872 .5151 m
.38854 .51539 L
s
.38831 .51505 m
.38872 .5151 L
s
.38831 .51505 m
.38854 .51539 L
s
1 .039 0 r
.54862 .54282 m
.54866 .54276 L
s
.54866 .54276 m
.54862 .54246 L
s
.54866 .54276 m
.54832 .54267 L
s
.54862 .54246 m
.54859 .54252 L
s
.54862 .54246 m
.54832 .54267 L
s
.54832 .54267 m
.54862 .54282 L
s
.54832 .54267 m
.54859 .54252 L
s
.54982 .54252 m
.54832 .54267 L
s
1 .021 0 r
.49319 .68107 m
.49321 .68111 L
s
.49321 .68091 m
.49319 .68107 L
s
.49337 .68102 m
.49319 .68107 L
s
.49322 .68095 m
.49321 .68091 L
s
.49321 .68091 m
.49337 .68102 L
s
.49337 .68102 m
.49321 .68111 L
s
.49322 .68095 m
.49337 .68102 L
s
.49254 .68096 m
.49337 .68102 L
s
.939 1 0 r
.53553 .45899 m
.53837 .46693 L
s
1 .039 0 r
.54859 .54252 m
.54862 .54282 L
s
1 .021 0 r
.49321 .68111 m
.49322 .68095 L
s
1 0 0 r
.27162 .62559 m
.27162 .62559 L
s
.27162 .62558 m
.27162 .62559 L
s
.27162 .62559 m
.27161 .62559 L
s
.27162 .62559 m
.27162 .62559 L
s
.27161 .62558 m
.27162 .62559 L
s
.27162 .62558 m
.27161 .62559 L
s
.27162 .62559 m
.27162 .62558 L
s
.27161 .62559 m
.27162 .62559 L
s
.27162 .62559 m
.27162 .62559 L
s
1 .023 0 r
.71348 .73634 m
.71425 .73606 L
s
1 0 0 r
.77076 .59789 m
.77076 .59789 L
s
1 .046 0 r
.32889 .48714 m
.32793 .4862 L
s
1 .741 0 r
.63571 .40405 m
.63979 .40807 L
s
1 .023 0 r
.71417 .73617 m
.71411 .73623 L
s
.71409 .736 m
.71417 .73617 L
s
.71425 .73606 m
.71417 .73617 L
s
.71403 .73606 m
.71409 .736 L
s
.71409 .736 m
.71425 .73606 L
s
.71411 .73623 m
.71403 .73606 L
s
.71425 .73606 m
.71411 .73623 L
s
0 1 .077 r
.56714 .4446 m
.55604 .45189 L
s
.57847 .45595 m
.56714 .4446 L
s
1 .023 0 r
.71403 .73606 m
.71425 .73606 L
s
1 .051 0 r
.37598 .79141 m
.37609 .79154 L
s
.37612 .79103 m
.37598 .79141 L
s
.37647 .79138 m
.37598 .79141 L
s
.37623 .79116 m
.37612 .79103 L
s
.37612 .79103 m
.37647 .79138 L
s
.37647 .79138 m
.37609 .79154 L
s
.37623 .79116 m
.37647 .79138 L
s
.37463 .79091 m
.37647 .79138 L
s
1 .046 0 r
.32813 .48618 m
.32834 .48631 L
s
.3279 .48646 m
.32813 .48618 L
s
.32813 .48618 m
.32793 .4862 L
s
1 .051 0 r
.37609 .79154 m
.37623 .79116 L
s
1 .046 0 r
.32811 .48659 m
.3279 .48646 L
s
.3279 .48646 m
.32793 .4862 L
s
.32834 .48631 m
.32811 .48659 L
s
.32793 .4862 m
.32834 .48631 L
s
.32793 .4862 m
.32811 .48659 L
s
1 .007 0 r
.43212 .65246 m
.43214 .65247 L
s
.43214 .65241 m
.43212 .65246 L
s
.43219 .65245 m
.43212 .65246 L
s
.43215 .65242 m
.43214 .65241 L
s
.43214 .65241 m
.43219 .65245 L
s
.43219 .65245 m
.43214 .65247 L
s
.43215 .65242 m
.43219 .65245 L
s
.43194 .65239 m
.43219 .65245 L
s
.43214 .65247 m
.43215 .65242 L
s
1 .001 0 r
.71029 .56929 m
.7103 .56929 L
s
.71029 .56928 m
.71029 .56929 L
s
.71029 .56929 m
.71029 .56929 L
s
.7103 .56929 m
.71029 .56929 L
s
.71031 .56928 m
.71029 .56929 L
s
.71029 .56928 m
.71029 .56929 L
s
.7103 .56929 m
.71029 .56928 L
s
.7103 .56929 m
.7103 .56929 L
s
.71029 .56929 m
.7103 .56929 L
s
1 .023 0 r
.653 .7078 m
.65383 .70757 L
s
1 .162 0 r
.48925 .51387 m
.48309 .5128 L
s
1 .04 0 r
.26819 .45846 m
.26755 .45755 L
s
1 .023 0 r
.65372 .70768 m
.65367 .70773 L
s
.65366 .7075 m
.65372 .70768 L
s
.65383 .70757 m
.65372 .70768 L
s
.65361 .70756 m
.65366 .7075 L
s
.65366 .7075 m
.65383 .70757 L
s
.808 1 0 r
.44093 .40248 m
.43709 .41119 L
s
.42936 .40255 m
.43709 .41119 L
s
1 .023 0 r
.65383 .70757 m
.65367 .70773 L
s
.65361 .70756 m
.65383 .70757 L
s
.65367 .70773 m
.65361 .70756 L
s
1 .162 0 r
.48432 .51376 m
.48408 .51353 L
s
.48408 .51353 m
.48433 .51228 L
s
.48408 .51353 m
.48309 .5128 L
s
1 .133 0 r
.58548 .51373 m
.58582 .51351 L
s
.58582 .51351 m
.58546 .51252 L
s
.58582 .51351 m
.58454 .51342 L
s
.58546 .51252 m
.58513 .51274 L
s
.58546 .51252 m
.58454 .51342 L
s
.58454 .51342 m
.58548 .51373 L
s
.58454 .51342 m
.58513 .51274 L
s
.58921 .51195 m
.58454 .51342 L
s
1 .162 0 r
.48433 .51228 m
.48457 .5125 L
s
.48433 .51228 m
.48309 .5128 L
s
.808 1 0 r
.42936 .40255 m
.44093 .40248 L
s
1 .029 0 r
.31487 .76274 m
.31467 .76281 L
s
.31469 .76253 m
.31487 .76274 L
s
.31487 .76274 m
.31459 .76273 L
s
.31477 .76261 m
.31487 .76274 L
s
.31393 .76239 m
.31487 .76274 L
s
.31459 .76273 m
.31467 .76281 L
s
.31469 .76253 m
.31459 .76273 L
s
.31477 .76261 m
.31469 .76253 L
s
1 .59 0 r
.50987 .48629 m
.51001 .48559 L
s
.51001 .48559 m
.5099 .48093 L
s
.51001 .48559 m
.50522 .4837 L
s
1 .04 0 r
.26769 .45755 m
.26788 .45769 L
s
.26747 .45778 m
.26769 .45755 L
s
.26769 .45755 m
.26755 .45755 L
s
0 .434 1 r
.60058 .45783 m
.61905 .46816 L
s
1 .04 0 r
.26766 .45792 m
.26747 .45778 L
s
.26747 .45778 m
.26755 .45755 L
s
1 .029 0 r
.31467 .76281 m
.31477 .76261 L
s
1 .014 0 r
.64936 .54085 m
.64945 .54087 L
s
.64945 .54074 m
.64936 .54085 L
s
.64936 .54085 m
.6494 .54077 L
s
.6495 .54084 m
.64936 .54085 L
s
.64979 .54063 m
.64936 .54085 L
s
1 .04 0 r
.26788 .45769 m
.26766 .45792 L
s
.26755 .45755 m
.26788 .45769 L
s
1 .014 0 r
.64945 .54087 m
.6495 .54084 L
s
.6495 .54084 m
.64945 .54074 L
s
.64945 .54074 m
.6494 .54077 L
s
1 .009 0 r
.9282 .45768 m
.92823 .45767 L
s
.92822 .4576 m
.9282 .45768 L
s
.9282 .45768 m
.92818 .45763 L
s
.92827 .45764 m
.9282 .45768 L
s
.92832 .45747 m
.9282 .45768 L
s
.92822 .4576 m
.92818 .45763 L
s
.92827 .45764 m
.92822 .4576 L
s
.92823 .45767 m
.92827 .45764 L
s
1 .04 0 r
.26755 .45755 m
.26766 .45792 L
s
1 .009 0 r
.92818 .45763 m
.92823 .45767 L
s
1 .014 0 r
.6494 .54077 m
.64945 .54087 L
s
1 .001 0 r
.37129 .6238 m
.37128 .6238 L
s
.37129 .62379 m
.37129 .6238 L
s
.37129 .6238 m
.37128 .6238 L
s
.37129 .6238 m
.37129 .6238 L
s
.37127 .62379 m
.37129 .6238 L
s
.37128 .6238 m
.37128 .6238 L
s
.37129 .62379 m
.37128 .6238 L
s
.37129 .6238 m
.37129 .62379 L
s
.37128 .6238 m
.37129 .6238 L
s
1 0 0 r
.87097 .59607 m
.87097 .59607 L
s
1 .02 0 r
.59245 .67923 m
.5932 .67911 L
s
1 .215 0 r
.42861 .48519 m
.4222 .48173 L
s
1 .034 0 r
.20743 .42975 m
.207 .42895 L
s
0 .813 1 r
.45728 .49026 m
.46652 .48515 L
s
.46652 .48515 m
.45789 .46125 L
s
.46652 .48515 m
.43568 .48287 L
s
1 .02 0 r
.59308 .67919 m
.59305 .67923 L
s
.59305 .67904 m
.59308 .67919 L
s
.5932 .67911 m
.59308 .67919 L
s
.59302 .67908 m
.59305 .67904 L
s
.59305 .67904 m
.5932 .67911 L
s
1 .162 0 r
.48309 .5128 m
.48432 .51376 L
s
.48309 .5128 m
.48457 .5125 L
s
1 .133 0 r
.58513 .51274 m
.58548 .51373 L
s
1 .59 0 r
.5099 .48093 m
.50976 .48162 L
s
.5099 .48093 m
.50522 .4837 L
s
1 .02 0 r
.5932 .67911 m
.59305 .67923 L
s
.59302 .67908 m
.5932 .67911 L
s
.59305 .67923 m
.59302 .67908 L
s
1 .077 0 r
.80657 .40185 m
.80676 .40182 L
s
.8067 .40114 m
.80657 .40185 L
s
.80657 .40185 m
.80631 .40143 L
s
.80715 .40153 m
.80657 .40185 L
s
.80739 .39999 m
.80657 .40185 L
s
1 .215 0 r
.62269 .48499 m
.62393 .48522 L
s
.62387 .48327 m
.62269 .48499 L
s
.62269 .48499 m
.62304 .48375 L
s
.62476 .48474 m
.62269 .48499 L
s
.62872 .48129 m
.62269 .48499 L
s
1 .162 0 r
.48457 .5125 m
.48432 .51376 L
s
1 .077 0 r
.8067 .40114 m
.80631 .40143 L
s
.80715 .40153 m
.8067 .40114 L
s
1 .026 0 r
.86756 .42937 m
.86764 .42937 L
s
.86762 .42913 m
.86756 .42937 L
s
.86756 .42937 m
.86749 .42923 L
s
.86777 .42927 m
.86756 .42937 L
s
.86789 .42875 m
.86756 .42937 L
s
1 .215 0 r
.62387 .48327 m
.62304 .48375 L
s
.62476 .48474 m
.62387 .48327 L
s
1 .026 0 r
.86762 .42913 m
.86749 .42923 L
s
.86777 .42927 m
.86762 .42913 L
s
1 .215 0 r
.62393 .48522 m
.62476 .48474 L
s
1 .077 0 r
.47679 .78972 m
.47685 .7899 L
s
.47686 .78913 m
.47679 .78972 L
s
.47745 .78957 m
.47679 .78972 L
s
1 .026 0 r
.86764 .42937 m
.86777 .42927 L
s
1 .077 0 r
.80676 .40182 m
.80715 .40153 L
s
1 .026 0 r
.86749 .42923 m
.86764 .42937 L
s
1 .077 0 r
.47692 .78931 m
.47686 .78913 L
s
.47686 .78913 m
.47745 .78957 L
s
1 .034 0 r
.2071 .42896 m
.20727 .42909 L
s
.2069 .42914 m
.2071 .42896 L
s
.2071 .42896 m
.207 .42895 L
s
1 .077 0 r
.80631 .40143 m
.80676 .40182 L
s
1 .034 0 r
.20707 .42926 m
.2069 .42914 L
s
.2069 .42914 m
.207 .42895 L
s
.20727 .42909 m
.20707 .42926 L
s
.207 .42895 m
.20727 .42909 L
s
1 .077 0 r
.47745 .78957 m
.47685 .7899 L
s
.47692 .78931 m
.47745 .78957 L
s
.47446 .7893 m
.47745 .78957 L
s
1 .034 0 r
.207 .42895 m
.20707 .42926 L
s
1 .077 0 r
.47685 .7899 m
.47692 .78931 L
s
1 .01 0 r
.53216 .65065 m
.53216 .65067 L
s
.53216 .65057 m
.53216 .65065 L
s
.53224 .65062 m
.53216 .65065 L
s
.53216 .65059 m
.53216 .65057 L
s
.53216 .65057 m
.53224 .65062 L
s
1 0 0 r
.81051 .56743 m
.81051 .56743 L
s
.81051 .56742 m
.81051 .56743 L
s
.81051 .56743 m
.81051 .56743 L
s
.81051 .56743 m
.81051 .56743 L
s
.81051 .56742 m
.81051 .56743 L
s
.81051 .56742 m
.81051 .56743 L
s
.81051 .56743 m
.81051 .56742 L
s
.81051 .56743 m
.81051 .56743 L
s
.81051 .56743 m
.81051 .56743 L
s
1 .011 0 r
.75314 .7061 m
.75348 .70593 L
s
1 .01 0 r
.53183 .65063 m
.53224 .65062 L
s
1 .166 0 r
.3679 .45648 m
.36446 .45299 L
s
1 0 0 r
.31053 .59516 m
.31053 .59516 L
s
1 .01 0 r
.53224 .65062 m
.53216 .65067 L
s
.53216 .65059 m
.53224 .65062 L
s
.53216 .65067 m
.53216 .65059 L
s
1 .011 0 r
.75341 .70591 m
.75346 .70599 L
s
.75337 .70594 m
.75341 .70591 L
s
.75341 .70591 m
.75348 .70593 L
s
.75346 .70599 m
.75342 .70602 L
s
.75348 .70593 m
.75346 .70599 L
s
.75342 .70602 m
.75337 .70594 L
s
.75337 .70594 m
.75348 .70593 L
s
.75348 .70593 m
.75342 .70602 L
s
1 .053 0 r
.41521 .76121 m
.41531 .76134 L
s
.41532 .76081 m
.41521 .76121 L
s
.41571 .76116 m
.41521 .76121 L
s
.973 1 0 r
.44101 .42995 m
.43794 .42828 L
s
.43794 .42828 m
.44125 .42078 L
s
.43794 .42828 m
.43432 .42248 L
s
1 .053 0 r
.41542 .76094 m
.41532 .76081 L
s
.41532 .76081 m
.41571 .76116 L
s
1 .215 0 r
.62304 .48375 m
.62393 .48522 L
s
1 .053 0 r
.41571 .76116 m
.41531 .76134 L
s
.41542 .76094 m
.41571 .76116 L
s
.41374 .76075 m
.41571 .76116 L
s
0 1 .511 r
.4303 .40313 m
.42704 .40049 L
s
.42704 .40049 m
.43098 .38088 L
s
.42704 .40049 m
.41129 .38839 L
s
1 .59 0 r
.50522 .4837 m
.50987 .48629 L
s
.50522 .4837 m
.50976 .48162 L
s
.52856 .48324 m
.50522 .4837 L
s
0 1 .077 r
.56739 .46331 m
.57847 .45595 L
s
0 .813 1 r
.45789 .46125 m
.44855 .46612 L
s
.45789 .46125 m
.43568 .48287 L
s
1 .825 0 r
.58856 .45579 m
.5925 .45627 L
s
.59234 .44884 m
.58856 .45579 L
s
.58856 .45579 m
.58865 .45093 L
s
.59618 .45417 m
.58856 .45579 L
s
.60803 .43947 m
.58856 .45579 L
s
1 .053 0 r
.41531 .76134 m
.41542 .76094 L
s
.973 1 0 r
.44125 .42078 m
.44433 .42242 L
s
.44125 .42078 m
.43432 .42248 L
s
1 .004 0 r
.7499 .53881 m
.74992 .53882 L
s
.74992 .53878 m
.7499 .53881 L
s
.7499 .53881 m
.7499 .53879 L
s
.74993 .53881 m
.7499 .53881 L
s
.74998 .53874 m
.7499 .53881 L
s
.74992 .53878 m
.7499 .53879 L
s
.74993 .53881 m
.74992 .53878 L
s
.74992 .53882 m
.74993 .53881 L
s
.7499 .53879 m
.74992 .53882 L
s
1 .002 0 r
.4712 .62201 m
.4712 .62201 L
s
.4712 .62199 m
.4712 .62201 L
s
.47121 .622 m
.4712 .62201 L
s
.4712 .622 m
.4712 .62199 L
s
.4712 .62199 m
.47121 .622 L
s
.47121 .622 m
.4712 .62201 L
s
.4712 .622 m
.47121 .622 L
s
.47115 .62199 m
.47121 .622 L
s
.4712 .62201 m
.4712 .622 L
s
1 .01 0 r
.69258 .6775 m
.69291 .67737 L
s
1 .114 0 r
.30713 .42774 m
.30548 .42509 L
s
1 0 0 r
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
1 .01 0 r
.69287 .67742 m
.69284 .67744 L
s
.69284 .67734 m
.69287 .67742 L
s
.69291 .67737 m
.69287 .67742 L
s
.69281 .67737 m
.69284 .67734 L
s
.69284 .67734 m
.69291 .67737 L
s
1 .229 0 r
.66376 .45537 m
.66472 .45543 L
s
.66463 .45337 m
.66376 .45537 L
s
.66376 .45537 m
.66356 .45403 L
s
.66579 .45476 m
.66376 .45537 L
s
.66837 .45052 m
.66376 .45537 L
s
1 .01 0 r
.69284 .67744 m
.69281 .67737 L
s
.69291 .67737 m
.69284 .67744 L
s
.69281 .67737 m
.69291 .67737 L
s
1 .215 0 r
.42352 .48145 m
.42429 .48189 L
s
.42268 .48295 m
.42352 .48145 L
s
.42352 .48145 m
.4222 .48173 L
s
.42345 .4834 m
.42268 .48295 L
s
.42268 .48295 m
.4222 .48173 L
s
1 .032 0 r
.6886 .51064 m
.68877 .51066 L
s
.68875 .51037 m
.6886 .51064 L
s
.6886 .51064 m
.68862 .51046 L
s
.6889 .51058 m
.6886 .51064 L
s
.68939 .51003 m
.6886 .51064 L
s
0 .813 1 r
.43568 .48287 m
.45728 .49026 L
s
.43568 .48287 m
.44855 .46612 L
s
.54705 .44634 m
.43568 .48287 L
s
1 .032 0 r
.68875 .51037 m
.68862 .51046 L
s
.6889 .51058 m
.68875 .51037 L
s
.68877 .51066 m
.6889 .51058 L
s
1 .229 0 r
.66463 .45337 m
.66356 .45403 L
s
.66579 .45476 m
.66463 .45337 L
s
1 .032 0 r
.68862 .51046 m
.68877 .51066 L
s
1 .028 0 r
.35364 .73249 m
.35371 .73256 L
s
.35373 .73228 m
.35364 .73249 L
s
.35391 .73249 m
.35364 .73249 L
s
.35391 .73249 m
.35371 .73256 L
s
.35373 .73228 m
.35391 .73249 L
s
.35381 .73235 m
.35391 .73249 L
s
.35296 .73216 m
.35391 .73249 L
s
.35381 .73235 m
.35373 .73228 L
s
1 .229 0 r
.66472 .45543 m
.66579 .45476 L
s
1 .028 0 r
.35371 .73256 m
.35381 .73235 L
s
1 .825 0 r
.59234 .44884 m
.58865 .45093 L
s
.59618 .45417 m
.59234 .44884 L
s
1 .08 0 r
.57708 .78769 m
.57702 .78787 L
s
.57701 .78708 m
.57708 .78769 L
s
.57764 .78742 m
.57708 .78769 L
s
1 0 0 r
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
1 .007 0 r
.63195 .64886 m
.63219 .64879 L
s
1 .08 0 r
.57451 .78769 m
.57764 .78742 L
s
1 0 0 r
.4104 .59333 m
.4104 .59333 L
s
1 .825 0 r
.46784 .4545 m
.44054 .44309 L
s
1 .08 0 r
.24628 .39897 m
.24544 .39702 L
s
1 .007 0 r
.63216 .64882 m
.63214 .64884 L
s
.63214 .64877 m
.63216 .64882 L
s
.63219 .64879 m
.63216 .64882 L
s
.63212 .64879 m
.63214 .64877 L
s
.63214 .64877 m
.63219 .64879 L
s
1 .08 0 r
.57694 .78726 m
.57701 .78708 L
s
.57701 .78708 m
.57764 .78742 L
s
1 .007 0 r
.63219 .64879 m
.63214 .64884 L
s
.63212 .64879 m
.63219 .64879 L
s
.63214 .64884 m
.63212 .64879 L
s
1 .59 0 r
.50976 .48162 m
.50987 .48629 L
s
1 .825 0 r
.5925 .45627 m
.59618 .45417 L
s
1 .08 0 r
.57764 .78742 m
.57702 .78787 L
s
.57694 .78726 m
.57764 .78742 L
s
1 .028 0 r
.9076 .39862 m
.90767 .39861 L
s
.90764 .39836 m
.9076 .39862 L
s
.9076 .39862 m
.9075 .39847 L
s
.9078 .3985 m
.9076 .39862 L
s
.90787 .39794 m
.9076 .39862 L
s
1 .215 0 r
.42429 .48189 m
.42345 .4834 L
s
.4222 .48173 m
.42429 .48189 L
s
.4222 .48173 m
.42345 .4834 L
s
1 .65 0 r
.39728 .39401 m
.40033 .39579 L
s
.39401 .39798 m
.39728 .39401 L
s
.39728 .39401 m
.39451 .39405 L
s
1 .166 0 r
.36519 .45294 m
.36595 .45342 L
s
.36435 .45396 m
.36519 .45294 L
s
.36519 .45294 m
.36446 .45299 L
s
1 .028 0 r
.90764 .39836 m
.9075 .39847 L
s
.9078 .3985 m
.90764 .39836 L
s
.90767 .39861 m
.9078 .3985 L
s
0 1 .511 r
.43098 .38088 m
.43428 .38336 L
s
.43098 .38088 m
.41129 .38839 L
s
1 .229 0 r
.66356 .45403 m
.66472 .45543 L
s
1 .08 0 r
.57702 .78787 m
.57694 .78726 L
s
1 .028 0 r
.9075 .39847 m
.90767 .39861 L
s
1 .166 0 r
.36512 .45444 m
.36435 .45396 L
s
.36435 .45396 m
.36446 .45299 L
s
1 .073 0 r
.51608 .75936 m
.5161 .75951 L
s
.5161 .75879 m
.51608 .75936 L
s
.51668 .75917 m
.51608 .75936 L
s
.51611 .75895 m
.5161 .75879 L
s
.5161 .75879 m
.51668 .75917 L
s
1 .011 0 r
.29245 .70371 m
.29237 .70373 L
s
.29238 .70362 m
.29245 .70371 L
s
.29245 .70371 m
.29234 .7037 L
s
.29242 .70365 m
.29245 .70371 L
s
.29211 .70354 m
.29245 .70371 L
s
1 .114 0 r
.30584 .42511 m
.30641 .4255 L
s
.30521 .42574 m
.30584 .42511 L
s
.30584 .42511 m
.30548 .42509 L
s
1 .011 0 r
.29238 .70362 m
.29234 .7037 L
s
.29242 .70365 m
.29238 .70362 L
s
.29234 .7037 m
.29237 .70373 L
s
.29237 .70373 m
.29242 .70365 L
s
1 .073 0 r
.51668 .75917 m
.5161 .75951 L
s
.51611 .75895 m
.51668 .75917 L
s
.51378 .7591 m
.51668 .75917 L
s
1 .65 0 r
.39705 .39976 m
.39401 .39798 L
s
.39401 .39798 m
.39451 .39405 L
s
1 .001 0 r
.85038 .53687 m
.85038 .53687 L
s
.85038 .53686 m
.85038 .53687 L
s
.85038 .53687 m
.85038 .53687 L
s
.85039 .53687 m
.85038 .53687 L
s
.8504 .53685 m
.85038 .53687 L
s
.85038 .53686 m
.85038 .53687 L
s
.85039 .53687 m
.85038 .53686 L
s
.85038 .53687 m
.85039 .53687 L
s
.85038 .53687 m
.85038 .53687 L
s
1 .114 0 r
.30577 .42613 m
.30521 .42574 L
s
.30521 .42574 m
.30548 .42509 L
s
1 .004 0 r
.79293 .67576 m
.79305 .67569 L
s
1 .002 0 r
.57125 .62019 m
.57133 .62018 L
s
1 .001 0 r
.34958 .56463 m
.34955 .56462 L
s
1 .525 0 r
.40705 .42572 m
.39634 .4144 L
s
1 .002 0 r
.57131 .62019 m
.57131 .62019 L
s
.57131 .62018 m
.57131 .62019 L
s
.57133 .62018 m
.57131 .62019 L
s
.57131 .62018 m
.57131 .62018 L
s
.57131 .62018 m
.57133 .62018 L
s
1 .001 0 r
.34956 .56462 m
.34956 .56462 L
s
.34956 .56462 m
.34956 .56462 L
s
.34956 .56462 m
.34955 .56462 L
s
.34956 .56462 m
.34956 .56462 L
s
.34956 .56462 m
.34955 .56462 L
s
1 .002 0 r
.57133 .62018 m
.57131 .62019 L
s
.57131 .62018 m
.57133 .62018 L
s
.57131 .62019 m
.57131 .62018 L
s
1 .001 0 r
.34956 .56462 m
.34956 .56462 L
s
.34955 .56462 m
.34956 .56462 L
s
.34955 .56462 m
.34956 .56462 L
s
1 .004 0 r
.79302 .67568 m
.79304 .67571 L
s
.793 .67569 m
.79302 .67568 L
s
.79302 .67568 m
.79305 .67569 L
s
.79304 .67571 m
.79302 .67572 L
s
.79305 .67569 m
.79304 .67571 L
s
.79302 .67572 m
.793 .67569 L
s
.793 .67569 m
.79305 .67569 L
s
.79305 .67569 m
.79302 .67572 L
s
1 .166 0 r
.36595 .45342 m
.36512 .45444 L
s
.36446 .45299 m
.36595 .45342 L
s
1 .073 0 r
.5161 .75951 m
.51611 .75895 L
s
1 .114 0 r
.30641 .4255 m
.30577 .42613 L
s
.30548 .42509 m
.30641 .4255 L
s
1 .166 0 r
.36446 .45299 m
.36512 .45444 L
s
1 .08 0 r
.24564 .39705 m
.24604 .39736 L
s
.24517 .39746 m
.24564 .39705 L
s
.24564 .39705 m
.24544 .39702 L
s
1 .114 0 r
.30548 .42509 m
.30577 .42613 L
s
1 .08 0 r
.24557 .39776 m
.24517 .39746 L
s
.24517 .39746 m
.24544 .39702 L
s
1 .052 0 r
.4545 .73087 m
.45457 .73098 L
s
.45458 .73047 m
.4545 .73087 L
s
.45498 .73078 m
.4545 .73087 L
s
1 .08 0 r
.24604 .39736 m
.24557 .39776 L
s
.24544 .39702 m
.24604 .39736 L
s
1 .052 0 r
.45465 .73058 m
.45458 .73047 L
s
.45458 .73047 m
.45498 .73078 L
s
.45498 .73078 m
.45457 .73098 L
s
.45465 .73058 m
.45498 .73078 L
s
.45299 .73048 m
.45498 .73078 L
s
1 .08 0 r
.24544 .39702 m
.24557 .39776 L
s
1 .008 0 r
.78964 .50828 m
.78967 .50828 L
s
.78967 .50821 m
.78964 .50828 L
s
.78964 .50828 m
.78963 .50823 L
s
.78971 .50826 m
.78964 .50828 L
s
.78979 .5081 m
.78964 .50828 L
s
.78967 .50821 m
.78963 .50823 L
s
.78971 .50826 m
.78967 .50821 L
s
.78967 .50828 m
.78971 .50826 L
s
1 .052 0 r
.45457 .73098 m
.45465 .73058 L
s
1 .008 0 r
.78963 .50823 m
.78967 .50828 L
s
1 .046 0 r
.72825 .48031 m
.72844 .48032 L
s
.72841 .4799 m
.72825 .48031 L
s
.72825 .48031 m
.72819 .48005 L
s
.72865 .48017 m
.72825 .48031 L
s
.72912 .47933 m
.72825 .48031 L
s
1 .057 0 r
.67479 .78608 m
.67683 .78555 L
s
1 .003 0 r
.73229 .64709 m
.73237 .64705 L
s
1 0 0 r
.51049 .59149 m
.51049 .59149 L
s
1 .293 0 r
.34619 .39691 m
.3426 .38986 L
s
1 .003 0 r
.28869 .5359 m
.28862 .53583 L
s
.73235 .64704 m
.73236 .64706 L
s
.73234 .64705 m
.73235 .64704 L
s
.73235 .64704 m
.73237 .64705 L
s
.73236 .64706 m
.73235 .64707 L
s
.73237 .64705 m
.73236 .64706 L
s
.73235 .64707 m
.73234 .64705 L
s
.73234 .64705 m
.73237 .64705 L
s
.73237 .64705 m
.73235 .64707 L
s
.28863 .53583 m
.28865 .53584 L
s
.28862 .53585 m
.28863 .53583 L
s
.28863 .53583 m
.28862 .53583 L
s
.28863 .53586 m
.28862 .53585 L
s
.28862 .53585 m
.28862 .53583 L
s
.28865 .53584 m
.28863 .53586 L
s
.28862 .53583 m
.28865 .53584 L
s
.28862 .53583 m
.28863 .53586 L
s
1 .046 0 r
.72841 .4799 m
.72819 .48005 L
s
.72865 .48017 m
.72841 .4799 L
s
.72844 .48032 m
.72865 .48017 L
s
0 .434 1 r
.43751 .45048 m
.44721 .47731 L
s
1 .046 0 r
.72819 .48005 m
.72844 .48032 L
s
1 .202 0 r
.7054 .42438 m
.706 .42434 L
s
.7059 .42253 m
.7054 .42438 L
s
.7054 .42438 m
.70487 .42323 L
s
.70702 .42364 m
.7054 .42438 L
s
.70816 .41964 m
.7054 .42438 L
s
1 .057 0 r
.67656 .78579 m
.67643 .78594 L
s
.6764 .78537 m
.67656 .78579 L
s
.67683 .78555 m
.67656 .78579 L
s
1 .787 0 r
.54609 .48118 m
.54817 .47994 L
s
.54817 .47994 m
.54605 .47402 L
s
.54817 .47994 m
.54056 .47937 L
s
1 .057 0 r
.67628 .78551 m
.6764 .78537 L
s
.6764 .78537 m
.67683 .78555 L
s
0 1 .077 r
.55604 .45189 m
.56739 .46331 L
s
1 .057 0 r
.67683 .78555 m
.67643 .78594 L
s
.67628 .78551 m
.67683 .78555 L
s
1 .026 0 r
.39278 .70211 m
.39285 .70217 L
s
.39286 .70192 m
.39278 .70211 L
s
.39304 .7021 m
.39278 .70211 L
s
1 .057 0 r
.67643 .78594 m
.67628 .78551 L
s
1 .026 0 r
.39292 .70198 m
.39286 .70192 L
s
.39286 .70192 m
.39304 .7021 L
s
.39304 .7021 m
.39285 .70217 L
s
.39292 .70198 m
.39304 .7021 L
s
.39212 .70183 m
.39304 .7021 L
s
1 .202 0 r
.7059 .42253 m
.70487 .42323 L
s
.70702 .42364 m
.7059 .42253 L
s
1 .787 0 r
.54605 .47402 m
.54397 .47525 L
s
.54605 .47402 m
.54056 .47937 L
s
1 .026 0 r
.39285 .70217 m
.39292 .70198 L
s
1 .787 0 r
.54056 .47937 m
.54609 .48118 L
s
.54056 .47937 m
.54397 .47525 L
s
.56823 .47045 m
.54056 .47937 L
s
1 0 0 r
.95104 .53496 m
.95104 .53496 L
s
.95104 .53496 m
.95104 .53496 L
s
.95104 .53496 m
.95103 .53496 L
s
.95104 .53496 m
.95104 .53496 L
s
.95104 .53495 m
.95104 .53496 L
s
.95104 .53496 m
.95103 .53496 L
s
.95104 .53496 m
.95104 .53496 L
s
.95104 .53496 m
.95104 .53496 L
s
.95103 .53496 m
.95104 .53496 L
s
1 .063 0 r
.61405 .75745 m
.61645 .75704 L
s
1 .001 0 r
.67158 .61839 m
.67161 .61838 L
s
1 .003 0 r
.44966 .56276 m
.44954 .56273 L
s
0 1 .331 r
.50719 .4237 m
.41761 .40733 L
s
1 .006 0 r
.22773 .50714 m
.22763 .50702 L
s
1 .001 0 r
.67161 .61838 m
.6716 .61838 L
s
.6716 .61838 m
.67161 .61838 L
s
.67161 .61838 m
.67161 .61838 L
s
.6716 .61838 m
.6716 .61838 L
s
.6716 .61838 m
.67161 .61838 L
s
.6716 .61838 m
.6716 .61838 L
s
.67161 .61838 m
.6716 .61838 L
s
.6716 .61838 m
.67161 .61838 L
s
1 .003 0 r
.44957 .56275 m
.44956 .56275 L
s
.44956 .56275 m
.44957 .56272 L
s
.44956 .56275 m
.44954 .56273 L
s
.44957 .56272 m
.44957 .56273 L
s
.44957 .56272 m
.44954 .56273 L
s
.44954 .56273 m
.44957 .56275 L
s
.44954 .56273 m
.44957 .56273 L
s
.44957 .56273 m
.44957 .56275 L
s
1 .202 0 r
.706 .42434 m
.70702 .42364 L
s
1 .006 0 r
.22766 .50701 m
.22768 .50703 L
s
.22762 .50705 m
.22766 .50701 L
s
.22766 .50701 m
.22763 .50702 L
s
.22765 .50707 m
.22762 .50705 L
s
.22762 .50705 m
.22763 .50702 L
s
1 .65 0 r
.40033 .39579 m
.39705 .39976 L
s
.39451 .39405 m
.40033 .39579 L
s
1 .006 0 r
.22768 .50703 m
.22765 .50707 L
s
.22763 .50702 m
.22768 .50703 L
s
.22763 .50702 m
.22765 .50707 L
s
1 .063 0 r
.61607 .7573 m
.61598 .75744 L
s
.61596 .75681 m
.61607 .7573 L
s
.61645 .75704 m
.61607 .7573 L
s
.61586 .75695 m
.61596 .75681 L
s
.61596 .75681 m
.61645 .75704 L
s
.808 1 0 r
.62712 .39562 m
.62731 .39499 L
s
.62696 .38442 m
.62712 .39562 L
s
.62712 .39562 m
.62035 .38983 L
s
.63392 .38956 m
.62712 .39562 L
s
.62721 .36558 m
.62712 .39562 L
s
1 .202 0 r
.70487 .42323 m
.706 .42434 L
s
1 .063 0 r
.61645 .75704 m
.61598 .75744 L
s
.61586 .75695 m
.61645 .75704 L
s
.61598 .75744 m
.61586 .75695 L
s
1 .825 0 r
.58865 .45093 m
.5925 .45627 L
s
1 .65 0 r
.39451 .39405 m
.39705 .39976 L
s
1 .009 0 r
.33145 .67327 m
.3314 .67328 L
s
.3314 .6732 m
.33145 .67327 L
s
.33145 .67327 m
.33137 .67326 L
s
.33143 .67322 m
.33145 .67327 L
s
.33119 .67314 m
.33145 .67327 L
s
.3314 .6732 m
.33137 .67326 L
s
.33143 .67322 m
.3314 .6732 L
s
.33137 .67326 m
.3314 .67328 L
s
.3314 .67328 m
.33143 .67322 L
s
1 .062 0 r
.55522 .72886 m
.55519 .72899 L
s
.55518 .72838 m
.55522 .72886 L
s
.55567 .72865 m
.55522 .72886 L
s
1 .003 0 r
.89038 .50623 m
.89039 .50623 L
s
.89039 .50621 m
.89038 .50623 L
s
.89038 .50623 m
.89037 .50622 L
s
.8904 .50622 m
.89038 .50623 L
s
.89042 .50617 m
.89038 .50623 L
s
.89039 .50621 m
.89037 .50622 L
s
.8904 .50622 m
.89039 .50621 L
s
.89039 .50623 m
.8904 .50622 L
s
.89037 .50622 m
.89039 .50623 L
s
.973 1 0 r
.44433 .42242 m
.44101 .42995 L
s
.43432 .42248 m
.44101 .42995 L
s
1 .607 0 r
.64013 .42272 m
.64179 .42258 L
s
.64158 .41716 m
.64013 .42272 L
s
.64013 .42272 m
.63842 .41926 L
s
.64495 .42047 m
.64013 .42272 L
s
.64795 .40839 m
.64013 .42272 L
s
1 .062 0 r
.55515 .72851 m
.55518 .72838 L
s
.55518 .72838 m
.55567 .72865 L
s
1 .001 0 r
.83286 .64531 m
.83288 .6453 L
s
1 .062 0 r
.55324 .7288 m
.55567 .72865 L
s
1 0 0 r
.61081 .58966 m
.61081 .58966 L
s
1 .014 0 r
.38876 .534 m
.38836 .53376 L
s
.542 1 0 r
.44633 .39486 m
.41689 .36247 L
s
1 .001 0 r
.83287 .64529 m
.83288 .6453 L
s
.83287 .6453 m
.83287 .64529 L
s
.83287 .64529 m
.83288 .6453 L
s
.83288 .6453 m
.83288 .6453 L
s
.83288 .6453 m
.83288 .6453 L
s
.83288 .6453 m
.83287 .6453 L
s
.83287 .6453 m
.83288 .6453 L
s
.83288 .6453 m
.83288 .6453 L
s
1 .014 0 r
.38844 .53374 m
.38849 .53378 L
s
.38838 .53384 m
.38844 .53374 L
s
.38844 .53374 m
.38836 .53376 L
s
.38844 .53387 m
.38838 .53384 L
s
.38838 .53384 m
.38836 .53376 L
s
1 .062 0 r
.55567 .72865 m
.55519 .72899 L
s
.55515 .72851 m
.55567 .72865 L
s
.973 1 0 r
.43432 .42248 m
.44433 .42242 L
s
1 .014 0 r
.38849 .53378 m
.38844 .53387 L
s
.38836 .53376 m
.38849 .53378 L
s
.38836 .53376 m
.38844 .53387 L
s
1 .062 0 r
.55519 .72899 m
.55515 .72851 L
s
1 .013 0 r
.82954 .47765 m
.82959 .47765 L
s
.82958 .47753 m
.82954 .47765 L
s
.82954 .47765 m
.82951 .47758 L
s
.82965 .4776 m
.82954 .47765 L
s
.82974 .47736 m
.82954 .47765 L
s
1 .046 0 r
.49376 .70036 m
.4938 .70045 L
s
.4938 .7 m
.49376 .70036 L
s
.49416 .70025 m
.49376 .70036 L
s
1 .013 0 r
.82958 .47753 m
.82951 .47758 L
s
.82965 .4776 m
.82958 .47753 L
s
.82959 .47765 m
.82965 .4776 L
s
1 .046 0 r
.49383 .70009 m
.4938 .7 L
s
.4938 .7 m
.49416 .70025 L
s
1 .013 0 r
.82951 .47758 m
.82959 .47765 L
s
1 .052 0 r
.76823 .44972 m
.7684 .44971 L
s
.76836 .44924 m
.76823 .44972 L
s
.76823 .44972 m
.7681 .44943 L
s
.76865 .44953 m
.76823 .44972 L
s
.76898 .44852 m
.76823 .44972 L
s
1 .046 0 r
.49416 .70025 m
.4938 .70045 L
s
.49383 .70009 m
.49416 .70025 L
s
.49236 .70011 m
.49416 .70025 L
s
1 .052 0 r
.76836 .44924 m
.7681 .44943 L
s
.76865 .44953 m
.76836 .44924 L
s
1 .005 0 r
.54979 .56093 m
.5498 .56093 L
s
.5498 .56093 m
.54979 .56088 L
s
.5498 .56093 m
.54975 .56091 L
s
1 .002 0 r
.27023 .64445 m
.27022 .64446 L
s
.27022 .64444 m
.27023 .64445 L
s
.27023 .64445 m
.27022 .64445 L
s
.27023 .64445 m
.27023 .64445 L
s
.27019 .64442 m
.27023 .64445 L
s
1 .005 0 r
.54979 .56088 m
.54979 .56089 L
s
.54979 .56088 m
.54975 .56091 L
s
1 .002 0 r
.27022 .64444 m
.27022 .64445 L
s
.27023 .64445 m
.27022 .64444 L
s
.27022 .64445 m
.27022 .64446 L
s
.27022 .64446 m
.27023 .64445 L
s
1 .005 0 r
.54975 .56091 m
.54979 .56093 L
s
.54975 .56091 m
.54979 .56089 L
s
.54996 .56089 m
.54975 .56091 L
s
1 .046 0 r
.4938 .70045 m
.49383 .70009 L
s
1 .052 0 r
.7684 .44971 m
.76865 .44953 L
s
1 .005 0 r
.54979 .56089 m
.54979 .56093 L
s
1 .038 0 r
.71454 .7558 m
.71579 .75535 L
s
1 0 0 r
.77214 .61658 m
.77214 .61658 L
s
1 .021 0 r
.32779 .5052 m
.32734 .50477 L
s
1 0 0 r
.77214 .61658 m
.77214 .61658 L
s
.77214 .61658 m
.77214 .61658 L
s
.77214 .61658 m
.77214 .61658 L
s
.77214 .61658 m
.77214 .61658 L
s
.77214 .61658 m
.77214 .61658 L
s
.77214 .61658 m
.77214 .61658 L
s
.77214 .61658 m
.77214 .61658 L
s
.77214 .61658 m
.77214 .61658 L
s
1 .052 0 r
.7681 .44943 m
.7684 .44971 L
s
1 .607 0 r
.64158 .41716 m
.63842 .41926 L
s
.64495 .42047 m
.64158 .41716 L
s
1 .021 0 r
.32743 .50476 m
.32753 .50482 L
s
.32733 .50489 m
.32743 .50476 L
s
.32743 .50476 m
.32734 .50477 L
s
.32742 .50495 m
.32733 .50489 L
s
.32733 .50489 m
.32734 .50477 L
s
1 .038 0 r
.71565 .75553 m
.71555 .75563 L
s
.71553 .75526 m
.71565 .75553 L
s
.71579 .75535 m
.71565 .75553 L
s
.71542 .75536 m
.71553 .75526 L
s
.71553 .75526 m
.71579 .75535 L
s
0 .813 1 r
.62507 .47698 m
.61409 .47819 L
s
.61328 .44909 m
.62507 .47698 L
s
.62507 .47698 m
.59745 .46879 L
s
.63001 .45833 m
.62507 .47698 L
s
.56634 .40784 m
.62507 .47698 L
s
1 .021 0 r
.32753 .50482 m
.32742 .50495 L
s
.32734 .50477 m
.32753 .50482 L
s
.32734 .50477 m
.32742 .50495 L
s
1 .038 0 r
.71555 .75563 m
.71542 .75536 L
s
.71579 .75535 m
.71555 .75563 L
s
.71542 .75536 m
.71579 .75535 L
s
1 .021 0 r
.43199 .6716 m
.43203 .67165 L
s
.43204 .67144 m
.43199 .6716 L
s
.43219 .67158 m
.43199 .6716 L
s
.43208 .67149 m
.43204 .67144 L
s
.43204 .67144 m
.43219 .67158 L
s
.43219 .67158 m
.43203 .67165 L
s
.43208 .67149 m
.43219 .67158 L
s
.43142 .67139 m
.43219 .67158 L
s
.43203 .67165 m
.43208 .67149 L
s
1 .168 0 r
.7466 .39281 m
.74694 .39272 L
s
.74684 .39124 m
.7466 .39281 L
s
.7466 .39281 m
.74596 .39189 L
s
.74782 .39207 m
.7466 .39281 L
s
.74807 .38866 m
.7466 .39281 L
s
.808 1 0 r
.62696 .38442 m
.62035 .38983 L
s
.63392 .38956 m
.62696 .38442 L
s
1 0 0 r
.71135 .58782 m
.71135 .58782 L
s
1 .042 0 r
.65372 .72711 m
.65523 .7267 L
s
1 .058 0 r
.48905 .5321 m
.48682 .53171 L
s
1 .022 0 r
.26675 .47638 m
.26639 .47588 L
s
1 .058 0 r
.48726 .53206 m
.48718 .53197 L
s
.48718 .53197 m
.48727 .53152 L
s
.48718 .53197 m
.48682 .53171 L
s
.48727 .53152 m
.48736 .53161 L
s
.48727 .53152 m
.48682 .53171 L
s
1 .607 0 r
.64179 .42258 m
.64495 .42047 L
s
1 .042 0 r
.65503 .72689 m
.65493 .72699 L
s
.65492 .72658 m
.65503 .72689 L
s
.65523 .7267 m
.65503 .72689 L
s
.65482 .72668 m
.65492 .72658 L
s
.65492 .72658 m
.65523 .7267 L
s
1 .022 0 r
.26647 .47587 m
.26658 .47595 L
s
.26634 .476 m
.26647 .47587 L
s
.26647 .47587 m
.26639 .47588 L
s
1 .043 0 r
.31414 .78254 m
.31385 .78265 L
s
.31387 .78222 m
.31414 .78254 L
s
.31414 .78254 m
.31372 .78253 L
s
.314 .78234 m
.31414 .78254 L
s
.31274 .78202 m
.31414 .78254 L
s
1 .168 0 r
.74684 .39124 m
.74596 .39189 L
s
.74782 .39207 m
.74684 .39124 L
s
1 .043 0 r
.31372 .78253 m
.31385 .78265 L
s
.31387 .78222 m
.31372 .78253 L
s
1 .022 0 r
.26645 .47608 m
.26634 .476 L
s
.26634 .476 m
.26639 .47588 L
s
1 .043 0 r
.314 .78234 m
.31387 .78222 L
s
1 .058 0 r
.48682 .53171 m
.48726 .53206 L
s
.48682 .53171 m
.48736 .53161 L
s
1 .022 0 r
.26658 .47595 m
.26645 .47608 L
s
.26639 .47588 m
.26658 .47595 L
s
.26639 .47588 m
.26645 .47608 L
s
1 .058 0 r
.48736 .53161 m
.48726 .53206 L
s
1 .042 0 r
.65523 .7267 m
.65493 .72699 L
s
.65482 .72668 m
.65523 .7267 L
s
.65493 .72699 m
.65482 .72668 L
s
1 .043 0 r
.31385 .78265 m
.314 .78234 L
s
1 .168 0 r
.74694 .39272 m
.74782 .39207 L
s
1 .293 0 r
.3434 .38998 m
.34491 .39102 L
s
.34174 .39154 m
.3434 .38998 L
s
.3434 .38998 m
.3426 .38986 L
s
1 .787 0 r
.54397 .47525 m
.54609 .48118 L
s
1 .825 0 r
.44593 .44911 m
.44344 .44772 L
s
.44344 .44772 m
.44612 .44166 L
s
.44344 .44772 m
.44054 .44309 L
s
1 .168 0 r
.74596 .39189 m
.74694 .39272 L
s
1 .005 0 r
.93052 .4755 m
.93053 .4755 L
s
.93053 .47546 m
.93052 .4755 L
s
.93052 .4755 m
.93051 .47547 L
s
.93056 .47548 m
.93052 .4755 L
s
.93058 .47539 m
.93052 .4755 L
s
.93053 .47546 m
.93051 .47547 L
s
.93056 .47548 m
.93053 .47546 L
s
.93053 .4755 m
.93056 .47548 L
s
.93051 .47547 m
.93053 .4755 L
s
.37056 .64271 m
.37053 .64272 L
s
.37053 .64267 m
.37056 .64271 L
s
.37056 .64271 m
.37051 .64271 L
s
.37055 .64269 m
.37056 .64271 L
s
.3704 .64264 m
.37056 .64271 L
s
.37051 .64271 m
.37053 .64272 L
s
.37053 .64267 m
.37051 .64271 L
s
.37055 .64269 m
.37053 .64267 L
s
.37053 .64272 m
.37055 .64269 L
s
1 .002 0 r
.65043 .55905 m
.65045 .55905 L
s
.65045 .55903 m
.65043 .55905 L
s
.65043 .55905 m
.65044 .55904 L
s
.65045 .55905 m
.65043 .55905 L
s
.65049 .55902 m
.65043 .55905 L
s
.65045 .55905 m
.65045 .55905 L
s
.65045 .55905 m
.65045 .55903 L
s
.65045 .55903 m
.65044 .55904 L
s
.65044 .55904 m
.65045 .55905 L
s
1 0 0 r
.87292 .61477 m
.87292 .61477 L
s
1 .043 0 r
.59283 .69839 m
.59445 .69813 L
s
1 .111 0 r
.42807 .50327 m
.42475 .50149 L
s
1 .021 0 r
.20565 .44752 m
.20538 .44702 L
s
1 0 0 r
.87292 .61477 m
.87292 .61477 L
s
.87292 .61477 m
.87292 .61477 L
s
.87292 .61477 m
.87292 .61477 L
s
.87292 .61477 m
.87292 .61477 L
s
.87292 .61477 m
.87292 .61477 L
s
.87292 .61477 m
.87292 .61477 L
s
.87292 .61477 m
.87292 .61477 L
s
.87292 .61477 m
.87292 .61477 L
s
1 .825 0 r
.44612 .44166 m
.44862 .44304 L
s
.44612 .44166 m
.44054 .44309 L
s
1 .043 0 r
.59419 .69831 m
.59413 .69839 L
s
.59412 .69798 m
.59419 .69831 L
s
.59445 .69813 m
.59419 .69831 L
s
.59406 .69807 m
.59412 .69798 L
s
.59412 .69798 m
.59445 .69813 L
s
1 .293 0 r
.34325 .39258 m
.34174 .39154 L
s
.34174 .39154 m
.3426 .38986 L
s
1 .043 0 r
.59445 .69813 m
.59413 .69839 L
s
.59406 .69807 m
.59445 .69813 L
s
1 .021 0 r
.20544 .44703 m
.20554 .44711 L
s
.20532 .44714 m
.20544 .44703 L
s
.20544 .44703 m
.20538 .44702 L
s
1 .043 0 r
.59413 .69839 m
.59406 .69807 L
s
1 .607 0 r
.63842 .41926 m
.64179 .42258 L
s
1 .021 0 r
.20542 .44722 m
.20532 .44714 L
s
.20532 .44714 m
.20538 .44702 L
s
.20554 .44711 m
.20542 .44722 L
s
.20538 .44702 m
.20554 .44711 L
s
1 .047 0 r
.58824 .53082 m
.58836 .53074 L
s
.58836 .53074 m
.58823 .53038 L
s
.58836 .53074 m
.58791 .5307 L
s
1 .021 0 r
.20538 .44702 m
.20542 .44722 L
s
1 .047 0 r
.58823 .53038 m
.58812 .53046 L
s
.58823 .53038 m
.58791 .5307 L
s
.58791 .5307 m
.58824 .53082 L
s
.58791 .5307 m
.58812 .53046 L
s
.58957 .53019 m
.58791 .5307 L
s
1 .344 0 r
.51761 .50312 m
.51769 .50269 L
s
.51769 .50269 m
.51762 .49996 L
s
.51769 .50269 m
.51488 .50159 L
s
1 .016 0 r
.86961 .4469 m
.86966 .44689 L
s
.86965 .44675 m
.86961 .4469 L
s
.86961 .4469 m
.86957 .44681 L
s
.86974 .44683 m
.86961 .4469 L
s
.86981 .44651 m
.86961 .4469 L
s
.86965 .44675 m
.86957 .44681 L
s
.86974 .44683 m
.86965 .44675 L
s
.86966 .44689 m
.86974 .44683 L
s
1 .047 0 r
.58812 .53046 m
.58824 .53082 L
s
1 .016 0 r
.86957 .44681 m
.86966 .44689 L
s
1 .293 0 r
.34491 .39102 m
.34325 .39258 L
s
.3426 .38986 m
.34491 .39102 L
s
1 .053 0 r
.8084 .41889 m
.80854 .41887 L
s
.8085 .4184 m
.8084 .41889 L
s
.8084 .41889 m
.80823 .4186 L
s
.80881 .41867 m
.8084 .41889 L
s
.80898 .41761 m
.8084 .41889 L
s
.8085 .4184 m
.80823 .4186 L
s
.80881 .41867 m
.8085 .4184 L
s
1 .032 0 r
.53289 .66972 m
.53289 .66978 L
s
.53289 .66947 m
.53289 .66972 L
s
.53314 .66962 m
.53289 .66972 L
s
1 .344 0 r
.51762 .49996 m
.51755 .50038 L
s
.51762 .49996 m
.51488 .50159 L
s
1 .032 0 r
.53288 .66953 m
.53289 .66947 L
s
.53289 .66947 m
.53314 .66962 L
s
1 .053 0 r
.80854 .41887 m
.80881 .41867 L
s
1 0 0 r
.30933 .61387 m
.30933 .61387 L
s
.30933 .61386 m
.30933 .61387 L
s
.30933 .61387 m
.30933 .61387 L
s
.30933 .61387 m
.30933 .61387 L
s
.30932 .61386 m
.30933 .61387 L
s
.30933 .61386 m
.30933 .61387 L
s
.30933 .61387 m
.30933 .61386 L
s
.30933 .61387 m
.30933 .61387 L
s
.30933 .61387 m
.30933 .61387 L
s
1 .021 0 r
.75442 .72542 m
.75506 .72513 L
s
1 0 0 r
.81212 .58597 m
.81212 .58597 L
s
1 .032 0 r
.53187 .66964 m
.53314 .66962 L
s
1 .1 0 r
.36702 .47441 m
.36494 .47232 L
s
1 .053 0 r
.80823 .4186 m
.80854 .41887 L
s
1 .032 0 r
.53314 .66962 m
.53289 .66978 L
s
.53288 .66953 m
.53314 .66962 L
s
.53289 .66978 m
.53288 .66953 L
s
0 1 .331 r
.43536 .42111 m
.43227 .4185 L
s
.43227 .4185 m
.43595 .40022 L
s
.43227 .4185 m
.41761 .40733 L
s
1 .077 0 r
.41525 .78106 m
.41539 .78124 L
s
.41541 .78048 m
.41525 .78106 L
s
.41597 .78098 m
.41525 .78106 L
s
1 .111 0 r
.42543 .50134 m
.42583 .50158 L
s
.425 .50212 m
.42543 .50134 L
s
.42543 .50134 m
.42475 .50149 L
s
.4254 .50236 m
.425 .50212 L
s
.425 .50212 m
.42475 .50149 L
s
1 .293 0 r
.3426 .38986 m
.34325 .39258 L
s
1 .077 0 r
.41556 .78066 m
.41541 .78048 L
s
.41541 .78048 m
.41597 .78098 L
s
1 .021 0 r
.75492 .72508 m
.75501 .72523 L
s
.75485 .72514 m
.75492 .72508 L
s
.75492 .72508 m
.75506 .72513 L
s
.75501 .72523 m
.75494 .72529 L
s
.75506 .72513 m
.75501 .72523 L
s
1 .077 0 r
.41597 .78098 m
.41539 .78124 L
s
.41556 .78066 m
.41597 .78098 L
s
.41311 .78039 m
.41597 .78098 L
s
1 .021 0 r
.75494 .72529 m
.75485 .72514 L
s
.75485 .72514 m
.75506 .72513 L
s
.75506 .72513 m
.75494 .72529 L
s
0 .434 1 r
.61905 .46816 m
.6367 .44617 L
s
1 .525 0 r
.39859 .41433 m
.40106 .4158 L
s
.39593 .41756 m
.39859 .41433 L
s
.39859 .41433 m
.39634 .4144 L
s
1 .077 0 r
.41539 .78124 m
.41556 .78066 L
s
1 .344 0 r
.51488 .50159 m
.51761 .50312 L
s
.51488 .50159 m
.51755 .50038 L
s
.52857 .50133 m
.51488 .50159 L
s
1 .111 0 r
.42583 .50158 m
.4254 .50236 L
s
.42475 .50149 m
.42583 .50158 L
s
.42475 .50149 m
.4254 .50236 L
s
.808 1 0 r
.62035 .38983 m
.62731 .39499 L
s
1 .013 0 r
.47121 .64096 m
.47123 .64098 L
s
.47123 .64086 m
.47121 .64096 L
s
.47133 .64094 m
.47121 .64096 L
s
.47125 .64088 m
.47123 .64086 L
s
.47123 .64086 m
.47133 .64094 L
s
.47133 .64094 m
.47123 .64098 L
s
.47125 .64088 m
.47133 .64094 L
s
.47084 .64086 m
.47133 .64094 L
s
.47123 .64098 m
.47125 .64088 L
s
1 0 0 r
.75124 .55715 m
.75124 .55715 L
s
.75124 .55714 m
.75124 .55715 L
s
.75124 .55715 m
.75124 .55715 L
s
.75124 .55715 m
.75124 .55715 L
s
.75125 .55714 m
.75124 .55715 L
s
.75124 .55714 m
.75124 .55715 L
s
.75124 .55715 m
.75124 .55714 L
s
.75124 .55715 m
.75124 .55715 L
s
.75124 .55715 m
.75124 .55715 L
s
1 .022 0 r
.69352 .69667 m
.69425 .69639 L
s
1 .075 0 r
.3059 .44551 m
.30481 .44379 L
s
1 0 0 r
.24817 .58505 m
.24817 .58505 L
s
1 .525 0 r
.3984 .41903 m
.39593 .41756 L
s
.39593 .41756 m
.39634 .4144 L
s
1 .111 0 r
.62618 .50128 m
.62682 .50141 L
s
.62679 .50039 m
.62618 .50128 L
s
.62618 .50128 m
.62636 .50065 L
s
.62725 .50115 m
.62618 .50128 L
s
.62931 .49938 m
.62618 .50128 L
s
.808 1 0 r
.62731 .39499 m
.63392 .38956 L
s
1 .111 0 r
.62679 .50039 m
.62636 .50065 L
s
.62725 .50115 m
.62679 .50039 L
s
.62682 .50141 m
.62725 .50115 L
s
1 .022 0 r
.69418 .6965 m
.69411 .69655 L
s
.6941 .69633 m
.69418 .6965 L
s
.69425 .69639 m
.69418 .6965 L
s
.69403 .69639 m
.6941 .69633 L
s
.6941 .69633 m
.69425 .69639 L
s
.69411 .69655 m
.69403 .69639 L
s
.69425 .69639 m
.69411 .69655 L
s
.69403 .69639 m
.69425 .69639 L
s
.285 1 0 r
.56687 .47307 m
.57108 .47304 L
s
.57085 .4574 m
.56687 .47307 L
s
.56687 .47307 m
.56161 .46352 L
s
.5803 .46688 m
.56687 .47307 L
s
.58771 .433 m
.56687 .47307 L
s
1 .045 0 r
.35308 .75218 m
.3532 .75229 L
s
.35323 .75185 m
.35308 .75218 L
s
.35352 .75217 m
.35308 .75218 L
s
.35352 .75217 m
.3532 .75229 L
s
.35323 .75185 m
.35352 .75217 L
s
.35335 .75196 m
.35352 .75217 L
s
.35199 .75165 m
.35352 .75217 L
s
.35335 .75196 m
.35323 .75185 L
s
1 .1 0 r
.36538 .47228 m
.36584 .47257 L
s
.36487 .4729 m
.36538 .47228 L
s
.36538 .47228 m
.36494 .47232 L
s
.36534 .47319 m
.36487 .4729 L
s
.36487 .4729 m
.36494 .47232 L
s
1 .045 0 r
.3532 .75229 m
.35335 .75196 L
s
1 .344 0 r
.51755 .50038 m
.51761 .50312 L
s
1 .111 0 r
.62636 .50065 m
.62682 .50141 L
s
1 .01 0 r
.69006 .52847 m
.69011 .52848 L
s
.69011 .52838 m
.69006 .52847 L
s
.69006 .52847 m
.69006 .52841 L
s
.69015 .52845 m
.69006 .52847 L
s
.69031 .52827 m
.69006 .52847 L
s
.69011 .52838 m
.69006 .52841 L
s
.69015 .52845 m
.69011 .52838 L
s
.69011 .52848 m
.69015 .52845 L
s
1 .1 0 r
.36584 .47257 m
.36534 .47319 L
s
.36494 .47232 m
.36584 .47257 L
s
1 .01 0 r
.69006 .52841 m
.69011 .52848 L
s
0 1 .331 r
.43595 .40022 m
.43907 .40268 L
s
.43595 .40022 m
.41761 .40733 L
s
1 .1 0 r
.36494 .47232 m
.36534 .47319 L
s
1 .001 0 r
.40978 .61206 m
.40979 .61206 L
s
.40979 .61205 m
.40978 .61206 L
s
.4098 .61206 m
.40978 .61206 L
s
.4098 .61206 m
.40979 .61206 L
s
.40979 .61205 m
.4098 .61206 L
s
.40979 .61205 m
.4098 .61206 L
s
.40975 .61204 m
.4098 .61206 L
s
.40979 .61205 m
.40979 .61205 L
s
.40979 .61206 m
.40979 .61205 L
s
1 0 0 r
.91311 .58412 m
.91311 .58412 L
s
1 .021 0 r
.63255 .66789 m
.6333 .66767 L
s
1 .59 0 r
.46751 .47243 m
.4479 .46432 L
s
1 .055 0 r
.24471 .41659 m
.24412 .41524 L
s
1 .021 0 r
.63321 .66777 m
.63316 .66782 L
s
.63315 .66761 m
.63321 .66777 L
s
.6333 .66767 m
.63321 .66777 L
s
.6331 .66766 m
.63315 .66761 L
s
.63315 .66761 m
.6333 .66767 L
s
1 .075 0 r
.30506 .44379 m
.30543 .44406 L
s
.30464 .44421 m
.30506 .44379 L
s
.30506 .44379 m
.30481 .44379 L
s
1 .021 0 r
.6333 .66767 m
.63316 .66782 L
s
.6331 .66766 m
.6333 .66767 L
s
.63316 .66782 m
.6331 .66766 L
s
0 1 .511 r
.41129 .38839 m
.4303 .40313 L
s
.41129 .38839 m
.43428 .38336 L
s
1 .075 0 r
.30501 .44447 m
.30464 .44421 L
s
.30464 .44421 m
.30481 .44379 L
s
.30543 .44406 m
.30501 .44447 L
s
.30481 .44379 m
.30543 .44406 L
s
1 .104 0 r
.51701 .77912 m
.51703 .77935 L
s
.51703 .77831 m
.51701 .77912 L
s
.51786 .77885 m
.51701 .77912 L
s
1 .018 0 r
.90984 .41602 m
.90989 .41601 L
s
.90987 .41584 m
.90984 .41602 L
s
.90984 .41602 m
.90977 .41592 L
s
.90998 .41593 m
.90984 .41602 L
s
.91003 .41556 m
.90984 .41602 L
s
1 .075 0 r
.30481 .44379 m
.30501 .44447 L
s
1 .018 0 r
.90987 .41584 m
.90977 .41592 L
s
.90998 .41593 m
.90987 .41584 L
s
.90989 .41601 m
.90998 .41593 L
s
1 .021 0 r
.29142 .72319 m
.29129 .72323 L
s
.2913 .72303 m
.29142 .72319 L
s
.29142 .72319 m
.29122 .72317 L
s
.29138 .72309 m
.29142 .72319 L
s
.29079 .72288 m
.29142 .72319 L
s
1 .104 0 r
.51706 .77854 m
.51703 .77831 L
s
.51703 .77831 m
.51786 .77885 L
s
1 .018 0 r
.90977 .41592 m
.90989 .41601 L
s
1 .021 0 r
.2913 .72303 m
.29122 .72317 L
s
.29138 .72309 m
.2913 .72303 L
s
.29122 .72317 m
.29129 .72323 L
s
.29129 .72323 m
.29138 .72309 L
s
1 .051 0 r
.8487 .38787 m
.8488 .38784 L
s
.84876 .38739 m
.8487 .38787 L
s
.8487 .38787 m
.84849 .3876 L
s
.84907 .38763 m
.8487 .38787 L
s
.84911 .38659 m
.8487 .38787 L
s
1 .525 0 r
.40106 .4158 m
.3984 .41903 L
s
.39634 .4144 m
.40106 .4158 L
s
0 .813 1 r
.61328 .44909 m
.59745 .46879 L
s
.63001 .45833 m
.61328 .44909 L
s
1 .051 0 r
.84876 .38739 m
.84849 .3876 L
s
.84907 .38763 m
.84876 .38739 L
s
1 .104 0 r
.51786 .77885 m
.51703 .77935 L
s
.51706 .77854 m
.51786 .77885 L
s
.51372 .77876 m
.51786 .77885 L
s
1 .055 0 r
.24426 .41526 m
.24455 .41548 L
s
.24394 .41554 m
.24426 .41526 L
s
.24426 .41526 m
.24412 .41524 L
s
1 .417 0 r
.68558 .38766 m
.68616 .38743 L
s
.68597 .38372 m
.68558 .38766 L
s
.68558 .38766 m
.68371 .38544 L
s
.68842 .38571 m
.68558 .38766 L
s
.68802 .3772 m
.68558 .38766 L
s
1 .141 0 r
.66631 .47145 m
.66691 .47149 L
s
.66686 .47021 m
.66631 .47145 L
s
.66631 .47145 m
.66619 .47063 L
s
.66758 .47108 m
.66631 .47145 L
s
.66918 .46847 m
.66631 .47145 L
s
1 .051 0 r
.8488 .38784 m
.84907 .38763 L
s
1 0 0 r
.85223 .55526 m
.85223 .55526 L
s
.85223 .55526 m
.85223 .55526 L
s
.85223 .55526 m
.85223 .55526 L
s
.85223 .55526 m
.85223 .55526 L
s
.85223 .55525 m
.85223 .55526 L
s
.85223 .55526 m
.85223 .55526 L
s
.85223 .55526 m
.85223 .55526 L
s
.85223 .55526 m
.85223 .55526 L
s
.85223 .55526 m
.85223 .55526 L
s
1 .01 0 r
.79444 .69495 m
.7947 .69479 L
s
1 .014 0 r
.57151 .63907 m
.57206 .63899 L
s
1 0 0 r
.34859 .58319 m
.34859 .58319 L
s
1 .39 0 r
.40638 .4435 m
.3984 .43515 L
s
1 .043 0 r
.18346 .38763 m
.18311 .38656 L
s
1 .055 0 r
.24422 .41576 m
.24394 .41554 L
s
.24394 .41554 m
.24412 .41524 L
s
1 .014 0 r
.57197 .63905 m
.57195 .63908 L
s
.57195 .63894 m
.57197 .63905 L
s
.57206 .63899 m
.57197 .63905 L
s
1 .051 0 r
.84849 .3876 m
.8488 .38784 L
s
1 .014 0 r
.57193 .63897 m
.57195 .63894 L
s
.57195 .63894 m
.57206 .63899 L
s
.57206 .63899 m
.57195 .63908 L
s
.57193 .63897 m
.57206 .63899 L
s
1 .055 0 r
.24455 .41548 m
.24422 .41576 L
s
.24412 .41524 m
.24455 .41548 L
s
1 .014 0 r
.57195 .63908 m
.57193 .63897 L
s
1 .01 0 r
.79464 .69477 m
.79469 .69484 L
s
.79461 .6948 m
.79464 .69477 L
s
.79464 .69477 m
.7947 .69479 L
s
.79469 .69484 m
.79465 .69487 L
s
.7947 .69479 m
.79469 .69484 L
s
.79465 .69487 m
.79461 .6948 L
s
.79461 .6948 m
.7947 .69479 L
s
.7947 .69479 m
.79465 .69487 L
s
1 .104 0 r
.51703 .77935 m
.51706 .77854 L
s
1 .055 0 r
.24412 .41524 m
.24422 .41576 L
s
1 .825 0 r
.44862 .44304 m
.44593 .44911 L
s
.44054 .44309 m
.44593 .44911 L
s
1 .525 0 r
.39634 .4144 m
.3984 .41903 L
s
1 .141 0 r
.66686 .47021 m
.66619 .47063 L
s
.66758 .47108 m
.66686 .47021 L
s
1 .081 0 r
.45495 .75058 m
.45506 .75076 L
s
.45508 .74996 m
.45495 .75058 L
s
.45569 .75045 m
.45495 .75058 L
s
.45519 .75014 m
.45508 .74996 L
s
.45508 .74996 m
.45569 .75045 L
s
1 .141 0 r
.66691 .47149 m
.66758 .47108 L
s
1 .825 0 r
.44054 .44309 m
.44862 .44304 L
s
1 .081 0 r
.45569 .75045 m
.45506 .75076 L
s
.45519 .75014 m
.45569 .75045 L
s
.45258 .74999 m
.45569 .75045 L
s
1 .043 0 r
.1832 .38659 m
.18342 .38676 L
s
.18294 .38679 m
.1832 .38659 L
s
.1832 .38659 m
.18311 .38656 L
s
1 .081 0 r
.45506 .75076 m
.45519 .75014 L
s
1 .043 0 r
.18316 .38697 m
.18294 .38679 L
s
.18294 .38679 m
.18311 .38656 L
s
1 .141 0 r
.66619 .47063 m
.66691 .47149 L
s
1 .043 0 r
.18342 .38676 m
.18316 .38697 L
s
.18311 .38656 m
.18342 .38676 L
s
1 .417 0 r
.68597 .38372 m
.68371 .38544 L
s
.68842 .38571 m
.68597 .38372 L
s
1 .043 0 r
.18311 .38656 m
.18316 .38697 L
s
1 .003 0 r
.79124 .52641 m
.79125 .52641 L
s
.79124 .52639 m
.79124 .52641 L
s
.79124 .52641 m
.79123 .5264 L
s
.79126 .5264 m
.79124 .52641 L
s
.79128 .52636 m
.79124 .52641 L
s
.79124 .52639 m
.79123 .5264 L
s
.79126 .5264 m
.79124 .52639 L
s
.79125 .52641 m
.79126 .5264 L
s
.79123 .5264 m
.79125 .52641 L
s
.51051 .61023 m
.51051 .61024 L
s
.51051 .61021 m
.51051 .61023 L
s
.51053 .61023 m
.51051 .61023 L
s
.51051 .61021 m
.51051 .61021 L
s
.51051 .61021 m
.51053 .61023 L
s
.51053 .61023 m
.51051 .61024 L
s
.51051 .61021 m
.51053 .61023 L
s
.51041 .61022 m
.51053 .61023 L
s
1 .009 0 r
.73346 .66613 m
.73371 .66599 L
s
1 .22 0 r
.34518 .41454 m
.34247 .40927 L
s
1 0 0 r
.28736 .55431 m
.28735 .5543 L
s
1 .003 0 r
.51051 .61024 m
.51051 .61021 L
s
1 0 0 r
.28735 .5543 m
.28735 .5543 L
s
.28735 .55431 m
.28735 .5543 L
s
.28735 .5543 m
.28735 .5543 L
s
.28735 .55431 m
.28735 .55431 L
s
.28735 .55431 m
.28735 .5543 L
s
.28735 .5543 m
.28735 .55431 L
s
.28735 .5543 m
.28735 .5543 L
s
.28735 .5543 m
.28735 .55431 L
s
1 .009 0 r
.73366 .66598 m
.73369 .66604 L
s
.73363 .666 m
.73366 .66598 L
s
.73366 .66598 m
.73371 .66599 L
s
.73369 .66604 m
.73366 .66606 L
s
.73371 .66599 m
.73369 .66604 L
s
.73366 .66606 m
.73363 .666 L
s
.73363 .666 m
.73371 .66599 L
s
.73371 .66599 m
.73366 .66606 L
s
1 .047 0 r
.39256 .72169 m
.39268 .7218 L
s
.3927 .72135 m
.39256 .72169 L
s
.39302 .72167 m
.39256 .72169 L
s
.39281 .72146 m
.3927 .72135 L
s
.3927 .72135 m
.39302 .72167 L
s
.39302 .72167 m
.39268 .7218 L
s
.39281 .72146 m
.39302 .72167 L
s
.39137 .72118 m
.39302 .72167 L
s
1 .021 0 r
.72986 .49788 m
.72995 .49789 L
s
.72994 .49769 m
.72986 .49788 L
s
.72986 .49788 m
.72984 .49776 L
s
.73005 .49782 m
.72986 .49788 L
s
.73027 .49743 m
.72986 .49788 L
s
.72994 .49769 m
.72984 .49776 L
s
.73005 .49782 m
.72994 .49769 L
s
.72995 .49789 m
.73005 .49782 L
s
1 .047 0 r
.39268 .7218 m
.39281 .72146 L
s
1 .021 0 r
.72984 .49776 m
.72995 .49789 L
s
1 .417 0 r
.68616 .38743 m
.68842 .38571 L
s
.285 1 0 r
.57085 .4574 m
.56161 .46352 L
s
.5803 .46688 m
.57085 .4574 L
s
1 0 0 r
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
1 .091 0 r
.61455 .77712 m
.61801 .77654 L
s
1 .006 0 r
.67241 .63728 m
.67261 .63719 L
s
1 0 0 r
.44923 .58134 m
.44923 .58134 L
s
0 1 .077 r
.50709 .44149 m
.4269 .42698 L
s
1 .002 0 r
.22606 .5254 m
.22602 .52536 L
s
1 .134 0 r
.28392 .38555 m
.28286 .38221 L
s
1 .002 0 r
.22603 .52536 m
.22604 .52537 L
s
.22602 .52537 m
.22603 .52536 L
s
.22603 .52536 m
.22602 .52536 L
s
.22603 .52538 m
.22602 .52537 L
s
.22602 .52537 m
.22602 .52536 L
s
.22604 .52537 m
.22603 .52538 L
s
.22602 .52536 m
.22604 .52537 L
s
.22602 .52536 m
.22603 .52538 L
s
1 .006 0 r
.67259 .63722 m
.67257 .63724 L
s
.67256 .63718 m
.67259 .63722 L
s
.67261 .63719 m
.67259 .63722 L
s
.67254 .63719 m
.67256 .63718 L
s
.67256 .63718 m
.67261 .63719 L
s
.67257 .63724 m
.67254 .63719 L
s
.67261 .63719 m
.67257 .63724 L
s
.67254 .63719 m
.67261 .63719 L
s
1 .417 0 r
.68371 .38544 m
.68616 .38743 L
s
0 1 .511 r
.43428 .38336 m
.4303 .40313 L
s
1 .091 0 r
.61747 .7769 m
.61733 .77711 L
s
.6173 .7762 m
.61747 .7769 L
s
.61801 .77654 m
.61747 .7769 L
s
1 .59 0 r
.59445 .46913 m
.5973 .4695 L
s
.59718 .46412 m
.59445 .46913 L
s
.59445 .46913 m
.59453 .46565 L
s
.59995 .46797 m
.59445 .46913 L
s
.6085 .45747 m
.59445 .46913 L
s
1 .091 0 r
.61716 .77641 m
.6173 .7762 L
s
.6173 .7762 m
.61801 .77654 L
s
0 .813 1 r
.59745 .46879 m
.61409 .47819 L
s
1 .019 0 r
.33069 .69262 m
.33057 .69266 L
s
.33058 .69247 m
.33069 .69262 L
s
.33069 .69262 m
.3305 .69261 L
s
.33064 .69253 m
.33069 .69262 L
s
.33009 .69235 m
.33069 .69262 L
s
.33058 .69247 m
.3305 .69261 L
s
.33064 .69253 m
.33058 .69247 L
s
.3305 .69261 m
.33057 .69266 L
s
1 .091 0 r
.61801 .77654 m
.61733 .77711 L
s
.61716 .77641 m
.61801 .77654 L
s
1 .019 0 r
.33057 .69266 m
.33064 .69253 L
s
1 .091 0 r
.61733 .77711 m
.61716 .77641 L
s
1 .137 0 r
.7073 .44066 m
.70771 .44064 L
s
.70764 .4394 m
.7073 .44066 L
s
.7073 .44066 m
.70694 .43988 L
s
.70841 .44015 m
.7073 .44066 L
s
.70919 .43745 m
.7073 .44066 L
s
1 .095 0 r
.55648 .74841 m
.55643 .74861 L
s
.55642 .74767 m
.55648 .74841 L
s
.55718 .7481 m
.55648 .74841 L
s
.55637 .74787 m
.55642 .74767 L
s
.55642 .74767 m
.55718 .7481 L
s
1 .001 0 r
.89247 .52445 m
.89247 .52446 L
s
.89247 .52445 m
.89247 .52445 L
s
.89247 .52445 m
.89247 .52445 L
s
.89248 .52445 m
.89247 .52445 L
s
.89248 .52444 m
.89247 .52445 L
s
.89247 .52445 m
.89247 .52445 L
s
.89248 .52445 m
.89247 .52445 L
s
.89247 .52446 m
.89248 .52445 L
s
.89247 .52445 m
.89247 .52446 L
s
1 .003 0 r
.83459 .66436 m
.83467 .6643 L
s
1 .095 0 r
.5534 .74832 m
.55718 .7481 L
s
1 .002 0 r
.61129 .60839 m
.61136 .60837 L
s
.38799 .55242 m
.38793 .55239 L
s
.717 1 0 r
.44588 .41249 m
.41988 .38417 L
s
1 .002 0 r
.61135 .60838 m
.61135 .60838 L
s
.61135 .60836 m
.61135 .60838 L
s
.61136 .60837 m
.61135 .60838 L
s
.61134 .60837 m
.61135 .60836 L
s
.61135 .60836 m
.61136 .60837 L
s
.38794 .55239 m
.38795 .55239 L
s
.38794 .5524 m
.38794 .55239 L
s
.38794 .55239 m
.38793 .55239 L
s
.38794 .55241 m
.38794 .5524 L
s
.38794 .5524 m
.38793 .55239 L
s
.61136 .60837 m
.61135 .60838 L
s
.61134 .60837 m
.61136 .60837 L
s
.61135 .60838 m
.61134 .60837 L
s
.38795 .55239 m
.38794 .55241 L
s
.38793 .55239 m
.38795 .55239 L
s
.38793 .55239 m
.38794 .55241 L
s
1 .003 0 r
.83465 .6643 m
.83467 .66432 L
s
.83464 .66431 m
.83465 .6643 L
s
.83465 .6643 m
.83467 .6643 L
s
.83467 .66432 m
.83466 .66433 L
s
.83467 .6643 m
.83467 .66432 L
s
.83466 .66433 m
.83464 .66431 L
s
.83464 .66431 m
.83467 .6643 L
s
.83467 .6643 m
.83466 .66433 L
s
1 .137 0 r
.70764 .4394 m
.70694 .43988 L
s
.70841 .44015 m
.70764 .4394 L
s
1 .59 0 r
.59718 .46412 m
.59453 .46565 L
s
.59995 .46797 m
.59718 .46412 L
s
1 .095 0 r
.55718 .7481 m
.55643 .74861 L
s
.55637 .74787 m
.55718 .7481 L
s
1 .137 0 r
.70771 .44064 m
.70841 .44015 L
s
1 .095 0 r
.55643 .74861 m
.55637 .74787 L
s
1 .59 0 r
.5973 .4695 m
.59995 .46797 L
s
1 .08 0 r
.49464 .71991 m
.49469 .72007 L
s
.4947 .71928 m
.49464 .71991 L
s
.49533 .71972 m
.49464 .71991 L
s
.49476 .71944 m
.4947 .71928 L
s
.4947 .71928 m
.49533 .71972 L
s
1 .137 0 r
.70694 .43988 m
.70771 .44064 L
s
0 1 .566 r
.47432 .50006 m
.4817 .49583 L
s
.4817 .49583 m
.4747 .4764 L
s
.4817 .49583 m
.45665 .49399 L
s
1 .08 0 r
.49533 .71972 m
.49469 .72007 L
s
.49476 .71944 m
.49533 .71972 L
s
.49218 .71948 m
.49533 .71972 L
s
0 .813 1 r
.44855 .46612 m
.45728 .49026 L
s
1 .59 0 r
.45178 .46864 m
.44998 .4676 L
s
.44998 .4676 m
.4519 .46326 L
s
.44998 .4676 m
.4479 .46432 L
s
1 .006 0 r
.83137 .4956 m
.83139 .4956 L
s
.83138 .49555 m
.83137 .4956 L
s
.83137 .4956 m
.83136 .49557 L
s
.83141 .49558 m
.83137 .4956 L
s
.83145 .49547 m
.83137 .4956 L
s
.83138 .49555 m
.83136 .49557 L
s
.83141 .49558 m
.83138 .49555 L
s
.83139 .4956 m
.83141 .49558 L
s
.2689 .66358 m
.26887 .66358 L
s
.26887 .66353 m
.2689 .66358 L
s
.2689 .66358 m
.26884 .66357 L
s
.26889 .66355 m
.2689 .66358 L
s
.26875 .66348 m
.2689 .66358 L
s
.26887 .66353 m
.26884 .66357 L
s
.26889 .66355 m
.26887 .66353 L
s
.26884 .66357 m
.26887 .66358 L
s
.83136 .49557 m
.83139 .4956 L
s
.26887 .66358 m
.26889 .66355 L
s
1 .08 0 r
.49469 .72007 m
.49476 .71944 L
s
1 .055 0 r
.7156 .77548 m
.71745 .77484 L
s
1 .002 0 r
.77353 .63548 m
.77358 .63544 L
s
1 0 0 r
.5501 .57948 m
.5501 .57948 L
s
1 .007 0 r
.32667 .52347 m
.32653 .52334 L
s
1 .575 0 r
.3846 .38347 m
.37948 .36911 L
s
1 .002 0 r
.77357 .63544 m
.77358 .63545 L
s
.77356 .63544 m
.77357 .63544 L
s
.77357 .63544 m
.77358 .63544 L
s
.77358 .63545 m
.77357 .63546 L
s
.77358 .63544 m
.77358 .63545 L
s
.77357 .63546 m
.77356 .63544 L
s
.77356 .63544 m
.77358 .63544 L
s
.77358 .63544 m
.77357 .63546 L
s
1 .59 0 r
.4519 .46326 m
.45371 .46428 L
s
.4519 .46326 m
.4479 .46432 L
s
1 .007 0 r
.32656 .52333 m
.32659 .52335 L
s
.32653 .52337 m
.32656 .52333 L
s
.32656 .52333 m
.32653 .52334 L
s
.32656 .5234 m
.32653 .52337 L
s
.32653 .52337 m
.32653 .52334 L
s
.32659 .52335 m
.32656 .5234 L
s
.32653 .52334 m
.32659 .52335 L
s
.32653 .52334 m
.32656 .5234 L
s
1 .134 0 r
.28312 .38228 m
.28382 .38282 L
s
.28232 .38293 m
.28312 .38228 L
s
.28312 .38228 m
.28286 .38221 L
s
1 .029 0 r
.76993 .46715 m
.77003 .46715 L
s
.77001 .46688 m
.76993 .46715 L
s
.76993 .46715 m
.76986 .46699 L
s
.77017 .46704 m
.76993 .46715 L
s
.77036 .46648 m
.76993 .46715 L
s
.77001 .46688 m
.76986 .46699 L
s
.77017 .46704 m
.77001 .46688 L
s
.77003 .46715 m
.77017 .46704 L
s
1 .055 0 r
.71725 .77509 m
.7171 .77524 L
s
.71707 .77469 m
.71725 .77509 L
s
.71745 .77484 m
.71725 .77509 L
s
1 .029 0 r
.76986 .46699 m
.77003 .46715 L
s
1 .046 0 r
.43213 .69106 m
.43223 .69115 L
s
.43224 .69071 m
.43213 .69106 L
s
.43257 .69101 m
.43213 .69106 L
s
1 .055 0 r
.71691 .77484 m
.71707 .77469 L
s
.71707 .77469 m
.71745 .77484 L
s
1 .134 0 r
.28302 .38347 m
.28232 .38293 L
s
.28232 .38293 m
.28286 .38221 L
s
1 .046 0 r
.43233 .69081 m
.43224 .69071 L
s
.43224 .69071 m
.43257 .69101 L
s
.43257 .69101 m
.43223 .69115 L
s
.43233 .69081 m
.43257 .69101 L
s
.43089 .69061 m
.43257 .69101 L
s
1 .22 0 r
.34307 .40934 m
.34421 .41013 L
s
.34182 .41052 m
.34307 .40934 L
s
.34307 .40934 m
.34247 .40927 L
s
.285 1 0 r
.57108 .47304 m
.5803 .46688 L
s
1 .134 0 r
.28382 .38282 m
.28302 .38347 L
s
.28286 .38221 m
.28382 .38282 L
s
1 .046 0 r
.43223 .69115 m
.43233 .69081 L
s
1 .055 0 r
.7171 .77524 m
.71691 .77484 L
s
.71745 .77484 m
.7171 .77524 L
s
.71691 .77484 m
.71745 .77484 L
s
1 .134 0 r
.28286 .38221 m
.28302 .38347 L
s
1 .22 0 r
.34296 .41131 m
.34182 .41052 L
s
.34182 .41052 m
.34247 .40927 L
s
0 1 .566 r
.4747 .4764 m
.46726 .48048 L
s
.4747 .4764 m
.45665 .49399 L
s
1 .066 0 r
.65444 .74665 m
.65683 .74601 L
s
1 .001 0 r
.7124 .60656 m
.71242 .60655 L
s
1 .008 0 r
.48884 .55053 m
.48853 .55047 L
s
1 .01 0 r
.26529 .49449 m
.26513 .49427 L
s
1 .001 0 r
.71241 .60655 m
.71242 .60655 L
s
.71241 .60655 m
.71241 .60655 L
s
.71241 .60655 m
.71242 .60655 L
s
.71242 .60655 m
.71241 .60656 L
s
.71242 .60655 m
.71242 .60655 L
s
.71241 .60656 m
.71241 .60655 L
s
.71241 .60655 m
.71242 .60655 L
s
.71242 .60655 m
.71241 .60656 L
s
1 .008 0 r
.48859 .55052 m
.48858 .55051 L
s
.48858 .55051 m
.48859 .55045 L
s
.48858 .55051 m
.48853 .55047 L
s
.48859 .55045 m
.4886 .55046 L
s
.48859 .55045 m
.48853 .55047 L
s
.48853 .55047 m
.48859 .55052 L
s
.48853 .55047 m
.4886 .55046 L
s
.4886 .55046 m
.48859 .55052 L
s
1 .481 0 r
.55486 .49516 m
.55612 .49438 L
s
.55612 .49438 m
.55482 .49073 L
s
.55612 .49438 m
.55144 .49403 L
s
1 .01 0 r
.26516 .49427 m
.26521 .4943 L
s
.26511 .49432 m
.26516 .49427 L
s
.26516 .49427 m
.26513 .49427 L
s
.26516 .49436 m
.26511 .49432 L
s
.26511 .49432 m
.26513 .49427 L
s
.26521 .4943 m
.26516 .49436 L
s
.26513 .49427 m
.26521 .4943 L
s
.26513 .49427 m
.26516 .49436 L
s
1 .22 0 r
.34421 .41013 m
.34296 .41131 L
s
.34247 .40927 m
.34421 .41013 L
s
1 .481 0 r
.55482 .49073 m
.55355 .49151 L
s
.55482 .49073 m
.55144 .49403 L
s
1 .066 0 r
.65652 .7463 m
.65636 .74646 L
s
.65634 .74581 m
.65652 .7463 L
s
.65683 .74601 m
.65652 .7463 L
s
.65619 .74597 m
.65634 .74581 L
s
.65634 .74581 m
.65683 .74601 L
s
1 .481 0 r
.55144 .49403 m
.55486 .49516 L
s
.55144 .49403 m
.55355 .49151 L
s
.56848 .48859 m
.55144 .49403 L
s
0 1 .566 r
.45665 .49399 m
.47432 .50006 L
s
.45665 .49399 m
.46726 .48048 L
s
.54717 .46459 m
.45665 .49399 L
s
1 .39 0 r
.40007 .43507 m
.40192 .43618 L
s
.39809 .43748 m
.40007 .43507 L
s
.40007 .43507 m
.3984 .43515 L
s
1 .22 0 r
.34247 .40927 m
.34296 .41131 L
s
1 .016 0 r
.37004 .66193 m
.36993 .66196 L
s
.36994 .66181 m
.37004 .66193 L
s
.37004 .66193 m
.36988 .66192 L
s
.36999 .66185 m
.37004 .66193 L
s
.36953 .66171 m
.37004 .66193 L
s
.36988 .66192 m
.36993 .66196 L
s
.36994 .66181 m
.36988 .66192 L
s
.36999 .66185 m
.36994 .66181 L
s
1 .066 0 r
.65683 .74601 m
.65636 .74646 L
s
.65619 .74597 m
.65683 .74601 L
s
.65636 .74646 m
.65619 .74597 L
s
1 .59 0 r
.59453 .46565 m
.5973 .4695 L
s
1 .016 0 r
.36993 .66196 m
.36999 .66185 L
s
1 .002 0 r
.93284 .49356 m
.93285 .49356 L
s
.93285 .49354 m
.93284 .49356 L
s
.93284 .49356 m
.93284 .49355 L
s
.93286 .49355 m
.93284 .49356 L
s
.93287 .49351 m
.93284 .49356 L
s
.93285 .49354 m
.93284 .49355 L
s
.93286 .49355 m
.93285 .49354 L
s
.93285 .49356 m
.93286 .49355 L
s
.93284 .49355 m
.93285 .49356 L
s
1 .39 0 r
.39993 .43859 m
.39809 .43748 L
s
.39809 .43748 m
.3984 .43515 L
s
1 .001 0 r
.87488 .63368 m
.8749 .63366 L
s
1 .075 0 r
.59321 .71778 m
.59608 .71732 L
s
1 0 0 r
.6512 .57761 m
.6512 .57761 L
s
1 .039 0 r
.42752 .52155 m
.42636 .52093 L
s
0 .04 1 r
.48551 .38138 m
.40439 .2893 L
s
1 .011 0 r
.20384 .46548 m
.20369 .46521 L
s
1 .001 0 r
.87489 .63366 m
.8749 .63367 L
s
.87489 .63366 m
.87489 .63366 L
s
.87489 .63366 m
.8749 .63366 L
s
.8749 .63367 m
.87489 .63367 L
s
.8749 .63366 m
.8749 .63367 L
s
.87489 .63367 m
.87489 .63366 L
s
.87489 .63366 m
.8749 .63366 L
s
.8749 .63366 m
.87489 .63367 L
s
1 .121 0 r
.74826 .40931 m
.74851 .40926 L
s
.74843 .40817 m
.74826 .40931 L
s
.74826 .40931 m
.7478 .40865 L
s
.74915 .40877 m
.74826 .40931 L
s
.74934 .40632 m
.74826 .40931 L
s
1 .075 0 r
.59562 .71762 m
.59551 .71778 L
s
.5955 .71705 m
.59562 .71762 L
s
.59608 .71732 m
.59562 .71762 L
s
1 .011 0 r
.20373 .46521 m
.20378 .46526 L
s
.20366 .46528 m
.20373 .46521 L
s
.20373 .46521 m
.20369 .46521 L
s
.20372 .46532 m
.20366 .46528 L
s
.20366 .46528 m
.20369 .46521 L
s
.20378 .46526 m
.20372 .46532 L
s
.20369 .46521 m
.20378 .46526 L
s
1 .075 0 r
.59539 .7172 m
.5955 .71705 L
s
.5955 .71705 m
.59608 .71732 L
s
.973 1 0 r
.62771 .40917 m
.62787 .40867 L
s
.62757 .39946 m
.62771 .40917 L
s
.62771 .40917 m
.62184 .40418 L
s
.63361 .40394 m
.62771 .40917 L
s
.62779 .38334 m
.62771 .40917 L
s
1 .011 0 r
.20369 .46521 m
.20372 .46532 L
s
1 .121 0 r
.74843 .40817 m
.7478 .40865 L
s
.74915 .40877 m
.74843 .40817 L
s
1 .039 0 r
.4266 .52087 m
.42674 .52096 L
s
.42644 .52115 m
.4266 .52087 L
s
.4266 .52087 m
.42636 .52093 L
s
.42658 .52123 m
.42644 .52115 L
s
.42644 .52115 m
.42636 .52093 L
s
1 .457 0 r
.6427 .43702 m
.64396 .43695 L
s
.64381 .43281 m
.6427 .43702 L
s
.6427 .43702 m
.64141 .43442 L
s
.64636 .43533 m
.6427 .43702 L
s
.64865 .42624 m
.6427 .43702 L
s
1 .075 0 r
.59608 .71732 m
.59551 .71778 L
s
.59539 .7172 m
.59608 .71732 L
s
0 1 .077 r
.4428 .43934 m
.43998 .43688 L
s
.43998 .43688 m
.44329 .42052 L
s
.43998 .43688 m
.4269 .42698 L
s
1 .039 0 r
.42674 .52096 m
.42658 .52123 L
s
.42636 .52093 m
.42674 .52096 L
s
.42636 .52093 m
.42658 .52123 L
s
1 .075 0 r
.59551 .71778 m
.59539 .7172 L
s
1 .121 0 r
.74851 .40926 m
.74915 .40877 L
s
.7478 .40865 m
.74851 .40926 L
s
1 .009 0 r
.87165 .46469 m
.87168 .46469 L
s
.87167 .46461 m
.87165 .46469 L
s
.87165 .46469 m
.87163 .46464 L
s
.87172 .46465 m
.87165 .46469 L
s
.87176 .46448 m
.87165 .46469 L
s
1 .068 0 r
.53409 .68904 m
.53408 .68917 L
s
.53407 .6885 m
.53409 .68904 L
s
.53462 .68883 m
.53409 .68904 L
s
1 .009 0 r
.87167 .46461 m
.87163 .46464 L
s
.87172 .46465 m
.87167 .46461 L
s
.87168 .46469 m
.87172 .46465 L
s
.87163 .46464 m
.87168 .46469 L
s
1 .068 0 r
.53406 .68863 m
.53407 .6885 L
s
.53407 .6885 m
.53462 .68883 L
s
1 .007 0 r
.58974 .54872 m
.58976 .54871 L
s
.58976 .54871 m
.58974 .54866 L
s
.58976 .54871 m
.5897 .5487 L
s
.58974 .54866 m
.58973 .54867 L
s
.58974 .54866 m
.5897 .5487 L
s
.5897 .5487 m
.58974 .54872 L
s
.5897 .5487 m
.58973 .54867 L
s
.58993 .54863 m
.5897 .5487 L
s
1 .003 0 r
.30818 .63283 m
.30817 .63283 L
s
.30817 .6328 m
.30818 .63283 L
s
.30818 .63283 m
.30815 .63282 L
s
.30818 .63281 m
.30818 .63283 L
s
.3081 .63277 m
.30818 .63283 L
s
.30817 .6328 m
.30815 .63282 L
s
.30818 .63281 m
.30817 .6328 L
s
.30815 .63282 m
.30817 .63283 L
s
1 .007 0 r
.58973 .54867 m
.58974 .54872 L
s
1 .003 0 r
.30817 .63283 m
.30818 .63281 L
s
1 .034 0 r
.75571 .74497 m
.75676 .74449 L
s
1 0 0 r
.81374 .60473 m
.81374 .60472 L
s
1 .068 0 r
.53191 .68887 m
.53462 .68883 L
s
1 .048 0 r
.36612 .49253 m
.36511 .49153 L
s
1 0 0 r
.81374 .60472 m
.81374 .60472 L
s
.81374 .60472 m
.81374 .60472 L
s
.81374 .60472 m
.81374 .60472 L
s
.81374 .60472 m
.81374 .60472 L
s
.81374 .60472 m
.81374 .60472 L
s
.81374 .60472 m
.81374 .60472 L
s
.81374 .60472 m
.81374 .60472 L
s
.81374 .60472 m
.81374 .60472 L
s
1 .59 0 r
.45371 .46428 m
.45178 .46864 L
s
.4479 .46432 m
.45178 .46864 L
s
1 .068 0 r
.53462 .68883 m
.53408 .68917 L
s
.53406 .68863 m
.53462 .68883 L
s
1 .59 0 r
.4479 .46432 m
.45371 .46428 L
s
1 .033 0 r
.81022 .43623 m
.8103 .43622 L
s
.81028 .43591 m
.81022 .43623 L
s
.81022 .43623 m
.81011 .43604 L
s
.81048 .43609 m
.81022 .43623 L
s
.81058 .43542 m
.81022 .43623 L
s
1 .068 0 r
.53408 .68917 m
.53406 .68863 L
s
1 .39 0 r
.40192 .43618 m
.39993 .43859 L
s
.3984 .43515 m
.40192 .43618 L
s
1 .033 0 r
.81028 .43591 m
.81011 .43604 L
s
.81048 .43609 m
.81028 .43591 L
s
.8103 .43622 m
.81048 .43609 L
s
1 .034 0 r
.75654 .74442 m
.75667 .74466 L
s
.75642 .74452 m
.75654 .74442 L
s
.75654 .74442 m
.75676 .74449 L
s
.75667 .74466 m
.75656 .74475 L
s
.75676 .74449 m
.75667 .74466 L
s
1 .457 0 r
.64381 .43281 m
.64141 .43442 L
s
.64636 .43533 m
.64381 .43281 L
s
1 .033 0 r
.81011 .43604 m
.8103 .43622 L
s
1 .136 0 r
.52426 .52033 m
.52428 .52015 L
s
.52428 .52015 m
.52426 .51907 L
s
.52428 .52015 m
.52317 .51972 L
s
1 .034 0 r
.75656 .74475 m
.75642 .74452 L
s
.75642 .74452 m
.75676 .74449 L
s
.75676 .74449 m
.75656 .74475 L
s
1 .136 0 r
.52426 .51907 m
.52423 .51924 L
s
.52426 .51907 m
.52317 .51972 L
s
1 .39 0 r
.3984 .43515 m
.39993 .43859 L
s
1 .039 0 r
.47168 .66024 m
.47173 .66031 L
s
.47174 .65994 m
.47168 .66024 L
s
.47204 .66017 m
.47168 .66024 L
s
.4718 .66001 m
.47174 .65994 L
s
.47174 .65994 m
.47204 .66017 L
s
1 .048 0 r
.36533 .49151 m
.36555 .49165 L
s
.36508 .49181 m
.36533 .49151 L
s
.36533 .49151 m
.36511 .49153 L
s
1 .039 0 r
.47204 .66017 m
.47173 .66031 L
s
.4718 .66001 m
.47204 .66017 L
s
.47054 .65994 m
.47204 .66017 L
s
1 .048 0 r
.36531 .49195 m
.36508 .49181 L
s
.36508 .49181 m
.36511 .49153 L
s
1 .481 0 r
.55355 .49151 m
.55486 .49516 L
s
1 .039 0 r
.47173 .66031 m
.4718 .66001 L
s
1 .136 0 r
.52317 .51972 m
.52426 .52033 L
s
.52317 .51972 m
.52423 .51924 L
s
.52859 .51961 m
.52317 .51972 L
s
1 .048 0 r
.36555 .49165 m
.36531 .49195 L
s
.36511 .49153 m
.36555 .49165 L
s
.36511 .49153 m
.36531 .49195 L
s
.285 1 0 r
.56161 .46352 m
.57108 .47304 L
s
1 0 0 r
.24661 .60381 m
.24661 .60381 L
s
.24661 .60381 m
.24661 .60381 L
s
.24661 .60381 m
.24661 .60381 L
s
.24661 .60381 m
.24661 .60381 L
s
.2466 .60381 m
.24661 .60381 L
s
.24661 .60381 m
.24661 .60381 L
s
.24661 .60381 m
.24661 .60381 L
s
.24661 .60381 m
.24661 .60381 L
s
.24661 .60381 m
.24661 .60381 L
s
.75253 .57574 m
.75253 .57574 L
s
1 .04 0 r
.69447 .71606 m
.6958 .71555 L
s
1 .043 0 r
.30466 .46348 m
.30404 .4625 L
s
0 1 .331 r
.41761 .40733 m
.43536 .42111 L
s
.41761 .40733 m
.43907 .40268 L
s
1 .066 0 r
.35261 .77212 m
.35279 .7723 L
s
.35282 .77164 m
.35261 .77212 L
s
.35325 .77212 m
.35261 .77212 L
s
1 .457 0 r
.64396 .43695 m
.64636 .43533 L
s
1 .066 0 r
.35325 .77212 m
.35279 .7723 L
s
.35282 .77164 m
.35325 .77212 L
s
.353 .77182 m
.35325 .77212 L
s
.35101 .77137 m
.35325 .77212 L
s
.353 .77182 m
.35282 .77164 L
s
0 1 .077 r
.44329 .42052 m
.44613 .42287 L
s
.44329 .42052 m
.4269 .42698 L
s
1 .136 0 r
.52423 .51924 m
.52426 .52033 L
s
1 .04 0 r
.69566 .71575 m
.69554 .71585 L
s
.69552 .71546 m
.69566 .71575 L
s
.6958 .71555 m
.69566 .71575 L
s
.6954 .71556 m
.69552 .71546 L
s
.69552 .71546 m
.6958 .71555 L
s
1 .066 0 r
.35279 .7723 m
.353 .77182 L
s
1 .04 0 r
.69554 .71585 m
.6954 .71556 L
s
.6958 .71555 m
.69554 .71585 L
s
.6954 .71556 m
.6958 .71555 L
s
.973 1 0 r
.62757 .39946 m
.62184 .40418 L
s
.63361 .40394 m
.62757 .39946 L
s
1 .043 0 r
.30417 .46251 m
.30439 .46266 L
s
.30393 .46274 m
.30417 .46251 L
s
.30417 .46251 m
.30404 .4625 L
s
.30415 .46289 m
.30393 .46274 L
s
.30393 .46274 m
.30404 .4625 L
s
.30439 .46266 m
.30415 .46289 L
s
.30404 .4625 m
.30439 .46266 L
s
1 .01 0 r
.40934 .6311 m
.40937 .63112 L
s
.40938 .63102 m
.40934 .6311 L
s
.40945 .6311 m
.40934 .6311 L
s
.40945 .6311 m
.40937 .63112 L
s
.40938 .63102 m
.40945 .6311 L
s
.40941 .63104 m
.40945 .6311 L
s
.4091 .63097 m
.40945 .6311 L
s
.40941 .63104 m
.40938 .63102 L
s
1 .043 0 r
.30404 .4625 m
.30415 .46289 L
s
1 .01 0 r
.40937 .63112 m
.40941 .63104 L
s
1 .001 0 r
.69121 .54675 m
.69122 .54675 L
s
.69122 .54674 m
.69121 .54675 L
s
.69121 .54675 m
.69121 .54674 L
s
.69123 .54675 m
.69121 .54675 L
s
.69125 .54673 m
.69121 .54675 L
s
.69122 .54674 m
.69121 .54674 L
s
.69123 .54675 m
.69122 .54674 L
s
.69122 .54675 m
.69123 .54675 L
s
.69121 .54674 m
.69122 .54675 L
s
1 .457 0 r
.64141 .43442 m
.64396 .43695 L
s
1 0 0 r
.91531 .60289 m
.91531 .60289 L
s
1 .046 0 r
.63316 .68713 m
.6348 .68667 L
s
1 .344 0 r
.46719 .49057 m
.4557 .48586 L
s
1 .035 0 r
.24313 .4344 m
.24275 .43356 L
s
1 0 0 r
.91531 .60289 m
.91531 .60289 L
s
.91531 .60289 m
.91531 .60289 L
s
.91531 .60289 m
.91531 .60289 L
s
.91531 .60289 m
.91531 .60289 L
s
.91531 .60289 m
.91531 .60289 L
s
.91531 .60289 m
.91531 .60289 L
s
.91531 .60289 m
.91531 .60289 L
s
.91531 .60289 m
.91531 .60289 L
s
1 .046 0 r
.63458 .68688 m
.63447 .68698 L
s
.63446 .68654 m
.63458 .68688 L
s
.6348 .68667 m
.63458 .68688 L
s
.63435 .68664 m
.63446 .68654 L
s
.63446 .68654 m
.6348 .68667 L
s
1 .039 0 r
.6288 .51834 m
.62902 .51838 L
s
.62901 .51802 m
.6288 .51834 L
s
.6288 .51834 m
.62886 .51812 L
s
.62917 .51829 m
.6288 .51834 L
s
.6299 .51768 m
.6288 .51834 L
s
.62901 .51802 m
.62886 .51812 L
s
.62917 .51829 m
.62901 .51802 L
s
.62902 .51838 m
.62917 .51829 L
s
1 .034 0 r
.29049 .74294 m
.29027 .74301 L
s
.2903 .74267 m
.29049 .74294 L
s
.29049 .74294 m
.29016 .74291 L
s
.29041 .74277 m
.29049 .74294 L
s
.28946 .74245 m
.29049 .74294 L
s
.2903 .74267 m
.29016 .74291 L
s
.29041 .74277 m
.2903 .74267 L
s
.29016 .74291 m
.29027 .74301 L
s
1 .104 0 r
.78906 .37773 m
.78921 .37767 L
s
.78913 .37674 m
.78906 .37773 L
s
.78906 .37773 m
.78858 .37719 L
s
.78976 .37722 m
.78906 .37773 L
s
.78962 .3751 m
.78906 .37773 L
s
1 .046 0 r
.6348 .68667 m
.63447 .68698 L
s
.63435 .68664 m
.6348 .68667 L
s
.63447 .68698 m
.63435 .68664 L
s
1 .039 0 r
.62886 .51812 m
.62902 .51838 L
s
1 .035 0 r
.24284 .43357 m
.24302 .43371 L
s
.24263 .43375 m
.24284 .43357 L
s
.24284 .43357 m
.24275 .43356 L
s
1 .034 0 r
.29027 .74301 m
.29041 .74277 L
s
1 .035 0 r
.24281 .43389 m
.24263 .43375 L
s
.24263 .43375 m
.24275 .43356 L
s
.24302 .43371 m
.24281 .43389 L
s
.24275 .43356 m
.24302 .43371 L
s
1 .104 0 r
.78913 .37674 m
.78858 .37719 L
s
.78976 .37722 m
.78913 .37674 L
s
1 .011 0 r
.91209 .43366 m
.91212 .43366 L
s
.91211 .43356 m
.91209 .43366 L
s
.91209 .43366 m
.91205 .4336 L
s
.91218 .43361 m
.91209 .43366 L
s
.91221 .43339 m
.91209 .43366 L
s
1 .035 0 r
.24275 .43356 m
.24281 .43389 L
s
1 .011 0 r
.91211 .43356 m
.91205 .4336 L
s
.91218 .43361 m
.91211 .43356 L
s
.91212 .43366 m
.91218 .43361 L
s
.91205 .4336 m
.91212 .43366 L
s
1 .104 0 r
.78921 .37767 m
.78976 .37722 L
s
1 .001 0 r
.34761 .60198 m
.3476 .60198 L
s
.34761 .60197 m
.34761 .60198 L
s
.34761 .60198 m
.3476 .60198 L
s
.34761 .60198 m
.34761 .60198 L
s
.34759 .60197 m
.34761 .60198 L
s
.34761 .60197 m
.3476 .60198 L
s
.34761 .60198 m
.34761 .60197 L
s
.3476 .60198 m
.3476 .60198 L
s
.3476 .60198 m
.34761 .60198 L
s
1 .115 0 r
.45554 .77055 m
.45571 .77081 L
s
.45573 .76966 m
.45554 .77055 L
s
.4566 .77037 m
.45554 .77055 L
s
1 .018 0 r
.79596 .71435 m
.79645 .71406 L
s
1 0 0 r
.85408 .57387 m
.85408 .57387 L
s
1 .043 0 r
.57177 .65816 m
.57346 .65793 L
s
1 .253 0 r
.40571 .46148 m
.40049 .45609 L
s
1 .029 0 r
.18152 .40529 m
.18128 .40458 L
s
1 .104 0 r
.78858 .37719 m
.78921 .37767 L
s
1 .043 0 r
.57318 .6581 m
.57312 .65818 L
s
.57312 .65776 m
.57318 .6581 L
s
.57346 .65793 m
.57318 .6581 L
s
1 .115 0 r
.45589 .76992 m
.45573 .76966 L
s
.45573 .76966 m
.4566 .77037 L
s
1 .043 0 r
.57306 .65785 m
.57312 .65776 L
s
.57312 .65776 m
.57346 .65793 L
s
1 .035 0 r
.85066 .40513 m
.85074 .40511 L
s
.8507 .4048 m
.85066 .40513 L
s
.85066 .40513 m
.85052 .40494 L
s
.85092 .40497 m
.85066 .40513 L
s
.85095 .40426 m
.85066 .40513 L
s
1 .115 0 r
.4566 .77037 m
.45571 .77081 L
s
.45589 .76992 m
.4566 .77037 L
s
.45217 .76972 m
.4566 .77037 L
s
1 .018 0 r
.79635 .71403 m
.79643 .71415 L
s
.79628 .71409 m
.79635 .71403 L
s
.79635 .71403 m
.79645 .71406 L
s
.79643 .71415 m
.79636 .71421 L
s
.79645 .71406 m
.79643 .71415 L
s
1 .035 0 r
.8507 .4048 m
.85052 .40494 L
s
.85092 .40497 m
.8507 .4048 L
s
1 .043 0 r
.57346 .65793 m
.57312 .65818 L
s
.57306 .65785 m
.57346 .65793 L
s
1 .018 0 r
.79636 .71421 m
.79628 .71409 L
s
.79628 .71409 m
.79645 .71406 L
s
.79645 .71406 m
.79636 .71421 L
s
1 .035 0 r
.85074 .40511 m
.85092 .40497 L
s
1 .043 0 r
.57312 .65818 m
.57306 .65785 L
s
1 .035 0 r
.85052 .40494 m
.85074 .40511 L
s
1 .029 0 r
.18135 .40459 m
.18149 .40471 L
s
.18117 .40473 m
.18135 .40459 L
s
.18135 .40459 m
.18128 .40458 L
s
.18132 .40485 m
.18117 .40473 L
s
.18117 .40473 m
.18128 .40458 L
s
.18149 .40471 m
.18132 .40485 L
s
.18128 .40458 m
.18149 .40471 L
s
.18128 .40458 m
.18132 .40485 L
s
1 .115 0 r
.45571 .77081 m
.45589 .76992 L
s
0 1 .331 r
.43907 .40268 m
.43536 .42111 L
s
1 .024 0 r
.51106 .62927 m
.51107 .62931 L
s
.51108 .62908 m
.51106 .62927 L
s
.51126 .6292 m
.51106 .62927 L
s
.51109 .62912 m
.51108 .62908 L
s
.51108 .62908 m
.51126 .6292 L
s
.51126 .6292 m
.51107 .62931 L
s
.51109 .62912 m
.51126 .6292 L
s
.51032 .62916 m
.51126 .6292 L
s
1 0 0 r
.79278 .54483 m
.79279 .54483 L
s
.79279 .54482 m
.79278 .54483 L
s
.79278 .54483 m
.79278 .54482 L
s
.79279 .54483 m
.79278 .54483 L
s
.79279 .54482 m
.79278 .54483 L
s
.79279 .54482 m
.79278 .54482 L
s
.79279 .54483 m
.79279 .54482 L
s
.79279 .54483 m
.79279 .54483 L
s
.79278 .54482 m
.79279 .54483 L
s
1 .019 0 r
.73464 .68538 m
.7352 .68508 L
s
1 0 0 r
.28601 .57293 m
.28601 .57293 L
s
1 .151 0 r
.34416 .43237 m
.3423 .42878 L
s
1 .024 0 r
.51107 .62931 m
.51109 .62912 L
s
1 .073 0 r
.39249 .74155 m
.39267 .74173 L
s
.3927 .741 m
.39249 .74155 L
s
.3932 .74152 m
.39249 .74155 L
s
.973 1 0 r
.62184 .40418 m
.62787 .40867 L
s
1 .073 0 r
.39288 .74118 m
.3927 .741 L
s
.3927 .741 m
.3932 .74152 L
s
.3932 .74152 m
.39267 .74173 L
s
.39288 .74118 m
.3932 .74152 L
s
.39061 .74076 m
.3932 .74152 L
s
1 .019 0 r
.73508 .68505 m
.73517 .68518 L
s
.73502 .6851 m
.73508 .68505 L
s
.73508 .68505 m
.7352 .68508 L
s
.73517 .68518 m
.7351 .68524 L
s
.7352 .68508 m
.73517 .68518 L
s
.973 1 0 r
.62787 .40867 m
.63361 .40394 L
s
1 .019 0 r
.7351 .68524 m
.73502 .6851 L
s
.73502 .6851 m
.7352 .68508 L
s
.7352 .68508 m
.7351 .68524 L
s
1 .073 0 r
.39267 .74173 m
.39288 .74118 L
s
1 .07 0 r
.66856 .48809 m
.66886 .48812 L
s
.66884 .48748 m
.66856 .48809 L
s
.66856 .48809 m
.6685 .48769 L
s
.66919 .48791 m
.66856 .48809 L
s
.67 .48662 m
.66856 .48809 L
s
.66884 .48748 m
.6685 .48769 L
s
.66919 .48791 m
.66884 .48748 L
s
.66886 .48812 m
.66919 .48791 L
s
1 .344 0 r
.45797 .48839 m
.45691 .48777 L
s
.45691 .48777 m
.45804 .48522 L
s
.45691 .48777 m
.4557 .48586 L
s
1 .007 0 r
.7313 .51588 m
.73133 .51588 L
s
.73132 .51582 m
.7313 .51588 L
s
.7313 .51588 m
.73129 .51584 L
s
.73136 .51586 m
.7313 .51588 L
s
.73143 .51574 m
.7313 .51588 L
s
.73132 .51582 m
.73129 .51584 L
s
.73136 .51586 m
.73132 .51582 L
s
.73133 .51588 m
.73136 .51586 L
s
.73129 .51584 m
.73133 .51588 L
s
1 .07 0 r
.6685 .48769 m
.66886 .48812 L
s
1 .344 0 r
.45804 .48522 m
.4591 .48584 L
s
.45804 .48522 m
.4557 .48586 L
s
1 .003 0 r
.44888 .60016 m
.44889 .60016 L
s
.44889 .60013 m
.44888 .60016 L
s
.44891 .60015 m
.44888 .60016 L
s
.4489 .60014 m
.44889 .60013 L
s
.44889 .60013 m
.44891 .60015 L
s
.44891 .60015 m
.44889 .60016 L
s
.4489 .60014 m
.44891 .60015 L
s
.4488 .60012 m
.44891 .60015 L
s
.44889 .60016 m
.4489 .60014 L
s
1 0 0 r
.95587 .57199 m
.95587 .57199 L
s
1 .02 0 r
.67324 .65638 m
.67387 .65611 L
s
.285 1 0 r
.50699 .45948 m
.44051 .44757 L
s
1 .095 0 r
.28255 .40322 m
.28179 .40085 L
s
1 0 0 r
.22436 .54386 m
.22436 .54386 L
s
.22436 .54386 m
.22436 .54386 L
s
.22435 .54386 m
.22436 .54386 L
s
.22436 .54386 m
.22436 .54386 L
s
.22436 .54386 m
.22435 .54386 L
s
.22435 .54386 m
.22436 .54386 L
s
.22436 .54386 m
.22436 .54386 L
s
.22436 .54386 m
.22436 .54386 L
s
.22436 .54386 m
.22436 .54386 L
s
1 .02 0 r
.67381 .65621 m
.67375 .65626 L
s
.67374 .65606 m
.67381 .65621 L
s
.67387 .65611 m
.67381 .65621 L
s
.67368 .65611 m
.67374 .65606 L
s
.67374 .65606 m
.67387 .65611 L
s
1 .323 0 r
.68704 .40298 m
.68749 .40282 L
s
.68734 .39992 m
.68704 .40298 L
s
.68704 .40298 m
.68558 .40127 L
s
.68926 .40148 m
.68704 .40298 L
s
.68895 .3949 m
.68704 .40298 L
s
1 .02 0 r
.67375 .65626 m
.67368 .65611 L
s
.67387 .65611 m
.67375 .65626 L
s
.67368 .65611 m
.67387 .65611 L
s
1 .035 0 r
.33008 .71227 m
.32985 .71234 L
s
.32987 .712 m
.33008 .71227 L
s
.33008 .71227 m
.32973 .71225 L
s
.32999 .71209 m
.33008 .71227 L
s
.32899 .71177 m
.33008 .71227 L
s
.32987 .712 m
.32973 .71225 L
s
.32999 .71209 m
.32987 .712 L
s
.32973 .71225 m
.32985 .71234 L
s
.32985 .71234 m
.32999 .71209 L
s
1 .134 0 r
.55791 .76819 m
.55784 .76848 L
s
.55782 .76714 m
.55791 .76819 L
s
.5589 .76775 m
.55791 .76819 L
s
.55775 .76743 m
.55782 .76714 L
s
.55782 .76714 m
.5589 .76775 L
s
1 .323 0 r
.68734 .39992 m
.68558 .40127 L
s
.68926 .40148 m
.68734 .39992 L
s
1 0 0 r
.89456 .54291 m
.89456 .54291 L
s
.89456 .54291 m
.89456 .54291 L
s
.89456 .54291 m
.89456 .54291 L
s
.89456 .54291 m
.89456 .54291 L
s
.89457 .54291 m
.89456 .54291 L
s
.89456 .54291 m
.89456 .54291 L
s
.89456 .54291 m
.89456 .54291 L
s
.89456 .54291 m
.89456 .54291 L
s
.89456 .54291 m
.89456 .54291 L
s
1 .008 0 r
.83634 .68363 m
.83654 .68349 L
s
1 .134 0 r
.55355 .76806 m
.5589 .76775 L
s
1 .016 0 r
.61178 .62734 m
.61235 .62717 L
s
1 0 0 r
.38721 .57105 m
.38721 .57105 L
s
.939 1 0 r
.44543 .43033 m
.42387 .40707 L
s
1 .066 0 r
.22086 .37404 m
.2205 .37237 L
s
1 .016 0 r
.61227 .62725 m
.61223 .62728 L
s
.61223 .62713 m
.61227 .62725 L
s
.61235 .62717 m
.61227 .62725 L
s
.61219 .62716 m
.61223 .62713 L
s
.61223 .62713 m
.61235 .62717 L
s
1 .008 0 r
.83649 .68348 m
.83653 .68353 L
s
.83646 .6835 m
.83649 .68348 L
s
.83649 .68348 m
.83654 .68349 L
s
.83653 .68353 m
.8365 .68355 L
s
.83654 .68349 m
.83653 .68353 L
s
.8365 .68355 m
.83646 .6835 L
s
.83646 .6835 m
.83654 .68349 L
s
0 .813 1 r
.61409 .47819 m
.63001 .45833 L
s
1 .008 0 r
.83654 .68349 m
.8365 .68355 L
s
1 .035 0 r
.89124 .37388 m
.8913 .37385 L
s
.89126 .37354 m
.89124 .37388 L
s
.89124 .37388 m
.89108 .3737 L
s
.89148 .3737 m
.89124 .37388 L
s
.89145 .37299 m
.89124 .37388 L
s
1 .016 0 r
.61235 .62717 m
.61223 .62728 L
s
.61219 .62716 m
.61235 .62717 L
s
.61223 .62728 m
.61219 .62716 L
s
1 .035 0 r
.89126 .37354 m
.89108 .3737 L
s
.89148 .3737 m
.89126 .37354 L
s
1 .121 0 r
.49575 .73971 m
.49584 .73996 L
s
.49585 .73876 m
.49575 .73971 L
s
.49681 .73943 m
.49575 .73971 L
s
1 .035 0 r
.8913 .37385 m
.89148 .3737 L
s
.89108 .3737 m
.8913 .37385 L
s
1 .121 0 r
.49594 .73901 m
.49585 .73876 L
s
.49585 .73876 m
.49681 .73943 L
s
1 .134 0 r
.5589 .76775 m
.55784 .76848 L
s
.55775 .76743 m
.5589 .76775 L
s
1 .151 0 r
.34271 .42882 m
.34349 .42937 L
s
.34185 .42963 m
.34271 .42882 L
s
.34271 .42882 m
.3423 .42878 L
s
1 .575 0 r
.38063 .36944 m
.38374 .37164 L
s
.37729 .37237 m
.38063 .36944 L
s
.38063 .36944 m
.37948 .36911 L
s
1 .121 0 r
.49681 .73943 m
.49584 .73996 L
s
.49594 .73901 m
.49681 .73943 L
s
.49199 .73907 m
.49681 .73943 L
s
1 .095 0 r
.28197 .4009 m
.28248 .40129 L
s
.2814 .40137 m
.28197 .4009 L
s
.28197 .4009 m
.28179 .40085 L
s
1 .134 0 r
.55784 .76848 m
.55775 .76743 L
s
1 .253 0 r
.40158 .45601 m
.40279 .45675 L
s
.40029 .45759 m
.40158 .45601 L
s
.40158 .45601 m
.40049 .45609 L
s
1 .344 0 r
.4591 .48584 m
.45797 .48839 L
s
.4557 .48586 m
.45797 .48839 L
s
1 .323 0 r
.68749 .40282 m
.68926 .40148 L
s
1 .151 0 r
.34263 .43018 m
.34185 .42963 L
s
.34185 .42963 m
.3423 .42878 L
s
1 .013 0 r
.26763 .68297 m
.26756 .68299 L
s
.26757 .68286 m
.26763 .68297 L
s
.26763 .68297 m
.26751 .68295 L
s
.26762 .6829 m
.26763 .68297 L
s
.26729 .68275 m
.26763 .68297 L
s
1 .344 0 r
.4557 .48586 m
.4591 .48584 L
s
1 .013 0 r
.26757 .68286 m
.26751 .68295 L
s
.26762 .6829 m
.26757 .68286 L
s
.26751 .68295 m
.26756 .68299 L
s
1 .095 0 r
.28191 .40176 m
.2814 .40137 L
s
.2814 .40137 m
.28179 .40085 L
s
1 .013 0 r
.26756 .68299 m
.26762 .6829 L
s
1 .095 0 r
.28248 .40129 m
.28191 .40176 L
s
.28179 .40085 m
.28248 .40129 L
s
1 .253 0 r
.40149 .45833 m
.40029 .45759 L
s
.40029 .45759 m
.40049 .45609 L
s
1 .323 0 r
.68558 .40127 m
.68749 .40282 L
s
1 .151 0 r
.34349 .42937 m
.34263 .43018 L
s
.3423 .42878 m
.34349 .42937 L
s
1 .002 0 r
.83317 .51383 m
.83317 .51383 L
s
.83317 .51381 m
.83317 .51383 L
s
.83317 .51383 m
.83316 .51382 L
s
.83318 .51382 m
.83317 .51383 L
s
.83319 .51379 m
.83317 .51383 L
s
1 .121 0 r
.49584 .73996 m
.49594 .73901 L
s
1 .002 0 r
.83317 .51381 m
.83316 .51382 L
s
.83318 .51382 m
.83317 .51381 L
s
.83317 .51383 m
.83318 .51382 L
s
.83316 .51382 m
.83317 .51383 L
s
1 .005 0 r
.55042 .59827 m
.55041 .59828 L
s
.55041 .59823 m
.55042 .59827 L
s
.55045 .59825 m
.55042 .59827 L
s
1 .007 0 r
.77494 .65459 m
.77512 .65447 L
s
1 .005 0 r
.55024 .59827 m
.55045 .59825 L
s
1 .001 0 r
.32555 .54195 m
.32553 .54193 L
s
1 .459 0 r
.3838 .40115 m
.3797 .38976 L
s
1 .005 0 r
.55041 .59824 m
.55041 .59823 L
s
.55041 .59823 m
.55045 .59825 L
s
1 .001 0 r
.32553 .54193 m
.32554 .54193 L
s
.32553 .54194 m
.32553 .54193 L
s
.32553 .54193 m
.32553 .54193 L
s
.32553 .54194 m
.32553 .54194 L
s
.32553 .54194 m
.32553 .54193 L
s
.32554 .54193 m
.32553 .54194 L
s
.32553 .54193 m
.32554 .54193 L
s
.32553 .54193 m
.32553 .54194 L
s
1 .005 0 r
.55045 .59825 m
.55041 .59828 L
s
.55041 .59824 m
.55045 .59825 L
s
.55041 .59828 m
.55041 .59824 L
s
.542 1 0 r
.42308 .36256 m
.4301 .36651 L
s
.41564 .37157 m
.42308 .36256 L
s
.42308 .36256 m
.41689 .36247 L
s
1 .095 0 r
.28179 .40085 m
.28191 .40176 L
s
.542 1 0 r
.63305 .37291 m
.62805 .37288 L
s
.62762 .35989 m
.63305 .37291 L
s
.63305 .37291 m
.62033 .36891 L
s
.63536 .36383 m
.63305 .37291 L
s
.6066 .33974 m
.63305 .37291 L
s
1 .007 0 r
.77508 .65446 m
.77511 .65451 L
s
.77505 .65448 m
.77508 .65446 L
s
.77508 .65446 m
.77512 .65447 L
s
.77511 .65451 m
.77508 .65453 L
s
.77512 .65447 m
.77511 .65451 L
s
1 .066 0 r
.2206 .37242 m
.22095 .3727 L
s
.2202 .37272 m
.2206 .37242 L
s
.2206 .37242 m
.2205 .37237 L
s
1 .08 0 r
.43253 .71082 m
.4327 .711 L
s
.43272 .71021 m
.43253 .71082 L
s
.4333 .71074 m
.43253 .71082 L
s
1 .081 0 r
.70911 .45735 m
.70935 .45735 L
s
.70931 .4566 m
.70911 .45735 L
s
.70911 .45735 m
.70889 .45689 L
s
.70977 .45705 m
.70911 .45735 L
s
.71024 .45546 m
.70911 .45735 L
s
1 .007 0 r
.77508 .65453 m
.77505 .65448 L
s
.77505 .65448 m
.77512 .65447 L
s
.77512 .65447 m
.77508 .65453 L
s
1 .08 0 r
.43289 .71039 m
.43272 .71021 L
s
.43272 .71021 m
.4333 .71074 L
s
1 .151 0 r
.3423 .42878 m
.34263 .43018 L
s
1 .08 0 r
.4333 .71074 m
.4327 .711 L
s
.43289 .71039 m
.4333 .71074 L
s
.43035 .71005 m
.4333 .71074 L
s
1 .066 0 r
.22054 .373 m
.2202 .37272 L
s
.2202 .37272 m
.2205 .37237 L
s
.22095 .3727 m
.22054 .373 L
s
.2205 .37237 m
.22095 .3727 L
s
1 .081 0 r
.70931 .4566 m
.70889 .45689 L
s
.70977 .45705 m
.70931 .4566 L
s
.70935 .45735 m
.70977 .45705 L
s
1 .066 0 r
.2205 .37237 m
.22054 .373 L
s
1 .08 0 r
.4327 .711 m
.43289 .71039 L
s
1 .081 0 r
.70889 .45689 m
.70935 .45735 L
s
1 .575 0 r
.38039 .37457 m
.37729 .37237 L
s
.37729 .37237 m
.37948 .36911 L
s
1 .013 0 r
.77155 .48494 m
.7716 .48494 L
s
.77159 .48482 m
.77155 .48494 L
s
.77155 .48494 m
.77152 .48487 L
s
.77166 .4849 m
.77155 .48494 L
s
.77175 .48464 m
.77155 .48494 L
s
1 .253 0 r
.40279 .45675 m
.40149 .45833 L
s
.40049 .45609 m
.40279 .45675 L
s
1 .013 0 r
.77159 .48482 m
.77152 .48487 L
s
.77166 .4849 m
.77159 .48482 L
s
.7716 .48494 m
.77166 .4849 L
s
.77152 .48487 m
.7716 .48494 L
s
1 .253 0 r
.40049 .45609 m
.40149 .45833 L
s
1 .005 0 r
.71346 .62552 m
.7136 .62544 L
s
1 .095 0 r
.65517 .7664 m
.65861 .76549 L
s
1 0 0 r
.48864 .56917 m
.48864 .56917 L
s
1 .003 0 r
.26382 .51282 m
.26376 .51275 L
s
1 .233 0 r
.3221 .37194 m
.32114 .36599 L
s
1 .003 0 r
.26378 .51275 m
.26379 .51276 L
s
.26376 .51276 m
.26378 .51275 L
s
.26378 .51275 m
.26376 .51275 L
s
.26377 .51277 m
.26376 .51276 L
s
.26376 .51276 m
.26376 .51275 L
s
.26379 .51276 m
.26377 .51277 L
s
.26376 .51275 m
.26379 .51276 L
s
1 .005 0 r
.71357 .62543 m
.71359 .62546 L
s
.71355 .62544 m
.71357 .62543 L
s
.71357 .62543 m
.7136 .62544 L
s
.71359 .62546 m
.71357 .62548 L
s
.7136 .62544 m
.71359 .62546 L
s
1 .003 0 r
.26376 .51275 m
.26377 .51277 L
s
1 .005 0 r
.71357 .62548 m
.71355 .62544 L
s
.71355 .62544 m
.7136 .62544 L
s
.7136 .62544 m
.71357 .62548 L
s
1 .575 0 r
.38374 .37164 m
.38039 .37457 L
s
.37948 .36911 m
.38374 .37164 L
s
.542 1 0 r
.42265 .37555 m
.41564 .37157 L
s
.41564 .37157 m
.41689 .36247 L
s
1 .035 0 r
.36977 .68147 m
.36954 .68154 L
s
.36955 .6812 m
.36977 .68147 L
s
.36977 .68147 m
.36942 .68145 L
s
.36966 .68129 m
.36977 .68147 L
s
.36864 .68099 m
.36977 .68147 L
s
.36942 .68145 m
.36954 .68154 L
s
.36955 .6812 m
.36942 .68145 L
s
.36966 .68129 m
.36955 .6812 L
s
1 .095 0 r
.65816 .76591 m
.65794 .76615 L
s
.65791 .7652 m
.65816 .76591 L
s
.65861 .76549 m
.65816 .76591 L
s
.65769 .76543 m
.65791 .7652 L
s
.65791 .7652 m
.65861 .76549 L
s
1 .035 0 r
.36954 .68154 m
.36966 .68129 L
s
.285 1 0 r
.4537 .45784 m
.4513 .45569 L
s
.4513 .45569 m
.45405 .44213 L
s
.4513 .45569 m
.44051 .44757 L
s
1 .001 0 r
.93518 .51185 m
.93518 .51185 L
s
.93518 .51185 m
.93518 .51185 L
s
.93518 .51185 m
.93518 .51185 L
s
.93518 .51185 m
.93518 .51185 L
s
.93519 .51184 m
.93518 .51185 L
s
.93518 .51185 m
.93518 .51185 L
s
.93518 .51185 m
.93518 .51185 L
s
.93518 .51185 m
.93518 .51185 L
s
.93518 .51185 m
.93518 .51185 L
s
1 .003 0 r
.87687 .6528 m
.87692 .65275 L
s
1 .114 0 r
.59359 .73738 m
.598 .73669 L
s
1 .002 0 r
.65191 .59642 m
.65197 .59639 L
s
1 .005 0 r
.42696 .54003 m
.4268 .53995 L
s
0 .197 1 r
.48528 .39907 m
.40705 .31112 L
s
1 .005 0 r
.20201 .48365 m
.20195 .48353 L
s
1 .002 0 r
.65197 .5964 m
.65196 .5964 L
s
.65196 .59638 m
.65197 .5964 L
s
.65197 .59639 m
.65197 .5964 L
s
.65195 .59639 m
.65196 .59638 L
s
.65196 .59638 m
.65197 .59639 L
s
.65196 .5964 m
.65195 .59639 L
s
.65197 .59639 m
.65196 .5964 L
s
.65195 .59639 m
.65197 .59639 L
s
1 .003 0 r
.87691 .65275 m
.87692 .65276 L
s
.8769 .65276 m
.87691 .65275 L
s
.87691 .65275 m
.87692 .65275 L
s
.87692 .65276 m
.87691 .65277 L
s
.87692 .65275 m
.87692 .65276 L
s
.87691 .65277 m
.8769 .65276 L
s
.8769 .65276 m
.87692 .65275 L
s
.87692 .65275 m
.87691 .65277 L
s
1 .005 0 r
.42683 .53994 m
.42685 .53995 L
s
.42681 .53998 m
.42683 .53994 L
s
.42683 .53994 m
.4268 .53995 L
s
.42683 .53999 m
.42681 .53998 L
s
.42681 .53998 m
.4268 .53995 L
s
.20196 .48353 m
.20199 .48355 L
s
.20193 .48356 m
.20196 .48353 L
s
.20196 .48353 m
.20195 .48353 L
s
.42685 .53995 m
.42683 .53999 L
s
.4268 .53995 m
.42685 .53995 L
s
.4268 .53995 m
.42683 .53999 L
s
.20196 .48358 m
.20193 .48356 L
s
.20193 .48356 m
.20195 .48353 L
s
1 .095 0 r
.65861 .76549 m
.65794 .76615 L
s
.65769 .76543 m
.65861 .76549 L
s
1 .005 0 r
.20199 .48355 m
.20196 .48358 L
s
.20195 .48353 m
.20199 .48355 L
s
.20195 .48353 m
.20196 .48358 L
s
1 .095 0 r
.65794 .76615 m
.65769 .76543 L
s
1 .114 0 r
.5973 .73715 m
.59713 .73739 L
s
.59711 .73626 m
.5973 .73715 L
s
.598 .73669 m
.5973 .73715 L
s
0 1 .077 r
.4269 .42698 m
.4428 .43934 L
s
.4269 .42698 m
.44613 .42287 L
s
1 .114 0 r
.59694 .73651 m
.59711 .73626 L
s
.59711 .73626 m
.598 .73669 L
s
1 .575 0 r
.37948 .36911 m
.38039 .37457 L
s
.542 1 0 r
.62762 .35989 m
.62033 .36891 L
s
.63536 .36383 m
.62762 .35989 L
s
1 .116 0 r
.53569 .7086 m
.53567 .70883 L
s
.53567 .70769 m
.53569 .7086 L
s
.5366 .70824 m
.53569 .7086 L
s
.53565 .70791 m
.53567 .70769 L
s
.53567 .70769 m
.5366 .70824 L
s
1 .01 0 r
.30714 .65208 m
.30708 .65209 L
s
.30709 .65199 m
.30714 .65208 L
s
.30714 .65208 m
.30704 .65206 L
s
.30713 .65202 m
.30714 .65208 L
s
.30687 .6519 m
.30714 .65208 L
s
1 .114 0 r
.598 .73669 m
.59713 .73739 L
s
.59694 .73651 m
.598 .73669 L
s
1 .01 0 r
.30709 .65199 m
.30704 .65206 L
s
.30713 .65202 m
.30709 .65199 L
s
.30704 .65206 m
.30708 .65209 L
s
.30708 .65209 m
.30713 .65202 L
s
1 .004 0 r
.87368 .48275 m
.87369 .48275 L
s
.87369 .48271 m
.87368 .48275 L
s
.87368 .48275 m
.87367 .48273 L
s
.87371 .48273 m
.87368 .48275 L
s
.87373 .48266 m
.87368 .48275 L
s
.87369 .48271 m
.87367 .48273 L
s
.87371 .48273 m
.87369 .48271 L
s
.87369 .48275 m
.87371 .48273 L
s
.87367 .48273 m
.87369 .48275 L
s
1 .114 0 r
.59713 .73739 m
.59694 .73651 L
s
1 .05 0 r
.75702 .76474 m
.75857 .76404 L
s
1 .002 0 r
.81538 .6237 m
.81541 .62366 L
s
1 .116 0 r
.53194 .70832 m
.5366 .70824 L
s
1 0 0 r
.5903 .56728 m
.5903 .56728 L
s
1 .016 0 r
.36522 .51086 m
.36488 .51053 L
s
.808 1 0 r
.42357 .36982 m
.42029 .33892 L
s
1 .002 0 r
.81541 .62366 m
.81541 .62367 L
s
.8154 .62367 m
.81541 .62366 L
s
.81541 .62366 m
.81541 .62366 L
s
.81541 .62367 m
.81541 .62368 L
s
.81541 .62366 m
.81541 .62367 L
s
.81541 .62368 m
.8154 .62367 L
s
.8154 .62367 m
.81541 .62366 L
s
.81541 .62366 m
.81541 .62368 L
s
1 .116 0 r
.5366 .70824 m
.53567 .70883 L
s
.53565 .70791 m
.5366 .70824 L
s
1 .08 0 r
.7499 .42614 m
.75007 .42611 L
s
.75001 .42539 m
.7499 .42614 L
s
.7499 .42614 m
.74959 .42571 L
s
.75049 .42579 m
.7499 .42614 L
s
.75061 .42419 m
.7499 .42614 L
s
.285 1 0 r
.45405 .44213 m
.45647 .4442 L
s
.45405 .44213 m
.44051 .44757 L
s
1 .344 0 r
.6007 .48246 m
.60239 .4827 L
s
.60231 .47952 m
.6007 .48246 L
s
.6007 .48246 m
.60076 .48043 L
s
.60394 .48179 m
.6007 .48246 L
s
.60897 .47568 m
.6007 .48246 L
s
1 .016 0 r
.36496 .51053 m
.36503 .51057 L
s
.36487 .51063 m
.36496 .51053 L
s
.36496 .51053 m
.36488 .51053 L
s
.36495 .51067 m
.36487 .51063 L
s
.36487 .51063 m
.36488 .51053 L
s
1 .08 0 r
.75001 .42539 m
.74959 .42571 L
s
.75049 .42579 m
.75001 .42539 L
s
1 .081 0 r
.47263 .67986 m
.47274 .68002 L
s
.47276 .67923 m
.47263 .67986 L
s
.47338 .67972 m
.47263 .67986 L
s
1 .016 0 r
.36503 .51057 m
.36495 .51067 L
s
.36488 .51053 m
.36503 .51057 L
s
.36488 .51053 m
.36495 .51067 L
s
1 .081 0 r
.47288 .67939 m
.47276 .67923 L
s
.47276 .67923 m
.47338 .67972 L
s
1 .116 0 r
.53567 .70883 m
.53565 .70791 L
s
1 .233 0 r
.72903 .36942 m
.72917 .36927 L
s
.72903 .3672 m
.72903 .36942 L
s
.72903 .36942 m
.72776 .36826 L
s
.73044 .36821 m
.72903 .36942 L
s
.72938 .36346 m
.72903 .36942 L
s
1 .08 0 r
.75007 .42611 m
.75049 .42579 L
s
1 .081 0 r
.47338 .67972 m
.47274 .68002 L
s
.47288 .67939 m
.47338 .67972 L
s
.47023 .67923 m
.47338 .67972 L
s
1 .08 0 r
.74959 .42571 m
.75007 .42611 L
s
1 .05 0 r
.75824 .76393 m
.75844 .76428 L
s
.75807 .76407 m
.75824 .76393 L
s
.75824 .76393 m
.75857 .76404 L
s
.75844 .76428 m
.75827 .76443 L
s
.75857 .76404 m
.75844 .76428 L
s
1 .018 0 r
.812 .45388 m
.81205 .45388 L
s
.81204 .45371 m
.812 .45388 L
s
.812 .45388 m
.81194 .45378 L
s
.81215 .4538 m
.812 .45388 L
s
.81221 .45344 m
.812 .45388 L
s
0 1 .566 r
.61448 .48209 m
.60543 .48313 L
s
.60484 .45937 m
.61448 .48209 L
s
.61448 .48209 m
.59193 .47543 L
s
.61841 .46696 m
.61448 .48209 L
s
.56658 .42627 m
.61448 .48209 L
s
1 .018 0 r
.81204 .45371 m
.81194 .45378 L
s
.81215 .4538 m
.81204 .45371 L
s
.81205 .45388 m
.81215 .4538 L
s
.81194 .45378 m
.81205 .45388 L
s
1 .344 0 r
.60231 .47952 m
.60076 .48043 L
s
.60394 .48179 m
.60231 .47952 L
s
1 .081 0 r
.47274 .68002 m
.47288 .67939 L
s
1 .05 0 r
.75827 .76443 m
.75807 .76407 L
s
.75807 .76407 m
.75857 .76404 L
s
.75857 .76404 m
.75827 .76443 L
s
.542 1 0 r
.62033 .36891 m
.62805 .37288 L
s
1 .344 0 r
.60239 .4827 m
.60394 .48179 L
s
0 1 .566 r
.46726 .48048 m
.47432 .50006 L
s
1 .233 0 r
.72903 .3672 m
.72776 .36826 L
s
.73044 .36821 m
.72903 .3672 L
s
1 .021 0 r
.52795 .53822 m
.52795 .53819 L
s
.52795 .53819 m
.52795 .53803 L
s
.52795 .53819 m
.52778 .53813 L
s
.52795 .53803 m
.52794 .53805 L
s
.52795 .53803 m
.52778 .53813 L
s
1 .002 0 r
.24506 .62282 m
.24505 .62282 L
s
.24505 .6228 m
.24506 .62282 L
s
.24506 .62282 m
.24504 .62281 L
s
.24506 .62281 m
.24506 .62282 L
s
.24502 .62278 m
.24506 .62282 L
s
.24505 .6228 m
.24504 .62281 L
s
.24506 .62281 m
.24505 .6228 L
s
.24504 .62281 m
.24505 .62282 L
s
.24505 .62282 m
.24506 .62281 L
s
1 .021 0 r
.52778 .53813 m
.52795 .53822 L
s
.52778 .53813 m
.52794 .53805 L
s
.52861 .53811 m
.52778 .53813 L
s
1 0 0 r
.75382 .59456 m
.75383 .59455 L
s
1 .063 0 r
.69543 .73568 m
.69754 .73488 L
s
1 .02 0 r
.30341 .48166 m
.30312 .48121 L
s
1 0 0 r
.75383 .59455 m
.75383 .59455 L
s
.75383 .59455 m
.75383 .59455 L
s
.75383 .59455 m
.75383 .59455 L
s
.75383 .59455 m
.75383 .59455 L
s
.75383 .59455 m
.75383 .59455 L
s
.75383 .59455 m
.75383 .59455 L
s
.75383 .59455 m
.75383 .59455 L
s
.75383 .59455 m
.75383 .59455 L
s
1 .021 0 r
.52794 .53805 m
.52795 .53822 L
s
1 .02 0 r
.30318 .48121 m
.30328 .48128 L
s
.30307 .48132 m
.30318 .48121 L
s
.30318 .48121 m
.30312 .48121 L
s
.30317 .48139 m
.30307 .48132 L
s
.30307 .48132 m
.30312 .48121 L
s
.30328 .48128 m
.30317 .48139 L
s
.30312 .48121 m
.30328 .48128 L
s
.30312 .48121 m
.30317 .48139 L
s
1 .233 0 r
.72776 .36826 m
.72917 .36927 L
s
.72917 .36927 m
.73044 .36821 L
s
1 .032 0 r
.4092 .65051 m
.4093 .65058 L
s
.40931 .65027 m
.4092 .65051 L
s
.40952 .65051 m
.4092 .65051 L
s
.40952 .65051 m
.4093 .65058 L
s
.40931 .65027 m
.40952 .65051 L
s
.4094 .65035 m
.40952 .65051 L
s
.40844 .65011 m
.40952 .65051 L
s
.4094 .65035 m
.40931 .65027 L
s
1 .199 0 r
.56305 .50967 m
.56357 .50933 L
s
.56357 .50933 m
.56302 .50781 L
s
.56357 .50933 m
.56161 .50919 L
s
1 .063 0 r
.69732 .73519 m
.69713 .73536 L
s
.6971 .73472 m
.69732 .73519 L
s
.69754 .73488 m
.69732 .73519 L
s
.69691 .73489 m
.6971 .73472 L
s
.6971 .73472 m
.69754 .73488 L
s
1 .199 0 r
.56302 .50781 m
.5625 .50815 L
s
.56302 .50781 m
.56161 .50919 L
s
0 1 .077 r
.44613 .42287 m
.4428 .43934 L
s
1 .199 0 r
.56161 .50919 m
.56305 .50967 L
s
.56161 .50919 m
.5625 .50815 L
s
.56872 .50695 m
.56161 .50919 L
s
1 .032 0 r
.4093 .65058 m
.4094 .65035 L
s
1 .233 0 r
.3214 .36614 m
.32267 .36715 L
s
.32 .36721 m
.3214 .36614 L
s
.3214 .36614 m
.32114 .36599 L
s
1 .063 0 r
.69713 .73536 m
.69691 .73489 L
s
.69754 .73488 m
.69713 .73536 L
s
.69691 .73489 m
.69754 .73488 L
s
1 .001 0 r
.91753 .62187 m
.91754 .62186 L
s
1 .08 0 r
.63377 .70659 m
.63665 .70579 L
s
1 0 0 r
.69219 .56539 m
.69219 .56539 L
s
1 .136 0 r
.46686 .50891 m
.46232 .50707 L
s
1 .019 0 r
.24152 .45243 m
.24131 .45196 L
s
1 .001 0 r
.91753 .62186 m
.91754 .62186 L
s
.91753 .62186 m
.91753 .62186 L
s
.91753 .62186 m
.91754 .62186 L
s
.91754 .62186 m
.91754 .62186 L
s
.91754 .62186 m
.91754 .62186 L
s
.91754 .62186 m
.91753 .62186 L
s
.91753 .62186 m
.91754 .62186 L
s
.91754 .62186 m
.91754 .62186 L
s
1 .05 0 r
.28964 .76295 m
.28932 .76306 L
s
.28935 .76256 m
.28964 .76295 L
s
.28964 .76295 m
.28915 .76291 L
s
.28953 .76271 m
.28964 .76295 L
s
.28812 .76223 m
.28964 .76295 L
s
.28935 .76256 m
.28915 .76291 L
s
.28953 .76271 m
.28935 .76256 L
s
.28915 .76291 m
.28932 .76306 L
s
1 .344 0 r
.60076 .48043 m
.60239 .4827 L
s
1 .019 0 r
.24136 .45197 m
.24146 .45204 L
s
.24125 .45207 m
.24136 .45197 L
s
.24136 .45197 m
.24131 .45196 L
s
.24135 .45214 m
.24125 .45207 L
s
.24125 .45207 m
.24131 .45196 L
s
.24146 .45204 m
.24135 .45214 L
s
.24131 .45196 m
.24146 .45204 L
s
.24131 .45196 m
.24135 .45214 L
s
1 .05 0 r
.28932 .76306 m
.28953 .76271 L
s
1 .233 0 r
.32127 .36822 m
.32 .36721 L
s
.32 .36721 m
.32114 .36599 L
s
1 .08 0 r
.63628 .70616 m
.63609 .70635 L
s
.63606 .70556 m
.63628 .70616 L
s
.63665 .70579 m
.63628 .70616 L
s
1 .233 0 r
.32267 .36715 m
.32127 .36822 L
s
.32114 .36599 m
.32267 .36715 L
s
1 .08 0 r
.63587 .70574 m
.63606 .70556 L
s
.63606 .70556 m
.63665 .70579 L
s
1 .199 0 r
.5625 .50815 m
.56305 .50967 L
s
1 .006 0 r
.91435 .45156 m
.91436 .45156 L
s
.91436 .4515 m
.91435 .45156 L
s
.91435 .45156 m
.91433 .45153 L
s
.91439 .45153 m
.91435 .45156 L
s
.91441 .45141 m
.91435 .45156 L
s
.91436 .4515 m
.91433 .45153 L
s
.91439 .45153 m
.91436 .4515 L
s
.91436 .45156 m
.91439 .45153 L
s
.34675 .62106 m
.34671 .62107 L
s
.34671 .62101 m
.34675 .62106 L
s
.34675 .62106 m
.34669 .62105 L
s
.34674 .62102 m
.34675 .62106 L
s
.34658 .62095 m
.34675 .62106 L
s
.91433 .45153 m
.91436 .45156 L
s
.34671 .62101 m
.34669 .62105 L
s
.34674 .62102 m
.34671 .62101 L
s
.34669 .62105 m
.34671 .62107 L
s
1 .005 0 r
.63034 .53627 m
.63037 .53628 L
s
.63037 .53623 m
.63034 .53627 L
s
.63034 .53627 m
.63035 .53624 L
s
.63039 .53627 m
.63034 .53627 L
s
.63049 .53618 m
.63034 .53627 L
s
.63037 .53623 m
.63035 .53624 L
s
.63039 .53627 m
.63037 .53623 L
s
.63037 .53628 m
.63039 .53627 L
s
1 .08 0 r
.63665 .70579 m
.63609 .70635 L
s
.63587 .70574 m
.63665 .70579 L
s
1 .006 0 r
.34671 .62107 m
.34674 .62102 L
s
1 .08 0 r
.63609 .70635 m
.63587 .70574 L
s
1 .005 0 r
.63035 .53624 m
.63037 .53628 L
s
.787 1 0 r
.57314 .47973 m
.57617 .47974 L
s
.576 .46852 m
.57314 .47973 L
s
.57314 .47973 m
.5694 .47292 L
s
.58276 .47531 m
.57314 .47973 L
s
.58807 .45131 m
.57314 .47973 L
s
1 .303 0 r
.64538 .45142 m
.64623 .45139 L
s
.64612 .44862 m
.64538 .45142 L
s
.64538 .45142 m
.64452 .4497 L
s
.64783 .4503 m
.64538 .45142 L
s
.64936 .4443 m
.64538 .45142 L
s
1 .029 0 r
.7975 .73398 m
.79831 .73351 L
s
1 0 0 r
.85596 .5927 m
.85596 .59269 L
s
1 .09 0 r
.57204 .67746 m
.57556 .67699 L
s
1 .133 0 r
.40503 .47967 m
.40228 .47686 L
s
1 .018 0 r
.17957 .42316 m
.17942 .42272 L
s
1 0 0 r
.85596 .59269 m
.85596 .59269 L
s
.85596 .59269 m
.85596 .59269 L
s
.85596 .59269 m
.85596 .59269 L
s
.85596 .59269 m
.85596 .59269 L
s
.85596 .59269 m
.85596 .59269 L
s
.85596 .59269 m
.85596 .59269 L
s
.85596 .59269 m
.85596 .59269 L
s
.85596 .59269 m
.85596 .59269 L
s
1 .233 0 r
.32114 .36599 m
.32127 .36822 L
s
1 .136 0 r
.46321 .50807 m
.46279 .50781 L
s
.46279 .50781 m
.46324 .50681 L
s
.46279 .50781 m
.46232 .50707 L
s
1 .09 0 r
.57497 .67735 m
.57486 .67752 L
s
.57485 .67664 m
.57497 .67735 L
s
.57556 .67699 m
.57497 .67735 L
s
.542 1 0 r
.4301 .36651 m
.42265 .37555 L
s
.41689 .36247 m
.4301 .36651 L
s
1 .136 0 r
.46324 .50681 m
.46366 .50706 L
s
.46324 .50681 m
.46232 .50707 L
s
1 .09 0 r
.57473 .67682 m
.57485 .67664 L
s
.57485 .67664 m
.57556 .67699 L
s
1 .073 0 r
.79073 .39465 m
.79083 .39462 L
s
.79078 .39396 m
.79073 .39465 L
s
.79073 .39465 m
.79039 .39427 L
s
.79123 .3943 m
.79073 .39465 L
s
.79112 .39281 m
.79073 .39465 L
s
1 .018 0 r
.17946 .42273 m
.17955 .4228 L
s
.17935 .42281 m
.17946 .42273 L
s
.17946 .42273 m
.17942 .42272 L
s
1 .575 0 r
.67129 .3663 m
.67083 .36596 L
s
.67059 .36083 m
.67129 .3663 L
s
.67129 .3663 m
.66742 .36376 L
s
.67401 .36302 m
.67129 .3663 L
s
.66837 .35167 m
.67129 .3663 L
s
1 .018 0 r
.17944 .42289 m
.17935 .42281 L
s
.17935 .42281 m
.17942 .42272 L
s
.17955 .4228 m
.17944 .42289 L
s
.17942 .42272 m
.17955 .4228 L
s
1 .029 0 r
.79813 .73346 m
.79827 .73366 L
s
.79803 .73355 m
.79813 .73346 L
s
.79813 .73346 m
.79831 .73351 L
s
.79827 .73366 m
.79816 .73375 L
s
.79831 .73351 m
.79827 .73366 L
s
1 .018 0 r
.17942 .42272 m
.17944 .42289 L
s
1 .073 0 r
.79078 .39396 m
.79039 .39427 L
s
.79123 .3943 m
.79078 .39396 L
s
1 .022 0 r
.85262 .42267 m
.85267 .42266 L
s
.85265 .42246 m
.85262 .42267 L
s
.85262 .42267 m
.85254 .42255 L
s
.85278 .42257 m
.85262 .42267 L
s
.8528 .42213 m
.85262 .42267 L
s
1 .029 0 r
.79816 .73375 m
.79803 .73355 L
s
.79803 .73355 m
.79831 .73351 L
s
.79831 .73351 m
.79816 .73375 L
s
1 .022 0 r
.85265 .42246 m
.85254 .42255 L
s
.85278 .42257 m
.85265 .42246 L
s
1 .09 0 r
.57556 .67699 m
.57486 .67752 L
s
.57473 .67682 m
.57556 .67699 L
s
1 .022 0 r
.85267 .42266 m
.85278 .42257 L
s
1 .073 0 r
.79083 .39462 m
.79123 .3943 L
s
1 .022 0 r
.85254 .42255 m
.85267 .42266 L
s
1 .073 0 r
.79039 .39427 m
.79083 .39462 L
s
1 .303 0 r
.64612 .44862 m
.64452 .4497 L
s
.64783 .4503 m
.64612 .44862 L
s
1 .07 0 r
.51245 .64864 m
.51248 .64876 L
s
.51249 .64808 m
.51245 .64864 L
s
.51305 .64845 m
.51245 .64864 L
s
1 .09 0 r
.57486 .67752 m
.57473 .67682 L
s
1 .104 0 r
.39253 .76167 m
.39279 .76194 L
s
.39283 .76089 m
.39253 .76167 L
s
.39356 .76163 m
.39253 .76167 L
s
1 .07 0 r
.51252 .6482 m
.51249 .64808 L
s
.51249 .64808 m
.51305 .64845 L
s
1 .104 0 r
.3931 .76116 m
.39283 .76089 L
s
.39283 .76089 m
.39356 .76163 L
s
.39356 .76163 m
.39279 .76194 L
s
.3931 .76116 m
.39356 .76163 L
s
.38984 .76056 m
.39356 .76163 L
s
1 .136 0 r
.46366 .50706 m
.46321 .50807 L
s
.46232 .50707 m
.46321 .50807 L
s
1 .07 0 r
.51305 .64845 m
.51248 .64876 L
s
.51252 .6482 m
.51305 .64845 L
s
.51024 .64831 m
.51305 .64845 L
s
1 .136 0 r
.46232 .50707 m
.46366 .50706 L
s
1 0 0 r
.28465 .59177 m
.28465 .59177 L
s
.28465 .59177 m
.28465 .59177 L
s
.28465 .59177 m
.28465 .59177 L
s
.28465 .59177 m
.28465 .59177 L
s
.28464 .59176 m
.28465 .59177 L
s
.28465 .59177 m
.28465 .59177 L
s
.28465 .59177 m
.28465 .59177 L
s
.28465 .59177 m
.28465 .59177 L
s
.28465 .59177 m
.28465 .59177 L
s
1 .035 0 r
.73583 .70485 m
.73687 .70432 L
s
1 0 0 r
.79431 .56349 m
.79431 .56349 L
s
1 .09 0 r
.34313 .4504 m
.34201 .44827 L
s
1 .07 0 r
.51248 .64876 m
.51252 .6482 L
s
1 .303 0 r
.64623 .45139 m
.64783 .4503 L
s
1 .825 0 r
.62831 .42202 m
.62844 .42166 L
s
.6282 .41417 m
.62831 .42202 L
s
.62831 .42202 m
.62356 .41801 L
s
.63309 .41781 m
.62831 .42202 L
s
.62838 .40129 m
.62831 .42202 L
s
1 .104 0 r
.39279 .76194 m
.3931 .76116 L
s
1 .035 0 r
.73665 .70425 m
.7368 .7045 L
s
.73652 .70435 m
.73665 .70425 L
s
.73665 .70425 m
.73687 .70432 L
s
.7368 .7045 m
.73667 .7046 L
s
.73687 .70432 m
.7368 .7045 L
s
.542 1 0 r
.41689 .36247 m
.42265 .37555 L
s
.717 1 0 r
.42533 .38414 m
.43154 .38769 L
s
.41876 .39211 m
.42533 .38414 L
s
.42533 .38414 m
.41988 .38417 L
s
1 .459 0 r
.38062 .38998 m
.38311 .39176 L
s
.37794 .39234 m
.38062 .38998 L
s
.38062 .38998 m
.3797 .38976 L
s
1 .035 0 r
.73667 .7046 m
.73652 .70435 L
s
.73652 .70435 m
.73687 .70432 L
s
.73687 .70432 m
.73667 .7046 L
s
1 .575 0 r
.67059 .36083 m
.66742 .36376 L
s
.67401 .36302 m
.67059 .36083 L
s
1 .303 0 r
.64452 .4497 m
.64623 .45139 L
s
1 .024 0 r
.44899 .61938 m
.44904 .61943 L
s
.44905 .6192 m
.44899 .61938 L
s
.44922 .61936 m
.44899 .61938 L
s
.44911 .61925 m
.44905 .6192 L
s
.44905 .6192 m
.44922 .61936 L
s
.44922 .61936 m
.44904 .61943 L
s
.44911 .61925 m
.44922 .61936 L
s
.44836 .61912 m
.44922 .61936 L
s
.44904 .61943 m
.44911 .61925 L
s
1 .133 0 r
.40286 .47681 m
.40349 .4772 L
s
.40218 .47764 m
.40286 .47681 L
s
.40286 .47681 m
.40228 .47686 L
s
0 1 .566 r
.60484 .45937 m
.59193 .47543 L
s
.61841 .46696 m
.60484 .45937 L
s
1 .001 0 r
.73259 .53427 m
.73259 .53427 L
s
.73259 .53426 m
.73259 .53427 L
s
.73259 .53427 m
.73259 .53427 L
s
.73259 .53427 m
.73259 .53427 L
s
.7326 .53425 m
.73259 .53427 L
s
.73259 .53426 m
.73259 .53427 L
s
.73259 .53427 m
.73259 .53426 L
s
.73259 .53427 m
.73259 .53427 L
s
.73259 .53427 m
.73259 .53427 L
s
1 0 0 r
.95832 .59083 m
.95833 .59083 L
s
1 .043 0 r
.67408 .67569 m
.67546 .67511 L
s
.787 1 0 r
.50688 .47768 m
.45966 .4693 L
s
1 0 0 r
.22264 .56254 m
.22264 .56254 L
s
1 .062 0 r
.28116 .4211 m
.28067 .41957 L
s
1 0 0 r
.95832 .59083 m
.95833 .59083 L
s
.95832 .59083 m
.95832 .59083 L
s
.95832 .59083 m
.95833 .59083 L
s
.95833 .59083 m
.95833 .59083 L
s
.95833 .59083 m
.95833 .59083 L
s
.95833 .59083 m
.95832 .59083 L
s
.95832 .59083 m
.95833 .59083 L
s
.95833 .59083 m
.95833 .59083 L
s
1 .133 0 r
.40281 .47804 m
.40218 .47764 L
s
.40218 .47764 m
.40228 .47686 L
s
1 .055 0 r
.3296 .7322 m
.32924 .73232 L
s
.32927 .73177 m
.3296 .7322 L
s
.3296 .7322 m
.32905 .73216 L
s
.32946 .73192 m
.3296 .7322 L
s
.32787 .73142 m
.3296 .7322 L
s
.32927 .73177 m
.32905 .73216 L
s
.32946 .73192 m
.32927 .73177 L
s
.32905 .73216 m
.32924 .73232 L
s
.32924 .73232 m
.32946 .73192 L
s
1 .043 0 r
.67533 .67533 m
.67519 .67544 L
s
.67517 .67502 m
.67533 .67533 L
s
.67546 .67511 m
.67533 .67533 L
s
.67504 .67513 m
.67517 .67502 L
s
.67517 .67502 m
.67546 .67511 L
s
1 .09 0 r
.34226 .44829 m
.34273 .44862 L
s
.34174 .44878 m
.34226 .44829 L
s
.34226 .44829 m
.34201 .44827 L
s
1 .459 0 r
.38042 .39412 m
.37794 .39234 L
s
.37794 .39234 m
.3797 .38976 L
s
1 .133 0 r
.40349 .4772 m
.40281 .47804 L
s
.40228 .47686 m
.40349 .4772 L
s
.787 1 0 r
.576 .46852 m
.5694 .47292 L
s
.58276 .47531 m
.576 .46852 L
s
1 .024 0 r
.67034 .50548 m
.67044 .50549 L
s
.67043 .50527 m
.67034 .50548 L
s
.67034 .50548 m
.67032 .50534 L
s
.67055 .50541 m
.67034 .50548 L
s
.67082 .50498 m
.67034 .50548 L
s
.67043 .50527 m
.67032 .50534 L
s
.67055 .50541 m
.67043 .50527 L
s
.67044 .50549 m
.67055 .50541 L
s
1 .133 0 r
.40228 .47686 m
.40281 .47804 L
s
1 .09 0 r
.34221 .44911 m
.34174 .44878 L
s
.34174 .44878 m
.34201 .44827 L
s
1 .043 0 r
.67519 .67544 m
.67504 .67513 L
s
.67546 .67511 m
.67519 .67544 L
s
1 .024 0 r
.67032 .50534 m
.67044 .50549 L
s
1 .043 0 r
.67504 .67513 m
.67546 .67511 L
s
.542 1 0 r
.62805 .37288 m
.63536 .36383 L
s
.717 1 0 r
.42496 .39569 m
.41876 .39211 L
s
.41876 .39211 m
.41988 .38417 L
s
1 .575 0 r
.66742 .36376 m
.67083 .36596 L
s
1 .09 0 r
.34273 .44862 m
.34221 .44911 L
s
.34201 .44827 m
.34273 .44862 L
s
.34201 .44827 m
.34221 .44911 L
s
1 .168 0 r
.49704 .75976 m
.49717 .76013 L
s
.49718 .75844 m
.49704 .75976 L
s
.49852 .75938 m
.49704 .75976 L
s
1 .002 0 r
.38647 .58993 m
.38646 .58993 L
s
.38646 .58991 m
.38647 .58993 L
s
.38647 .58993 m
.38646 .58992 L
s
.38647 .58992 m
.38647 .58993 L
s
.38642 .58989 m
.38647 .58993 L
s
.38646 .58991 m
.38646 .58992 L
s
.38647 .58992 m
.38646 .58991 L
s
.38646 .58992 m
.38646 .58993 L
s
.38646 .58993 m
.38647 .58992 L
s
1 .014 0 r
.83812 .70311 m
.83848 .70286 L
s
1 0 0 r
.89667 .56159 m
.89667 .56159 L
s
1 .048 0 r
.61227 .6465 m
.61401 .646 L
s
1 .787 0 r
.44497 .44837 m
.42892 .43123 L
s
1 .045 0 r
.21913 .39176 m
.21887 .39062 L
s
1 .459 0 r
.38311 .39176 m
.38042 .39412 L
s
.3797 .38976 m
.38311 .39176 L
s
1 .825 0 r
.6282 .41417 m
.62356 .41801 L
s
.63309 .41781 m
.6282 .41417 L
s
1 .062 0 r
.28079 .4196 m
.28112 .41985 L
s
.28042 .4199 m
.28079 .4196 L
s
.28079 .4196 m
.28067 .41957 L
s
1 .168 0 r
.49731 .7588 m
.49718 .75844 L
s
.49718 .75844 m
.49852 .75938 L
s
1 .062 0 r
.28075 .42016 m
.28042 .4199 L
s
.28042 .4199 m
.28067 .41957 L
s
1 .014 0 r
.8384 .70284 m
.83847 .70293 L
s
.83834 .70289 m
.8384 .70284 L
s
.8384 .70284 m
.83848 .70286 L
s
1 .062 0 r
.28112 .41985 m
.28075 .42016 L
s
.28067 .41957 m
.28112 .41985 L
s
1 .014 0 r
.83847 .70293 m
.83841 .70298 L
s
.83848 .70286 m
.83847 .70293 L
s
.83841 .70298 m
.83834 .70289 L
s
.83834 .70289 m
.83848 .70286 L
s
.83848 .70286 m
.83841 .70298 L
s
1 .048 0 r
.61379 .64624 m
.61367 .64634 L
s
.61365 .64587 m
.61379 .64624 L
s
.61401 .646 m
.61379 .64624 L
s
.61354 .64597 m
.61365 .64587 L
s
.61365 .64587 m
.61401 .646 L
s
1 .062 0 r
.28067 .41957 m
.28075 .42016 L
s
1 .168 0 r
.49852 .75938 m
.49717 .76013 L
s
.49731 .7588 m
.49852 .75938 L
s
.4918 .75888 m
.49852 .75938 L
s
1 .575 0 r
.67083 .36596 m
.67401 .36302 L
s
1 .066 0 r
.83159 .36302 m
.83165 .36297 L
s
.8316 .36238 m
.83159 .36302 L
s
.83159 .36302 m
.83124 .36269 L
s
.832 .36267 m
.83159 .36302 L
s
.83178 .36133 m
.83159 .36302 L
s
1 .023 0 r
.8934 .39131 m
.89344 .39129 L
s
.89341 .39108 m
.8934 .39131 L
s
.8934 .39131 m
.89329 .39119 L
s
.89356 .39119 m
.8934 .39131 L
s
.89354 .39071 m
.8934 .39131 L
s
.89341 .39108 m
.89329 .39119 L
s
.89356 .39119 m
.89341 .39108 L
s
.89344 .39129 m
.89356 .39119 L
s
.26645 .70264 m
.26631 .70267 L
s
.26633 .70244 m
.26645 .70264 L
s
.26645 .70264 m
.26622 .7026 L
s
.26642 .70252 m
.26645 .70264 L
s
.26582 .70224 m
.26645 .70264 L
s
.89329 .39119 m
.89344 .39129 L
s
1 .048 0 r
.61401 .646 m
.61367 .64634 L
s
.61354 .64597 m
.61401 .646 L
s
.61367 .64634 m
.61354 .64597 L
s
1 .066 0 r
.8316 .36238 m
.83124 .36269 L
s
.832 .36267 m
.8316 .36238 L
s
1 .023 0 r
.26633 .70244 m
.26622 .7026 L
s
.26642 .70252 m
.26633 .70244 L
s
.26622 .7026 m
.26631 .70267 L
s
1 .121 0 r
.43315 .73087 m
.43341 .73115 L
s
.43344 .72994 m
.43315 .73087 L
s
.43433 .73075 m
.43315 .73087 L
s
1 .023 0 r
.26631 .70267 m
.26642 .70252 L
s
1 .121 0 r
.4337 .73022 m
.43344 .72994 L
s
.43344 .72994 m
.43433 .73075 L
s
1 .066 0 r
.83124 .36269 m
.83165 .36297 L
s
.83165 .36297 m
.832 .36267 L
s
1 .045 0 r
.21894 .39064 m
.21918 .39084 L
s
.21867 .39085 m
.21894 .39064 L
s
.21894 .39064 m
.21887 .39062 L
s
1 .121 0 r
.43433 .73075 m
.43341 .73115 L
s
.4337 .73022 m
.43433 .73075 L
s
.42981 .72971 m
.43433 .73075 L
s
.285 1 0 r
.44051 .44757 m
.4537 .45784 L
s
.44051 .44757 m
.45647 .4442 L
s
1 .045 0 r
.21891 .39105 m
.21867 .39085 L
s
.21867 .39085 m
.21887 .39062 L
s
.21918 .39084 m
.21891 .39105 L
s
.21887 .39062 m
.21918 .39084 L
s
1 .459 0 r
.3797 .38976 m
.38042 .39412 L
s
1 .168 0 r
.49717 .76013 m
.49731 .7588 L
s
1 .045 0 r
.21887 .39062 m
.21891 .39105 L
s
1 0 0 r
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
1 .039 0 r
.55165 .61728 m
.55162 .61735 L
s
.55161 .61697 m
.55165 .61728 L
s
.55192 .61713 m
.55165 .61728 L
s
1 .015 0 r
.77636 .67392 m
.77676 .67365 L
s
1 .039 0 r
.55038 .61728 m
.55192 .61713 L
s
1 0 0 r
.32441 .56064 m
.32441 .56064 L
s
1 .336 0 r
.38299 .41903 m
.37997 .41075 L
s
1 .035 0 r
.15702 .36239 m
.15687 .3615 L
s
1 .039 0 r
.55158 .61704 m
.55161 .61697 L
s
.55161 .61697 m
.55192 .61713 L
s
.55192 .61713 m
.55162 .61735 L
s
.55158 .61704 m
.55192 .61713 L
s
1 .015 0 r
.77668 .67363 m
.77675 .67373 L
s
.77662 .67368 m
.77668 .67363 L
s
.77668 .67363 m
.77676 .67365 L
s
.77675 .67373 m
.77669 .67378 L
s
.77676 .67365 m
.77675 .67373 L
s
1 .039 0 r
.55162 .61735 m
.55158 .61704 L
s
0 1 .566 r
.59193 .47543 m
.60543 .48313 L
s
1 .015 0 r
.77669 .67378 m
.77662 .67368 L
s
.77662 .67368 m
.77676 .67365 L
s
.77676 .67365 m
.77669 .67378 L
s
1 .121 0 r
.43341 .73115 m
.4337 .73022 L
s
.787 1 0 r
.57617 .47974 m
.58276 .47531 L
s
1 .229 0 r
.68852 .41851 m
.68885 .41841 L
s
.68874 .41633 m
.68852 .41851 L
s
.68852 .41851 m
.68749 .4173 L
s
.6901 .41745 m
.68852 .41851 L
s
.68988 .41281 m
.68852 .41851 L
s
1 .035 0 r
.15692 .36152 m
.1571 .36168 L
s
.1567 .36167 m
.15692 .36152 L
s
.15692 .36152 m
.15687 .3615 L
s
.787 1 0 r
.46904 .47661 m
.46727 .47501 L
s
.46727 .47501 m
.46924 .46538 L
s
.46727 .47501 m
.45966 .4693 L
s
1 .035 0 r
.1571 .36168 m
.15688 .36183 L
s
.15687 .3615 m
.1571 .36168 L
s
.15688 .36183 m
.1567 .36167 L
s
.1567 .36167 m
.15687 .3615 L
s
.15687 .3615 m
.15688 .36183 L
s
1 .004 0 r
.77309 .50311 m
.77311 .50311 L
s
.77311 .50307 m
.77309 .50311 L
s
.77309 .50311 m
.77308 .50308 L
s
.77313 .50309 m
.77309 .50311 L
s
.77316 .50301 m
.77309 .50311 L
s
.77311 .50307 m
.77308 .50308 L
s
.77313 .50309 m
.77311 .50307 L
s
.77311 .50311 m
.77313 .50309 L
s
1 .008 0 r
.48867 .58809 m
.48869 .5881 L
s
.48869 .58802 m
.48867 .58809 L
s
.48875 .58808 m
.48867 .58809 L
s
1 .004 0 r
.77308 .50308 m
.77311 .50311 L
s
1 .008 0 r
.4887 .58804 m
.48869 .58802 L
s
.48869 .58802 m
.48875 .58808 L
s
.48875 .58808 m
.48869 .5881 L
s
.4887 .58804 m
.48875 .58808 L
s
.48843 .58802 m
.48875 .58808 L
s
.48869 .5881 m
.4887 .58804 L
s
1 .825 0 r
.62356 .41801 m
.62844 .42166 L
s
1 .016 0 r
.71454 .6447 m
.71498 .64443 L
s
1 .172 0 r
.32094 .38966 m
.32023 .38529 L
s
1 0 0 r
.26232 .53135 m
.26232 .53134 L
s
.26232 .53134 m
.26232 .53134 L
s
.26231 .53134 m
.26232 .53134 L
s
.26232 .53134 m
.26232 .53134 L
s
.26232 .53134 m
.26231 .53134 L
s
.26231 .53134 m
.26232 .53134 L
s
.26232 .53134 m
.26232 .53134 L
s
.26232 .53134 m
.26232 .53134 L
s
.26232 .53134 m
.26232 .53134 L
s
1 .229 0 r
.68874 .41633 m
.68749 .4173 L
s
.6901 .41745 m
.68874 .41633 L
s
1 .062 0 r
.36975 .70133 m
.36934 .70147 L
s
.36937 .70086 m
.36975 .70133 L
s
.36975 .70133 m
.36914 .7013 L
s
.36957 .70102 m
.36975 .70133 L
s
.36775 .7005 m
.36975 .70133 L
s
.36914 .7013 m
.36934 .70147 L
s
.36937 .70086 m
.36914 .7013 L
s
.36957 .70102 m
.36937 .70086 L
s
1 .039 0 r
.71075 .47457 m
.71087 .47457 L
s
.71085 .47421 m
.71075 .47457 L
s
.71075 .47457 m
.71065 .47435 L
s
.71107 .47443 m
.71075 .47457 L
s
.71129 .47367 m
.71075 .47457 L
s
1 .825 0 r
.62844 .42166 m
.63309 .41781 L
s
1 .039 0 r
.71085 .47421 m
.71065 .47435 L
s
.71107 .47443 m
.71085 .47421 L
s
1 .016 0 r
.71489 .6444 m
.71496 .64451 L
s
.71482 .64445 m
.71489 .6444 L
s
.71489 .6444 m
.71498 .64443 L
s
.71496 .64451 m
.7149 .64456 L
s
.71498 .64443 m
.71496 .64451 L
s
1 .039 0 r
.71087 .47457 m
.71107 .47443 L
s
1 .016 0 r
.7149 .64456 m
.71482 .64445 L
s
.71482 .64445 m
.71498 .64443 L
s
.71498 .64443 m
.7149 .64456 L
s
1 .039 0 r
.71065 .47435 m
.71087 .47457 L
s
1 .062 0 r
.36934 .70147 m
.36957 .70102 L
s
1 .229 0 r
.68885 .41841 m
.6901 .41745 L
s
.787 1 0 r
.46924 .46538 m
.47102 .46694 L
s
.46924 .46538 m
.45966 .4693 L
s
1 .229 0 r
.68749 .4173 m
.68885 .41841 L
s
.425 1 0 r
.50216 .50492 m
.50661 .50227 L
s
.50661 .50227 m
.50227 .4902 L
s
.50661 .50227 m
.49106 .50113 L
s
.285 1 0 r
.45647 .4442 m
.4537 .45784 L
s
1 0 0 r
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
1 .006 0 r
.87887 .67214 m
.87901 .67203 L
s
1 .158 0 r
.59398 .7572 m
.60015 .75625 L
s
1 .014 0 r
.65264 .61544 m
.65308 .61522 L
s
1 0 0 r
.4264 .55873 m
.4264 .55873 L
s
0 .434 1 r
.48506 .41696 m
.41148 .33508 L
s
1 .002 0 r
.20017 .50202 m
.20015 .50199 L
s
1 .104 0 r
.25882 .36026 m
.25862 .35757 L
s
1 .002 0 r
.20015 .50199 m
.20016 .50199 L
s
.20014 .502 m
.20015 .50199 L
s
.20015 .50199 m
.20015 .50199 L
s
.20015 .502 m
.20014 .502 L
s
.20014 .502 m
.20015 .50199 L
s
.20016 .50199 m
.20015 .502 L
s
.20015 .50199 m
.20016 .50199 L
s
.20015 .50199 m
.20015 .502 L
s
1 .006 0 r
.87898 .67202 m
.87901 .67206 L
s
.87895 .67204 m
.87898 .67202 L
s
.87898 .67202 m
.87901 .67203 L
s
.87901 .67206 m
.87898 .67208 L
s
.87901 .67203 m
.87901 .67206 L
s
.87898 .67208 m
.87895 .67204 L
s
.87895 .67204 m
.87901 .67203 L
s
.87901 .67203 m
.87898 .67208 L
s
1 .014 0 r
.65304 .6153 m
.65299 .61533 L
s
.65299 .6152 m
.65304 .6153 L
s
.65308 .61522 m
.65304 .6153 L
s
.65294 .61523 m
.65299 .6152 L
s
.65299 .6152 m
.65308 .61522 L
s
.65299 .61533 m
.65294 .61523 L
s
.65308 .61522 m
.65299 .61533 L
s
.65294 .61523 m
.65308 .61522 L
s
1 .158 0 r
.59916 .75688 m
.59893 .75724 L
s
.5989 .75565 m
.59916 .75688 L
s
.60015 .75625 m
.59916 .75688 L
s
.59867 .756 m
.5989 .75565 L
s
.5989 .75565 m
.60015 .75625 L
s
1 .172 0 r
.53758 .72841 m
.53756 .72876 L
s
.53755 .72704 m
.53758 .72841 L
s
.53895 .72787 m
.53758 .72841 L
s
.425 1 0 r
.50227 .4902 m
.49779 .4928 L
s
.50227 .4902 m
.49106 .50113 L
s
1 .022 0 r
.30623 .67163 m
.3061 .67166 L
s
.30611 .67145 m
.30623 .67163 L
s
.30623 .67163 m
.30601 .6716 L
s
.3062 .67151 m
.30623 .67163 L
s
.30562 .67125 m
.30623 .67163 L
s
.30611 .67145 m
.30601 .6716 L
s
.3062 .67151 m
.30611 .67145 L
s
.30601 .6716 m
.3061 .67166 L
s
1 .172 0 r
.53753 .72739 m
.53755 .72704 L
s
.53755 .72704 m
.53895 .72787 L
s
1 .022 0 r
.3061 .67166 m
.3062 .67151 L
s
.787 1 0 r
.5694 .47292 m
.57617 .47974 L
s
1 .137 0 r
.47398 .6998 m
.47419 .70009 L
s
.47421 .69873 m
.47398 .6998 L
s
.47527 .69957 m
.47398 .6998 L
s
.717 1 0 r
.43154 .38769 m
.42496 .39569 L
s
.41988 .38417 m
.43154 .38769 L
s
1 .137 0 r
.47441 .69901 m
.47421 .69873 L
s
.47421 .69873 m
.47527 .69957 L
s
.425 1 0 r
.49106 .50113 m
.50216 .50492 L
s
.49106 .50113 m
.49779 .4928 L
s
.5473 .48306 m
.49106 .50113 L
s
1 .001 0 r
.87571 .50106 m
.87571 .50106 L
s
.87571 .50105 m
.87571 .50106 L
s
.87571 .50106 m
.8757 .50106 L
s
.87572 .50106 m
.87571 .50106 L
s
.87572 .50104 m
.87571 .50106 L
s
.87571 .50105 m
.8757 .50106 L
s
.87572 .50106 m
.87571 .50105 L
s
.87571 .50106 m
.87572 .50106 L
s
.8757 .50106 m
.87571 .50106 L
s
1 .005 0 r
.81704 .64288 m
.81715 .64278 L
s
1 .172 0 r
.53198 .72799 m
.53895 .72787 L
s
1 .007 0 r
.59067 .58614 m
.59091 .58607 L
s
1 .002 0 r
.3643 .52941 m
.36426 .52936 L
s
.973 1 0 r
.42299 .38756 m
.42014 .36111 L
s
1 .002 0 r
.36427 .52936 m
.36428 .52937 L
s
.36426 .52937 m
.36427 .52936 L
s
.36427 .52936 m
.36426 .52936 L
s
.36427 .52938 m
.36426 .52937 L
s
.36426 .52937 m
.36426 .52936 L
s
.36428 .52937 m
.36427 .52938 L
s
.36426 .52936 m
.36428 .52937 L
s
1 .007 0 r
.59088 .58611 m
.59086 .58612 L
s
.59086 .58606 m
.59088 .58611 L
s
.59091 .58607 m
.59088 .58611 L
s
1 .002 0 r
.36426 .52936 m
.36427 .52938 L
s
1 .007 0 r
.59084 .58607 m
.59086 .58606 L
s
.59086 .58606 m
.59091 .58607 L
s
1 .137 0 r
.47527 .69957 m
.47419 .70009 L
s
.47441 .69901 m
.47527 .69957 L
s
.46991 .69875 m
.47527 .69957 L
s
1 .007 0 r
.59091 .58607 m
.59086 .58612 L
s
.59084 .58607 m
.59091 .58607 L
s
1 .005 0 r
.81713 .64278 m
.81715 .64281 L
s
.8171 .64279 m
.81713 .64278 L
s
.81713 .64278 m
.81715 .64278 L
s
1 .007 0 r
.59086 .58612 m
.59084 .58607 L
s
1 .005 0 r
.81715 .64281 m
.81713 .64283 L
s
.81715 .64278 m
.81715 .64281 L
s
.81713 .64283 m
.8171 .64279 L
s
.8171 .64279 m
.81715 .64278 L
s
.81715 .64278 m
.81713 .64283 L
s
1 .158 0 r
.60015 .75625 m
.59893 .75724 L
s
.59867 .756 m
.60015 .75625 L
s
1 .172 0 r
.53895 .72787 m
.53756 .72876 L
s
.53753 .72739 m
.53895 .72787 L
s
1 .158 0 r
.59893 .75724 m
.59867 .756 L
s
1 .172 0 r
.53756 .72876 m
.53753 .72739 L
s
1 .137 0 r
.47419 .70009 m
.47441 .69901 L
s
1 .104 0 r
.2587 .35765 m
.25927 .35813 L
s
.25806 .35809 m
.2587 .35765 L
s
.2587 .35765 m
.25862 .35757 L
s
.717 1 0 r
.63053 .38673 m
.62608 .38677 L
s
.62571 .3752 m
.63053 .38673 L
s
.63053 .38673 m
.61924 .38321 L
s
.63257 .37874 m
.63053 .38673 L
s
.60707 .35759 m
.63053 .38673 L
s
1 .008 0 r
.81376 .47186 m
.81378 .47186 L
s
.81377 .47178 m
.81376 .47186 L
s
.81376 .47186 m
.81373 .47181 L
s
.81382 .47182 m
.81376 .47186 L
s
.81385 .47166 m
.81376 .47186 L
s
.81377 .47178 m
.81373 .47181 L
s
.81382 .47182 m
.81377 .47178 L
s
.81378 .47186 m
.81382 .47182 L
s
.81373 .47181 m
.81378 .47186 L
s
1 .006 0 r
.24355 .64209 m
.24352 .64209 L
s
.24352 .64204 m
.24355 .64209 L
s
.24355 .64209 m
.24349 .64207 L
s
.24355 .64206 m
.24355 .64209 L
s
.24342 .64198 m
.24355 .64209 L
s
.24352 .64204 m
.24349 .64207 L
s
.24355 .64206 m
.24352 .64204 L
s
1 .172 0 r
.32042 .38539 m
.32136 .38615 L
s
.31938 .38619 m
.32042 .38539 L
s
.32042 .38539 m
.32023 .38529 L
s
1 .006 0 r
.24349 .64207 m
.24352 .64209 L
s
.24352 .64209 m
.24355 .64206 L
s
1 .046 0 r
.75149 .44337 m
.75159 .44335 L
s
.75156 .44294 m
.75149 .44337 L
s
.75149 .44337 m
.75131 .44312 L
s
.75183 .44317 m
.75149 .44337 L
s
.7519 .44225 m
.75149 .44337 L
s
1 .104 0 r
.25927 .35813 m
.25862 .35858 L
s
.25862 .35757 m
.25927 .35813 L
s
1 .004 0 r
.75513 .61359 m
.75521 .61352 L
s
1 .091 0 r
.69641 .75552 m
.69944 .75438 L
s
1 0 0 r
.52863 .55682 m
.52863 .55682 L
s
1 .006 0 r
.30214 .50005 m
.30204 .49991 L
s
1 .417 0 r
.36086 .35812 m
.36146 .34732 L
s
.717 1 0 r
.41988 .38417 m
.42496 .39569 L
s
1 .046 0 r
.75156 .44294 m
.75131 .44312 L
s
.75183 .44317 m
.75156 .44294 L
s
1 .104 0 r
.25862 .35858 m
.25806 .35809 L
s
.25806 .35809 m
.25862 .35757 L
s
1 .004 0 r
.75519 .61352 m
.75521 .61354 L
s
.75518 .61353 m
.75519 .61352 L
s
.75519 .61352 m
.75521 .61352 L
s
.75521 .61354 m
.7552 .61355 L
s
.75521 .61352 m
.75521 .61354 L
s
1 .068 0 r
.4094 .67031 m
.4096 .67047 L
s
.40963 .6698 m
.4094 .67031 L
s
.41008 .6703 m
.4094 .67031 L
s
.41008 .6703 m
.4096 .67047 L
s
.40963 .6698 m
.41008 .6703 L
s
.40983 .66997 m
.41008 .6703 L
s
.40777 .66947 m
.41008 .6703 L
s
1 .004 0 r
.7552 .61355 m
.75518 .61353 L
s
.75518 .61353 m
.75521 .61352 L
s
.75521 .61352 m
.7552 .61355 L
s
1 .068 0 r
.40983 .66997 m
.40963 .6698 L
s
1 .006 0 r
.30206 .4999 m
.3021 .49993 L
s
.30203 .49994 m
.30206 .4999 L
s
.30206 .4999 m
.30204 .49991 L
s
1 .046 0 r
.75159 .44335 m
.75183 .44317 L
s
1 .006 0 r
.30206 .49996 m
.30203 .49994 L
s
.30203 .49994 m
.30204 .49991 L
s
.3021 .49993 m
.30206 .49996 L
s
.30204 .49991 m
.3021 .49993 L
s
.30204 .49991 m
.30206 .49996 L
s
1 .046 0 r
.75131 .44312 m
.75159 .44335 L
s
1 .104 0 r
.25862 .35757 m
.25862 .35858 L
s
1 .172 0 r
.32032 .38694 m
.31938 .38619 L
s
.31938 .38619 m
.32023 .38529 L
s
.939 1 0 r
.42837 .40696 m
.43353 .40996 L
s
.42292 .41359 m
.42837 .40696 L
s
.42837 .40696 m
.42387 .40707 L
s
1 .172 0 r
.32136 .38615 m
.32032 .38694 L
s
.32023 .38529 m
.32136 .38615 L
s
1 .068 0 r
.4096 .67047 m
.40983 .66997 L
s
1 .172 0 r
.32023 .38529 m
.32032 .38694 L
s
1 .091 0 r
.69913 .75482 m
.69886 .75507 L
s
.69881 .75415 m
.69913 .75482 L
s
.69944 .75438 m
.69913 .75482 L
s
.69853 .7544 m
.69881 .75415 L
s
.69881 .75415 m
.69944 .75438 L
s
1 .172 0 r
.73029 .38561 m
.73039 .38551 L
s
.73029 .38396 m
.73029 .38561 L
s
.73029 .38561 m
.72934 .38475 L
s
.73134 .38471 m
.73029 .38561 L
s
.73055 .38122 m
.73029 .38561 L
s
1 .002 0 r
.91977 .64107 m
.91981 .64103 L
s
1 .121 0 r
.63439 .72627 m
.6388 .72507 L
s
1 .001 0 r
.69315 .58426 m
.69318 .58424 L
s
1 .021 0 r
.46652 .52746 m
.46582 .52718 L
s
1 .009 0 r
.2399 .47066 m
.2398 .47045 L
s
1 .001 0 r
.69317 .58424 m
.69318 .58424 L
s
.69317 .58424 m
.69317 .58424 L
s
.69317 .58424 m
.69318 .58424 L
s
.69318 .58424 m
.69317 .58425 L
s
.69318 .58424 m
.69318 .58424 L
s
.69317 .58425 m
.69317 .58424 L
s
.69317 .58424 m
.69318 .58424 L
s
.69318 .58424 m
.69317 .58425 L
s
1 .002 0 r
.9198 .64102 m
.91981 .64104 L
s
.91979 .64103 m
.9198 .64102 L
s
.9198 .64102 m
.91981 .64103 L
s
.91981 .64104 m
.9198 .64104 L
s
.91981 .64103 m
.91981 .64104 L
s
.9198 .64104 m
.91979 .64103 L
s
.91979 .64103 m
.91981 .64103 L
s
.91981 .64103 m
.9198 .64104 L
s
1 .009 0 r
.23982 .47045 m
.23987 .47048 L
s
.23977 .47049 m
.23982 .47045 L
s
.23982 .47045 m
.2398 .47045 L
s
.23982 .47053 m
.23977 .47049 L
s
.23977 .47049 m
.2398 .47045 L
s
.23987 .47048 m
.23982 .47053 L
s
.2398 .47045 m
.23987 .47048 L
s
1 .021 0 r
.46596 .52733 m
.4659 .52729 L
s
.4659 .52729 m
.46597 .52714 L
s
.4659 .52729 m
.46582 .52718 L
s
.46597 .52714 m
.46603 .52718 L
s
.46597 .52714 m
.46582 .52718 L
s
1 .009 0 r
.2398 .47045 m
.23982 .47053 L
s
1 .172 0 r
.73029 .38396 m
.72934 .38475 L
s
.73134 .38471 m
.73029 .38396 L
s
.939 1 0 r
.42807 .41661 m
.42292 .41359 L
s
.42292 .41359 m
.42387 .40707 L
s
1 .021 0 r
.46603 .52718 m
.46596 .52733 L
s
.46582 .52718 m
.46596 .52733 L
s
.46582 .52718 m
.46603 .52718 L
s
1 .091 0 r
.69886 .75507 m
.69853 .7544 L
s
.69944 .75438 m
.69886 .75507 L
s
.69853 .7544 m
.69944 .75438 L
s
1 .336 0 r
.38065 .41088 m
.38248 .4122 L
s
.37868 .41262 m
.38065 .41088 L
s
.38065 .41088 m
.37997 .41075 L
s
1 .02 0 r
.3461 .64049 m
.34598 .64052 L
s
.34599 .64033 m
.3461 .64049 L
s
.3461 .64049 m
.34591 .64046 L
s
.34607 .64038 m
.3461 .64049 L
s
.34555 .64016 m
.3461 .64049 L
s
1 .172 0 r
.72934 .38475 m
.73039 .38551 L
s
1 .02 0 r
.34599 .64033 m
.34591 .64046 L
s
.34607 .64038 m
.34599 .64033 L
s
.34591 .64046 m
.34598 .64052 L
s
1 .172 0 r
.73039 .38551 m
.73134 .38471 L
s
1 .121 0 r
.63823 .72563 m
.63794 .72592 L
s
.6379 .7247 m
.63823 .72563 L
s
.6388 .72507 m
.63823 .72563 L
s
1 .02 0 r
.34598 .64052 m
.34607 .64038 L
s
1 .121 0 r
.63761 .72499 m
.6379 .7247 L
s
.6379 .7247 m
.6388 .72507 L
s
1 .003 0 r
.91661 .46971 m
.91662 .46971 L
s
.91661 .46969 m
.91661 .46971 L
s
.91661 .46971 m
.9166 .4697 L
s
.91663 .4697 m
.91661 .46971 L
s
.91664 .46965 m
.91661 .46971 L
s
.91661 .46969 m
.9166 .4697 L
s
.91663 .4697 m
.91661 .46969 L
s
.91662 .46971 m
.91663 .4697 L
s
.9166 .4697 m
.91662 .46971 L
s
.717 1 0 r
.62571 .3752 m
.61924 .38321 L
s
.63257 .37874 m
.62571 .3752 L
s
1 .043 0 r
.79906 .75383 m
.80026 .75315 L
s
1 .001 0 r
.85785 .61174 m
.85787 .61171 L
s
1 .151 0 r
.57231 .69699 m
.57824 .6962 L
s
1 0 0 r
.63109 .5549 m
.63109 .5549 L
s
1 .047 0 r
.40434 .49807 m
.40336 .49708 L
s
0 1 .511 r
.46313 .35598 m
.49098 .29153 L
s
1 .01 0 r
.17759 .44123 m
.1775 .44099 L
s
1 .001 0 r
.85787 .61171 m
.85787 .61172 L
s
.85786 .61172 m
.85787 .61171 L
s
.85787 .61171 m
.85787 .61171 L
s
.85787 .61172 m
.85787 .61172 L
s
.85787 .61171 m
.85787 .61172 L
s
.85787 .61172 m
.85786 .61172 L
s
.85786 .61172 m
.85787 .61171 L
s
.85787 .61171 m
.85787 .61172 L
s
1 .01 0 r
.17753 .441 m
.17758 .44104 L
s
.17747 .44104 m
.17753 .441 L
s
.17753 .441 m
.1775 .44099 L
s
.17752 .44109 m
.17747 .44104 L
s
.17747 .44104 m
.1775 .44099 L
s
1 .336 0 r
.38051 .41394 m
.37868 .41262 L
s
.37868 .41262 m
.37997 .41075 L
s
1 .01 0 r
.17758 .44104 m
.17752 .44109 L
s
.1775 .44099 m
.17758 .44104 L
s
.1775 .44099 m
.17752 .44109 L
s
1 .151 0 r
.57726 .6968 m
.57707 .6971 L
s
.57704 .69561 m
.57726 .6968 L
s
.57824 .6962 m
.57726 .6968 L
s
1 .141 0 r
.51463 .66834 m
.5147 .6686 L
s
.51471 .66721 m
.51463 .66834 L
s
.51585 .66796 m
.51463 .66834 L
s
.787 1 0 r
.45966 .4693 m
.46904 .47661 L
s
.45966 .4693 m
.47102 .46694 L
s
1 .151 0 r
.57685 .69592 m
.57704 .69561 L
s
.57704 .69561 m
.57824 .6962 L
s
1 .121 0 r
.6388 .72507 m
.63794 .72592 L
s
.63761 .72499 m
.6388 .72507 L
s
1 .141 0 r
.51478 .66747 m
.51471 .66721 L
s
.51471 .66721 m
.51585 .66796 L
s
1 .121 0 r
.63794 .72592 m
.63761 .72499 L
s
1 .043 0 r
.8 .75307 m
.8002 .75336 L
s
.79984 .75321 m
.8 .75307 L
s
.8 .75307 m
.80026 .75315 L
s
.8002 .75336 m
.80004 .7535 L
s
.80026 .75315 m
.8002 .75336 L
s
1 .336 0 r
.38248 .4122 m
.38051 .41394 L
s
.37997 .41075 m
.38248 .4122 L
s
1 .032 0 r
.56806 .52594 m
.56814 .52589 L
s
.56814 .52589 m
.56806 .52564 L
s
.56814 .52589 m
.56783 .52586 L
s
.56806 .52564 m
.56797 .5257 L
s
.56806 .52564 m
.56783 .52586 L
s
.56783 .52586 m
.56806 .52594 L
s
.56783 .52586 m
.56797 .5257 L
s
.56897 .52551 m
.56783 .52586 L
s
1 .047 0 r
.40357 .49706 m
.40379 .4972 L
s
.40333 .49735 m
.40357 .49706 L
s
.40357 .49706 m
.40336 .49708 L
s
1 .141 0 r
.51585 .66796 m
.5147 .6686 L
s
.51478 .66747 m
.51585 .66796 L
s
.51015 .66768 m
.51585 .66796 L
s
1 .012 0 r
.85458 .4405 m
.85461 .44049 L
s
.85459 .44038 m
.85458 .4405 L
s
.85458 .4405 m
.85453 .44043 L
s
.85467 .44044 m
.85458 .4405 L
s
.85468 .4402 m
.85458 .4405 L
s
1 .047 0 r
.40355 .49749 m
.40333 .49735 L
s
.40333 .49735 m
.40336 .49708 L
s
1 .043 0 r
.80004 .7535 m
.79984 .75321 L
s
.79984 .75321 m
.80026 .75315 L
s
1 .012 0 r
.85459 .44038 m
.85453 .44043 L
s
.85467 .44044 m
.85459 .44038 L
s
1 .043 0 r
.80026 .75315 m
.80004 .7535 L
s
1 .012 0 r
.85461 .44049 m
.85467 .44044 L
s
.85453 .44043 m
.85461 .44049 L
s
1 .032 0 r
.56797 .5257 m
.56806 .52594 L
s
1 .047 0 r
.79239 .4119 m
.79246 .41188 L
s
.79243 .41146 m
.79239 .4119 L
s
.79239 .4119 m
.79217 .41166 L
s
.79271 .41168 m
.79239 .4119 L
s
.79265 .41073 m
.79239 .4119 L
s
.40379 .4972 m
.40355 .49749 L
s
.40336 .49708 m
.40379 .4972 L
s
1 .151 0 r
.57824 .6962 m
.57707 .6971 L
s
.57685 .69592 m
.57824 .6962 L
s
1 .047 0 r
.40336 .49708 m
.40355 .49749 L
s
1 .003 0 r
.28334 .61088 m
.28332 .61088 L
s
.28333 .61085 m
.28334 .61088 L
s
.28334 .61088 m
.28331 .61087 L
s
.28334 .61086 m
.28334 .61088 L
s
.28327 .61081 m
.28334 .61088 L
s
.28333 .61085 m
.28331 .61087 L
s
.28334 .61086 m
.28333 .61085 L
s
.28331 .61087 m
.28332 .61088 L
s
.28332 .61088 m
.28334 .61086 L
s
1 .047 0 r
.79243 .41146 m
.79217 .41166 L
s
.79271 .41168 m
.79243 .41146 L
s
1 .055 0 r
.73703 .72455 m
.73869 .72371 L
s
1 0 0 r
.79586 .58238 m
.79586 .58237 L
s
1 .043 0 r
.34209 .46864 m
.34155 .46762 L
s
1 0 0 r
.79586 .58237 m
.79586 .58237 L
s
.79586 .58237 m
.79586 .58237 L
s
.79586 .58237 m
.79586 .58237 L
s
.79586 .58237 m
.79586 .58237 L
s
.79586 .58237 m
.79586 .58237 L
s
.79586 .58237 m
.79586 .58237 L
s
.79586 .58237 m
.79586 .58237 L
s
.79586 .58237 m
.79586 .58237 L
s
1 .047 0 r
.79246 .41188 m
.79271 .41168 L
s
1 .151 0 r
.57707 .6971 m
.57685 .69592 L
s
1 .047 0 r
.79217 .41166 m
.79246 .41188 L
s
1 .141 0 r
.5147 .6686 m
.51478 .66747 L
s
.717 1 0 r
.61924 .38321 m
.62608 .38677 L
s
1 .07 0 r
.44978 .6391 m
.44995 .63925 L
s
.44997 .63857 m
.44978 .6391 L
s
.45047 .63905 m
.44978 .6391 L
s
.45014 .63872 m
.44997 .63857 L
s
.44997 .63857 m
.45047 .63905 L
s
.45047 .63905 m
.44995 .63925 L
s
.45014 .63872 m
.45047 .63905 L
s
.44792 .63833 m
.45047 .63905 L
s
1 .336 0 r
.37997 .41075 m
.38051 .41394 L
s
1 .136 0 r
.60617 .49675 m
.60684 .49686 L
s
.60681 .49559 m
.60617 .49675 L
s
.60617 .49675 m
.60619 .49596 L
s
.60746 .49649 m
.60617 .49675 L
s
.60945 .49409 m
.60617 .49675 L
s
.60681 .49559 m
.60619 .49596 L
s
.60746 .49649 m
.60681 .49559 L
s
1 .07 0 r
.44995 .63925 m
.45014 .63872 L
s
1 .136 0 r
.60684 .49686 m
.60746 .49649 L
s
1 .055 0 r
.73834 .7236 m
.73858 .72399 L
s
.73814 .72376 m
.73834 .7236 L
s
.73834 .7236 m
.73869 .72371 L
s
.73858 .72399 m
.73838 .72415 L
s
.73869 .72371 m
.73858 .72399 L
s
1 .08 0 r
.32925 .75241 m
.32873 .75259 L
s
.32877 .75178 m
.32925 .75241 L
s
.32925 .75241 m
.32845 .75235 L
s
.32904 .75201 m
.32925 .75241 L
s
.32673 .75129 m
.32925 .75241 L
s
1 .043 0 r
.34167 .46762 m
.34189 .46779 L
s
.34142 .46786 m
.34167 .46762 L
s
.34167 .46762 m
.34155 .46762 L
s
.787 1 0 r
.47102 .46694 m
.46904 .47661 L
s
1 .08 0 r
.32877 .75178 m
.32845 .75235 L
s
.32904 .75201 m
.32877 .75178 L
s
.32845 .75235 m
.32873 .75259 L
s
1 .043 0 r
.34164 .46802 m
.34142 .46786 L
s
.34142 .46786 m
.34155 .46762 L
s
.34189 .46779 m
.34164 .46802 L
s
.34155 .46762 m
.34189 .46779 L
s
1 .055 0 r
.73838 .72415 m
.73814 .72376 L
s
.73814 .72376 m
.73869 .72371 L
s
1 .043 0 r
.34155 .46762 m
.34164 .46802 L
s
1 .055 0 r
.73869 .72371 m
.73838 .72415 L
s
1 0 0 r
.22091 .58144 m
.22091 .58144 L
s
.22091 .58143 m
.22091 .58144 L
s
.22091 .58144 m
.22091 .58144 L
s
.22091 .58144 m
.22091 .58144 L
s
.22091 .58143 m
.22091 .58144 L
s
.22091 .58143 m
.22091 .58144 L
s
.22091 .58144 m
.22091 .58143 L
s
.22091 .58144 m
.22091 .58144 L
s
.22091 .58144 m
.22091 .58144 L
s
.96081 .60988 m
.96081 .60987 L
s
1 .075 0 r
.67494 .69523 m
.67736 .69422 L
s
1 0 0 r
.73379 .55298 m
.73379 .55298 L
s
1 .606 0 r
.50678 .49608 m
.48311 .49193 L
s
1 .035 0 r
.27976 .43918 m
.27948 .43832 L
s
1 0 0 r
.96081 .60987 m
.96082 .60988 L
s
.96081 .60987 m
.96081 .60987 L
s
.96081 .60987 m
.96081 .60987 L
s
.96082 .60988 m
.96081 .60988 L
s
.96081 .60987 m
.96082 .60988 L
s
.96081 .60988 m
.96081 .60987 L
s
.96081 .60987 m
.96081 .60987 L
s
.96081 .60987 m
.96081 .60988 L
s
1 .136 0 r
.60619 .49596 m
.60684 .49686 L
s
1 .08 0 r
.32873 .75259 m
.32904 .75201 L
s
1 .035 0 r
.27955 .43833 m
.27974 .43848 L
s
.27934 .43851 m
.27955 .43833 L
s
.27955 .43833 m
.27948 .43832 L
s
.27953 .43865 m
.27934 .43851 L
s
.27934 .43851 m
.27948 .43832 L
s
0 1 .566 r
.60543 .48313 m
.61841 .46696 L
s
1 .035 0 r
.27974 .43848 m
.27953 .43865 L
s
.27948 .43832 m
.27974 .43848 L
s
1 .075 0 r
.67714 .6946 m
.67689 .69479 L
s
.67686 .69406 m
.67714 .6946 L
s
.67736 .69422 m
.67714 .6946 L
s
.67662 .69425 m
.67686 .69406 L
s
.67686 .69406 m
.67736 .69422 L
s
.939 1 0 r
.43353 .40996 m
.42807 .41661 L
s
.42387 .40707 m
.43353 .40996 L
s
1 .014 0 r
.38603 .60919 m
.38595 .60921 L
s
.38595 .60907 m
.38603 .60919 L
s
.38603 .60919 m
.38589 .60917 L
s
.38601 .60911 m
.38603 .60919 L
s
.38562 .60895 m
.38603 .60919 L
s
1 .035 0 r
.27948 .43832 m
.27953 .43865 L
s
1 .014 0 r
.38595 .60907 m
.38589 .60917 L
s
.38601 .60911 m
.38595 .60907 L
s
.38589 .60917 m
.38595 .60921 L
s
1 .134 0 r
.77153 .35297 m
.77154 .35288 L
s
.77144 .35169 m
.77153 .35297 L
s
.77153 .35297 m
.77071 .35234 L
s
.77227 .35223 m
.77153 .35297 L
s
.77135 .34951 m
.77153 .35297 L
s
1 .014 0 r
.38595 .60921 m
.38601 .60911 L
s
1 .003 0 r
.67159 .52362 m
.67161 .52362 L
s
.6716 .52359 m
.67159 .52362 L
s
.67159 .52362 m
.67159 .5236 L
s
.67162 .52361 m
.67159 .52362 L
s
.67166 .52355 m
.67159 .52362 L
s
.6716 .52359 m
.67159 .5236 L
s
.67162 .52361 m
.6716 .52359 L
s
.67161 .52362 m
.67162 .52361 L
s
.67159 .5236 m
.67161 .52362 L
s
1 .023 0 r
.83991 .72282 m
.8405 .72241 L
s
1 0 0 r
.8988 .58049 m
.8988 .58048 L
s
1 .1 0 r
.61277 .66589 m
.61638 .66486 L
s
1 .481 0 r
.44451 .46662 m
.43468 .45623 L
s
1 .028 0 r
.21737 .40968 m
.21721 .40897 L
s
1 0 0 r
.8988 .58048 m
.8988 .58048 L
s
.8988 .58048 m
.8988 .58048 L
s
.8988 .58048 m
.8988 .58048 L
s
.8988 .58048 m
.8988 .58049 L
s
.8988 .58048 m
.8988 .58048 L
s
.8988 .58049 m
.8988 .58048 L
s
.8988 .58048 m
.8988 .58048 L
s
.8988 .58048 m
.8988 .58049 L
s
1 .459 0 r
.67154 .38112 m
.67117 .38088 L
s
.67098 .37673 m
.67154 .38112 L
s
.67154 .38112 m
.66843 .3791 L
s
.67372 .37851 m
.67154 .38112 L
s
.6692 .36948 m
.67154 .38112 L
s
1 .134 0 r
.77144 .35169 m
.77071 .35234 L
s
.77227 .35223 m
.77144 .35169 L
s
1 .075 0 r
.67689 .69479 m
.67662 .69425 L
s
.67736 .69422 m
.67689 .69479 L
s
.67662 .69425 m
.67736 .69422 L
s
1 .168 0 r
.43391 .75119 m
.43427 .75159 L
s
.43432 .74989 m
.43391 .75119 L
s
.43555 .75103 m
.43391 .75119 L
s
.43467 .75029 m
.43432 .74989 L
s
.43432 .74989 m
.43555 .75103 L
s
1 .162 0 r
.64793 .46636 m
.64839 .46635 L
s
.64833 .46485 m
.64793 .46636 L
s
.64793 .46636 m
.64747 .46544 L
s
.64925 .46576 m
.64793 .46636 L
s
.65007 .46256 m
.64793 .46636 L
s
1 .038 0 r
.26535 .72259 m
.26513 .72265 L
s
.26516 .72227 m
.26535 .72259 L
s
.26535 .72259 m
.26498 .72253 L
s
.26531 .72239 m
.26535 .72259 L
s
.26433 .72196 m
.26535 .72259 L
s
1 .168 0 r
.43555 .75103 m
.43427 .75159 L
s
.43467 .75029 m
.43555 .75103 L
s
.42926 .74959 m
.43555 .75103 L
s
1 .038 0 r
.26516 .72227 m
.26498 .72253 L
s
.26531 .72239 m
.26516 .72227 L
s
1 .023 0 r
.84037 .72237 m
.84049 .72253 L
s
.84028 .72245 m
.84037 .72237 L
s
.84037 .72237 m
.8405 .72241 L
s
1 .606 0 r
.48782 .4956 m
.48689 .49476 L
s
.48689 .49476 m
.48788 .48993 L
s
.48689 .49476 m
.48311 .49193 L
s
1 .038 0 r
.26498 .72253 m
.26513 .72265 L
s
1 .023 0 r
.84049 .72253 m
.84039 .72261 L
s
.8405 .72241 m
.84049 .72253 L
s
1 .134 0 r
.77071 .35234 m
.77154 .35288 L
s
1 .023 0 r
.84039 .72261 m
.84028 .72245 L
s
.84028 .72245 m
.8405 .72241 L
s
.8405 .72241 m
.84039 .72261 L
s
1 .028 0 r
.21725 .40899 m
.21741 .40911 L
s
.21708 .40912 m
.21725 .40899 L
s
.21725 .40899 m
.21721 .40897 L
s
1 .134 0 r
.77154 .35288 m
.77227 .35223 L
s
1 .038 0 r
.26513 .72265 m
.26531 .72239 L
s
1 .028 0 r
.21723 .40924 m
.21708 .40912 L
s
.21708 .40912 m
.21721 .40897 L
s
.21741 .40911 m
.21723 .40924 L
s
.21721 .40897 m
.21741 .40911 L
s
1 .162 0 r
.64833 .46485 m
.64747 .46544 L
s
.64925 .46576 m
.64833 .46485 L
s
1 .1 0 r
.61592 .66534 m
.61567 .66556 L
s
.61565 .66458 m
.61592 .66534 L
s
.61638 .66486 m
.61592 .66534 L
s
1 .028 0 r
.21721 .40897 m
.21723 .40924 L
s
1 .014 0 r
.89556 .409 m
.89559 .40899 L
s
.89557 .40886 m
.89556 .409 L
s
.89556 .409 m
.8955 .40893 L
s
.89566 .40893 m
.89556 .409 L
s
.89565 .40864 m
.89556 .409 L
s
1 .1 0 r
.6154 .66479 m
.61565 .66458 L
s
.61565 .66458 m
.61638 .66486 L
s
.939 1 0 r
.42387 .40707 m
.42807 .41661 L
s
1 .014 0 r
.89557 .40886 m
.8955 .40893 L
s
.89566 .40893 m
.89557 .40886 L
s
.89559 .40899 m
.89566 .40893 L
s
.8955 .40893 m
.89559 .40899 L
s
1 .606 0 r
.48788 .48993 m
.48881 .49076 L
s
.48788 .48993 m
.48311 .49193 L
s
1 .162 0 r
.64839 .46635 m
.64925 .46576 L
s
0 1 .511 r
.61783 .35178 m
.6228 .35408 L
s
.62209 .3316 m
.61783 .35178 L
s
.64185 .34655 m
.61783 .35178 L
s
1 .045 0 r
.8334 .38025 m
.83345 .38022 L
s
.83341 .37982 m
.8334 .38025 L
s
.8334 .38025 m
.83317 .38003 L
s
.83369 .38001 m
.8334 .38025 L
s
.83354 .37909 m
.8334 .38025 L
s
1 .001 0 r
.32327 .57956 m
.32327 .57956 L
s
.32327 .57955 m
.32327 .57956 L
s
.32327 .57956 m
.32326 .57956 L
s
.32327 .57955 m
.32327 .57956 L
s
.32325 .57954 m
.32327 .57956 L
s
.32327 .57955 m
.32326 .57956 L
s
.32327 .57955 m
.32327 .57955 L
s
.32326 .57956 m
.32327 .57956 L
s
.32327 .57956 m
.32327 .57955 L
s
1 .111 0 r
.55419 .63651 m
.55409 .63671 L
s
.55408 .63562 m
.55419 .63651 L
s
.55497 .63608 m
.55419 .63651 L
s
1 .028 0 r
.7778 .69347 m
.77854 .69298 L
s
1 0 0 r
.83673 .55106 m
.83673 .55106 L
s
1 .111 0 r
.55053 .63651 m
.55497 .63608 L
s
1 .215 0 r
.38218 .43712 m
.38023 .43185 L
s
1 .023 0 r
.1549 .38016 m
.1548 .37956 L
s
1 .045 0 r
.83341 .37982 m
.83317 .38003 L
s
.83369 .38001 m
.83341 .37982 L
s
1 .168 0 r
.43427 .75159 m
.43467 .75029 L
s
1 .111 0 r
.55398 .63582 m
.55408 .63562 L
s
.55408 .63562 m
.55497 .63608 L
s
1 .459 0 r
.67098 .37673 m
.66843 .3791 L
s
.67372 .37851 m
.67098 .37673 L
s
1 .045 0 r
.83317 .38003 m
.83345 .38022 L
s
.83345 .38022 m
.83369 .38001 L
s
1 .1 0 r
.61638 .66486 m
.61567 .66556 L
s
.6154 .66479 m
.61638 .66486 L
s
1 .162 0 r
.64747 .46544 m
.64839 .46635 L
s
1 .1 0 r
.61567 .66556 m
.6154 .66479 L
s
1 .787 0 r
.43226 .43107 m
.43611 .43335 L
s
.4282 .43602 m
.43226 .43107 L
s
.43226 .43107 m
.42892 .43123 L
s
1 .028 0 r
.77839 .69294 m
.77852 .69313 L
s
.77827 .69303 m
.77839 .69294 L
s
.77839 .69294 m
.77854 .69298 L
s
.77852 .69313 m
.77841 .69322 L
s
.77854 .69298 m
.77852 .69313 L
s
1 .023 0 r
.15484 .37957 m
.15496 .37968 L
s
.15469 .37967 m
.15484 .37957 L
s
.15484 .37957 m
.1548 .37956 L
s
.15496 .37968 m
.15481 .37978 L
s
.1548 .37956 m
.15496 .37968 L
s
.15481 .37978 m
.15469 .37967 L
s
.15469 .37967 m
.1548 .37956 L
s
1 .111 0 r
.55497 .63608 m
.55409 .63671 L
s
.55398 .63582 m
.55497 .63608 L
s
1 .058 0 r
.48995 .60757 m
.49004 .60767 L
s
.49004 .60711 m
.48995 .60757 L
s
.4905 .60747 m
.48995 .60757 L
s
.425 1 0 r
.49779 .4928 m
.50216 .50492 L
s
1 .028 0 r
.77841 .69322 m
.77827 .69303 L
s
.77827 .69303 m
.77854 .69298 L
s
1 .023 0 r
.1548 .37956 m
.15481 .37978 L
s
1 .028 0 r
.77854 .69298 m
.77841 .69322 L
s
1 .095 0 r
.36995 .7215 m
.36931 .72172 L
s
.36935 .72077 m
.36995 .7215 L
s
.36995 .7215 m
.369 .72146 L
s
.36966 .72102 m
.36995 .7215 L
s
.36684 .72022 m
.36995 .7215 L
s
1 .058 0 r
.49013 .60721 m
.49004 .60711 L
s
.49004 .60711 m
.4905 .60747 L
s
1 .095 0 r
.369 .72146 m
.36931 .72172 L
s
.36935 .72077 m
.369 .72146 L
s
.36966 .72102 m
.36935 .72077 L
s
1 .058 0 r
.4905 .60747 m
.49004 .60767 L
s
.49013 .60721 m
.4905 .60747 L
s
.48822 .60709 m
.4905 .60747 L
s
1 .111 0 r
.55409 .63671 m
.55398 .63582 L
s
1 .058 0 r
.49004 .60767 m
.49013 .60721 L
s
1 .417 0 r
.36144 .34762 m
.36377 .34963 L
s
.35891 .34935 m
.36144 .34762 L
s
.36144 .34762 m
.36146 .34732 L
s
1 .001 0 r
.77457 .5216 m
.77457 .5216 L
s
.77457 .5216 m
.77457 .5216 L
s
.77457 .5216 m
.77457 .5216 L
s
.77458 .5216 m
.77457 .5216 L
s
.77458 .52159 m
.77457 .5216 L
s
.77457 .5216 m
.77457 .5216 L
s
.77458 .5216 m
.77457 .5216 L
s
.77457 .5216 m
.77458 .5216 L
s
.77457 .5216 m
.77457 .5216 L
s
1 .459 0 r
.66843 .3791 m
.67117 .38088 L
s
1 .035 0 r
.71562 .66409 m
.7166 .66351 L
s
1 0 0 r
.26081 .55009 m
.26081 .55009 L
s
1 .116 0 r
.31977 .40759 m
.31928 .40467 L
s
1 .095 0 r
.36931 .72172 m
.36966 .72102 L
s
1 .787 0 r
.43205 .43831 m
.4282 .43602 L
s
.4282 .43602 m
.42892 .43123 L
s
.717 1 0 r
.62608 .38677 m
.63257 .37874 L
s
1 .035 0 r
.7164 .66345 m
.71655 .66369 L
s
.71626 .66356 m
.7164 .66345 L
s
.7164 .66345 m
.7166 .66351 L
s
.71655 .66369 m
.71641 .6638 L
s
.7166 .66351 m
.71655 .66369 L
s
1 .459 0 r
.67117 .38088 m
.67372 .37851 L
s
1 .035 0 r
.71641 .6638 m
.71626 .66356 L
s
.71626 .66356 m
.7166 .66351 L
s
.7166 .66351 m
.71641 .6638 L
s
1 .013 0 r
.71218 .49239 m
.71222 .49239 L
s
.71221 .49227 m
.71218 .49239 L
s
.71218 .49239 m
.71215 .49232 L
s
.71229 .49234 m
.71218 .49239 L
s
.71236 .49209 m
.71218 .49239 L
s
.71221 .49227 m
.71215 .49232 L
s
.71229 .49234 m
.71221 .49227 L
s
.71222 .49239 m
.71229 .49234 L
s
.71215 .49232 m
.71222 .49239 L
s
0 1 .511 r
.6271 .33373 m
.62209 .3316 L
s
.62209 .3316 m
.64185 .34655 L
s
1 .417 0 r
.36377 .34963 m
.36124 .35136 L
s
.36146 .34732 m
.36377 .34963 L
s
1 .005 0 r
.426 .57773 m
.42596 .57774 L
s
.42597 .57768 m
.426 .57773 L
s
.426 .57773 m
.42595 .57772 L
s
.42599 .5777 m
.426 .57773 L
s
.42583 .57764 m
.426 .57773 L
s
.42597 .57768 m
.42595 .57772 L
s
.42599 .5777 m
.42597 .57768 L
s
.42595 .57772 m
.42596 .57774 L
s
.42596 .57774 m
.42599 .5777 L
s
1 .011 0 r
.88091 .69171 m
.88116 .69149 L
s
1 0 0 r
.9399 .54913 m
.9399 .54913 L
s
1 .043 0 r
.65337 .63468 m
.65472 .63403 L
s
0 .813 1 r
.48483 .43506 m
.41897 .36251 L
s
1 .073 0 r
.25729 .37803 m
.25715 .37615 L
s
1 0 0 r
.1983 .52061 m
.1983 .52061 L
s
.1983 .52061 m
.1983 .52061 L
s
.19829 .52061 m
.1983 .52061 L
s
.1983 .52061 m
.1983 .52061 L
s
.1983 .52061 m
.19829 .52061 L
s
.19829 .52061 m
.1983 .52061 L
s
.1983 .52061 m
.1983 .52061 L
s
.1983 .52061 m
.1983 .52061 L
s
.1983 .52061 m
.1983 .52061 L
s
1 .417 0 r
.36124 .35136 m
.35891 .34935 L
s
.35891 .34935 m
.36146 .34732 L
s
1 .011 0 r
.8811 .69148 m
.88116 .69155 L
s
.88105 .69152 m
.8811 .69148 L
s
.8811 .69148 m
.88116 .69149 L
s
1 .606 0 r
.48311 .49193 m
.48782 .4956 L
s
.48311 .49193 m
.48881 .49076 L
s
1 .011 0 r
.88116 .69155 m
.88111 .69159 L
s
.88116 .69149 m
.88116 .69155 L
s
.88111 .69159 m
.88105 .69152 L
s
.88105 .69152 m
.88116 .69149 L
s
1 .202 0 r
.47562 .72003 m
.47592 .72046 L
s
.47595 .71844 m
.47562 .72003 L
s
.47751 .71969 m
.47562 .72003 L
s
1 .011 0 r
.88116 .69149 m
.88111 .69159 L
s
1 .04 0 r
.30546 .6915 m
.30522 .69156 L
s
.30525 .69116 m
.30546 .6915 L
s
.30546 .6915 m
.30506 .69144 L
s
.30541 .69129 m
.30546 .6915 L
s
.30435 .69082 m
.30546 .6915 L
s
.30525 .69116 m
.30506 .69144 L
s
.30541 .69129 m
.30525 .69116 L
s
.30506 .69144 m
.30522 .69156 L
s
1 .233 0 r
.53965 .74845 m
.53961 .74894 L
s
.5396 .74658 m
.53965 .74845 L
s
.54151 .74773 m
.53965 .74845 L
s
1 .202 0 r
.47625 .71887 m
.47595 .71844 L
s
.47595 .71844 m
.47751 .71969 L
s
1 .043 0 r
.65461 .63426 m
.65446 .63437 L
s
.65444 .63395 m
.65461 .63426 L
s
.65472 .63403 m
.65461 .63426 L
s
.65429 .63406 m
.65444 .63395 L
s
.65444 .63395 m
.65472 .63403 L
s
1 .04 0 r
.30522 .69156 m
.30541 .69129 L
s
1 .233 0 r
.53957 .74708 m
.5396 .74658 L
s
.5396 .74658 m
.54151 .74773 L
s
1 .202 0 r
.47751 .71969 m
.47592 .72046 L
s
.47625 .71887 m
.47751 .71969 L
s
.46959 .71849 m
.47751 .71969 L
s
1 .141 0 r
.68998 .43443 m
.69019 .43438 L
s
.69012 .43308 m
.68998 .43443 L
s
.68998 .43443 m
.68934 .43369 L
s
.69097 .43378 m
.68998 .43443 L
s
.69083 .43093 m
.68998 .43443 L
s
1 .043 0 r
.65446 .63437 m
.65429 .63406 L
s
.65472 .63403 m
.65446 .63437 L
s
.65429 .63406 m
.65472 .63403 L
s
1 .59 0 r
.62892 .43427 m
.62902 .43405 L
s
.62884 .42861 m
.62892 .43427 L
s
.62892 .43427 m
.6255 .4314 L
s
.63237 .43126 m
.62892 .43427 L
s
.62898 .41946 m
.62892 .43427 L
s
1 .606 0 r
.48881 .49076 m
.48782 .4956 L
s
1 .141 0 r
.69012 .43308 m
.68934 .43369 L
s
.69097 .43378 m
.69012 .43308 L
s
1 .116 0 r
.31942 .40473 m
.32005 .40524 L
s
.31871 .40527 m
.31942 .40473 L
s
.31942 .40473 m
.31928 .40467 L
s
1 .043 0 r
.87452 .34846 m
.87455 .34843 L
s
.87451 .34805 m
.87452 .34846 L
s
.87452 .34846 m
.87428 .34825 L
s
.87478 .34822 m
.87452 .34846 L
s
.87457 .34735 m
.87452 .34846 L
s
.808 1 0 r
.42113 .33986 m
.42788 .34504 L
s
.41402 .34533 m
.42113 .33986 L
s
.42113 .33986 m
.42029 .33892 L
s
1 0 0 r
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
1 .012 0 r
.81871 .66229 m
.81898 .66206 L
s
1 .233 0 r
.53202 .74789 m
.54151 .74773 L
s
1 .047 0 r
.59105 .60523 m
.59275 .60472 L
s
1 0 0 r
.36338 .54816 m
.36338 .54816 L
s
1 .825 0 r
.4224 .4055 m
.4201 .38439 L
s
1 .051 0 r
.19474 .34843 m
.19469 .3471 L
s
1 .043 0 r
.87451 .34805 m
.87428 .34825 L
s
.87478 .34822 m
.87451 .34805 L
s
1 .417 0 r
.36146 .34732 m
.36124 .35136 L
s
1 .043 0 r
.87428 .34825 m
.87455 .34843 L
s
1 .012 0 r
.81892 .66205 m
.81898 .66213 L
s
.81887 .66209 m
.81892 .66205 L
s
.81892 .66205 m
.81898 .66206 L
s
.81898 .66213 m
.81893 .66217 L
s
.81898 .66206 m
.81898 .66213 L
s
1 .233 0 r
.54151 .74773 m
.53961 .74894 L
s
.53957 .74708 m
.54151 .74773 L
s
1 .043 0 r
.87455 .34843 m
.87478 .34822 L
s
1 .116 0 r
.31935 .40578 m
.31871 .40527 L
s
.31871 .40527 m
.31928 .40467 L
s
1 .012 0 r
.81893 .66217 m
.81887 .66209 L
s
.81887 .66209 m
.81898 .66206 L
s
1 .073 0 r
.2572 .3762 m
.2576 .37654 L
s
.25675 .37652 m
.2572 .3762 L
s
.2572 .3762 m
.25715 .37615 L
s
1 .012 0 r
.81898 .66206 m
.81893 .66217 L
s
1 .116 0 r
.32005 .40524 m
.31935 .40578 L
s
.31928 .40467 m
.32005 .40524 L
s
1 .141 0 r
.69019 .43438 m
.69097 .43378 L
s
1 .047 0 r
.59253 .60496 m
.59241 .60505 L
s
.5924 .60459 m
.59253 .60496 L
s
.59275 .60472 m
.59253 .60496 L
s
.59228 .60469 m
.5924 .60459 L
s
.5924 .60459 m
.59275 .60472 L
s
1 .141 0 r
.68934 .43369 m
.69019 .43438 L
s
1 .116 0 r
.4099 .69048 m
.41025 .69076 L
s
.41028 .68961 m
.4099 .69048 L
s
.41106 .69047 m
.4099 .69048 L
s
1 .202 0 r
.47592 .72046 m
.47625 .71887 L
s
1 .116 0 r
.41106 .69047 m
.41025 .69076 L
s
.41028 .68961 m
.41106 .69047 L
s
.41063 .6899 m
.41106 .69047 L
s
.40709 .68905 m
.41106 .69047 L
s
1 .073 0 r
.2576 .37654 m
.25715 .37686 L
s
.25715 .37615 m
.2576 .37654 L
s
.25715 .37686 m
.25675 .37652 L
s
.25675 .37652 m
.25715 .37615 L
s
1 .116 0 r
.41063 .6899 m
.41028 .68961 L
s
.31928 .40467 m
.31935 .40578 L
s
1 .047 0 r
.59275 .60472 m
.59241 .60505 L
s
.59228 .60469 m
.59275 .60472 L
s
1 .215 0 r
.38067 .43192 m
.38184 .43277 L
s
.3794 .43304 m
.38067 .43192 L
s
.38067 .43192 m
.38023 .43185 L
s
1 .047 0 r
.59241 .60505 m
.59228 .60469 L
s
1 .073 0 r
.25715 .37615 m
.25715 .37686 L
s
1 .787 0 r
.43611 .43335 m
.43205 .43831 L
s
.42892 .43123 m
.43611 .43335 L
s
1 .013 0 r
.2421 .66164 m
.24203 .66166 L
s
.24204 .66153 m
.2421 .66164 L
s
.2421 .66164 m
.24197 .66161 L
s
.2421 .66157 m
.2421 .66164 L
s
.24179 .66139 m
.2421 .66164 L
s
1 .233 0 r
.53961 .74894 m
.53957 .74708 L
s
1 .013 0 r
.24204 .66153 m
.24197 .66161 L
s
.2421 .66157 m
.24204 .66153 L
s
.24197 .66161 m
.24203 .66166 L
s
.24203 .66166 m
.2421 .66157 L
s
1 .051 0 r
.19473 .34713 m
.195 .34738 L
s
.1944 .34735 m
.19473 .34713 L
s
.19473 .34713 m
.19469 .3471 L
s
1 .003 0 r
.81548 .49016 m
.81549 .49016 L
s
.81548 .49013 m
.81548 .49016 L
s
.81548 .49016 m
.81547 .49014 L
s
.8155 .49015 m
.81548 .49016 L
s
.81551 .4901 m
.81548 .49016 L
s
1 .021 0 r
.52933 .5758 m
.52932 .57583 L
s
.52932 .57563 m
.52933 .5758 L
s
.52949 .57573 m
.52933 .5758 L
s
1 .003 0 r
.81548 .49013 m
.81547 .49014 L
s
.8155 .49015 m
.81548 .49013 L
s
.81549 .49016 m
.8155 .49015 L
s
.81547 .49014 m
.81549 .49016 L
s
1 .215 0 r
.38058 .4339 m
.3794 .43304 L
s
.3794 .43304 m
.38023 .43185 L
s
1 .021 0 r
.52932 .57566 m
.52932 .57563 L
s
.52932 .57563 m
.52949 .57573 L
s
1 .051 0 r
.195 .34738 m
.19468 .34759 L
s
.19469 .3471 m
.195 .34738 L
s
1 .012 0 r
.75645 .63284 m
.75673 .63261 L
s
1 .021 0 r
.52865 .57574 m
.52949 .57573 L
s
1 .001 0 r
.30085 .51864 m
.30084 .51863 L
s
1 .323 0 r
.35991 .3759 m
.36038 .36758 L
s
1 .051 0 r
.19468 .34759 m
.1944 .34735 L
s
.1944 .34735 m
.19469 .3471 L
s
1 .116 0 r
.41025 .69076 m
.41063 .6899 L
s
1 .001 0 r
.30084 .51863 m
.30085 .51863 L
s
.30084 .51863 m
.30084 .51863 L
s
.30084 .51863 m
.30084 .51863 L
s
.30084 .51863 m
.30084 .51863 L
s
.30084 .51863 m
.30084 .51863 L
s
.30085 .51863 m
.30084 .51863 L
s
.30084 .51863 m
.30085 .51863 L
s
1 .021 0 r
.52949 .57573 m
.52932 .57583 L
s
.52932 .57566 m
.52949 .57573 L
s
1 .001 0 r
.30084 .51863 m
.30084 .51863 L
s
1 .021 0 r
.52932 .57583 m
.52932 .57566 L
s
1 .051 0 r
.19469 .3471 m
.19468 .34759 L
s
1 .59 0 r
.62884 .42861 m
.6255 .4314 L
s
.63237 .43126 m
.62884 .42861 L
s
1 .012 0 r
.75667 .6326 m
.75673 .63268 L
s
.75661 .63264 m
.75667 .6326 L
s
.75667 .6326 m
.75673 .63261 L
s
.75673 .63268 m
.75667 .63272 L
s
.75673 .63261 m
.75673 .63268 L
s
.75667 .63272 m
.75661 .63264 L
s
.75661 .63264 m
.75673 .63261 L
s
1 .215 0 r
.38184 .43277 m
.38058 .4339 L
s
.38023 .43185 m
.38184 .43277 L
s
1 .012 0 r
.75673 .63261 m
.75667 .63272 L
s
1 .787 0 r
.42892 .43123 m
.43205 .43831 L
s
1 .021 0 r
.75301 .46104 m
.75306 .46104 L
s
.75304 .46084 m
.75301 .46104 L
s
.75301 .46104 m
.75293 .46093 L
s
.75317 .46095 m
.75301 .46104 L
s
.7532 .46053 m
.75301 .46104 L
s
.75304 .46084 m
.75293 .46093 L
s
.75317 .46095 m
.75304 .46084 L
s
.75306 .46104 m
.75317 .46095 L
s
.75293 .46093 m
.75306 .46104 L
s
1 .215 0 r
.38023 .43185 m
.38058 .4339 L
s
0 1 .511 r
.64185 .34655 m
.6228 .35408 L
s
.6271 .33373 m
.64185 .34655 L
s
.54403 .32765 m
.64185 .34655 L
s
1 .005 0 r
.92204 .66049 m
.92213 .66039 L
s
1 .168 0 r
.63502 .74618 m
.64117 .74453 L
s
1 .01 0 r
.69411 .60335 m
.69437 .60316 L
s
1 0 0 r
.46618 .54622 m
.46618 .54622 L
s
1 .003 0 r
.23825 .48909 m
.23822 .48903 L
s
1 .168 0 r
.29735 .34627 m
.29782 .34191 L
s
1 .003 0 r
.23823 .48903 m
.23825 .48904 L
s
.23822 .48904 m
.23823 .48903 L
s
.23823 .48903 m
.23822 .48903 L
s
.23823 .48906 m
.23822 .48904 L
s
.23822 .48904 m
.23822 .48903 L
s
.23825 .48904 m
.23823 .48906 L
s
.23822 .48903 m
.23825 .48904 L
s
.23822 .48903 m
.23823 .48906 L
s
1 .005 0 r
.92211 .66039 m
.92214 .66042 L
s
.92209 .66041 m
.92211 .66039 L
s
.92211 .66039 m
.92213 .66039 L
s
.92214 .66042 m
.92212 .66043 L
s
.92213 .66039 m
.92214 .66042 L
s
.92212 .66043 m
.92209 .66041 L
s
.92209 .66041 m
.92213 .66039 L
s
.92213 .66039 m
.92212 .66043 L
s
1 .01 0 r
.69432 .60315 m
.69437 .60322 L
s
.69427 .60318 m
.69432 .60315 L
s
.69432 .60315 m
.69437 .60316 L
s
.69437 .60322 m
.69432 .60325 L
s
.69437 .60316 m
.69437 .60322 L
s
.69432 .60325 m
.69427 .60318 L
s
.69427 .60318 m
.69437 .60316 L
s
.69437 .60316 m
.69432 .60325 L
s
1 .043 0 r
.34571 .66029 m
.34546 .66036 L
s
.34548 .65994 m
.34571 .66029 L
s
.34571 .66029 m
.34529 .66024 L
s
.34565 .66007 m
.34571 .66029 L
s
.34452 .65958 m
.34571 .66029 L
s
.34548 .65994 m
.34529 .66024 L
s
.34565 .66007 m
.34548 .65994 L
s
.34529 .66024 m
.34546 .66036 L
s
.34546 .66036 m
.34565 .66007 L
s
1 .59 0 r
.6255 .4314 m
.62902 .43405 L
s
.62902 .43405 m
.63237 .43126 L
s
1 .229 0 r
.51737 .68833 m
.51749 .68877 L
s
.51749 .6865 m
.51737 .68833 L
s
.51935 .68772 m
.51737 .68833 L
s
.808 1 0 r
.42077 .35053 m
.41402 .34533 L
s
.41402 .34533 m
.42029 .33892 L
s
1 .481 0 r
.43672 .45609 m
.43908 .45751 L
s
.43423 .45913 m
.43672 .45609 L
s
.43672 .45609 m
.43468 .45623 L
s
1 .001 0 r
.91888 .48811 m
.91888 .48811 L
s
.91888 .4881 m
.91888 .48811 L
s
.91888 .48811 m
.91888 .48811 L
s
.91889 .48811 m
.91888 .48811 L
s
.91889 .48809 m
.91888 .48811 L
s
.91888 .4881 m
.91888 .48811 L
s
.91889 .48811 m
.91888 .4881 L
s
.91888 .48811 m
.91889 .48811 L
s
.91888 .48811 m
.91888 .48811 L
s
1 .004 0 r
.85976 .631 m
.85984 .63092 L
s
1 .22 0 r
.57258 .71675 m
.58131 .71559 L
s
1 .005 0 r
.6317 .57384 m
.63186 .57375 L
s
1 .007 0 r
.40364 .51667 m
.40351 .51653 L
s
0 1 .331 r
.46277 .37376 m
.48871 .31429 L
s
1 .004 0 r
.17558 .45951 m
.17555 .45941 L
s
1 .229 0 r
.51761 .68694 m
.51749 .6865 L
s
.51749 .6865 m
.51935 .68772 L
s
1 .168 0 r
.64037 .7453 m
.63996 .74571 L
s
.63991 .74401 m
.64037 .7453 L
s
.64117 .74453 m
.64037 .7453 L
s
1 .004 0 r
.85982 .63092 m
.85984 .63094 L
s
.8598 .63093 m
.85982 .63092 L
s
.85982 .63092 m
.85984 .63092 L
s
1 .005 0 r
.63183 .57374 m
.63185 .57378 L
s
.63181 .57375 m
.63183 .57374 L
s
.63183 .57374 m
.63186 .57375 L
s
.63185 .57378 m
.63183 .57379 L
s
.63186 .57375 m
.63185 .57378 L
s
1 .004 0 r
.85984 .63094 m
.85983 .63096 L
s
.85984 .63092 m
.85984 .63094 L
s
.17556 .45941 m
.17558 .45943 L
s
.17553 .45943 m
.17556 .45941 L
s
.17556 .45941 m
.17555 .45941 L
s
.85983 .63096 m
.8598 .63093 L
s
.8598 .63093 m
.85984 .63092 L
s
.85984 .63092 m
.85983 .63096 L
s
.17555 .45945 m
.17553 .45943 L
s
.17553 .45943 m
.17555 .45941 L
s
.17558 .45943 m
.17555 .45945 L
s
.17555 .45941 m
.17558 .45943 L
s
1 .005 0 r
.63183 .57379 m
.63181 .57375 L
s
.63181 .57375 m
.63186 .57375 L
s
.63186 .57375 m
.63183 .57379 L
s
1 .004 0 r
.17555 .45941 m
.17555 .45945 L
s
1 .007 0 r
.40353 .51653 m
.40357 .51655 L
s
.4035 .51657 m
.40353 .51653 L
s
.40353 .51653 m
.40351 .51653 L
s
.40353 .51659 m
.4035 .51657 L
s
.4035 .51657 m
.40351 .51653 L
s
1 .168 0 r
.6395 .74443 m
.63991 .74401 L
s
.63991 .74401 m
.64117 .74453 L
s
1 .007 0 r
.40357 .51655 m
.40353 .51659 L
s
.40351 .51653 m
.40357 .51655 L
s
.40351 .51653 m
.40353 .51659 L
s
.808 1 0 r
.42788 .34504 m
.42077 .35053 L
s
.42029 .33892 m
.42788 .34504 L
s
1 .293 0 r
.7124 .34501 m
.71203 .34484 L
s
.71187 .34221 m
.7124 .34501 L
s
.7124 .34501 m
.71027 .3438 L
s
.71363 .34325 m
.7124 .34501 L
s
.71016 .33755 m
.7124 .34501 L
s
1 .116 0 r
.73155 .40213 m
.73162 .40207 L
s
.73155 .40101 m
.73155 .40213 L
s
.73155 .40213 m
.73091 .40155 L
s
.73226 .40152 m
.73155 .40213 L
s
.73173 .39918 m
.73155 .40213 L
s
1 .141 0 r
.45123 .65931 m
.45158 .65962 L
s
.45161 .65823 m
.45123 .65931 L
s
.45263 .65921 m
.45123 .65931 L
s
1 .22 0 r
.57985 .71646 m
.57958 .71693 L
s
.57954 .71472 m
.57985 .71646 L
s
.58131 .71559 m
.57985 .71646 L
s
1 .141 0 r
.45197 .65853 m
.45161 .65823 L
s
.45161 .65823 m
.45263 .65921 L
s
1 .481 0 r
.4366 .46056 m
.43423 .45913 L
s
.43423 .45913 m
.43468 .45623 L
s
1 .141 0 r
.45263 .65921 m
.45158 .65962 L
s
.45197 .65853 m
.45263 .65921 L
s
.44748 .65777 m
.45263 .65921 L
s
1 .116 0 r
.73155 .40101 m
.73091 .40155 L
s
.73226 .40152 m
.73155 .40101 L
s
1 .229 0 r
.51935 .68772 m
.51749 .68877 L
s
.51761 .68694 m
.51935 .68772 L
s
.51006 .68727 m
.51935 .68772 L
s
1 .22 0 r
.57926 .71518 m
.57954 .71472 L
s
.57954 .71472 m
.58131 .71559 L
s
1 .116 0 r
.73091 .40155 m
.73162 .40207 L
s
1 .011 0 r
.28211 .63029 m
.28206 .6303 L
s
.28206 .63019 m
.28211 .63029 L
s
.28211 .63029 m
.28201 .63026 L
s
.28211 .63023 m
.28211 .63029 L
s
.28187 .63008 m
.28211 .63029 L
s
1 .116 0 r
.73162 .40207 m
.73226 .40152 L
s
1 .293 0 r
.71187 .34221 m
.71027 .3438 L
s
.71363 .34325 m
.71187 .34221 L
s
1 .011 0 r
.28206 .63019 m
.28201 .63026 L
s
.28211 .63023 m
.28206 .63019 L
s
.28201 .63026 m
.28206 .6303 L
s
.28206 .6303 m
.28211 .63023 L
s
1 .005 0 r
.85653 .45862 m
.85654 .45862 L
s
.85654 .45857 m
.85653 .45862 L
s
.85653 .45862 m
.85651 .45859 L
s
.85657 .45859 m
.85653 .45862 L
s
.85658 .45849 m
.85653 .45862 L
s
.85654 .45857 m
.85651 .45859 L
s
.85657 .45859 m
.85654 .45857 L
s
.85654 .45862 m
.85657 .45859 L
s
.85651 .45859 m
.85654 .45862 L
s
1 .168 0 r
.64117 .74453 m
.63996 .74571 L
s
.6395 .74443 m
.64117 .74453 L
s
.63996 .74571 m
.6395 .74443 L
s
1 .08 0 r
.73825 .74447 m
.74066 .74327 L
s
1 .003 0 r
.79742 .60148 m
.79747 .60143 L
s
1 0 0 r
.56922 .54428 m
.56922 .54428 L
s
1 .014 0 r
.34103 .48709 m
.34085 .48676 L
s
1 .741 0 r
.40019 .3441 m
.40764 .32529 L
s
1 .003 0 r
.79745 .60143 m
.79747 .60144 L
s
.79744 .60143 m
.79745 .60143 L
s
.79745 .60143 m
.79747 .60143 L
s
.79747 .60144 m
.79746 .60145 L
s
.79747 .60143 m
.79747 .60144 L
s
.79746 .60145 m
.79744 .60143 L
s
.79744 .60143 m
.79747 .60143 L
s
.79747 .60143 m
.79746 .60145 L
s
1 .141 0 r
.45158 .65962 m
.45197 .65853 L
s
1 .229 0 r
.51749 .68877 m
.51761 .68694 L
s
1 .014 0 r
.34089 .48676 m
.34097 .48681 L
s
.34081 .48683 m
.34089 .48676 L
s
.34089 .48676 m
.34085 .48676 L
s
.34089 .48689 m
.34081 .48683 L
s
.34081 .48683 m
.34085 .48676 L
s
1 .293 0 r
.71027 .3438 m
.71203 .34484 L
s
1 .014 0 r
.34097 .48681 m
.34089 .48689 L
s
.34085 .48676 m
.34097 .48681 L
s
.34085 .48676 m
.34089 .48689 L
s
1 .22 0 r
.58131 .71559 m
.57958 .71693 L
s
.57926 .71518 m
.58131 .71559 L
s
1 .026 0 r
.79405 .42951 m
.79408 .4295 L
s
.79406 .42926 m
.79405 .42951 L
s
.79405 .42951 m
.79392 .42937 L
s
.79423 .42938 m
.79405 .42951 L
s
.79419 .42885 m
.79405 .42951 L
s
.79406 .42926 m
.79392 .42937 L
s
.79423 .42938 m
.79406 .42926 L
s
.79408 .4295 m
.79423 .42938 L
s
.79392 .42937 m
.79408 .4295 L
s
1 .22 0 r
.57958 .71693 m
.57926 .71518 L
s
1 .293 0 r
.71203 .34484 m
.71363 .34325 L
s
1 .168 0 r
.29778 .34203 m
.29871 .34288 L
s
.29675 .34269 m
.29778 .34203 L
s
.29778 .34203 m
.29782 .34191 L
s
1 .08 0 r
.74015 .7431 m
.74049 .74367 L
s
.73986 .74334 m
.74015 .7431 L
s
.74015 .7431 m
.74066 .74327 L
s
.74049 .74367 m
.7402 .74391 L
s
.74066 .74327 m
.74049 .74367 L
s
1 .481 0 r
.43908 .45751 m
.4366 .46056 L
s
.43468 .45623 m
.43908 .45751 L
s
1 .002 0 r
.21918 .60058 m
.21918 .60058 L
s
.21918 .60056 m
.21918 .60058 L
s
.21918 .60058 m
.21917 .60057 L
s
.21919 .60057 m
.21918 .60058 L
s
.21915 .60054 m
.21918 .60058 L
s
.21918 .60056 m
.21917 .60057 L
s
.21919 .60057 m
.21918 .60056 L
s
.21917 .60057 m
.21918 .60058 L
s
.21918 .60058 m
.21919 .60057 L
s
.96332 .62916 m
.96334 .62912 L
s
1 .114 0 r
.6758 .715 m
.67953 .71346 L
s
1 .001 0 r
.735 .57193 m
.73501 .57191 L
s
1 .117 0 r
.50667 .5147 m
.5021 .5139 L
s
1 .016 0 r
.27835 .45747 m
.27822 .45708 L
s
1 .001 0 r
.73501 .57191 m
.73501 .57191 L
s
.735 .57191 m
.73501 .57191 L
s
.73501 .57191 m
.73501 .57191 L
s
.73501 .57191 m
.73501 .57192 L
s
.73501 .57191 m
.73501 .57191 L
s
.73501 .57192 m
.735 .57191 L
s
.735 .57191 m
.73501 .57191 L
s
.73501 .57191 m
.73501 .57192 L
s
1 .002 0 r
.96334 .62912 m
.96335 .62913 L
s
.96333 .62913 m
.96334 .62912 L
s
.96334 .62912 m
.96334 .62912 L
s
.96335 .62913 m
.96334 .62914 L
s
.96334 .62912 m
.96335 .62913 L
s
.96334 .62914 m
.96333 .62913 L
s
.96333 .62913 m
.96334 .62912 L
s
.96334 .62912 m
.96334 .62914 L
s
1 .168 0 r
.29871 .34288 m
.29767 .34354 L
s
.29782 .34191 m
.29871 .34288 L
s
1 .043 0 r
.38607 .62894 m
.38581 .62901 L
s
.38583 .62859 m
.38607 .62894 L
s
.38607 .62894 m
.38564 .62889 L
s
.386 .62871 m
.38607 .62894 L
s
.38482 .62823 m
.38607 .62894 L
s
1 .117 0 r
.50301 .51461 m
.50282 .51444 L
s
.50282 .51444 m
.50302 .51351 L
s
.50282 .51444 m
.5021 .5139 L
s
1 .016 0 r
.27825 .45708 m
.27834 .45715 L
s
.27815 .45716 m
.27825 .45708 L
s
.27825 .45708 m
.27822 .45708 L
s
1 .043 0 r
.38583 .62859 m
.38564 .62889 L
s
.386 .62871 m
.38583 .62859 L
s
.38564 .62889 m
.38581 .62901 L
s
1 .168 0 r
.29767 .34354 m
.29675 .34269 L
s
.29675 .34269 m
.29782 .34191 L
s
1 .016 0 r
.27824 .45723 m
.27815 .45716 L
s
.27815 .45716 m
.27822 .45708 L
s
.27834 .45715 m
.27824 .45723 L
s
.27822 .45708 m
.27834 .45715 L
s
1 .08 0 r
.7402 .74391 m
.73986 .74334 L
s
.73986 .74334 m
.74066 .74327 L
s
.74066 .74327 m
.7402 .74391 L
s
1 .016 0 r
.27822 .45708 m
.27824 .45723 L
s
1 .117 0 r
.50302 .51351 m
.5032 .51368 L
s
.50302 .51351 m
.5021 .5139 L
s
1 .481 0 r
.43468 .45623 m
.4366 .46056 L
s
1 .043 0 r
.38581 .62901 m
.386 .62871 L
s
.939 1 0 r
.6271 .39971 m
.62338 .3998 L
s
.62308 .39011 m
.6271 .39971 L
s
.6271 .39971 m
.61768 .39679 L
s
.62878 .3931 m
.6271 .39971 L
s
.60755 .37565 m
.6271 .39971 L
s
1 .168 0 r
.29782 .34191 m
.29767 .34354 L
s
1 .117 0 r
.5021 .5139 m
.50301 .51461 L
s
.5021 .5139 m
.5032 .51368 L
s
1 .055 0 r
.26432 .74281 m
.264 .74291 L
s
.26404 .74235 m
.26432 .74281 L
s
.26432 .74281 m
.26378 .74273 L
s
.26426 .74253 m
.26432 .74281 L
s
.26282 .7419 m
.26432 .74281 L
s
1 .117 0 r
.5032 .51368 m
.50301 .51461 L
s
1 .035 0 r
.84173 .74276 m
.84261 .74214 L
s
1 .001 0 r
.90096 .5996 m
.90097 .59958 L
s
1 .166 0 r
.61327 .68549 m
.61933 .6838 L
s
1 0 0 r
.6725 .54234 m
.6725 .54234 L
s
1 .199 0 r
.44405 .48508 m
.43997 .48081 L
s
0 .04 1 r
.50328 .34192 m
.64867 .29102 L
s
1 .015 0 r
.21559 .42781 m
.2155 .42743 L
s
.808 1 0 r
.42029 .33892 m
.42077 .35053 L
s
1 .055 0 r
.26404 .74235 m
.26378 .74273 L
s
.26426 .74253 m
.26404 .74235 L
s
1 .001 0 r
.90097 .59958 m
.90097 .59959 L
s
.90096 .59959 m
.90097 .59958 L
s
.90097 .59958 m
.90097 .59958 L
s
.90097 .59959 m
.90097 .59959 L
s
.90097 .59958 m
.90097 .59959 L
s
.90097 .59959 m
.90096 .59959 L
s
.90096 .59959 m
.90097 .59958 L
s
.90097 .59958 m
.90097 .59959 L
s
1 .055 0 r
.26378 .74273 m
.264 .74291 L
s
1 .114 0 r
.67918 .71403 m
.67881 .71434 L
s
.67876 .7132 m
.67918 .71403 L
s
.67953 .71346 m
.67918 .71403 L
s
.67839 .71351 m
.67876 .7132 L
s
.67876 .7132 m
.67953 .71346 L
s
1 .015 0 r
.21553 .42743 m
.21561 .4275 L
s
.21543 .4275 m
.21553 .42743 L
s
.21553 .42743 m
.2155 .42743 L
s
1 .055 0 r
.264 .74291 m
.26426 .74253 L
s
1 .015 0 r
.21552 .42757 m
.21543 .4275 L
s
.21543 .4275 m
.2155 .42743 L
s
.21561 .4275 m
.21552 .42757 L
s
.2155 .42743 m
.21561 .4275 L
s
.2155 .42743 m
.21552 .42757 L
s
1 .323 0 r
.36036 .36779 m
.36217 .36936 L
s
.3584 .36914 m
.36036 .36779 L
s
.36036 .36779 m
.36038 .36758 L
s
1 .035 0 r
.84242 .74209 m
.8426 .74232 L
s
.84227 .74221 m
.84242 .74209 L
s
.84242 .74209 m
.84261 .74214 L
s
.8426 .74232 m
.84245 .74244 L
s
.84261 .74214 m
.8426 .74232 L
s
1 .162 0 r
.49284 .6277 m
.49309 .628 L
s
.4931 .62641 m
.49284 .6277 L
s
.49437 .62741 m
.49284 .6277 L
s
1 .021 0 r
.60943 .51312 m
.60954 .51314 L
s
.60953 .51294 m
.60943 .51312 L
s
.60943 .51312 m
.60944 .513 L
s
.60963 .51308 m
.60943 .51312 L
s
.60994 .51272 m
.60943 .51312 L
s
.60953 .51294 m
.60944 .513 L
s
.60963 .51308 m
.60953 .51294 L
s
.60954 .51314 m
.60963 .51308 L
s
1 .035 0 r
.84245 .74244 m
.84227 .74221 L
s
.84227 .74221 m
.84261 .74214 L
s
.84261 .74214 m
.84245 .74244 L
s
1 .114 0 r
.67881 .71434 m
.67839 .71351 L
s
.67953 .71346 m
.67881 .71434 L
s
1 .162 0 r
.49336 .62671 m
.4931 .62641 L
s
.4931 .62641 m
.49437 .62741 L
s
1 .114 0 r
.67839 .71351 m
.67953 .71346 L
s
1 .021 0 r
.60944 .513 m
.60954 .51314 L
s
1 .095 0 r
.7729 .36978 m
.77291 .36972 L
s
.77284 .36886 m
.7729 .36978 L
s
.7729 .36978 m
.77232 .36933 L
s
.77343 .36925 m
.7729 .36978 L
s
.77277 .36733 m
.7729 .36978 L
s
1 .008 0 r
.89774 .42697 m
.89775 .42696 L
s
.89775 .42689 m
.89774 .42697 L
s
.89774 .42697 m
.89771 .42693 L
s
.8978 .42693 m
.89774 .42697 L
s
.89779 .42677 m
.89774 .42697 L
s
.89775 .42689 m
.89771 .42693 L
s
.8978 .42693 m
.89775 .42689 L
s
.89775 .42696 m
.8978 .42693 L
s
.89771 .42693 m
.89775 .42696 L
s
1 .007 0 r
.32223 .59879 m
.3222 .5988 L
s
.32221 .59873 m
.32223 .59879 L
s
.32223 .59879 m
.32217 .59878 L
s
.32224 .59876 m
.32223 .59879 L
s
.32209 .59866 m
.32223 .59879 L
s
.32221 .59873 m
.32217 .59878 L
s
.32224 .59876 m
.32221 .59873 L
s
.32217 .59878 m
.3222 .5988 L
s
1 .162 0 r
.49437 .62741 m
.49309 .628 L
s
.49336 .62671 m
.49437 .62741 L
s
.488 .62638 m
.49437 .62741 L
s
1 .007 0 r
.3222 .5988 m
.32224 .59876 L
s
1 .095 0 r
.77284 .36886 m
.77232 .36933 L
s
.77343 .36925 m
.77284 .36886 L
s
1 .134 0 r
.37032 .74195 m
.36941 .74228 L
s
.36947 .74092 m
.37032 .74195 L
s
.37032 .74195 m
.36898 .7419 L
s
.36991 .74129 m
.37032 .74195 L
s
.36593 .74018 m
.37032 .74195 L
s
1 .606 0 r
.58087 .48409 m
.58242 .4841 L
s
.58232 .47841 m
.58087 .48409 L
s
.58087 .48409 m
.57899 .48065 L
s
.58575 .48186 m
.58087 .48409 L
s
.58844 .46984 m
.58087 .48409 L
s
1 .215 0 r
.55782 .65596 m
.55762 .65636 L
s
.5576 .65424 m
.55782 .65596 L
s
.55935 .65514 m
.55782 .65596 L
s
1 .134 0 r
.36898 .7419 m
.36941 .74228 L
s
.36947 .74092 m
.36898 .7419 L
s
1 .045 0 r
.77926 .71325 m
.78045 .71247 L
s
1 0 0 r
.83852 .57001 m
.83853 .57001 L
s
1 .215 0 r
.55067 .65596 m
.55935 .65514 L
s
1 .111 0 r
.38135 .45542 m
.38034 .45272 L
s
1 .014 0 r
.15276 .39813 m
.1527 .39776 L
s
1 0 0 r
.83853 .57001 m
.83853 .57001 L
s
.83853 .57001 m
.83853 .57001 L
s
.83853 .57001 m
.83853 .57001 L
s
.83853 .57001 m
.83853 .57001 L
s
.83853 .57001 m
.83853 .57001 L
s
.83853 .57001 m
.83853 .57001 L
s
.83853 .57001 m
.83853 .57001 L
s
.83853 .57001 m
.83853 .57001 L
s
1 .134 0 r
.36991 .74129 m
.36947 .74092 L
s
1 .166 0 r
.61855 .68458 m
.61814 .68496 L
s
.61809 .68331 m
.61855 .68458 L
s
.61933 .6838 m
.61855 .68458 L
s
.61768 .68369 m
.61809 .68331 L
s
.61809 .68331 m
.61933 .6838 L
s
1 .323 0 r
.36217 .36936 m
.36021 .37071 L
s
.36038 .36758 m
.36217 .36936 L
s
1 .095 0 r
.77232 .36933 m
.77291 .36972 L
s
1 .215 0 r
.55741 .65464 m
.5576 .65424 L
s
.5576 .65424 m
.55935 .65514 L
s
1 .095 0 r
.77291 .36972 m
.77343 .36925 L
s
.973 1 0 r
.42088 .36182 m
.42671 .36633 L
s
.41473 .36658 m
.42088 .36182 L
s
.42088 .36182 m
.42014 .36111 L
s
1 .65 0 r
.65985 .3406 m
.65766 .3405 L
s
.65741 .33467 m
.65985 .3406 L
s
.65985 .3406 m
.65411 .33875 L
s
.66096 .33642 m
.65985 .3406 L
s
.64818 .32544 m
.65985 .3406 L
s
1 .014 0 r
.15272 .39777 m
.1528 .39783 L
s
.15263 .39783 m
.15272 .39777 L
s
.15272 .39777 m
.1527 .39776 L
s
.1528 .39783 m
.15271 .3979 L
s
.1527 .39776 m
.1528 .39783 L
s
.15271 .3979 m
.15263 .39783 L
s
.15263 .39783 m
.1527 .39776 L
s
.1527 .39776 m
.15271 .3979 L
s
1 .323 0 r
.36021 .37071 m
.3584 .36914 L
s
.3584 .36914 m
.36038 .36758 L
s
1 .028 0 r
.83523 .39779 m
.83526 .39777 L
s
.83524 .39752 m
.83523 .39779 L
s
.83523 .39779 m
.83508 .39765 L
s
.83542 .39764 m
.83523 .39779 L
s
.83532 .39707 m
.83523 .39779 L
s
.939 1 0 r
.62308 .39011 m
.61768 .39679 L
s
.62878 .3931 m
.62308 .39011 L
s
1 .028 0 r
.83524 .39752 m
.83508 .39765 L
s
.83542 .39764 m
.83524 .39752 L
s
.83508 .39765 m
.83526 .39777 L
s
.83526 .39777 m
.83542 .39764 L
s
1 .162 0 r
.49309 .628 m
.49336 .62671 L
s
1 .045 0 r
.7802 .7124 m
.78042 .7127 L
s
.78001 .71255 m
.7802 .7124 L
s
.7802 .7124 m
.78045 .71247 L
s
.78042 .7127 m
.78023 .71285 L
s
.78045 .71247 m
.78042 .7127 L
s
1 .134 0 r
.36941 .74228 m
.36991 .74129 L
s
1 .045 0 r
.78023 .71285 m
.78001 .71255 L
s
.78001 .71255 m
.78045 .71247 L
s
.78045 .71247 m
.78023 .71285 L
s
1 .215 0 r
.55935 .65514 m
.55762 .65636 L
s
.55741 .65464 m
.55935 .65514 L
s
1 .166 0 r
.61933 .6838 m
.61814 .68496 L
s
.61768 .68369 m
.61933 .6838 L
s
.61814 .68496 m
.61768 .68369 L
s
1 0 0 r
.25929 .56906 m
.25929 .56906 L
s
.25929 .56906 m
.25929 .56906 L
s
.25929 .56906 m
.25929 .56906 L
s
.25929 .56906 m
.25929 .56906 L
s
.25928 .56905 m
.25929 .56906 L
s
.25929 .56906 m
.25929 .56906 L
s
.25929 .56906 m
.25929 .56906 L
s
.25929 .56906 m
.25929 .56906 L
s
.25929 .56906 m
.25929 .56906 L
s
1 .062 0 r
.71672 .68371 m
.71846 .68269 L
s
1 0 0 r
.77602 .54039 m
.77602 .54039 L
s
1 .068 0 r
.31858 .42573 m
.3183 .42403 L
s
1 .323 0 r
.36038 .36758 m
.36021 .37071 L
s
1 .606 0 r
.58232 .47841 m
.57899 .48065 L
s
.58575 .48186 m
.58232 .47841 L
s
.939 1 0 r
.61768 .39679 m
.62338 .3998 L
s
1 .215 0 r
.55762 .65636 m
.55741 .65464 L
s
1 .65 0 r
.65741 .33467 m
.65411 .33875 L
s
.66096 .33642 m
.65741 .33467 L
s
1 .039 0 r
.42645 .59738 m
.42621 .59744 L
s
.42622 .59707 m
.42645 .59738 L
s
.42645 .59738 m
.42606 .59735 L
s
.42636 .59716 m
.42645 .59738 L
s
.42526 .59677 m
.42645 .59738 L
s
.42622 .59707 m
.42606 .59735 L
s
.42636 .59716 m
.42622 .59707 L
s
.42606 .59735 m
.42621 .59744 L
s
0 1 .331 r
.61312 .36789 m
.61773 .37017 L
s
.6171 .34904 m
.61312 .36789 L
s
.63556 .36304 m
.61312 .36789 L
s
1 .039 0 r
.42621 .59744 m
.42636 .59716 L
s
1 .271 0 r
.47738 .74051 m
.47779 .74111 L
s
.47782 .73837 m
.47738 .74051 L
s
.47994 .74006 m
.47738 .74051 L
s
1 .058 0 r
.65002 .4824 m
.65018 .4824 L
s
.65016 .48186 m
.65002 .4824 L
s
.65002 .4824 m
.64985 .48207 L
s
.65049 .48219 m
.65002 .4824 L
s
.65079 .48104 m
.65002 .4824 L
s
1 .062 0 r
.7181 .68258 m
.71838 .68301 L
s
.71785 .68277 m
.7181 .68258 L
s
.7181 .68258 m
.71846 .68269 L
s
1 .058 0 r
.65016 .48186 m
.64985 .48207 L
s
.65049 .48219 m
.65016 .48186 L
s
1 .062 0 r
.71838 .68301 m
.71813 .6832 L
s
.71846 .68269 m
.71838 .68301 L
s
1 .063 0 r
.30482 .71168 m
.30445 .71179 L
s
.3045 .71115 m
.30482 .71168 L
s
.30482 .71168 m
.3042 .71158 L
s
.30475 .71135 m
.30482 .71168 L
s
.30308 .71062 m
.30482 .71168 L
s
1 .111 0 r
.38057 .45274 m
.38118 .45319 L
s
.37991 .45333 m
.38057 .45274 L
s
.38057 .45274 m
.38034 .45272 L
s
1 .271 0 r
.47823 .73897 m
.47782 .73837 L
s
.47782 .73837 m
.47994 .74006 L
s
1 .058 0 r
.65018 .4824 m
.65049 .48219 L
s
1 .063 0 r
.3045 .71115 m
.3042 .71158 L
s
.30475 .71135 m
.3045 .71115 L
s
1 .199 0 r
.44081 .48073 m
.44179 .48134 L
s
.43978 .482 m
.44081 .48073 L
s
.44081 .48073 m
.43997 .48081 L
s
1 .063 0 r
.3042 .71158 m
.30445 .71179 L
s
1 .65 0 r
.65411 .33875 m
.65766 .3405 L
s
1 .002 0 r
.71342 .51077 m
.71342 .51077 L
s
.71342 .51075 m
.71342 .51077 L
s
.71342 .51077 m
.71341 .51076 L
s
.71343 .51076 m
.71342 .51077 L
s
.71344 .51073 m
.71342 .51077 L
s
.71342 .51075 m
.71341 .51076 L
s
.71343 .51076 m
.71342 .51075 L
s
.71342 .51077 m
.71343 .51076 L
s
.71341 .51076 m
.71342 .51077 L
s
1 .058 0 r
.64985 .48207 m
.65018 .4824 L
s
1 .018 0 r
.88296 .7115 m
.88338 .71115 L
s
1 0 0 r
.94229 .56809 m
.94229 .56809 L
s
1 .09 0 r
.65411 .65414 m
.65693 .6528 L
s
0 1 .566 r
.48459 .45337 m
.43167 .39567 L
s
1 0 0 r
.19641 .53941 m
.19641 .53941 L
s
1 .047 0 r
.25574 .39601 m
.25565 .39481 L
s
1 0 0 r
.94229 .56809 m
.94229 .56809 L
s
.94229 .56809 m
.94229 .56809 L
s
.94229 .56809 m
.94229 .56809 L
s
.94229 .56809 m
.94229 .56809 L
s
.94229 .56809 m
.94229 .56809 L
s
.94229 .56809 m
.94229 .56809 L
s
.94229 .56809 m
.94229 .56809 L
s
.94229 .56809 m
.94229 .56809 L
s
1 .336 0 r
.67176 .39599 m
.67149 .39583 L
s
.67134 .39276 m
.67176 .39599 L
s
.67176 .39599 m
.66946 .39451 L
s
.67337 .39408 m
.67176 .39599 L
s
.67004 .38749 m
.67176 .39599 L
s
1 .111 0 r
.38052 .45378 m
.37991 .45333 L
s
.37991 .45333 m
.38034 .45272 L
s
1 .062 0 r
.71813 .6832 m
.71785 .68277 L
s
.71785 .68277 m
.71846 .68269 L
s
1 .199 0 r
.44076 .4826 m
.43978 .482 L
s
.43978 .482 m
.43997 .48081 L
s
1 .062 0 r
.71846 .68269 m
.71813 .6832 L
s
1 .068 0 r
.31837 .42406 m
.31875 .42436 L
s
.31796 .42438 m
.31837 .42406 L
s
.31837 .42406 m
.3183 .42403 L
s
1 .271 0 r
.47994 .74006 m
.47779 .74111 L
s
.47823 .73897 m
.47994 .74006 L
s
.46927 .73845 m
.47994 .74006 L
s
1 .063 0 r
.30445 .71179 m
.30475 .71135 L
s
1 .111 0 r
.38118 .45319 m
.38052 .45378 L
s
.38034 .45272 m
.38118 .45319 L
s
1 .606 0 r
.58242 .4841 m
.58575 .48186 L
s
1 .018 0 r
.88328 .71112 m
.88338 .71124 L
s
.8832 .71119 m
.88328 .71112 L
s
.88328 .71112 m
.88338 .71115 L
s
.88338 .71124 m
.8833 .71131 L
s
.88338 .71115 m
.88338 .71124 L
s
1 .068 0 r
.31833 .42468 m
.31796 .42438 L
s
.31796 .42438 m
.3183 .42403 L
s
.31875 .42436 m
.31833 .42468 L
s
.3183 .42403 m
.31875 .42436 L
s
1 .018 0 r
.8833 .71131 m
.8832 .71119 L
s
.8832 .71119 m
.88338 .71115 L
s
.88338 .71115 m
.8833 .71131 L
s
1 .111 0 r
.38034 .45272 m
.38052 .45378 L
s
1 .068 0 r
.3183 .42403 m
.31833 .42468 L
s
1 .172 0 r
.41061 .71096 m
.41113 .7114 L
s
.41118 .70967 m
.41061 .71096 L
s
.41234 .71096 m
.41061 .71096 L
s
.41234 .71096 m
.41113 .7114 L
s
.41118 .70967 m
.41234 .71096 L
s
.4117 .71011 m
.41234 .71096 L
s
.40641 .70886 m
.41234 .71096 L
s
.4117 .71011 m
.41118 .70967 L
s
.973 1 0 r
.42056 .37111 m
.41473 .36658 L
s
.41473 .36658 m
.42014 .36111 L
s
1 .199 0 r
.44179 .48134 m
.44076 .4826 L
s
.43997 .48081 m
.44179 .48134 L
s
1 .336 0 r
.67134 .39276 m
.66946 .39451 L
s
.67337 .39408 m
.67134 .39276 L
s
1 .047 0 r
.25569 .39484 m
.25594 .39506 L
s
.25539 .39504 m
.25569 .39484 L
s
.25569 .39484 m
.25565 .39481 L
s
1 .199 0 r
.43997 .48081 m
.44076 .4826 L
s
1 .047 0 r
.25594 .39506 m
.25565 .39527 L
s
.25565 .39481 m
.25594 .39506 L
s
.25565 .39527 m
.25539 .39504 L
s
.25539 .39504 m
.25565 .39481 L
s
.973 1 0 r
.42671 .36633 m
.42056 .37111 L
s
.42014 .36111 m
.42671 .36633 L
s
1 .09 0 r
.6567 .65328 m
.65638 .65351 L
s
.65635 .65263 m
.6567 .65328 L
s
.65693 .6528 m
.6567 .65328 L
s
.65603 .65286 m
.65635 .65263 L
s
.65635 .65263 m
.65693 .6528 L
s
1 .002 0 r
.36249 .56718 m
.36248 .56718 L
s
.36248 .56716 m
.36249 .56718 L
s
.36249 .56718 m
.36247 .56717 L
s
.36249 .56716 m
.36249 .56718 L
s
.36244 .56713 m
.36249 .56718 L
s
.36248 .56716 m
.36247 .56717 L
s
.36249 .56716 m
.36248 .56716 L
s
.36247 .56717 m
.36248 .56718 L
s
.36248 .56718 m
.36249 .56716 L
s
1 0 0 r
.87978 .53843 m
.87978 .53843 L
s
1 .022 0 r
.82041 .68192 m
.8209 .68151 L
s
1 .133 0 r
.59143 .62453 m
.59627 .62311 L
s
1 .59 0 r
.42181 .42365 m
.42015 .40866 L
s
1 .035 0 r
.19283 .36625 m
.19279 .36534 L
s
1 .047 0 r
.25565 .39481 m
.25565 .39527 L
s
1 .08 0 r
.81421 .33744 m
.81419 .33739 L
s
.81413 .33667 m
.81421 .33744 L
s
.81421 .33744 m
.81369 .33708 L
s
.81463 .33697 m
.81421 .33744 L
s
.81396 .33536 m
.81421 .33744 L
s
1 .271 0 r
.47779 .74111 m
.47823 .73897 L
s
1 .08 0 r
.81413 .33667 m
.81369 .33708 L
s
.81463 .33697 m
.81413 .33667 L
s
0 1 .331 r
.62174 .35117 m
.6171 .34904 L
s
.6171 .34904 m
.63556 .36304 L
s
1 .029 0 r
.87655 .36592 m
.87658 .3659 L
s
.87655 .36564 m
.87655 .36592 L
s
.87655 .36592 m
.87639 .36578 L
s
.87673 .36576 m
.87655 .36592 L
s
.87659 .36517 m
.87655 .36592 L
s
1 .022 0 r
.8208 .68148 m
.82091 .68162 L
s
.8207 .68156 m
.8208 .68148 L
s
.8208 .68148 m
.8209 .68151 L
s
.82091 .68162 m
.82082 .6817 L
s
.8209 .68151 m
.82091 .68162 L
s
1 .029 0 r
.87655 .36564 m
.87639 .36578 L
s
.87673 .36576 m
.87655 .36564 L
s
1 .606 0 r
.57899 .48065 m
.58242 .4841 L
s
1 .09 0 r
.65638 .65351 m
.65603 .65286 L
s
.65693 .6528 m
.65638 .65351 L
s
.65603 .65286 m
.65693 .6528 L
s
1 .022 0 r
.82082 .6817 m
.8207 .68156 L
s
.8207 .68156 m
.8209 .68151 L
s
1 .336 0 r
.66946 .39451 m
.67149 .39583 L
s
1 .022 0 r
.8209 .68151 m
.82082 .6817 L
s
1 .08 0 r
.81369 .33708 m
.81419 .33739 L
s
1 .029 0 r
.87639 .36578 m
.87658 .3659 L
s
.87658 .3659 m
.87673 .36576 L
s
1 .024 0 r
.24071 .68149 m
.24059 .68152 L
s
.24061 .68127 m
.24071 .68149 L
s
.24071 .68149 m
.24048 .68143 L
s
.24072 .68136 m
.24071 .68149 L
s
.24015 .68103 m
.24071 .68149 L
s
.24061 .68127 m
.24048 .68143 L
s
.24072 .68136 m
.24061 .68127 L
s
1 .08 0 r
.81419 .33739 m
.81463 .33697 L
s
1 .172 0 r
.41113 .7114 m
.4117 .71011 L
s
1 .024 0 r
.24048 .68143 m
.24059 .68152 L
s
1 .035 0 r
.19282 .36537 m
.19301 .36554 L
s
.1926 .36551 m
.19282 .36537 L
s
.19282 .36537 m
.19279 .36534 L
s
1 .136 0 r
.53313 .59524 m
.53311 .59546 L
s
.53311 .59414 m
.53313 .59524 L
s
.53422 .59478 m
.53313 .59524 L
s
1 .024 0 r
.24059 .68152 m
.24072 .68136 L
s
1 .035 0 r
.19301 .36554 m
.19278 .36568 L
s
.19279 .36534 m
.19301 .36554 L
s
.19278 .36568 m
.1926 .36551 L
s
.1926 .36551 m
.19279 .36534 L
s
1 .136 0 r
.53308 .59436 m
.53311 .59414 L
s
.53311 .59414 m
.53422 .59478 L
s
1 .035 0 r
.19279 .36534 m
.19278 .36568 L
s
1 .336 0 r
.67149 .39583 m
.67337 .39408 L
s
1 .133 0 r
.59565 .62377 m
.59531 .62404 L
s
.59529 .62274 m
.59565 .62377 L
s
.59627 .62311 m
.59565 .62377 L
s
.59495 .62302 m
.59529 .62274 L
s
.59529 .62274 m
.59627 .62311 L
s
1 0 0 r
.81718 .50875 m
.81718 .50875 L
s
.81718 .50875 m
.81718 .50875 L
s
.81718 .50875 m
.81718 .50875 L
s
.81719 .50875 m
.81718 .50875 L
s
.81719 .50874 m
.81718 .50875 L
s
.81718 .50875 m
.81718 .50875 L
s
.81719 .50875 m
.81718 .50875 L
s
.81718 .50875 m
.81719 .50875 L
s
.81718 .50875 m
.81718 .50875 L
s
1 .026 0 r
.75779 .65231 m
.7584 .65182 L
s
1 .136 0 r
.52867 .59488 m
.53422 .59478 L
s
1 0 0 r
.29955 .53746 m
.29955 .53746 L
s
1 .229 0 r
.35895 .39389 m
.35928 .38803 L
s
1 .028 0 r
.12984 .33646 m
.12983 .33573 L
s
1 .65 0 r
.65766 .3405 m
.66096 .33642 L
s
1 .136 0 r
.53422 .59478 m
.53311 .59546 L
s
.53308 .59436 m
.53422 .59478 L
s
1 .07 0 r
.69137 .45099 m
.69147 .45097 L
s
.69143 .45031 m
.69137 .45099 L
s
.69137 .45099 m
.69104 .45062 L
s
.69186 .45066 m
.69137 .45099 L
s
.69179 .44925 m
.69137 .45099 L
s
1 .026 0 r
.75827 .65179 m
.7584 .65196 L
s
.75815 .65187 m
.75827 .65179 L
s
.75827 .65179 m
.7584 .65182 L
s
0 .813 1 r
.54671 .65196 m
.53439 .65542 L
s
.5343 .62375 m
.54671 .65196 L
s
.54671 .65196 m
.51784 .64435 L
s
.55095 .63464 m
.54671 .65196 L
s
.48288 .5877 m
.54671 .65196 L
s
1 .026 0 r
.7584 .65196 m
.75829 .65205 L
s
.7584 .65182 m
.7584 .65196 L
s
1 .136 0 r
.53311 .59546 m
.53308 .59436 L
s
1 .028 0 r
.12985 .33575 m
.12999 .33589 L
s
.12967 .33586 m
.12985 .33575 L
s
.12985 .33575 m
.12983 .33573 L
s
1 .07 0 r
.69143 .45031 m
.69104 .45062 L
s
.69186 .45066 m
.69143 .45031 L
s
1 .026 0 r
.75829 .65205 m
.75815 .65187 L
s
.75815 .65187 m
.7584 .65182 L
s
.7584 .65182 m
.75829 .65205 L
s
1 .028 0 r
.12999 .33589 m
.12981 .336 L
s
.12983 .33573 m
.12999 .33589 L
s
1 .133 0 r
.59627 .62311 m
.59531 .62404 L
s
.59495 .62302 m
.59627 .62311 L
s
0 1 .511 r
.6228 .35408 m
.6271 .33373 L
s
1 .028 0 r
.12981 .336 m
.12967 .33586 L
s
.12967 .33586 m
.12983 .33573 L
s
1 .133 0 r
.59531 .62404 m
.59495 .62302 L
s
.425 1 0 r
.59674 .47943 m
.59101 .48006 L
s
.5907 .46524 m
.59674 .47943 L
s
.59674 .47943 m
.58263 .47527 L
s
.5991 .46999 m
.59674 .47943 L
s
.56683 .44491 m
.59674 .47943 L
s
1 .028 0 r
.12983 .33573 m
.12981 .336 L
s
1 .075 0 r
.34557 .68047 m
.34513 .6806 L
s
.34517 .67985 m
.34557 .68047 L
s
.34557 .68047 m
.34483 .68037 L
s
.34547 .68008 m
.34557 .68047 L
s
.34347 .67923 m
.34557 .68047 L
s
1 .07 0 r
.69147 .45097 m
.69186 .45066 L
s
.69104 .45062 m
.69147 .45097 L
s
1 .075 0 r
.34517 .67985 m
.34483 .68037 L
s
.34547 .68008 m
.34517 .67985 L
s
1 .021 0 r
.46634 .56548 m
.4664 .56553 L
s
.46641 .56533 m
.46634 .56548 L
s
.46655 .56548 m
.46634 .56548 L
s
.46655 .56548 m
.4664 .56553 L
s
.46641 .56533 m
.46655 .56548 L
s
.46647 .56537 m
.46655 .56548 L
s
.46584 .56521 m
.46655 .56548 L
s
.46647 .56537 m
.46641 .56533 L
s
1 .075 0 r
.34483 .68037 m
.34513 .6806 L
s
.939 1 0 r
.62338 .3998 m
.62878 .3931 L
s
1 .021 0 r
.4664 .56553 m
.46647 .56537 L
s
1 .007 0 r
.75446 .47918 m
.75448 .47918 L
s
.75447 .47911 m
.75446 .47918 L
s
.75446 .47918 m
.75444 .47914 L
s
.75451 .47915 m
.75446 .47918 L
s
.75452 .47901 m
.75446 .47918 L
s
.75447 .47911 m
.75444 .47914 L
s
.75451 .47915 m
.75447 .47911 L
s
.75448 .47918 m
.75451 .47915 L
s
.75444 .47914 m
.75448 .47918 L
s
1 .009 0 r
.92434 .68013 m
.92451 .67995 L
s
1 .032 0 r
.69509 .62267 m
.6959 .62208 L
s
1 0 0 r
.23659 .50775 m
.23659 .50774 L
s
1 .121 0 r
.29603 .36409 m
.29637 .36096 L
s
1 0 0 r
.23659 .50774 m
.23659 .50774 L
s
.23659 .50774 m
.23659 .50774 L
s
.23659 .50774 m
.23659 .50774 L
s
.23659 .50774 m
.23659 .50774 L
s
.23659 .50774 m
.23659 .50774 L
s
.23659 .50774 m
.23659 .50774 L
s
.23659 .50774 m
.23659 .50774 L
s
.23659 .50774 m
.23659 .50774 L
s
1 .075 0 r
.34513 .6806 m
.34547 .68008 L
s
1 .009 0 r
.92447 .67995 m
.92452 .68 L
s
.92443 .67998 m
.92447 .67995 L
s
.92447 .67995 m
.92451 .67995 L
s
.92452 .68 m
.92448 .68003 L
s
.92451 .67995 m
.92452 .68 L
s
.92448 .68003 m
.92443 .67998 L
s
.92443 .67998 m
.92451 .67995 L
s
.92451 .67995 m
.92448 .68003 L
s
1 .229 0 r
.45315 .67991 m
.45372 .68043 L
s
.45377 .67815 m
.45315 .67991 L
s
.45542 .67975 m
.45315 .67991 L
s
1 .323 0 r
.52037 .70858 m
.52054 .70923 L
s
.52054 .70597 m
.52037 .70858 L
s
.52318 .70773 m
.52037 .70858 L
s
1 .229 0 r
.45434 .67866 m
.45377 .67815 L
s
.45377 .67815 m
.45542 .67975 L
s
.973 1 0 r
.42014 .36111 m
.42056 .37111 L
s
1 .229 0 r
.45542 .67975 m
.45372 .68043 L
s
.45434 .67866 m
.45542 .67975 L
s
.44703 .67743 m
.45542 .67975 L
s
1 .032 0 r
.69573 .62204 m
.69589 .62226 L
s
.69559 .62214 m
.69573 .62204 L
s
.69573 .62204 m
.6959 .62208 L
s
.69589 .62226 m
.69575 .62235 L
s
.6959 .62208 m
.69589 .62226 L
s
.69575 .62235 m
.69559 .62214 L
s
.69559 .62214 m
.6959 .62208 L
s
.6959 .62208 m
.69575 .62235 L
s
1 .323 0 r
.52071 .70662 m
.52054 .70597 L
s
.52054 .70597 m
.52318 .70773 L
s
0 1 .331 r
.63556 .36304 m
.61773 .37017 L
s
.62174 .35117 m
.63556 .36304 L
s
.54414 .34555 m
.63556 .36304 L
s
1 0 0 r
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
1 .009 0 r
.8617 .65048 m
.86187 .65031 L
s
1 .293 0 r
.57285 .73673 m
.58454 .7352 L
s
1 .039 0 r
.63232 .59299 m
.63345 .59234 L
s
1 0 0 r
.40294 .5355 m
.40294 .5355 L
s
0 1 .077 r
.46241 .39176 m
.48556 .33915 L
s
1 .001 0 r
.17356 .478 m
.17355 .47797 L
s
1 .077 0 r
.23303 .33426 m
.23328 .33226 L
s
1 .001 0 r
.17355 .47797 m
.17356 .47798 L
s
.17354 .47798 m
.17355 .47797 L
s
.17355 .47797 m
.17355 .47797 L
s
.17355 .47798 m
.17354 .47798 L
s
.17354 .47798 m
.17355 .47797 L
s
.17356 .47798 m
.17355 .47798 L
s
.17355 .47797 m
.17356 .47798 L
s
.17355 .47797 m
.17355 .47798 L
s
1 .398 0 r
.53589 .5073 m
.53699 .50662 L
s
.53699 .50662 m
.53588 .50352 L
s
.53699 .50662 m
.53301 .50633 L
s
1 .009 0 r
.86183 .6503 m
.86188 .65035 L
s
.86179 .65033 m
.86183 .6503 L
s
.86183 .6503 m
.86187 .65031 L
s
.86188 .65035 m
.86184 .65038 L
s
.86187 .65031 m
.86188 .65035 L
s
.86184 .65038 m
.86179 .65033 L
s
.86179 .65033 m
.86187 .65031 L
s
.86187 .65031 m
.86184 .65038 L
s
1 .323 0 r
.52318 .70773 m
.52054 .70923 L
s
.52071 .70662 m
.52318 .70773 L
s
.50997 .7071 m
.52318 .70773 L
s
1 .398 0 r
.53588 .50352 m
.53478 .5042 L
s
.53588 .50352 m
.53301 .50633 L
s
0 .434 1 r
.55411 .6789 m
.5404 .68317 L
s
.54024 .6474 m
.55411 .6789 L
s
.55411 .6789 m
.52181 .67052 L
s
.55896 .65982 m
.55411 .6789 L
s
.48262 .60782 m
.55411 .6789 L
s
1 .398 0 r
.53301 .50633 m
.53589 .5073 L
s
.53301 .50633 m
.53478 .5042 L
s
.54743 .50174 m
.53301 .50633 L
s
1 .293 0 r
.58259 .73636 m
.58222 .737 L
s
.58217 .73402 m
.58259 .73636 L
s
.58454 .7352 m
.58259 .73636 L
s
1 .039 0 r
.63321 .59229 m
.63338 .59256 L
s
.63306 .59239 m
.63321 .59229 L
s
.63321 .59229 m
.63345 .59234 L
s
.63338 .59256 m
.63323 .59266 L
s
.63345 .59234 m
.63338 .59256 L
s
1 .023 0 r
.28099 .65003 m
.28088 .65005 L
s
.28089 .64982 m
.28099 .65003 L
s
.28099 .65003 m
.28077 .64997 L
s
.281 .6499 m
.28099 .65003 L
s
.28046 .64957 m
.28099 .65003 L
s
1 .229 0 r
.45372 .68043 m
.45434 .67866 L
s
1 .023 0 r
.28089 .64982 m
.28077 .64997 L
s
.281 .6499 m
.28089 .64982 L
s
.28077 .64997 m
.28088 .65005 L
s
1 .039 0 r
.63323 .59266 m
.63306 .59239 L
s
.63306 .59239 m
.63345 .59234 L
s
1 .023 0 r
.28088 .65005 m
.281 .6499 L
s
1 .039 0 r
.63345 .59234 m
.63323 .59266 L
s
1 .293 0 r
.5818 .73466 m
.58217 .73402 L
s
.58217 .73402 m
.58454 .7352 L
s
1 .825 0 r
.42069 .38488 m
.4254 .38855 L
s
.41574 .38875 m
.42069 .38488 L
s
.42069 .38488 m
.4201 .38439 L
s
1 .002 0 r
.85848 .47702 m
.85849 .47702 L
s
.85849 .47701 m
.85848 .47702 L
s
.85848 .47702 m
.85848 .47702 L
s
.8585 .47702 m
.85848 .47702 L
s
.8585 .47699 m
.85848 .47702 L
s
.85849 .47701 m
.85848 .47702 L
s
.8585 .47702 m
.85849 .47701 L
s
.85849 .47702 m
.8585 .47702 L
s
.85848 .47702 m
.85849 .47702 L
s
1 .008 0 r
.79899 .62081 m
.79915 .62063 L
s
1 .032 0 r
.56948 .56328 m
.57063 .56292 L
s
1 .002 0 r
.33996 .50575 m
.33994 .50571 L
s
1 .607 0 r
.39947 .36193 m
.40559 .34661 L
s
1 .121 0 r
.29634 .36104 m
.29701 .36165 L
s
.29559 .36152 m
.29634 .36104 L
s
.29634 .36104 m
.29637 .36096 L
s
1 .002 0 r
.33995 .50571 m
.33996 .50571 L
s
.33993 .50572 m
.33995 .50571 L
s
.33995 .50571 m
.33994 .50571 L
s
.33994 .50572 m
.33993 .50572 L
s
.33993 .50572 m
.33994 .50571 L
s
.33996 .50571 m
.33994 .50572 L
s
.33994 .50571 m
.33996 .50571 L
s
.33994 .50571 m
.33994 .50572 L
s
1 .008 0 r
.79912 .62063 m
.79916 .62068 L
s
.79908 .62066 m
.79912 .62063 L
s
.79912 .62063 m
.79915 .62063 L
s
.79916 .62068 m
.79913 .62071 L
s
.79915 .62063 m
.79916 .62068 L
s
.79913 .62071 m
.79908 .62066 L
s
.79908 .62066 m
.79915 .62063 L
s
.79915 .62063 m
.79913 .62071 L
s
1 .032 0 r
.57049 .56309 m
.57041 .56315 L
s
.5704 .56284 m
.57049 .56309 L
s
.57063 .56292 m
.57049 .56309 L
s
.57032 .5629 m
.5704 .56284 L
s
.5704 .56284 m
.57063 .56292 L
s
1 .323 0 r
.52054 .70923 m
.52071 .70662 L
s
1 .121 0 r
.29701 .36165 m
.29626 .36214 L
s
.29637 .36096 m
.29701 .36165 L
s
1 .077 0 r
.23326 .33232 m
.23368 .33271 L
s
.23278 .33261 m
.23326 .33232 L
s
.23326 .33232 m
.23328 .33226 L
s
.425 1 0 r
.5907 .46524 m
.58263 .47527 L
s
.5991 .46999 m
.5907 .46524 L
s
1 .032 0 r
.57063 .56292 m
.57041 .56315 L
s
.57032 .5629 m
.57063 .56292 L
s
1 .068 0 r
.73282 .41907 m
.73287 .41904 L
s
.73282 .41842 m
.73282 .41907 L
s
.73282 .41907 m
.73245 .41874 L
s
.73324 .41872 m
.73282 .41907 L
s
.73293 .41736 m
.73282 .41907 L
s
1 .032 0 r
.57041 .56315 m
.57032 .5629 L
s
1 .121 0 r
.29626 .36214 m
.29559 .36152 L
s
.29559 .36152 m
.29637 .36096 L
s
1 .09 0 r
.38662 .6492 m
.38608 .64935 L
s
.38612 .64846 m
.38662 .6492 L
s
.38662 .6492 m
.38573 .6491 L
s
.38647 .64872 m
.38662 .6492 L
s
.384 .64773 m
.38662 .6492 L
s
1 .077 0 r
.23368 .33271 m
.23319 .33301 L
s
.23328 .33226 m
.23368 .33271 L
s
1 .09 0 r
.38612 .64846 m
.38573 .6491 L
s
.38647 .64872 m
.38612 .64846 L
s
1 .077 0 r
.23319 .33301 m
.23278 .33261 L
s
.23278 .33261 m
.23328 .33226 L
s
1 .09 0 r
.38573 .6491 m
.38608 .64935 L
s
1 .068 0 r
.73282 .41842 m
.73245 .41874 L
s
.73324 .41872 m
.73282 .41842 L
s
0 1 .566 r
.5346 .62027 m
.52457 .62274 L
s
.52457 .59746 m
.5346 .62027 L
s
.5346 .62027 m
.51129 .61402 L
s
.53791 .60606 m
.5346 .62027 L
s
.48313 .56782 m
.5346 .62027 L
s
1 .121 0 r
.29637 .36096 m
.29626 .36214 L
s
1 .077 0 r
.23328 .33226 m
.23319 .33301 L
s
1 .068 0 r
.73245 .41874 m
.73287 .41904 L
s
.73287 .41904 m
.73324 .41872 L
s
1 .012 0 r
.79568 .44748 m
.7957 .44748 L
s
.79569 .44737 m
.79568 .44748 L
s
.79568 .44748 m
.79563 .44742 L
s
.79577 .44743 m
.79568 .44748 L
s
.79575 .44719 m
.79568 .44748 L
s
.79569 .44737 m
.79563 .44742 L
s
.79577 .44743 m
.79569 .44737 L
s
1 .293 0 r
.58454 .7352 m
.58222 .737 L
s
.5818 .73466 m
.58454 .7352 L
s
1 .012 0 r
.7957 .44748 m
.79577 .44743 L
s
.79563 .44742 m
.7957 .44748 L
s
1 .229 0 r
.35927 .38816 m
.36056 .38928 L
s
.35788 .38913 m
.35927 .38816 L
s
.35927 .38816 m
.35928 .38803 L
s
1 .22 0 r
.71293 .361 m
.71265 .36088 L
s
.71253 .35889 m
.71293 .361 L
s
.71293 .361 m
.71132 .36009 L
s
.71386 .35968 m
.71293 .361 L
s
.71123 .35541 m
.71293 .361 L
s
1 .006 0 r
.21748 .61999 m
.21746 .61999 L
s
.21746 .61994 m
.21748 .61999 L
s
.21748 .61999 m
.21743 .61997 L
s
.21749 .61996 m
.21748 .61999 L
s
.21738 .61987 m
.21748 .61999 L
s
.21746 .61994 m
.21743 .61997 L
s
.21749 .61996 m
.21746 .61994 L
s
.21743 .61997 m
.21746 .61999 L
s
.21746 .61999 m
.21749 .61996 L
s
1 .09 0 r
.38608 .64935 m
.38647 .64872 L
s
1 .003 0 r
.96586 .64865 m
.96592 .64858 L
s
1 .158 0 r
.67667 .73499 m
.68189 .73287 L
s
1 .007 0 r
.73621 .59109 m
.73634 .59095 L
s
1 0 0 r
.50656 .53353 m
.50656 .53353 L
s
1 .005 0 r
.27692 .47597 m
.27687 .47585 L
s
1 .271 0 r
.33645 .33207 m
.33894 .32515 L
s
1 .003 0 r
.96591 .64858 m
.96593 .6486 L
s
.96589 .64859 m
.96591 .64858 L
s
.96591 .64858 m
.96592 .64858 L
s
.96593 .6486 m
.96591 .64861 L
s
.96592 .64858 m
.96593 .6486 L
s
.96591 .64861 m
.96589 .64859 L
s
.96589 .64859 m
.96592 .64858 L
s
.96592 .64858 m
.96591 .64861 L
s
1 .005 0 r
.27689 .47585 m
.27691 .47587 L
s
.27685 .47587 m
.27689 .47585 L
s
.27689 .47585 m
.27687 .47585 L
s
.27688 .47589 m
.27685 .47587 L
s
.27685 .47587 m
.27687 .47585 L
s
.27691 .47587 m
.27688 .47589 L
s
.27687 .47585 m
.27691 .47587 L
s
1 .007 0 r
.73632 .59095 m
.73635 .59099 L
s
.73628 .59097 m
.73632 .59095 L
s
.73632 .59095 m
.73634 .59095 L
s
.73635 .59099 m
.73632 .59101 L
s
.73634 .59095 m
.73635 .59099 L
s
1 .005 0 r
.27687 .47585 m
.27688 .47589 L
s
1 .007 0 r
.73632 .59101 m
.73628 .59097 L
s
.73628 .59097 m
.73634 .59095 L
s
.73634 .59095 m
.73632 .59101 L
s
1 .293 0 r
.58222 .737 m
.5818 .73466 L
s
1 .229 0 r
.36056 .38928 m
.35916 .39025 L
s
.35928 .38803 m
.36056 .38928 L
s
1 .22 0 r
.71253 .35889 m
.71132 .36009 L
s
.71386 .35968 m
.71253 .35889 L
s
1 .303 0 r
.49688 .64835 m
.49736 .64893 L
s
.49738 .64593 m
.49688 .64835 L
s
.49976 .64781 m
.49688 .64835 L
s
1 .398 0 r
.53478 .5042 m
.53589 .5073 L
s
.808 1 0 r
.61289 .33158 m
.61724 .33323 L
s
.61692 .32252 m
.61289 .33158 L
s
.62492 .33151 m
.61289 .33158 L
s
1 .229 0 r
.35916 .39025 m
.35788 .38913 L
s
.35788 .38913 m
.35928 .38803 L
s
.808 1 0 r
.62492 .33151 m
.61724 .33323 L
s
.61692 .32252 m
.62492 .33151 L
s
.62129 .32414 m
.62492 .33151 L
s
.58541 .31317 m
.62492 .33151 L
s
1 .303 0 r
.49786 .64651 m
.49738 .64593 L
s
.49738 .64593 m
.49976 .64781 L
s
.425 1 0 r
.58263 .47527 m
.59101 .48006 L
s
1 .344 0 r
.62955 .44647 m
.62961 .44635 L
s
.6295 .44314 m
.62955 .44647 L
s
.62955 .44647 m
.62753 .44479 L
s
.63158 .44471 m
.62955 .44647 L
s
.62959 .43783 m
.62955 .44647 L
s
1 .22 0 r
.71132 .36009 m
.71265 .36088 L
s
.808 1 0 r
.62129 .32414 m
.61692 .32252 L
s
1 .825 0 r
.42044 .39243 m
.41574 .38875 L
s
.41574 .38875 m
.4201 .38439 L
s
1 .741 0 r
.40627 .32576 m
.41036 .32988 L
s
.40192 .32828 m
.40627 .32576 L
s
.40627 .32576 m
.40764 .32529 L
s
1 .303 0 r
.49976 .64781 m
.49736 .64893 L
s
.49786 .64651 m
.49976 .64781 L
s
.48779 .6459 m
.49976 .64781 L
s
1 .229 0 r
.35928 .38803 m
.35916 .39025 L
s
1 .003 0 r
.90314 .61894 m
.90318 .61888 L
s
1 .241 0 r
.61378 .70533 m
.62263 .70288 L
s
1 .003 0 r
.67336 .56134 m
.67342 .56128 L
s
1 .032 0 r
.44358 .50375 m
.44292 .50307 L
s
0 .197 1 r
.50315 .35976 m
.64347 .3111 L
s
1 .007 0 r
.2138 .44615 m
.21376 .44598 L
s
1 .825 0 r
.4254 .38855 m
.42044 .39243 L
s
.4201 .38439 m
.4254 .38855 L
s
1 .003 0 r
.90317 .61888 m
.90319 .61889 L
s
.90316 .61889 m
.90317 .61888 L
s
.90317 .61888 m
.90318 .61888 L
s
.67341 .56127 m
.67343 .56129 L
s
.67339 .56128 m
.67341 .56127 L
s
.67341 .56127 m
.67342 .56128 L
s
.90319 .61889 m
.90318 .6189 L
s
.90318 .61888 m
.90319 .61889 L
s
.67343 .56129 m
.67341 .56131 L
s
.67342 .56128 m
.67343 .56129 L
s
.90318 .6189 m
.90316 .61889 L
s
.90316 .61889 m
.90318 .61888 L
s
.90318 .61888 m
.90318 .6189 L
s
.67341 .56131 m
.67339 .56128 L
s
.67339 .56128 m
.67342 .56128 L
s
.67342 .56128 m
.67341 .56131 L
s
1 .22 0 r
.71265 .36088 m
.71386 .35968 L
s
1 .007 0 r
.21377 .44598 m
.2138 .44601 L
s
.21372 .44602 m
.21377 .44598 L
s
.21377 .44598 m
.21376 .44598 L
s
.21376 .44605 m
.21372 .44602 L
s
.21372 .44602 m
.21376 .44598 L
s
.2138 .44601 m
.21376 .44605 L
s
.21376 .44598 m
.2138 .44601 L
s
.21376 .44598 m
.21376 .44605 L
s
1 .032 0 r
.44306 .50306 m
.44321 .50316 L
s
.44289 .50326 m
.44306 .50306 L
s
.44306 .50306 m
.44292 .50307 L
s
1 .344 0 r
.6295 .44314 m
.62753 .44479 L
s
.63158 .44471 m
.6295 .44314 L
s
1 .032 0 r
.44305 .50336 m
.44289 .50326 L
s
.44289 .50326 m
.44292 .50307 L
s
1 .158 0 r
.6814 .73366 m
.68088 .7341 L
s
.68081 .73249 m
.6814 .73366 L
s
.68189 .73287 m
.6814 .73366 L
s
1 .021 0 r
.32137 .61842 m
.32127 .61844 L
s
.32129 .61823 m
.32137 .61842 L
s
.32137 .61842 m
.32118 .61837 L
s
.32139 .61831 m
.32137 .61842 L
s
.32091 .618 m
.32137 .61842 L
s
1 .158 0 r
.68029 .73293 m
.68081 .73249 L
s
.68081 .73249 m
.68189 .73287 L
s
1 .021 0 r
.32129 .61823 m
.32118 .61837 L
s
.32139 .61831 m
.32129 .61823 L
s
1 .032 0 r
.44321 .50316 m
.44305 .50336 L
s
.44292 .50307 m
.44321 .50316 L
s
1 .021 0 r
.32118 .61837 m
.32127 .61844 L
s
1 .032 0 r
.44292 .50307 m
.44305 .50336 L
s
1 .021 0 r
.32127 .61844 m
.32139 .61831 L
s
0 .813 1 r
.5343 .62375 m
.51784 .64435 L
s
.55095 .63464 m
.5343 .62375 L
s
1 .003 0 r
.89993 .4452 m
.89994 .4452 L
s
.89993 .44517 m
.89993 .4452 L
s
.89993 .4452 m
.89991 .44518 L
s
.89995 .44519 m
.89993 .4452 L
s
.89995 .44512 m
.89993 .4452 L
s
.89993 .44517 m
.89991 .44518 L
s
.89995 .44519 m
.89993 .44517 L
s
.89994 .4452 m
.89995 .44519 L
s
.89991 .44518 m
.89994 .4452 L
s
1 .741 0 r
.41036 .32988 m
.40601 .33241 L
s
.40764 .32529 m
.41036 .32988 L
s
1 .336 0 r
.56204 .67564 m
.56174 .67629 L
s
.5617 .67293 m
.56204 .67564 L
s
.56445 .67436 m
.56204 .67564 L
s
1 .066 0 r
.78074 .73326 m
.78248 .73213 L
s
1 .002 0 r
.84034 .58919 m
.84037 .58915 L
s
1 .336 0 r
.55082 .67563 m
.56445 .67436 L
s
1 0 0 r
.61043 .53156 m
.61043 .53156 L
s
1 .039 0 r
.38052 .47393 m
.38016 .473 L
s
.808 1 0 r
.44012 .32986 m
.46742 .30351 L
s
1 .008 0 r
.1506 .4163 m
.15057 .41611 L
s
1 .002 0 r
.84036 .58915 m
.84038 .58916 L
s
.84036 .58916 m
.84036 .58915 L
s
.84036 .58915 m
.84037 .58915 L
s
.84038 .58916 m
.84037 .58917 L
s
.84037 .58915 m
.84038 .58916 L
s
.84037 .58917 m
.84036 .58916 L
s
.84036 .58916 m
.84037 .58915 L
s
.84037 .58915 m
.84037 .58917 L
s
1 .303 0 r
.49736 .64893 m
.49786 .64651 L
s
1 .008 0 r
.15058 .41611 m
.15062 .41615 L
s
.15053 .41615 m
.15058 .41611 L
s
.15058 .41611 m
.15057 .41611 L
s
.15062 .41615 m
.15057 .41618 L
s
.15057 .41611 m
.15062 .41615 L
s
.15057 .41618 m
.15053 .41615 L
s
.15053 .41615 m
.15057 .41611 L
s
.15057 .41611 m
.15057 .41618 L
s
1 .111 0 r
.42811 .61784 m
.42741 .61804 L
s
.42744 .61695 m
.42811 .61784 L
s
.42811 .61784 m
.427 .61776 L
s
.42785 .61724 m
.42811 .61784 L
s
.42468 .61613 m
.42811 .61784 L
s
.42744 .61695 m
.427 .61776 L
s
.42785 .61724 m
.42744 .61695 L
s
.427 .61776 m
.42741 .61804 L
s
1 .336 0 r
.5614 .67358 m
.5617 .67293 L
s
.5617 .67293 m
.56445 .67436 L
s
1 .344 0 r
.62753 .44479 m
.62961 .44635 L
s
1 .158 0 r
.68088 .7341 m
.68029 .73293 L
s
.68189 .73287 m
.68088 .7341 L
s
.68029 .73293 m
.68189 .73287 L
s
1 .344 0 r
.62961 .44635 m
.63158 .44471 L
s
1 .241 0 r
.62149 .70402 m
.62089 .70458 L
s
.62082 .70216 m
.62149 .70402 L
s
.62263 .70288 m
.62149 .70402 L
s
1 .062 0 r
.77429 .38693 m
.7743 .3869 L
s
.77425 .38633 m
.77429 .38693 L
s
.77429 .38693 m
.77391 .38664 L
s
.77464 .38659 m
.77429 .38693 L
s
.77421 .38535 m
.77429 .38693 L
s
1 .241 0 r
.62022 .70272 m
.62082 .70216 L
s
.62082 .70216 m
.62263 .70288 L
s
1 .015 0 r
.83707 .41564 m
.83709 .41564 L
s
.83707 .41549 m
.83707 .41564 L
s
.83707 .41564 m
.83699 .41557 L
s
.83717 .41556 m
.83707 .41564 L
s
.83712 .41525 m
.83707 .41564 L
s
1 .039 0 r
.38024 .473 m
.38045 .47316 L
s
.38001 .47321 m
.38024 .473 L
s
.38024 .473 m
.38016 .473 L
s
1 .062 0 r
.77425 .38633 m
.77391 .38664 L
s
.77464 .38659 m
.77425 .38633 L
s
1 .015 0 r
.83707 .41549 m
.83699 .41557 L
s
.83717 .41556 m
.83707 .41549 L
s
.83699 .41557 m
.83709 .41564 L
s
.83709 .41564 m
.83717 .41556 L
s
1 .039 0 r
.38022 .47336 m
.38001 .47321 L
s
.38001 .47321 m
.38016 .473 L
s
.38045 .47316 m
.38022 .47336 L
s
.38016 .473 m
.38045 .47316 L
s
1 .062 0 r
.77391 .38664 m
.7743 .3869 L
s
1 .111 0 r
.42741 .61804 m
.42785 .61724 L
s
1 .039 0 r
.38016 .473 m
.38022 .47336 L
s
1 .062 0 r
.7743 .3869 m
.77464 .38659 L
s
1 .066 0 r
.78211 .73202 m
.78243 .73247 L
s
.78183 .73224 m
.78211 .73202 L
s
.78211 .73202 m
.78248 .73213 L
s
.78243 .73247 m
.78215 .73269 L
s
.78248 .73213 m
.78243 .73247 L
s
1 .003 0 r
.25779 .5883 m
.25778 .5883 L
s
.25778 .58827 m
.25779 .5883 L
s
.25779 .5883 m
.25776 .58829 L
s
.2578 .58829 m
.25779 .5883 L
s
.25774 .58823 m
.25779 .5883 L
s
.25778 .58827 m
.25776 .58829 L
s
.2578 .58829 m
.25778 .58827 L
s
.25776 .58829 m
.25778 .5883 L
s
.25778 .5883 m
.2578 .58829 L
s
1 .825 0 r
.4201 .38439 m
.42044 .39243 L
s
1 .095 0 r
.71783 .70356 m
.72054 .70199 L
s
1 .001 0 r
.77748 .5594 m
.77748 .55939 L
s
1 .032 0 r
.31738 .44408 m
.31724 .44328 L
s
1 .001 0 r
.77748 .55939 m
.77749 .55939 L
s
.77748 .55939 m
.77748 .55939 L
s
.77748 .55939 m
.77748 .55939 L
s
.77749 .55939 m
.77748 .5594 L
s
.77748 .55939 m
.77749 .55939 L
s
.77748 .5594 m
.77748 .55939 L
s
.77748 .55939 m
.77748 .55939 L
s
.77748 .55939 m
.77748 .5594 L
s
1 .066 0 r
.78215 .73269 m
.78183 .73224 L
s
.78183 .73224 m
.78248 .73213 L
s
.78248 .73213 m
.78215 .73269 L
s
1 .091 0 r
.3043 .73215 m
.30377 .73231 L
s
.30383 .73139 m
.3043 .73215 L
s
.3043 .73215 m
.3034 .73202 L
s
.3042 .73168 m
.3043 .73215 L
s
.30178 .73065 m
.3043 .73215 L
s
0 .197 1 r
.55885 .70327 m
.54424 .70821 L
s
.54403 .66966 m
.55885 .70327 L
s
.55885 .70327 m
.52431 .69445 L
s
.56411 .68316 m
.55885 .70327 L
s
.48236 .62818 m
.55885 .70327 L
s
1 .091 0 r
.30383 .73139 m
.3034 .73202 L
s
.3042 .73168 m
.30383 .73139 L
s
1 .336 0 r
.56445 .67436 m
.56174 .67629 L
s
.5614 .67358 m
.56445 .67436 L
s
1 .091 0 r
.3034 .73202 m
.30377 .73231 L
s
1 .741 0 r
.40601 .33241 m
.40192 .32828 L
s
.40192 .32828 m
.40764 .32529 L
s
1 .032 0 r
.31728 .44329 m
.31746 .44344 L
s
.31708 .44344 m
.31728 .44329 L
s
.31728 .44329 m
.31724 .44328 L
s
.31726 .44359 m
.31708 .44344 L
s
.31708 .44344 m
.31724 .44328 L
s
.31746 .44344 m
.31726 .44359 L
s
.31724 .44328 m
.31746 .44344 L
s
.31724 .44328 m
.31726 .44359 L
s
1 .233 0 r
.41144 .73173 m
.41214 .73234 L
s
.41222 .72997 m
.41144 .73173 L
s
.41379 .73172 m
.41144 .73173 L
s
1 .241 0 r
.62263 .70288 m
.62089 .70458 L
s
.62022 .70272 m
.62263 .70288 L
s
1 .233 0 r
.41379 .73172 m
.41214 .73234 L
s
.41222 .72997 m
.41379 .73172 L
s
.41292 .73058 m
.41379 .73172 L
s
.40571 .7289 m
.41379 .73172 L
s
1 .091 0 r
.30377 .73231 m
.3042 .73168 L
s
1 .241 0 r
.62089 .70458 m
.62022 .70272 L
s
1 .233 0 r
.41292 .73058 m
.41222 .72997 L
s
0 1 .566 r
.52457 .59746 m
.51129 .61402 L
s
.53791 .60606 m
.52457 .59746 L
s
1 .336 0 r
.56174 .67629 m
.5614 .67358 L
s
1 0 0 r
.1945 .55844 m
.1945 .55844 L
s
.1945 .55844 m
.1945 .55844 L
s
.1945 .55844 m
.1945 .55844 L
s
.1945 .55844 m
.1945 .55844 L
s
.1945 .55843 m
.1945 .55844 L
s
.1945 .55844 m
.1945 .55844 L
s
.1945 .55844 m
.1945 .55844 L
s
.1945 .55844 m
.1945 .55844 L
s
.1945 .55844 m
.1945 .55844 L
s
1 .028 0 r
.88504 .73152 m
.88567 .73099 L
s
1 .001 0 r
.94472 .58728 m
.94473 .58727 L
s
1 .151 0 r
.65486 .67382 m
.65962 .6716 L
s
1 0 0 r
.71454 .52959 m
.71454 .52959 L
s
.425 1 0 r
.48435 .47189 m
.45208 .43707 L
s
1 .026 0 r
.25417 .41419 m
.25412 .41353 L
s
1 .001 0 r
.94472 .58727 m
.94473 .58727 L
s
.94472 .58727 m
.94472 .58727 L
s
.94472 .58727 m
.94473 .58727 L
s
.94473 .58727 m
.94473 .58727 L
s
.94473 .58727 m
.94473 .58727 L
s
.94473 .58727 m
.94472 .58727 L
s
.94472 .58727 m
.94473 .58727 L
s
.94473 .58727 m
.94473 .58727 L
s
1 .095 0 r
.71997 .70182 m
.72041 .70249 L
s
.71959 .70212 m
.71997 .70182 L
s
.71997 .70182 m
.72054 .70199 L
s
.72041 .70249 m
.72003 .70278 L
s
.72054 .70199 m
.72041 .70249 L
s
1 .271 0 r
.33852 .32532 m
.34 .32683 L
s
.33689 .32625 m
.33852 .32532 L
s
.33852 .32532 m
.33894 .32515 L
s
1 .158 0 r
.75401 .32727 m
.75378 .32717 L
s
.75367 .32575 m
.75401 .32727 L
s
.75401 .32727 m
.75281 .32664 L
s
.75464 .32628 m
.75401 .32727 L
s
.75258 .32322 m
.75401 .32727 L
s
1 .028 0 r
.88553 .73096 m
.88568 .73114 L
s
.8854 .73106 m
.88553 .73096 L
s
.88553 .73096 m
.88567 .73099 L
s
1 .026 0 r
.25414 .41354 m
.25429 .41367 L
s
.25398 .41366 m
.25414 .41354 L
s
.25414 .41354 m
.25412 .41353 L
s
1 .028 0 r
.88568 .73114 m
.88556 .73124 L
s
.88567 .73099 m
.88568 .73114 L
s
0 .434 1 r
.54024 .6474 m
.52181 .67052 L
s
.55896 .65982 m
.54024 .6474 L
s
1 .026 0 r
.25429 .41367 m
.25412 .41378 L
s
.25412 .41353 m
.25429 .41367 L
s
.25412 .41378 m
.25398 .41366 L
s
.25398 .41366 m
.25412 .41353 L
s
1 .028 0 r
.88556 .73124 m
.8854 .73106 L
s
.8854 .73106 m
.88567 .73099 L
s
.88567 .73099 m
.88556 .73124 L
s
1 .026 0 r
.25412 .41353 m
.25412 .41378 L
s
1 .741 0 r
.40764 .32529 m
.40601 .33241 L
s
1 .095 0 r
.72003 .70278 m
.71959 .70212 L
s
.71959 .70212 m
.72054 .70199 L
s
.72054 .70199 m
.72003 .70278 L
s
1 .016 0 r
.36184 .58665 m
.36177 .58666 L
s
.36177 .58651 m
.36184 .58665 L
s
.36184 .58665 m
.36169 .58661 L
s
.36185 .58656 m
.36184 .58665 L
s
.3615 .58633 m
.36184 .58665 L
s
0 .813 1 r
.51784 .64435 m
.53439 .65542 L
s
1 .158 0 r
.75367 .32575 m
.75281 .32664 L
s
.75464 .32628 m
.75367 .32575 L
s
1 .016 0 r
.36177 .58651 m
.36169 .58661 L
s
.36185 .58656 m
.36177 .58651 L
s
.36169 .58661 m
.36177 .58666 L
s
1 .271 0 r
.34 .32683 m
.33837 .32776 L
s
.33894 .32515 m
.34 .32683 L
s
1 .016 0 r
.36177 .58666 m
.36185 .58656 L
s
1 .008 0 r
.65141 .49993 m
.65144 .49993 L
s
.65143 .49985 m
.65141 .49993 L
s
.65141 .49993 m
.65139 .49988 L
s
.65148 .49989 m
.65141 .49993 L
s
.65152 .49973 m
.65141 .49993 L
s
.65143 .49985 m
.65139 .49988 L
s
.65148 .49989 m
.65143 .49985 L
s
.65144 .49993 m
.65148 .49989 L
s
.65139 .49988 m
.65144 .49993 L
s
1 .525 0 r
.65839 .35556 m
.6566 .35551 L
s
.6564 .35075 m
.65839 .35556 L
s
.65839 .35556 m
.65372 .35407 L
s
.65929 .35218 m
.65839 .35556 L
s
.6489 .34334 m
.65839 .35556 L
s
1 .59 0 r
.42058 .40895 m
.42395 .4116 L
s
.41702 .41174 m
.42058 .40895 L
s
.42058 .40895 m
.42015 .40866 L
s
1 .158 0 r
.75281 .32664 m
.75378 .32717 L
s
1 .035 0 r
.82213 .70178 m
.82293 .70112 L
s
1 0 0 r
.88184 .55746 m
.88184 .55746 L
s
1 .253 0 r
.59181 .64405 m
.60111 .64136 L
s
1 .344 0 r
.42121 .442 m
.42024 .43332 L
s
1 .022 0 r
.19089 .38427 m
.19087 .38371 L
s
1 0 0 r
.88184 .55746 m
.88184 .55746 L
s
.88184 .55746 m
.88184 .55746 L
s
.88184 .55746 m
.88184 .55746 L
s
.88184 .55746 m
.88184 .55746 L
s
.88184 .55746 m
.88184 .55746 L
s
.88184 .55746 m
.88184 .55746 L
s
.88184 .55746 m
.88184 .55746 L
s
.88184 .55746 m
.88184 .55746 L
s
1 .233 0 r
.41214 .73234 m
.41292 .73058 L
s
1 .344 0 r
.54009 .61516 m
.54004 .61574 L
s
.54003 .61235 m
.54009 .61516 L
s
.54287 .61399 m
.54009 .61516 L
s
1 .136 0 r
.46876 .58621 m
.46919 .58651 L
s
.46922 .58519 m
.46876 .58621 L
s
.47013 .58621 m
.46876 .58621 L
s
.47013 .58621 m
.46919 .58651 L
s
.46922 .58519 m
.47013 .58621 L
s
.46965 .58548 m
.47013 .58621 L
s
.46549 .58441 m
.47013 .58621 L
s
.46965 .58548 m
.46922 .58519 L
s
1 .039 0 r
.23939 .70163 m
.2392 .70168 L
s
.23923 .70128 m
.23939 .70163 L
s
.23939 .70163 m
.23902 .70154 L
s
.23941 .70142 m
.23939 .70163 L
s
.23849 .70089 m
.23939 .70163 L
s
1 .158 0 r
.75378 .32717 m
.75464 .32628 L
s
1 .039 0 r
.23923 .70128 m
.23902 .70154 L
s
.23941 .70142 m
.23923 .70128 L
s
1 .271 0 r
.33837 .32776 m
.33689 .32625 L
s
.33689 .32625 m
.33894 .32515 L
s
1 .039 0 r
.23902 .70154 m
.2392 .70168 L
s
1 .344 0 r
.53998 .61293 m
.54003 .61235 L
s
.54003 .61235 m
.54287 .61399 L
s
1 .022 0 r
.19089 .38373 m
.191 .38383 L
s
.19075 .38382 m
.19089 .38373 L
s
.19089 .38373 m
.19087 .38371 L
s
1 .039 0 r
.2392 .70168 m
.23941 .70142 L
s
1 .022 0 r
.191 .38383 m
.19087 .38393 L
s
.19087 .38371 m
.191 .38383 L
s
.19087 .38393 m
.19075 .38382 L
s
.19075 .38382 m
.19087 .38371 L
s
.19087 .38371 m
.19087 .38393 L
s
1 .035 0 r
.82275 .70107 m
.82294 .7013 L
s
.8226 .7012 m
.82275 .70107 L
s
.82275 .70107 m
.82293 .70112 L
s
.82294 .7013 m
.82278 .70143 L
s
.82293 .70112 m
.82294 .7013 L
s
1 .018 0 r
.87861 .38366 m
.87862 .38365 L
s
.87861 .38349 m
.87861 .38366 L
s
.87861 .38366 m
.87851 .38357 L
s
.87872 .38356 m
.87861 .38366 L
s
.87863 .3832 m
.87861 .38366 L
s
1 .151 0 r
.65923 .67239 m
.6587 .6728 L
s
.65864 .67129 m
.65923 .67239 L
s
.65962 .6716 m
.65923 .67239 L
s
.6581 .6717 m
.65864 .67129 L
s
.65864 .67129 m
.65962 .6716 L
s
1 .018 0 r
.87861 .38349 m
.87851 .38357 L
s
.87872 .38356 m
.87861 .38349 L
s
.87851 .38357 m
.87862 .38365 L
s
1 .035 0 r
.82278 .70143 m
.8226 .7012 L
s
.8226 .7012 m
.82293 .70112 L
s
1 .018 0 r
.87862 .38365 m
.87872 .38356 L
s
1 .055 0 r
.81581 .35467 m
.8158 .35463 L
s
.81576 .35413 m
.81581 .35467 L
s
.81581 .35467 m
.81545 .35441 L
s
.81611 .35434 m
.81581 .35467 L
s
.81564 .35323 m
.81581 .35467 L
s
1 .035 0 r
.82293 .70112 m
.82278 .70143 L
s
1 .271 0 r
.33894 .32515 m
.33837 .32776 L
s
0 1 .077 r
.60615 .38351 m
.61023 .38566 L
s
.60971 .36661 m
.60615 .38351 L
s
.62626 .37919 m
.60615 .38351 L
s
1 .525 0 r
.6564 .35075 m
.65372 .35407 L
s
.65929 .35218 m
.6564 .35075 L
s
1 .055 0 r
.81576 .35413 m
.81545 .35441 L
s
.81611 .35434 m
.81576 .35413 L
s
1 .136 0 r
.46919 .58651 m
.46965 .58548 L
s
.425 1 0 r
.59101 .48006 m
.5991 .46999 L
s
1 .114 0 r
.34563 .70099 m
.34496 .70119 L
s
.34502 .70004 m
.34563 .70099 L
s
.34563 .70099 m
.3445 .70084 L
s
.34548 .70039 m
.34563 .70099 L
s
.34241 .69911 m
.34563 .70099 L
s
1 .055 0 r
.81545 .35441 m
.8158 .35463 L
s
.8158 .35463 m
.81611 .35434 L
s
1 .001 0 r
.29825 .55651 m
.29825 .55651 L
s
.29825 .5565 m
.29825 .55651 L
s
.29825 .55651 m
.29825 .5565 L
s
.29825 .5565 m
.29825 .55651 L
s
.29824 .55649 m
.29825 .55651 L
s
.29825 .5565 m
.29825 .5565 L
s
.29825 .5565 m
.29825 .5565 L
s
.29825 .5565 m
.29825 .55651 L
s
.29825 .55651 m
.29825 .5565 L
s
1 .047 0 r
.75914 .67201 m
.76025 .67113 L
s
1 0 0 r
.81889 .52761 m
.81889 .52761 L
s
1 .344 0 r
.52869 .61425 m
.54287 .61399 L
s
1 .141 0 r
.35799 .41208 m
.35819 .40849 L
s
1 .018 0 r
.12754 .35432 m
.12753 .35384 L
s
1 .114 0 r
.34502 .70004 m
.3445 .70084 L
s
.34548 .70039 m
.34502 .70004 L
s
.3445 .70084 m
.34496 .70119 L
s
1 .323 0 r
.45527 .70081 m
.45609 .70156 L
s
.45616 .6983 m
.45527 .70081 L
s
.45851 .70058 m
.45527 .70081 L
s
1 .525 0 r
.65372 .35407 m
.6566 .35551 L
s
0 1 .566 r
.51129 .61402 m
.52457 .62274 L
s
1 .323 0 r
.45697 .69905 m
.45616 .6983 L
s
.45616 .6983 m
.45851 .70058 L
s
1 .344 0 r
.54287 .61399 m
.54004 .61574 L
s
.53998 .61293 m
.54287 .61399 L
s
1 .787 0 r
.62268 .41177 m
.61988 .41187 L
s
.61966 .40459 m
.62268 .41177 L
s
.62268 .41177 m
.61562 .4096 L
s
.62393 .40685 m
.62268 .41177 L
s
.60803 .39392 m
.62268 .41177 L
s
1 .018 0 r
.12754 .35385 m
.12764 .35394 L
s
.12742 .35392 m
.12754 .35385 L
s
.12754 .35385 m
.12753 .35384 L
s
1 .59 0 r
.4204 .4144 m
.41702 .41174 L
s
.41702 .41174 m
.42015 .40866 L
s
1 .151 0 r
.6587 .6728 m
.6581 .6717 L
s
.65962 .6716 m
.6587 .6728 L
s
.6581 .6717 m
.65962 .6716 L
s
1 .018 0 r
.12764 .35394 m
.12752 .35402 L
s
.12753 .35384 m
.12764 .35394 L
s
1 .323 0 r
.45851 .70058 m
.45609 .70156 L
s
.45697 .69905 m
.45851 .70058 L
s
.44657 .69733 m
.45851 .70058 L
s
1 .018 0 r
.12752 .35402 m
.12742 .35392 L
s
.12742 .35392 m
.12753 .35384 L
s
.12753 .35384 m
.12752 .35402 L
s
1 .59 0 r
.42395 .4116 m
.4204 .4144 L
s
.42015 .40866 m
.42395 .4116 L
s
1 .114 0 r
.34496 .70119 m
.34548 .70039 L
s
1 .253 0 r
.59993 .64261 m
.59928 .64316 L
s
.59922 .64064 m
.59993 .64261 L
s
.60111 .64136 m
.59993 .64261 L
s
1 .047 0 r
.76001 .67107 m
.76025 .67138 L
s
.7598 .67123 m
.76001 .67107 L
s
.76001 .67107 m
.76025 .67113 L
s
1 .253 0 r
.59857 .64119 m
.59922 .64064 L
s
.59922 .64064 m
.60111 .64136 L
s
1 .047 0 r
.76025 .67138 m
.76005 .67154 L
s
.76025 .67113 m
.76025 .67138 L
s
.808 1 0 r
.61724 .33323 m
.62129 .32414 L
s
1 .417 0 r
.52338 .72905 m
.52361 .72992 L
s
.52361 .72567 m
.52338 .72905 L
s
.52704 .72796 m
.52338 .72905 L
s
1 .047 0 r
.76005 .67154 m
.7598 .67123 L
s
.7598 .67123 m
.76025 .67113 L
s
1 .215 0 r
.67199 .41114 m
.67181 .41105 L
s
.67172 .40906 m
.67199 .41114 L
s
.67199 .41114 m
.67051 .41019 L
s
.67303 .40992 m
.67199 .41114 L
s
.67088 .40571 m
.67199 .41114 L
s
1 .047 0 r
.76025 .67113 m
.76005 .67154 L
s
1 .001 0 r
.75585 .49774 m
.75585 .49774 L
s
.75585 .49773 m
.75585 .49774 L
s
.75585 .49774 m
.75585 .49773 L
s
.75586 .49773 m
.75585 .49774 L
s
.75586 .49772 m
.75585 .49774 L
s
.75585 .49773 m
.75585 .49773 L
s
.75586 .49773 m
.75585 .49773 L
s
.75585 .49774 m
.75586 .49773 L
s
.75585 .49773 m
.75585 .49774 L
s
1 .014 0 r
.92666 .7 m
.92695 .69972 L
s
1 .068 0 r
.69608 .64221 m
.69781 .64097 L
s
1 0 0 r
.23491 .52661 m
.23491 .52661 L
s
1 .08 0 r
.29469 .38212 m
.29492 .38008 L
s
0 1 .331 r
.61773 .37017 m
.62174 .35117 L
s
1 .344 0 r
.54004 .61574 m
.53998 .61293 L
s
1 .417 0 r
.52383 .72654 m
.52361 .72567 L
s
.52361 .72567 m
.52704 .72796 L
s
1 .014 0 r
.92688 .6997 m
.92697 .69979 L
s
.92682 .69976 m
.92688 .6997 L
s
.92688 .6997 m
.92695 .69972 L
s
.92697 .69979 m
.9269 .69985 L
s
.92695 .69972 m
.92697 .69979 L
s
.9269 .69985 m
.92682 .69976 L
s
.92682 .69976 m
.92695 .69972 L
s
.92695 .69972 m
.9269 .69985 L
s
0 1 .077 r
.61382 .36864 m
.60971 .36661 L
s
.60971 .36661 m
.62626 .37919 L
s
1 .215 0 r
.67172 .40906 m
.67051 .41019 L
s
.67303 .40992 m
.67172 .40906 L
s
1 .024 0 r
.69262 .46837 m
.69265 .46837 L
s
.69264 .46815 m
.69262 .46837 L
s
.69262 .46837 m
.69251 .46825 L
s
.69278 .46827 m
.69262 .46837 L
s
.69276 .46779 m
.69262 .46837 L
s
.69264 .46815 m
.69251 .46825 L
s
.69278 .46827 m
.69264 .46815 L
s
.69265 .46837 m
.69278 .46827 L
s
.69251 .46825 m
.69265 .46837 L
s
0 .434 1 r
.52181 .67052 m
.5404 .68317 L
s
1 .787 0 r
.61966 .40459 m
.61562 .4096 L
s
.62393 .40685 m
.61966 .40459 L
s
1 .215 0 r
.67051 .41019 m
.67181 .41105 L
s
1 .007 0 r
.40237 .55467 m
.40234 .55468 L
s
.40234 .55461 m
.40237 .55467 L
s
.40237 .55467 m
.4023 .55466 L
s
.40237 .55464 m
.40237 .55467 L
s
.40223 .55454 m
.40237 .55467 L
s
.40234 .55461 m
.4023 .55466 L
s
.40237 .55464 m
.40234 .55461 L
s
1 .59 0 r
.42015 .40866 m
.4204 .4144 L
s
1 .007 0 r
.4023 .55466 m
.40234 .55468 L
s
.40234 .55468 m
.40237 .55464 L
s
1 .323 0 r
.45609 .70156 m
.45697 .69905 L
s
1 .068 0 r
.69745 .64088 m
.69778 .64134 L
s
.69715 .64109 m
.69745 .64088 L
s
.69745 .64088 m
.69781 .64097 L
s
1 .253 0 r
.60111 .64136 m
.59928 .64316 L
s
.59857 .64119 m
.60111 .64136 L
s
1 .068 0 r
.69778 .64134 m
.69748 .64155 L
s
.69781 .64097 m
.69778 .64134 L
s
1 .525 0 r
.6566 .35551 m
.65929 .35218 L
s
1 .253 0 r
.59928 .64316 m
.59857 .64119 L
s
1 0 0 r
.92348 .52562 m
.92348 .52562 L
s
1 .016 0 r
.86366 .6702 m
.86398 .66987 L
s
1 .111 0 r
.63294 .61237 m
.6362 .61052 L
s
.285 1 0 r
.46204 .40996 m
.48117 .36692 L
s
1 0 0 r
.17151 .49671 m
.17151 .4967 L
s
1 .053 0 r
.23132 .35213 m
.2315 .35075 L
s
1 0 0 r
.17151 .4967 m
.17151 .4967 L
s
.17151 .4967 m
.17151 .4967 L
s
.17151 .4967 m
.17151 .4967 L
s
.17151 .49671 m
.17151 .4967 L
s
.17151 .4967 m
.17151 .4967 L
s
.17151 .4967 m
.17151 .49671 L
s
.17151 .4967 m
.17151 .4967 L
s
.17151 .4967 m
.17151 .49671 L
s
1 .215 0 r
.67181 .41105 m
.67303 .40992 L
s
1 .417 0 r
.52704 .72796 m
.52361 .72992 L
s
.52383 .72654 m
.52704 .72796 L
s
.50989 .72715 m
.52704 .72796 L
s
1 .042 0 r
.27999 .6701 m
.27978 .67015 L
s
.27981 .66973 m
.27999 .6701 L
s
.27999 .6701 m
.27959 .67 L
s
.28001 .66988 m
.27999 .6701 L
s
.27903 .66929 m
.27999 .6701 L
s
.27981 .66973 m
.27959 .67 L
s
.28001 .66988 m
.27981 .66973 L
s
1 .068 0 r
.69748 .64155 m
.69715 .64109 L
s
.69715 .64109 m
.69781 .64097 L
s
1 .042 0 r
.27959 .67 m
.27978 .67015 L
s
1 .068 0 r
.69781 .64097 m
.69748 .64155 L
s
1 .016 0 r
.86391 .66985 m
.864 .66995 L
s
.86383 .66991 m
.86391 .66985 L
s
.86391 .66985 m
.86398 .66987 L
s
.864 .66995 m
.86393 .67001 L
s
.86398 .66987 m
.864 .66995 L
s
.86393 .67001 m
.86383 .66991 L
s
.86383 .66991 m
.86398 .66987 L
s
1 .08 0 r
.2949 .38012 m
.29534 .38053 L
s
.2944 .38044 m
.2949 .38012 L
s
.2949 .38012 m
.29492 .38008 L
s
1 .151 0 r
.38759 .6699 m
.38668 .67017 L
s
.38674 .66866 m
.38759 .6699 L
s
.38759 .6699 m
.38609 .66974 L
s
.38734 .6691 m
.38759 .6699 L
s
.38318 .66747 m
.38759 .6699 L
s
1 .016 0 r
.86398 .66987 m
.86393 .67001 L
s
1 .787 0 r
.61562 .4096 m
.61988 .41187 L
s
1 .042 0 r
.27978 .67015 m
.28001 .66988 L
s
1 .141 0 r
.35818 .40856 m
.35898 .40926 L
s
.35732 .40916 m
.35818 .40856 L
s
.35818 .40856 m
.35819 .40849 L
s
1 .151 0 r
.38674 .66866 m
.38609 .66974 L
s
.38734 .6691 m
.38674 .66866 L
s
1 .08 0 r
.29534 .38053 m
.29485 .38085 L
s
.29492 .38008 m
.29534 .38053 L
s
1 .151 0 r
.38609 .66974 m
.38668 .67017 L
s
1 .08 0 r
.29485 .38085 m
.2944 .38044 L
s
.2944 .38044 m
.29492 .38008 L
s
1 .141 0 r
.35898 .40926 m
.35811 .40986 L
s
.35819 .40849 m
.35898 .40926 L
s
1 .607 0 r
.40446 .34695 m
.40782 .35035 L
s
.40088 .34904 m
.40446 .34695 L
s
.40446 .34695 m
.40559 .34661 L
s
1 .08 0 r
.29492 .38008 m
.29485 .38085 L
s
1 .141 0 r
.35811 .40986 m
.35732 .40916 L
s
.35732 .40916 m
.35819 .40849 L
s
1 .05 0 r
.85743 .3223 m
.85741 .32226 L
s
.85736 .32181 m
.85743 .3223 L
s
.85743 .3223 m
.85709 .32208 L
s
.85768 .322 m
.85743 .3223 L
s
.85721 .32099 m
.85743 .3223 L
s
1 .053 0 r
.23148 .35079 m
.23178 .35106 L
s
.23115 .35099 m
.23148 .35079 L
s
.23148 .35079 m
.2315 .35075 L
s
1 .05 0 r
.85736 .32181 m
.85709 .32208 L
s
.85768 .322 m
.85736 .32181 L
s
1 .457 0 r
.50136 .66931 m
.50209 .67023 L
s
.50212 .66564 m
.50136 .66931 L
s
.50574 .66851 m
.50136 .66931 L
s
1 .117 0 r
.50996 .55359 m
.51015 .55377 L
s
.51016 .55265 m
.50996 .55359 L
s
.51108 .55337 m
.50996 .55359 L
s
1 .053 0 r
.23178 .35106 m
.23144 .35127 L
s
.2315 .35075 m
.23178 .35106 L
s
1 0 0 r
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
1 .018 0 r
.80059 .64036 m
.80095 .63998 L
s
1 .199 0 r
.56974 .58249 m
.57703 .58029 L
s
1 0 0 r
.33888 .52463 m
.33888 .52463 L
s
1 .457 0 r
.39873 .37997 m
.40336 .36849 L
s
1 .039 0 r
.16788 .32211 m
.16801 .32108 L
s
1 .05 0 r
.85709 .32208 m
.85741 .32226 L
s
1 .053 0 r
.23144 .35127 m
.23115 .35099 L
s
.23115 .35099 m
.2315 .35075 L
s
1 .117 0 r
.51035 .55283 m
.51016 .55265 L
s
.51016 .55265 m
.51108 .55337 L
s
1 .141 0 r
.35819 .40849 m
.35811 .40986 L
s
1 .05 0 r
.85741 .32226 m
.85768 .322 L
s
1 .053 0 r
.2315 .35075 m
.23144 .35127 L
s
1 .117 0 r
.51108 .55337 m
.51015 .55377 L
s
.51035 .55283 m
.51108 .55337 L
s
.50645 .55258 m
.51108 .55337 L
s
1 .151 0 r
.38668 .67017 m
.38734 .6691 L
s
1 .018 0 r
.80087 .63996 m
.80097 .64007 L
s
.80078 .64003 m
.80087 .63996 L
s
.80087 .63996 m
.80095 .63998 L
s
1 .111 0 r
.63553 .61035 m
.636 .61114 L
s
.63508 .61065 m
.63553 .61035 L
s
.63553 .61035 m
.6362 .61052 L
s
.636 .61114 m
.63556 .61144 L
s
.6362 .61052 m
.636 .61114 L
s
1 .018 0 r
.80097 .64007 m
.80089 .64014 L
s
.80095 .63998 m
.80097 .64007 L
s
1 .417 0 r
.52361 .72992 m
.52383 .72654 L
s
1 .457 0 r
.50286 .66656 m
.50212 .66564 L
s
.50212 .66564 m
.50574 .66851 L
s
1 .018 0 r
.80089 .64014 m
.80078 .64003 L
s
.80078 .64003 m
.80095 .63998 L
s
.80095 .63998 m
.80089 .64014 L
s
1 .607 0 r
.40782 .35035 m
.40425 .35246 L
s
.40559 .34661 m
.40782 .35035 L
s
1 .039 0 r
.168 .32111 m
.16821 .32132 L
s
.16775 .32126 m
.168 .32111 L
s
.168 .32111 m
.16801 .32108 L
s
1 .117 0 r
.51015 .55377 m
.51035 .55283 L
s
1 .039 0 r
.16821 .32132 m
.16796 .32146 L
s
.16801 .32108 m
.16821 .32132 L
s
1 .013 0 r
.21582 .63969 m
.21576 .6397 L
s
.21577 .63958 m
.21582 .63969 L
s
.21582 .63969 m
.2157 .63966 L
s
.21584 .63963 m
.21582 .63969 L
s
.21558 .63943 m
.21582 .63969 L
s
0 1 .077 r
.62626 .37919 m
.61023 .38566 L
s
.61382 .36864 m
.62626 .37919 L
s
.54425 .36365 m
.62626 .37919 L
s
1 .013 0 r
.21577 .63958 m
.2157 .63966 L
s
.21584 .63963 m
.21577 .63958 L
s
.2157 .63966 m
.21576 .6397 L
s
1 .039 0 r
.16796 .32146 m
.16775 .32126 L
s
.16775 .32126 m
.16801 .32108 L
s
1 .013 0 r
.21576 .6397 m
.21584 .63963 L
s
1 .111 0 r
.63556 .61144 m
.63508 .61065 L
s
.63508 .61065 m
.6362 .61052 L
s
1 .039 0 r
.16801 .32108 m
.16796 .32146 L
s
1 .111 0 r
.6362 .61052 m
.63556 .61144 L
s
0 .197 1 r
.54403 .66966 m
.52431 .69445 L
s
.56411 .68316 m
.54403 .66966 L
s
1 .457 0 r
.50574 .66851 m
.50209 .67023 L
s
.50286 .66656 m
.50574 .66851 L
s
.48757 .66564 m
.50574 .66851 L
s
1 .004 0 r
.79731 .46583 m
.79731 .46583 L
s
.79731 .46579 m
.79731 .46583 L
s
.79731 .46583 m
.79729 .46581 L
s
.79733 .46581 m
.79731 .46583 L
s
.79733 .46574 m
.79731 .46583 L
s
.79731 .46579 m
.79729 .46581 L
s
.79733 .46581 m
.79731 .46579 L
s
.79731 .46583 m
.79733 .46581 L
s
.79729 .46581 m
.79731 .46583 L
s
1 .007 0 r
.96843 .66838 m
.96855 .66824 L
s
1 .021 0 r
.73744 .61048 m
.73786 .61004 L
s
0 .04 1 r
.56206 .72627 m
.54683 .7318 L
s
.54658 .69122 m
.56206 .72627 L
s
.56206 .72627 m
.52596 .71718 L
s
.5676 .70555 m
.56206 .72627 L
s
.4821 .6488 m
.56206 .72627 L
s
1 .001 0 r
.27547 .49469 m
.27546 .49467 L
s
1 .202 0 r
.33535 .34994 m
.33722 .3448 L
s
1 .001 0 r
.27546 .49467 m
.27547 .49467 L
s
.27546 .49467 m
.27546 .49467 L
s
.27546 .49467 m
.27546 .49467 L
s
.27546 .49468 m
.27546 .49467 L
s
.27546 .49467 m
.27546 .49467 L
s
.27547 .49467 m
.27546 .49468 L
s
.27546 .49467 m
.27547 .49467 L
s
.27546 .49467 m
.27546 .49468 L
s
1 .007 0 r
.96852 .66823 m
.96856 .66827 L
s
.96849 .66826 m
.96852 .66823 L
s
.96852 .66823 m
.96855 .66824 L
s
.96856 .66827 m
.96853 .6683 L
s
.96855 .66824 m
.96856 .66827 L
s
.96853 .6683 m
.96849 .66826 L
s
.96849 .66826 m
.96855 .66824 L
s
.96855 .66824 m
.96853 .6683 L
s
1 .199 0 r
.57611 .58131 m
.57559 .5817 L
s
.57556 .57976 m
.57611 .58131 L
s
.57703 .58029 m
.57611 .58131 L
s
1 .032 0 r
.73409 .43655 m
.73411 .43654 L
s
.73409 .43624 m
.73409 .43655 L
s
.73409 .43655 m
.73391 .43639 L
s
.73429 .43638 m
.73409 .43655 L
s
.73414 .43574 m
.73409 .43655 L
s
.73409 .43624 m
.73391 .43639 L
s
.73429 .43638 m
.73409 .43624 L
s
1 .021 0 r
.73777 .61003 m
.73789 .61016 L
s
.73767 .6101 m
.73777 .61003 L
s
.73777 .61003 m
.73786 .61004 L
s
1 .199 0 r
.57503 .58015 m
.57556 .57976 L
s
.57556 .57976 m
.57703 .58029 L
s
1 .021 0 r
.73789 .61016 m
.73779 .61023 L
s
.73786 .61004 m
.73789 .61016 L
s
1 .032 0 r
.73391 .43639 m
.73411 .43654 L
s
.73411 .43654 m
.73429 .43638 L
s
1 .021 0 r
.73779 .61023 m
.73767 .6101 L
s
.73767 .6101 m
.73786 .61004 L
s
.73786 .61004 m
.73779 .61023 L
s
1 .215 0 r
.43078 .63901 m
.42942 .63942 L
s
.42948 .63728 m
.43078 .63901 L
s
.43078 .63901 m
.42861 .63885 L
s
.43028 .63785 m
.43078 .63901 L
s
.42409 .63571 m
.43078 .63901 L
s
.425 1 0 r
.51517 .58096 m
.50887 .58223 L
s
.50895 .56682 m
.51517 .58096 L
s
.51517 .58096 m
.50075 .57701 L
s
.5171 .572 m
.51517 .58096 L
s
.48338 .54818 m
.51517 .58096 L
s
1 .215 0 r
.42948 .63728 m
.42861 .63885 L
s
.43028 .63785 m
.42948 .63728 L
s
.42861 .63885 m
.42942 .63942 L
s
1 .344 0 r
.42048 .43346 m
.42246 .43503 L
s
.4184 .43511 m
.42048 .43346 L
s
.42048 .43346 m
.42024 .43332 L
s
1 .607 0 r
.40425 .35246 m
.40088 .34904 L
s
.40088 .34904 m
.40559 .34661 L
s
1 .787 0 r
.61988 .41187 m
.62393 .40685 L
s
1 .006 0 r
.90534 .6385 m
.90545 .63836 L
s
1 .318 0 r
.6143 .7254 m
.62606 .72218 L
s
1 .024 0 r
.67422 .58057 m
.67472 .58008 L
s
1 0 0 r
.4431 .52264 m
.4431 .52264 L
s
0 .434 1 r
.50302 .37781 m
.63513 .33244 L
s
1 .002 0 r
.21198 .46471 m
.21196 .46465 L
s
1 .115 0 r
.2719 .31988 m
.27286 .31692 L
s
1 .046 0 r
.32073 .63847 m
.32051 .63852 L
s
.32054 .63806 m
.32073 .63847 L
s
.32073 .63847 m
.3203 .63836 L
s
.32075 .63822 m
.32073 .63847 L
s
.31971 .63757 m
.32073 .63847 L
s
1 .002 0 r
.21197 .46465 m
.21198 .46466 L
s
.21195 .46466 m
.21197 .46465 L
s
.21197 .46465 m
.21196 .46465 L
s
.21197 .46467 m
.21195 .46466 L
s
.21195 .46466 m
.21196 .46465 L
s
.21198 .46466 m
.21197 .46467 L
s
.21196 .46465 m
.21198 .46466 L
s
.21196 .46465 m
.21197 .46467 L
s
1 .006 0 r
.90543 .63836 m
.90546 .6384 L
s
.90539 .63839 m
.90543 .63836 L
s
.90543 .63836 m
.90545 .63836 L
s
1 .046 0 r
.32054 .63806 m
.3203 .63836 L
s
.32075 .63822 m
.32054 .63806 L
s
1 .006 0 r
.90546 .6384 m
.90543 .63842 L
s
.90545 .63836 m
.90546 .6384 L
s
.90543 .63842 m
.90539 .63839 L
s
.90539 .63839 m
.90545 .63836 L
s
.90545 .63836 m
.90543 .63842 L
s
1 .046 0 r
.3203 .63836 m
.32051 .63852 L
s
0 .04 1 r
.42186 .29069 m
.4416 .30108 L
s
.40106 .31575 m
.42186 .29069 L
s
.42186 .29069 m
.40439 .2893 L
s
1 .199 0 r
.57703 .58029 m
.57559 .5817 L
s
.57503 .58015 m
.57703 .58029 L
s
1 .046 0 r
.32051 .63852 m
.32075 .63822 L
s
1 .199 0 r
.57559 .5817 m
.57503 .58015 L
s
1 .024 0 r
.67462 .58007 m
.67474 .58022 L
s
.6745 .58014 m
.67462 .58007 L
s
.67462 .58007 m
.67472 .58008 L
s
.67474 .58022 m
.67463 .5803 L
s
.67472 .58008 m
.67474 .58022 L
s
.67463 .5803 m
.6745 .58014 L
s
.6745 .58014 m
.67472 .58008 L
s
.67472 .58008 m
.67463 .5803 L
s
1 .151 0 r
.71349 .37729 m
.7133 .37722 L
s
.71321 .37584 m
.71349 .37729 L
s
.71349 .37729 m
.71238 .37667 L
s
.71413 .37639 m
.71349 .37729 L
s
.71232 .37348 m
.71349 .37729 L
s
1 .344 0 r
.42038 .43668 m
.4184 .43511 L
s
.4184 .43511 m
.42024 .43332 L
s
1 .457 0 r
.50209 .67023 m
.50286 .66656 L
s
1 .344 0 r
.42246 .43503 m
.42038 .43668 L
s
.42024 .43332 m
.42246 .43503 L
s
1 .215 0 r
.42942 .63942 m
.43028 .63785 L
s
1 .607 0 r
.40559 .34661 m
.40425 .35246 L
s
1 .151 0 r
.71321 .37584 m
.71238 .37667 L
s
.71413 .37639 m
.71321 .37584 L
s
1 .001 0 r
.90213 .4637 m
.90213 .4637 L
s
.90213 .46369 m
.90213 .4637 L
s
.90213 .4637 m
.90213 .4637 L
s
.90214 .4637 m
.90213 .4637 L
s
.90214 .46368 m
.90213 .4637 L
s
.90213 .46369 m
.90213 .4637 L
s
.90214 .4637 m
.90213 .46369 L
s
.90213 .4637 m
.90214 .4637 L
s
.90213 .4637 m
.90213 .4637 L
s
1 .459 0 r
.56639 .69555 m
.56599 .69648 L
s
.56593 .69183 m
.56639 .69555 L
s
.56971 .69381 m
.56639 .69555 L
s
1 .006 0 r
.84218 .60859 m
.84227 .60846 L
s
1 .459 0 r
.55097 .69554 m
.56971 .69381 L
s
1 .021 0 r
.61093 .55062 m
.61144 .55022 L
s
1 .005 0 r
.37967 .49266 m
.37962 .49253 L
s
.973 1 0 r
.43963 .34775 m
.46322 .32517 L
s
1 .003 0 r
.14841 .43469 m
.1484 .43461 L
s
1 .151 0 r
.71238 .37667 m
.7133 .37722 L
s
1 .003 0 r
.1484 .43461 m
.14842 .43463 L
s
.14838 .43462 m
.1484 .43461 L
s
.1484 .43461 m
.1484 .43461 L
s
.14842 .43463 m
.1484 .43464 L
s
.1484 .43461 m
.14842 .43463 L
s
.1484 .43464 m
.14838 .43462 L
s
.14838 .43462 m
.1484 .43461 L
s
.1484 .43461 m
.1484 .43464 L
s
1 .005 0 r
.37963 .49253 m
.37966 .49255 L
s
.3796 .49256 m
.37963 .49253 L
s
.37963 .49253 m
.37962 .49253 L
s
1 .006 0 r
.84225 .60846 m
.84229 .60849 L
s
.84223 .60848 m
.84225 .60846 L
s
.84225 .60846 m
.84227 .60846 L
s
.84229 .60849 m
.84226 .60852 L
s
.84227 .60846 m
.84229 .60849 L
s
1 .005 0 r
.37963 .49258 m
.3796 .49256 L
s
.3796 .49256 m
.37962 .49253 L
s
.37966 .49255 m
.37963 .49258 L
s
.37962 .49253 m
.37966 .49255 L
s
1 .006 0 r
.84226 .60852 m
.84223 .60848 L
s
.84223 .60848 m
.84227 .60846 L
s
1 .005 0 r
.37962 .49253 m
.37963 .49258 L
s
1 .006 0 r
.84227 .60846 m
.84226 .60852 L
s
1 .344 0 r
.47348 .60838 m
.47459 .60916 L
s
.47464 .60577 m
.47348 .60838 L
s
.47697 .60837 m
.47348 .60838 L
s
.47697 .60837 m
.47459 .60916 L
s
.47464 .60577 m
.47697 .60837 L
s
.47575 .60654 m
.47697 .60837 L
s
.46514 .60384 m
.47697 .60837 L
s
1 .318 0 r
.69601 .31848 m
.69497 .3184 L
s
.69481 .31554 m
.69601 .31848 L
s
.69601 .31848 m
.69319 .31756 L
s
.6966 .31639 m
.69601 .31848 L
s
.6904 .31092 m
.69601 .31848 L
s
1 .021 0 r
.61133 .5502 m
.61143 .55034 L
s
.61124 .55026 m
.61133 .5502 L
s
.61133 .5502 m
.61144 .55022 L
s
.61143 .55034 m
.61134 .5504 L
s
.61144 .55022 m
.61143 .55034 L
s
1 .151 0 r
.7133 .37722 m
.71413 .37639 L
s
1 .344 0 r
.47575 .60654 m
.47464 .60577 L
s
1 .021 0 r
.61134 .5504 m
.61124 .55026 L
s
.61124 .55026 m
.61144 .55022 L
s
.61144 .55022 m
.61134 .5504 L
s
1 .459 0 r
.56552 .69275 m
.56593 .69183 L
s
.56593 .69183 m
.56971 .69381 L
s
1 .344 0 r
.42024 .43332 m
.42038 .43668 L
s
.973 1 0 r
.6096 .34694 m
.61336 .34842 L
s
.6131 .33908 m
.6096 .34694 L
s
.62004 .34687 m
.6096 .34694 L
s
1 .01 0 r
.25635 .60786 m
.25631 .60786 L
s
.25632 .60776 m
.25635 .60786 L
s
.25635 .60786 m
.25626 .60783 L
s
.25637 .6078 m
.25635 .60786 L
s
.25618 .60764 m
.25635 .60786 L
s
.25632 .60776 m
.25626 .60783 L
s
.25637 .6078 m
.25632 .60776 L
s
.973 1 0 r
.62004 .34687 m
.61336 .34842 L
s
.6131 .33908 m
.62004 .34687 L
s
.61687 .34054 m
.62004 .34687 L
s
.58576 .33111 m
.62004 .34687 L
s
1 .318 0 r
.69481 .31554 m
.69319 .31756 L
s
.6966 .31639 m
.69481 .31554 L
s
1 .01 0 r
.25626 .60783 m
.25631 .60786 L
s
.25631 .60786 m
.25637 .6078 L
s
1 .115 0 r
.27271 .31699 m
.27333 .31764 L
s
.272 .31739 m
.27271 .31699 L
s
.27271 .31699 m
.27286 .31692 L
s
1 .007 0 r
.83892 .43382 m
.83893 .43382 L
s
.83892 .43375 m
.83892 .43382 L
s
.83892 .43382 m
.83888 .43379 L
s
.83896 .43378 m
.83892 .43382 L
s
.83894 .43364 m
.83892 .43382 L
s
.83892 .43375 m
.83888 .43379 L
s
.83896 .43378 m
.83892 .43375 L
s
.83888 .43379 m
.83893 .43382 L
s
.83893 .43382 m
.83896 .43378 L
s
1 .318 0 r
.62455 .72367 m
.62375 .72445 L
s
.62366 .7212 m
.62455 .72367 L
s
.62606 .72218 m
.62455 .72367 L
s
1 .134 0 r
.71896 .72364 m
.72279 .72145 L
s
1 .004 0 r
.77895 .57864 m
.77901 .57855 L
s
1 0 0 r
.54756 .52064 m
.54756 .52064 L
s
1 .01 0 r
.31617 .46264 m
.31612 .46239 L
s
1 .417 0 r
.37616 .31765 m
.38349 .30765 L
s
1 .115 0 r
.27333 .31764 m
.27262 .31803 L
s
.27286 .31692 m
.27333 .31764 L
s
.973 1 0 r
.61687 .34054 m
.6131 .33908 L
s
1 .004 0 r
.779 .57855 m
.77902 .57857 L
s
.77898 .57856 m
.779 .57855 L
s
.779 .57855 m
.77901 .57855 L
s
.77902 .57857 m
.779 .57859 L
s
.77901 .57855 m
.77902 .57857 L
s
.779 .57859 m
.77898 .57856 L
s
.77898 .57856 m
.77901 .57855 L
s
1 .318 0 r
.69319 .31756 m
.69497 .3184 L
s
1 .004 0 r
.77901 .57855 m
.779 .57859 L
s
1 .318 0 r
.62287 .72198 m
.62366 .7212 L
s
.62366 .7212 m
.62606 .72218 L
s
1 .035 0 r
.77571 .40447 m
.77572 .40445 L
s
.77569 .40413 m
.77571 .40447 L
s
.77571 .40447 m
.7755 .40431 L
s
.77591 .40428 m
.77571 .40447 L
s
.77567 .40358 m
.77571 .40447 L
s
1 .01 0 r
.31613 .46239 m
.31619 .46244 L
s
.31607 .46244 m
.31613 .46239 L
s
.31613 .46239 m
.31612 .46239 L
s
.31613 .46249 m
.31607 .46244 L
s
.31607 .46244 m
.31612 .46239 L
s
.31619 .46244 m
.31613 .46249 L
s
.31612 .46239 m
.31619 .46244 L
s
0 .197 1 r
.52431 .69445 m
.54424 .70821 L
s
1 .01 0 r
.31612 .46239 m
.31613 .46249 L
s
1 .202 0 r
.3369 .34492 m
.33801 .34605 L
s
.33568 .34562 m
.3369 .34492 L
s
.3369 .34492 m
.33722 .3448 L
s
1 .115 0 r
.27262 .31803 m
.272 .31739 L
s
.272 .31739 m
.27286 .31692 L
s
1 .035 0 r
.77569 .40413 m
.7755 .40431 L
s
.77591 .40428 m
.77569 .40413 L
s
.425 1 0 r
.50895 .56682 m
.50075 .57701 L
s
.5171 .572 m
.50895 .56682 L
s
1 .117 0 r
.58733 .49134 m
.58764 .49134 L
s
.58761 .49023 m
.58733 .49134 L
s
.58733 .49134 m
.58697 .49067 L
s
.58828 .4909 m
.58733 .49134 L
s
.58881 .48859 m
.58733 .49134 L
s
1 .035 0 r
.7755 .40431 m
.77572 .40445 L
s
.77572 .40445 m
.77591 .40428 L
s
1 .115 0 r
.27286 .31692 m
.27262 .31803 L
s
1 .202 0 r
.33801 .34605 m
.33679 .34675 L
s
.33722 .3448 m
.33801 .34605 L
s
1 .117 0 r
.58761 .49023 m
.58697 .49067 L
s
.58828 .4909 m
.58761 .49023 L
s
.58764 .49134 m
.58828 .4909 L
s
1 .459 0 r
.56971 .69381 m
.56599 .69648 L
s
.56552 .69275 m
.56971 .69381 L
s
1 .202 0 r
.33679 .34675 m
.33568 .34562 L
s
.33568 .34562 m
.33722 .3448 L
s
1 .117 0 r
.58697 .49067 m
.58764 .49134 L
s
1 .002 0 r
.19258 .57771 m
.19258 .57771 L
s
.19258 .5777 m
.19258 .57771 L
s
.19258 .57771 m
.19257 .5777 L
s
.19259 .5777 m
.19258 .57771 L
s
.19256 .57768 m
.19258 .57771 L
s
.19258 .5777 m
.19257 .5777 L
s
.19259 .5777 m
.19258 .5777 L
s
.19257 .5777 m
.19258 .57771 L
s
.19258 .57771 m
.19259 .5777 L
s
1 .048 0 r
.36159 .60671 m
.36136 .60676 L
s
.36139 .60628 m
.36159 .60671 L
s
.36159 .60671 m
.36113 .60659 L
s
.36162 .60644 m
.36159 .60671 L
s
.36054 .60574 m
.36159 .60671 L
s
1 .002 0 r
.94717 .60669 m
.9472 .60665 L
s
1 .22 0 r
.65562 .69374 m
.66262 .69051 L
s
1 .002 0 r
.71564 .54866 m
.71567 .54862 L
s
1 .398 0 r
.48412 .49063 m
.47602 .48199 L
s
1 .012 0 r
.25259 .43259 m
.25256 .43229 L
s
1 .002 0 r
.71566 .54862 m
.71567 .54863 L
s
.71565 .54863 m
.71566 .54862 L
s
.71566 .54862 m
.71567 .54862 L
s
.71567 .54863 m
.71566 .54864 L
s
.71567 .54862 m
.71567 .54863 L
s
.94719 .60665 m
.9472 .60666 L
s
.94718 .60665 m
.94719 .60665 L
s
.94719 .60665 m
.9472 .60665 L
s
.71566 .54864 m
.71565 .54863 L
s
.71565 .54863 m
.71567 .54862 L
s
.71567 .54862 m
.71566 .54864 L
s
.9472 .60666 m
.9472 .60667 L
s
.9472 .60665 m
.9472 .60666 L
s
.9472 .60667 m
.94718 .60665 L
s
.94718 .60665 m
.9472 .60665 L
s
.9472 .60665 m
.9472 .60667 L
s
1 .344 0 r
.47459 .60916 m
.47575 .60654 L
s
1 .048 0 r
.36139 .60628 m
.36113 .60659 L
s
.36162 .60644 m
.36139 .60628 L
s
.36113 .60659 m
.36136 .60676 L
s
1 .318 0 r
.69497 .3184 m
.6966 .31639 L
s
1 .012 0 r
.25257 .4323 m
.25264 .43236 L
s
.2525 .43235 m
.25257 .4323 L
s
.25257 .4323 m
.25256 .43229 L
s
.25264 .43236 m
.25256 .43241 L
s
.25256 .43229 m
.25264 .43236 L
s
.25256 .43241 m
.2525 .43235 L
s
.2525 .43235 m
.25256 .43229 L
s
1 .202 0 r
.33722 .3448 m
.33679 .34675 L
s
1 .012 0 r
.25256 .43229 m
.25256 .43241 L
s
1 .048 0 r
.36136 .60676 m
.36162 .60644 L
s
1 .59 0 r
.54835 .63539 m
.54828 .63643 L
s
.54824 .63056 m
.54835 .63539 L
s
.55315 .63341 m
.54835 .63539 L
s
1 .134 0 r
.72198 .7212 m
.72259 .72215 L
s
.72145 .72163 m
.72198 .7212 L
s
.72198 .7212 m
.72279 .72145 L
s
1 .318 0 r
.62606 .72218 m
.62375 .72445 L
s
.62287 .72198 m
.62606 .72218 L
s
1 .606 0 r
.52462 .57703 m
.52564 .57806 L
s
.52564 .57213 m
.52462 .57703 L
s
.53046 .5759 m
.52462 .57703 L
s
0 1 .566 r
.52457 .62274 m
.53791 .60606 L
s
.425 1 0 r
.50075 .57701 m
.50887 .58223 L
s
1 .134 0 r
.72259 .72215 m
.72206 .72257 L
s
.72279 .72145 m
.72259 .72215 L
s
0 .04 1 r
.42064 .3264 m
.40106 .31575 L
s
.40106 .31575 m
.40439 .2893 L
s
1 .459 0 r
.56599 .69648 m
.56552 .69275 L
s
1 .318 0 r
.62375 .72445 m
.62287 .72198 L
s
1 .057 0 r
.23814 .72206 m
.23785 .72214 L
s
.2379 .72155 m
.23814 .72206 L
s
.23814 .72206 m
.2376 .72193 L
s
.23816 .72176 m
.23814 .72206 L
s
.23682 .72099 m
.23814 .72206 L
s
1 .59 0 r
.54818 .63159 m
.54824 .63056 L
s
.54824 .63056 m
.55315 .63341 L
s
1 .057 0 r
.2379 .72155 m
.2376 .72193 L
s
.23816 .72176 m
.2379 .72155 L
s
.2376 .72193 m
.23785 .72214 L
s
1 .417 0 r
.45741 .72191 m
.45847 .72292 L
s
.45856 .71866 m
.45741 .72191 L
s
.46161 .72162 m
.45741 .72191 L
s
1 .001 0 r
.88392 .57671 m
.88394 .57668 L
s
1 .051 0 r
.82386 .72188 m
.82505 .72091 L
s
1 .39 0 r
.5922 .66381 m
.6066 .6597 L
s
1 0 0 r
.65226 .51864 m
.65226 .51864 L
s
1 .136 0 r
.4206 .46058 m
.42021 .45719 L
s
.542 1 0 r
.48066 .31541 m
.53381 .29646 L
s
1 .012 0 r
.18894 .40251 m
.18892 .40221 L
s
1 .001 0 r
.88394 .57668 m
.88394 .57669 L
s
.88393 .57669 m
.88394 .57668 L
s
.88394 .57668 m
.88394 .57668 L
s
.88394 .57669 m
.88394 .57669 L
s
.88394 .57668 m
.88394 .57669 L
s
.88394 .57669 m
.88393 .57669 L
s
.88393 .57669 m
.88394 .57668 L
s
.88394 .57668 m
.88394 .57669 L
s
1 .158 0 r
.34585 .72182 m
.3449 .72211 L
s
.34499 .72049 m
.34585 .72182 L
s
.34585 .72182 m
.34426 .72161 L
s
.34563 .72099 m
.34585 .72182 L
s
.34134 .71922 m
.34585 .72182 L
s
1 .057 0 r
.23785 .72214 m
.23816 .72176 L
s
1 .606 0 r
.52667 .57315 m
.52564 .57213 L
s
.52564 .57213 m
.53046 .5759 L
s
0 .813 1 r
.53439 .65542 m
.55095 .63464 L
s
1 .417 0 r
.45962 .71966 m
.45856 .71866 L
s
.45856 .71866 m
.46161 .72162 L
s
1 .012 0 r
.18893 .40221 m
.189 .40227 L
s
.18886 .40226 m
.18893 .40221 L
s
.18893 .40221 m
.18892 .40221 L
s
.189 .40227 m
.18892 .40232 L
s
.18892 .40221 m
.189 .40227 L
s
.18892 .40232 m
.18886 .40226 L
s
.18886 .40226 m
.18892 .40221 L
s
1 .158 0 r
.34499 .72049 m
.34426 .72161 L
s
.34563 .72099 m
.34499 .72049 L
s
1 .012 0 r
.18892 .40221 m
.18892 .40232 L
s
1 .134 0 r
.72206 .72257 m
.72145 .72163 L
s
.72145 .72163 m
.72279 .72145 L
s
1 .417 0 r
.46161 .72162 m
.45847 .72292 L
s
.45962 .71966 m
.46161 .72162 L
s
.44611 .71745 m
.46161 .72162 L
s
1 .158 0 r
.34426 .72161 m
.3449 .72211 L
s
1 .134 0 r
.72279 .72145 m
.72206 .72257 L
s
1 .114 0 r
.75495 .34403 m
.75478 .34397 L
s
.7547 .34293 m
.75495 .34403 L
s
.75495 .34403 m
.75408 .34358 L
s
.7554 .34332 m
.75495 .34403 L
s
.75391 .34113 m
.75495 .34403 L
s
0 .04 1 r
.62946 .31496 m
.61952 .3194 L
s
.61842 .28364 m
.62946 .31496 L
s
.64867 .29102 m
.62946 .31496 L
s
1 .114 0 r
.7547 .34293 m
.75408 .34358 L
s
.7554 .34332 m
.7547 .34293 L
s
1 .136 0 r
.63018 .45982 m
.63021 .45978 L
s
.63016 .4585 m
.63018 .45982 L
s
.63018 .45982 m
.62938 .45916 L
s
.63099 .45912 m
.63018 .45982 L
s
.6302 .45643 m
.63018 .45982 L
s
1 .051 0 r
.82479 .72084 m
.82507 .72117 L
s
.82456 .72103 m
.82479 .72084 L
s
.82479 .72084 m
.82505 .72091 L
s
1 .01 0 r
.88069 .40169 m
.8807 .40168 L
s
.88069 .40159 m
.88069 .40169 L
s
.88069 .40169 m
.88063 .40164 L
s
.88075 .40163 m
.88069 .40169 L
s
.8807 .40144 m
.88069 .40169 L
s
1 .114 0 r
.75408 .34358 m
.75478 .34397 L
s
1 .01 0 r
.88069 .40159 m
.88063 .40164 L
s
.88075 .40163 m
.88069 .40159 L
s
1 .051 0 r
.82507 .72117 m
.82484 .72136 L
s
.82505 .72091 m
.82507 .72117 L
s
1 .01 0 r
.88063 .40164 m
.8807 .40168 L
s
.8807 .40168 m
.88075 .40163 L
s
1 .606 0 r
.53046 .5759 m
.52564 .57806 L
s
.52667 .57315 m
.53046 .5759 L
s
.50634 .57186 m
.53046 .5759 L
s
1 .006 0 r
.29701 .57588 m
.29699 .57588 L
s
.29699 .57582 m
.29701 .57588 L
s
.29701 .57588 m
.29695 .57586 L
s
.29702 .57585 m
.29701 .57588 L
s
.29691 .57574 m
.29701 .57588 L
s
.29699 .57582 m
.29695 .57586 L
s
.29702 .57585 m
.29699 .57582 L
s
.29695 .57586 m
.29699 .57588 L
s
.29699 .57588 m
.29702 .57585 L
s
1 .051 0 r
.82484 .72136 m
.82456 .72103 L
s
.82456 .72103 m
.82505 .72091 L
s
1 .158 0 r
.3449 .72211 m
.34563 .72099 L
s
1 .073 0 r
.76051 .69194 m
.76226 .69057 L
s
1 0 0 r
.8206 .54669 m
.82061 .54668 L
s
1 .59 0 r
.52871 .63384 m
.55315 .63341 L
s
1 .07 0 r
.35701 .43049 m
.35711 .42872 L
s
1 .011 0 r
.12521 .37239 m
.1252 .3721 L
s
1 0 0 r
.82061 .54668 m
.82061 .54668 L
s
.82061 .54668 m
.82061 .54668 L
s
.82061 .54668 m
.82061 .54668 L
s
.82061 .54668 m
.82061 .54669 L
s
.82061 .54668 m
.82061 .54668 L
s
.82061 .54669 m
.82061 .54668 L
s
.82061 .54668 m
.82061 .54668 L
s
.82061 .54668 m
.82061 .54669 L
s
1 .051 0 r
.82505 .72091 m
.82484 .72136 L
s
1 .114 0 r
.75478 .34397 m
.7554 .34332 L
s
1 .136 0 r
.63016 .4585 m
.62938 .45916 L
s
.63099 .45912 m
.63016 .4585 L
s
1 .035 0 r
.81745 .37221 m
.81744 .37219 L
s
.81741 .37186 m
.81745 .37221 L
s
.81745 .37221 m
.81722 .37205 L
s
.81764 .372 m
.81745 .37221 L
s
.81734 .3713 m
.81745 .37221 L
s
1 .011 0 r
.12521 .3721 m
.12527 .37216 L
s
.12514 .37215 m
.12521 .3721 L
s
.12521 .3721 m
.1252 .3721 L
s
.12527 .37216 m
.1252 .37221 L
s
.1252 .3721 m
.12527 .37216 L
s
.1252 .37221 m
.12514 .37215 L
s
.12514 .37215 m
.1252 .3721 L
s
.1252 .3721 m
.1252 .37221 L
s
1 .035 0 r
.81741 .37186 m
.81722 .37205 L
s
.81764 .372 m
.81741 .37186 L
s
1 .457 0 r
.40251 .3687 m
.40506 .37129 L
s
.3998 .37031 m
.40251 .3687 L
s
.40251 .3687 m
.40336 .36849 L
s
1 .22 0 r
.66205 .69166 m
.66126 .69227 L
s
.66117 .69005 m
.66205 .69166 L
s
.66262 .69051 m
.66205 .69166 L
s
.66038 .69066 m
.66117 .69005 L
s
.66117 .69005 m
.66262 .69051 L
s
1 .035 0 r
.81722 .37205 m
.81744 .37219 L
s
.81744 .37219 m
.81764 .372 L
s
1 .136 0 r
.62938 .45916 m
.63021 .45978 L
s
.63021 .45978 m
.63099 .45912 L
s
1 .59 0 r
.55315 .63341 m
.54828 .63643 L
s
.54818 .63159 m
.55315 .63341 L
s
0 .04 1 r
.54658 .69122 m
.52596 .71718 L
s
.5676 .70555 m
.54658 .69122 L
s
1 0 0 r
.23321 .54571 m
.23321 .54571 L
s
.23321 .54571 m
.23321 .54571 L
s
.23321 .54571 m
.23321 .54571 L
s
.23322 .54571 m
.23321 .54571 L
s
.23321 .5457 m
.23321 .54571 L
s
.23321 .54571 m
.23321 .54571 L
s
.23322 .54571 m
.23321 .54571 L
s
.23321 .54571 m
.23321 .54571 L
s
.23321 .54571 m
.23322 .54571 L
s
1 .022 0 r
.92901 .72011 m
.92945 .71968 L
s
1 .116 0 r
.69708 .66197 m
.70006 .65987 L
s
1 0 0 r
.75721 .51664 m
.75721 .51664 L
s
1 .046 0 r
.29334 .40037 m
.29347 .3992 L
s
1 .047 0 r
.4025 .57477 m
.4023 .5748 L
s
.40231 .57435 m
.4025 .57477 L
s
.4025 .57477 m
.40207 .57465 L
s
.40254 .5745 m
.4025 .57477 L
s
.40151 .5738 m
.4025 .57477 L
s
1 .457 0 r
.40506 .37129 m
.40235 .3729 L
s
.40336 .36849 m
.40506 .37129 L
s
1 .073 0 r
.76189 .69048 m
.76227 .69096 L
s
.76156 .69073 m
.76189 .69048 L
s
.76189 .69048 m
.76226 .69057 L
s
1 .047 0 r
.40231 .57435 m
.40207 .57465 L
s
.40254 .5745 m
.40231 .57435 L
s
1 .22 0 r
.38883 .69096 m
.38749 .69137 L
s
.38758 .68914 m
.38883 .69096 L
s
.38883 .69096 m
.38662 .69072 L
s
.38846 .6898 m
.38883 .69096 L
s
.38234 .68743 m
.38883 .69096 L
s
1 .073 0 r
.76227 .69096 m
.76194 .69122 L
s
.76226 .69057 m
.76227 .69096 L
s
1 .047 0 r
.40207 .57465 m
.4023 .5748 L
s
1 .07 0 r
.3571 .42874 m
.3575 .42909 L
s
.35667 .42905 m
.3571 .42874 L
s
.3571 .42874 m
.35711 .42872 L
s
1 .136 0 r
.42031 .45723 m
.42109 .45785 L
s
.41949 .45788 m
.42031 .45723 L
s
.42031 .45723 m
.42021 .45719 L
s
1 .047 0 r
.4023 .5748 m
.40254 .5745 L
s
1 .417 0 r
.45847 .72292 m
.45962 .71966 L
s
1 .22 0 r
.38758 .68914 m
.38662 .69072 L
s
.38846 .6898 m
.38758 .68914 L
s
1 .07 0 r
.3575 .42909 m
.35707 .4294 L
s
.35711 .42872 m
.3575 .42909 L
s
1 .022 0 r
.92935 .71965 m
.92947 .71979 L
s
.92925 .71974 m
.92935 .71965 L
s
.92935 .71965 m
.92945 .71968 L
s
1 .073 0 r
.76194 .69122 m
.76156 .69073 L
s
.76156 .69073 m
.76226 .69057 L
s
1 .22 0 r
.38662 .69072 m
.38749 .69137 L
s
1 .022 0 r
.92947 .71979 m
.92937 .71987 L
s
.92945 .71968 m
.92947 .71979 L
s
1 .07 0 r
.35707 .4294 m
.35667 .42905 L
s
.35667 .42905 m
.35711 .42872 L
s
0 .04 1 r
.60832 .28768 m
.61842 .28364 L
s
.61842 .28364 m
.64867 .29102 L
s
1 .073 0 r
.76226 .69057 m
.76194 .69122 L
s
1 .39 0 r
.60475 .66161 m
.60376 .66248 L
s
.60366 .65856 m
.60475 .66161 L
s
.6066 .6597 m
.60475 .66161 L
s
1 .022 0 r
.92937 .71987 m
.92925 .71974 L
s
.92925 .71974 m
.92945 .71968 L
s
1 .22 0 r
.66126 .69227 m
.66038 .69066 L
s
.66262 .69051 m
.66126 .69227 L
s
.66038 .69066 m
.66262 .69051 L
s
1 .022 0 r
.92945 .71968 m
.92937 .71987 L
s
1 .07 0 r
.35711 .42872 m
.35707 .4294 L
s
1 .066 0 r
.2791 .69051 m
.27878 .69059 L
s
.27883 .68992 m
.2791 .69051 L
s
.2791 .69051 m
.27847 .69035 L
s
.27913 .69016 m
.2791 .69051 L
s
.27759 .68924 m
.2791 .69051 L
s
1 .39 0 r
.60266 .65943 m
.60366 .65856 L
s
.60366 .65856 m
.6066 .6597 L
s
1 .136 0 r
.42027 .45851 m
.41949 .45788 L
s
.41949 .45788 m
.42021 .45719 L
s
.42109 .45785 m
.42027 .45851 L
s
.42021 .45719 m
.42109 .45785 L
s
1 .607 0 r
.50573 .69045 m
.50672 .69171 L
s
.50675 .68556 m
.50573 .69045 L
s
.51157 .68939 m
.50573 .69045 L
s
1 .066 0 r
.27883 .68992 m
.27847 .69035 L
s
.27913 .69016 m
.27883 .68992 L
s
1 .39 0 r
.65672 .3705 m
.65538 .37049 L
s
.65523 .36691 m
.65672 .3705 L
s
.65672 .3705 m
.65323 .36939 L
s
.65739 .368 m
.65672 .3705 L
s
.64963 .36145 m
.65672 .3705 L
s
1 .046 0 r
.29346 .39922 m
.29372 .39946 L
s
.29317 .39941 m
.29346 .39922 L
s
.29346 .39922 m
.29347 .3992 L
s
1 .066 0 r
.27847 .69035 m
.27878 .69059 L
s
0 1 .077 r
.61023 .38566 m
.61382 .36864 L
s
.808 1 0 r
.46201 .30347 m
.46778 .31149 L
s
.45601 .30617 m
.46201 .30347 L
s
.46201 .30347 m
.46742 .30351 L
s
1 .046 0 r
.29372 .39946 m
.29343 .39965 L
s
.29347 .3992 m
.29372 .39946 L
s
1 .59 0 r
.54828 .63643 m
.54818 .63159 L
s
1 .046 0 r
.29343 .39965 m
.29317 .39941 L
s
.29317 .39941 m
.29347 .3992 L
s
1 .457 0 r
.40235 .3729 m
.3998 .37031 L
s
.3998 .37031 m
.40336 .36849 L
s
1 .003 0 r
.69372 .48663 m
.69373 .48663 L
s
.69373 .4866 m
.69372 .48663 L
s
.69372 .48663 m
.69371 .48661 L
s
.69374 .48661 m
.69372 .48663 L
s
.69374 .48655 m
.69372 .48663 L
s
.69373 .4866 m
.69371 .48661 L
s
.69374 .48661 m
.69373 .4866 L
s
.69373 .48663 m
.69374 .48661 L
s
.69371 .48661 m
.69373 .48663 L
s
1 .136 0 r
.42021 .45719 m
.42027 .45851 L
s
1 .066 0 r
.27878 .69059 m
.27913 .69016 L
s
1 .046 0 r
.29347 .3992 m
.29343 .39965 L
s
1 .026 0 r
.86565 .69014 m
.86617 .68961 L
s
1 0 0 r
.92581 .54472 m
.92581 .54472 L
s
1 .215 0 r
.63358 .63197 m
.63993 .62842 L
s
.787 1 0 r
.46167 .42838 m
.47519 .39826 L
s
1 0 0 r
.16943 .51563 m
.16943 .51563 L
s
1 .033 0 r
.2296 .37021 m
.22971 .36935 L
s
1 0 0 r
.92581 .54472 m
.92581 .54472 L
s
.92581 .54472 m
.92581 .54472 L
s
.92581 .54472 m
.92581 .54472 L
s
.92581 .54472 m
.92581 .54472 L
s
.92581 .54472 m
.92581 .54472 L
s
.92581 .54472 m
.92581 .54472 L
s
.92581 .54472 m
.92581 .54472 L
s
.92581 .54472 m
.92581 .54472 L
s
0 1 .511 r
.48541 .29349 m
.4996 .30756 L
s
.47087 .30198 m
.48541 .29349 L
s
.48541 .29349 m
.49098 .29153 L
s
1 .607 0 r
.50774 .68682 m
.50675 .68556 L
s
.50675 .68556 m
.51157 .68939 L
s
1 .606 0 r
.52564 .57806 m
.52667 .57315 L
s
.973 1 0 r
.61336 .34842 m
.61687 .34054 L
s
1 .22 0 r
.38749 .69137 m
.38846 .6898 L
s
1 .026 0 r
.86605 .68958 m
.8662 .68974 L
s
.86593 .68968 m
.86605 .68958 L
s
.86605 .68958 m
.86617 .68961 L
s
1 .39 0 r
.65523 .36691 m
.65323 .36939 L
s
.65739 .368 m
.65523 .36691 L
s
1 .026 0 r
.8662 .68974 m
.86608 .68985 L
s
.86617 .68961 m
.8662 .68974 L
s
1 .336 0 r
.434 .66063 m
.43186 .6613 L
s
.43195 .65792 m
.434 .66063 L
s
.434 .66063 m
.43059 .66039 L
s
.43322 .65883 m
.434 .66063 L
s
.42349 .65552 m
.434 .66063 L
s
.808 1 0 r
.46778 .31149 m
.46179 .31422 L
s
.46742 .30351 m
.46778 .31149 L
s
1 .026 0 r
.86608 .68985 m
.86593 .68968 L
s
.86593 .68968 m
.86617 .68961 L
s
1 .116 0 r
.69944 .65971 m
.7 .6605 L
s
.69893 .66008 m
.69944 .65971 L
s
.69944 .65971 m
.70006 .65987 L
s
1 .026 0 r
.86617 .68961 m
.86608 .68985 L
s
1 .033 0 r
.2297 .36937 m
.22989 .36954 L
s
.22949 .3695 m
.2297 .36937 L
s
.2297 .36937 m
.22971 .36935 L
s
1 .116 0 r
.7 .6605 m
.6995 .66087 L
s
.70006 .65987 m
.7 .6605 L
s
1 .033 0 r
.22989 .36954 m
.22967 .36967 L
s
.22971 .36935 m
.22989 .36954 L
s
1 .457 0 r
.40336 .36849 m
.40235 .3729 L
s
1 .033 0 r
.22967 .36967 m
.22949 .3695 L
s
.22949 .3695 m
.22971 .36935 L
s
1 .336 0 r
.43195 .65792 m
.43059 .66039 L
s
.43322 .65883 m
.43195 .65792 L
s
1 .033 0 r
.22971 .36935 m
.22967 .36967 L
s
1 .336 0 r
.43059 .66039 m
.43186 .6613 L
s
1 .39 0 r
.65323 .36939 m
.65538 .37049 L
s
1 .59 0 r
.47913 .63122 m
.48105 .6326 L
s
.48113 .62672 m
.47913 .63122 L
s
.48514 .63119 m
.47913 .63122 L
s
1 .607 0 r
.51157 .68939 m
.50672 .69171 L
s
.50774 .68682 m
.51157 .68939 L
s
.48735 .68561 m
.51157 .68939 L
s
1 .59 0 r
.48514 .63119 m
.48105 .6326 L
s
.48113 .62672 m
.48514 .63119 L
s
.48306 .62809 m
.48514 .63119 L
s
.46479 .6235 m
.48514 .63119 L
s
.285 1 0 r
.59585 .39832 m
.59918 .4002 L
s
.59881 .38428 m
.59585 .39832 L
s
.61256 .39477 m
.59585 .39832 L
s
1 .091 0 r
.79654 .311 m
.7964 .31094 L
s
.79632 .31012 m
.79654 .311 L
s
.79654 .311 m
.79583 .31065 L
s
.79688 .31042 m
.79654 .311 L
s
.79564 .30867 m
.79654 .311 L
s
0 .197 1 r
.42386 .31214 m
.44292 .32236 L
s
.4038 .33636 m
.42386 .31214 L
s
.42386 .31214 m
.40705 .31112 L
s
1 .002 0 r
.33781 .54377 m
.33781 .54377 L
s
.33781 .54376 m
.33781 .54377 L
s
.33781 .54377 m
.3378 .54377 L
s
.33782 .54376 m
.33781 .54377 L
s
.33779 .54373 m
.33781 .54377 L
s
.33781 .54376 m
.3378 .54377 L
s
.33782 .54376 m
.33781 .54376 L
s
.3378 .54377 m
.33781 .54377 L
s
.33781 .54377 m
.33782 .54376 L
s
1 .59 0 r
.48306 .62809 m
.48113 .62672 L
s
1 .033 0 r
.8022 .66013 m
.80286 .65945 L
s
1 0 0 r
.86241 .51463 m
.86241 .51463 L
s
1 .481 0 r
.57 .60193 m
.58775 .59664 L
s
1 .303 0 r
.39799 .39822 m
.40107 .39066 L
s
1 .026 0 r
.16579 .34002 m
.16587 .33933 L
s
1 .116 0 r
.6995 .66087 m
.69893 .66008 L
s
.69893 .66008 m
.70006 .65987 L
s
1 .417 0 r
.3821 .30777 m
.38426 .31041 L
s
.37977 .3089 m
.3821 .30777 L
s
.3821 .30777 m
.38349 .30765 L
s
1 .091 0 r
.79632 .31012 m
.79583 .31065 L
s
.79688 .31042 m
.79632 .31012 L
s
1 .116 0 r
.70006 .65987 m
.6995 .66087 L
s
1 .034 0 r
.85931 .3398 m
.8593 .33977 L
s
.85926 .33946 m
.85931 .3398 L
s
.85931 .3398 m
.85908 .33965 L
s
.85948 .33959 m
.85931 .3398 L
s
.85916 .33891 m
.85931 .3398 L
s
1 .091 0 r
.79583 .31065 m
.7964 .31094 L
s
1 .034 0 r
.85926 .33946 m
.85908 .33965 L
s
.85948 .33959 m
.85926 .33946 L
s
.787 1 0 r
.54292 .60163 m
.54505 .6038 L
s
.54498 .5918 m
.54292 .60163 L
s
.55466 .59939 m
.54292 .60163 L
s
1 .034 0 r
.85908 .33965 m
.8593 .33977 L
s
0 .434 1 r
.5404 .68317 m
.55896 .65982 L
s
1 .111 0 r
.67231 .42694 m
.67222 .4269 L
s
.67217 .42586 m
.67231 .42694 L
s
.67231 .42694 m
.67154 .42645 L
s
.67285 .42631 m
.67231 .42694 L
s
.67174 .42415 m
.67231 .42694 L
s
1 .034 0 r
.8593 .33977 m
.85948 .33959 L
s
1 .026 0 r
.16587 .33935 m
.16601 .33949 L
s
.1657 .33945 m
.16587 .33935 L
s
.16587 .33935 m
.16587 .33933 L
s
1 .091 0 r
.7964 .31094 m
.79688 .31042 L
s
1 .417 0 r
.38426 .31041 m
.38193 .31154 L
s
.38349 .30765 m
.38426 .31041 L
s
1 .023 0 r
.2142 .6597 m
.2141 .65972 L
s
.21412 .65949 m
.2142 .6597 L
s
.2142 .6597 m
.21399 .65963 L
s
.21424 .65958 m
.2142 .6597 L
s
.21376 .65921 m
.2142 .6597 L
s
1 .39 0 r
.6066 .6597 m
.60376 .66248 L
s
.60266 .65943 m
.6066 .6597 L
s
1 .026 0 r
.16601 .33949 m
.16584 .33959 L
s
.16587 .33933 m
.16601 .33949 L
s
1 .033 0 r
.80272 .65942 m
.80291 .65963 L
s
.80256 .65955 m
.80272 .65942 L
s
.80272 .65942 m
.80286 .65945 L
s
1 .026 0 r
.16584 .33959 m
.1657 .33945 L
s
.1657 .33945 m
.16587 .33933 L
s
1 .023 0 r
.21412 .65949 m
.21399 .65963 L
s
.21424 .65958 m
.21412 .65949 L
s
.21399 .65963 m
.2141 .65972 L
s
1 .033 0 r
.80291 .65963 m
.80275 .65976 L
s
.80286 .65945 m
.80291 .65963 L
s
1 .026 0 r
.16587 .33933 m
.16584 .33959 L
s
1 .39 0 r
.60376 .66248 m
.60266 .65943 L
s
1 .023 0 r
.2141 .65972 m
.21424 .65958 L
s
1 .111 0 r
.67217 .42586 m
.67154 .42645 L
s
.67285 .42631 m
.67217 .42586 L
s
1 .033 0 r
.80275 .65976 m
.80256 .65955 L
s
.80256 .65955 m
.80286 .65945 L
s
.80286 .65945 m
.80275 .65976 L
s
1 .398 0 r
.47767 .48182 m
.47971 .48305 L
s
.47559 .48439 m
.47767 .48182 L
s
.47767 .48182 m
.47602 .48199 L
s
1 .111 0 r
.67154 .42645 m
.67222 .4269 L
s
.425 1 0 r
.50887 .58223 m
.5171 .572 L
s
1 .111 0 r
.67222 .4269 m
.67285 .42631 L
s
1 0 0 r
.79892 .48452 m
.79892 .48451 L
s
.79892 .48451 m
.79892 .48452 L
s
.79892 .48452 m
.79892 .48451 L
s
.79892 .48451 m
.79892 .48452 L
s
.79892 .4845 m
.79892 .48452 L
s
.79892 .48451 m
.79892 .48451 L
s
.79892 .48451 m
.79892 .48451 L
s
.79892 .48451 m
.79892 .48451 L
s
.79892 .48451 m
.79892 .48451 L
s
1 .011 0 r
.97103 .68833 m
.97123 .6881 L
s
1 .046 0 r
.73869 .6301 m
.7396 .62916 L
s
1 0 0 r
.274 .51362 m
.274 .51362 L
s
1 .137 0 r
.33424 .36803 m
.33551 .36455 L
s
1 .022 0 r
.1019 .30979 m
.10196 .30922 L
s
1 .39 0 r
.65538 .37049 m
.65739 .368 L
s
1 .398 0 r
.47762 .48562 m
.47559 .48439 L
s
.47559 .48439 m
.47602 .48199 L
s
1 .011 0 r
.97118 .68809 m
.97125 .68816 L
s
.97113 .68814 m
.97118 .68809 L
s
.97118 .68809 m
.97123 .6881 L
s
.97125 .68816 m
.97119 .6882 L
s
.97123 .6881 m
.97125 .68816 L
s
.97119 .6882 m
.97113 .68814 L
s
.97113 .68814 m
.97123 .6881 L
s
.97123 .6881 m
.97119 .6882 L
s
.285 1 0 r
.60216 .38608 m
.59881 .38428 L
s
.59881 .38428 m
.61256 .39477 L
s
.787 1 0 r
.54712 .59394 m
.54498 .5918 L
s
.54498 .5918 m
.55466 .59939 L
s
0 .04 1 r
.52596 .71718 m
.54683 .7318 L
s
1 .08 0 r
.32029 .65893 m
.31991 .65902 L
s
.31996 .65822 m
.32029 .65893 L
s
.32029 .65893 m
.31953 .65874 L
s
.32033 .6585 m
.32029 .65893 L
s
.31851 .65737 m
.32029 .65893 L
s
1 .032 0 r
.44328 .54242 m
.44314 .54244 L
s
.44315 .54213 m
.44328 .54242 L
s
.44328 .54242 m
.44298 .54234 L
s
.44331 .54223 m
.44328 .54242 L
s
.44262 .54175 m
.44328 .54242 L
s
1 .022 0 r
.10196 .30924 m
.10207 .30935 L
s
.10182 .30932 m
.10196 .30924 L
s
.10196 .30924 m
.10196 .30922 L
s
1 .032 0 r
.44315 .54213 m
.44298 .54234 L
s
.44331 .54223 m
.44315 .54213 L
s
1 .022 0 r
.10207 .30935 m
.10193 .30943 L
s
.10196 .30922 m
.10207 .30935 L
s
1 .032 0 r
.44298 .54234 m
.44314 .54244 L
s
1 .336 0 r
.43186 .6613 m
.43322 .65883 L
s
1 .022 0 r
.10193 .30943 m
.10182 .30932 L
s
.10182 .30932 m
.10196 .30922 L
s
1 .08 0 r
.31996 .65822 m
.31953 .65874 L
s
.32033 .6585 m
.31996 .65822 L
s
1 .022 0 r
.10196 .30922 m
.10193 .30943 L
s
1 .215 0 r
.63862 .62806 m
.63955 .6296 L
s
.63776 .62865 m
.63862 .62806 L
s
.63862 .62806 m
.63993 .62842 L
s
1 .575 0 r
.64429 .30922 m
.64103 .30967 L
s
.64083 .30448 m
.64429 .30922 L
s
.64429 .30922 m
.6385 .30871 L
s
.64337 .30544 m
.64429 .30922 L
s
.62742 .29846 m
.64429 .30922 L
s
1 .032 0 r
.44314 .54244 m
.44331 .54223 L
s
1 .08 0 r
.31953 .65874 m
.31991 .65902 L
s
1 .215 0 r
.63955 .6296 m
.63869 .6302 L
s
.63993 .62842 m
.63955 .6296 L
s
1 .046 0 r
.73941 .62912 m
.73966 .62941 L
s
.73918 .62928 m
.73941 .62912 L
s
.73941 .62912 m
.7396 .62916 L
s
.73966 .62941 m
.73944 .62957 L
s
.7396 .62916 m
.73966 .62941 L
s
1 .01 0 r
.73535 .4546 m
.73536 .4546 L
s
.73535 .4545 m
.73535 .4546 L
s
.73535 .4546 m
.73529 .45455 L
s
.73542 .45455 m
.73535 .4546 L
s
.73537 .45434 m
.73535 .4546 L
s
.73535 .4545 m
.73529 .45455 L
s
.73542 .45455 m
.73535 .4545 L
s
1 .08 0 r
.31991 .65902 m
.32033 .6585 L
s
1 .417 0 r
.38193 .31154 m
.37977 .3089 L
s
.37977 .3089 m
.38349 .30765 L
s
1 .01 0 r
.73529 .45455 m
.73536 .4546 L
s
.73536 .4546 m
.73542 .45455 L
s
1 .046 0 r
.73944 .62957 m
.73918 .62928 L
s
.73918 .62928 m
.7396 .62916 L
s
.7396 .62916 m
.73944 .62957 L
s
1 .575 0 r
.64083 .30448 m
.6385 .30871 L
s
.64337 .30544 m
.64083 .30448 L
s
.6385 .30871 m
.64103 .30967 L
s
1 .012 0 r
.90757 .65829 m
.90778 .65804 L
s
1 .07 0 r
.6751 .60002 m
.67659 .59859 L
s
0 .813 1 r
.50289 .39607 m
.62139 .35577 L
s
1 0 0 r
.21014 .48348 m
.21014 .48347 L
s
1 .081 0 r
.27041 .3378 m
.27109 .33572 L
s
1 0 0 r
.21014 .48347 m
.21014 .48347 L
s
.21013 .48347 m
.21014 .48347 L
s
.21014 .48347 m
.21014 .48347 L
s
.21014 .48347 m
.21013 .48347 L
s
.21013 .48347 m
.21014 .48347 L
s
.21014 .48347 m
.21014 .48347 L
s
.21014 .48347 m
.21014 .48347 L
s
.21014 .48347 m
.21014 .48347 L
s
1 .417 0 r
.38349 .30765 m
.38193 .31154 L
s
1 .012 0 r
.90773 .65803 m
.9078 .6581 L
s
.90767 .65808 m
.90773 .65803 L
s
.90773 .65803 m
.90778 .65804 L
s
1 .607 0 r
.50672 .69171 m
.50774 .68682 L
s
1 .012 0 r
.9078 .6581 m
.90774 .65815 L
s
.90778 .65804 m
.9078 .6581 L
s
.90774 .65815 m
.90767 .65808 L
s
.90767 .65808 m
.90778 .65804 L
s
.90778 .65804 m
.90774 .65815 L
s
1 .398 0 r
.47971 .48305 m
.47762 .48562 L
s
.47602 .48199 m
.47971 .48305 L
s
1 .215 0 r
.63869 .6302 m
.63776 .62865 L
s
.63776 .62865 m
.63993 .62842 L
s
.63993 .62842 m
.63869 .6302 L
s
.787 1 0 r
.55466 .59939 m
.54505 .6038 L
s
.54712 .59394 m
.55466 .59939 L
s
.50623 .59136 m
.55466 .59939 L
s
1 .398 0 r
.47602 .48199 m
.47762 .48562 L
s
1 .59 0 r
.48105 .6326 m
.48306 .62809 L
s
1 .481 0 r
.5855 .5991 m
.58423 .60008 L
s
.58415 .59532 m
.5855 .5991 L
s
.58775 .59664 m
.5855 .5991 L
s
1 .575 0 r
.57056 .71569 m
.57006 .7169 L
s
.56998 .71101 m
.57056 .71569 L
s
.57475 .71352 m
.57056 .71569 L
s
0 1 .511 r
.4996 .30756 m
.48511 .31614 L
s
.49098 .29153 m
.4996 .30756 L
s
1 0 0 r
.90435 .48246 m
.90435 .48246 L
s
.90435 .48245 m
.90435 .48246 L
s
.90435 .48246 m
.90435 .48246 L
s
.90435 .48246 m
.90435 .48246 L
s
.90435 .48245 m
.90435 .48246 L
s
.90435 .48245 m
.90435 .48246 L
s
.90435 .48246 m
.90435 .48245 L
s
.90435 .48246 m
.90435 .48246 L
s
.90435 .48246 m
.90435 .48246 L
s
1 .013 0 r
.84405 .62822 m
.84425 .62794 L
s
1 .575 0 r
.55112 .71567 m
.57475 .71352 L
s
1 .136 0 r
.61143 .56991 m
.6148 .56729 L
s
1 0 0 r
.37881 .51161 m
.37881 .51161 L
s
1 .825 0 r
.43912 .36584 m
.45814 .34782 L
s
1 .001 0 r
.1462 .4533 m
.14619 .45327 L
s
1 .055 0 r
.20651 .30754 m
.20692 .3061 L
s
1 .001 0 r
.1462 .45327 m
.1462 .45328 L
s
.14619 .45328 m
.1462 .45327 L
s
.1462 .45327 m
.14619 .45327 L
s
1 .07 0 r
.67627 .59853 m
.67665 .59898 L
s
.67593 .59877 m
.67627 .59853 L
s
.67627 .59853 m
.67659 .59859 L
s
1 .001 0 r
.1462 .45328 m
.14619 .45328 L
s
.14619 .45327 m
.1462 .45328 L
s
.14619 .45328 m
.14619 .45328 L
s
.14619 .45328 m
.14619 .45327 L
s
.14619 .45327 m
.14619 .45328 L
s
1 .07 0 r
.67665 .59898 m
.67631 .59922 L
s
.67659 .59859 m
.67665 .59898 L
s
1 .137 0 r
.33529 .36462 m
.33605 .3654 L
s
.33446 .3651 m
.33529 .36462 L
s
.33529 .36462 m
.33551 .36455 L
s
1 .013 0 r
.8442 .62793 m
.84428 .62801 L
s
.84414 .62798 m
.8442 .62793 L
s
.8442 .62793 m
.84425 .62794 L
s
1 .481 0 r
.58288 .5963 m
.58415 .59532 L
s
.58415 .59532 m
.58775 .59664 L
s
.285 1 0 r
.61256 .39477 m
.59918 .4002 L
s
.60216 .38608 m
.61256 .39477 L
s
.54436 .38197 m
.61256 .39477 L
s
1 .013 0 r
.84428 .62801 m
.84422 .62806 L
s
.84425 .62794 m
.84428 .62801 L
s
.84422 .62806 m
.84414 .62798 L
s
.84414 .62798 m
.84425 .62794 L
s
.84425 .62794 m
.84422 .62806 L
s
1 .081 0 r
.27098 .33577 m
.27143 .33622 L
s
.27048 .33605 m
.27098 .33577 L
s
.27098 .33577 m
.27109 .33572 L
s
0 .197 1 r
.42271 .34683 m
.4038 .33636 L
s
.4038 .33636 m
.40705 .31112 L
s
1 .07 0 r
.67631 .59922 m
.67593 .59877 L
s
.67593 .59877 m
.67659 .59859 L
s
.67659 .59859 m
.67631 .59922 L
s
1 .137 0 r
.33605 .3654 m
.33522 .36588 L
s
.33551 .36455 m
.33605 .3654 L
s
1 .081 0 r
.27143 .33622 m
.27092 .3365 L
s
.27109 .33572 m
.27143 .33622 L
s
1 .575 0 r
.56947 .71221 m
.56998 .71101 L
s
.56998 .71101 m
.57475 .71352 L
s
1 .022 0 r
.25498 .62775 m
.25489 .62777 L
s
.25491 .62755 m
.25498 .62775 L
s
.25498 .62775 m
.25478 .62768 L
s
.25502 .62763 m
.25498 .62775 L
s
.25459 .62727 m
.25498 .62775 L
s
.25491 .62755 m
.25478 .62768 L
s
.25502 .62763 m
.25491 .62755 L
s
.25478 .62768 m
.25489 .62777 L
s
1 .081 0 r
.27092 .3365 m
.27048 .33605 L
s
.27048 .33605 m
.27109 .33572 L
s
1 .022 0 r
.25489 .62777 m
.25502 .62763 L
s
1 .137 0 r
.33522 .36588 m
.33446 .3651 L
s
.33446 .3651 m
.33551 .36455 L
s
1 .081 0 r
.27109 .33572 m
.27092 .3365 L
s
1 .481 0 r
.61755 .4233 m
.61582 .42339 L
s
.61569 .41888 m
.61755 .4233 L
s
.61755 .4233 m
.6132 .42197 L
s
.61831 .42029 m
.61755 .4233 L
s
.60852 .4124 m
.61755 .4233 L
s
1 .055 0 r
.20686 .30614 m
.20716 .30645 L
s
.20651 .30633 m
.20686 .30614 L
s
.20686 .30614 m
.20692 .3061 L
s
1 .1 0 r
.36175 .62738 m
.36129 .62748 L
s
.36134 .62649 m
.36175 .62738 L
s
.36175 .62738 m
.36081 .62714 L
s
.36182 .62683 m
.36175 .62738 L
s
.35957 .62539 m
.36175 .62738 L
s
1 .137 0 r
.33551 .36455 m
.33522 .36588 L
s
1 .09 0 r
.71412 .39402 m
.71401 .39399 L
s
.71396 .39315 m
.71412 .39402 L
s
.71412 .39402 m
.71346 .39365 L
s
.71451 .39349 m
.71412 .39402 L
s
.71342 .39175 m
.71412 .39402 L
s
1 .002 0 r
.84078 .45231 m
.84078 .45231 L
s
.84078 .45229 m
.84078 .45231 L
s
.84078 .45231 m
.84077 .4523 L
s
.84079 .4523 m
.84078 .45231 L
s
.84078 .45226 m
.84078 .45231 L
s
.84078 .45229 m
.84077 .4523 L
s
.84079 .4523 m
.84078 .45229 L
s
.84077 .4523 m
.84078 .45231 L
s
.84078 .45231 m
.84079 .4523 L
s
1 .055 0 r
.20716 .30645 m
.20681 .30664 L
s
.20692 .3061 m
.20716 .30645 L
s
1 .013 0 r
.78044 .5981 m
.78064 .59781 L
s
1 .398 0 r
.54769 .53976 m
.56236 .5352 L
s
1 .001 0 r
.31494 .48143 m
.31493 .48139 L
s
1 .323 0 r
.37528 .33558 m
.38098 .32787 L
s
1 .001 0 r
.31493 .48139 m
.31494 .4814 L
s
.31492 .4814 m
.31493 .48139 L
s
.31493 .48139 m
.31493 .48139 L
s
.31493 .4814 m
.31492 .4814 L
s
.31492 .4814 m
.31493 .48139 L
s
.31494 .4814 m
.31493 .4814 L
s
.31493 .48139 m
.31494 .4814 L
s
.31493 .48139 m
.31493 .4814 L
s
1 .1 0 r
.36134 .62649 m
.36081 .62714 L
s
.36182 .62683 m
.36134 .62649 L
s
1 .055 0 r
.20681 .30664 m
.20651 .30633 L
s
.20651 .30633 m
.20692 .3061 L
s
1 .09 0 r
.71396 .39315 m
.71346 .39365 L
s
.71451 .39349 m
.71396 .39315 L
s
1 .1 0 r
.36081 .62714 m
.36129 .62748 L
s
1 .055 0 r
.20692 .3061 m
.20681 .30664 L
s
.808 1 0 r
.46179 .31422 m
.45601 .30617 L
s
.45601 .30617 m
.46742 .30351 L
s
1 .013 0 r
.7806 .5978 m
.78068 .59788 L
s
.78053 .59786 m
.7806 .5978 L
s
.7806 .5978 m
.78064 .59781 L
s
.78068 .59788 m
.78061 .59793 L
s
.78064 .59781 m
.78068 .59788 L
s
1 .09 0 r
.71346 .39365 m
.71401 .39399 L
s
1 .013 0 r
.78061 .59793 m
.78053 .59786 L
s
.78053 .59786 m
.78064 .59781 L
s
.78064 .59781 m
.78061 .59793 L
s
1 .09 0 r
.71401 .39399 m
.71451 .39349 L
s
1 .1 0 r
.36129 .62748 m
.36182 .62683 L
s
1 .016 0 r
.77716 .42243 m
.77716 .42242 L
s
.77715 .42227 m
.77716 .42243 L
s
.77716 .42243 m
.77706 .42236 L
s
.77725 .42234 m
.77716 .42243 L
s
.77714 .42202 m
.77716 .42243 L
s
1 .481 0 r
.61569 .41888 m
.6132 .42197 L
s
.61831 .42029 m
.61569 .41888 L
s
1 .016 0 r
.77715 .42227 m
.77706 .42236 L
s
.77725 .42234 m
.77715 .42227 L
s
1 .825 0 r
.55633 .65581 m
.55626 .65734 L
s
.55618 .64903 m
.55633 .65581 L
s
.5631 .65306 m
.55633 .65581 L
s
1 .016 0 r
.77706 .42236 m
.77716 .42242 L
s
.77716 .42242 m
.77725 .42234 L
s
1 .136 0 r
.61411 .56715 m
.61477 .56808 L
s
.61348 .56756 m
.61411 .56715 L
s
.61411 .56715 m
.6148 .56729 L
s
1 .303 0 r
.40051 .39077 m
.4022 .3925 L
s
.3987 .39186 m
.40051 .39077 L
s
.40051 .39077 m
.40107 .39066 L
s
1 .575 0 r
.64103 .30967 m
.64337 .30544 L
s
.808 1 0 r
.46742 .30351 m
.46179 .31422 L
s
1 .136 0 r
.61477 .56808 m
.61414 .56848 L
s
.6148 .56729 m
.61477 .56808 L
s
1 .005 0 r
.19067 .59726 m
.19066 .59726 L
s
.19066 .59721 m
.19067 .59726 L
s
.19067 .59726 m
.19063 .59724 L
s
.19069 .59723 m
.19067 .59726 L
s
.19061 .59714 m
.19067 .59726 L
s
.19066 .59721 m
.19063 .59724 L
s
.19069 .59723 m
.19066 .59721 L
s
1 .241 0 r
.69564 .33458 m
.69485 .33453 L
s
.69473 .33234 m
.69564 .33458 L
s
.69564 .33458 m
.69349 .33388 L
s
.69609 .333 m
.69564 .33458 L
s
.69137 .32887 m
.69564 .33458 L
s
1 .005 0 r
.19063 .59724 m
.19066 .59726 L
s
.19066 .59726 m
.19069 .59723 L
s
.542 1 0 r
.52723 .30529 m
.52309 .30688 L
s
.5231 .29371 m
.52723 .30529 L
s
.53381 .29646 m
.52723 .30529 L
s
1 .005 0 r
.94965 .62633 m
.94972 .62623 L
s
1 .293 0 r
.65638 .71389 m
.66577 .70963 L
s
1 .013 0 r
.71676 .56796 m
.71695 .56767 L
s
1 0 0 r
.48387 .50958 m
.48387 .50958 L
s
1 .004 0 r
.25098 .45121 m
.25098 .45112 L
s
1 .168 0 r
.31136 .30528 m
.31383 .3011 L
s
1 .481 0 r
.6132 .42197 m
.61582 .42339 L
s
1 .004 0 r
.25098 .45112 m
.251 .45114 L
s
.25096 .45113 m
.25098 .45112 L
s
.25098 .45112 m
.25098 .45112 L
s
.251 .45114 m
.25098 .45115 L
s
.25098 .45112 m
.251 .45114 L
s
.25098 .45115 m
.25096 .45113 L
s
.25096 .45113 m
.25098 .45112 L
s
1 .005 0 r
.9497 .62623 m
.94973 .62625 L
s
.94968 .62625 m
.9497 .62623 L
s
.9497 .62623 m
.94972 .62623 L
s
1 .004 0 r
.25098 .45112 m
.25098 .45115 L
s
1 .005 0 r
.94973 .62625 m
.94971 .62627 L
s
.94972 .62623 m
.94973 .62625 L
s
.94971 .62627 m
.94968 .62625 L
s
.94968 .62625 m
.94972 .62623 L
s
.94972 .62623 m
.94971 .62627 L
s
1 .013 0 r
.71691 .56767 m
.71698 .56774 L
s
.71684 .56772 m
.71691 .56767 L
s
.71691 .56767 m
.71695 .56767 L
s
.71698 .56774 m
.71691 .56779 L
s
.71695 .56767 m
.71698 .56774 L
s
.71691 .56779 m
.71684 .56772 L
s
.71684 .56772 m
.71695 .56767 L
s
.71695 .56767 m
.71691 .56779 L
s
1 .303 0 r
.4022 .3925 m
.40039 .39359 L
s
.40107 .39066 m
.4022 .3925 L
s
1 .241 0 r
.69473 .33234 m
.69349 .33388 L
s
.69609 .333 m
.69473 .33234 L
s
1 .136 0 r
.61414 .56848 m
.61348 .56756 L
s
.61348 .56756 m
.6148 .56729 L
s
1 .575 0 r
.57475 .71352 m
.57006 .7169 L
s
.56947 .71221 m
.57475 .71352 L
s
0 .197 1 r
.62499 .33398 m
.61534 .3385 L
s
.61432 .30376 m
.62499 .33398 L
s
.64347 .3111 m
.62499 .33398 L
s
1 .825 0 r
.55611 .65054 m
.55618 .64903 L
s
.55618 .64903 m
.5631 .65306 L
s
1 .136 0 r
.6148 .56729 m
.61414 .56848 L
s
1 .241 0 r
.69349 .33388 m
.69485 .33453 L
s
1 .481 0 r
.58775 .59664 m
.58423 .60008 L
s
.58288 .5963 m
.58775 .59664 L
s
.58423 .60008 m
.58288 .5963 L
s
.808 1 0 r
.56174 .30454 m
.56166 .30527 L
s
.56153 .2945 m
.56174 .30454 L
s
.57155 .29966 m
.56174 .30454 L
s
.542 1 0 r
.51894 .29524 m
.5231 .29371 L
s
.5231 .29371 m
.53381 .29646 L
s
1 .303 0 r
.40039 .39359 m
.3987 .39186 L
s
.3987 .39186 m
.40107 .39066 L
s
.285 1 0 r
.55813 .62548 m
.56125 .6287 L
s
.56106 .61156 m
.55813 .62548 L
s
.57482 .62235 m
.55813 .62548 L
s
1 .004 0 r
.88604 .59618 m
.88609 .5961 L
s
1 .525 0 r
.59259 .6838 m
.61213 .67829 L
s
1 .008 0 r
.65301 .53778 m
.65312 .53758 L
s
1 .021 0 r
.41998 .47937 m
.41992 .47885 L
s
.717 1 0 r
.4804 .33335 m
.52739 .31675 L
s
1 .005 0 r
.18696 .42096 m
.18695 .42083 L
s
1 .004 0 r
.88607 .5961 m
.8861 .59612 L
s
.88605 .59611 m
.88607 .5961 L
s
.88607 .5961 m
.88609 .5961 L
s
.8861 .59612 m
.88608 .59613 L
s
.88609 .5961 m
.8861 .59612 L
s
.88608 .59613 m
.88605 .59611 L
s
.88605 .59611 m
.88609 .5961 L
s
.88609 .5961 m
.88608 .59613 L
s
1 .005 0 r
.18695 .42083 m
.18698 .42085 L
s
.18692 .42085 m
.18695 .42083 L
s
.18695 .42083 m
.18695 .42083 L
s
.18698 .42085 m
.18695 .42088 L
s
.18695 .42083 m
.18698 .42085 L
s
.18695 .42088 m
.18692 .42085 L
s
.18692 .42085 m
.18695 .42083 L
s
.18695 .42083 m
.18695 .42088 L
s
1 .008 0 r
.6531 .53758 m
.65315 .53763 L
s
.65305 .53761 m
.6531 .53758 L
s
.6531 .53758 m
.65312 .53758 L
s
.65315 .53763 m
.6531 .53766 L
s
.65312 .53758 m
.65315 .53763 L
s
.6531 .53766 m
.65305 .53761 L
s
.65305 .53761 m
.65312 .53758 L
s
.65312 .53758 m
.6531 .53766 L
s
1 .133 0 r
.40362 .59601 m
.40302 .59612 L
s
.40307 .59481 m
.40362 .59601 L
s
.40362 .59601 m
.40237 .59568 L
s
.40373 .59526 m
.40362 .59601 L
s
.40078 .59329 m
.40362 .59601 L
s
0 1 .331 r
.48353 .31589 m
.49677 .32906 L
s
.46997 .32391 m
.48353 .31589 L
s
.48353 .31589 m
.48871 .31429 L
s
1 .241 0 r
.69485 .33453 m
.69609 .333 L
s
1 .021 0 r
.41994 .47886 m
.42006 .47895 L
s
.41981 .47896 m
.41994 .47886 L
s
.41994 .47886 m
.41992 .47885 L
s
1 .303 0 r
.40107 .39066 m
.40039 .39359 L
s
1 .575 0 r
.57006 .7169 m
.56947 .71221 L
s
1 .021 0 r
.41993 .47905 m
.41981 .47896 L
s
.41981 .47896 m
.41992 .47885 L
s
.42006 .47895 m
.41993 .47905 L
s
.41992 .47885 m
.42006 .47895 L
s
1 .133 0 r
.40307 .59481 m
.40237 .59568 L
s
.40373 .59526 m
.40307 .59481 L
s
1 .021 0 r
.41992 .47885 m
.41993 .47905 L
s
1 .398 0 r
.56052 .53732 m
.55944 .53806 L
s
.5594 .53418 m
.56052 .53732 L
s
.56236 .5352 m
.56052 .53732 L
s
0 .434 1 r
.42725 .3357 m
.4452 .34552 L
s
.40837 .35853 m
.42725 .3357 L
s
.42725 .3357 m
.41148 .33508 L
s
1 .133 0 r
.40237 .59568 m
.40302 .59612 L
s
1 .825 0 r
.48455 .65409 m
.48726 .65609 L
s
.48736 .64778 m
.48455 .65409 L
s
.49299 .65405 m
.48455 .65409 L
s
.60541 .36196 m
.60845 .36319 L
s
.60824 .3556 m
.60541 .36196 L
s
.61386 .3619 m
.60541 .36196 L
s
1 .02 0 r
.29587 .59566 m
.2958 .59567 L
s
.29582 .59547 m
.29587 .59566 L
s
.29587 .59566 m
.2957 .59559 L
s
.29592 .59555 m
.29587 .59566 L
s
.29557 .59522 m
.29587 .59566 L
s
1 .398 0 r
.49174 .53723 m
.4901 .53748 L
s
.49015 .53361 m
.49174 .53723 L
s
.49174 .53723 m
.48805 .5362 L
s
.4922 .53489 m
.49174 .53723 L
s
.48363 .52877 m
.49174 .53723 L
s
1 .825 0 r
.49299 .65405 m
.48726 .65609 L
s
.48736 .64778 m
.49299 .65405 L
s
.49008 .64976 m
.49299 .65405 L
s
.46443 .64339 m
.49299 .65405 L
s
.61386 .3619 m
.60845 .36319 L
s
.60824 .3556 m
.61386 .3619 L
s
.61128 .35682 m
.61386 .3619 L
s
.58612 .34927 m
.61386 .3619 L
s
1 .02 0 r
.29582 .59547 m
.2957 .59559 L
s
.29592 .59555 m
.29582 .59547 L
s
.2957 .59559 m
.2958 .59567 L
s
1 .481 0 r
.61582 .42339 m
.61831 .42029 L
s
.973 1 0 r
.45856 .32505 m
.46355 .332 L
s
.45336 .32745 m
.45856 .32505 L
s
.45856 .32505 m
.46322 .32517 L
s
1 .398 0 r
.55831 .53491 m
.5594 .53418 L
s
.5594 .53418 m
.56236 .5352 L
s
1 .02 0 r
.2958 .59567 m
.29592 .59555 L
s
0 .197 1 r
.54424 .70821 m
.56411 .68316 L
s
.808 1 0 r
.56145 .29519 m
.56153 .2945 L
s
.56153 .2945 m
.57155 .29966 L
s
1 .825 0 r
.49008 .64976 m
.48736 .64778 L
s
.61128 .35682 m
.60824 .3556 L
s
1 .293 0 r
.39018 .71229 m
.38839 .71286 L
s
.38851 .70986 m
.39018 .71229 L
s
.39018 .71229 m
.38722 .71197 L
s
.38968 .71075 m
.39018 .71229 L
s
.3815 .70762 m
.39018 .71229 L
s
1 .004 0 r
.88279 .42 m
.88279 .42 L
s
.88279 .41996 m
.88279 .42 L
s
.88279 .42 m
.88276 .41998 L
s
.88281 .41998 m
.88279 .42 L
s
.88279 .41989 m
.88279 .42 L
s
.88279 .41996 m
.88276 .41998 L
s
.88281 .41998 m
.88279 .41996 L
s
.88276 .41998 m
.88279 .42 L
s
.88279 .42 m
.88281 .41998 L
s
1 .133 0 r
.40302 .59612 m
.40373 .59526 L
s
1 .104 0 r
.76189 .71211 m
.76441 .71017 L
s
1 .003 0 r
.82234 .566 m
.82237 .56594 L
s
1 .825 0 r
.52873 .65366 m
.5631 .65306 L
s
1 0 0 r
.58918 .50756 m
.58918 .50756 L
s
1 .024 0 r
.35602 .44912 m
.35605 .44852 L
s
1 .575 0 r
.41647 .30301 m
.4323 .29144 L
s
1 .006 0 r
.12285 .39067 m
.12285 .39052 L
s
1 .003 0 r
.82237 .56594 m
.82238 .56595 L
s
.82235 .56595 m
.82237 .56594 L
s
.82237 .56594 m
.82237 .56594 L
s
.82238 .56595 m
.82237 .56597 L
s
.82237 .56594 m
.82238 .56595 L
s
.82237 .56597 m
.82235 .56595 L
s
.82235 .56595 m
.82237 .56594 L
s
.82237 .56594 m
.82237 .56597 L
s
1 .293 0 r
.38851 .70986 m
.38722 .71197 L
s
.38968 .71075 m
.38851 .70986 L
s
1 .006 0 r
.12285 .39052 m
.12289 .39055 L
s
.12281 .39055 m
.12285 .39052 L
s
.12285 .39052 m
.12285 .39052 L
s
.12289 .39055 m
.12285 .39058 L
s
.12285 .39052 m
.12289 .39055 L
s
.12285 .39058 m
.12281 .39055 L
s
.12281 .39055 m
.12285 .39052 L
s
.12285 .39052 m
.12285 .39058 L
s
1 .293 0 r
.38722 .71197 m
.38839 .71286 L
s
.973 1 0 r
.46355 .332 m
.45836 .33442 L
s
.46322 .32517 m
.46355 .332 L
s
1 .398 0 r
.49015 .53361 m
.48805 .5362 L
s
.4922 .53489 m
.49015 .53361 L
s
.285 1 0 r
.5642 .61471 m
.56106 .61156 L
s
.56106 .61156 m
.57482 .62235 L
s
1 .075 0 r
.75594 .36114 m
.75583 .36111 L
s
.75578 .36042 m
.75594 .36114 L
s
.75594 .36114 m
.75537 .36085 L
s
.75624 .36068 m
.75594 .36114 L
s
.75526 .35925 m
.75594 .36114 L
s
0 .197 1 r
.60452 .30791 m
.61432 .30376 L
s
.61432 .30376 m
.64347 .3111 L
s
.787 1 0 r
.54505 .6038 m
.54712 .59394 L
s
1 .024 0 r
.35605 .44853 m
.35618 .44865 L
s
.3559 .44863 m
.35605 .44853 L
s
.35605 .44853 m
.35605 .44852 L
s
1 .459 0 r
.43732 .6825 m
.43438 .68345 L
s
.43451 .67878 m
.43732 .6825 L
s
.43732 .6825 m
.43264 .68217 L
s
.43625 .68006 m
.43732 .6825 L
s
.42289 .67556 m
.43732 .6825 L
s
1 .075 0 r
.75578 .36042 m
.75537 .36085 L
s
.75624 .36068 m
.75578 .36042 L
s
1 .024 0 r
.35618 .44865 m
.35604 .44875 L
s
.35605 .44852 m
.35618 .44865 L
s
.35604 .44875 m
.3559 .44863 L
s
.3559 .44863 m
.35605 .44852 L
s
1 .741 0 r
.50969 .71168 m
.51091 .71329 L
s
.51095 .70569 m
.50969 .71168 L
s
.51686 .7104 m
.50969 .71168 L
s
1 .024 0 r
.35605 .44852 m
.35604 .44875 L
s
1 .168 0 r
.31338 .30118 m
.31427 .30221 L
s
.31239 .30166 m
.31338 .30118 L
s
.31338 .30118 m
.31383 .3011 L
s
1 .019 0 r
.81912 .39009 m
.81912 .39008 L
s
.8191 .3899 m
.81912 .39009 L
s
.81912 .39009 m
.819 .39 L
s
.81923 .38997 m
.81912 .39009 L
s
.81906 .38959 m
.81912 .39009 L
s
1 .075 0 r
.75537 .36085 m
.75583 .36111 L
s
1 .019 0 r
.8191 .3899 m
.819 .39 L
s
.81923 .38997 m
.8191 .3899 L
s
1 .398 0 r
.48805 .5362 m
.4901 .53748 L
s
1 .019 0 r
.819 .39 m
.81912 .39008 L
s
.81912 .39008 m
.81923 .38997 L
s
1 .825 0 r
.5631 .65306 m
.55626 .65734 L
s
.55611 .65054 m
.5631 .65306 L
s
1 .075 0 r
.75583 .36111 m
.75624 .36068 L
s
1 .168 0 r
.31427 .30221 m
.31328 .30269 L
s
.31383 .3011 m
.31427 .30221 L
s
.425 1 0 r
.45879 .4367 m
.46681 .44141 L
s
.45048 .44687 m
.45879 .4367 L
s
.45879 .4367 m
.45208 .43707 L
s
1 .199 0 r
.44629 .56524 m
.44544 .56539 L
s
.44548 .56343 m
.44629 .56524 L
s
.44629 .56524 m
.44443 .56473 L
s
.44649 .56409 m
.44629 .56524 L
s
.44213 .56109 m
.44629 .56524 L
s
1 .459 0 r
.43451 .67878 m
.43264 .68217 L
s
.43625 .68006 m
.43451 .67878 L
s
.43264 .68217 m
.43438 .68345 L
s
0 1 .511 r
.48511 .31614 m
.47087 .30198 L
s
.47087 .30198 m
.49098 .29153 L
s
1 .003 0 r
.23152 .56508 m
.23151 .56508 L
s
.23152 .56506 m
.23152 .56508 L
s
.23152 .56508 m
.2315 .56507 L
s
.23153 .56507 m
.23152 .56508 L
s
.23149 .56502 m
.23152 .56508 L
s
.23152 .56506 m
.2315 .56507 L
s
.23153 .56507 m
.23152 .56506 L
s
.2315 .56507 m
.23151 .56508 L
s
.23151 .56508 m
.23153 .56507 L
s
1 .095 0 r
.27831 .71123 m
.27784 .71135 L
s
.27791 .71038 m
.27831 .71123 L
s
.27831 .71123 m
.2774 .711 L
s
.27835 .71073 m
.27831 .71123 L
s
.27613 .70942 m
.27831 .71123 L
s
1 .172 0 r
.69809 .68197 m
.70256 .67886 L
s
1 .001 0 r
.75858 .53578 m
.75859 .53576 L
s
1 .021 0 r
.29197 .41883 m
.29203 .41829 L
s
1 .001 0 r
.75858 .53576 m
.75859 .53577 L
s
.75858 .53576 m
.75858 .53576 L
s
.75858 .53576 m
.75859 .53576 L
s
.75859 .53577 m
.75858 .53577 L
s
.75859 .53576 m
.75859 .53577 L
s
.75858 .53577 m
.75858 .53576 L
s
.75858 .53576 m
.75859 .53576 L
s
.75859 .53576 m
.75858 .53577 L
s
1 .741 0 r
.51217 .70729 m
.51095 .70569 L
s
.51095 .70569 m
.51686 .7104 L
s
1 .293 0 r
.665 .71115 m
.66395 .71198 L
s
.66382 .70898 m
.665 .71115 L
s
.66577 .70963 m
.665 .71115 L
s
.66277 .70981 m
.66382 .70898 L
s
.66382 .70898 m
.66577 .70963 L
s
1 .199 0 r
.44548 .56343 m
.44443 .56473 L
s
.44649 .56409 m
.44548 .56343 L
s
1 .095 0 r
.27791 .71038 m
.2774 .711 L
s
.27835 .71073 m
.27791 .71038 L
s
1 .168 0 r
.31328 .30269 m
.31239 .30166 L
s
.31239 .30166 m
.31383 .3011 L
s
1 .095 0 r
.2774 .711 m
.27784 .71135 L
s
1 .199 0 r
.44443 .56473 m
.44544 .56539 L
s
1 .021 0 r
.29203 .4183 m
.29215 .41841 L
s
.2919 .41839 m
.29203 .4183 L
s
.29203 .4183 m
.29203 .41829 L
s
1 .168 0 r
.31383 .3011 m
.31328 .30269 L
s
1 .021 0 r
.29215 .41841 m
.29202 .4185 L
s
.29203 .41829 m
.29215 .41841 L
s
.29202 .4185 m
.2919 .41839 L
s
.2919 .41839 m
.29203 .41829 L
s
.29203 .41829 m
.29202 .4185 L
s
1 .104 0 r
.76387 .71003 m
.76441 .71072 L
s
.7634 .7104 m
.76387 .71003 L
s
.76387 .71003 m
.76441 .71017 L
s
1 .293 0 r
.38839 .71286 m
.38968 .71075 L
s
1 .095 0 r
.27784 .71135 m
.27835 .71073 L
s
1 .104 0 r
.76441 .71072 m
.76394 .71109 L
s
.76441 .71017 m
.76441 .71072 L
s
1 .398 0 r
.56236 .5352 m
.55944 .53806 L
s
.55831 .53491 m
.56236 .5352 L
s
.55944 .53806 m
.55831 .53491 L
s
1 .323 0 r
.37991 .32794 m
.38158 .33 L
s
.37809 .32883 m
.37991 .32794 L
s
.37991 .32794 m
.38098 .32787 L
s
0 .04 1 r
.4416 .30108 m
.42064 .3264 L
s
.40439 .2893 m
.4416 .30108 L
s
1 .398 0 r
.4901 .53748 m
.4922 .53489 L
s
1 .741 0 r
.51686 .7104 m
.51091 .71329 L
s
.51217 .70729 m
.51686 .7104 L
s
.48712 .70582 m
.51686 .7104 L
s
1 .104 0 r
.76394 .71109 m
.7634 .7104 L
s
.7634 .7104 m
.76441 .71017 L
s
1 .199 0 r
.44544 .56539 m
.44649 .56409 L
s
1 .104 0 r
.76441 .71017 m
.76394 .71109 L
s
1 .323 0 r
.38158 .33 m
.37977 .33089 L
s
.38098 .32787 m
.38158 .33 L
s
1 0 0 r
.16734 .53479 m
.16734 .53479 L
s
.16734 .53479 m
.16734 .53479 L
s
.16734 .53479 m
.16734 .53479 L
s
.16734 .53479 m
.16734 .53479 L
s
.16734 .53478 m
.16734 .53479 L
s
.16734 .53479 m
.16734 .53479 L
s
.16734 .53479 m
.16734 .53479 L
s
.16734 .53479 m
.16734 .53479 L
s
.16734 .53479 m
.16734 .53479 L
s
1 .001 0 r
.92817 .56404 m
.92818 .56402 L
s
1 .039 0 r
.86765 .71032 m
.86843 .70953 L
s
1 .336 0 r
.63421 .65181 m
.64421 .64628 L
s
1 0 0 r
.69473 .50553 m
.69473 .50553 L
s
1 .606 0 r
.4613 .44702 m
.46803 .43216 L
s
.808 1 0 r
.52182 .30074 m
.57155 .29966 L
s
1 .018 0 r
.22786 .3885 m
.22792 .38803 L
s
1 .001 0 r
.92818 .56402 m
.92819 .56402 L
s
.92818 .56402 m
.92818 .56402 L
s
.92818 .56402 m
.92818 .56402 L
s
.92819 .56402 m
.92818 .56403 L
s
.92818 .56402 m
.92819 .56402 L
s
.92818 .56403 m
.92818 .56402 L
s
.92818 .56402 m
.92818 .56402 L
s
.92818 .56402 m
.92818 .56403 L
s
.425 1 0 r
.45848 .45162 m
.45048 .44687 L
s
.45048 .44687 m
.45208 .43707 L
s
.285 1 0 r
.57482 .62235 m
.56125 .6287 L
s
.5642 .61471 m
.57482 .62235 L
s
.50612 .6111 m
.57482 .62235 L
s
1 .525 0 r
.60962 .68085 m
.60827 .68206 L
s
.60814 .67673 m
.60962 .68085 L
s
.61213 .67829 m
.60962 .68085 L
s
1 .018 0 r
.22791 .38804 m
.22802 .38814 L
s
.2278 .38811 m
.22791 .38804 L
s
.22791 .38804 m
.22792 .38803 L
s
.22802 .38814 m
.2279 .38821 L
s
.22792 .38803 m
.22802 .38814 L
s
.2279 .38821 m
.2278 .38811 L
s
.2278 .38811 m
.22792 .38803 L
s
.22792 .38803 m
.2279 .38821 L
s
1 .168 0 r
.73617 .30024 m
.73564 .30019 L
s
.73554 .29867 m
.73617 .30024 L
s
.73617 .30024 m
.73467 .29974 L
s
.73651 .29912 m
.73617 .30024 L
s
.73327 .29618 m
.73617 .30024 L
s
1 .525 0 r
.60679 .67794 m
.60814 .67673 L
s
.60814 .67673 m
.61213 .67829 L
s
1 .021 0 r
.63081 .47575 m
.63082 .47575 L
s
.63081 .47555 m
.63081 .47575 L
s
.63081 .47575 m
.63069 .47565 L
s
.63094 .47565 m
.63081 .47575 L
s
.63082 .47524 m
.63081 .47575 L
s
.63081 .47555 m
.63069 .47565 L
s
.63094 .47565 m
.63081 .47555 L
s
1 .293 0 r
.66395 .71198 m
.66277 .70981 L
s
.66577 .70963 m
.66395 .71198 L
s
.66277 .70981 m
.66577 .70963 L
s
1 .021 0 r
.63069 .47565 m
.63082 .47575 L
s
1 .039 0 r
.86826 .70949 m
.86848 .70974 L
s
.86807 .70965 m
.86826 .70949 L
s
.86826 .70949 m
.86843 .70953 L
s
1 .021 0 r
.63082 .47575 m
.63094 .47565 L
s
1 .825 0 r
.55626 .65734 m
.55611 .65054 L
s
1 .039 0 r
.86848 .70974 m
.8683 .70989 L
s
.86843 .70953 m
.86848 .70974 L
s
0 .434 1 r
.4262 .36857 m
.40837 .35853 L
s
.40837 .35853 m
.41148 .33508 L
s
1 .014 0 r
.33687 .56338 m
.33683 .56339 L
s
.33684 .56325 m
.33687 .56338 L
s
.33687 .56338 m
.33675 .56333 L
s
.33691 .5633 m
.33687 .56338 L
s
.33668 .56306 m
.33687 .56338 L
s
.33684 .56325 m
.33675 .56333 L
s
.33691 .5633 m
.33684 .56325 L
s
.33675 .56333 m
.33683 .56339 L
s
1 .168 0 r
.73554 .29867 m
.73467 .29974 L
s
.73651 .29912 m
.73554 .29867 L
s
1 .014 0 r
.33683 .56339 m
.33691 .5633 L
s
1 .039 0 r
.8683 .70989 m
.86807 .70965 L
s
.86807 .70965 m
.86843 .70953 L
s
.86843 .70953 m
.8683 .70989 L
s
0 1 .331 r
.49677 .32906 m
.48324 .33716 L
s
.48871 .31429 m
.49677 .32906 L
s
1 .168 0 r
.73467 .29974 m
.73564 .30019 L
s
.285 1 0 r
.59918 .4002 m
.60216 .38608 L
s
.808 1 0 r
.57155 .29966 m
.56166 .30527 L
s
.56145 .29519 m
.57155 .29966 L
s
1 .053 0 r
.80384 .68015 m
.80489 .67907 L
s
1 0 0 r
.86439 .53378 m
.8644 .53378 L
s
1 .787 0 r
.57026 .6216 m
.59956 .61297 L
s
1 .162 0 r
.39724 .41669 m
.39889 .41268 L
s
1 .016 0 r
.16367 .35814 m
.16372 .35772 L
s
1 0 0 r
.8644 .53378 m
.8644 .53378 L
s
.86439 .53378 m
.8644 .53378 L
s
.8644 .53378 m
.8644 .53378 L
s
.8644 .53378 m
.8644 .53378 L
s
.8644 .53378 m
.8644 .53378 L
s
.8644 .53378 m
.86439 .53378 L
s
.86439 .53378 m
.8644 .53378 L
s
.8644 .53378 m
.8644 .53378 L
s
1 .323 0 r
.37977 .33089 m
.37809 .32883 L
s
.37809 .32883 m
.38098 .32787 L
s
1 .459 0 r
.43438 .68345 m
.43625 .68006 L
s
1 .038 0 r
.21263 .68001 m
.21247 .68005 L
s
.2125 .67966 m
.21263 .68001 L
s
.21263 .68001 m
.21228 .6799 L
s
.21269 .67981 m
.21263 .68001 L
s
.21193 .67923 m
.21263 .68001 L
s
.2125 .67966 m
.21228 .6799 L
s
.21269 .67981 m
.2125 .67966 L
s
1 .016 0 r
.16372 .35773 m
.1638 .35782 L
s
.16361 .35779 m
.16372 .35773 L
s
.16372 .35773 m
.16372 .35772 L
s
1 .038 0 r
.21228 .6799 m
.21247 .68005 L
s
1 .172 0 r
.70162 .67861 m
.70247 .6798 L
s
.70086 .67918 m
.70162 .67861 L
s
.70162 .67861 m
.70256 .67886 L
s
1 .016 0 r
.1638 .35782 m
.1637 .35788 L
s
.16372 .35772 m
.1638 .35782 L
s
.1637 .35788 m
.16361 .35779 L
s
.16361 .35779 m
.16372 .35772 L
s
1 .323 0 r
.38098 .32787 m
.37977 .33089 L
s
1 .016 0 r
.16372 .35772 m
.1637 .35788 L
s
1 .038 0 r
.21247 .68005 m
.21269 .67981 L
s
1 .172 0 r
.70247 .6798 m
.70171 .68036 L
s
.70256 .67886 m
.70247 .6798 L
s
1 .168 0 r
.73564 .30019 m
.73651 .29912 L
s
1 .121 0 r
.32001 .67976 m
.31943 .6799 L
s
.31951 .67867 m
.32001 .67976 L
s
.32001 .67976 m
.31886 .67947 L
s
.32008 .6791 m
.32001 .67976 L
s
.31728 .6774 m
.32001 .67976 L
s
1 .021 0 r
.86122 .35759 m
.86122 .35757 L
s
.86119 .35738 m
.86122 .35759 L
s
.86122 .35759 m
.86108 .35749 L
s
.86133 .35746 m
.86122 .35759 L
s
.86113 .35704 m
.86122 .35759 L
s
.86119 .35738 m
.86108 .35749 L
s
.86133 .35746 m
.86119 .35738 L
s
1 .063 0 r
.79787 .32825 m
.79777 .32821 L
s
.79771 .32764 m
.79787 .32825 L
s
.79787 .32825 m
.79737 .32801 L
s
.79811 .32785 m
.79787 .32825 L
s
.79724 .32663 m
.79787 .32825 L
s
1 .021 0 r
.86108 .35749 m
.86122 .35757 L
s
.86122 .35757 m
.86133 .35746 L
s
1 .121 0 r
.31951 .67867 m
.31886 .67947 L
s
.32008 .6791 m
.31951 .67867 L
s
1 .063 0 r
.79771 .32764 m
.79737 .32801 L
s
.79811 .32785 m
.79771 .32764 L
s
1 .121 0 r
.31886 .67947 m
.31943 .6799 L
s
1 .063 0 r
.79737 .32801 m
.79777 .32821 L
s
1 .053 0 r
.80466 .67901 m
.80496 .67935 L
s
.8044 .67922 m
.80466 .67901 L
s
.80466 .67901 m
.80489 .67907 L
s
.80496 .67935 m
.80471 .67955 L
s
.80489 .67907 m
.80496 .67935 L
s
1 .063 0 r
.79777 .32821 m
.79811 .32785 L
s
1 .825 0 r
.48726 .65609 m
.49008 .64976 L
s
.60845 .36319 m
.61128 .35682 L
s
1 .001 0 r
.27252 .5328 m
.27252 .5328 L
s
.27252 .53279 m
.27252 .5328 L
s
.27252 .5328 m
.27252 .53279 L
s
.27253 .53279 m
.27252 .5328 L
s
.27252 .53278 m
.27252 .5328 L
s
.27252 .53279 m
.27252 .53279 L
s
.27253 .53279 m
.27252 .53279 L
s
.27252 .53279 m
.27252 .5328 L
s
.27252 .5328 m
.27253 .53279 L
s
1 .017 0 r
.97366 .70852 m
.97396 .70818 L
s
1 .08 0 r
.73995 .64994 m
.74156 .64831 L
s
1 0 0 r
.80054 .50349 m
.80054 .50349 L
s
1 .081 0 r
.33311 .38633 m
.33387 .38428 L
s
1 .014 0 r
.0994 .32775 m
.09944 .32737 L
s
1 .053 0 r
.80471 .67955 m
.8044 .67922 L
s
.8044 .67922 m
.80489 .67907 L
s
0 .813 1 r
.433 .36271 m
.44913 .37172 L
s
.4161 .38321 m
.433 .36271 L
s
.433 .36271 m
.41897 .36251 L
s
1 .172 0 r
.70171 .68036 m
.70086 .67918 L
s
.70086 .67918 m
.70256 .67886 L
s
1 .053 0 r
.80489 .67907 m
.80471 .67955 L
s
1 .121 0 r
.31943 .6799 m
.32008 .6791 L
s
1 .172 0 r
.70256 .67886 m
.70171 .68036 L
s
1 .014 0 r
.09944 .32738 m
.09952 .32746 L
s
.09934 .32743 m
.09944 .32738 L
s
.09944 .32738 m
.09944 .32737 L
s
.09952 .32746 m
.09942 .32751 L
s
.09944 .32737 m
.09952 .32746 L
s
.973 1 0 r
.45836 .33442 m
.45336 .32745 L
s
.45336 .32745 m
.46322 .32517 L
s
1 .017 0 r
.97389 .70816 m
.97399 .70826 L
s
.97381 .70823 m
.97389 .70816 L
s
.97389 .70816 m
.97396 .70818 L
s
1 .014 0 r
.09942 .32751 m
.09934 .32743 L
s
.09934 .32743 m
.09944 .32737 L
s
1 .017 0 r
.97399 .70826 m
.97391 .70833 L
s
.97396 .70818 m
.97399 .70826 L
s
1 .014 0 r
.09944 .32737 m
.09942 .32751 L
s
1 .017 0 r
.97391 .70833 m
.97381 .70823 L
s
.97381 .70823 m
.97396 .70818 L
s
.97396 .70818 m
.97391 .70833 L
s
1 .253 0 r
.65501 .38565 m
.65413 .38566 L
s
.65404 .3833 m
.65501 .38565 L
s
.65501 .38565 m
.65272 .38493 L
s
.65545 .38403 m
.65501 .38565 L
s
.65037 .37978 m
.65501 .38565 L
s
0 1 .511 r
.49098 .29153 m
.48511 .31614 L
s
1 .481 0 r
.45171 .59059 m
.44965 .591 L
s
.44976 .58623 m
.45171 .59059 L
s
.45171 .59059 m
.44722 .58938 L
s
.4522 .58785 m
.45171 .59059 L
s
.44163 .58065 m
.45171 .59059 L
s
1 .741 0 r
.51091 .71329 m
.51217 .70729 L
s
.973 1 0 r
.46322 .32517 m
.45836 .33442 L
s
1 .001 0 r
.73661 .4732 m
.73661 .4732 L
s
.73661 .47318 m
.73661 .4732 L
s
.73661 .4732 m
.7366 .47319 L
s
.73662 .47319 m
.73661 .4732 L
s
.73661 .47316 m
.73661 .4732 L
s
.73661 .47318 m
.7366 .47319 L
s
.73662 .47319 m
.73661 .47318 L
s
.7366 .47319 m
.73661 .4732 L
s
.73661 .4732 m
.73662 .47319 L
s
1 .019 0 r
.90983 .67832 m
.91017 .67791 L
s
1 .141 0 r
.67598 .6197 m
.67901 .61684 L
s
0 1 .566 r
.50276 .41455 m
.59832 .38238 L
s
1 0 0 r
.20828 .50247 m
.20828 .50247 L
s
1 .052 0 r
.2689 .35593 m
.26934 .3546 L
s
1 .525 0 r
.61213 .67829 m
.60827 .68206 L
s
.60679 .67794 m
.61213 .67829 L
s
1 .253 0 r
.65404 .3833 m
.65272 .38493 L
s
.65545 .38403 m
.65404 .3833 L
s
0 1 .566 r
.44284 .39549 m
.45587 .40294 L
s
.42924 .41204 m
.44284 .39549 L
s
.44284 .39549 m
.43167 .39567 L
s
1 .039 0 r
.6728 .44377 m
.67277 .44376 L
s
.67276 .44339 m
.6728 .44377 L
s
.6728 .44377 m
.67253 .4436 L
s
.67299 .44355 m
.6728 .44377 L
s
.6726 .4428 m
.6728 .44377 L
s
1 .525 0 r
.60827 .68206 m
.60679 .67794 L
s
1 .039 0 r
.67276 .44339 m
.67253 .4436 L
s
.67299 .44355 m
.67276 .44339 L
s
0 1 .077 r
.48097 .34036 m
.49279 .35218 L
s
.46884 .34764 m
.48097 .34036 L
s
.48097 .34036 m
.48556 .33915 L
s
1 .08 0 r
.74121 .64824 m
.74165 .64875 L
s
.74082 .64853 m
.74121 .64824 L
s
.74121 .64824 m
.74156 .64831 L
s
0 .04 1 r
.40439 .2893 m
.42064 .3264 L
s
1 .039 0 r
.67253 .4436 m
.67277 .44376 L
s
1 .08 0 r
.74165 .64875 m
.74126 .64904 L
s
.74156 .64831 m
.74165 .64875 L
s
1 .253 0 r
.65272 .38493 m
.65413 .38566 L
s
1 .039 0 r
.67277 .44376 m
.67299 .44355 L
s
1 .081 0 r
.33374 .38431 m
.33419 .38478 L
s
.33324 .3846 m
.33374 .38431 L
s
.33374 .38431 m
.33387 .38428 L
s
1 .019 0 r
.91009 .67789 m
.91021 .67801 L
s
.90999 .67797 m
.91009 .67789 L
s
.91009 .67789 m
.91017 .67791 L
s
.91021 .67801 m
.91011 .67809 L
s
.91017 .67791 m
.91021 .67801 L
s
.91011 .67809 m
.90999 .67797 L
s
.90999 .67797 m
.91017 .67791 L
s
.91017 .67791 m
.91011 .67809 L
s
1 .081 0 r
.33419 .38478 m
.33369 .38507 L
s
.33387 .38428 m
.33419 .38478 L
s
1 .166 0 r
.36223 .64856 m
.36147 .64874 L
s
.36155 .64706 m
.36223 .64856 L
s
.36223 .64856 m
.36066 .64816 L
s
.36235 .64765 m
.36223 .64856 L
s
.35859 .64527 m
.36223 .64856 L
s
1 .08 0 r
.74126 .64904 m
.74082 .64853 L
s
.74082 .64853 m
.74156 .64831 L
s
1 .398 0 r
.5748 .4726 m
.57329 .47275 L
s
.57323 .46893 m
.5748 .4726 L
s
.5748 .4726 m
.57115 .47152 L
s
.57537 .47016 m
.5748 .4726 L
s
.56707 .46378 m
.5748 .4726 L
s
1 .081 0 r
.33369 .38507 m
.33324 .3846 L
s
.33324 .3846 m
.33387 .38428 L
s
1 .162 0 r
.39859 .41272 m
.3995 .41365 L
s
.39762 .41331 m
.39859 .41272 L
s
.39859 .41272 m
.39889 .41268 L
s
1 .08 0 r
.74156 .64831 m
.74126 .64904 L
s
1 .481 0 r
.44976 .58623 m
.44722 .58938 L
s
.4522 .58785 m
.44976 .58623 L
s
1 .081 0 r
.33387 .38428 m
.33369 .38507 L
s
0 1 .077 r
.56926 .64834 m
.57314 .65244 L
s
.57284 .63144 m
.56926 .64834 L
s
.5896 .64459 m
.56926 .64834 L
s
.542 1 0 r
.53381 .29646 m
.52309 .30688 L
s
.51894 .29524 m
.53381 .29646 L
s
.808 1 0 r
.56166 .30527 m
.56145 .29519 L
s
1 .166 0 r
.36155 .64706 m
.36066 .64816 L
s
.36235 .64765 m
.36155 .64706 L
s
1 .052 0 r
.26927 .35463 m
.26956 .35492 L
s
.26895 .35481 m
.26927 .35463 L
s
.26927 .35463 m
.26934 .3546 L
s
1 .162 0 r
.3995 .41365 m
.39853 .41424 L
s
.39889 .41268 m
.3995 .41365 L
s
1 .005 0 r
.378 .5309 m
.37799 .5309 L
s
.37799 .53085 m
.378 .5309 L
s
.378 .5309 m
.37796 .53088 L
s
.37802 .53088 m
.378 .5309 L
s
.37795 .53078 m
.378 .5309 L
s
.37799 .53085 m
.37796 .53088 L
s
.37802 .53088 m
.37799 .53085 L
s
1 .336 0 r
.64215 .6457 m
.64362 .64813 L
s
.64079 .64665 m
.64215 .6457 L
s
.64215 .6457 m
.64421 .64628 L
s
1 .005 0 r
.37796 .53088 m
.37799 .5309 L
s
.37799 .5309 m
.37802 .53088 L
s
1 .052 0 r
.26956 .35492 m
.26923 .35511 L
s
.26934 .3546 m
.26956 .35492 L
s
1 .166 0 r
.36066 .64816 m
.36147 .64874 L
s
1 .336 0 r
.64362 .64813 m
.64226 .64909 L
s
.64421 .64628 m
.64362 .64813 L
s
1 .023 0 r
.84593 .64808 m
.84631 .64757 L
s
1 0 0 r
.90659 .50145 m
.90659 .50145 L
s
1 .344 0 r
.61194 .58943 m
.62058 .5828 L
s
1 .59 0 r
.43861 .38415 m
.45226 .37134 L
s
1 0 0 r
.14396 .47213 m
.14396 .47212 L
s
1 .038 0 r
.20462 .3255 m
.20491 .32452 L
s
1 0 0 r
.14396 .47212 m
.14396 .47212 L
s
.14396 .47212 m
.14396 .47212 L
s
.14396 .47212 m
.14396 .47212 L
s
.14396 .47212 m
.14396 .47212 L
s
.14396 .47212 m
.14396 .47212 L
s
.14396 .47212 m
.14396 .47212 L
s
.14396 .47212 m
.14396 .47212 L
s
.14396 .47212 m
.14396 .47212 L
s
1 .052 0 r
.26923 .35511 m
.26895 .35481 L
s
.26895 .35481 m
.26934 .3546 L
s
1 .481 0 r
.44722 .58938 m
.44965 .591 L
s
.542 1 0 r
.52309 .30688 m
.51894 .29524 L
s
1 .04 0 r
.25369 .648 m
.25353 .64803 L
s
.25357 .64762 m
.25369 .648 L
s
.25369 .648 m
.25333 .64787 L
s
.25377 .64778 m
.25369 .648 L
s
.25299 .64714 m
.25369 .648 L
s
1 .052 0 r
.26934 .3546 m
.26923 .35511 L
s
1 .253 0 r
.65413 .38566 m
.65545 .38403 L
s
1 .162 0 r
.39853 .41424 m
.39762 .41331 L
s
.39762 .41331 m
.39889 .41268 L
s
1 .04 0 r
.25357 .64762 m
.25333 .64787 L
s
.25377 .64778 m
.25357 .64762 L
s
.25333 .64787 m
.25353 .64803 L
s
1 .398 0 r
.57323 .46893 m
.57115 .47152 L
s
.57537 .47016 m
.57323 .46893 L
s
1 .04 0 r
.25353 .64803 m
.25377 .64778 L
s
1 .023 0 r
.84622 .64755 m
.84636 .64769 L
s
.8461 .64765 m
.84622 .64755 L
s
.84622 .64755 m
.84631 .64757 L
s
1 .162 0 r
.39889 .41268 m
.39853 .41424 L
s
1 .023 0 r
.84636 .64769 m
.84624 .64779 L
s
.84631 .64757 m
.84636 .64769 L
s
1 .459 0 r
.64158 .32502 m
.63896 .32541 L
s
.6388 .32122 m
.64158 .32502 L
s
.64158 .32502 m
.63693 .32462 L
s
.64084 .32201 m
.64158 .32502 L
s
.62802 .31646 m
.64158 .32502 L
s
1 .023 0 r
.84624 .64779 m
.8461 .64765 L
s
.8461 .64765 m
.84631 .64757 L
s
1 .166 0 r
.36147 .64874 m
.36235 .64765 L
s
1 .023 0 r
.84631 .64757 m
.84624 .64779 L
s
1 .398 0 r
.57115 .47152 m
.57329 .47275 L
s
1 .038 0 r
.20487 .32455 m
.20507 .32476 L
s
.20463 .32468 m
.20487 .32455 L
s
.20487 .32455 m
.20491 .32452 L
s
1 .253 0 r
.40548 .61816 m
.40435 .6184 L
s
.40444 .61586 m
.40548 .61816 L
s
.40548 .61816 m
.4031 .61753 L
s
.4057 .61673 m
.40548 .61816 L
s
.40004 .61302 m
.40548 .61816 L
s
1 .575 0 r
.4292 .29117 m
.43171 .29532 L
s
.42653 .29221 m
.4292 .29117 L
s
.4292 .29117 m
.4323 .29144 L
s
1 .038 0 r
.20507 .32476 m
.20483 .32489 L
s
.20491 .32452 m
.20507 .32476 L
s
.20483 .32489 m
.20463 .32468 L
s
.20463 .32468 m
.20491 .32452 L
s
.973 1 0 r
.48922 .67672 m
.49263 .6793 L
s
.49273 .66883 m
.48922 .67672 L
s
.49977 .67667 m
.48922 .67672 L
s
1 .575 0 r
.43171 .29532 m
.42904 .29637 L
s
.4323 .29144 m
.43171 .29532 L
s
1 .055 0 r
.83994 .29531 m
.83985 .29528 L
s
.8398 .29478 m
.83994 .29531 L
s
.83994 .29531 m
.8395 .2951 L
s
.84014 .29495 m
.83994 .29531 L
s
.83937 .29389 m
.83994 .29531 L
s
1 .459 0 r
.6388 .32122 m
.63693 .32462 L
s
.64084 .32201 m
.6388 .32122 L
s
.63693 .32462 m
.63896 .32541 L
s
1 .038 0 r
.20491 .32452 m
.20483 .32489 L
s
.973 1 0 r
.49977 .67667 m
.49263 .6793 L
s
.49273 .66883 m
.49977 .67667 L
s
.49616 .67138 m
.49977 .67667 L
s
.46407 .66352 m
.49977 .67667 L
s
0 .813 1 r
.43212 .3924 m
.4161 .38321 L
s
.4161 .38321 m
.41897 .36251 L
s
1 .055 0 r
.8398 .29478 m
.8395 .2951 L
s
.84014 .29495 m
.8398 .29478 L
s
.717 1 0 r
.5216 .32448 m
.51791 .32596 L
s
.51794 .31424 m
.5216 .32448 L
s
.52739 .31675 m
.5216 .32448 L
s
1 .055 0 r
.8395 .2951 m
.83985 .29528 L
s
1 .825 0 r
.4544 .34765 m
.45842 .35326 L
s
.45019 .34963 m
.4544 .34765 L
s
.4544 .34765 m
.45814 .34782 L
s
0 .434 1 r
.61781 .35375 m
.60864 .35825 L
s
.60775 .3253 m
.61781 .35375 L
s
.63513 .33244 m
.61781 .35375 L
s
1 0 0 r
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
1 .029 0 r
.78195 .6178 m
.7824 .61715 L
s
.425 1 0 r
.54782 .55911 m
.60663 .54104 L
s
1 0 0 r
.31369 .50043 m
.31369 .50043 L
s
1 .229 0 r
.37439 .35372 m
.37844 .34829 L
s
1 .029 0 r
.14026 .29503 m
.14046 .29426 L
s
.973 1 0 r
.49616 .67138 m
.49273 .66883 L
s
1 .141 0 r
.67837 .61671 m
.67913 .61763 L
s
.67768 .61719 m
.67837 .61671 L
s
.67837 .61671 m
.67901 .61684 L
s
1 .253 0 r
.40444 .61586 m
.4031 .61753 L
s
.4057 .61673 m
.40444 .61586 L
s
1 .055 0 r
.83985 .29528 m
.84014 .29495 L
s
.973 1 0 r
.5633 .67638 m
.56323 .67836 L
s
.56312 .6679 m
.5633 .67638 L
s
.57179 .67297 m
.5633 .67638 L
s
1 .141 0 r
.67913 .61763 m
.67843 .61812 L
s
.67901 .61684 m
.67913 .61763 L
s
1 .253 0 r
.4031 .61753 m
.40435 .6184 L
s
0 .04 1 r
.54683 .7318 m
.5676 .70555 L
s
.425 1 0 r
.46681 .44141 m
.45848 .45162 L
s
.45208 .43707 m
.46681 .44141 L
s
.787 1 0 r
.58122 .41206 m
.58354 .41345 L
s
.58332 .40205 m
.58122 .41206 L
s
.59312 .40954 m
.58122 .41206 L
s
0 1 .077 r
.57675 .63541 m
.57284 .63144 L
s
.57284 .63144 m
.5896 .64459 L
s
0 1 .566 r
.44221 .41961 m
.42924 .41204 L
s
.42924 .41204 m
.43167 .39567 L
s
1 .825 0 r
.45842 .35326 m
.45422 .35526 L
s
.45814 .34782 m
.45842 .35326 L
s
0 1 .331 r
.48324 .33716 m
.46997 .32391 L
s
.46997 .32391 m
.48871 .31429 L
s
1 .029 0 r
.14044 .29429 m
.14059 .29445 L
s
.14025 .29438 m
.14044 .29429 L
s
.14044 .29429 m
.14046 .29426 L
s
.7823 .61714 m
.78247 .61731 L
s
.78215 .61726 m
.7823 .61714 L
s
.7823 .61714 m
.7824 .61715 L
s
.14059 .29445 m
.1404 .29455 L
s
.14046 .29426 m
.14059 .29445 L
s
.78247 .61731 m
.78232 .61743 L
s
.7824 .61715 m
.78247 .61731 L
s
1 .336 0 r
.64226 .64909 m
.64079 .64665 L
s
.64079 .64665 m
.64421 .64628 L
s
.717 1 0 r
.51424 .31568 m
.51794 .31424 L
s
.51794 .31424 m
.52739 .31675 L
s
1 .029 0 r
.1404 .29455 m
.14025 .29438 L
s
.14025 .29438 m
.14046 .29426 L
s
.78232 .61743 m
.78215 .61726 L
s
.78215 .61726 m
.7824 .61715 L
s
1 .336 0 r
.64421 .64628 m
.64226 .64909 L
s
1 .029 0 r
.14046 .29426 m
.1404 .29455 L
s
.7824 .61715 m
.78232 .61743 L
s
1 .481 0 r
.44965 .591 m
.4522 .58785 L
s
1 .141 0 r
.67843 .61812 m
.67768 .61719 L
s
.67768 .61719 m
.67901 .61684 L
s
1 .011 0 r
.18878 .6171 m
.18874 .61711 L
s
.18876 .61699 m
.18878 .6171 L
s
.18878 .6171 m
.18869 .61706 L
s
.18882 .61704 m
.18878 .6171 L
s
.18863 .61684 m
.18878 .6171 L
s
.18876 .61699 m
.18869 .61706 L
s
.18882 .61704 m
.18876 .61699 L
s
1 .141 0 r
.67901 .61684 m
.67843 .61812 L
s
1 .011 0 r
.18869 .61706 m
.18874 .61711 L
s
.18874 .61711 m
.18882 .61704 L
s
1 .787 0 r
.59582 .61699 m
.59375 .61865 L
s
.59359 .61077 m
.59582 .61699 L
s
.59956 .61297 m
.59582 .61699 L
s
1 .005 0 r
.77864 .44081 m
.77864 .44081 L
s
.77863 .44076 m
.77864 .44081 L
s
.77864 .44081 m
.77861 .44079 L
s
.77867 .44079 m
.77864 .44081 L
s
.77863 .44069 m
.77864 .44081 L
s
.77863 .44076 m
.77861 .44079 L
s
.77867 .44079 m
.77863 .44076 L
s
1 .398 0 r
.57329 .47275 m
.57537 .47016 L
s
1 .005 0 r
.77861 .44079 m
.77864 .44081 L
s
.77864 .44081 m
.77867 .44079 L
s
1 .043 0 r
.71487 .41134 m
.71482 .41132 L
s
.71479 .41092 m
.71487 .41134 L
s
.71487 .41134 m
.71455 .41116 L
s
.71506 .41108 m
.71487 .41134 L
s
.71454 .41025 m
.71487 .41134 L
s
1 .009 0 r
.95216 .6462 m
.95229 .64601 L
s
1 .039 0 r
.7179 .58748 m
.71846 .58661 L
s
1 0 0 r
.24936 .47005 m
.24936 .47003 L
s
1 .121 0 r
.3101 .32325 m
.31188 .32024 L
s
1 0 0 r
.24936 .47003 m
.24936 .47004 L
s
.24936 .47004 m
.24936 .47003 L
s
.24936 .47003 m
.24936 .47003 L
s
.24936 .47004 m
.24936 .47004 L
s
.24936 .47003 m
.24936 .47004 L
s
.24936 .47004 m
.24936 .47004 L
s
.24936 .47004 m
.24936 .47003 L
s
.24936 .47003 m
.24936 .47004 L
s
.973 1 0 r
.56305 .66985 m
.56312 .6679 L
s
.56312 .6679 m
.57179 .67297 L
s
1 .043 0 r
.71479 .41092 m
.71455 .41116 L
s
.71506 .41108 m
.71479 .41092 L
s
1 .253 0 r
.40435 .6184 m
.4057 .61673 L
s
1 .009 0 r
.95226 .64601 m
.95231 .64606 L
s
.95222 .64604 m
.95226 .64601 L
s
.95226 .64601 m
.95229 .64601 L
s
1 .043 0 r
.71455 .41116 m
.71482 .41132 L
s
1 .009 0 r
.95231 .64606 m
.95227 .64609 L
s
.95229 .64601 m
.95231 .64606 L
s
.95227 .64609 m
.95222 .64604 L
s
.95222 .64604 m
.95229 .64601 L
s
.95229 .64601 m
.95227 .64609 L
s
1 .043 0 r
.71482 .41132 m
.71506 .41108 L
s
1 .787 0 r
.59152 .61242 m
.59359 .61077 L
s
.59359 .61077 m
.59956 .61297 L
s
.787 1 0 r
.58565 .4034 m
.58332 .40205 L
s
.58332 .40205 m
.59312 .40954 L
s
1 .787 0 r
.45767 .61656 m
.45431 .61732 L
s
.45447 .60943 m
.45767 .61656 L
s
.45767 .61656 m
.4503 .6146 L
s
.45849 .61213 m
.45767 .61656 L
s
.44113 .60046 m
.45767 .61656 L
s
0 1 .077 r
.49279 .35218 m
.48069 .35952 L
s
.48556 .33915 m
.49279 .35218 L
s
1 .741 0 r
.586 .29334 m
.58742 .29389 L
s
.58728 .28718 m
.586 .29334 L
s
.59326 .2917 m
.586 .29334 L
s
1 .575 0 r
.44045 .70446 m
.43676 .70571 L
s
.43691 .69979 m
.44045 .70446 L
s
.44045 .70446 m
.43456 .70406 L
s
.43912 .70144 m
.44045 .70446 L
s
.42228 .69585 m
.44045 .70446 L
s
1 .039 0 r
.71834 .58659 m
.71857 .58682 L
s
.71813 .58675 m
.71834 .58659 L
s
.71834 .58659 m
.71846 .58661 L
s
.71857 .58682 m
.71836 .58698 L
s
.71846 .58661 m
.71857 .58682 L
s
.425 1 0 r
.45208 .43707 m
.45848 .45162 L
s
1 .039 0 r
.71836 .58698 m
.71813 .58675 L
s
.71813 .58675 m
.71846 .58661 L
s
0 .434 1 r
.59845 .32947 m
.60775 .3253 L
s
.60775 .3253 m
.63513 .33244 L
s
0 .197 1 r
.44292 .32236 m
.42271 .34683 L
s
.40705 .31112 m
.44292 .32236 L
s
1 .039 0 r
.71846 .58661 m
.71836 .58698 L
s
.285 1 0 r
.56125 .6287 m
.5642 .61471 L
s
1 .575 0 r
.43691 .69979 m
.43456 .70406 L
s
.43912 .70144 m
.43691 .69979 L
s
.43456 .70406 m
.43676 .70571 L
s
1 .009 0 r
.88817 .61589 m
.88829 .61569 L
s
1 .65 0 r
.59299 .70402 m
.61734 .69724 L
s
1 .058 0 r
.65377 .55714 m
.65456 .5558 L
s
1 0 0 r
.41936 .49838 m
.41936 .49838 L
s
.939 1 0 r
.48013 .3515 m
.51915 .33785 L
s
1 .002 0 r
.18495 .43963 m
.18495 .43959 L
s
1 .077 0 r
.24573 .29274 m
.24669 .29078 L
s
1 .043 0 r
.29486 .61587 m
.29472 .6159 L
s
.29475 .61547 m
.29486 .61587 L
s
.29486 .61587 m
.2945 .61572 L
s
.29497 .61564 m
.29486 .61587 L
s
.29421 .61493 m
.29486 .61587 L
s
1 .002 0 r
.18495 .43959 m
.18496 .4396 L
s
.18494 .43959 m
.18495 .43959 L
s
.18495 .43959 m
.18495 .43959 L
s
.18496 .4396 m
.18495 .4396 L
s
.18495 .43959 m
.18496 .4396 L
s
.18495 .4396 m
.18494 .43959 L
s
.18494 .43959 m
.18495 .43959 L
s
.18495 .43959 m
.18495 .4396 L
s
1 .741 0 r
.58871 .28771 m
.58728 .28718 L
s
.58728 .28718 m
.59326 .2917 L
s
1 .459 0 r
.63896 .32541 m
.64084 .32201 L
s
1 .043 0 r
.29475 .61547 m
.2945 .61572 L
s
.29497 .61564 m
.29475 .61547 L
s
.973 1 0 r
.5564 .32199 m
.55631 .32269 L
s
.55621 .3133 m
.5564 .32199 L
s
.56488 .3178 m
.5564 .32199 L
s
1 .009 0 r
.88826 .61569 m
.88831 .61574 L
s
.88821 .61573 m
.88826 .61569 L
s
.88826 .61569 m
.88829 .61569 L
s
.88831 .61574 m
.88827 .61578 L
s
.88829 .61569 m
.88831 .61574 L
s
.88827 .61578 m
.88821 .61573 L
s
.88821 .61573 m
.88829 .61569 L
s
1 .043 0 r
.2945 .61572 m
.29472 .6159 L
s
1 .009 0 r
.88829 .61569 m
.88827 .61578 L
s
1 .043 0 r
.29472 .6159 m
.29497 .61564 L
s
.285 1 0 r
.47739 .36773 m
.48717 .37755 L
s
.46735 .37384 m
.47739 .36773 L
s
.47739 .36773 m
.48117 .36692 L
s
1 .575 0 r
.42904 .29637 m
.42653 .29221 L
s
.42653 .29221 m
.4323 .29144 L
s
1 .166 0 r
.69532 .35096 m
.69477 .35094 L
s
.69469 .34941 m
.69532 .35096 L
s
.69532 .35096 m
.69383 .35048 L
s
.69563 .34987 m
.69532 .35096 L
s
.69236 .34704 m
.69532 .35096 L
s
1 .575 0 r
.4323 .29144 m
.42904 .29637 L
s
1 .787 0 r
.45447 .60943 m
.4503 .6146 L
s
.45849 .61213 m
.45447 .60943 L
s
.787 1 0 r
.59312 .40954 m
.58354 .41345 L
s
.58565 .4034 m
.59312 .40954 L
s
.54448 .4005 m
.59312 .40954 L
s
0 1 .077 r
.5896 .64459 m
.57314 .65244 L
s
.57675 .63541 m
.5896 .64459 L
s
.50601 .63107 m
.5896 .64459 L
s
1 .166 0 r
.69469 .34941 m
.69383 .35048 L
s
.69563 .34987 m
.69469 .34941 L
s
1 .121 0 r
.31156 .32029 m
.31221 .32104 L
s
.31084 .32065 m
.31156 .32029 L
s
.31156 .32029 m
.31188 .32024 L
s
1 .741 0 r
.59326 .2917 m
.58742 .29389 L
s
.58871 .28771 m
.59326 .2917 L
s
.56361 .28584 m
.59326 .2917 L
s
1 .166 0 r
.69383 .35048 m
.69477 .35094 L
s
1 .058 0 r
.65439 .55578 m
.65473 .55612 L
s
.65407 .55601 m
.65439 .55578 L
s
.65439 .55578 m
.65456 .5558 L
s
1 .121 0 r
.31221 .32104 m
.31149 .3214 L
s
.31188 .32024 m
.31221 .32104 L
s
1 .001 0 r
.88491 .4386 m
.88491 .4386 L
s
.88491 .43859 m
.88491 .4386 L
s
.88491 .4386 m
.8849 .43859 L
s
.88492 .43859 m
.88491 .4386 L
s
.88491 .43857 m
.88491 .4386 L
s
.88491 .43859 m
.8849 .43859 L
s
.88492 .43859 m
.88491 .43859 L
s
.8849 .43859 m
.88491 .4386 L
s
.88491 .4386 m
.88492 .43859 L
s
1 .008 0 r
.8241 .58554 m
.8242 .58535 L
s
.973 1 0 r
.52875 .67372 m
.57179 .67297 L
s
1 .117 0 r
.58956 .52675 m
.59106 .52402 L
s
1 .003 0 r
.35501 .46796 m
.35502 .46788 L
s
1 .459 0 r
.41582 .32099 m
.42852 .3118 L
s
1 .003 0 r
.12047 .40917 m
.12047 .4091 L
s
1 .058 0 r
.65473 .55612 m
.65442 .55635 L
s
.65456 .5558 m
.65473 .55612 L
s
1 .003 0 r
.12047 .40911 m
.12048 .40912 L
s
.12045 .40912 m
.12047 .40911 L
s
.12047 .40911 m
.12047 .4091 L
s
.12048 .40912 m
.12047 .40913 L
s
.12047 .4091 m
.12048 .40912 L
s
.12047 .40913 m
.12045 .40912 L
s
.12045 .40912 m
.12047 .4091 L
s
.35502 .46788 m
.35504 .4679 L
s
.355 .4679 m
.35502 .46788 L
s
.35502 .46788 m
.35502 .46788 L
s
.973 1 0 r
.55612 .31397 m
.55621 .3133 L
s
.55621 .3133 m
.56488 .3178 L
s
1 .003 0 r
.12047 .4091 m
.12047 .40913 L
s
.35504 .4679 m
.35502 .46791 L
s
.35502 .46788 m
.35504 .4679 L
s
.35502 .46791 m
.355 .4679 L
s
.355 .4679 m
.35502 .46788 L
s
.35502 .46788 m
.35502 .46791 L
s
1 .008 0 r
.82418 .58535 m
.82423 .58539 L
s
.82413 .58538 m
.82418 .58535 L
s
.82418 .58535 m
.8242 .58535 L
s
1 .058 0 r
.65442 .55635 m
.65407 .55601 L
s
.65407 .55601 m
.65456 .5558 L
s
1 .008 0 r
.82423 .58539 m
.82418 .58543 L
s
.8242 .58535 m
.82423 .58539 L
s
.82418 .58543 m
.82413 .58538 L
s
.82413 .58538 m
.8242 .58535 L
s
1 .077 0 r
.24653 .29083 m
.24694 .29129 L
s
.24606 .29106 m
.24653 .29083 L
s
.24653 .29083 m
.24669 .29078 L
s
1 .008 0 r
.8242 .58535 m
.82418 .58543 L
s
1 .058 0 r
.65456 .5558 m
.65442 .55635 L
s
1 .077 0 r
.24694 .29129 m
.24647 .29152 L
s
.24669 .29078 m
.24694 .29129 L
s
1 .121 0 r
.31149 .3214 m
.31084 .32065 L
s
.31084 .32065 m
.31188 .32024 L
s
1 .229 0 r
.37768 .34833 m
.37887 .34979 L
s
.37639 .34897 m
.37768 .34833 L
s
.37768 .34833 m
.37844 .34829 L
s
1 .787 0 r
.4503 .6146 m
.45431 .61732 L
s
1 .121 0 r
.31188 .32024 m
.31149 .3214 L
s
1 .166 0 r
.69477 .35094 m
.69563 .34987 L
s
1 .077 0 r
.24647 .29152 m
.24606 .29106 L
s
.24606 .29106 m
.24669 .29078 L
s
0 .04 1 r
.64867 .29102 m
.61952 .3194 L
s
.60832 .28768 m
.64867 .29102 L
s
1 .229 0 r
.37887 .34979 m
.37758 .35044 L
s
.37844 .34829 m
.37887 .34979 L
s
1 .077 0 r
.24669 .29078 m
.24647 .29152 L
s
1 .344 0 r
.6188 .58242 m
.6205 .58479 L
s
.61719 .58347 m
.6188 .58242 L
s
.6188 .58242 m
.62058 .5828 L
s
1 .825 0 r
.45422 .35526 m
.45019 .34963 L
s
.45019 .34963 m
.45814 .34782 L
s
1 .344 0 r
.6205 .58479 m
.6189 .58584 L
s
.62058 .5828 m
.6205 .58479 L
s
1 .009 0 r
.82083 .40832 m
.82083 .40831 L
s
.82082 .40823 m
.82083 .40832 L
s
.82083 .40832 m
.82077 .40828 L
s
.82088 .40827 m
.82083 .40832 L
s
.8208 .40809 m
.82083 .40832 L
s
.22985 .58476 m
.22982 .58477 L
s
.22983 .58468 m
.22985 .58476 L
s
.22985 .58476 m
.22978 .58473 L
s
.22988 .58472 m
.22985 .58476 L
s
.22975 .58456 m
.22985 .58476 L
s
.973 1 0 r
.57179 .67297 m
.56323 .67836 L
s
.56305 .66985 m
.57179 .67297 L
s
1 .009 0 r
.82082 .40823 m
.82077 .40828 L
s
.82088 .40827 m
.82082 .40823 L
s
.22983 .58468 m
.22978 .58473 L
s
.22988 .58472 m
.22983 .58468 L
s
.82077 .40828 m
.82083 .40831 L
s
.22978 .58473 m
.22982 .58477 L
s
.82083 .40831 m
.82088 .40827 L
s
.22982 .58477 m
.22988 .58472 L
s
1 .233 0 r
.69912 .70221 m
.70522 .69803 L
s
1 .007 0 r
.75996 .55515 m
.76002 .55499 L
s
.29059 .43751 m
.29061 .43733 L
s
1 .233 0 r
.35144 .29045 m
.35658 .28513 L
s
0 1 .331 r
.48871 .31429 m
.48324 .33716 L
s
1 .043 0 r
.75701 .37866 m
.75695 .37864 L
s
.75692 .37825 m
.75701 .37866 L
s
.75701 .37866 m
.75668 .37849 L
s
.75718 .3784 m
.75701 .37866 L
s
.75662 .37758 m
.75701 .37866 L
s
.75692 .37825 m
.75668 .37849 L
s
.75718 .3784 m
.75692 .37825 L
s
1 .007 0 r
.76001 .55499 m
.76005 .55503 L
s
.75997 .55502 m
.76001 .55499 L
s
.76001 .55499 m
.76002 .55499 L
s
.29061 .43734 m
.29065 .43737 L
s
.29057 .43737 m
.29061 .43734 L
s
.29061 .43734 m
.29061 .43733 L
s
.76005 .55503 m
.76001 .55506 L
s
.76002 .55499 m
.76005 .55503 L
s
.29065 .43737 m
.2906 .4374 L
s
.29061 .43733 m
.29065 .43737 L
s
1 .825 0 r
.45814 .34782 m
.45422 .35526 L
s
1 .007 0 r
.76001 .55506 m
.75997 .55502 L
s
.75997 .55502 m
.76002 .55499 L
s
.2906 .4374 m
.29057 .43737 L
s
.29057 .43737 m
.29061 .43733 L
s
.76002 .55499 m
.76001 .55506 L
s
.29061 .43733 m
.2906 .4374 L
s
1 .043 0 r
.75668 .37849 m
.75695 .37864 L
s
.75695 .37864 m
.75718 .3784 L
s
1 .229 0 r
.37758 .35044 m
.37639 .34897 L
s
.37639 .34897 m
.37844 .34829 L
s
.787 1 0 r
.47254 .39867 m
.47946 .40566 L
s
.46542 .40307 m
.47254 .39867 L
s
.47254 .39867 m
.47519 .39826 L
s
0 .04 1 r
.61952 .3194 m
.60832 .28768 L
s
1 .229 0 r
.37844 .34829 m
.37758 .35044 L
s
1 .606 0 r
.46673 .43227 m
.47018 .43578 L
s
.46317 .43452 m
.46673 .43227 L
s
.46673 .43227 m
.46803 .43216 L
s
1 .293 0 r
.67793 .28954 m
.67643 .28966 L
s
.6763 .28701 m
.67793 .28954 L
s
.67793 .28954 m
.67501 .28912 L
s
.67772 .28755 m
.67793 .28954 L
s
.67008 .28352 m
.67793 .28954 L
s
1 .575 0 r
.43676 .70571 m
.43912 .70144 L
s
1 .117 0 r
.59075 .524 m
.59142 .52469 L
s
.59009 .52445 m
.59075 .524 L
s
.59075 .524 m
.59106 .52402 L
s
1 .001 0 r
.16523 .55419 m
.16522 .55419 L
s
.16522 .55418 m
.16523 .55419 L
s
.16523 .55419 m
.16522 .55418 L
s
.16523 .55418 m
.16523 .55419 L
s
.16521 .55416 m
.16523 .55419 L
s
.16522 .55418 m
.16522 .55418 L
s
.16523 .55418 m
.16522 .55418 L
s
.16522 .55418 m
.16522 .55419 L
s
.16522 .55419 m
.16523 .55418 L
s
1 .043 0 r
.33613 .5836 m
.336 .58361 L
s
.33603 .58319 m
.33613 .5836 L
s
.33613 .5836 m
.33577 .58344 L
s
.33626 .58336 m
.33613 .5836 L
s
.33557 .58261 m
.33613 .5836 L
s
1 .003 0 r
.93056 .58359 m
.93059 .58353 L
s
1 .459 0 r
.63486 .67188 m
.64862 .66437 L
s
1 .003 0 r
.69574 .52473 m
.69576 .52465 L
s
1 .117 0 r
.46092 .46587 m
.46221 .46304 L
s
.973 1 0 r
.5218 .31872 m
.56488 .3178 L
s
1 .008 0 r
.22609 .40701 m
.22612 .4068 L
s
.285 1 0 r
.48717 .37755 m
.47715 .3837 L
s
.48117 .36692 m
.48717 .37755 L
s
1 .117 0 r
.59142 .52469 m
.59077 .52514 L
s
.59106 .52402 m
.59142 .52469 L
s
1 .003 0 r
.93058 .58353 m
.9306 .58354 L
s
.93057 .58354 m
.93058 .58353 L
s
.93058 .58353 m
.93059 .58353 L
s
1 .787 0 r
.59956 .61297 m
.59375 .61865 L
s
.59152 .61242 m
.59956 .61297 L
s
1 .003 0 r
.9306 .58354 m
.93059 .58355 L
s
.93059 .58353 m
.9306 .58354 L
s
.93059 .58355 m
.93057 .58354 L
s
.93057 .58354 m
.93059 .58353 L
s
.69576 .52465 m
.69577 .52467 L
s
.69574 .52467 m
.69576 .52465 L
s
.69576 .52465 m
.69576 .52465 L
s
.93059 .58353 m
.93059 .58355 L
s
.69577 .52467 m
.69576 .52468 L
s
.69576 .52465 m
.69577 .52467 L
s
.69576 .52468 m
.69574 .52467 L
s
.69574 .52467 m
.69576 .52465 L
s
.69576 .52465 m
.69576 .52468 L
s
1 .043 0 r
.33603 .58319 m
.33577 .58344 L
s
.33626 .58336 m
.33603 .58319 L
s
1 .293 0 r
.6763 .28701 m
.67501 .28912 L
s
.67772 .28755 m
.6763 .28701 L
s
1 .344 0 r
.6189 .58584 m
.61719 .58347 L
s
.61719 .58347 m
.62058 .5828 L
s
1 .008 0 r
.22612 .4068 m
.22617 .40685 L
s
.22607 .40684 m
.22612 .4068 L
s
.22612 .4068 m
.22612 .4068 L
s
0 .197 1 r
.40705 .31112 m
.42271 .34683 L
s
1 .293 0 r
.67501 .28912 m
.67643 .28966 L
s
1 .008 0 r
.22617 .40685 m
.22611 .40688 L
s
.22612 .4068 m
.22617 .40685 L
s
1 .043 0 r
.33577 .58344 m
.336 .58361 L
s
1 .008 0 r
.22611 .40688 m
.22607 .40684 L
s
.22607 .40684 m
.22612 .4068 L
s
.22612 .4068 m
.22611 .40688 L
s
1 .787 0 r
.59375 .61865 m
.59152 .61242 L
s
.973 1 0 r
.49263 .6793 m
.49616 .67138 L
s
1 .043 0 r
.336 .58361 m
.33626 .58336 L
s
1 .117 0 r
.59077 .52514 m
.59009 .52445 L
s
.59009 .52445 m
.59106 .52402 L
s
1 .344 0 r
.62058 .5828 m
.6189 .58584 L
s
1 .168 0 r
.31985 .70091 m
.31904 .70113 L
s
.31914 .6994 m
.31985 .70091 L
s
.31985 .70091 m
.31824 .70051 L
s
.31994 .70001 m
.31985 .70091 L
s
.31605 .69767 m
.31985 .70091 L
s
1 .117 0 r
.59106 .52402 m
.59077 .52514 L
s
0 1 .077 r
.48069 .35952 m
.46884 .34764 L
s
.46884 .34764 m
.48556 .33915 L
s
.939 1 0 r
.46296 .64197 m
.45844 .6431 L
s
.45865 .63236 m
.46296 .64197 L
s
.46296 .64197 m
.45301 .63937 L
s
.46408 .63607 m
.46296 .64197 L
s
.44063 .62049 m
.46296 .64197 L
s
1 .606 0 r
.47018 .43578 m
.46662 .43803 L
s
.46803 .43216 m
.47018 .43578 L
s
1 .168 0 r
.31914 .6994 m
.31824 .70051 L
s
.31994 .70001 m
.31914 .6994 L
s
1 .055 0 r
.2111 .70062 m
.21087 .70068 L
s
.21092 .70011 m
.2111 .70062 L
s
.2111 .70062 m
.2106 .70045 L
s
.21119 .70033 m
.2111 .70062 L
s
.21007 .69949 m
.2111 .70062 L
s
1 .199 0 r
.61279 .43562 m
.61206 .43566 L
s
.61201 .43377 m
.61279 .43562 L
s
.61279 .43562 m
.61097 .43507 L
s
.61311 .43437 m
.61279 .43562 L
s
.60902 .43111 m
.61279 .43562 L
s
1 .741 0 r
.58742 .29389 m
.58871 .28771 L
s
1 .59 0 r
.6004 .3767 m
.60257 .37762 L
s
.60243 .37212 m
.6004 .3767 L
s
.60649 .37667 m
.6004 .3767 L
s
.973 1 0 r
.56488 .3178 m
.55631 .32269 L
s
.55612 .31397 m
.56488 .3178 L
s
1 .59 0 r
.60649 .37667 m
.60257 .37762 L
s
.60243 .37212 m
.60649 .37667 L
s
.60461 .37303 m
.60649 .37667 L
s
.58648 .36764 m
.60649 .37667 L
s
1 .055 0 r
.21092 .70011 m
.2106 .70045 L
s
.21119 .70033 m
.21092 .70011 L
s
1 .168 0 r
.31824 .70051 m
.31904 .70113 L
s
1 .787 0 r
.45431 .61732 m
.45849 .61213 L
s
1 .055 0 r
.2106 .70045 m
.21087 .70068 L
s
1 .59 0 r
.60461 .37303 m
.60243 .37212 L
s
1 .077 0 r
.80549 .7004 m
.80703 .69885 L
s
1 .002 0 r
.86641 .55316 m
.86642 .55313 L
s
.939 1 0 r
.57053 .6415 m
.6103 .62994 L
s
1 0 0 r
.63144 .49427 m
.63144 .49427 L
s
1 .058 0 r
.39648 .43538 m
.39708 .43394 L
s
1 .65 0 r
.4574 .28814 m
.4812 .2795 L
s
1 .009 0 r
.16152 .37648 m
.16155 .37626 L
s
1 .65 0 r
.61421 .70039 m
.61254 .70195 L
s
.61237 .69526 m
.61421 .70039 L
s
.61734 .69724 m
.61421 .70039 L
s
1 .002 0 r
.86642 .55313 m
.86643 .55313 L
s
.86641 .55313 m
.86642 .55313 L
s
.86642 .55313 m
.86642 .55313 L
s
.86643 .55313 m
.86642 .55314 L
s
.86642 .55313 m
.86643 .55313 L
s
.86642 .55314 m
.86641 .55313 L
s
.86641 .55313 m
.86642 .55313 L
s
.86642 .55313 m
.86642 .55314 L
s
1 .055 0 r
.21087 .70068 m
.21119 .70033 L
s
1 .199 0 r
.61201 .43377 m
.61097 .43507 L
s
.61311 .43437 m
.61201 .43377 L
s
1 .009 0 r
.16155 .37626 m
.16159 .37631 L
s
.16149 .3763 m
.16155 .37626 L
s
.16155 .37626 m
.16155 .37626 L
s
.16159 .37631 m
.16154 .37634 L
s
.16155 .37626 m
.16159 .37631 L
s
.16154 .37634 m
.16149 .3763 L
s
.16149 .3763 m
.16155 .37626 L
s
.16155 .37626 m
.16154 .37634 L
s
.973 1 0 r
.56323 .67836 m
.56305 .66985 L
s
.787 1 0 r
.47946 .40566 m
.47235 .41008 L
s
.47519 .39826 m
.47946 .40566 L
s
1 .199 0 r
.61097 .43507 m
.61206 .43566 L
s
1 .65 0 r
.61069 .69681 m
.61237 .69526 L
s
.61237 .69526 m
.61734 .69724 L
s
1 .168 0 r
.31904 .70113 m
.31994 .70001 L
s
1 .121 0 r
.73661 .31711 m
.73623 .31708 L
s
.73615 .31597 m
.73661 .31711 L
s
.73661 .31711 m
.73552 .31675 L
s
.73686 .3163 m
.73661 .31711 L
s
.7345 .31418 m
.73661 .31711 L
s
0 1 .331 r
.57722 .67051 m
.58166 .67531 L
s
.58126 .65147 m
.57722 .67051 L
s
.60017 .66634 m
.57722 .67051 L
s
1 .293 0 r
.67643 .28966 m
.67772 .28755 L
s
1 .121 0 r
.73615 .31597 m
.73552 .31675 L
s
.73686 .3163 m
.73615 .31597 L
s
1 .011 0 r
.86318 .37568 m
.86317 .37567 L
s
.86316 .37557 m
.86318 .37568 L
s
.86318 .37568 m
.8631 .37563 L
s
.86323 .37561 m
.86318 .37568 L
s
.86313 .37538 m
.86318 .37568 L
s
1 .39 0 r
.4077 .64081 m
.40596 .64122 L
s
.4061 .63728 m
.4077 .64081 L
s
.4077 .64081 m
.40401 .63985 L
s
.40804 .63865 m
.4077 .64081 L
s
.39929 .63298 m
.4077 .64081 L
s
.717 1 0 r
.52739 .31675 m
.51791 .32596 L
s
.51424 .31568 m
.52739 .31675 L
s
1 .121 0 r
.73552 .31675 m
.73623 .31708 L
s
1 .011 0 r
.86316 .37557 m
.8631 .37563 L
s
.86323 .37561 m
.86316 .37557 L
s
.8631 .37563 m
.86317 .37567 L
s
.86317 .37567 m
.86323 .37561 L
s
1 .606 0 r
.46662 .43803 m
.46317 .43452 L
s
.46317 .43452 m
.46803 .43216 L
s
1 .59 0 r
.44959 .37117 m
.45247 .3752 L
s
.44656 .37263 m
.44959 .37117 L
s
.44959 .37117 m
.45226 .37134 L
s
1 .117 0 r
.46196 .46305 m
.46263 .46373 L
s
.46128 .46349 m
.46196 .46305 L
s
.46196 .46305 m
.46221 .46304 L
s
1 .005 0 r
.27106 .55229 m
.27105 .55229 L
s
.27105 .55224 m
.27106 .55229 L
s
.27106 .55229 m
.27102 .55227 L
s
.27108 .55226 m
.27106 .55229 L
s
.27102 .55217 m
.27106 .55229 L
s
.27105 .55224 m
.27102 .55227 L
s
.27108 .55226 m
.27105 .55224 L
s
1 .241 0 r
.36292 .67012 m
.36179 .6704 L
s
.36191 .66795 m
.36292 .67012 L
s
.36292 .67012 m
.36062 .66954 L
s
.36309 .66881 m
.36292 .67012 L
s
.35759 .66538 m
.36292 .67012 L
s
1 .005 0 r
.27102 .55227 m
.27105 .55229 L
s
.27105 .55229 m
.27108 .55226 L
s
1 .058 0 r
.39697 .43395 m
.3973 .43429 L
s
.39662 .43417 m
.39697 .43395 L
s
.39697 .43395 m
.39708 .43394 L
s
1 .199 0 r
.61206 .43566 m
.61311 .43437 L
s
1 .121 0 r
.74122 .67003 m
.7437 .66756 L
s
1 0 0 r
.80217 .5227 m
.80218 .52269 L
s
1 .039 0 r
.33197 .40485 m
.33233 .40387 L
s
1 .009 0 r
.09687 .34592 m
.09689 .34569 L
s
1 0 0 r
.80218 .52269 m
.80218 .5227 L
s
.80217 .5227 m
.80218 .52269 L
s
.80218 .52269 m
.80218 .52269 L
s
.80218 .5227 m
.80218 .5227 L
s
.80218 .52269 m
.80218 .5227 L
s
.80218 .5227 m
.80217 .5227 L
s
.80217 .5227 m
.80218 .52269 L
s
.80218 .52269 m
.80218 .5227 L
s
1 .058 0 r
.3973 .43429 m
.39695 .4345 L
s
.39708 .43394 m
.3973 .43429 L
s
.717 1 0 r
.51791 .32596 m
.51424 .31568 L
s
1 .117 0 r
.46263 .46373 m
.46194 .46417 L
s
.46221 .46304 m
.46263 .46373 L
s
1 .04 0 r
.79925 .34583 m
.79919 .34581 L
s
.79916 .34544 m
.79925 .34583 L
s
.79925 .34583 m
.79894 .34567 L
s
.79941 .34557 m
.79925 .34583 L
s
.79885 .3448 m
.79925 .34583 L
s
1 .233 0 r
.70393 .69767 m
.70509 .69928 L
s
.70289 .69845 m
.70393 .69767 L
s
.70393 .69767 m
.70522 .69803 L
s
.35561 .28514 m
.35674 .28673 L
s
.35436 .28567 m
.35561 .28514 L
s
.35561 .28514 m
.35658 .28513 L
s
1 .058 0 r
.39695 .4345 m
.39662 .43417 L
s
.39662 .43417 m
.39708 .43394 L
s
1 .121 0 r
.73623 .31708 m
.73686 .3163 L
s
1 .009 0 r
.09689 .3457 m
.09694 .34574 L
s
.09684 .34573 m
.09689 .3457 L
s
.09689 .3457 m
.09689 .34569 L
s
.09694 .34574 m
.09688 .34578 L
s
.09689 .34569 m
.09694 .34574 L
s
1 .04 0 r
.79916 .34544 m
.79894 .34567 L
s
.79941 .34557 m
.79916 .34544 L
s
1 .59 0 r
.45247 .3752 m
.44945 .37667 L
s
.45226 .37134 m
.45247 .3752 L
s
1 .009 0 r
.09688 .34578 m
.09684 .34573 L
s
.09684 .34573 m
.09689 .34569 L
s
1 .077 0 r
.80669 .69876 m
.80713 .69925 L
s
.80631 .69907 m
.80669 .69876 L
s
.80669 .69876 m
.80703 .69885 L
s
1 .009 0 r
.09689 .34569 m
.09688 .34578 L
s
1 .04 0 r
.79894 .34567 m
.79919 .34581 L
s
1 .233 0 r
.70509 .69928 m
.70406 .70007 L
s
.70522 .69803 m
.70509 .69928 L
s
.35674 .28673 m
.35549 .28725 L
s
.35658 .28513 m
.35674 .28673 L
s
1 .058 0 r
.39708 .43394 m
.39695 .4345 L
s
1 .077 0 r
.80713 .69925 m
.80675 .69955 L
s
.80703 .69885 m
.80713 .69925 L
s
1 .117 0 r
.46194 .46417 m
.46128 .46349 L
s
.46128 .46349 m
.46221 .46304 L
s
1 .241 0 r
.36191 .66795 m
.36062 .66954 L
s
.36309 .66881 m
.36191 .66795 L
s
1 .04 0 r
.79919 .34581 m
.79941 .34557 L
s
.939 1 0 r
.45865 .63236 m
.45301 .63937 L
s
.46408 .63607 m
.45865 .63236 L
s
0 .434 1 r
.4452 .34552 m
.4262 .36857 L
s
.41148 .33508 m
.4452 .34552 L
s
.787 1 0 r
.58354 .41345 m
.58565 .4034 L
s
1 .39 0 r
.4061 .63728 m
.40401 .63985 L
s
.40804 .63865 m
.4061 .63728 L
s
.808 1 0 r
.49304 .69909 m
.49704 .70218 L
s
.49714 .68989 m
.49304 .69909 L
s
.50535 .69903 m
.49304 .69909 L
s
1 .117 0 r
.46221 .46304 m
.46194 .46417 L
s
1 .077 0 r
.80675 .69955 m
.80631 .69907 L
s
.80631 .69907 m
.80703 .69885 L
s
.808 1 0 r
.50535 .69903 m
.49704 .70218 L
s
.49714 .68989 m
.50535 .69903 L
s
.50115 .69295 m
.50535 .69903 L
s
.4637 .68388 m
.50535 .69903 L
s
1 .241 0 r
.36062 .66954 m
.36179 .6704 L
s
1 .077 0 r
.80703 .69885 m
.80675 .69955 L
s
1 .039 0 r
.33227 .40389 m
.33249 .40411 L
s
.33203 .40403 m
.33227 .40389 L
s
.33227 .40389 m
.33233 .40387 L
s
0 .813 1 r
.60598 .37468 m
.59762 .37893 L
s
.59693 .34915 m
.60598 .37468 L
s
.62139 .35577 m
.60598 .37468 L
s
1 .039 0 r
.33249 .40411 m
.33225 .40425 L
s
.33233 .40387 m
.33249 .40411 L
s
1 .606 0 r
.46803 .43216 m
.46662 .43803 L
s
1 .39 0 r
.40401 .63985 m
.40596 .64122 L
s
1 .039 0 r
.33225 .40425 m
.33203 .40403 L
s
.33203 .40403 m
.33233 .40387 L
s
.808 1 0 r
.50115 .69295 m
.49714 .68989 L
s
1 .039 0 r
.33233 .40387 m
.33225 .40425 L
s
1 0 0 r
.20639 .5217 m
.20639 .5217 L
s
.20639 .52169 m
.20639 .5217 L
s
.20639 .5217 m
.20639 .5217 L
s
.2064 .5217 m
.20639 .5217 L
s
.20639 .52169 m
.20639 .5217 L
s
.20639 .52169 m
.20639 .5217 L
s
.2064 .5217 m
.20639 .52169 L
s
.20639 .5217 m
.20639 .5217 L
s
.20639 .5217 m
.2064 .5217 L
s
1 .029 0 r
.91212 .69858 m
.91262 .69797 L
s
1 .229 0 r
.67688 .63962 m
.68182 .635 L
s
1 0 0 r
.73786 .49221 m
.73786 .49221 L
s
.425 1 0 r
.50262 .43325 m
.56122 .41372 L
s
1 .029 0 r
.26738 .37428 m
.26763 .37354 L
s
1 .039 0 r
.37744 .55109 m
.37735 .5511 L
s
.37737 .55072 m
.37744 .55109 L
s
.37744 .55109 m
.37714 .55093 L
s
.37759 .55088 m
.37744 .55109 L
s
.37707 .55017 m
.37744 .55109 L
s
1 .233 0 r
.70406 .70007 m
.70289 .69845 L
s
.70289 .69845 m
.70522 .69803 L
s
.35549 .28725 m
.35436 .28567 L
s
.35436 .28567 m
.35658 .28513 L
s
1 .039 0 r
.37737 .55072 m
.37714 .55093 L
s
.37759 .55088 m
.37737 .55072 L
s
.973 1 0 r
.55631 .32269 m
.55612 .31397 L
s
1 .039 0 r
.37714 .55093 m
.37735 .5511 L
s
.939 1 0 r
.45301 .63937 m
.45844 .6431 L
s
1 .233 0 r
.70522 .69803 m
.70406 .70007 L
s
.35658 .28513 m
.35549 .28725 L
s
1 .039 0 r
.37735 .5511 m
.37759 .55088 L
s
0 1 .331 r
.58574 .65612 m
.58126 .65147 L
s
.58126 .65147 m
.60017 .66634 L
s
1 .459 0 r
.42604 .31155 m
.42804 .31488 L
s
.42389 .31241 m
.42604 .31155 L
s
.42604 .31155 m
.42852 .3118 L
s
1 .241 0 r
.36179 .6704 m
.36309 .66881 L
s
1 .459 0 r
.42804 .31488 m
.4259 .31575 L
s
.42852 .3118 m
.42804 .31488 L
s
.285 1 0 r
.47715 .3837 m
.46735 .37384 L
s
.46735 .37384 m
.48117 .36692 L
s
1 .029 0 r
.9125 .69794 m
.91268 .69812 L
s
.91236 .69806 m
.9125 .69794 L
s
.9125 .69794 m
.91262 .69797 L
s
.26759 .37355 m
.26775 .37372 L
s
.26741 .37366 m
.26759 .37355 L
s
.26759 .37355 m
.26763 .37354 L
s
.91268 .69812 m
.91254 .69824 L
s
.91262 .69797 m
.91268 .69812 L
s
.26775 .37372 m
.26757 .37382 L
s
.26763 .37354 m
.26775 .37372 L
s
.939 1 0 r
.51436 .3442 m
.51128 .3455 L
s
.51132 .3357 m
.51436 .3442 L
s
.51915 .33785 m
.51436 .3442 L
s
1 .063 0 r
.25248 .66859 m
.25223 .66864 L
s
.25228 .66799 m
.25248 .66859 L
s
.25248 .66859 m
.25191 .66838 L
s
.2526 .66825 m
.25248 .66859 L
s
.25137 .66724 m
.25248 .66859 L
s
1 .029 0 r
.91254 .69824 m
.91236 .69806 L
s
.91236 .69806 m
.91262 .69797 L
s
.26757 .37382 m
.26741 .37366 L
s
.26741 .37366 m
.26763 .37354 L
s
.91262 .69797 m
.91254 .69824 L
s
.26763 .37354 m
.26757 .37382 L
s
.787 1 0 r
.47235 .41008 m
.46542 .40307 L
s
.46542 .40307 m
.47519 .39826 L
s
0 1 .077 r
.48556 .33915 m
.48069 .35952 L
s
1 .063 0 r
.25228 .66799 m
.25191 .66838 L
s
.2526 .66825 m
.25228 .66799 L
s
0 1 .566 r
.45587 .40294 m
.44221 .41961 L
s
.43167 .39567 m
.45587 .40294 L
s
1 .063 0 r
.25191 .66838 m
.25223 .66864 L
s
1 .121 0 r
.74316 .66743 m
.74384 .66822 L
s
.74256 .66789 m
.74316 .66743 L
s
.74316 .66743 m
.7437 .66756 L
s
1 .005 0 r
.67351 .46181 m
.6735 .46181 L
s
.6735 .46176 m
.67351 .46181 L
s
.67351 .46181 m
.67347 .46179 L
s
.67353 .46178 m
.67351 .46181 L
s
.67348 .46168 m
.67351 .46181 L
s
.6735 .46176 m
.67347 .46179 L
s
.67353 .46178 m
.6735 .46176 L
s
.67347 .46179 m
.6735 .46181 L
s
.6735 .46181 m
.67353 .46178 L
s
1 .063 0 r
.25223 .66864 m
.2526 .66825 L
s
1 .121 0 r
.74384 .66822 m
.74324 .66867 L
s
.7437 .66756 m
.74384 .66822 L
s
1 .59 0 r
.60257 .37762 m
.60461 .37303 L
s
1 .038 0 r
.84784 .66817 m
.84845 .66737 L
s
1 0 0 r
.90886 .52068 m
.90886 .52067 L
s
1 .59 0 r
.61245 .60917 m
.6274 .59785 L
s
1 .344 0 r
.4381 .40268 m
.44609 .39525 L
s
1 0 0 r
.14169 .49118 m
.14169 .49118 L
s
1 .023 0 r
.20272 .34368 m
.20289 .34307 L
s
1 0 0 r
.90886 .52067 m
.90886 .52067 L
s
.90886 .52067 m
.90886 .52067 L
s
.90886 .52067 m
.90886 .52067 L
s
.90886 .52067 m
.90886 .52067 L
s
.90886 .52067 m
.90886 .52067 L
s
.90886 .52067 m
.90886 .52067 L
s
.90886 .52067 m
.90886 .52067 L
s
.90886 .52067 m
.90886 .52067 L
s
1 .39 0 r
.40596 .64122 m
.40804 .63865 L
s
.939 1 0 r
.50823 .33697 m
.51132 .3357 L
s
.51132 .3357 m
.51915 .33785 L
s
0 .813 1 r
.58847 .35314 m
.59693 .34915 L
s
.59693 .34915 m
.62139 .35577 L
s
1 .121 0 r
.74324 .66867 m
.74256 .66789 L
s
.74256 .66789 m
.7437 .66756 L
s
1 .023 0 r
.20287 .34309 m
.203 .34322 L
s
.20272 .34317 m
.20287 .34309 L
s
.20287 .34309 m
.20289 .34307 L
s
.203 .34322 m
.20285 .3433 L
s
.20289 .34307 m
.203 .34322 L
s
1 .121 0 r
.7437 .66756 m
.74324 .66867 L
s
1 .023 0 r
.20285 .3433 m
.20272 .34317 L
s
.20272 .34317 m
.20289 .34307 L
s
1 .65 0 r
.61734 .69724 m
.61254 .70195 L
s
.61069 .69681 m
.61734 .69724 L
s
1 .023 0 r
.20289 .34307 m
.20285 .3433 L
s
1 .59 0 r
.44945 .37667 m
.44656 .37263 L
s
.44656 .37263 m
.45226 .37134 L
s
1 .038 0 r
.84831 .66733 m
.84854 .66756 L
s
.84812 .66749 m
.84831 .66733 L
s
.84831 .66733 m
.84845 .66737 L
s
1 .65 0 r
.61254 .70195 m
.61069 .69681 L
s
.808 1 0 r
.56911 .69708 m
.56906 .69949 L
s
.5689 .68719 m
.56911 .69708 L
s
.57904 .69316 m
.56911 .69708 L
s
1 .038 0 r
.84854 .66756 m
.84835 .66772 L
s
.84845 .66737 m
.84854 .66756 L
s
.425 1 0 r
.59908 .54947 m
.59493 .55248 L
s
.5946 .53693 m
.59908 .54947 L
s
.60663 .54104 m
.59908 .54947 L
s
1 .038 0 r
.84835 .66772 m
.84812 .66749 L
s
.84812 .66749 m
.84845 .66737 L
s
.84845 .66737 m
.84835 .66772 L
s
1 .59 0 r
.45226 .37134 m
.44945 .37667 L
s
1 .001 0 r
.31244 .51969 m
.31244 .51969 L
s
.31244 .51968 m
.31244 .51969 L
s
.31244 .51969 m
.31243 .51969 L
s
.31245 .51969 m
.31244 .51969 L
s
.31243 .51966 m
.31244 .51969 L
s
.31244 .51968 m
.31243 .51969 L
s
.31245 .51969 m
.31244 .51968 L
s
.31243 .51969 m
.31244 .51969 L
s
.31244 .51969 m
.31245 .51969 L
s
1 .095 0 r
.7784 .28354 m
.77812 .2835 L
s
.77804 .28264 m
.7784 .28354 L
s
.7784 .28354 m
.77755 .28326 L
s
.77861 .28289 m
.7784 .28354 L
s
.7768 .28121 m
.7784 .28354 L
s
1 .052 0 r
.78348 .63773 m
.78429 .63659 L
s
1 0 0 r
.84454 .49014 m
.84454 .49014 L
s
0 1 .566 r
.54796 .57869 m
.64502 .54922 L
s
1 .141 0 r
.3735 .37207 m
.376 .36875 L
s
1 .019 0 r
.13797 .31304 m
.1381 .31253 L
s
1 .65 0 r
.47834 .28352 m
.47637 .28418 L
s
.47647 .27829 m
.47834 .28352 L
s
.4812 .2795 m
.47834 .28352 L
s
1 .095 0 r
.77804 .28264 m
.77755 .28326 L
s
.77861 .28289 m
.77804 .28264 L
s
1 .038 0 r
.84163 .31287 m
.84157 .31285 L
s
.84153 .3125 m
.84163 .31287 L
s
.84163 .31287 m
.84133 .31273 L
s
.84177 .31262 m
.84163 .31287 L
s
.84124 .3119 m
.84163 .31287 L
s
1 .133 0 r
.65356 .40139 m
.6531 .4014 L
s
.65305 .40015 m
.65356 .40139 L
s
.65356 .40139 m
.65235 .40102 L
s
.65379 .40054 m
.65356 .40139 L
s
.65111 .39832 m
.65356 .40139 L
s
1 .038 0 r
.84153 .3125 m
.84133 .31273 L
s
.84177 .31262 m
.84153 .3125 L
s
1 .095 0 r
.77755 .28326 m
.77812 .2835 L
s
1 .038 0 r
.84133 .31273 m
.84157 .31285 L
s
1 .459 0 r
.64578 .66353 m
.6478 .66688 L
s
.64392 .66487 m
.64578 .66353 L
s
.64578 .66353 m
.64862 .66437 L
s
1 .019 0 r
.13809 .31254 m
.13819 .31265 L
s
.13796 .31261 m
.13809 .31254 L
s
.13809 .31254 m
.1381 .31253 L
s
0 .813 1 r
.44913 .37172 m
.43212 .3924 L
s
.41897 .36251 m
.44913 .37172 L
s
1 .65 0 r
.4745 .27895 m
.47647 .27829 L
s
.47647 .27829 m
.4812 .2795 L
s
1 .019 0 r
.13819 .31265 m
.13807 .31272 L
s
.1381 .31253 m
.13819 .31265 L
s
1 .038 0 r
.84157 .31285 m
.84177 .31262 L
s
1 .019 0 r
.13807 .31272 m
.13796 .31261 L
s
.13796 .31261 m
.1381 .31253 L
s
1 .459 0 r
.6478 .66688 m
.64594 .66822 L
s
.64862 .66437 m
.6478 .66688 L
s
1 .019 0 r
.1381 .31253 m
.13807 .31272 L
s
1 .133 0 r
.65305 .40015 m
.65235 .40102 L
s
.65379 .40054 m
.65305 .40015 L
s
.425 1 0 r
.59043 .53988 m
.5946 .53693 L
s
.5946 .53693 m
.60663 .54104 L
s
1 .021 0 r
.18691 .63725 m
.18684 .63726 L
s
.18686 .63705 m
.18691 .63725 L
s
.18691 .63725 m
.18673 .63717 L
s
.18697 .63714 m
.18691 .63725 L
s
.18662 .63678 m
.18691 .63725 L
s
.787 1 0 r
.47519 .39826 m
.47235 .41008 L
s
0 .434 1 r
.41148 .33508 m
.4262 .36857 L
s
1 .133 0 r
.65235 .40102 m
.6531 .4014 L
s
1 .095 0 r
.77812 .2835 m
.77861 .28289 L
s
1 .459 0 r
.4259 .31575 m
.42389 .31241 L
s
.42389 .31241 m
.42852 .3118 L
s
1 .021 0 r
.18686 .63705 m
.18673 .63717 L
s
.18697 .63714 m
.18686 .63705 L
s
.18673 .63717 m
.18684 .63726 L
s
.18684 .63726 m
.18697 .63714 L
s
1 .459 0 r
.42852 .3118 m
.4259 .31575 L
s
.808 1 0 r
.56885 .68956 m
.5689 .68719 L
s
.5689 .68719 m
.57904 .69316 L
s
.717 1 0 r
.46723 .66651 m
.46175 .66801 L
s
.462 .65488 m
.46723 .66651 L
s
.46723 .66651 m
.45515 .6634 L
s
.46861 .65946 m
.46723 .66651 L
s
.44012 .64078 m
.46723 .66651 L
s
0 1 .077 r
.57314 .65244 m
.57675 .63541 L
s
1 .052 0 r
.7841 .63655 m
.78442 .63686 L
s
.78383 .63677 m
.7841 .63655 L
s
.7841 .63655 m
.78429 .63659 L
s
.78442 .63686 m
.78414 .63708 L
s
.78429 .63659 m
.78442 .63686 L
s
1 .133 0 r
.6531 .4014 m
.65379 .40054 L
s
0 1 .331 r
.60017 .66634 m
.58166 .67531 L
s
.58574 .65612 m
.60017 .66634 L
s
.50589 .65128 m
.60017 .66634 L
s
1 .001 0 r
.78014 .45959 m
.78014 .45959 L
s
.78014 .45958 m
.78014 .45959 L
s
.78014 .45959 m
.78014 .45959 L
s
.78014 .45958 m
.78014 .45959 L
s
.78014 .45957 m
.78014 .45959 L
s
.78014 .45958 m
.78014 .45959 L
s
.78014 .45958 m
.78014 .45958 L
s
.78014 .45959 m
.78014 .45959 L
s
.78014 .45959 m
.78014 .45958 L
s
1 .014 0 r
.9547 .66631 m
.95492 .666 L
s
1 .081 0 r
.71904 .60724 m
.72024 .60542 L
s
1 0 0 r
.24772 .48911 m
.24772 .48911 L
s
1 .08 0 r
.30882 .34143 m
.30999 .33947 L
s
1 .017 0 r
.07315 .28237 m
.07325 .28192 L
s
1 .052 0 r
.78414 .63708 m
.78383 .63677 L
s
.78383 .63677 m
.78429 .63659 L
s
0 1 .566 r
.43167 .39567 m
.44221 .41961 L
s
.285 1 0 r
.48117 .36692 m
.47715 .3837 L
s
1 .052 0 r
.78429 .63659 m
.78414 .63708 L
s
1 .014 0 r
.95486 .66599 m
.95496 .66607 L
s
.95479 .66605 m
.95486 .66599 L
s
.95486 .66599 m
.95492 .666 L
s
.95496 .66607 m
.95488 .66613 L
s
.95492 .666 m
.95496 .66607 L
s
1 .017 0 r
.07324 .28193 m
.07333 .28203 L
s
.07313 .28199 m
.07324 .28193 L
s
.07324 .28193 m
.07325 .28192 L
s
1 .014 0 r
.95488 .66613 m
.95479 .66605 L
s
.95479 .66605 m
.95492 .666 L
s
1 .075 0 r
.29399 .63651 m
.29373 .63656 L
s
.29379 .63581 m
.29399 .63651 L
s
.29399 .63651 m
.29334 .63626 L
s
.29418 .63611 m
.29399 .63651 L
s
.29283 .63488 m
.29399 .63651 L
s
1 .017 0 r
.07333 .28203 m
.07322 .28208 L
s
.07325 .28192 m
.07333 .28203 L
s
1 .014 0 r
.95492 .666 m
.95488 .66613 L
s
1 .229 0 r
.68078 .63477 m
.68201 .63627 L
s
.67965 .63558 m
.68078 .63477 L
s
.68078 .63477 m
.68182 .635 L
s
1 .017 0 r
.07322 .28208 m
.07313 .28199 L
s
.07313 .28199 m
.07325 .28192 L
s
.07325 .28192 m
.07322 .28208 L
s
1 .075 0 r
.29379 .63581 m
.29334 .63626 L
s
.29418 .63611 m
.29379 .63581 L
s
1 .336 0 r
.63863 .34092 m
.63669 .34122 L
s
.63658 .33812 m
.63863 .34092 L
s
.63863 .34092 m
.6352 .34062 L
s
.63807 .33872 m
.63863 .34092 L
s
.62864 .33467 m
.63863 .34092 L
s
1 .021 0 r
.41879 .51813 m
.41877 .51813 L
s
.41878 .51793 m
.41879 .51813 L
s
.41879 .51813 m
.41865 .51803 L
s
.4189 .51803 m
.41879 .51813 L
s
.41873 .51762 m
.41879 .51813 L
s
1 .229 0 r
.68201 .63627 m
.68088 .63708 L
s
.68182 .635 m
.68201 .63627 L
s
1 .021 0 r
.41878 .51793 m
.41865 .51803 L
s
.4189 .51803 m
.41878 .51793 L
s
1 .075 0 r
.29334 .63626 m
.29373 .63656 L
s
1 .021 0 r
.41865 .51803 m
.41877 .51813 L
s
.41877 .51813 m
.4189 .51803 L
s
1 .014 0 r
.71577 .42932 m
.71576 .42932 L
s
.71575 .42918 m
.71577 .42932 L
s
.71577 .42932 m
.71567 .42926 L
s
.71584 .42924 m
.71577 .42932 L
s
.71566 .42897 m
.71577 .42932 L
s
.71575 .42918 m
.71567 .42926 L
s
.71584 .42924 m
.71575 .42918 L
s
1 .075 0 r
.29373 .63656 m
.29418 .63611 L
s
0 .197 1 r
.64347 .3111 m
.61534 .3385 L
s
.60452 .30791 m
.64347 .3111 L
s
1 .336 0 r
.63658 .33812 m
.6352 .34062 L
s
.63807 .33872 m
.63658 .33812 L
s
.6352 .34062 m
.63669 .34122 L
s
1 .014 0 r
.71567 .42926 m
.71576 .42932 L
s
.939 1 0 r
.45844 .6431 m
.46408 .63607 L
s
1 .014 0 r
.71576 .42932 m
.71584 .42924 L
s
1 .016 0 r
.89033 .63583 m
.89055 .63547 L
s
1 .162 0 r
.65453 .57673 m
.65677 .57303 L
s
1 .787 0 r
.47986 .36986 m
.50895 .35978 L
s
1 0 0 r
.18293 .45852 m
.18293 .45851 L
s
1 .053 0 r
.24406 .31076 m
.24473 .30941 L
s
1 0 0 r
.18293 .45851 m
.18293 .45851 L
s
.18293 .45851 m
.18293 .45851 L
s
.18293 .45851 m
.18293 .45851 L
s
.18293 .45851 m
.18293 .45851 L
s
.18293 .45851 m
.18293 .45851 L
s
.18293 .45851 m
.18293 .45851 L
s
.18293 .45851 m
.18293 .45851 L
s
.18293 .45851 m
.18293 .45851 L
s
1 .141 0 r
.37553 .36875 m
.37627 .36966 L
s
.37473 .36916 m
.37553 .36875 L
s
.37553 .36875 m
.376 .36875 L
s
.37627 .36966 m
.37547 .37007 L
s
.376 .36875 m
.37627 .36966 L
s
1 .08 0 r
.30978 .33949 m
.31021 .33999 L
s
.30931 .33973 m
.30978 .33949 L
s
.30978 .33949 m
.30999 .33947 L
s
1 .016 0 r
.8905 .63546 m
.8906 .63555 L
s
.89041 .63553 m
.8905 .63546 L
s
.8905 .63546 m
.89055 .63547 L
s
1 .229 0 r
.68088 .63708 m
.67965 .63558 L
s
.67965 .63558 m
.68182 .635 L
s
1 .08 0 r
.31021 .33999 m
.30973 .34023 L
s
.30999 .33947 m
.31021 .33999 L
s
1 .016 0 r
.8906 .63555 m
.89051 .63562 L
s
.89055 .63547 m
.8906 .63555 L
s
1 .081 0 r
.71997 .60538 m
.72046 .60587 L
s
.71954 .60571 m
.71997 .60538 L
s
.71997 .60538 m
.72024 .60542 L
s
1 .016 0 r
.89051 .63562 m
.89041 .63553 L
s
.89041 .63553 m
.89055 .63547 L
s
.89055 .63547 m
.89051 .63562 L
s
1 .081 0 r
.72046 .60587 m
.72002 .6062 L
s
.72024 .60542 m
.72046 .60587 L
s
1 .229 0 r
.68182 .635 m
.68088 .63708 L
s
1 .08 0 r
.30973 .34023 m
.30931 .33973 L
s
.30931 .33973 m
.30999 .33947 L
s
.939 1 0 r
.60519 .63532 m
.60242 .63765 L
s
.60217 .62689 m
.60519 .63532 L
s
.6103 .62994 m
.60519 .63532 L
s
1 .459 0 r
.64594 .66822 m
.64392 .66487 L
s
.64392 .66487 m
.64862 .66437 L
s
0 .197 1 r
.61534 .3385 m
.60452 .30791 L
s
1 .081 0 r
.72002 .6062 m
.71954 .60571 L
s
.71954 .60571 m
.72024 .60542 L
s
1 .08 0 r
.30999 .33947 m
.30973 .34023 L
s
1 .459 0 r
.64862 .66437 m
.64594 .66822 L
s
1 .141 0 r
.37547 .37007 m
.37473 .36916 L
s
.37473 .36916 m
.376 .36875 L
s
1 .607 0 r
.58229 .31 m
.58345 .31049 L
s
.58334 .30493 m
.58229 .31 L
s
.58828 .30866 m
.58229 .31 L
s
1 .825 0 r
.54975 .33954 m
.54966 .34016 L
s
.5496 .33253 m
.54975 .33954 L
s
.55659 .33619 m
.54975 .33954 L
s
1 .081 0 r
.72024 .60542 m
.72002 .6062 L
s
1 .141 0 r
.376 .36875 m
.37547 .37007 L
s
1 .053 0 r
.24462 .30943 m
.24491 .30976 L
s
.24429 .3096 m
.24462 .30943 L
s
.24462 .30943 m
.24473 .30941 L
s
.24491 .30976 m
.24458 .30992 L
s
.24473 .30941 m
.24491 .30976 L
s
.717 1 0 r
.462 .65488 m
.45515 .6634 L
s
.46861 .65946 m
.462 .65488 L
s
1 0 0 r
.88705 .45747 m
.88705 .45747 L
s
.88705 .45746 m
.88705 .45747 L
s
.88705 .45747 m
.88705 .45747 L
s
.88705 .45747 m
.88705 .45747 L
s
.88705 .45746 m
.88705 .45747 L
s
.88705 .45746 m
.88705 .45747 L
s
.88705 .45747 m
.88705 .45746 L
s
.88705 .45747 m
.88705 .45747 L
s
.88705 .45747 m
.88705 .45747 L
s
1 .018 0 r
.82588 .60531 m
.8261 .60489 L
s
.808 1 0 r
.52877 .69402 m
.57904 .69316 L
s
1 .606 0 r
.58994 .54617 m
.59783 .53199 L
s
1 0 0 r
.354 .48703 m
.354 .48703 L
s
1 .336 0 r
.41517 .33918 m
.4245 .33249 L
s
1 .039 0 r
.17923 .28004 m
.17966 .27903 L
s
1 .001 0 r
.11806 .42789 m
.11806 .42787 L
s
.11806 .42787 m
.11806 .42788 L
s
.11805 .42788 m
.11806 .42787 L
s
.11806 .42787 m
.11806 .42787 L
s
.11806 .42788 m
.11806 .42788 L
s
.11806 .42787 m
.11806 .42788 L
s
.11806 .42788 m
.11805 .42788 L
s
.11805 .42788 m
.11806 .42787 L
s
1 .053 0 r
.24458 .30992 m
.24429 .3096 L
s
.24429 .3096 m
.24473 .30941 L
s
1 .001 0 r
.11806 .42787 m
.11806 .42788 L
s
.939 1 0 r
.59939 .62919 m
.60217 .62689 L
s
.60217 .62689 m
.6103 .62994 L
s
1 .053 0 r
.24473 .30941 m
.24458 .30992 L
s
1 .607 0 r
.58451 .30541 m
.58334 .30493 L
s
.58334 .30493 m
.58828 .30866 L
s
0 .813 1 r
.41897 .36251 m
.43212 .3924 L
s
1 .018 0 r
.82605 .60488 m
.82616 .60498 L
s
.82595 .60496 m
.82605 .60488 L
s
.82605 .60488 m
.8261 .60489 L
s
.82616 .60498 m
.82607 .60506 L
s
.8261 .60489 m
.82616 .60498 L
s
.82607 .60506 m
.82595 .60496 L
s
.82595 .60496 m
.8261 .60489 L
s
.8261 .60489 m
.82607 .60506 L
s
1 .336 0 r
.63669 .34122 m
.63807 .33872 L
s
1 .825 0 r
.54951 .33312 m
.5496 .33253 L
s
.5496 .33253 m
.55659 .33619 L
s
1 .65 0 r
.4812 .2795 m
.47637 .28418 L
s
.4745 .27895 m
.4812 .2795 L
s
1 .019 0 r
.22821 .60479 m
.22816 .60479 L
s
.22817 .6046 m
.22821 .60479 L
s
.22821 .60479 m
.22805 .60471 L
s
.22828 .60469 m
.22821 .60479 L
s
.22799 .60434 m
.22821 .60479 L
s
1 .344 0 r
.44452 .39512 m
.44622 .39749 L
s
.44275 .396 m
.44452 .39512 L
s
.44452 .39512 m
.44609 .39525 L
s
1 .019 0 r
.22817 .6046 m
.22805 .60471 L
s
.22828 .60469 m
.22817 .6046 L
s
1 .039 0 r
.17959 .27906 m
.1798 .27929 L
s
.17934 .27917 m
.17959 .27906 L
s
.17959 .27906 m
.17966 .27903 L
s
1 .65 0 r
.47637 .28418 m
.4745 .27895 L
s
1 .019 0 r
.22805 .60471 m
.22816 .60479 L
s
.22816 .60479 m
.22828 .60469 L
s
1 .039 0 r
.1798 .27929 m
.17955 .27941 L
s
.17966 .27903 m
.1798 .27929 L
s
.17955 .27941 m
.17934 .27917 L
s
.17934 .27917 m
.17966 .27903 L
s
1 .344 0 r
.44622 .39749 m
.44444 .39837 L
s
.44609 .39525 m
.44622 .39749 L
s
1 .039 0 r
.17966 .27903 m
.17955 .27941 L
s
0 1 .566 r
.58605 .39744 m
.57914 .40106 L
s
.57873 .37684 m
.58605 .39744 L
s
.59832 .38238 m
.58605 .39744 L
s
.808 1 0 r
.49704 .70218 m
.50115 .69295 L
s
1 .607 0 r
.58828 .30866 m
.58345 .31049 L
s
.58451 .30541 m
.58828 .30866 L
s
.56384 .30388 m
.58828 .30866 L
s
1 .525 0 r
.40992 .66364 m
.40756 .66425 L
s
.40775 .65888 m
.40992 .66364 L
s
.40992 .66364 m
.40493 .66237 L
s
.41038 .66075 m
.40992 .66364 L
s
.39853 .65317 m
.40992 .66364 L
s
1 .1 0 r
.69515 .36777 m
.69482 .36776 L
s
.69476 .36683 m
.69515 .36777 L
s
.69515 .36777 m
.69425 .36748 L
s
.69533 .36712 m
.69515 .36777 L
s
.69336 .36542 m
.69515 .36777 L
s
1 .09 0 r
.33561 .60444 m
.33535 .60448 L
s
.3354 .60358 m
.33561 .60444 L
s
.33561 .60444 m
.33486 .6041 L
s
.33589 .60396 m
.33561 .60444 L
s
.33443 .6024 m
.33561 .60444 L
s
1 .003 0 r
.82257 .42689 m
.82257 .42689 L
s
.82257 .42686 m
.82257 .42689 L
s
.82257 .42689 m
.82256 .42687 L
s
.82259 .42687 m
.82257 .42689 L
s
.82257 .42682 m
.82257 .42689 L
s
.82257 .42686 m
.82256 .42687 L
s
.82259 .42687 m
.82257 .42686 L
s
.808 1 0 r
.57904 .69316 m
.56906 .69949 L
s
.56885 .68956 m
.57904 .69316 L
s
1 .003 0 r
.82256 .42687 m
.82257 .42689 L
s
.82257 .42689 m
.82259 .42687 L
s
1 .021 0 r
.76136 .57475 m
.76156 .57426 L
s
1 .001 0 r
.28919 .45641 m
.2892 .45638 L
s
1 .172 0 r
.3504 .30847 m
.35422 .30456 L
s
1 .001 0 r
.2892 .45638 m
.2892 .45639 L
s
.28919 .45639 m
.2892 .45638 L
s
.2892 .45638 m
.2892 .45638 L
s
.2892 .45639 m
.28919 .45639 L
s
.2892 .45638 m
.2892 .45639 L
s
.28919 .45639 m
.28919 .45639 L
s
.28919 .45639 m
.2892 .45638 L
s
.2892 .45638 m
.28919 .45639 L
s
1 .1 0 r
.69476 .36683 m
.69425 .36748 L
s
.69533 .36712 m
.69476 .36683 L
s
1 .09 0 r
.3354 .60358 m
.33486 .6041 L
s
.33589 .60396 m
.3354 .60358 L
s
.717 1 0 r
.45515 .6634 m
.46175 .66801 L
s
1 .1 0 r
.69425 .36748 m
.69482 .36776 L
s
.939 1 0 r
.51915 .33785 m
.51128 .3455 L
s
.50823 .33697 m
.51915 .33785 L
s
1 .09 0 r
.33486 .6041 m
.33535 .60448 L
s
1 .021 0 r
.76151 .57425 m
.76164 .57437 L
s
.7614 .57435 m
.76151 .57425 L
s
.76151 .57425 m
.76156 .57426 L
s
.76164 .57437 m
.76153 .57446 L
s
.76156 .57426 m
.76164 .57437 L
s
1 .09 0 r
.33535 .60448 m
.33589 .60396 L
s
1 .021 0 r
.76153 .57446 m
.7614 .57435 L
s
.7614 .57435 m
.76156 .57426 L
s
.939 1 0 r
.51128 .3455 m
.50823 .33697 L
s
1 .021 0 r
.76156 .57426 m
.76153 .57446 L
s
1 .1 0 r
.69482 .36776 m
.69533 .36712 L
s
1 .02 0 r
.75818 .39663 m
.75815 .39663 L
s
.75814 .39644 m
.75818 .39663 L
s
.75818 .39663 m
.75803 .39656 L
s
.75826 .39651 m
.75818 .39663 L
s
.758 .39614 m
.75818 .39663 L
s
1 .162 0 r
.65629 .57296 m
.65724 .57393 L
s
.6554 .57361 m
.65629 .57296 L
s
.65629 .57296 m
.65677 .57303 L
s
1 .02 0 r
.75814 .39644 m
.75803 .39656 L
s
.75826 .39651 m
.75814 .39644 L
s
.75803 .39656 m
.75815 .39663 L
s
.75815 .39663 m
.75826 .39651 L
s
1 .525 0 r
.40775 .65888 m
.40493 .66237 L
s
.41038 .66075 m
.40775 .65888 L
s
1 .162 0 r
.65724 .57393 m
.65635 .57458 L
s
.65677 .57303 m
.65724 .57393 L
s
1 .004 0 r
.1631 .57387 m
.16309 .57387 L
s
.1631 .57383 m
.1631 .57387 L
s
.1631 .57387 m
.16307 .57385 L
s
.16312 .57385 m
.1631 .57387 L
s
.16307 .57377 m
.1631 .57387 L
s
0 1 .511 r
.58298 .69228 m
.58784 .69767 L
s
.58736 .67169 m
.58298 .69228 L
s
.60785 .68782 m
.58298 .69228 L
s
1 .004 0 r
.1631 .57383 m
.16307 .57385 L
s
.16312 .57385 m
.1631 .57383 L
s
.16307 .57385 m
.16309 .57387 L
s
.16309 .57387 m
.16312 .57385 L
s
1 .006 0 r
.93298 .60337 m
.93305 .60323 L
s
1 .575 0 r
.63551 .69219 m
.65289 .68283 L
s
1 .024 0 r
.69676 .54416 m
.69691 .54359 L
s
1 0 0 r
.46053 .48495 m
.46053 .48495 L
s
1 .825 0 r
.52178 .33693 m
.55659 .33619 L
s
1 .003 0 r
.22431 .42574 m
.22432 .42568 L
s
1 .104 0 r
.28555 .27772 m
.28748 .2752 L
s
1 .003 0 r
.22432 .42568 m
.22433 .42569 L
s
.2243 .42569 m
.22432 .42568 L
s
.22432 .42568 m
.22432 .42568 L
s
.22433 .42569 m
.22431 .4257 L
s
.22432 .42568 m
.22433 .42569 L
s
.22431 .4257 m
.2243 .42569 L
s
.2243 .42569 m
.22432 .42568 L
s
.22432 .42568 m
.22431 .4257 L
s
1 .006 0 r
.93303 .60323 m
.93307 .60326 L
s
.933 .60326 m
.93303 .60323 L
s
.93303 .60323 m
.93305 .60323 L
s
0 1 .566 r
.57175 .38029 m
.57873 .37684 L
s
.57873 .37684 m
.59832 .38238 L
s
1 .006 0 r
.93307 .60326 m
.93304 .60329 L
s
.93305 .60323 m
.93307 .60326 L
s
.93304 .60329 m
.933 .60326 L
s
.933 .60326 m
.93305 .60323 L
s
1 .344 0 r
.44444 .39837 m
.44275 .396 L
s
.44275 .396 m
.44609 .39525 L
s
1 .006 0 r
.93305 .60323 m
.93304 .60329 L
s
1 .162 0 r
.65635 .57458 m
.6554 .57361 L
s
.6554 .57361 m
.65677 .57303 L
s
1 .525 0 r
.40493 .66237 m
.40756 .66425 L
s
1 .318 0 r
.36366 .69195 m
.36218 .69236 L
s
.36233 .68907 m
.36366 .69195 L
s
.36366 .69195 m
.36062 .69119 L
s
.36389 .69023 m
.36366 .69195 L
s
.35659 .68574 m
.36366 .69195 L
s
1 .344 0 r
.44609 .39525 m
.44444 .39837 L
s
.285 1 0 r
.43989 .60303 m
.44342 .60396 L
s
.44384 .58668 m
.43989 .60303 L
s
.43989 .60303 m
.43358 .59364 L
s
.45366 .59694 m
.43989 .60303 L
s
.45895 .56361 m
.43989 .60303 L
s
1 .024 0 r
.69687 .54359 m
.69702 .54371 L
s
.69674 .5437 m
.69687 .54359 L
s
.69687 .54359 m
.69691 .54359 L
s
1 .162 0 r
.65677 .57303 m
.65635 .57458 L
s
1 .024 0 r
.69702 .54371 m
.69688 .54382 L
s
.69691 .54359 m
.69702 .54371 L
s
.69688 .54382 m
.69674 .5437 L
s
.69674 .5437 m
.69691 .54359 L
s
.69691 .54359 m
.69688 .54382 L
s
1 .825 0 r
.55659 .33619 m
.54966 .34016 L
s
.54951 .33312 m
.55659 .33619 L
s
1 .606 0 r
.56312 .42503 m
.56424 .42576 L
s
.56417 .41998 m
.56312 .42503 L
s
.5691 .42377 m
.56312 .42503 L
s
1 .318 0 r
.36233 .68907 m
.36062 .69119 L
s
.36389 .69023 m
.36233 .68907 L
s
1 .417 0 r
.61711 .2766 m
.61841 .27701 L
s
.6183 .27322 m
.61711 .2766 L
s
.62142 .27621 m
.61711 .2766 L
s
1 .005 0 r
.86844 .57278 m
.86849 .57265 L
s
.717 1 0 r
.5708 .66165 m
.61928 .64772 L
s
1 .021 0 r
.63208 .51353 m
.63208 .51302 L
s
1 .008 0 r
.39571 .45429 m
.3958 .45408 L
s
1 .525 0 r
.45699 .30618 m
.47631 .29922 L
s
1 .004 0 r
.15935 .39504 m
.15936 .39494 L
s
.15936 .39495 m
.15938 .39497 L
s
.15933 .39496 m
.15936 .39495 L
s
.15936 .39495 m
.15936 .39494 L
s
.15938 .39497 m
.15936 .39498 L
s
.15936 .39494 m
.15938 .39497 L
s
.15936 .39498 m
.15933 .39496 L
s
.15933 .39496 m
.15936 .39494 L
s
1 .318 0 r
.36062 .69119 m
.36218 .69236 L
s
1 .004 0 r
.15936 .39494 m
.15936 .39498 L
s
1 .22 0 r
.67688 .30608 m
.67575 .30619 L
s
.67565 .30417 m
.67688 .30608 L
s
.67688 .30608 m
.67467 .30577 L
s
.67672 .30459 m
.67688 .30608 L
s
.67094 .30157 m
.67688 .30608 L
s
1 .005 0 r
.86848 .57265 m
.86851 .57268 L
s
.86845 .57268 m
.86848 .57265 L
s
.86848 .57265 m
.86849 .57265 L
s
.86851 .57268 m
.86848 .5727 L
s
.86849 .57265 m
.86851 .57268 L
s
.86848 .5727 m
.86845 .57268 L
s
.86845 .57268 m
.86849 .57265 L
s
.86849 .57265 m
.86848 .5727 L
s
1 .008 0 r
.39578 .45409 m
.39583 .45413 L
s
.39573 .45412 m
.39578 .45409 L
s
.39578 .45409 m
.3958 .45408 L
s
1 .606 0 r
.5653 .4207 m
.56417 .41998 L
s
.56417 .41998 m
.5691 .42377 L
s
1 .008 0 r
.39583 .45413 m
.39578 .45416 L
s
.3958 .45408 m
.39583 .45413 L
s
.39578 .45416 m
.39573 .45412 L
s
.39573 .45412 m
.3958 .45408 L
s
.3958 .45408 m
.39578 .45416 L
s
1 .417 0 r
.61961 .27363 m
.6183 .27322 L
s
.6183 .27322 m
.62142 .27621 L
s
1 .607 0 r
.58345 .31049 m
.58451 .30541 L
s
1 .172 0 r
.3535 .30456 m
.35434 .30574 L
s
.35257 .30495 m
.3535 .30456 L
s
.3535 .30456 m
.35422 .30456 L
s
1 .417 0 r
.62142 .27621 m
.61841 .27701 L
s
.61961 .27363 m
.62142 .27621 L
s
.60606 .27071 m
.62142 .27621 L
s
1 .22 0 r
.67565 .30417 m
.67467 .30577 L
s
.67672 .30459 m
.67565 .30417 L
s
1 .021 0 r
.63208 .51302 m
.63221 .51312 L
s
.63196 .51313 m
.63208 .51302 L
s
.63208 .51302 m
.63208 .51302 L
s
1 .22 0 r
.67467 .30577 m
.67575 .30619 L
s
1 .111 0 r
.37724 .57242 m
.377 .57245 L
s
.37705 .57134 m
.37724 .57242 L
s
.37724 .57242 m
.37637 .57196 L
s
.37768 .57183 m
.37724 .57242 L
s
.37619 .56981 m
.37724 .57242 L
s
1 .172 0 r
.35434 .30574 m
.35341 .30613 L
s
.35422 .30456 m
.35434 .30574 L
s
1 .021 0 r
.63208 .51323 m
.63196 .51313 L
s
.63196 .51313 m
.63208 .51302 L
s
.63221 .51312 m
.63208 .51323 L
s
.63208 .51302 m
.63221 .51312 L
s
.63208 .51302 m
.63208 .51323 L
s
1 .104 0 r
.28713 .27523 m
.28766 .27591 L
s
.28653 .27549 m
.28713 .27523 L
s
.28713 .27523 m
.28748 .2752 L
s
.28766 .27591 m
.28706 .27617 L
s
.28748 .2752 m
.28766 .27591 L
s
1 .111 0 r
.37705 .57134 m
.37637 .57196 L
s
.37768 .57183 m
.37705 .57134 L
s
1 .016 0 r
.26964 .57217 m
.2696 .57217 L
s
.26961 .57201 m
.26964 .57217 L
s
.26964 .57217 m
.26951 .5721 L
s
.2697 .57209 m
.26964 .57217 L
s
.2695 .57179 m
.26964 .57217 L
s
.26961 .57201 m
.26951 .5721 L
s
.2697 .57209 m
.26961 .57201 L
s
.26951 .5721 m
.2696 .57217 L
s
.2696 .57217 m
.2697 .57209 L
s
.808 1 0 r
.56906 .69949 m
.56885 .68956 L
s
1 .111 0 r
.37637 .57196 m
.377 .57245 L
s
1 .606 0 r
.5691 .42377 m
.56424 .42576 L
s
.5653 .4207 m
.5691 .42377 L
s
.54459 .41926 m
.5691 .42377 L
s
1 .59 0 r
.62431 .59716 m
.62725 .60127 L
s
.62154 .59899 m
.62431 .59716 L
s
.62431 .59716 m
.6274 .59785 L
s
1 .787 0 r
.5054 .36447 m
.50308 .36549 L
s
.50313 .35813 m
.5054 .36447 L
s
.50895 .35978 m
.5054 .36447 L
s
0 1 .511 r
.59227 .67691 m
.58736 .67169 L
s
.58736 .67169 m
.60785 .68782 L
s
1 .005 0 r
.86517 .39408 m
.86516 .39407 L
s
.86516 .39403 m
.86517 .39408 L
s
.86517 .39408 m
.86513 .39405 L
s
.86519 .39405 m
.86517 .39408 L
s
.86514 .39395 m
.86517 .39408 L
s
1 .336 0 r
.42268 .33228 m
.42416 .33473 L
s
.4211 .33294 m
.42268 .33228 L
s
.42268 .33228 m
.4245 .33249 L
s
1 .005 0 r
.86516 .39403 m
.86513 .39405 L
s
.86519 .39405 m
.86516 .39403 L
s
.86513 .39405 m
.86516 .39407 L
s
.86516 .39407 m
.86519 .39405 L
s
1 .104 0 r
.28706 .27617 m
.28653 .27549 L
s
.28653 .27549 m
.28748 .2752 L
s
1 .336 0 r
.42416 .33473 m
.42258 .33539 L
s
.4245 .33249 m
.42416 .33473 L
s
.787 1 0 r
.44585 .57185 m
.44837 .57234 L
s
.44865 .56022 m
.44585 .57185 L
s
.44585 .57185 m
.44141 .56508 L
s
.45561 .56746 m
.44585 .57185 L
s
.45935 .54359 m
.44585 .57185 L
s
1 .525 0 r
.40756 .66425 m
.41038 .66075 L
s
1 .111 0 r
.377 .57245 m
.37768 .57183 L
s
0 1 .077 r
.43544 .6311 m
.43969 .63247 L
s
.44022 .61133 m
.43544 .6311 L
s
.43544 .6311 m
.42775 .6199 L
s
.45213 .62384 m
.43544 .6311 L
s
.45854 .58388 m
.43544 .6311 L
s
1 .104 0 r
.28748 .2752 m
.28706 .27617 L
s
1 .168 0 r
.74251 .69035 m
.74596 .68695 L
s
1 .004 0 r
.80383 .54215 m
.80385 .54206 L
s
1 0 0 r
.56732 .48287 m
.56732 .48287 L
s
1 .013 0 r
.33082 .42359 m
.33093 .42327 L
s
1 .293 0 r
.39213 .27539 m
.4009 .2698 L
s
1 .005 0 r
.09431 .36431 m
.09432 .36419 L
s
1 .004 0 r
.80384 .54206 m
.80387 .54208 L
s
.80382 .54208 m
.80384 .54206 L
s
.80384 .54206 m
.80385 .54206 L
s
1 .172 0 r
.35341 .30613 m
.35257 .30495 L
s
.35257 .30495 m
.35422 .30456 L
s
1 .004 0 r
.80387 .54208 m
.80385 .54209 L
s
.80385 .54206 m
.80387 .54208 L
s
.80385 .54209 m
.80382 .54208 L
s
.80382 .54208 m
.80385 .54206 L
s
1 .005 0 r
.09432 .36419 m
.09435 .36421 L
s
.09429 .36421 m
.09432 .36419 L
s
.09432 .36419 m
.09432 .36419 L
s
.542 1 0 r
.47053 .69028 m
.4643 .69213 L
s
.46457 .67704 m
.47053 .69028 L
s
.47053 .69028 m
.45676 .68678 L
s
.47213 .68235 m
.47053 .69028 L
s
.4396 .6613 m
.47053 .69028 L
s
1 .004 0 r
.80385 .54206 m
.80385 .54209 L
s
1 .005 0 r
.09435 .36421 m
.09432 .36423 L
s
.09432 .36419 m
.09435 .36421 L
s
.09432 .36423 m
.09429 .36421 L
s
.09429 .36421 m
.09432 .36419 L
s
.09432 .36419 m
.09432 .36423 L
s
1 .318 0 r
.36218 .69236 m
.36389 .69023 L
s
1 .172 0 r
.35422 .30456 m
.35341 .30613 L
s
1 .59 0 r
.62725 .60127 m
.62448 .6031 L
s
.6274 .59785 m
.62725 .60127 L
s
1 .013 0 r
.33091 .42327 m
.33099 .42335 L
s
.33084 .42332 m
.33091 .42327 L
s
.33091 .42327 m
.33093 .42327 L
s
.33099 .42335 m
.33091 .42339 L
s
.33093 .42327 m
.33099 .42335 L
s
.33091 .42339 m
.33084 .42332 L
s
.33084 .42332 m
.33093 .42327 L
s
1 .787 0 r
.50081 .35914 m
.50313 .35813 L
s
.50313 .35813 m
.50895 .35978 L
s
1 .013 0 r
.33093 .42327 m
.33091 .42339 L
s
1 .08 0 r
.73715 .33432 m
.73689 .3343 L
s
.73684 .33356 m
.73715 .33432 L
s
.73715 .33432 m
.73643 .33408 L
s
.73731 .33378 m
.73715 .33432 L
s
.73575 .3324 m
.73715 .33432 L
s
1 .22 0 r
.67575 .30619 m
.67672 .30459 L
s
1 .08 0 r
.73684 .33356 m
.73643 .33408 L
s
.73731 .33378 m
.73684 .33356 L
s
1 .022 0 r
.80071 .36376 m
.80068 .36375 L
s
.80066 .36354 m
.80071 .36376 L
s
.80071 .36376 m
.80053 .36367 L
s
.8008 .36362 m
.80071 .36376 L
s
.80049 .36319 m
.80071 .36376 L
s
1 .08 0 r
.73643 .33408 m
.73689 .3343 L
s
1 .022 0 r
.80066 .36354 m
.80053 .36367 L
s
.8008 .36362 m
.80066 .36354 L
s
.80053 .36367 m
.80068 .36375 L
s
1 .825 0 r
.54966 .34016 m
.54951 .33312 L
s
1 .022 0 r
.80068 .36375 m
.8008 .36362 L
s
.425 1 0 r
.55386 .42283 m
.54946 .42518 L
s
.54935 .41017 m
.55386 .42283 L
s
.56122 .41372 m
.55386 .42283 L
s
1 .08 0 r
.73689 .3343 m
.73731 .33378 L
s
1 .091 0 r
.25133 .6895 m
.25097 .68958 L
s
.25104 .68864 m
.25133 .6895 L
s
.25133 .6895 m
.2505 .68921 L
s
.25151 .68902 m
.25133 .6895 L
s
.24973 .68759 m
.25133 .6895 L
s
1 .002 0 r
.2045 .54119 m
.2045 .54119 L
s
.2045 .54117 m
.2045 .54119 L
s
.2045 .54119 m
.20448 .54118 L
s
.20451 .54118 m
.2045 .54119 L
s
.20449 .54114 m
.2045 .54119 L
s
.2045 .54117 m
.20448 .54118 L
s
.20451 .54118 m
.2045 .54117 L
s
.20448 .54118 m
.2045 .54119 L
s
.2045 .54119 m
.20451 .54118 L
s
1 .323 0 r
.67778 .65977 m
.68483 .65327 L
s
1 .001 0 r
.73914 .51148 m
.73914 .51145 L
s
1 .398 0 r
.50249 .45217 m
.51728 .44729 L
s
1 .013 0 r
.26584 .39285 m
.26595 .39251 L
s
1 .001 0 r
.73914 .51145 m
.73915 .51145 L
s
.73913 .51145 m
.73914 .51145 L
s
.73914 .51145 m
.73914 .51145 L
s
.73914 .51146 m
.73913 .51145 L
s
.73913 .51145 m
.73914 .51145 L
s
.73915 .51145 m
.73914 .51146 L
s
.73914 .51145 m
.73915 .51145 L
s
.73914 .51145 m
.73914 .51146 L
s
.425 1 0 r
.60663 .54104 m
.59493 .55248 L
s
.59043 .53988 m
.60663 .54104 L
s
1 .091 0 r
.25104 .68864 m
.2505 .68921 L
s
.25151 .68902 m
.25104 .68864 L
s
.939 1 0 r
.6103 .62994 m
.60242 .63765 L
s
.59939 .62919 m
.6103 .62994 L
s
1 .013 0 r
.26594 .39252 m
.26601 .39259 L
s
.26585 .39257 m
.26594 .39252 L
s
.26594 .39252 m
.26595 .39251 L
s
.26601 .39259 m
.26592 .39264 L
s
.26595 .39251 m
.26601 .39259 L
s
1 .091 0 r
.2505 .68921 m
.25097 .68958 L
s
1 .013 0 r
.26592 .39264 m
.26585 .39257 L
s
.26585 .39257 m
.26595 .39251 L
s
.26595 .39251 m
.26592 .39264 L
s
1 .417 0 r
.61841 .27701 m
.61961 .27363 L
s
.717 1 0 r
.46175 .66801 m
.46861 .65946 L
s
.939 1 0 r
.60242 .63765 m
.59939 .62919 L
s
1 .091 0 r
.25097 .68958 m
.25151 .68902 L
s
.425 1 0 r
.59493 .55248 m
.59043 .53988 L
s
.54491 .41246 m
.54935 .41017 L
s
.54935 .41017 m
.56122 .41372 L
s
1 .336 0 r
.42258 .33539 m
.4211 .33294 L
s
.4211 .33294 m
.4245 .33249 L
s
.4245 .33249 m
.42258 .33539 L
s
1 .136 0 r
.41849 .5404 m
.41839 .54041 L
s
.41843 .53907 m
.41849 .5404 L
s
.41849 .5404 m
.41759 .53976 L
s
.41923 .53972 m
.41849 .5404 L
s
.41809 .53709 m
.41849 .5404 L
s
.285 1 0 r
.44384 .58668 m
.43358 .59364 L
s
.45366 .59694 m
.44384 .58668 L
s
0 .434 1 r
.63513 .33244 m
.60864 .35825 L
s
.59845 .32947 m
.63513 .33244 L
s
1 .575 0 r
.51875 .27308 m
.51814 .2734 L
s
.51815 .26818 m
.51875 .27308 L
s
.52294 .27022 m
.51875 .27308 L
s
1 0 0 r
.1394 .51046 m
.1394 .51046 L
s
.1394 .51046 m
.1394 .51046 L
s
.1394 .51046 m
.1394 .51046 L
s
.1394 .51046 m
.1394 .51046 L
s
.1394 .51045 m
.1394 .51046 L
s
.1394 .51046 m
.1394 .51046 L
s
.1394 .51046 m
.1394 .51046 L
s
.1394 .51046 m
.1394 .51046 L
s
.1394 .51046 m
.1394 .51046 L
s
1 .055 0 r
.84976 .68851 m
.85068 .68733 L
s
1 .001 0 r
.91115 .54013 m
.91116 .5401 L
s
1 .825 0 r
.61298 .62916 m
.63405 .6134 L
s
1 0 0 r
.67437 .48078 m
.67437 .48078 L
s
1 .136 0 r
.43758 .42143 m
.44073 .41852 L
s
1 .575 0 r
.49897 .27305 m
.52294 .27022 L
s
1 .013 0 r
.20079 .36208 m
.20088 .36175 L
s
1 .001 0 r
.91116 .5401 m
.91117 .54011 L
s
.91115 .54011 m
.91116 .5401 L
s
.91116 .5401 m
.91116 .5401 L
s
.91117 .54011 m
.91116 .54011 L
s
.91116 .5401 m
.91117 .54011 L
s
.91116 .54011 m
.91115 .54011 L
s
.91115 .54011 m
.91116 .5401 L
s
.91116 .5401 m
.91116 .54011 L
s
1 .136 0 r
.41843 .53907 m
.41759 .53976 L
s
.41923 .53972 m
.41843 .53907 L
s
1 .606 0 r
.56424 .42576 m
.5653 .4207 L
s
1 .013 0 r
.20087 .36175 m
.20094 .36183 L
s
.20079 .3618 m
.20087 .36175 L
s
.20087 .36175 m
.20088 .36175 L
s
1 .344 0 r
.59503 .39151 m
.5963 .39207 L
s
.59623 .38882 m
.59503 .39151 L
s
.59862 .39149 m
.59503 .39151 L
s
1 .013 0 r
.20094 .36183 m
.20086 .36187 L
s
.20088 .36175 m
.20094 .36183 L
s
1 .525 0 r
.474 .30245 m
.4724 .30303 L
s
.47248 .29821 m
.474 .30245 L
s
.47631 .29922 m
.474 .30245 L
s
1 .344 0 r
.59862 .39149 m
.5963 .39207 L
s
.59623 .38882 m
.59862 .39149 L
s
.5975 .38937 m
.59862 .39149 L
s
.58685 .38624 m
.59862 .39149 L
s
1 .013 0 r
.20086 .36187 m
.20079 .3618 L
s
.20079 .3618 m
.20088 .36175 L
s
.20088 .36175 m
.20086 .36187 L
s
1 .344 0 r
.5975 .38937 m
.59623 .38882 L
s
1 .032 0 r
.61012 .45076 m
.61001 .45076 L
s
.61 .45046 m
.61012 .45076 L
s
.61012 .45076 m
.60983 .45067 L
s
.61017 .45056 m
.61012 .45076 L
s
.60952 .45004 m
.61012 .45076 L
s
1 .136 0 r
.41759 .53976 m
.41839 .54041 L
s
1 .032 0 r
.61 .45046 m
.60983 .45067 L
s
.61017 .45056 m
.61 .45046 L
s
1 .136 0 r
.41839 .54041 m
.41923 .53972 L
s
1 .032 0 r
.60983 .45067 m
.61001 .45076 L
s
1 .575 0 r
.51753 .26849 m
.51815 .26818 L
s
.51815 .26818 m
.52294 .27022 L
s
.787 1 0 r
.44865 .56022 m
.44141 .56508 L
s
.45561 .56746 m
.44865 .56022 L
s
1 .59 0 r
.62448 .6031 m
.62154 .59899 L
s
.62154 .59899 m
.6274 .59785 L
s
1 .525 0 r
.47087 .29878 m
.47248 .29821 L
s
.47248 .29821 m
.47631 .29922 L
s
1 .032 0 r
.61001 .45076 m
.61017 .45056 L
s
1 .168 0 r
.74522 .68677 m
.74616 .68786 L
s
.74438 .68741 m
.74522 .68677 L
s
.74522 .68677 m
.74596 .68695 L
s
.542 1 0 r
.46457 .67704 m
.45676 .68678 L
s
.47213 .68235 m
.46457 .67704 L
s
1 .168 0 r
.74616 .68786 m
.74533 .6885 L
s
.74596 .68695 m
.74616 .68786 L
s
0 1 .511 r
.60785 .68782 m
.58784 .69767 L
s
.59227 .67691 m
.60785 .68782 L
s
.50577 .67174 m
.60785 .68782 L
s
1 .01 0 r
.31121 .53937 m
.31119 .53937 L
s
.3112 .53927 m
.31121 .53937 L
s
.31121 .53937 m
.31114 .53932 L
s
.31126 .53932 m
.31121 .53937 L
s
.31116 .53912 m
.31121 .53937 L
s
.3112 .53927 m
.31114 .53932 L
s
.31126 .53932 m
.3112 .53927 L
s
0 .434 1 r
.60864 .35825 m
.59845 .32947 L
s
1 .01 0 r
.31114 .53932 m
.31119 .53937 L
s
.31119 .53937 m
.31126 .53932 L
s
1 .59 0 r
.6274 .59785 m
.62448 .6031 L
s
1 .055 0 r
.85047 .68729 m
.8508 .68762 L
s
.85018 .68752 m
.85047 .68729 L
s
.85047 .68729 m
.85068 .68733 L
s
.8508 .68762 m
.85052 .68785 L
s
.85068 .68733 m
.8508 .68762 L
s
1 .081 0 r
.78502 .65789 m
.78629 .65613 L
s
1 0 0 r
.84645 .50942 m
.84645 .50942 L
s
0 .813 1 r
.54809 .59851 m
.66993 .56195 L
s
1 .07 0 r
.37259 .39065 m
.37384 .38901 L
s
1 .012 0 r
.13566 .33126 m
.13574 .33095 L
s
1 0 0 r
.84645 .50942 m
.84645 .50942 L
s
.84645 .50942 m
.84645 .50942 L
s
.84645 .50942 m
.84645 .50942 L
s
.84645 .50942 m
.84645 .50942 L
s
.84645 .50942 m
.84645 .50942 L
s
.84645 .50942 m
.84645 .50942 L
s
.84645 .50942 m
.84645 .50942 L
s
.84645 .50942 m
.84645 .50942 L
s
1 .158 0 r
.71736 .2718 m
.71662 .27183 L
s
.71652 .2704 m
.71736 .2718 L
s
.71736 .2718 m
.71579 .27152 L
s
.71735 .27071 m
.71736 .2718 L
s
.7134 .26836 m
.71736 .2718 L
s
0 1 .331 r
.58166 .67531 m
.58574 .65612 L
s
1 .055 0 r
.85052 .68785 m
.85018 .68752 L
s
.85018 .68752 m
.85068 .68733 L
s
1 .293 0 r
.4004 .27179 m
.39909 .27225 L
s
.3992 .26959 m
.4004 .27179 L
s
.4009 .2698 m
.4004 .27179 L
s
.39789 .27005 m
.3992 .26959 L
s
.3992 .26959 m
.4009 .2698 L
s
1 .055 0 r
.85068 .68733 m
.85052 .68785 L
s
1 .168 0 r
.74533 .6885 m
.74438 .68741 L
s
.74438 .68741 m
.74596 .68695 L
s
1 .012 0 r
.13573 .33096 m
.13579 .33103 L
s
.13565 .331 m
.13573 .33096 L
s
.13573 .33096 m
.13574 .33095 L
s
1 .034 0 r
.18507 .6577 m
.18495 .65772 L
s
.18499 .65738 m
.18507 .6577 L
s
.18507 .6577 m
.18478 .65757 L
s
.18517 .65753 m
.18507 .6577 L
s
.18459 .65695 m
.18507 .6577 L
s
1 .012 0 r
.13579 .33103 m
.13571 .33107 L
s
.13574 .33095 m
.13579 .33103 L
s
.13571 .33107 m
.13565 .331 L
s
.13565 .331 m
.13574 .33095 L
s
.13574 .33095 m
.13571 .33107 L
s
1 .158 0 r
.71652 .2704 m
.71579 .27152 L
s
.71735 .27071 m
.71652 .2704 L
s
1 .034 0 r
.18499 .65738 m
.18478 .65757 L
s
.18517 .65753 m
.18499 .65738 L
s
1 .158 0 r
.71579 .27152 m
.71662 .27183 L
s
1 .034 0 r
.18478 .65757 m
.18495 .65772 L
s
1 .168 0 r
.74596 .68695 m
.74533 .6885 L
s
1 .114 0 r
.29322 .65754 m
.29283 .65763 L
s
.29291 .65646 m
.29322 .65754 L
s
.29322 .65754 m
.29222 .65715 L
s
.29351 .65694 m
.29322 .65754 L
s
.29144 .65506 m
.29322 .65754 L
s
1 .034 0 r
.18495 .65772 m
.18517 .65753 L
s
1 .398 0 r
.51547 .44955 m
.51431 .45018 L
s
.51432 .44635 m
.51547 .44955 L
s
.51728 .44729 m
.51547 .44955 L
s
1 .023 0 r
.84337 .33073 m
.84333 .33072 L
s
.84331 .3305 m
.84337 .33073 L
s
.84337 .33073 m
.84318 .33064 L
s
.84346 .33058 m
.84337 .33073 L
s
.84313 .33013 m
.84337 .33073 L
s
.84331 .3305 m
.84318 .33064 L
s
.84346 .33058 m
.84331 .3305 L
s
.84318 .33064 m
.84333 .33072 L
s
1 .066 0 r
.77943 .30089 m
.77923 .30087 L
s
.77918 .30026 m
.77943 .30089 L
s
.77943 .30089 m
.77884 .30069 L
s
.77958 .30044 m
.77943 .30089 L
s
.7783 .29926 m
.77943 .30089 L
s
1 .023 0 r
.84333 .33072 m
.84346 .33058 L
s
1 .114 0 r
.29291 .65646 m
.29222 .65715 L
s
.29351 .65694 m
.29291 .65646 L
s
1 .398 0 r
.51316 .44698 m
.51432 .44635 L
s
.51432 .44635 m
.51728 .44729 L
s
1 .066 0 r
.77918 .30026 m
.77884 .30069 L
s
.77958 .30044 m
.77918 .30026 L
s
.77884 .30069 m
.77923 .30087 L
s
1 .114 0 r
.29222 .65715 m
.29283 .65763 L
s
1 .136 0 r
.44012 .41846 m
.44078 .4194 L
s
.43941 .41882 m
.44012 .41846 L
s
.44012 .41846 m
.44073 .41852 L
s
.542 1 0 r
.45676 .68678 m
.4643 .69213 L
s
1 .136 0 r
.44078 .4194 m
.44008 .41975 L
s
.44073 .41852 m
.44078 .4194 L
s
1 .066 0 r
.77923 .30087 m
.77958 .30044 L
s
1 .606 0 r
.45298 .53812 m
.45426 .53828 L
s
.45439 .53228 m
.45298 .53812 L
s
.45298 .53812 m
.45078 .53467 L
s
.45787 .53588 m
.45298 .53812 L
s
.45975 .52381 m
.45298 .53812 L
s
1 0 0 r
.24606 .50841 m
.24606 .50841 L
s
.24606 .5084 m
.24606 .50841 L
s
.24606 .50841 m
.24606 .5084 L
s
.24606 .5084 m
.24606 .50841 L
s
.24606 .50839 m
.24606 .50841 L
s
.24606 .5084 m
.24606 .5084 L
s
.24606 .5084 m
.24606 .5084 L
s
.24606 .50841 m
.24606 .5084 L
s
.24606 .5084 m
.24606 .50841 L
s
1 .158 0 r
.71662 .27183 m
.71735 .27071 L
s
1 .022 0 r
.95727 .68666 m
.9576 .68619 L
s
1 .137 0 r
.7202 .62724 m
.72224 .62419 L
s
1 0 0 r
.78167 .47868 m
.78167 .47868 L
s
1 .046 0 r
.30752 .35984 m
.3082 .35872 L
s
1 .011 0 r
.07045 .30042 m
.07051 .30012 L
s
1 .114 0 r
.29283 .65763 m
.29351 .65694 L
s
1 .07 0 r
.3736 .38901 m
.37397 .38946 L
s
.3732 .38921 m
.3736 .38901 L
s
.3736 .38901 m
.37384 .38901 L
s
1 .787 0 r
.50895 .35978 m
.50308 .36549 L
s
.50081 .35914 m
.50895 .35978 L
s
1 .344 0 r
.5963 .39207 m
.5975 .38937 L
s
1 .07 0 r
.37397 .38946 m
.37357 .38967 L
s
.37384 .38901 m
.37397 .38946 L
s
0 1 .331 r
.43215 .65686 m
.4369 .65867 L
s
.43752 .6347 m
.43215 .65686 L
s
.43215 .65686 m
.42346 .64445 L
s
.45093 .64882 m
.43215 .65686 L
s
.45813 .6044 m
.43215 .65686 L
s
1 .011 0 r
.07051 .30013 m
.07057 .30019 L
s
.07043 .30017 m
.07051 .30013 L
s
.07051 .30013 m
.07051 .30012 L
s
.07057 .30019 m
.07049 .30023 L
s
.07051 .30012 m
.07057 .30019 L
s
1 .65 0 r
.41194 .68646 m
.40901 .68728 L
s
.40924 .68055 m
.41194 .68646 L
s
.41194 .68646 m
.40573 .6849 L
s
.41251 .68292 m
.41194 .68646 L
s
.39777 .67362 m
.41194 .68646 L
s
1 .011 0 r
.07049 .30023 m
.07043 .30017 L
s
.07043 .30017 m
.07051 .30012 L
s
1 .787 0 r
.50308 .36549 m
.50081 .35914 L
s
1 .011 0 r
.07051 .30012 m
.07049 .30023 L
s
1 .081 0 r
.78601 .65607 m
.7865 .65656 L
s
.78558 .65641 m
.78601 .65607 L
s
.78601 .65607 m
.78629 .65613 L
s
1 .07 0 r
.37357 .38967 m
.3732 .38921 L
s
.3732 .38921 m
.37384 .38901 L
s
0 1 .077 r
.44022 .61133 m
.42775 .6199 L
s
.45213 .62384 m
.44022 .61133 L
s
1 .022 0 r
.95752 .68617 m
.95766 .6863 L
s
.95741 .68627 m
.95752 .68617 L
s
.95752 .68617 m
.9576 .68619 L
s
.787 1 0 r
.44837 .57234 m
.45561 .56746 L
s
1 .07 0 r
.37384 .38901 m
.37357 .38967 L
s
1 .022 0 r
.95766 .6863 m
.95755 .6864 L
s
.9576 .68619 m
.95766 .6863 L
s
1 .136 0 r
.44008 .41975 m
.43941 .41882 L
s
.43941 .41882 m
.44073 .41852 L
s
1 .575 0 r
.52294 .27022 m
.51814 .2734 L
s
.51753 .26849 m
.52294 .27022 L
s
1 .081 0 r
.7865 .65656 m
.78607 .6569 L
s
.78629 .65613 m
.7865 .65656 L
s
1 .022 0 r
.95755 .6864 m
.95741 .68627 L
s
.95741 .68627 m
.9576 .68619 L
s
.9576 .68619 m
.95755 .6864 L
s
1 .136 0 r
.44073 .41852 m
.44008 .41975 L
s
1 .293 0 r
.39909 .27225 m
.39789 .27005 L
s
.4009 .2698 m
.39909 .27225 L
s
.39789 .27005 m
.4009 .2698 L
s
1 .081 0 r
.78607 .6569 m
.78558 .65641 L
s
.78558 .65641 m
.78629 .65613 L
s
.285 1 0 r
.44342 .60396 m
.45366 .59694 L
s
1 .575 0 r
.64929 .68174 m
.65184 .68597 L
s
.64695 .68346 m
.64929 .68174 L
s
.64929 .68174 m
.65289 .68283 L
s
1 .046 0 r
.30808 .35873 m
.30832 .35902 L
s
.3078 .35887 m
.30808 .35873 L
s
.30808 .35873 m
.3082 .35872 L
s
1 .081 0 r
.78629 .65613 m
.78607 .6569 L
s
1 .046 0 r
.30832 .35902 m
.30805 .35916 L
s
.3082 .35872 m
.30832 .35902 L
s
1 .575 0 r
.65184 .68597 m
.64951 .68769 L
s
.65289 .68283 m
.65184 .68597 L
s
1 .046 0 r
.30805 .35916 m
.3078 .35887 L
s
.3078 .35887 m
.3082 .35872 L
s
.3082 .35872 m
.30805 .35916 L
s
1 .002 0 r
.71682 .44795 m
.71682 .44795 L
s
.71682 .44793 m
.71682 .44795 L
s
.71682 .44795 m
.71681 .44794 L
s
.71683 .44794 m
.71682 .44795 L
s
.7168 .44791 m
.71682 .44795 L
s
.71682 .44793 m
.71681 .44794 L
s
.71683 .44794 m
.71682 .44793 L
s
.71681 .44794 m
.71682 .44795 L
s
.71682 .44795 m
.71683 .44794 L
s
1 .026 0 r
.89252 .65601 m
.89288 .65542 L
s
1 .303 0 r
.6553 .59655 m
.65953 .58966 L
s
1 .481 0 r
.47959 .38845 m
.49743 .38233 L
s
1 0 0 r
.18088 .47763 m
.18088 .47763 L
s
1 .033 0 r
.24238 .32899 m
.2428 .32814 L
s
1 .047 0 r
.65274 .41817 m
.65257 .41818 L
s
.65256 .41773 m
.65274 .41817 L
s
.65274 .41817 m
.65231 .41804 L
s
.65282 .41787 m
.65274 .41817 L
s
.65187 .41709 m
.65274 .41817 L
s
1 .525 0 r
.47631 .29922 m
.4724 .30303 L
s
.47087 .29878 m
.47631 .29922 L
s
1 .047 0 r
.65256 .41773 m
.65231 .41804 L
s
.65282 .41787 m
.65256 .41773 L
s
.65231 .41804 m
.65257 .41818 L
s
1 .525 0 r
.4724 .30303 m
.47087 .29878 L
s
1 .606 0 r
.45439 .53228 m
.45078 .53467 L
s
.45787 .53588 m
.45439 .53228 L
s
1 .047 0 r
.65257 .41818 m
.65282 .41787 L
s
1 .117 0 r
.45884 .50705 m
.45909 .50707 L
s
.45911 .50592 m
.45884 .50705 L
s
.45884 .50705 m
.45842 .50638 L
s
.45978 .50661 m
.45884 .50705 L
s
.46014 .50426 m
.45884 .50705 L
s
1 .65 0 r
.40924 .68055 m
.40573 .6849 L
s
.41251 .68292 m
.40924 .68055 L
s
1 .575 0 r
.51814 .2734 m
.51753 .26849 L
s
1 .026 0 r
.89279 .6554 m
.89296 .65556 L
s
.89265 .65552 m
.89279 .6554 L
s
.89279 .6554 m
.89288 .65542 L
s
.89296 .65556 m
.89282 .65567 L
s
.89288 .65542 m
.89296 .65556 L
s
1 .151 0 r
.33528 .62582 m
.33484 .62591 L
s
.33493 .62437 m
.33528 .62582 L
s
.33528 .62582 m
.33401 .62526 L
s
.33575 .62502 m
.33528 .62582 L
s
.33329 .62243 m
.33528 .62582 L
s
1 .033 0 r
.24273 .32816 m
.24291 .32836 L
s
.24252 .32826 m
.24273 .32816 L
s
.24273 .32816 m
.2428 .32814 L
s
1 .026 0 r
.89282 .65567 m
.89265 .65552 L
s
.89265 .65552 m
.89288 .65542 L
s
1 .117 0 r
.45911 .50592 m
.45842 .50638 L
s
.45978 .50661 m
.45911 .50592 L
s
1 .033 0 r
.24291 .32836 m
.2427 .32847 L
s
.2428 .32814 m
.24291 .32836 L
s
1 .026 0 r
.89288 .65542 m
.89282 .65567 L
s
1 .398 0 r
.51728 .44729 m
.51431 .45018 L
s
.51316 .44698 m
.51728 .44729 L
s
1 .033 0 r
.2427 .32847 m
.24252 .32826 L
s
.24252 .32826 m
.2428 .32814 L
s
1 .398 0 r
.51431 .45018 m
.51316 .44698 L
s
1 .033 0 r
.2428 .32814 m
.2427 .32847 L
s
1 .606 0 r
.59618 .53185 m
.59974 .53545 L
s
.59274 .53424 m
.59618 .53185 L
s
.59618 .53185 m
.59783 .53199 L
s
1 .323 0 r
.68334 .65292 m
.6851 .65507 L
s
.68173 .65409 m
.68334 .65292 L
s
.68334 .65292 m
.68483 .65327 L
s
1 .117 0 r
.45909 .50707 m
.45978 .50661 L
s
1 .151 0 r
.33493 .62437 m
.33401 .62526 L
s
.33575 .62502 m
.33493 .62437 L
s
1 .65 0 r
.40573 .6849 m
.40901 .68728 L
s
1 .003 0 r
.35297 .50641 m
.35297 .50641 L
s
.35297 .50638 m
.35297 .50641 L
s
.35297 .50641 m
.35295 .50639 L
s
.35299 .5064 m
.35297 .50641 L
s
.35297 .50633 m
.35297 .50641 L
s
.35297 .50638 m
.35295 .50639 L
s
.35299 .5064 m
.35297 .50638 L
s
.35297 .50641 m
.35299 .5064 L
s
.35295 .50639 m
.35297 .50641 L
s
1 .117 0 r
.45842 .50638 m
.45909 .50707 L
s
1 .323 0 r
.6851 .65507 m
.68349 .65624 L
s
.68483 .65327 m
.6851 .65507 L
s
1 .033 0 r
.82769 .62532 m
.82808 .62455 L
s
1 0 0 r
.88922 .47658 m
.88922 .47658 L
s
.787 1 0 r
.59033 .56582 m
.60636 .53736 L
s
1 .215 0 r
.41451 .3576 m
.42051 .35334 L
s
1 .026 0 r
.17715 .2981 m
.17744 .29742 L
s
1 0 0 r
.11562 .44684 m
.11562 .44683 L
s
.11562 .44683 m
.11562 .44684 L
s
.11562 .44684 m
.11562 .44683 L
s
.11562 .44683 m
.11562 .44683 L
s
.11562 .44684 m
.11562 .44684 L
s
.11562 .44683 m
.11562 .44684 L
s
.11562 .44684 m
.11562 .44684 L
s
.11562 .44684 m
.11562 .44683 L
s
.11562 .44683 m
.11562 .44684 L
s
1 .151 0 r
.33401 .62526 m
.33484 .62591 L
s
1 .035 0 r
.22661 .62516 m
.22651 .62517 L
s
.22654 .62482 m
.22661 .62516 L
s
.22661 .62516 m
.22632 .62502 L
s
.22673 .62498 m
.22661 .62516 L
s
.2262 .62436 m
.22661 .62516 L
s
1 .606 0 r
.45426 .53828 m
.45787 .53588 L
s
1 .137 0 r
.72179 .6241 m
.72261 .62493 L
s
.72105 .62467 m
.72179 .6241 L
s
.72179 .6241 m
.72224 .62419 L
s
1 .035 0 r
.22654 .62482 m
.22632 .62502 L
s
.22673 .62498 m
.22654 .62482 L
s
.22632 .62502 m
.22651 .62517 L
s
1 .151 0 r
.33484 .62591 m
.33575 .62502 L
s
1 .59 0 r
.5419 .35721 m
.54182 .35769 L
s
.54179 .35217 m
.5419 .35721 L
s
.54681 .35482 m
.5419 .35721 L
s
1 .035 0 r
.22651 .62517 m
.22673 .62498 L
s
1 .026 0 r
.1774 .29744 m
.17754 .2976 L
s
.17723 .29752 m
.1774 .29744 L
s
.1774 .29744 m
.17744 .29742 L
s
1 .137 0 r
.72261 .62493 m
.72187 .6255 L
s
.72224 .62419 m
.72261 .62493 L
s
1 .026 0 r
.17754 .2976 m
.17737 .29768 L
s
.17744 .29742 m
.17754 .2976 L
s
1 .215 0 r
.6357 .35709 m
.63445 .3573 L
s
.63438 .35529 m
.6357 .35709 L
s
.6357 .35709 m
.63349 .3569 L
s
.63534 .35568 m
.6357 .35709 L
s
.62926 .3531 m
.6357 .35709 L
s
1 .026 0 r
.17737 .29768 m
.17723 .29752 L
s
.17723 .29752 m
.17744 .29742 L
s
.17744 .29742 m
.17737 .29768 L
s
1 .033 0 r
.82799 .62454 m
.8282 .62473 L
s
.82781 .62469 m
.82799 .62454 L
s
.82799 .62454 m
.82808 .62455 L
s
.8282 .62473 m
.82802 .62488 L
s
.82808 .62455 m
.8282 .62473 L
s
1 .215 0 r
.63438 .35529 m
.63349 .3569 L
s
.63534 .35568 m
.63438 .35529 L
s
1 .606 0 r
.59974 .53545 m
.59631 .53785 L
s
.59783 .53199 m
.59974 .53545 L
s
1 .215 0 r
.63349 .3569 m
.63445 .3573 L
s
1 .033 0 r
.82802 .62488 m
.82781 .62469 L
s
.82781 .62469 m
.82808 .62455 L
s
1 .137 0 r
.72187 .6255 m
.72105 .62467 L
s
.72105 .62467 m
.72224 .62419 L
s
1 .344 0 r
.41846 .56513 m
.4182 .56519 L
s
.41831 .56175 m
.41846 .56513 L
s
.41846 .56513 m
.41617 .56351 L
s
.42034 .56343 m
.41846 .56513 L
s
.41744 .5568 m
.41846 .56513 L
s
1 .033 0 r
.82808 .62455 m
.82802 .62488 L
s
.787 1 0 r
.44141 .56508 m
.44837 .57234 L
s
1 .057 0 r
.82194 .26742 m
.82178 .2674 L
s
.82173 .26688 m
.82194 .26742 L
s
.82194 .26742 m
.82144 .26725 L
s
.82208 .26703 m
.82194 .26742 L
s
.82101 .266 m
.82194 .26742 L
s
1 .59 0 r
.5417 .35264 m
.54179 .35217 L
s
.54179 .35217 m
.54681 .35482 L
s
1 .137 0 r
.72224 .62419 m
.72187 .6255 L
s
1 .215 0 r
.37734 .5947 m
.37688 .59478 L
s
.37698 .59261 m
.37734 .5947 L
s
.37734 .5947 m
.37565 .59382 L
s
.3782 .59357 m
.37734 .5947 L
s
.37529 .58967 m
.37734 .5947 L
s
1 .057 0 r
.82173 .26688 m
.82144 .26725 L
s
.82208 .26703 m
.82173 .26688 L
s
.717 1 0 r
.61302 .65421 m
.60968 .65713 L
s
.60935 .64395 m
.61302 .65421 L
s
.61928 .64772 m
.61302 .65421 L
s
1 .057 0 r
.82144 .26725 m
.82178 .2674 L
s
1 .457 0 r
.57808 .32674 m
.57895 .32714 L
s
.57888 .32289 m
.57808 .32674 L
s
.58262 .32573 m
.57808 .32674 L
s
1 0 0 r
.82435 .44578 m
.82435 .44578 L
s
.82435 .44577 m
.82435 .44578 L
s
.82435 .44578 m
.82435 .44577 L
s
.82435 .44577 m
.82435 .44578 L
s
.82435 .44577 m
.82435 .44578 L
s
.82435 .44577 m
.82435 .44577 L
s
.82435 .44577 m
.82435 .44577 L
s
.82435 .44577 m
.82435 .44578 L
s
.82435 .44578 m
.82435 .44577 L
s
1 .046 0 r
.76277 .59459 m
.76321 .59352 L
s
1 0 0 r
.28778 .47553 m
.28778 .47553 L
s
1 .116 0 r
.34935 .32671 m
.35193 .32409 L
s
1 .022 0 r
.11185 .26718 m
.11206 .26661 L
s
1 .323 0 r
.68349 .65624 m
.68173 .65409 L
s
.68173 .65409 m
.68483 .65327 L
s
1 .057 0 r
.82178 .2674 m
.82208 .26703 L
s
1 .457 0 r
.57976 .32328 m
.57888 .32289 L
s
.57888 .32289 m
.58262 .32573 L
s
1 .323 0 r
.68483 .65327 m
.68349 .65624 L
s
1 .022 0 r
.11203 .26662 m
.11215 .26675 L
s
.11189 .26669 m
.11203 .26662 L
s
.11203 .26662 m
.11206 .26661 L
s
.11215 .26675 m
.112 .26682 L
s
.11206 .26661 m
.11215 .26675 L
s
1 .215 0 r
.37698 .59261 m
.37565 .59382 L
s
.3782 .59357 m
.37698 .59261 L
s
1 .606 0 r
.45078 .53467 m
.45426 .53828 L
s
1 .022 0 r
.112 .26682 m
.11189 .26669 L
s
.11189 .26669 m
.11206 .26661 L
s
.11206 .26661 m
.112 .26682 L
s
1 .575 0 r
.64951 .68769 m
.64695 .68346 L
s
.64695 .68346 m
.65289 .68283 L
s
1 .344 0 r
.41831 .56175 m
.41617 .56351 L
s
.42034 .56343 m
.41831 .56175 L
s
0 1 .077 r
.43969 .63247 m
.45213 .62384 L
s
.717 1 0 r
.60599 .64683 m
.60935 .64395 L
s
.60935 .64395 m
.61928 .64772 L
s
1 .575 0 r
.65289 .68283 m
.64951 .68769 L
s
0 .813 1 r
.62139 .35577 m
.59762 .37893 L
s
.58847 .35314 m
.62139 .35577 L
s
1 .215 0 r
.63445 .3573 m
.63534 .35568 L
s
1 .046 0 r
.76311 .59351 m
.7634 .59376 L
s
.76286 .59371 m
.76311 .59351 L
s
.76311 .59351 m
.76321 .59352 L
s
1 .01 0 r
.16098 .59384 m
.16096 .59384 L
s
.16097 .59374 m
.16098 .59384 L
s
.16098 .59384 m
.1609 .59379 L
s
.16102 .59379 m
.16098 .59384 L
s
.16089 .59361 m
.16098 .59384 L
s
1 .215 0 r
.37565 .59382 m
.37688 .59478 L
s
1 .01 0 r
.16097 .59374 m
.1609 .59379 L
s
.16102 .59379 m
.16097 .59374 L
s
1 .606 0 r
.59631 .53785 m
.59274 .53424 L
s
.59274 .53424 m
.59783 .53199 L
s
1 .01 0 r
.1609 .59379 m
.16096 .59384 L
s
.16096 .59384 m
.16102 .59379 L
s
1 .046 0 r
.7634 .59376 m
.76314 .59397 L
s
.76321 .59352 m
.7634 .59376 L
s
1 .457 0 r
.58262 .32573 m
.57895 .32714 L
s
.57976 .32328 m
.58262 .32573 L
s
.56407 .32213 m
.58262 .32573 L
s
1 .006 0 r
.75945 .41507 m
.75945 .41507 L
s
.75944 .41501 m
.75945 .41507 L
s
.75945 .41507 m
.75941 .41505 L
s
.75948 .41503 m
.75945 .41507 L
s
.7594 .41491 m
.75945 .41507 L
s
.75944 .41501 m
.75941 .41505 L
s
.75948 .41503 m
.75944 .41501 L
s
.75941 .41505 m
.75945 .41507 L
s
.75945 .41507 m
.75948 .41503 L
s
1 .046 0 r
.76314 .59397 m
.76286 .59371 L
s
.76286 .59371 m
.76321 .59352 L
s
1 .481 0 r
.49527 .38517 m
.49383 .38583 L
s
.49388 .38128 m
.49527 .38517 L
s
.49743 .38233 m
.49527 .38517 L
s
.285 1 0 r
.43358 .59364 m
.44342 .60396 L
s
1 .048 0 r
.69524 .38516 m
.69508 .38516 L
s
.69505 .3847 m
.69524 .38516 L
s
.69524 .38516 m
.6948 .38502 L
s
.69533 .38484 m
.69524 .38516 L
s
.69437 .38402 m
.69524 .38516 L
s
1 .046 0 r
.76321 .59352 m
.76314 .59397 L
s
1 .011 0 r
.93543 .62339 m
.93555 .62313 L
s
1 .07 0 r
.69779 .56383 m
.69823 .56214 L
s
1 .59 0 r
.52176 .35535 m
.54681 .35482 L
s
1 0 0 r
.2225 .4447 m
.2225 .44469 L
s
1 .073 0 r
.28411 .29578 m
.28548 .29402 L
s
1 0 0 r
.2225 .44469 m
.22251 .44469 L
s
.2225 .44469 m
.2225 .44469 L
s
.2225 .44469 m
.2225 .44469 L
s
.22251 .44469 m
.2225 .44469 L
s
.2225 .44469 m
.22251 .44469 L
s
.2225 .44469 m
.2225 .44469 L
s
.2225 .44469 m
.2225 .44469 L
s
.2225 .44469 m
.2225 .44469 L
s
1 .65 0 r
.40901 .68728 m
.41251 .68292 L
s
1 .215 0 r
.37688 .59478 m
.3782 .59357 L
s
1 .048 0 r
.69505 .3847 m
.6948 .38502 L
s
.69533 .38484 m
.69505 .3847 L
s
.6948 .38502 m
.69508 .38516 L
s
1 .011 0 r
.93552 .62313 m
.93559 .62319 L
s
.93546 .62318 m
.93552 .62313 L
s
.93552 .62313 m
.93555 .62313 L
s
1 .481 0 r
.49243 .38194 m
.49388 .38128 L
s
.49388 .38128 m
.49743 .38233 L
s
1 .011 0 r
.93559 .62319 m
.93553 .62324 L
s
.93555 .62313 m
.93559 .62319 L
s
.93553 .62324 m
.93546 .62318 L
s
.93546 .62318 m
.93555 .62313 L
s
.93555 .62313 m
.93553 .62324 L
s
1 .048 0 r
.69508 .38516 m
.69533 .38484 L
s
1 .344 0 r
.41617 .56351 m
.4182 .56519 L
s
0 .813 1 r
.59762 .37893 m
.58847 .35314 L
s
1 .344 0 r
.4182 .56519 m
.42034 .56343 L
s
1 .59 0 r
.54681 .35482 m
.54182 .35769 L
s
.5417 .35264 m
.54681 .35482 L
s
1 .215 0 r
.41934 .35318 m
.42029 .35476 L
s
.41832 .35362 m
.41934 .35318 L
s
.41934 .35318 m
.42051 .35334 L
s
.42029 .35476 m
.41927 .3552 L
s
.42051 .35334 m
.42029 .35476 L
s
1 .116 0 r
.35144 .32408 m
.35201 .32488 L
s
.35081 .32436 m
.35144 .32408 L
s
.35144 .32408 m
.35193 .32409 L
s
.35201 .32488 m
.35138 .32515 L
s
.35193 .32409 m
.35201 .32488 L
s
.542 1 0 r
.4643 .69213 m
.47213 .68235 L
s
1 .606 0 r
.59783 .53199 m
.59631 .53785 L
s
0 1 .566 r
.63228 .56302 m
.62572 .5681 L
s
.62494 .54239 m
.63228 .56302 L
s
.64502 .54922 m
.63228 .56302 L
s
0 1 .331 r
.43752 .6347 m
.42346 .64445 L
s
.45093 .64882 m
.43752 .6347 L
s
1 .012 0 r
.8705 .59263 m
.87061 .59235 L
s
.542 1 0 r
.57107 .68203 m
.62656 .6663 L
s
1 .136 0 r
.63272 .53303 m
.63274 .52969 L
s
1 0 0 r
.39493 .47343 m
.39493 .47343 L
s
1 .39 0 r
.45658 .32442 m
.47099 .31929 L
s
1 .051 0 r
.2188 .26482 m
.21962 .26353 L
s
1 .001 0 r
.15715 .41382 m
.15715 .41379 L
s
.15715 .41379 m
.15716 .4138 L
s
.15715 .4138 m
.15715 .41379 L
s
.15715 .41379 m
.15715 .41379 L
s
.15716 .4138 m
.15715 .41381 L
s
.15715 .41379 m
.15716 .4138 L
s
.15715 .41381 m
.15715 .4138 L
s
.15715 .4138 m
.15715 .41379 L
s
.15715 .41379 m
.15715 .41381 L
s
1 .073 0 r
.28523 .29404 m
.2856 .29452 L
s
.2848 .29422 m
.28523 .29404 L
s
.28523 .29404 m
.28548 .29402 L
s
1 .116 0 r
.35138 .32515 m
.35081 .32436 L
s
.35081 .32436 m
.35193 .32409 L
s
1 .073 0 r
.2856 .29452 m
.28518 .29471 L
s
.28548 .29402 m
.2856 .29452 L
s
.425 1 0 r
.56122 .41372 m
.54946 .42518 L
s
.54491 .41246 m
.56122 .41372 L
s
1 .116 0 r
.35193 .32409 m
.35138 .32515 L
s
1 .035 0 r
.26826 .59247 m
.26819 .59248 L
s
.26822 .59213 m
.26826 .59247 L
s
.26826 .59247 m
.26799 .59232 L
s
.26841 .59229 m
.26826 .59247 L
s
.26796 .59164 m
.26826 .59247 L
s
1 .07 0 r
.69812 .56213 m
.69856 .5625 L
s
.69772 .56246 m
.69812 .56213 L
s
.69812 .56213 m
.69823 .56214 L
s
1 .012 0 r
.87058 .59234 m
.87066 .59241 L
s
.87052 .5924 m
.87058 .59234 L
s
.87058 .59234 m
.87061 .59235 L
s
.87066 .59241 m
.87059 .59246 L
s
.87061 .59235 m
.87066 .59241 L
s
.87059 .59246 m
.87052 .5924 L
s
.87052 .5924 m
.87061 .59235 L
s
1 .035 0 r
.26822 .59213 m
.26799 .59232 L
s
.26841 .59229 m
.26822 .59213 L
s
1 .012 0 r
.87061 .59235 m
.87059 .59246 L
s
1 .035 0 r
.26799 .59232 m
.26819 .59248 L
s
1 .07 0 r
.69856 .5625 m
.69816 .56283 L
s
.69823 .56214 m
.69856 .5625 L
s
1 .073 0 r
.28518 .29471 m
.2848 .29422 L
s
.2848 .29422 m
.28548 .29402 L
s
1 .035 0 r
.26819 .59248 m
.26841 .59229 L
s
1 .07 0 r
.69816 .56283 m
.69772 .56246 L
s
.69772 .56246 m
.69823 .56214 L
s
1 .073 0 r
.28548 .29402 m
.28518 .29471 L
s
.425 1 0 r
.54946 .42518 m
.54491 .41246 L
s
1 .07 0 r
.69823 .56214 m
.69816 .56283 L
s
1 .215 0 r
.41927 .3552 m
.41832 .35362 L
s
.41832 .35362 m
.42051 .35334 L
s
.42051 .35334 m
.41927 .3552 L
s
0 1 .566 r
.42478 .56727 m
.43306 .56219 L
s
.43306 .56219 m
.42556 .54156 L
s
.43306 .56219 m
.40633 .5603 L
s
1 .457 0 r
.57895 .32714 m
.57976 .32328 L
s
1 .051 0 r
.21948 .26355 m
.21975 .26388 L
s
.21916 .26369 m
.21948 .26355 L
s
.21948 .26355 m
.21962 .26353 L
s
.21975 .26388 m
.21943 .26402 L
s
.21962 .26353 m
.21975 .26388 L
s
1 .303 0 r
.65862 .58952 m
.66042 .59134 L
s
.65694 .59075 m
.65862 .58952 L
s
.65862 .58952 m
.65953 .58966 L
s
1 .59 0 r
.54182 .35769 m
.5417 .35264 L
s
0 1 .511 r
.42965 .68115 m
.43476 .68337 L
s
.43545 .65726 m
.42965 .68115 L
s
.42965 .68115 m
.42023 .66794 L
s
.44994 .67259 m
.42965 .68115 L
s
.45771 .62517 m
.42965 .68115 L
s
1 .051 0 r
.21943 .26402 m
.21916 .26369 L
s
.21916 .26369 m
.21962 .26353 L
s
1 .002 0 r
.86719 .41277 m
.86719 .41277 L
s
.86719 .41276 m
.86719 .41277 L
s
.86719 .41277 m
.86718 .41277 L
s
.8672 .41276 m
.86719 .41277 L
s
.86719 .41273 m
.86719 .41277 L
s
.86719 .41276 m
.86718 .41277 L
s
.8672 .41276 m
.86719 .41276 L
s
.86718 .41277 m
.86719 .41277 L
s
.86719 .41277 m
.8672 .41276 L
s
1 .012 0 r
.8055 .56182 m
.80557 .56154 L
s
1 .398 0 r
.56757 .50219 m
.55968 .49337 L
s
1 .002 0 r
.32965 .44255 m
.32966 .44251 L
s
1 .22 0 r
.39133 .29346 m
.39796 .28928 L
s
1 .002 0 r
.09172 .38291 m
.09173 .38286 L
s
1 .051 0 r
.21962 .26353 m
.21943 .26402 L
s
1 .002 0 r
.32966 .44251 m
.32967 .44252 L
s
.32965 .44252 m
.32966 .44251 L
s
.32966 .44251 m
.32966 .44251 L
s
.32967 .44252 m
.32966 .44253 L
s
.32966 .44251 m
.32967 .44252 L
s
.09173 .38286 m
.09174 .38287 L
s
.09171 .38287 m
.09173 .38286 L
s
.09173 .38286 m
.09173 .38286 L
s
.32966 .44253 m
.32965 .44252 L
s
.32965 .44252 m
.32966 .44251 L
s
.32966 .44251 m
.32966 .44253 L
s
.09174 .38287 m
.09172 .38288 L
s
.09173 .38286 m
.09174 .38287 L
s
.09172 .38288 m
.09171 .38287 L
s
.09171 .38287 m
.09173 .38286 L
s
.09173 .38286 m
.09172 .38288 L
s
1 .323 0 r
.61516 .29334 m
.61617 .29368 L
s
.61608 .29071 m
.61516 .29334 L
s
.61852 .29305 m
.61516 .29334 L
s
0 1 .566 r
.61831 .5473 m
.62494 .54239 L
s
.62494 .54239 m
.64502 .54922 L
s
1 .012 0 r
.80555 .56154 m
.80563 .5616 L
s
.80549 .56159 m
.80555 .56154 L
s
.80555 .56154 m
.80557 .56154 L
s
.80563 .5616 m
.80556 .56166 L
s
.80557 .56154 m
.80563 .5616 L
s
.80556 .56166 m
.80549 .56159 L
s
.80549 .56159 m
.80557 .56154 L
s
.80557 .56154 m
.80556 .56166 L
s
1 .323 0 r
.6171 .29105 m
.61608 .29071 L
s
.61608 .29071 m
.61852 .29305 L
s
1 .303 0 r
.66042 .59134 m
.65874 .59258 L
s
.65953 .58966 m
.66042 .59134 L
s
1 .151 0 r
.67591 .32291 m
.67513 .32299 L
s
.67506 .3216 m
.67591 .32291 L
s
.67591 .32291 m
.67439 .3227 L
s
.6758 .32189 m
.67591 .32291 L
s
.67182 .31984 m
.67591 .32291 L
s
1 .323 0 r
.61852 .29305 m
.61617 .29368 L
s
.6171 .29105 m
.61852 .29305 L
s
.60654 .28879 m
.61852 .29305 L
s
1 .151 0 r
.67506 .3216 m
.67439 .3227 L
s
.6758 .32189 m
.67506 .3216 L
s
0 1 .566 r
.59832 .38238 m
.57914 .40106 L
s
.57175 .38029 m
.59832 .38238 L
s
1 .151 0 r
.67439 .3227 m
.67513 .32299 L
s
1 .481 0 r
.49743 .38233 m
.49383 .38583 L
s
.49243 .38194 m
.49743 .38233 L
s
.49383 .38583 m
.49243 .38194 L
s
1 .59 0 r
.41854 .59089 m
.4181 .59106 L
s
.41829 .5851 m
.41854 .59089 L
s
.41854 .59089 m
.41461 .58814 L
s
.42178 .58801 m
.41854 .59089 L
s
.41679 .57674 m
.41854 .59089 L
s
1 .01 0 r
.80224 .38206 m
.80223 .38206 L
s
.80222 .38196 m
.80224 .38206 L
s
.80224 .38206 m
.80216 .38202 L
s
.80228 .382 m
.80224 .38206 L
s
.80214 .3818 m
.80224 .38206 L
s
.80222 .38196 m
.80216 .38202 L
s
.80228 .382 m
.80222 .38196 L
s
.80216 .38202 m
.80223 .38206 L
s
.80223 .38206 m
.80228 .382 L
s
1 .007 0 r
.2026 .56099 m
.20259 .56099 L
s
.2026 .56092 m
.2026 .56099 L
s
.2026 .56099 m
.20255 .56096 L
s
.20263 .56095 m
.2026 .56099 L
s
.20256 .56082 m
.2026 .56099 L
s
.2026 .56092 m
.20255 .56096 L
s
.20263 .56095 m
.2026 .56092 L
s
.20255 .56096 m
.20259 .56099 L
s
.20259 .56099 m
.20263 .56095 L
s
1 .303 0 r
.65874 .59258 m
.65694 .59075 L
s
.65694 .59075 m
.65953 .58966 L
s
0 1 .566 r
.42556 .54156 m
.41721 .54646 L
s
.42556 .54156 m
.40633 .5603 L
s
1 .417 0 r
.6787 .68017 m
.68787 .67183 L
s
1 .01 0 r
.74042 .53099 m
.74044 .53073 L
s
1 0 0 r
.50235 .47131 m
.50235 .47131 L
s
1 .004 0 r
.26428 .41164 m
.26432 .41154 L
s
1 .134 0 r
.326 .26246 m
.32935 .25952 L
s
1 .046 0 r
.73782 .35193 m
.73768 .35193 L
s
.73765 .3515 m
.73782 .35193 L
s
.73782 .35193 m
.73741 .3518 L
s
.73792 .35163 m
.73782 .35193 L
s
.73702 .35084 m
.73782 .35193 L
s
1 .004 0 r
.26431 .41154 m
.26433 .41156 L
s
.26428 .41155 m
.26431 .41154 L
s
.26431 .41154 m
.26432 .41154 L
s
0 1 .566 r
.57914 .40106 m
.57175 .38029 L
s
1 .004 0 r
.26433 .41156 m
.26431 .41158 L
s
.26432 .41154 m
.26433 .41156 L
s
.26431 .41158 m
.26428 .41155 L
s
.26428 .41155 m
.26432 .41154 L
s
.26432 .41154 m
.26431 .41158 L
s
1 .046 0 r
.73765 .3515 m
.73741 .3518 L
s
.73792 .35163 m
.73765 .3515 L
s
.73741 .3518 m
.73768 .35193 L
s
1 .01 0 r
.74043 .53073 m
.7405 .53078 L
s
.74037 .53078 m
.74043 .53073 L
s
.74043 .53073 m
.74044 .53073 L
s
.74044 .53083 m
.74037 .53078 L
s
.74037 .53078 m
.74044 .53073 L
s
.7405 .53078 m
.74044 .53083 L
s
.74044 .53073 m
.7405 .53078 L
s
1 .151 0 r
.67513 .32299 m
.6758 .32189 L
s
1 .01 0 r
.74044 .53073 m
.74044 .53083 L
s
1 .136 0 r
.63271 .52969 m
.63356 .53034 L
s
.63191 .53037 m
.63271 .52969 L
s
.63271 .52969 m
.63274 .52969 L
s
1 .046 0 r
.73768 .35193 m
.73792 .35163 L
s
1 .303 0 r
.65953 .58966 m
.65874 .59258 L
s
1 .39 0 r
.46927 .32167 m
.46807 .32213 L
s
.46814 .31851 m
.46927 .32167 L
s
.47099 .31929 m
.46927 .32167 L
s
0 1 .566 r
.40633 .5603 m
.42478 .56727 L
s
.40633 .5603 m
.41721 .54646 L
s
.50193 .53016 m
.40633 .5603 L
s
1 .39 0 r
.46693 .31896 m
.46814 .31851 L
s
.46814 .31851 m
.47099 .31929 L
s
1 .136 0 r
.63276 .53103 m
.63191 .53037 L
s
.63191 .53037 m
.63274 .52969 L
s
0 1 .077 r
.42775 .6199 m
.43969 .63247 L
s
1 .136 0 r
.63356 .53034 m
.63276 .53103 L
s
.63274 .52969 m
.63356 .53034 L
s
.425 1 0 r
.45482 .53316 m
.45975 .53022 L
s
.45975 .53022 m
.45515 .51753 L
s
.45975 .53022 m
.44334 .52904 L
s
1 .323 0 r
.61617 .29368 m
.6171 .29105 L
s
1 .136 0 r
.63274 .52969 m
.63276 .53103 L
s
1 .001 0 r
.13708 .52999 m
.13708 .52999 L
s
.13708 .52998 m
.13708 .52999 L
s
.13708 .52999 m
.13707 .52998 L
s
.13709 .52998 m
.13708 .52999 L
s
.13708 .52996 m
.13708 .52999 L
s
.13708 .52998 m
.13707 .52998 L
s
.13709 .52998 m
.13708 .52998 L
s
.13708 .52999 m
.13709 .52998 L
s
.13707 .52998 m
.13708 .52999 L
s
1 .459 0 r
.51469 .29115 m
.51419 .29144 L
s
.51421 .28722 m
.51469 .29115 L
s
.51805 .28888 m
.51469 .29115 L
s
1 .003 0 r
.91348 .55982 m
.9135 .55974 L
s
.973 1 0 r
.6135 .64938 m
.63997 .62985 L
s
1 .005 0 r
.67526 .50011 m
.67523 .49998 L
s
1 .021 0 r
.43705 .4404 m
.43753 .43996 L
s
1 .459 0 r
.49881 .29113 m
.51805 .28888 L
s
1 .006 0 r
.19884 .38069 m
.19888 .38055 L
s
0 .813 1 r
.40561 .59626 m
.41612 .58963 L
s
.41612 .58963 m
.40677 .56399 L
s
.41612 .58963 m
.38283 .58732 L
s
1 .003 0 r
.91349 .55974 m
.91351 .55975 L
s
.91347 .55975 m
.91349 .55974 L
s
.91349 .55974 m
.9135 .55974 L
s
.91351 .55975 m
.9135 .55977 L
s
.9135 .55974 m
.91351 .55975 L
s
.9135 .55977 m
.91347 .55975 L
s
.91347 .55975 m
.9135 .55974 L
s
.9135 .55974 m
.9135 .55977 L
s
1 .005 0 r
.67524 .49998 m
.67527 .5 L
s
.67521 .50001 m
.67524 .49998 L
s
.67524 .49998 m
.67523 .49998 L
s
1 .006 0 r
.19887 .38055 m
.1989 .38058 L
s
.19884 .38057 m
.19887 .38055 L
s
.19887 .38055 m
.19888 .38055 L
s
.1989 .38058 m
.19887 .3806 L
s
.19888 .38055 m
.1989 .38058 L
s
1 .005 0 r
.67524 .50003 m
.67521 .50001 L
s
.67521 .50001 m
.67523 .49998 L
s
.67527 .5 m
.67524 .50003 L
s
.67523 .49998 m
.67527 .5 L
s
1 .006 0 r
.19887 .3806 m
.19884 .38057 L
s
.19884 .38057 m
.19888 .38055 L
s
1 .005 0 r
.67523 .49998 m
.67524 .50003 L
s
1 .006 0 r
.19888 .38055 m
.19887 .3806 L
s
1 .59 0 r
.41829 .5851 m
.41461 .58814 L
s
.42178 .58801 m
.41829 .5851 L
s
1 .032 0 r
.31002 .55959 m
.30998 .55959 L
s
.31 .55927 m
.31002 .55959 L
s
.31002 .55959 m
.30979 .55944 L
s
.31018 .55943 m
.31002 .55959 L
s
.30987 .55881 m
.31002 .55959 L
s
1 .021 0 r
.43744 .43995 m
.43754 .44009 L
s
.43733 .44 m
.43744 .43995 L
s
.43744 .43995 m
.43753 .43996 L
s
.43754 .44009 m
.43743 .44015 L
s
.43753 .43996 m
.43754 .44009 L
s
1 .032 0 r
.31 .55927 m
.30979 .55944 L
s
.31018 .55943 m
.31 .55927 L
s
1 .22 0 r
.39758 .29077 m
.39659 .29113 L
s
.39667 .28911 m
.39758 .29077 L
s
.39796 .28928 m
.39758 .29077 L
s
.39568 .28946 m
.39667 .28911 L
s
.39667 .28911 m
.39796 .28928 L
s
1 .158 0 r
.29253 .67891 m
.29197 .67905 L
s
.29208 .67741 m
.29253 .67891 L
s
.29253 .67891 m
.29113 .67838 L
s
.29293 .67808 m
.29253 .67891 L
s
.29003 .67549 m
.29253 .67891 L
s
1 .021 0 r
.43743 .44015 m
.43733 .44 L
s
.43733 .44 m
.43753 .43996 L
s
1 .032 0 r
.30979 .55944 m
.30998 .55959 L
s
1 .021 0 r
.43753 .43996 m
.43743 .44015 L
s
1 .459 0 r
.5137 .28751 m
.51421 .28722 L
s
.51421 .28722 m
.51805 .28888 L
s
1 .032 0 r
.30998 .55959 m
.31018 .55943 L
s
0 1 .511 r
.58784 .69767 m
.59227 .67691 L
s
.425 1 0 r
.45515 .51753 m
.45019 .5204 L
s
.45515 .51753 m
.44334 .52904 L
s
0 1 .331 r
.4369 .65867 m
.45093 .64882 L
s
1 .134 0 r
.32872 .2595 m
.32934 .26046 L
s
.32802 .25976 m
.32872 .2595 L
s
.32872 .2595 m
.32935 .25952 L
s
1 .158 0 r
.29208 .67741 m
.29113 .67838 L
s
.29293 .67808 m
.29208 .67741 L
s
1 .134 0 r
.32934 .26046 m
.32864 .26072 L
s
.32935 .25952 m
.32934 .26046 L
s
1 .05 0 r
.18324 .67846 m
.18308 .6785 L
s
.18313 .67798 m
.18324 .67846 L
s
.18324 .67846 m
.18281 .67828 L
s
.18339 .67821 m
.18324 .67846 L
s
.18254 .67737 m
.18324 .67846 L
s
1 .417 0 r
.5551 .26029 m
.55537 .26049 L
s
.55534 .25669 m
.5551 .26029 L
s
.5589 .25881 m
.5551 .26029 L
s
.425 1 0 r
.44334 .52904 m
.45482 .53316 L
s
.44334 .52904 m
.45019 .5204 L
s
.50207 .51031 m
.44334 .52904 L
s
1 .158 0 r
.29113 .67838 m
.29197 .67905 L
s
1 .05 0 r
.18313 .67798 m
.18281 .67828 L
s
.18339 .67821 m
.18313 .67798 L
s
1 .825 0 r
.62967 .61237 m
.63382 .61816 L
s
.62579 .61499 m
.62967 .61237 L
s
.62967 .61237 m
.63405 .6134 L
s
1 .117 0 r
.54831 .43935 m
.54852 .4395 L
s
.54851 .43837 m
.54831 .43935 L
s
.54946 .43911 m
.54831 .43935 L
s
1 .115 0 r
.78659 .6783 m
.7884 .67582 L
s
1 .002 0 r
.84838 .52894 m
.84839 .52889 L
s
0 .434 1 r
.54823 .61856 m
.68572 .57781 L
s
1 0 0 r
.61002 .4692 m
.61002 .4692 L
s
1 .024 0 r
.37167 .40945 m
.37209 .4089 L
s
1 .318 0 r
.43346 .26009 m
.4452 .25575 L
s
1 .006 0 r
.13331 .34971 m
.13335 .34954 L
s
1 .05 0 r
.18281 .67828 m
.18308 .6785 L
s
1 .002 0 r
.84839 .52889 m
.8484 .5289 L
s
.84837 .5289 m
.84839 .52889 L
s
.84839 .52889 m
.84839 .52889 L
s
.84839 .52891 m
.84837 .5289 L
s
.84837 .5289 m
.84839 .52889 L
s
.8484 .5289 m
.84839 .52891 L
s
.84839 .52889 m
.8484 .5289 L
s
.84839 .52889 m
.84839 .52891 L
s
1 .117 0 r
.54872 .43852 m
.54851 .43837 L
s
.54851 .43837 m
.54946 .43911 L
s
1 .05 0 r
.18308 .6785 m
.18339 .67821 L
s
1 .006 0 r
.13335 .34954 m
.13338 .34958 L
s
.13331 .34957 m
.13335 .34954 L
s
.13335 .34954 m
.13335 .34954 L
s
.13338 .34958 m
.13334 .3496 L
s
.13335 .34954 m
.13338 .34958 L
s
.13334 .3496 m
.13331 .34957 L
s
.13331 .34957 m
.13335 .34954 L
s
.13335 .34954 m
.13334 .3496 L
s
1 .117 0 r
.54946 .43911 m
.54852 .4395 L
s
.54872 .43852 m
.54946 .43911 L
s
.54471 .43825 m
.54946 .43911 L
s
1 .417 0 r
.55561 .25689 m
.55534 .25669 L
s
.55534 .25669 m
.5589 .25881 L
s
1 .158 0 r
.29197 .67905 m
.29293 .67808 L
s
1 .134 0 r
.32864 .26072 m
.32802 .25976 L
s
.32802 .25976 m
.32935 .25952 L
s
.32935 .25952 m
.32864 .26072 L
s
1 .024 0 r
.37201 .4089 m
.37214 .40905 L
s
.37188 .40897 m
.37201 .4089 L
s
.37201 .4089 m
.37209 .4089 L
s
.37214 .40905 m
.372 .40912 L
s
.37209 .4089 m
.37214 .40905 L
s
1 .825 0 r
.63382 .61816 m
.62994 .62078 L
s
.63405 .6134 m
.63382 .61816 L
s
1 .22 0 r
.39659 .29113 m
.39568 .28946 L
s
.39796 .28928 m
.39659 .29113 L
s
.39568 .28946 m
.39796 .28928 L
s
1 .024 0 r
.372 .40912 m
.37188 .40897 L
s
.37188 .40897 m
.37209 .4089 L
s
.37209 .4089 m
.372 .40912 L
s
1 .39 0 r
.47099 .31929 m
.46807 .32213 L
s
.46693 .31896 m
.47099 .31929 L
s
1 .59 0 r
.41461 .58814 m
.4181 .59106 L
s
1 .39 0 r
.46807 .32213 m
.46693 .31896 L
s
0 .813 1 r
.40677 .56399 m
.39616 .57034 L
s
.40677 .56399 m
.38283 .58732 L
s
1 .117 0 r
.54852 .4395 m
.54872 .43852 L
s
1 .59 0 r
.4181 .59106 m
.42178 .58801 L
s
1 .013 0 r
.84518 .3489 m
.84516 .34889 L
s
.84514 .34878 m
.84518 .3489 L
s
.84518 .3489 m
.84507 .34885 L
s
.84522 .34882 m
.84518 .3489 L
s
.84504 .34857 m
.84518 .3489 L
s
.84514 .34878 m
.84507 .34885 L
s
.84522 .34882 m
.84514 .34878 L
s
.717 1 0 r
.61928 .64772 m
.60968 .65713 L
s
.60599 .64683 m
.61928 .64772 L
s
1 .013 0 r
.84507 .34885 m
.84516 .34889 L
s
1 .233 0 r
.65462 .25919 m
.65554 .25947 L
s
.65544 .25735 m
.65462 .25919 L
s
.65707 .25917 m
.65462 .25919 L
s
.65707 .25917 m
.65554 .25947 L
s
.65544 .25735 m
.65707 .25917 L
s
.65636 .25762 m
.65707 .25917 L
s
.64917 .25534 m
.65707 .25917 L
s
1 .013 0 r
.84516 .34889 m
.84522 .34882 L
s
1 .233 0 r
.65636 .25762 m
.65544 .25735 L
s
1 .22 0 r
.33506 .64761 m
.33441 .64776 L
s
.33454 .6455 m
.33506 .64761 L
s
.33506 .64761 m
.3332 .64681 L
s
.33575 .64645 m
.33506 .64761 L
s
.33213 .6427 m
.33506 .64761 L
s
1 .114 0 r
.7174 .28893 m
.71686 .28896 L
s
.7168 .28791 m
.7174 .28893 L
s
.7174 .28893 m
.71627 .28873 L
s
.71739 .28814 m
.7174 .28893 L
s
.71454 .28645 m
.7174 .28893 L
s
1 .004 0 r
.24438 .52801 m
.24438 .52801 L
s
.24438 .52797 m
.24438 .52801 L
s
.24438 .52801 m
.24436 .52799 L
s
.2444 .52799 m
.24438 .52801 L
s
.24438 .52792 m
.24438 .52801 L
s
.24438 .52797 m
.24436 .52799 L
s
.2444 .52799 m
.24438 .52797 L
s
1 .459 0 r
.51805 .28888 m
.51419 .29144 L
s
.5137 .28751 m
.51805 .28888 L
s
1 .004 0 r
.24438 .52801 m
.2444 .52799 L
s
.24436 .52799 m
.24438 .52801 L
s
1 .202 0 r
.72138 .64748 m
.72439 .64301 L
s
1 .001 0 r
.78321 .49803 m
.78321 .49801 L
s
1 .021 0 r
.30621 .37846 m
.30652 .37795 L
s
1 .007 0 r
.06771 .31868 m
.06775 .31851 L
s
1 .001 0 r
.78321 .49801 m
.78321 .49801 L
s
.78321 .49801 m
.78321 .49801 L
s
.78321 .49801 m
.78321 .49801 L
s
.78321 .49802 m
.78321 .49801 L
s
.78321 .49801 m
.78321 .49801 L
s
.78321 .49801 m
.78321 .49802 L
s
.78321 .49801 m
.78321 .49801 L
s
.78321 .49801 m
.78321 .49802 L
s
1 .336 0 r
.3776 .61757 m
.37688 .61773 L
s
.37703 .61431 m
.3776 .61757 L
s
.3776 .61757 m
.37496 .61621 L
s
.37895 .61582 m
.3776 .61757 L
s
.37438 .60978 m
.3776 .61757 L
s
1 .114 0 r
.7168 .28791 m
.71627 .28873 L
s
.71739 .28814 m
.7168 .28791 L
s
.717 1 0 r
.60968 .65713 m
.60599 .64683 L
s
1 .114 0 r
.71627 .28873 m
.71686 .28896 L
s
1 .417 0 r
.5589 .25881 m
.55537 .26049 L
s
.55561 .25689 m
.5589 .25881 L
s
.54119 .25772 m
.5589 .25881 L
s
1 .042 0 r
.78055 .31856 m
.78042 .31855 L
s
.78039 .31816 m
.78055 .31856 L
s
.78055 .31856 m
.78017 .31844 L
s
.78064 .31828 m
.78055 .31856 L
s
.77983 .31753 m
.78055 .31856 L
s
1 .007 0 r
.06774 .31851 m
.06778 .31855 L
s
.0677 .31854 m
.06774 .31851 L
s
.06774 .31851 m
.06775 .31851 L
s
.06778 .31855 m
.06773 .31857 L
s
.06775 .31851 m
.06778 .31855 L
s
.06773 .31857 m
.0677 .31854 L
s
.0677 .31854 m
.06775 .31851 L
s
.06775 .31851 m
.06773 .31857 L
s
1 .042 0 r
.78039 .31816 m
.78017 .31844 L
s
.78064 .31828 m
.78039 .31816 L
s
.78017 .31844 m
.78042 .31855 L
s
1 .021 0 r
.30647 .37795 m
.30658 .37809 L
s
.30634 .37802 m
.30647 .37795 L
s
.30647 .37795 m
.30652 .37795 L
s
1 .22 0 r
.33454 .6455 m
.3332 .64681 L
s
.33575 .64645 m
.33454 .6455 L
s
1 .021 0 r
.30658 .37809 m
.30645 .37815 L
s
.30652 .37795 m
.30658 .37809 L
s
1 .042 0 r
.78042 .31855 m
.78064 .31828 L
s
0 .813 1 r
.38283 .58732 m
.40561 .59626 L
s
.38283 .58732 m
.39616 .57034 L
s
.50179 .55026 m
.38283 .58732 L
s
1 .021 0 r
.30645 .37815 m
.30634 .37802 L
s
.30634 .37802 m
.30652 .37795 L
s
.30652 .37795 m
.30645 .37815 L
s
1 .114 0 r
.71686 .28896 m
.71739 .28814 L
s
1 .22 0 r
.3332 .64681 m
.33441 .64776 L
s
1 .459 0 r
.51419 .29144 m
.5137 .28751 L
s
1 .336 0 r
.37703 .61431 m
.37496 .61621 L
s
.37895 .61582 m
.37703 .61431 L
s
1 .115 0 r
.78799 .67572 m
.78869 .67642 L
s
.78738 .67621 m
.78799 .67572 L
s
.78799 .67572 m
.7884 .67582 L
s
1 .318 0 r
.44382 .25776 m
.44281 .25807 L
s
.44289 .25517 m
.44382 .25776 L
s
.4452 .25575 m
.44382 .25776 L
s
1 0 0 r
.1788 .49699 m
.1788 .49699 L
s
.1788 .49698 m
.1788 .49699 L
s
.1788 .49699 m
.1788 .49699 L
s
.1788 .49699 m
.1788 .49699 L
s
.1788 .49698 m
.1788 .49699 L
s
.1788 .49698 m
.1788 .49699 L
s
.1788 .49699 m
.1788 .49698 L
s
.1788 .49699 m
.1788 .49699 L
s
.1788 .49699 m
.1788 .49699 L
s
1 .039 0 r
.89473 .67643 m
.89527 .67557 L
s
1 .457 0 r
.65609 .61661 m
.66252 .60626 L
s
1 0 0 r
.71796 .46707 m
.71796 .46707 L
s
1 .199 0 r
.47931 .40726 m
.48673 .40474 L
s
1 .018 0 r
.24067 .34744 m
.24091 .34698 L
s
1 .233 0 r
.65554 .25947 m
.65636 .25762 L
s
1 .115 0 r
.78869 .67642 m
.78808 .67691 L
s
.7884 .67582 m
.78869 .67642 L
s
1 .22 0 r
.33441 .64776 m
.33575 .64645 L
s
1 .825 0 r
.41859 .61651 m
.41797 .61685 L
s
.41824 .60842 m
.41859 .61651 L
s
.41859 .61651 m
.41307 .61272 L
s
.42313 .61254 m
.41859 .61651 L
s
.41613 .59693 m
.41859 .61651 L
s
1 .136 0 r
.59047 .40713 m
.59097 .40736 L
s
.59094 .40606 m
.59047 .40713 L
s
.59189 .40712 m
.59047 .40713 L
s
1 .318 0 r
.44188 .25547 m
.44289 .25517 L
s
.44289 .25517 m
.4452 .25575 L
s
1 .136 0 r
.59189 .40712 m
.59097 .40736 L
s
.59094 .40606 m
.59189 .40712 L
s
.59144 .40629 m
.59189 .40712 L
s
.58722 .40506 m
.59189 .40712 L
s
.59144 .40629 m
.59094 .40606 L
s
0 1 .511 r
.43545 .65726 m
.42023 .66794 L
s
.44994 .67259 m
.43545 .65726 L
s
1 .115 0 r
.78808 .67691 m
.78738 .67621 L
s
.78738 .67621 m
.7884 .67582 L
s
1 .018 0 r
.24087 .34698 m
.24097 .3471 L
s
.24075 .34704 m
.24087 .34698 L
s
.24087 .34698 m
.24091 .34698 L
s
.24097 .3471 m
.24085 .34716 L
s
.24091 .34698 m
.24097 .3471 L
s
1 .417 0 r
.55537 .26049 m
.55561 .25689 L
s
1 .018 0 r
.24085 .34716 m
.24075 .34704 L
s
.24075 .34704 m
.24091 .34698 L
s
.24091 .34698 m
.24085 .34716 L
s
1 .115 0 r
.7884 .67582 m
.78808 .67691 L
s
1 .336 0 r
.37496 .61621 m
.37688 .61773 L
s
1 .024 0 r
.3519 .52644 m
.3519 .52645 L
s
.35191 .52621 m
.3519 .52644 L
s
.3519 .52644 m
.35176 .52632 L
s
.35205 .52634 m
.3519 .52644 L
s
.35193 .52586 m
.3519 .52644 L
s
.35191 .52621 m
.35176 .52632 L
s
.35205 .52634 m
.35191 .52621 L
s
.3519 .52645 m
.35205 .52634 L
s
.35176 .52632 m
.3519 .52645 L
s
1 .039 0 r
.89514 .67554 m
.89539 .67576 L
s
.89493 .67571 m
.89514 .67554 L
s
.89514 .67554 m
.89527 .67557 L
s
1 .055 0 r
.22505 .64587 m
.22489 .6459 L
s
.22494 .64533 m
.22505 .64587 L
s
.22505 .64587 m
.22459 .64565 L
s
.22525 .64559 m
.22505 .64587 L
s
.2244 .64461 m
.22505 .64587 L
s
1 .039 0 r
.89539 .67576 m
.89518 .67594 L
s
.89527 .67557 m
.89539 .67576 L
s
1 .398 0 r
.56124 .49318 m
.56342 .49446 L
s
.55912 .49582 m
.56124 .49318 L
s
.56124 .49318 m
.55968 .49337 L
s
1 .039 0 r
.89518 .67594 m
.89493 .67571 L
s
.89493 .67571 m
.89527 .67557 L
s
1 .055 0 r
.22494 .64533 m
.22459 .64565 L
s
.22525 .64559 m
.22494 .64533 L
s
1 .336 0 r
.37688 .61773 m
.37895 .61582 L
s
1 .039 0 r
.89527 .67557 m
.89518 .67594 L
s
1 .136 0 r
.59097 .40736 m
.59144 .40629 L
s
1 .007 0 r
.65275 .43624 m
.65273 .43624 L
s
.65273 .43617 m
.65275 .43624 L
s
.65275 .43624 m
.65269 .43622 L
s
.65276 .43619 m
.65275 .43624 L
s
.65263 .43608 m
.65275 .43624 L
s
.65273 .43617 m
.65269 .43622 L
s
.65276 .43619 m
.65273 .43617 L
s
.65269 .43622 m
.65273 .43624 L
s
.65273 .43624 m
.65276 .43619 L
s
1 .055 0 r
.22459 .64565 m
.22489 .6459 L
s
.22489 .6459 m
.22525 .64559 L
s
1 .053 0 r
.82951 .64557 m
.83014 .64436 L
s
1 0 0 r
.89142 .49594 m
.89142 .49593 L
s
.285 1 0 r
.59072 .58572 m
.61368 .54544 L
s
1 .111 0 r
.41384 .37623 m
.41695 .37405 L
s
1 .016 0 r
.17505 .31638 m
.17523 .31596 L
s
1 0 0 r
.11315 .46601 m
.11315 .46601 L
s
.89142 .49593 m
.89142 .49593 L
s
.89142 .49593 m
.89142 .49593 L
s
.89142 .49593 m
.89142 .49593 L
s
.89142 .49593 m
.89142 .49593 L
s
.89142 .49593 m
.89142 .49593 L
s
.89142 .49593 m
.89142 .49593 L
s
.89142 .49593 m
.89142 .49593 L
s
.89142 .49593 m
.89142 .49593 L
s
1 .398 0 r
.56129 .4971 m
.55912 .49582 L
s
.55912 .49582 m
.55968 .49337 L
s
.49027 .4965 m
.49148 .4958 L
s
.49148 .4958 m
.49031 .49258 L
s
.49148 .4958 m
.48732 .4955 L
s
1 .199 0 r
.48584 .40591 m
.48523 .4062 L
s
.48526 .40429 m
.48584 .40591 L
s
.48673 .40474 m
.48584 .40591 L
s
1 .016 0 r
.17521 .31597 m
.17529 .31607 L
s
.1751 .31602 m
.17521 .31597 L
s
.17521 .31597 m
.17523 .31596 L
s
.17529 .31607 m
.17519 .31612 L
s
.17523 .31596 m
.17529 .31607 L
s
.17519 .31612 m
.1751 .31602 L
s
.1751 .31602 m
.17523 .31596 L
s
1 .199 0 r
.48465 .40458 m
.48526 .40429 L
s
.48526 .40429 m
.48673 .40474 L
s
1 .016 0 r
.17523 .31596 m
.17519 .31612 L
s
1 .398 0 r
.49031 .49258 m
.48911 .49327 L
s
.49031 .49258 m
.48732 .4955 L
s
.48732 .4955 m
.49027 .4965 L
s
.48732 .4955 m
.48911 .49327 L
s
.50221 .49069 m
.48732 .4955 L
s
1 .318 0 r
.4452 .25575 m
.44281 .25807 L
s
.44188 .25547 m
.4452 .25575 L
s
1 .825 0 r
.62994 .62078 m
.62579 .61499 L
s
.62579 .61499 m
.63405 .6134 L
s
1 .318 0 r
.44281 .25807 m
.44188 .25547 L
s
1 .053 0 r
.82999 .64433 m
.83033 .64463 L
s
.8297 .64457 m
.82999 .64433 L
s
.82999 .64433 m
.83014 .64436 L
s
.83033 .64463 m
.83004 .64488 L
s
.83014 .64436 m
.83033 .64463 L
s
1 .001 0 r
.28634 .49491 m
.28634 .49491 L
s
.28634 .4949 m
.28634 .49491 L
s
.28634 .49491 m
.28634 .49491 L
s
.28635 .49491 m
.28634 .49491 L
s
.28634 .49489 m
.28634 .49491 L
s
.28634 .4949 m
.28634 .49491 L
s
.28635 .49491 m
.28634 .4949 L
s
.28634 .49491 m
.28635 .49491 L
s
.28634 .49491 m
.28634 .49491 L
s
1 .08 0 r
.76421 .61467 m
.76498 .61281 L
s
1 0 0 r
.82615 .46495 m
.82615 .46495 L
s
1 .068 0 r
.34829 .34517 m
.34981 .34364 L
s
1 .014 0 r
.10936 .28528 m
.10949 .2849 L
s
1 .825 0 r
.41824 .60842 m
.41307 .61272 L
s
.42313 .61254 m
.41824 .60842 L
s
1 .344 0 r
.53356 .37508 m
.5335 .37538 L
s
.5335 .37212 m
.53356 .37508 L
s
.53644 .37369 m
.53356 .37508 L
s
1 .053 0 r
.83004 .64488 m
.8297 .64457 L
s
.8297 .64457 m
.83014 .64436 L
s
1 .417 0 r
.68593 .67133 m
.68822 .67413 L
s
.68384 .67287 m
.68593 .67133 L
s
.68593 .67133 m
.68787 .67183 L
s
1 .825 0 r
.63405 .6134 m
.62994 .62078 L
s
1 .053 0 r
.83014 .64436 m
.83004 .64488 L
s
0 1 .331 r
.42346 .64445 m
.4369 .65867 L
s
1 .039 0 r
.82344 .28508 m
.82333 .28506 L
s
.82329 .2847 m
.82344 .28508 L
s
.82344 .28508 m
.82309 .28496 L
s
.82353 .28481 m
.82344 .28508 L
s
.82279 .28411 m
.82344 .28508 L
s
1 .014 0 r
.10948 .28491 m
.10955 .285 L
s
.10938 .28496 m
.10948 .28491 L
s
.10948 .28491 m
.10949 .2849 L
s
1 .202 0 r
.72373 .64287 m
.72494 .6441 L
s
.72263 .64372 m
.72373 .64287 L
s
.72373 .64287 m
.72439 .64301 L
s
1 .014 0 r
.10955 .285 m
.10946 .28504 L
s
.10949 .2849 m
.10955 .285 L
s
1 .039 0 r
.82329 .2847 m
.82309 .28496 L
s
.82353 .28481 m
.82329 .2847 L
s
1 .091 0 r
.75955 .25501 m
.75915 .25501 L
s
.75909 .25419 m
.75955 .25501 L
s
.75955 .25501 m
.75866 .25483 L
s
.75959 .25437 m
.75955 .25501 L
s
.75741 .25295 m
.75955 .25501 L
s
1 .014 0 r
.10946 .28504 m
.10938 .28496 L
s
.10938 .28496 m
.10949 .2849 L
s
1 .039 0 r
.82309 .28496 m
.82333 .28506 L
s
1 .111 0 r
.41634 .37396 m
.41684 .37478 L
s
.41582 .37419 m
.41634 .37396 L
s
.41634 .37396 m
.41695 .37405 L
s
1 .199 0 r
.48673 .40474 m
.48523 .4062 L
s
.48465 .40458 m
.48673 .40474 L
s
1 .014 0 r
.10949 .2849 m
.10946 .28504 L
s
1 .111 0 r
.41684 .37478 m
.41631 .37501 L
s
.41695 .37405 m
.41684 .37478 L
s
1 .199 0 r
.48523 .4062 m
.48465 .40458 L
s
1 .344 0 r
.53344 .37242 m
.5335 .37212 L
s
.5335 .37212 m
.53644 .37369 L
s
1 .091 0 r
.75909 .25419 m
.75866 .25483 L
s
.75959 .25437 m
.75909 .25419 L
s
1 .039 0 r
.82333 .28506 m
.82353 .28481 L
s
1 .398 0 r
.56342 .49446 m
.56129 .4971 L
s
.55968 .49337 m
.56342 .49446 L
s
0 .434 1 r
.39357 .622 m
.40551 .61426 L
s
.40551 .61426 m
.395 .5855 L
s
.40551 .61426 m
.36812 .61171 L
s
1 .091 0 r
.75866 .25483 m
.75915 .25501 L
s
1 .417 0 r
.68822 .67413 m
.68613 .67567 L
s
.68787 .67183 m
.68822 .67413 L
s
1 .202 0 r
.72494 .6441 m
.72385 .64495 L
s
.72439 .64301 m
.72494 .6441 L
s
1 .018 0 r
.15886 .61411 m
.15881 .61412 L
s
.15883 .61393 m
.15886 .61411 L
s
.15886 .61411 m
.15872 .61403 L
s
.15893 .61402 m
.15886 .61411 L
s
.15869 .61369 m
.15886 .61411 L
s
.15883 .61393 m
.15872 .61403 L
s
.15893 .61402 m
.15883 .61393 L
s
.15872 .61403 m
.15881 .61412 L
s
.15881 .61412 m
.15893 .61402 L
s
1 .398 0 r
.55968 .49337 m
.56129 .4971 L
s
1 .091 0 r
.75915 .25501 m
.75959 .25437 L
s
1 .111 0 r
.41631 .37501 m
.41582 .37419 L
s
.41582 .37419 m
.41695 .37405 L
s
.41695 .37405 m
.41631 .37501 L
s
1 .068 0 r
.34952 .34363 m
.34986 .3441 L
s
.34915 .3438 m
.34952 .34363 L
s
.34952 .34363 m
.34981 .34364 L
s
1 .202 0 r
.72385 .64495 m
.72263 .64372 L
s
.72263 .64372 m
.72439 .64301 L
s
1 .068 0 r
.34986 .3441 m
.34948 .34427 L
s
.34981 .34364 m
.34986 .3441 L
s
1 .001 0 r
.76082 .43394 m
.76082 .43394 L
s
.76082 .43393 m
.76082 .43394 L
s
.76082 .43394 m
.76081 .43394 L
s
.76082 .43393 m
.76082 .43394 L
s
.76081 .43392 m
.76082 .43394 L
s
.542 1 0 r
.61937 .67363 m
.61557 .67707 L
s
.61517 .66191 m
.61937 .67363 L
s
.62656 .6663 m
.61937 .67363 L
s
1 .001 0 r
.76082 .43393 m
.76081 .43394 L
s
.76082 .43393 m
.76082 .43393 L
s
.76081 .43394 m
.76082 .43394 L
s
.76082 .43394 m
.76082 .43393 L
s
1 .018 0 r
.9379 .64365 m
.93811 .64323 L
s
1 .141 0 r
.69883 .58373 m
.69974 .58036 L
s
1 .344 0 r
.52173 .37399 m
.53644 .37369 L
s
1 0 0 r
.22067 .46388 m
.22067 .46388 L
s
1 .047 0 r
.28266 .31407 m
.28353 .31295 L
s
1 .111 0 r
.63323 .3738 m
.63258 .37392 L
s
.63254 .37287 m
.63323 .3738 L
s
.63323 .3738 m
.63208 .3737 L
s
.63304 .37308 m
.63323 .3738 L
s
.62989 .37175 m
.63323 .3738 L
s
1 .068 0 r
.34948 .34427 m
.34915 .3438 L
s
.34915 .3438 m
.34981 .34364 L
s
.34981 .34364 m
.34948 .34427 L
s
1 .202 0 r
.72439 .64301 m
.72385 .64495 L
s
1 .111 0 r
.63254 .37287 m
.63208 .3737 L
s
.63304 .37308 m
.63254 .37287 L
s
.63208 .3737 m
.63258 .37392 L
s
1 .344 0 r
.53644 .37369 m
.5335 .37538 L
s
.53344 .37242 m
.53644 .37369 L
s
1 .018 0 r
.93806 .64322 m
.93818 .64332 L
s
.93796 .64331 m
.93806 .64322 L
s
.93806 .64322 m
.93811 .64323 L
s
1 .08 0 r
.7648 .61278 m
.7653 .61322 L
s
.76435 .61314 m
.7648 .61278 L
s
.7648 .61278 m
.76498 .61281 L
s
1 .303 0 r
.57365 .34365 m
.57423 .34393 L
s
.57418 .34109 m
.57365 .34365 L
s
.57668 .34299 m
.57365 .34365 L
s
1 .398 0 r
.48911 .49327 m
.49027 .4965 L
s
1 .018 0 r
.93818 .64332 m
.93808 .64341 L
s
.93811 .64323 m
.93818 .64332 L
s
.93808 .64341 m
.93796 .64331 L
s
.93796 .64331 m
.93811 .64323 L
s
.93811 .64323 m
.93808 .64341 L
s
1 .08 0 r
.7653 .61322 m
.76486 .61359 L
s
.76498 .61281 m
.7653 .61322 L
s
1 .062 0 r
.26694 .61318 m
.26681 .61321 L
s
.26686 .61258 m
.26694 .61318 L
s
.26694 .61318 m
.26647 .61292 L
s
.26721 .61287 m
.26694 .61318 L
s
.26641 .61174 m
.26694 .61318 L
s
1 .08 0 r
.76486 .61359 m
.76435 .61314 L
s
.76435 .61314 m
.76498 .61281 L
s
1 .303 0 r
.57476 .34137 m
.57418 .34109 L
s
.57418 .34109 m
.57668 .34299 L
s
1 .047 0 r
.28337 .31295 m
.28361 .31326 L
s
.2831 .31307 m
.28337 .31295 L
s
.28337 .31295 m
.28353 .31295 L
s
1 .062 0 r
.26686 .61258 m
.26647 .61292 L
s
.26721 .61287 m
.26686 .61258 L
s
1 .016 0 r
.69568 .40322 m
.69562 .40323 L
s
.69562 .40307 m
.69568 .40322 L
s
.69568 .40322 m
.69553 .40318 L
s
.69571 .40312 m
.69568 .40322 L
s
.69539 .40285 m
.69568 .40322 L
s
.69562 .40307 m
.69553 .40318 L
s
.69571 .40312 m
.69562 .40307 L
s
1 .047 0 r
.28361 .31326 m
.28334 .31339 L
s
.28353 .31295 m
.28361 .31326 L
s
1 .016 0 r
.69553 .40318 m
.69562 .40323 L
s
.542 1 0 r
.61135 .66529 m
.61517 .66191 L
s
.61517 .66191 m
.62656 .6663 L
s
1 .08 0 r
.76498 .61281 m
.76486 .61359 L
s
1 .016 0 r
.69562 .40323 m
.69571 .40312 L
s
1 .062 0 r
.26647 .61292 m
.26681 .61321 L
s
1 .417 0 r
.68613 .67567 m
.68384 .67287 L
s
.68384 .67287 m
.68787 .67183 L
s
1 .008 0 r
.39406 .493 m
.39408 .493 L
s
.39408 .49291 m
.39406 .493 L
s
.39406 .493 m
.39403 .49295 L
s
.39413 .49296 m
.39406 .493 L
s
.39415 .49279 m
.39406 .493 L
s
1 .111 0 r
.63258 .37392 m
.63304 .37308 L
s
1 .008 0 r
.39408 .49291 m
.39403 .49295 L
s
.39413 .49296 m
.39408 .49291 L
s
.39408 .493 m
.39413 .49296 L
s
1 .062 0 r
.26681 .61321 m
.26721 .61287 L
s
1 .008 0 r
.39403 .49295 m
.39408 .493 L
s
1 .047 0 r
.28334 .31339 m
.2831 .31307 L
s
.2831 .31307 m
.28353 .31295 L
s
.28353 .31295 m
.28334 .31339 L
s
1 .303 0 r
.57668 .34299 m
.57423 .34393 L
s
.57476 .34137 m
.57668 .34299 L
s
.56431 .34061 m
.57668 .34299 L
s
1 .825 0 r
.41307 .61272 m
.41797 .61685 L
s
1 .022 0 r
.87259 .61272 m
.87278 .61221 L
s
1 .344 0 r
.63337 .55275 m
.63343 .5443 L
s
1 .253 0 r
.45617 .34289 m
.46559 .33957 L
s
1 .035 0 r
.21695 .28293 m
.21751 .28205 L
s
1 0 0 r
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
1 .344 0 r
.5335 .37538 m
.53344 .37242 L
s
0 1 .511 r
.43476 .68337 m
.44994 .67259 L
s
1 .417 0 r
.68787 .67183 m
.68613 .67567 L
s
1 .825 0 r
.41797 .61685 m
.42313 .61254 L
s
0 .434 1 r
.395 .5855 m
.38293 .59291 L
s
.395 .5855 m
.36812 .61171 L
s
1 .022 0 r
.87273 .6122 m
.87288 .61231 L
s
.87261 .6123 m
.87273 .6122 L
s
.87273 .6122 m
.87278 .61221 L
s
.87288 .61231 m
.87276 .61242 L
s
.87278 .61221 m
.87288 .61231 L
s
.87276 .61242 m
.87261 .6123 L
s
.87261 .6123 m
.87278 .61221 L
s
.87278 .61221 m
.87276 .61242 L
s
1 .035 0 r
.21741 .28207 m
.21759 .28229 L
s
.2172 .28216 m
.21741 .28207 L
s
.21741 .28207 m
.21751 .28205 L
s
.21759 .28229 m
.21738 .28239 L
s
.21751 .28205 m
.21759 .28229 L
s
.21738 .28239 m
.2172 .28216 L
s
.2172 .28216 m
.21751 .28205 L
s
.21751 .28205 m
.21738 .28239 L
s
1 0 0 r
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
1 .026 0 r
.8072 .58174 m
.80735 .58111 L
s
.425 1 0 r
.56783 .52174 m
.53596 .48653 L
s
1 0 0 r
.32846 .46175 m
.32846 .46175 L
s
1 .151 0 r
.39052 .31175 m
.39508 .3089 L
s
1 .001 0 r
.0891 .40175 m
.0891 .40173 L
s
1 .028 0 r
.15116 .25176 m
.15154 .25104 L
s
1 .001 0 r
.0891 .40173 m
.0891 .40174 L
s
.0891 .40173 m
.0891 .40173 L
s
.0891 .40173 m
.0891 .40173 L
s
.0891 .40174 m
.0891 .40174 L
s
.0891 .40173 m
.0891 .40174 L
s
.0891 .40174 m
.0891 .40173 L
s
.0891 .40173 m
.0891 .40173 L
s
.0891 .40173 m
.0891 .40174 L
s
0 .434 1 r
.36812 .61171 m
.39357 .622 L
s
.36812 .61171 m
.38293 .59291 L
s
.50164 .57061 m
.36812 .61171 L
s
1 .303 0 r
.57423 .34393 m
.57476 .34137 L
s
.973 1 0 r
.41854 .6415 m
.41776 .64204 L
s
.4181 .63145 m
.41854 .6415 L
s
.41854 .6415 m
.41165 .63685 L
s
.42422 .63662 m
.41854 .6415 L
s
.41546 .61737 m
.41854 .6415 L
s
1 .141 0 r
.69952 .58032 m
.70041 .58108 L
s
.6987 .58099 m
.69952 .58032 L
s
.69952 .58032 m
.69974 .58036 L
s
1 .028 0 r
.15148 .25105 m
.15163 .25123 L
s
.1513 .25113 m
.15148 .25105 L
s
.15148 .25105 m
.15154 .25104 L
s
1 .026 0 r
.80731 .58111 m
.80748 .58124 L
s
.80716 .58123 m
.80731 .58111 L
s
.80731 .58111 m
.80735 .58111 L
s
1 .028 0 r
.15163 .25123 m
.15145 .25131 L
s
.15154 .25104 m
.15163 .25123 L
s
1 .026 0 r
.80748 .58124 m
.80733 .58137 L
s
.80735 .58111 m
.80748 .58124 L
s
.425 1 0 r
.45019 .5204 m
.45482 .53316 L
s
1 .026 0 r
.80733 .58137 m
.80716 .58123 L
s
.80716 .58123 m
.80735 .58111 L
s
1 .028 0 r
.15145 .25131 m
.1513 .25113 L
s
.1513 .25113 m
.15154 .25104 L
s
.15154 .25104 m
.15145 .25131 L
s
1 .253 0 r
.46447 .34111 m
.46368 .34142 L
s
.46373 .33904 m
.46447 .34111 L
s
.46559 .33957 m
.46447 .34111 L
s
1 .026 0 r
.80735 .58111 m
.80733 .58137 L
s
1 .015 0 r
.2007 .58111 m
.20067 .58112 L
s
.20069 .58096 m
.2007 .58111 L
s
.2007 .58111 m
.20059 .58104 L
s
.20078 .58104 m
.2007 .58111 L
s
.20061 .58074 m
.2007 .58111 L
s
.20069 .58096 m
.20059 .58104 L
s
.20078 .58104 m
.20069 .58096 L
s
1 .141 0 r
.70041 .58108 m
.69959 .58175 L
s
.69974 .58036 m
.70041 .58108 L
s
1 .253 0 r
.46293 .33935 m
.46373 .33904 L
s
.46373 .33904 m
.46559 .33957 L
s
1 .015 0 r
.20059 .58104 m
.20067 .58112 L
s
.20067 .58112 m
.20078 .58104 L
s
1 .141 0 r
.69959 .58175 m
.6987 .58099 L
s
.6987 .58099 m
.69974 .58036 L
s
1 .003 0 r
.80385 .40072 m
.80384 .40072 L
s
.80384 .40069 m
.80385 .40072 L
s
.80385 .40072 m
.80382 .40071 L
s
.80386 .4007 m
.80385 .40072 L
s
.80382 .40064 m
.80385 .40072 L
s
.80384 .40069 m
.80382 .40071 L
s
.80386 .4007 m
.80384 .40069 L
s
.80382 .40071 m
.80384 .40072 L
s
.80384 .40072 m
.80386 .4007 L
s
1 .032 0 r
.74172 .55073 m
.74178 .54994 L
s
1 .001 0 r
.2627 .43066 m
.26271 .43065 L
s
1 .095 0 r
.3248 .28058 m
.32719 .27849 L
s
1 .001 0 r
.26271 .43065 m
.26271 .43065 L
s
.2627 .43065 m
.26271 .43065 L
s
.26271 .43065 m
.26271 .43065 L
s
.26271 .43065 m
.26271 .43065 L
s
.26271 .43065 m
.26271 .43065 L
s
.26271 .43065 m
.2627 .43065 L
s
.2627 .43065 m
.26271 .43065 L
s
.26271 .43065 m
.26271 .43065 L
s
1 .141 0 r
.69974 .58036 m
.69959 .58175 L
s
1 .459 0 r
.37788 .64069 m
.3769 .64096 L
s
.37711 .63622 m
.37788 .64069 L
s
.37788 .64069 m
.37426 .63885 L
s
.37975 .63832 m
.37788 .64069 L
s
.37346 .63013 m
.37788 .64069 L
s
1 .229 0 r
.61317 .31031 m
.61389 .31057 L
s
.61382 .30844 m
.61317 .31031 L
s
.61556 .3101 m
.61317 .31031 L
s
.61455 .30869 m
.61382 .30844 L
s
.61382 .30844 m
.61556 .3101 L
s
1 .068 0 r
.30888 .58038 m
.30879 .58039 L
s
.30884 .57971 m
.30888 .58038 L
s
.30888 .58038 m
.3084 .58006 L
s
.30923 .58004 m
.30888 .58038 L
s
.30857 .57874 m
.30888 .58038 L
s
1 .09 0 r
.67516 .34015 m
.67469 .34021 L
s
.67465 .33936 m
.67516 .34015 L
s
.67516 .34015 m
.67425 .34002 L
s
.6751 .33954 m
.67516 .34015 L
s
.67271 .33832 m
.67516 .34015 L
s
1 .229 0 r
.61556 .3101 m
.61389 .31057 L
s
.61455 .30869 m
.61556 .3101 L
s
.60704 .3071 m
.61556 .3101 L
s
1 .09 0 r
.67465 .33936 m
.67425 .34002 L
s
.6751 .33954 m
.67465 .33936 L
s
.67425 .34002 m
.67469 .34021 L
s
1 .068 0 r
.30884 .57971 m
.3084 .58006 L
s
.30923 .58004 m
.30884 .57971 L
s
1 .032 0 r
.74176 .54994 m
.74196 .55009 L
s
.74157 .5501 m
.74176 .54994 L
s
.74176 .54994 m
.74178 .54994 L
s
1 .021 0 r
.73868 .37 m
.73861 .37 L
s
.73859 .3698 m
.73868 .37 L
s
.73868 .37 m
.73848 .36994 L
s
.73872 .36986 m
.73868 .37 L
s
.7383 .3695 m
.73868 .37 L
s
1 .151 0 r
.39482 .30992 m
.39414 .31017 L
s
.3942 .30877 m
.39482 .30992 L
s
.39508 .3089 m
.39482 .30992 L
s
.39351 .30903 m
.3942 .30877 L
s
.3942 .30877 m
.39508 .3089 L
s
1 .021 0 r
.73859 .3698 m
.73848 .36994 L
s
.73872 .36986 m
.73859 .3698 L
s
.73848 .36994 m
.73861 .37 L
s
1 .032 0 r
.74178 .55026 m
.74157 .5501 L
s
.74157 .5501 m
.74178 .54994 L
s
.74196 .55009 m
.74178 .55026 L
s
.74178 .54994 m
.74196 .55009 L
s
1 .021 0 r
.73861 .37 m
.73872 .36986 L
s
1 .068 0 r
.3084 .58006 m
.30879 .58039 L
s
1 .032 0 r
.74178 .54994 m
.74178 .55026 L
s
1 .068 0 r
.30879 .58039 m
.30923 .58004 L
s
1 .253 0 r
.46559 .33957 m
.46368 .34142 L
s
.46293 .33935 m
.46559 .33957 L
s
1 .003 0 r
.13474 .54979 m
.13474 .54979 L
s
.13474 .54976 m
.13474 .54979 L
s
.13474 .54979 m
.13472 .54978 L
s
.13476 .54978 m
.13474 .54979 L
s
.13473 .54971 m
.13474 .54979 L
s
.13474 .54976 m
.13472 .54978 L
s
.13476 .54978 m
.13474 .54976 L
s
1 .09 0 r
.67469 .34021 m
.6751 .33954 L
s
1 .003 0 r
.13474 .54979 m
.13476 .54978 L
s
.13472 .54978 m
.13474 .54979 L
s
1 .253 0 r
.46368 .34142 m
.46293 .33935 L
s
1 .336 0 r
.51034 .30945 m
.50997 .30968 L
s
.50998 .30656 m
.51034 .30945 L
s
.51281 .30779 m
.51034 .30945 L
s
1 .008 0 r
.91583 .57974 m
.91588 .57956 L
s
.808 1 0 r
.61404 .66985 m
.64502 .64728 L
s
1 .039 0 r
.67617 .51967 m
.67597 .51872 L
s
1 0 0 r
.43651 .4596 m
.43651 .4596 L
s
1 .336 0 r
.49865 .30943 m
.51281 .30779 L
s
1 .002 0 r
.19686 .39954 m
.19687 .39949 L
s
1 .066 0 r
.25899 .24936 m
.2604 .2478 L
s
1 .002 0 r
.19687 .39949 m
.19688 .3995 L
s
.19686 .3995 m
.19687 .39949 L
s
.19687 .39949 m
.19687 .39949 L
s
.19688 .3995 m
.19687 .39951 L
s
.19687 .39949 m
.19688 .3995 L
s
.19687 .39951 m
.19686 .3995 L
s
.19686 .3995 m
.19687 .39949 L
s
.19687 .39949 m
.19687 .39951 L
s
1 .459 0 r
.37711 .63622 m
.37426 .63885 L
s
.37975 .63832 m
.37711 .63622 L
s
1 .008 0 r
.91586 .57956 m
.91591 .5796 L
s
.91582 .5796 m
.91586 .57956 L
s
.91586 .57956 m
.91588 .57956 L
s
.91591 .5796 m
.91587 .57963 L
s
.91588 .57956 m
.91591 .5796 L
s
.91587 .57963 m
.91582 .5796 L
s
.91582 .5796 m
.91588 .57956 L
s
1 .293 0 r
.33488 .6697 m
.33401 .66993 L
s
.33418 .66688 m
.33488 .6697 L
s
.33488 .6697 m
.33239 .66864 L
s
.3358 .66817 m
.33488 .6697 L
s
.33095 .66321 m
.33488 .6697 L
s
1 .008 0 r
.91588 .57956 m
.91587 .57963 L
s
1 .095 0 r
.32674 .27847 m
.32719 .27915 L
s
.32624 .27866 m
.32674 .27847 L
s
.32674 .27847 m
.32719 .27849 L
s
.32719 .27915 m
.32669 .27934 L
s
.32719 .27849 m
.32719 .27915 L
s
1 .336 0 r
.50961 .30679 m
.50998 .30656 L
s
.50998 .30656 m
.51281 .30779 L
s
1 .457 0 r
.66113 .60601 m
.66388 .60878 L
s
.65858 .6079 m
.66113 .60601 L
s
.66113 .60601 m
.66252 .60626 L
s
1 .151 0 r
.39414 .31017 m
.39351 .30903 L
s
.39508 .3089 m
.39414 .31017 L
s
.39351 .30903 m
.39508 .3089 L
s
0 1 .566 r
.64502 .54922 m
.62572 .5681 L
s
.61831 .5473 m
.64502 .54922 L
s
1 .229 0 r
.61389 .31057 m
.61455 .30869 L
s
.973 1 0 r
.4181 .63145 m
.41165 .63685 L
s
.42422 .63662 m
.4181 .63145 L
s
1 .095 0 r
.32669 .27934 m
.32624 .27866 L
s
.32624 .27866 m
.32719 .27849 L
s
1 .039 0 r
.676 .51872 m
.67624 .51889 L
s
.67577 .51894 m
.676 .51872 L
s
.676 .51872 m
.67597 .51872 L
s
0 .813 1 r
.65371 .5791 m
.64571 .58566 L
s
.64454 .55329 m
.65371 .5791 L
s
.66993 .56195 m
.65371 .5791 L
s
1 .095 0 r
.32719 .27849 m
.32669 .27934 L
s
1 .039 0 r
.67602 .51911 m
.67577 .51894 L
s
.67577 .51894 m
.67597 .51872 L
s
.67624 .51889 m
.67602 .51911 L
s
.67597 .51872 m
.67624 .51889 L
s
1 .293 0 r
.33418 .66688 m
.33239 .66864 L
s
.3358 .66817 m
.33418 .66688 L
s
1 .039 0 r
.67597 .51872 m
.67602 .51911 L
s
1 .066 0 r
.26014 .24781 m
.26047 .24827 L
s
.25977 .24796 m
.26014 .24781 L
s
.26014 .24781 m
.2604 .2478 L
s
.26047 .24827 m
.26009 .24841 L
s
.2604 .2478 m
.26047 .24827 L
s
1 .459 0 r
.37426 .63885 m
.3769 .64096 L
s
1 .007 0 r
.85034 .54869 m
.85036 .54852 L
s
0 .197 1 r
.54837 .63885 m
.6962 .5956 L
s
1 .032 0 r
.61054 .48859 m
.60992 .48787 L
s
1 .003 0 r
.37074 .42848 m
.3708 .42841 L
s
1 .241 0 r
.43291 .27821 m
.44183 .27494 L
s
1 .003 0 r
.13094 .36837 m
.13096 .3683 L
s
1 .457 0 r
.66388 .60878 m
.66132 .61068 L
s
.66252 .60626 m
.66388 .60878 L
s
1 .003 0 r
.13095 .3683 m
.13097 .36832 L
s
.13094 .36831 m
.13095 .3683 L
s
.13095 .3683 m
.13096 .3683 L
s
.37078 .4284 m
.3708 .42843 L
s
.37077 .42841 m
.37078 .4284 L
s
.37078 .4284 m
.3708 .42841 L
s
.13097 .36832 m
.13095 .36833 L
s
.13096 .3683 m
.13097 .36832 L
s
.3708 .42843 m
.37078 .42844 L
s
.3708 .42841 m
.3708 .42843 L
s
.13095 .36833 m
.13094 .36831 L
s
.13094 .36831 m
.13096 .3683 L
s
.13096 .3683 m
.13095 .36833 L
s
.37078 .42844 m
.37077 .42841 L
s
.37077 .42841 m
.3708 .42841 L
s
.3708 .42841 m
.37078 .42844 L
s
0 1 .566 r
.62572 .5681 m
.61831 .5473 L
s
1 .007 0 r
.85035 .54852 m
.8504 .54856 L
s
.85031 .54856 m
.85035 .54852 L
s
.85035 .54852 m
.85036 .54852 L
s
.85036 .54859 m
.85031 .54856 L
s
.85031 .54856 m
.85036 .54852 L
s
.8504 .54856 m
.85036 .54859 L
s
.85036 .54852 m
.8504 .54856 L
s
.85036 .54852 m
.85036 .54859 L
s
1 .066 0 r
.26009 .24841 m
.25977 .24796 L
s
.25977 .24796 m
.2604 .2478 L
s
.2604 .2478 m
.26009 .24841 L
s
1 .293 0 r
.33239 .66864 m
.33401 .66993 L
s
1 .323 0 r
.55212 .27784 m
.55234 .27801 L
s
.55231 .27503 m
.55212 .27784 L
s
.55508 .27669 m
.55212 .27784 L
s
1 .336 0 r
.51281 .30779 m
.50997 .30968 L
s
.50961 .30679 m
.51281 .30779 L
s
1 .032 0 r
.61004 .48786 m
.61022 .48796 L
s
.60987 .48807 m
.61004 .48786 L
s
.61004 .48786 m
.60992 .48787 L
s
.61005 .48817 m
.60987 .48807 L
s
.60987 .48807 m
.60992 .48787 L
s
1 .459 0 r
.3769 .64096 m
.37975 .63832 L
s
1 .032 0 r
.61022 .48796 m
.61005 .48817 L
s
.60992 .48787 m
.61022 .48796 L
s
1 .323 0 r
.55252 .27521 m
.55231 .27503 L
s
.55231 .27503 m
.55508 .27669 L
s
1 .032 0 r
.60992 .48787 m
.61005 .48817 L
s
1 .012 0 r
.2427 .54796 m
.24269 .54796 L
s
.2427 .54785 m
.2427 .54796 L
s
.2427 .54796 m
.24262 .5479 L
s
.24277 .54791 m
.2427 .54796 L
s
.24267 .54767 m
.2427 .54796 L
s
.2427 .54785 m
.24262 .5479 L
s
.24277 .54791 m
.2427 .54785 L
s
.24269 .54796 m
.24277 .54791 L
s
.24262 .5479 m
.24269 .54796 L
s
1 .293 0 r
.33401 .66993 m
.3358 .66817 L
s
1 .006 0 r
.84704 .36739 m
.84703 .36739 L
s
.84703 .36733 m
.84704 .36739 L
s
.84704 .36739 m
.84699 .36737 L
s
.84706 .36735 m
.84704 .36739 L
s
.84698 .36725 m
.84704 .36739 L
s
.84703 .36733 m
.84699 .36737 L
s
.84706 .36735 m
.84703 .36733 L
s
.84699 .36737 m
.84703 .36739 L
s
0 1 .566 r
.41721 .54646 m
.42478 .56727 L
s
1 .006 0 r
.84703 .36739 m
.84706 .36735 L
s
1 .457 0 r
.66132 .61068 m
.65858 .6079 L
s
.65858 .6079 m
.66252 .60626 L
s
1 .336 0 r
.50997 .30968 m
.50961 .30679 L
s
1 .271 0 r
.72256 .66796 m
.72663 .66201 L
s
1 .005 0 r
.78477 .5176 m
.78477 .51748 L
s
1 0 0 r
.54483 .45746 m
.54483 .45746 L
s
1 .007 0 r
.30488 .39732 m
.30498 .39715 L
s
1 .158 0 r
.36709 .24696 m
.37208 .24402 L
s
1 .003 0 r
.06494 .33717 m
.06496 .33708 L
s
0 1 .511 r
.42023 .66794 m
.43476 .68337 L
s
1 .003 0 r
.06495 .33708 m
.06497 .3371 L
s
.06493 .3371 m
.06495 .33708 L
s
.06495 .33708 m
.06496 .33708 L
s
.06497 .3371 m
.06495 .33712 L
s
.06496 .33708 m
.06497 .3371 L
s
.06495 .33712 m
.06493 .3371 L
s
.06493 .3371 m
.06496 .33708 L
s
.06496 .33708 m
.06495 .33712 L
s
1 .005 0 r
.78477 .51748 m
.7848 .5175 L
s
.78474 .5175 m
.78477 .51748 L
s
.78477 .51748 m
.78477 .51748 L
s
.78477 .51753 m
.78474 .5175 L
s
.78474 .5175 m
.78477 .51748 L
s
.7848 .5175 m
.78477 .51753 L
s
.78477 .51748 m
.7848 .5175 L
s
1 .007 0 r
.30496 .39715 m
.305 .3972 L
s
.30492 .39718 m
.30496 .39715 L
s
.30496 .39715 m
.30498 .39715 L
s
.305 .3972 m
.30496 .39722 L
s
.30498 .39715 m
.305 .3972 L
s
1 .005 0 r
.78477 .51748 m
.78477 .51753 L
s
1 .007 0 r
.30496 .39722 m
.30492 .39718 L
s
.30492 .39718 m
.30498 .39715 L
s
.30498 .39715 m
.30496 .39722 L
s
0 .813 1 r
.63643 .55957 m
.64454 .55329 L
s
.64454 .55329 m
.66993 .56195 L
s
1 .323 0 r
.55508 .27669 m
.55234 .27801 L
s
.55252 .27521 m
.55508 .27669 L
s
.54128 .27585 m
.55508 .27669 L
s
1 .07 0 r
.35078 .54735 m
.35079 .54736 L
s
.35082 .54665 m
.35078 .54735 L
s
.35078 .54735 m
.35037 .54698 L
s
.35123 .54703 m
.35078 .54735 L
s
.35088 .54563 m
.35078 .54735 L
s
.35082 .54665 m
.35037 .54698 L
s
.35123 .54703 m
.35082 .54665 L
s
1 .241 0 r
.44078 .27646 m
.44001 .27671 L
s
.44008 .27449 m
.44078 .27646 L
s
.44183 .27494 m
.44078 .27646 L
s
1 .023 0 r
.78178 .3366 m
.7817 .33659 L
s
.78169 .33637 m
.78178 .3366 L
s
.78178 .3366 m
.78156 .33653 L
s
.78183 .33644 m
.78178 .3366 L
s
.78137 .33603 m
.78178 .3366 L
s
0 .197 1 r
.38562 .646 m
.39851 .63739 L
s
.39851 .63739 m
.38725 .60661 L
s
.39851 .63739 m
.35844 .6347 L
s
1 .023 0 r
.78169 .33637 m
.78156 .33653 L
s
.78183 .33644 m
.78169 .33637 L
s
.78156 .33653 m
.7817 .33659 L
s
1 .241 0 r
.4393 .27473 m
.44008 .27449 L
s
.44008 .27449 m
.44183 .27494 L
s
1 .172 0 r
.65397 .27631 m
.65465 .27653 L
s
.65458 .27494 m
.65397 .27631 L
s
.65579 .2763 m
.65397 .27631 L
s
.65579 .2763 m
.65465 .27653 L
s
.65458 .27494 m
.65579 .2763 L
s
.65526 .27516 m
.65579 .2763 L
s
.64992 .27347 m
.65579 .2763 L
s
1 .075 0 r
.71757 .30638 m
.71722 .30641 L
s
.71717 .30571 m
.71757 .30638 L
s
.71757 .30638 m
.71682 .30625 L
s
.71756 .30587 m
.71757 .30638 L
s
.71569 .30477 m
.71757 .30638 L
s
1 .457 0 r
.66252 .60626 m
.66132 .61068 L
s
1 .07 0 r
.35079 .54736 m
.35123 .54703 L
s
1 .023 0 r
.7817 .33659 m
.78183 .33644 L
s
1 .172 0 r
.65526 .27516 m
.65458 .27494 L
s
1 .07 0 r
.35037 .54698 m
.35079 .54736 L
s
1 .075 0 r
.71717 .30571 m
.71682 .30625 L
s
.71756 .30587 m
.71717 .30571 L
s
.71682 .30625 m
.71722 .30641 L
s
1 .344 0 r
.63336 .54427 m
.63553 .54596 L
s
.6313 .54604 m
.63336 .54427 L
s
.63336 .54427 m
.63343 .5443 L
s
1 .002 0 r
.1767 .5166 m
.1767 .5166 L
s
.1767 .51659 m
.1767 .5166 L
s
.1767 .5166 m
.17669 .51659 L
s
.17671 .5166 m
.1767 .5166 L
s
.1767 .51656 m
.1767 .5166 L
s
.1767 .51659 m
.17669 .51659 L
s
.17671 .5166 m
.1767 .51659 L
s
.1767 .5166 m
.17671 .5166 L
s
.17669 .51659 m
.1767 .5166 L
s
1 .607 0 r
.65688 .63692 m
.66549 .62325 L
s
1 .002 0 r
.71913 .48647 m
.71911 .48643 L
s
1 .032 0 r
.47904 .42629 m
.48022 .4259 L
s
1 .008 0 r
.23894 .36612 m
.23905 .36591 L
s
1 .002 0 r
.71911 .48643 m
.71913 .48644 L
s
.7191 .48644 m
.71911 .48643 L
s
.71911 .48643 m
.71911 .48643 L
s
.71912 .48645 m
.7191 .48644 L
s
.7191 .48644 m
.71911 .48643 L
s
.71913 .48644 m
.71912 .48645 L
s
.71911 .48643 m
.71913 .48644 L
s
.71911 .48643 m
.71912 .48645 L
s
1 .075 0 r
.71722 .30641 m
.71756 .30587 L
s
.973 1 0 r
.41165 .63685 m
.41776 .64204 L
s
1 .08 0 r
.22352 .66692 m
.22329 .66697 L
s
.22336 .66614 m
.22352 .66692 L
s
.22352 .66692 m
.22285 .6666 L
s
.2238 .66651 m
.22352 .66692 L
s
.22257 .66511 m
.22352 .66692 L
s
1 .008 0 r
.23903 .36591 m
.23908 .36596 L
s
.23898 .36594 m
.23903 .36591 L
s
.23903 .36591 m
.23905 .36591 L
s
.23908 .36596 m
.23903 .36599 L
s
.23905 .36591 m
.23908 .36596 L
s
.23903 .36599 m
.23898 .36594 L
s
.23898 .36594 m
.23905 .36591 L
s
.23905 .36591 m
.23903 .36599 L
s
1 .032 0 r
.48008 .42608 m
.47998 .42613 L
s
.47999 .42582 m
.48008 .42608 L
s
.48022 .4259 m
.48008 .42608 L
s
.47989 .42587 m
.47999 .42582 L
s
.47999 .42582 m
.48022 .4259 L
s
1 .323 0 r
.55234 .27801 m
.55252 .27521 L
s
1 .08 0 r
.22336 .66614 m
.22285 .6666 L
s
.2238 .66651 m
.22336 .66614 L
s
.973 1 0 r
.41776 .64204 m
.42422 .63662 L
s
1 .032 0 r
.48022 .4259 m
.47998 .42613 L
s
.47989 .42587 m
.48022 .4259 L
s
.47998 .42613 m
.47989 .42587 L
s
.787 1 0 r
.60296 .53704 m
.61019 .54435 L
s
.59602 .54191 m
.60296 .53704 L
s
.60296 .53704 m
.60636 .53736 L
s
1 .08 0 r
.22285 .6666 m
.22329 .66697 L
s
.22329 .66697 m
.2238 .66651 L
s
1 .172 0 r
.65465 .27653 m
.65526 .27516 L
s
1 .158 0 r
.37174 .24511 m
.37105 .24533 L
s
.37112 .24389 m
.37174 .24511 L
s
.37208 .24402 m
.37174 .24511 L
s
.37042 .2441 m
.37112 .24389 L
s
.37112 .24389 m
.37208 .24402 L
s
1 .344 0 r
.63347 .54773 m
.6313 .54604 L
s
.6313 .54604 m
.63343 .5443 L
s
1 .271 0 r
.59242 .24501 m
.59296 .24517 L
s
.5929 .2427 m
.59242 .24501 L
s
.59514 .24439 m
.59242 .24501 L
s
.973 1 0 r
.63445 .6285 m
.63965 .63576 L
s
.62959 .63182 m
.63445 .6285 L
s
.63445 .6285 m
.63997 .62985 L
s
1 .344 0 r
.63553 .54596 m
.63347 .54773 L
s
.63343 .5443 m
.63553 .54596 L
s
.542 1 0 r
.62656 .6663 m
.61557 .67707 L
s
.61135 .66529 m
.62656 .6663 L
s
1 .241 0 r
.44183 .27494 m
.44001 .27671 L
s
.4393 .27473 m
.44183 .27494 L
s
.44001 .27671 m
.4393 .27473 L
s
1 .271 0 r
.59344 .24286 m
.5929 .2427 L
s
.5929 .2427 m
.59514 .24439 L
s
1 0 0 r
.11064 .48542 m
.11064 .48542 L
s
.11064 .48542 m
.11064 .48542 L
s
.11064 .48542 m
.11064 .48542 L
s
.11065 .48542 m
.11064 .48542 L
s
.11064 .48542 m
.11064 .48542 L
s
.11064 .48542 m
.11064 .48542 L
s
.11065 .48542 m
.11064 .48542 L
s
.11064 .48542 m
.11065 .48542 L
s
.11064 .48542 m
.11064 .48542 L
s
1 .077 0 r
.83136 .66606 m
.83228 .66433 L
s
1 .001 0 r
.89364 .51552 m
.89364 .51549 L
s
0 1 .077 r
.59112 .60585 m
.61927 .5571 L
s
1 0 0 r
.6534 .45531 m
.6534 .45531 L
s
1 .039 0 r
.41317 .39509 m
.41425 .39434 L
s
1 .293 0 r
.47545 .24455 m
.48758 .24243 L
s
1 .009 0 r
.17293 .33488 m
.17303 .33465 L
s
1 .001 0 r
.89364 .51549 m
.89365 .5155 L
s
.89363 .5155 m
.89364 .51549 L
s
.89364 .51549 m
.89364 .51549 L
s
.89364 .5155 m
.89363 .5155 L
s
.89363 .5155 m
.89364 .51549 L
s
.89365 .5155 m
.89364 .5155 L
s
.89364 .51549 m
.89365 .5155 L
s
.89364 .51549 m
.89364 .5155 L
s
.542 1 0 r
.61557 .67707 m
.61135 .66529 L
s
1 .009 0 r
.17301 .33466 m
.17306 .33471 L
s
.17295 .33469 m
.17301 .33466 L
s
.17301 .33466 m
.17303 .33465 L
s
1 .271 0 r
.59514 .24439 m
.59296 .24517 L
s
.59344 .24286 m
.59514 .24439 L
s
.58407 .24214 m
.59514 .24439 L
s
1 .009 0 r
.17306 .33471 m
.173 .33474 L
s
.17303 .33465 m
.17306 .33471 L
s
.173 .33474 m
.17295 .33469 L
s
.17295 .33469 m
.17303 .33465 L
s
.17303 .33465 m
.173 .33474 L
s
.973 1 0 r
.63965 .63576 m
.6348 .6391 L
s
.63997 .62985 m
.63965 .63576 L
s
.808 1 0 r
.41839 .66582 m
.41748 .66658 L
s
.41787 .65414 m
.41839 .66582 L
s
.41839 .66582 m
.41035 .66047 L
s
.425 .66022 m
.41839 .66582 L
s
.41478 .63805 m
.41839 .66582 L
s
1 .158 0 r
.37105 .24533 m
.37042 .2441 L
s
.37208 .24402 m
.37105 .24533 L
s
.37042 .2441 m
.37208 .24402 L
s
1 .293 0 r
.48563 .24404 m
.48514 .2442 L
s
.48517 .24152 m
.48563 .24404 L
s
.48758 .24243 m
.48563 .24404 L
s
0 .197 1 r
.38725 .60661 m
.3742 .61482 L
s
.38725 .60661 m
.35844 .6347 L
s
1 .039 0 r
.41404 .3943 m
.41421 .39459 L
s
.41386 .39439 m
.41404 .3943 L
s
.41404 .3943 m
.41425 .39434 L
s
.41421 .39459 m
.41403 .39467 L
s
.41425 .39434 m
.41421 .39459 L
s
1 .344 0 r
.63343 .5443 m
.63347 .54773 L
s
1 .039 0 r
.41403 .39467 m
.41386 .39439 L
s
.41386 .39439 m
.41425 .39434 L
s
.41425 .39434 m
.41403 .39467 L
s
1 .293 0 r
.48468 .24168 m
.48517 .24152 L
s
.48517 .24152 m
.48758 .24243 L
s
1 .021 0 r
.5881 .42442 m
.58817 .42446 L
s
.58817 .42426 m
.5881 .42442 L
s
.58831 .42442 m
.5881 .42442 L
s
.58831 .42442 m
.58817 .42446 L
s
.58817 .42426 m
.58831 .42442 L
s
.58825 .42429 m
.58831 .42442 L
s
.5876 .42411 m
.58831 .42442 L
s
.58825 .42429 m
.58817 .42426 L
s
.58817 .42446 m
.58825 .42429 L
s
1 .007 0 r
.28487 .51465 m
.28488 .51465 L
s
.28488 .51458 m
.28487 .51465 L
s
.28487 .51465 m
.28484 .51461 L
s
.28492 .51462 m
.28487 .51465 L
s
.28489 .51448 m
.28487 .51465 L
s
.28488 .51458 m
.28484 .51461 L
s
.28492 .51462 m
.28488 .51458 L
s
.28488 .51465 m
.28492 .51462 L
s
.28484 .51461 m
.28488 .51465 L
s
1 .121 0 r
.76566 .63499 m
.76685 .63218 L
s
1 0 0 r
.82798 .48436 m
.82798 .48435 L
s
1 .032 0 r
.34721 .36385 m
.34794 .36314 L
s
1 .009 0 r
.10683 .3036 m
.10692 .30337 L
s
1 0 0 r
.82798 .48435 m
.82798 .48435 L
s
.82798 .48435 m
.82798 .48435 L
s
.82798 .48435 m
.82798 .48435 L
s
.82798 .48435 m
.82798 .48435 L
s
.82798 .48435 m
.82798 .48435 L
s
.82798 .48435 m
.82798 .48435 L
s
.82798 .48435 m
.82798 .48435 L
s
.82798 .48435 m
.82798 .48435 L
s
1 .009 0 r
.1069 .30338 m
.10695 .30343 L
s
.10685 .30341 m
.1069 .30338 L
s
.1069 .30338 m
.10692 .30337 L
s
.10695 .30343 m
.10689 .30346 L
s
.10692 .30337 m
.10695 .30343 L
s
.10689 .30346 m
.10685 .30341 L
s
.10685 .30341 m
.10692 .30337 L
s
.10692 .30337 m
.10689 .30346 L
s
1 .271 0 r
.59296 .24517 m
.59344 .24286 L
s
.787 1 0 r
.61019 .54435 m
.60325 .54924 L
s
.60636 .53736 m
.61019 .54435 L
s
1 .077 0 r
.83206 .66428 m
.83255 .66472 L
s
.83164 .66463 m
.83206 .66428 L
s
.83206 .66428 m
.83228 .66433 L
s
0 .197 1 r
.35844 .6347 m
.38562 .646 L
s
.35844 .6347 m
.3742 .61482 L
s
.50149 .59121 m
.35844 .6347 L
s
1 .029 0 r
.15673 .63469 m
.15666 .6347 L
s
.1567 .63441 m
.15673 .63469 L
s
.15673 .63469 m
.15651 .63456 L
s
.15685 .63455 m
.15673 .63469 L
s
.15647 .63402 m
.15673 .63469 L
s
.1567 .63441 m
.15651 .63456 L
s
.15685 .63455 m
.1567 .63441 L
s
1 .077 0 r
.83255 .66472 m
.83213 .66508 L
s
.83228 .66433 m
.83255 .66472 L
s
1 .032 0 r
.3478 .36313 m
.34796 .36335 L
s
.34762 .36321 m
.3478 .36313 L
s
.3478 .36313 m
.34794 .36314 L
s
1 .029 0 r
.15651 .63456 m
.15666 .6347 L
s
1 .032 0 r
.34796 .36335 m
.34778 .36343 L
s
.34794 .36314 m
.34796 .36335 L
s
1 .029 0 r
.15666 .6347 m
.15685 .63455 L
s
1 .024 0 r
.825 .30303 m
.82493 .30302 L
s
.82491 .3028 m
.825 .30303 L
s
.825 .30303 m
.82478 .30296 L
s
.82506 .30287 m
.825 .30303 L
s
.8246 .30243 m
.825 .30303 L
s
1 .077 0 r
.83213 .66508 m
.83164 .66463 L
s
.83164 .66463 m
.83228 .66433 L
s
1 .024 0 r
.82491 .3028 m
.82478 .30296 L
s
.82506 .30287 m
.82491 .3028 L
s
.82478 .30296 m
.82493 .30302 L
s
1 .032 0 r
.34778 .36343 m
.34762 .36321 L
s
.34762 .36321 m
.34794 .36314 L
s
.34794 .36314 m
.34778 .36343 L
s
1 .136 0 r
.5264 .39329 m
.52637 .39342 L
s
.52637 .39212 m
.5264 .39329 L
s
.52754 .39274 m
.5264 .39329 L
s
1 .024 0 r
.82493 .30302 m
.82506 .30287 L
s
1 .058 0 r
.39274 .5138 m
.39285 .51381 L
s
.39288 .51323 m
.39274 .5138 L
s
.39274 .5138 m
.39252 .51346 L
s
.39321 .51358 m
.39274 .5138 L
s
.39335 .5124 m
.39274 .5138 L
s
1 .077 0 r
.83228 .66433 m
.83213 .66508 L
s
1 .095 0 r
.26567 .63429 m
.26546 .63434 L
s
.26554 .63336 m
.26567 .63429 L
s
.26567 .63429 m
.26492 .63389 L
s
.26608 .63381 m
.26567 .63429 L
s
.26483 .63208 m
.26567 .63429 L
s
1 .136 0 r
.52634 .39225 m
.52637 .39212 L
s
.52637 .39212 m
.52754 .39274 L
s
1 .293 0 r
.48758 .24243 m
.48514 .2442 L
s
.48468 .24168 m
.48758 .24243 L
s
1 .058 0 r
.39288 .51323 m
.39252 .51346 L
s
.39321 .51358 m
.39288 .51323 L
s
1 .063 0 r
.76032 .27253 m
.76004 .27254 L
s
.76 .27195 m
.76032 .27253 L
s
.76032 .27253 m
.7597 .2724 L
s
.76035 .27209 m
.76032 .27253 L
s
.75882 .2711 m
.76032 .27253 L
s
1 .058 0 r
.39285 .51381 m
.39321 .51358 L
s
1 .063 0 r
.76 .27195 m
.7597 .2724 L
s
.76035 .27209 m
.76 .27195 L
s
.7597 .2724 m
.76004 .27254 L
s
1 .095 0 r
.26554 .63336 m
.26492 .63389 L
s
.26608 .63381 m
.26554 .63336 L
s
1 .134 0 r
.69717 .24222 m
.69637 .24233 L
s
.6963 .24111 m
.69717 .24222 L
s
.69717 .24222 m
.69577 .24215 L
s
.69689 .24129 m
.69717 .24222 L
s
.69296 .23972 m
.69717 .24222 L
s
1 .058 0 r
.39252 .51346 m
.39285 .51381 L
s
1 0 0 r
.21882 .48331 m
.21882 .48331 L
s
.21882 .4833 m
.21882 .48331 L
s
.21882 .48331 m
.21882 .4833 L
s
.21883 .4833 m
.21882 .48331 L
s
.21882 .4833 m
.21882 .48331 L
s
.21882 .4833 m
.21882 .4833 L
s
.21883 .4833 m
.21882 .4833 L
s
1 .134 0 r
.69577 .24215 m
.69637 .24233 L
s
.6963 .24111 m
.69577 .24215 L
s
1 0 0 r
.21882 .48331 m
.21883 .4833 L
s
.21882 .4833 m
.21882 .48331 L
s
1 .028 0 r
.94041 .66416 m
.94073 .66353 L
s
1 .229 0 r
.69988 .60387 m
.70137 .59843 L
s
1 0 0 r
.76224 .45315 m
.76224 .45315 L
s
1 .136 0 r
.52171 .39286 m
.52754 .39274 L
s
1 .026 0 r
.28118 .33258 m
.28167 .33195 L
s
1 .134 0 r
.69689 .24129 m
.6963 .24111 L
s
1 .136 0 r
.52754 .39274 m
.52637 .39342 L
s
.52634 .39225 m
.52754 .39274 L
s
1 .095 0 r
.26492 .63389 m
.26546 .63434 L
s
1 .293 0 r
.48514 .2442 m
.48468 .24168 L
s
1 .063 0 r
.76004 .27254 m
.76035 .27209 L
s
1 .095 0 r
.26546 .63434 m
.26608 .63381 L
s
1 .271 0 r
.72573 .6618 m
.72738 .66346 L
s
.72426 .66295 m
.72573 .6618 L
s
.72573 .6618 m
.72663 .66201 L
s
1 .575 0 r
.3781 .66385 m
.37686 .66425 L
s
.37713 .65825 m
.3781 .66385 L
s
.3781 .66385 m
.37354 .66157 L
s
.38045 .66092 m
.3781 .66385 L
s
.37253 .65073 m
.3781 .66385 L
s
1 .026 0 r
.28159 .33195 m
.28172 .33213 L
s
.28143 .33202 m
.28159 .33195 L
s
.28159 .33195 m
.28167 .33195 L
s
.28172 .33213 m
.28157 .3322 L
s
.28167 .33195 m
.28172 .33213 L
s
1 .136 0 r
.52637 .39342 m
.52634 .39225 L
s
1 .028 0 r
.94064 .66351 m
.94083 .66367 L
s
.9405 .66365 m
.94064 .66351 L
s
.94064 .66351 m
.94073 .66353 L
s
1 .026 0 r
.28157 .3322 m
.28143 .33202 L
s
.28143 .33202 m
.28167 .33195 L
s
.28167 .33195 m
.28157 .3322 L
s
1 .028 0 r
.94083 .66367 m
.94068 .6638 L
s
.94073 .66353 m
.94083 .66367 L
s
.94068 .6638 m
.9405 .66365 L
s
.9405 .66365 m
.94073 .66353 L
s
.94073 .66353 m
.94068 .6638 L
s
1 .134 0 r
.69637 .24233 m
.69689 .24129 L
s
1 .271 0 r
.72738 .66346 m
.7259 .66462 L
s
.72663 .66201 m
.72738 .66346 L
s
1 .002 0 r
.69646 .42196 m
.69645 .42196 L
s
.69645 .42194 m
.69646 .42196 L
s
.69646 .42196 m
.69644 .42195 L
s
.69647 .42195 m
.69646 .42196 L
s
.69642 .42191 m
.69646 .42196 L
s
.69645 .42194 m
.69644 .42195 L
s
.69647 .42195 m
.69645 .42194 L
s
.69644 .42195 m
.69645 .42196 L
s
.69645 .42196 m
.69647 .42195 L
s
.808 1 0 r
.41787 .65414 m
.41035 .66047 L
s
.425 .66022 m
.41787 .65414 L
s
1 .035 0 r
.8747 .63305 m
.87502 .63223 L
s
1 .59 0 r
.63403 .57272 m
.63414 .55826 L
s
1 .133 0 r
.45575 .36158 m
.46071 .35985 L
s
1 .022 0 r
.21507 .30126 m
.21542 .30072 L
s
1 0 0 r
.15268 .45207 m
.15268 .45207 L
s
1 .121 0 r
.76656 .63211 m
.76734 .6328 L
s
.76588 .63268 m
.76656 .63211 L
s
.76656 .63211 m
.76685 .63218 L
s
.76734 .6328 m
.76665 .63337 L
s
.76685 .63218 m
.76734 .6328 L
s
1 .271 0 r
.7259 .66462 m
.72426 .66295 L
s
.72426 .66295 m
.72663 .66201 L
s
1 .022 0 r
.21536 .30072 m
.21548 .30087 L
s
.21523 .30078 m
.21536 .30072 L
s
.21536 .30072 m
.21542 .30072 L
s
.21548 .30087 m
.21534 .30093 L
s
.21542 .30072 m
.21548 .30087 L
s
1 .039 0 r
.6317 .39134 m
.63147 .39138 L
s
.63145 .39101 m
.6317 .39134 L
s
.6317 .39134 m
.63129 .39131 L
s
.63163 .39109 m
.6317 .39134 L
s
.63052 .39063 m
.6317 .39134 L
s
1 .121 0 r
.76665 .63337 m
.76588 .63268 L
s
.76588 .63268 m
.76685 .63218 L
s
1 .039 0 r
.63145 .39101 m
.63129 .39131 L
s
.63163 .39109 m
.63145 .39101 L
s
.63129 .39131 m
.63147 .39138 L
s
1 .022 0 r
.21534 .30093 m
.21523 .30078 L
s
.21523 .30078 m
.21542 .30072 L
s
.21542 .30072 m
.21534 .30093 L
s
1 .162 0 r
.56957 .36093 m
.56988 .36109 L
s
.56986 .35955 m
.56957 .36093 L
s
.5712 .36058 m
.56957 .36093 L
s
1 .035 0 r
.87493 .63221 m
.87517 .63241 L
s
.87474 .63238 m
.87493 .63221 L
s
.87493 .63221 m
.87502 .63223 L
s
1 .039 0 r
.63147 .39138 m
.63163 .39109 L
s
1 .575 0 r
.37713 .65825 m
.37354 .66157 L
s
.38045 .66092 m
.37713 .65825 L
s
1 .121 0 r
.76685 .63218 m
.76665 .63337 L
s
.787 1 0 r
.60325 .54924 m
.59602 .54191 L
s
.59602 .54191 m
.60636 .53736 L
s
1 .035 0 r
.87517 .63241 m
.87497 .63258 L
s
.87502 .63223 m
.87517 .63241 L
s
.87497 .63258 m
.87474 .63238 L
s
.87474 .63238 m
.87502 .63223 L
s
1 .271 0 r
.72663 .66201 m
.7259 .66462 L
s
1 .162 0 r
.57017 .35972 m
.56986 .35955 L
s
.56986 .35955 m
.5712 .36058 L
s
0 .813 1 r
.39616 .57034 m
.40561 .59626 L
s
1 .035 0 r
.87502 .63223 m
.87497 .63258 L
s
1 .133 0 r
.46012 .36065 m
.4597 .36083 L
s
.45973 .35957 m
.46012 .36065 L
s
.46071 .35985 m
.46012 .36065 L
s
.45931 .35974 m
.45973 .35957 L
s
.45973 .35957 m
.46071 .35985 L
s
1 .162 0 r
.5712 .36058 m
.56988 .36109 L
s
.57017 .35972 m
.5712 .36058 L
s
.56454 .35931 m
.5712 .36058 L
s
1 .002 0 r
.32725 .48121 m
.32725 .48121 L
s
.32725 .4812 m
.32725 .48121 L
s
.32725 .48121 m
.32724 .4812 L
s
.32726 .48121 m
.32725 .48121 L
s
.32727 .48117 m
.32725 .48121 L
s
.32725 .4812 m
.32724 .4812 L
s
.32726 .48121 m
.32725 .4812 L
s
.32725 .48121 m
.32726 .48121 L
s
.32724 .4812 m
.32725 .48121 L
s
1 .047 0 r
.80891 .6019 m
.80919 .60078 L
s
1 0 0 r
.87135 .45099 m
.87135 .45099 L
s
0 1 .566 r
.56809 .54153 m
.51516 .48373 L
s
1 .09 0 r
.3897 .33027 m
.39243 .32858 L
s
1 0 0 r
.08645 .42081 m
.08645 .42081 L
s
1 .018 0 r
.14888 .26991 m
.14914 .26943 L
s
1 0 0 r
.08645 .42081 m
.08645 .42081 L
s
.08645 .42081 m
.08645 .42081 L
s
.08645 .42081 m
.08645 .42081 L
s
.08645 .42081 m
.08645 .42081 L
s
.08645 .42081 m
.08645 .42081 L
s
.08645 .42081 m
.08645 .42081 L
s
.08645 .42081 m
.08645 .42081 L
s
.08645 .42081 m
.08645 .42081 L
s
1 .116 0 r
.30778 .60169 m
.30763 .60173 L
s
.30771 .60054 m
.30778 .60169 L
s
.30778 .60169 m
.30696 .60115 L
s
.30838 .60112 m
.30778 .60169 L
s
.30725 .59892 m
.30778 .60169 L
s
.973 1 0 r
.6348 .6391 m
.62959 .63182 L
s
.62959 .63182 m
.63997 .62985 L
s
1 .018 0 r
.1491 .26944 m
.1492 .26956 L
s
.14898 .26949 m
.1491 .26944 L
s
.1491 .26944 m
.14914 .26943 L
s
.1492 .26956 m
.14908 .26961 L
s
.14914 .26943 m
.1492 .26956 L
s
1 .028 0 r
.19881 .60158 m
.19876 .60159 L
s
.19878 .6013 m
.19881 .60158 L
s
.19881 .60158 m
.1986 .60145 L
s
.19894 .60144 m
.19881 .60158 L
s
.19863 .60091 m
.19881 .60158 L
s
1 .018 0 r
.14908 .26961 m
.14898 .26949 L
s
.14898 .26949 m
.14914 .26943 L
s
.14914 .26943 m
.14908 .26961 L
s
1 .028 0 r
.19878 .6013 m
.1986 .60145 L
s
.19894 .60144 m
.19878 .6013 L
s
.1986 .60145 m
.19876 .60159 L
s
.19876 .60159 m
.19894 .60144 L
s
1 .116 0 r
.30771 .60054 m
.30696 .60115 L
s
.30838 .60112 m
.30771 .60054 L
s
1 .162 0 r
.56988 .36109 m
.57017 .35972 L
s
1 .133 0 r
.46071 .35985 m
.4597 .36083 L
s
.45931 .35974 m
.46071 .35985 L
s
.4597 .36083 m
.45931 .35974 L
s
1 .575 0 r
.37354 .66157 m
.37686 .66425 L
s
1 .116 0 r
.30696 .60115 m
.30763 .60173 L
s
.30763 .60173 m
.30838 .60112 L
s
1 .047 0 r
.80912 .60076 m
.80942 .60101 L
s
.80885 .601 m
.80912 .60076 L
s
.80912 .60076 m
.80919 .60078 L
s
.973 1 0 r
.63997 .62985 m
.6348 .6391 L
s
1 .047 0 r
.80942 .60101 m
.80916 .60124 L
s
.80919 .60078 m
.80942 .60101 L
s
.80916 .60124 m
.80885 .601 L
s
.80885 .601 m
.80919 .60078 L
s
1 .055 0 r
.80334 .23859 m
.80312 .23859 L
s
.80307 .23808 m
.80334 .23859 L
s
.80334 .23859 m
.80281 .23847 L
s
.80339 .2382 m
.80334 .23859 L
s
.80211 .2373 m
.80334 .23859 L
s
1 .09 0 r
.39228 .32918 m
.39187 .32934 L
s
.39191 .32849 m
.39228 .32918 L
s
.39243 .32858 m
.39228 .32918 L
s
.3915 .32865 m
.39191 .32849 L
s
.39191 .32849 m
.39243 .32858 L
s
1 0 0 r
.80552 .41972 m
.80552 .41972 L
s
.80552 .41972 m
.80552 .41972 L
s
.80552 .41972 m
.80551 .41972 L
s
.80552 .41972 m
.80552 .41972 L
s
.80551 .41971 m
.80552 .41972 L
s
.80552 .41972 m
.80551 .41972 L
s
.80552 .41972 m
.80552 .41972 L
s
.80551 .41972 m
.80552 .41972 L
s
.80552 .41972 m
.80552 .41972 L
s
1 .068 0 r
.74304 .57071 m
.74316 .56905 L
s
1 0 0 r
.2611 .44991 m
.2611 .44991 L
s
1 .062 0 r
.32358 .29891 m
.32514 .29756 L
s
1 .055 0 r
.80307 .23808 m
.80281 .23847 L
s
.80339 .2382 m
.80307 .23808 L
s
1 .047 0 r
.80919 .60078 m
.80916 .60124 L
s
1 .055 0 r
.80281 .23847 m
.80312 .23859 L
s
.80312 .23859 m
.80339 .2382 L
s
1 .09 0 r
.39187 .32934 m
.3915 .32865 L
s
.39243 .32858 m
.39187 .32934 L
s
.3915 .32865 m
.39243 .32858 L
s
1 .575 0 r
.37686 .66425 m
.38045 .66092 L
s
.787 1 0 r
.60636 .53736 m
.60325 .54924 L
s
1 .021 0 r
.43549 .47948 m
.43558 .47949 L
s
.43559 .47929 m
.43549 .47948 L
s
.43549 .47948 m
.43548 .47935 L
s
.43569 .47943 m
.43549 .47948 L
s
.43597 .47904 m
.43549 .47948 L
s
.43559 .47929 m
.43548 .47935 L
s
.43569 .47943 m
.43559 .47929 L
s
.43558 .47949 m
.43569 .47943 L
s
.43548 .47935 m
.43558 .47949 L
s
1 .062 0 r
.32484 .29755 m
.32513 .29799 L
s
.32452 .29767 m
.32484 .29755 L
s
.32484 .29755 m
.32514 .29756 L
s
.32513 .29799 m
.32481 .29812 L
s
.32514 .29756 m
.32513 .29799 L
s
1 .008 0 r
.13239 .56988 m
.13237 .56989 L
s
.13238 .56981 m
.13239 .56988 L
s
.13239 .56988 m
.13233 .56985 L
s
.13243 .56985 m
.13239 .56988 L
s
.13235 .5697 m
.13239 .56988 L
s
1 .229 0 r
.70101 .59835 m
.70246 .5996 L
s
.69968 .59945 m
.70101 .59835 L
s
.70101 .59835 m
.70137 .59843 L
s
1 .008 0 r
.13238 .56981 m
.13233 .56985 L
s
.13243 .56985 m
.13238 .56981 L
s
.13237 .56989 m
.13243 .56985 L
s
.13233 .56985 m
.13237 .56989 L
s
1 .007 0 r
.73972 .38855 m
.7397 .38855 L
s
.73969 .38848 m
.73972 .38855 L
s
.73972 .38855 m
.73966 .38853 L
s
.73973 .3885 m
.73972 .38855 L
s
.7396 .38839 m
.73972 .38855 L
s
.73969 .38848 m
.73966 .38853 L
s
.73973 .3885 m
.73969 .38848 L
s
.808 1 0 r
.41035 .66047 m
.41748 .66658 L
s
1 .007 0 r
.73966 .38853 m
.7397 .38855 L
s
.7397 .38855 m
.73973 .3885 L
s
1 .215 0 r
.50602 .32796 m
.50577 .32813 L
s
.50579 .32611 m
.50602 .32796 L
s
.5076 .32691 m
.50602 .32796 L
s
1 .014 0 r
.9182 .59991 m
.9183 .59957 L
s
1 .111 0 r
.67709 .53948 m
.6765 .53676 L
s
1 .215 0 r
.49849 .32795 m
.5076 .32691 L
s
1 0 0 r
.19486 .41861 m
.19486 .4186 L
s
1 .045 0 r
.25737 .26752 m
.25834 .26645 L
s
1 0 0 r
.19486 .4186 m
.19486 .4186 L
s
.19486 .4186 m
.19486 .4186 L
s
.19486 .4186 m
.19486 .4186 L
s
.19486 .4186 m
.19486 .4186 L
s
.19486 .4186 m
.19486 .4186 L
s
.19486 .4186 m
.19486 .4186 L
s
.19486 .4186 m
.19486 .4186 L
s
.19486 .4186 m
.19486 .4186 L
s
1 .062 0 r
.32481 .29812 m
.32452 .29767 L
s
.32452 .29767 m
.32514 .29756 L
s
.32514 .29756 m
.32481 .29812 L
s
1 .068 0 r
.74311 .56904 m
.74355 .56938 L
s
.74272 .56939 m
.74311 .56904 L
s
.74311 .56904 m
.74316 .56905 L
s
.808 1 0 r
.41748 .66658 m
.425 .66022 L
s
1 .215 0 r
.50554 .32627 m
.50579 .32611 L
s
.50579 .32611 m
.5076 .32691 L
s
1 .043 0 r
.67479 .35791 m
.67457 .35794 L
s
.67455 .35753 m
.67479 .35791 L
s
.67479 .35791 m
.67435 .35785 L
s
.67476 .35762 m
.67479 .35791 L
s
.67361 .35703 m
.67479 .35791 L
s
1 .014 0 r
.91827 .59957 m
.91837 .59964 L
s
.91819 .59964 m
.91827 .59957 L
s
.91827 .59957 m
.9183 .59957 L
s
.91837 .59964 m
.91829 .59971 L
s
.9183 .59957 m
.91837 .59964 L
s
1 .043 0 r
.67455 .35753 m
.67435 .35785 L
s
.67476 .35762 m
.67455 .35753 L
s
1 .014 0 r
.91829 .59971 m
.91819 .59964 L
s
.91819 .59964 m
.9183 .59957 L
s
1 .043 0 r
.67435 .35785 m
.67457 .35794 L
s
1 .141 0 r
.61134 .32761 m
.61179 .32777 L
s
.61175 .32645 m
.61134 .32761 L
s
.61283 .32748 m
.61134 .32761 L
s
1 .068 0 r
.74316 .56973 m
.74272 .56939 L
s
.74272 .56939 m
.74316 .56905 L
s
1 .014 0 r
.9183 .59957 m
.91829 .59971 L
s
1 .068 0 r
.74355 .56938 m
.74316 .56973 L
s
.74316 .56905 m
.74355 .56938 L
s
1 .229 0 r
.70246 .5996 m
.70113 .6007 L
s
.70137 .59843 m
.70246 .5996 L
s
1 .141 0 r
.6122 .32661 m
.61175 .32645 L
s
.61175 .32645 m
.61283 .32748 L
s
.61283 .32748 m
.61179 .32777 L
s
.6122 .32661 m
.61283 .32748 L
s
.60753 .32563 m
.61283 .32748 L
s
1 .229 0 r
.70113 .6007 m
.69968 .59945 L
s
.69968 .59945 m
.70137 .59843 L
s
1 .068 0 r
.74316 .56905 m
.74316 .56973 L
s
1 .043 0 r
.67457 .35794 m
.67476 .35762 L
s
0 .04 1 r
.38004 .66909 m
.3936 .65978 L
s
.3936 .65978 m
.38181 .62759 L
s
.3936 .65978 m
.35166 .657 L
s
1 .045 0 r
.25817 .26646 m
.25839 .26677 L
s
.25791 .26656 m
.25817 .26646 L
s
.25817 .26646 m
.25834 .26645 L
s
1 .141 0 r
.34962 .56908 m
.34962 .56911 L
s
.3497 .56767 m
.34962 .56908 L
s
.34962 .56908 m
.34879 .56835 L
s
.35053 .56844 m
.34962 .56908 L
s
.34982 .56564 m
.34962 .56908 L
s
1 .045 0 r
.25839 .26677 m
.25813 .26687 L
s
.25834 .26645 m
.25839 .26677 L
s
.25813 .26687 m
.25791 .26656 L
s
.25791 .26656 m
.25834 .26645 L
s
.25834 .26645 m
.25813 .26687 L
s
1 .215 0 r
.5076 .32691 m
.50577 .32813 L
s
.50554 .32627 m
.5076 .32691 L
s
1 .141 0 r
.3497 .56767 m
.34879 .56835 L
s
.35053 .56844 m
.3497 .56767 L
s
1 .229 0 r
.70137 .59843 m
.70113 .6007 L
s
1 .015 0 r
.85232 .56868 m
.85237 .56831 L
s
0 .04 1 r
.54851 .65939 m
.70357 .61461 L
s
1 .199 0 r
.61106 .50821 m
.60718 .50377 L
s
1 0 0 r
.3698 .44774 m
.3698 .44774 L
s
1 .166 0 r
.43235 .29656 m
.43853 .29431 L
s
1 .001 0 r
.12853 .38727 m
.12854 .38725 L
s
1 .035 0 r
.19108 .23609 m
.19173 .23522 L
s
1 .001 0 r
.12854 .38725 m
.12854 .38725 L
s
.12853 .38725 m
.12854 .38725 L
s
.12854 .38725 m
.12854 .38725 L
s
.12854 .38725 m
.12854 .38725 L
s
.12854 .38725 m
.12854 .38725 L
s
.12854 .38725 m
.12853 .38725 L
s
.12853 .38725 m
.12854 .38725 L
s
.12854 .38725 m
.12854 .38725 L
s
1 .141 0 r
.61179 .32777 m
.6122 .32661 L
s
.34962 .56911 m
.35053 .56844 L
s
1 .015 0 r
.85235 .5683 m
.85246 .56838 L
s
.85227 .56838 m
.85235 .5683 L
s
.85235 .5683 m
.85237 .56831 L
s
1 .215 0 r
.50577 .32813 m
.50554 .32627 L
s
1 .015 0 r
.85237 .56846 m
.85227 .56838 L
s
.85227 .56838 m
.85237 .56831 L
s
.85246 .56838 m
.85237 .56846 L
s
.85237 .56831 m
.85246 .56838 L
s
1 .141 0 r
.34879 .56835 m
.34962 .56911 L
s
1 .015 0 r
.85237 .56831 m
.85237 .56846 L
s
1 .026 0 r
.24101 .56831 m
.24099 .56831 L
s
.24101 .56805 m
.24101 .56831 L
s
.24101 .56831 m
.24084 .56818 L
s
.24116 .56819 m
.24101 .56831 L
s
.24095 .56767 m
.24101 .56831 L
s
.24101 .56805 m
.24084 .56818 L
s
.24116 .56819 m
.24101 .56805 L
s
1 .035 0 r
.19162 .23523 m
.1918 .23547 L
s
.19141 .23531 m
.19162 .23523 L
s
.19162 .23523 m
.19173 .23522 L
s
1 .026 0 r
.24099 .56831 m
.24116 .56819 L
s
.24084 .56818 m
.24099 .56831 L
s
1 .035 0 r
.1918 .23547 m
.19158 .23555 L
s
.19173 .23522 m
.1918 .23547 L
s
.19158 .23555 m
.19141 .23531 L
s
.19141 .23531 m
.19173 .23522 L
s
.19173 .23522 m
.19158 .23555 L
s
1 .229 0 r
.54909 .2956 m
.54924 .29574 L
s
.54923 .29361 m
.54909 .2956 L
s
.5512 .29479 m
.54909 .2956 L
s
1 .111 0 r
.67659 .53675 m
.6773 .53724 L
s
.67594 .53737 m
.67659 .53675 L
s
.67659 .53675 m
.6765 .53676 L
s
1 .002 0 r
.84896 .38619 m
.84896 .38619 L
s
.84896 .38617 m
.84896 .38619 L
s
.84896 .38619 m
.84895 .38618 L
s
.84897 .38618 m
.84896 .38619 L
s
.84894 .38614 m
.84896 .38619 L
s
.84896 .38617 m
.84895 .38618 L
s
.84897 .38618 m
.84896 .38617 L
s
.84895 .38618 m
.84896 .38619 L
s
.84896 .38619 m
.84897 .38618 L
s
1 .016 0 r
.78635 .53742 m
.78634 .53702 L
s
1 .117 0 r
.54495 .47691 m
.54013 .47605 L
s
1 .114 0 r
.36612 .26513 m
.36974 .26302 L
s
1 .001 0 r
.30354 .4164 m
.30355 .41638 L
s
1 .002 0 r
.06213 .35589 m
.06214 .35585 L
s
1 .001 0 r
.30355 .41638 m
.30355 .41638 L
s
.30354 .41638 m
.30355 .41638 L
s
.30355 .41638 m
.30355 .41638 L
s
.30355 .41638 m
.30355 .41639 L
s
.30355 .41638 m
.30355 .41638 L
s
.30355 .41639 m
.30354 .41638 L
s
.30354 .41638 m
.30355 .41638 L
s
.30355 .41638 m
.30355 .41639 L
s
1 .229 0 r
.54937 .29375 m
.54923 .29361 L
s
.54923 .29361 m
.5512 .29479 L
s
1 .166 0 r
.43781 .29535 m
.43727 .29553 L
s
.43731 .29399 m
.43781 .29535 L
s
.43853 .29431 m
.43781 .29535 L
s
1 .002 0 r
.06214 .35585 m
.06215 .35586 L
s
.06213 .35586 m
.06214 .35585 L
s
.06214 .35585 m
.06214 .35585 L
s
.06215 .35586 m
.06213 .35586 L
s
.06214 .35585 m
.06215 .35586 L
s
.06213 .35586 m
.06213 .35586 L
s
.06213 .35586 m
.06214 .35585 L
s
.06214 .35585 m
.06213 .35586 L
s
1 .111 0 r
.67664 .53786 m
.67594 .53737 L
s
.67594 .53737 m
.6765 .53676 L
s
1 .166 0 r
.43678 .29417 m
.43731 .29399 L
s
.43731 .29399 m
.43853 .29431 L
s
1 .111 0 r
.6773 .53724 m
.67664 .53786 L
s
.6765 .53676 m
.6773 .53724 L
s
1 .117 0 r
.5411 .4768 m
.54088 .47663 L
s
.54088 .47663 m
.54109 .47565 L
s
.54088 .47663 m
.54013 .47605 L
s
1 .016 0 r
.78633 .53702 m
.78644 .53709 L
s
.78624 .53711 m
.78633 .53702 L
s
.78633 .53702 m
.78634 .53702 L
s
.78635 .53718 m
.78624 .53711 L
s
.78624 .53711 m
.78634 .53702 L
s
.78644 .53709 m
.78635 .53718 L
s
.78634 .53702 m
.78644 .53709 L
s
.78634 .53702 m
.78635 .53718 L
s
1 .117 0 r
.54109 .47565 m
.5413 .47581 L
s
.54109 .47565 m
.54013 .47605 L
s
1 .111 0 r
.6765 .53676 m
.67664 .53786 L
s
1 .229 0 r
.5512 .29479 m
.54924 .29574 L
s
.54937 .29375 m
.5512 .29479 L
s
.54138 .2942 m
.5512 .29479 L
s
0 .04 1 r
.38181 .62759 m
.36807 .63648 L
s
.38181 .62759 m
.35166 .657 L
s
1 .607 0 r
.66363 .62287 m
.66729 .62659 L
s
.66022 .62542 m
.66363 .62287 L
s
.66363 .62287 m
.66549 .62325 L
s
1 .011 0 r
.78312 .355 m
.78309 .355 L
s
.78308 .3549 m
.78312 .355 L
s
.78312 .355 m
.78302 .35497 L
s
.78314 .35493 m
.78312 .355 L
s
.78294 .35475 m
.78312 .355 L
s
.78308 .3549 m
.78302 .35497 L
s
.78314 .35493 m
.78308 .3549 L
s
1 .117 0 r
.54013 .47605 m
.5411 .4768 L
s
.54013 .47605 m
.5413 .47581 L
s
1 .011 0 r
.78302 .35497 m
.78309 .355 L
s
.78309 .355 m
.78314 .35493 L
s
1 .005 0 r
.17458 .53651 m
.17457 .53651 L
s
.17458 .53646 m
.17458 .53651 L
s
.17458 .53651 m
.17455 .53649 L
s
.17461 .53649 m
.17458 .53651 L
s
.17457 .53638 m
.17458 .53651 L
s
.17458 .53646 m
.17455 .53649 L
s
.17461 .53649 m
.17458 .53646 L
s
.17457 .53651 m
.17461 .53649 L
s
.17455 .53649 m
.17457 .53651 L
s
1 .166 0 r
.43853 .29431 m
.43727 .29553 L
s
.43678 .29417 m
.43853 .29431 L
s
1 .117 0 r
.5413 .47581 m
.5411 .4768 L
s
1 .166 0 r
.43727 .29553 m
.43678 .29417 L
s
0 .434 1 r
.66727 .59696 m
.65841 .60458 L
s
.65694 .56788 m
.66727 .59696 L
s
.68572 .57781 m
.66727 .59696 L
s
1 .741 0 r
.65768 .65748 m
.66829 .64087 L
s
1 .014 0 r
.72031 .50611 m
.7202 .50576 L
s
1 0 0 r
.47875 .44557 m
.47875 .44557 L
s
1 .003 0 r
.2372 .38502 m
.23723 .38495 L
s
1 .08 0 r
.29982 .23365 m
.30199 .23194 L
s
1 .003 0 r
.23723 .38496 m
.23724 .38497 L
s
.23721 .38496 m
.23723 .38496 L
s
.23723 .38496 m
.23723 .38495 L
s
.23724 .38497 m
.23722 .38498 L
s
.23723 .38495 m
.23724 .38497 L
s
.23722 .38498 m
.23721 .38496 L
s
.23721 .38496 m
.23723 .38495 L
s
.23723 .38495 m
.23722 .38498 L
s
1 .114 0 r
.36949 .2638 m
.36899 .26397 L
s
.36904 .26291 m
.36949 .2638 L
s
.36974 .26302 m
.36949 .2638 L
s
.36854 .26308 m
.36904 .26291 L
s
.36904 .26291 m
.36974 .26302 L
s
1 .229 0 r
.54924 .29574 m
.54937 .29375 L
s
1 .043 0 r
.71793 .32423 m
.71773 .32424 L
s
.7177 .32384 m
.71793 .32423 L
s
.71793 .32423 m
.7175 .32415 L
s
.71793 .32393 m
.71793 .32423 L
s
.71685 .32331 m
.71793 .32423 L
s
1 .014 0 r
.72022 .50576 m
.72031 .50582 L
s
.72013 .50585 m
.72022 .50576 L
s
.72022 .50576 m
.7202 .50576 L
s
.72022 .5059 m
.72013 .50585 L
s
.72013 .50585 m
.7202 .50576 L
s
1 .162 0 r
.39085 .53612 m
.39116 .53616 L
s
.39122 .53453 m
.39085 .53612 L
s
.39085 .53612 m
.39022 .53518 L
s
.39216 .53551 m
.39085 .53612 L
s
.39254 .53224 m
.39085 .53612 L
s
1 .043 0 r
.7177 .32384 m
.7175 .32415 L
s
.71793 .32393 m
.7177 .32384 L
s
.7175 .32415 m
.71773 .32424 L
s
1 .014 0 r
.72031 .50582 m
.72022 .5059 L
s
.7202 .50576 m
.72031 .50582 L
s
.7202 .50576 m
.72022 .5059 L
s
1 .116 0 r
.65342 .29374 m
.65388 .29389 L
s
.65383 .29281 m
.65342 .29374 L
s
.65465 .29373 m
.65342 .29374 L
s
.65465 .29373 m
.65388 .29389 L
s
.65383 .29281 m
.65465 .29373 L
s
.65429 .29296 m
.65465 .29373 L
s
.65068 .29183 m
.65465 .29373 L
s
.65429 .29296 m
.65383 .29281 L
s
1 .043 0 r
.71773 .32424 m
.71793 .32393 L
s
0 .04 1 r
.35166 .657 m
.38004 .66909 L
s
.35166 .657 m
.36807 .63648 L
s
.50134 .61208 m
.35166 .657 L
s
1 .162 0 r
.39122 .53453 m
.39022 .53518 L
s
.39216 .53551 m
.39122 .53453 L
s
1 .607 0 r
.66729 .62659 m
.66389 .62915 L
s
.66549 .62325 m
.66729 .62659 L
s
1 .114 0 r
.36899 .26397 m
.36854 .26308 L
s
.36974 .26302 m
.36899 .26397 L
s
.36854 .26308 m
.36974 .26302 L
s
1 .162 0 r
.39116 .53616 m
.39216 .53551 L
s
1 .199 0 r
.60793 .50366 m
.60905 .50431 L
s
.60686 .505 m
.60793 .50366 L
s
.60793 .50366 m
.60718 .50377 L
s
1 .08 0 r
.30158 .23192 m
.30194 .23251 L
s
.30117 .23205 m
.30158 .23192 L
s
.30158 .23192 m
.30199 .23194 L
s
.30194 .23251 m
.30153 .23265 L
s
.30199 .23194 m
.30194 .23251 L
s
1 .001 0 r
.10811 .50508 m
.10811 .50508 L
s
.10811 .50507 m
.10811 .50508 L
s
.10811 .50508 m
.10811 .50507 L
s
.10812 .50508 m
.10811 .50508 L
s
.10811 .50506 m
.10811 .50508 L
s
.10811 .50507 m
.10811 .50507 L
s
.10812 .50508 m
.10811 .50507 L
s
.10811 .50508 m
.10812 .50508 L
s
.10811 .50507 m
.10811 .50508 L
s
1 .004 0 r
.89589 .53535 m
.89589 .53525 L
s
0 1 .331 r
.59152 .62623 m
.62344 .57166 L
s
1 .007 0 r
.65418 .47477 m
.65406 .47462 L
s
1 .005 0 r
.41248 .41418 m
.41263 .41408 L
s
1 .22 0 r
.47514 .26273 m
.48432 .26114 L
s
1 .004 0 r
.17078 .3536 m
.17082 .3535 L
s
1 .116 0 r
.65388 .29389 m
.65429 .29296 L
s
1 .199 0 r
.60798 .50565 m
.60686 .505 L
s
.60686 .505 m
.60718 .50377 L
s
1 .004 0 r
.17081 .3535 m
.17083 .35353 L
s
.17079 .35352 m
.17081 .3535 L
s
.17081 .3535 m
.17082 .3535 L
s
1 .005 0 r
.4126 .41407 m
.41263 .41411 L
s
.41258 .41409 m
.4126 .41407 L
s
.4126 .41407 m
.41263 .41408 L
s
.41263 .41411 m
.4126 .41413 L
s
.41263 .41408 m
.41263 .41411 L
s
1 .004 0 r
.17083 .35353 m
.17081 .35354 L
s
.17082 .3535 m
.17083 .35353 L
s
.89589 .53525 m
.89592 .53527 L
s
.89587 .53527 m
.89589 .53525 L
s
.89589 .53525 m
.89589 .53525 L
s
.17081 .35354 m
.17079 .35352 L
s
.17079 .35352 m
.17082 .3535 L
s
.17082 .3535 m
.17081 .35354 L
s
.8959 .53529 m
.89587 .53527 L
s
.89587 .53527 m
.89589 .53525 L
s
.89592 .53527 m
.8959 .53529 L
s
.89589 .53525 m
.89592 .53527 L
s
1 .005 0 r
.4126 .41413 m
.41258 .41409 L
s
.41258 .41409 m
.41263 .41408 L
s
.41263 .41408 m
.4126 .41413 L
s
1 .004 0 r
.89589 .53525 m
.8959 .53529 L
s
1 .007 0 r
.65408 .47461 m
.65412 .47464 L
s
.65405 .47466 m
.65408 .47461 L
s
.65408 .47461 m
.65406 .47462 L
s
.65409 .47468 m
.65405 .47466 L
s
.65405 .47466 m
.65406 .47462 L
s
.65412 .47464 m
.65409 .47468 L
s
.65406 .47462 m
.65412 .47464 L
s
.65406 .47462 m
.65409 .47468 L
s
1 .162 0 r
.39022 .53518 m
.39116 .53616 L
s
1 .202 0 r
.59071 .26246 m
.59111 .26259 L
s
.59107 .26073 m
.59071 .26246 L
s
.59275 .26199 m
.59071 .26246 L
s
1 .08 0 r
.30153 .23265 m
.30117 .23205 L
s
.30117 .23205 m
.30199 .23194 L
s
1 .22 0 r
.48284 .26234 m
.48247 .26247 L
s
.4825 .26044 m
.48284 .26234 L
s
.48432 .26114 m
.48284 .26234 L
s
1 .08 0 r
.30199 .23194 m
.30153 .23265 L
s
1 .202 0 r
.59147 .26086 m
.59107 .26073 L
s
.59107 .26073 m
.59275 .26199 L
s
1 .021 0 r
.28337 .53484 m
.28337 .53484 L
s
.28339 .53463 m
.28337 .53484 L
s
.28337 .53484 m
.28325 .53472 L
s
.28351 .53474 m
.28337 .53484 L
s
.28342 .53432 m
.28337 .53484 L
s
1 .22 0 r
.48212 .26057 m
.4825 .26044 L
s
.4825 .26044 m
.48432 .26114 L
s
1 .021 0 r
.28339 .53463 m
.28325 .53472 L
s
.28351 .53474 m
.28339 .53463 L
s
.28337 .53484 m
.28351 .53474 L
s
.28325 .53472 m
.28337 .53484 L
s
1 .202 0 r
.59275 .26199 m
.59111 .26259 L
s
.59147 .26086 m
.59275 .26199 L
s
.58443 .26032 m
.59275 .26199 L
s
1 .199 0 r
.60905 .50431 m
.60798 .50565 L
s
.60718 .50377 m
.60905 .50431 L
s
0 .434 1 r
.64794 .57515 m
.65694 .56788 L
s
.65694 .56788 m
.68572 .57781 L
s
1 .134 0 r
.26442 .65576 m
.26413 .65584 L
s
.26424 .65444 m
.26442 .65576 L
s
.26442 .65576 m
.26337 .65519 L
s
.265 .65509 m
.26442 .65576 L
s
.26324 .65267 m
.26442 .65576 L
s
1 .607 0 r
.66389 .62915 m
.66022 .62542 L
s
.66022 .62542 m
.66549 .62325 L
s
1 .199 0 r
.60718 .50377 m
.60798 .50565 L
s
1 .043 0 r
.15461 .65558 m
.15451 .6556 L
s
.15456 .65516 m
.15461 .65558 L
s
.15461 .65558 m
.15427 .65539 L
s
.15479 .65537 m
.15461 .65558 L
s
.15421 .65459 m
.15461 .65558 L
s
1 .168 0 r
.76713 .65556 m
.76879 .65169 L
s
1 .003 0 r
.82983 .50401 m
.82982 .50394 L
s
1 0 0 r
.58798 .44339 m
.58798 .44339 L
s
1 .01 0 r
.34613 .38277 m
.34636 .38253 L
s
1 .168 0 r
.40883 .23121 m
.41508 .22886 L
s
1 .005 0 r
.10428 .32215 m
.10432 .32202 L
s
1 .003 0 r
.82982 .50394 m
.82984 .50395 L
s
.82981 .50395 m
.82982 .50394 L
s
.82982 .50394 m
.82982 .50394 L
s
.82982 .50397 m
.82981 .50395 L
s
.82981 .50395 m
.82982 .50394 L
s
.82984 .50395 m
.82982 .50397 L
s
.82982 .50394 m
.82984 .50395 L
s
.82982 .50394 m
.82982 .50397 L
s
1 .005 0 r
.10431 .32203 m
.10434 .32205 L
s
.10428 .32204 m
.10431 .32203 L
s
.10431 .32203 m
.10432 .32202 L
s
1 .043 0 r
.15456 .65516 m
.15427 .65539 L
s
.15479 .65537 m
.15456 .65516 L
s
1 .005 0 r
.10434 .32205 m
.10431 .32207 L
s
.10432 .32202 m
.10434 .32205 L
s
.10431 .32207 m
.10428 .32204 L
s
.10428 .32204 m
.10432 .32202 L
s
.10432 .32202 m
.10431 .32207 L
s
1 .134 0 r
.26424 .65444 m
.26337 .65519 L
s
.265 .65509 m
.26424 .65444 L
s
1 .01 0 r
.34632 .38253 m
.34637 .3826 L
s
.34626 .38256 m
.34632 .38253 L
s
.34632 .38253 m
.34636 .38253 L
s
.34637 .3826 m
.34631 .38263 L
s
.34636 .38253 m
.34637 .3826 L
s
1 .043 0 r
.15427 .65539 m
.15451 .6556 L
s
1 .01 0 r
.34631 .38263 m
.34626 .38256 L
s
.34626 .38256 m
.34636 .38253 L
s
.34636 .38253 m
.34631 .38263 L
s
1 .043 0 r
.15451 .6556 m
.15479 .65537 L
s
0 .434 1 r
.38293 .59291 m
.39357 .622 L
s
1 .22 0 r
.48432 .26114 m
.48247 .26247 L
s
.48212 .26057 m
.48432 .26114 L
s
1 .134 0 r
.26337 .65519 m
.26413 .65584 L
s
1 .202 0 r
.59111 .26259 m
.59147 .26086 L
s
1 .134 0 r
.26413 .65584 m
.265 .65509 L
s
1 .22 0 r
.48247 .26247 m
.48212 .26057 L
s
1 .013 0 r
.82665 .32131 m
.82661 .3213 L
s
.8266 .32118 m
.82665 .32131 L
s
.82665 .32131 m
.82653 .32127 L
s
.82668 .32121 m
.82665 .32131 L
s
.82643 .32098 m
.82665 .32131 L
s
.8266 .32118 m
.82653 .32127 L
s
.82668 .32121 m
.8266 .32118 L
s
.82653 .32127 m
.82661 .3213 L
s
1 .607 0 r
.66549 .62325 m
.66389 .62915 L
s
1 .013 0 r
.82661 .3213 m
.82668 .32121 L
s
.808 1 0 r
.63855 .64562 m
.64463 .65412 L
s
.63287 .64957 m
.63855 .64562 L
s
.63855 .64562 m
.64502 .64728 L
s
1 .003 0 r
.21694 .50301 m
.21694 .50301 L
s
.21695 .50299 m
.21694 .50301 L
s
.21694 .50301 m
.21693 .503 L
s
.21696 .503 m
.21694 .50301 L
s
.21695 .50295 m
.21694 .50301 L
s
1 .021 0 r
.52241 .41203 m
.52241 .41205 L
s
.52241 .41185 m
.52241 .41203 L
s
.52259 .41195 m
.52241 .41203 L
s
1 .003 0 r
.21695 .50299 m
.21693 .503 L
s
.21696 .503 m
.21695 .50299 L
s
.21694 .50301 m
.21696 .503 L
s
.21693 .503 m
.21694 .50301 L
s
1 .021 0 r
.5224 .41187 m
.52241 .41185 L
s
.52241 .41185 m
.52259 .41195 L
s
1 .323 0 r
.70095 .62426 m
.70307 .61661 L
s
1 .001 0 r
.76369 .47262 m
.76368 .4726 L
s
1 .021 0 r
.52169 .41196 m
.52259 .41195 L
s
1 .012 0 r
.27969 .35131 m
.27992 .35103 L
s
1 .001 0 r
.76368 .4726 m
.76369 .47261 L
s
.76368 .47261 m
.76368 .4726 L
s
.76368 .4726 m
.76368 .4726 L
s
.76368 .47261 m
.76368 .47261 L
s
.76368 .47261 m
.76368 .4726 L
s
.76369 .47261 m
.76368 .47261 L
s
.76368 .4726 m
.76369 .47261 L
s
1 .021 0 r
.52259 .41195 m
.52241 .41205 L
s
.5224 .41187 m
.52259 .41195 L
s
1 .001 0 r
.76368 .4726 m
.76368 .47261 L
s
1 .168 0 r
.41436 .22995 m
.4138 .2301 L
s
.41386 .22856 m
.41436 .22995 L
s
.41508 .22886 m
.41436 .22995 L
s
1 .021 0 r
.52241 .41205 m
.5224 .41187 L
s
1 .168 0 r
.4133 .2287 m
.41386 .22856 L
s
.41386 .22856 m
.41508 .22886 L
s
1 .012 0 r
.27987 .35103 m
.27994 .35111 L
s
.2798 .35106 m
.27987 .35103 L
s
.27987 .35103 m
.27992 .35103 L
s
.27994 .35111 m
.27987 .35114 L
s
.27992 .35103 m
.27994 .35111 L
s
.27987 .35114 m
.2798 .35106 L
s
.2798 .35106 m
.27992 .35103 L
s
.27992 .35103 m
.27987 .35114 L
s
1 .04 0 r
.76121 .29037 m
.76103 .29038 L
s
.761 .29 m
.76121 .29037 L
s
.76121 .29037 m
.76081 .29029 L
s
.76122 .29009 m
.76121 .29037 L
s
.76025 .28946 m
.76121 .29037 L
s
.761 .29 m
.76081 .29029 L
s
.76122 .29009 m
.761 .29 L
s
.76081 .29029 m
.76103 .29038 L
s
1 .233 0 r
.52622 .22957 m
.52617 .22966 L
s
.52617 .22752 m
.52622 .22957 L
s
.52819 .22854 m
.52622 .22957 L
s
1 .04 0 r
.76103 .29038 m
.76122 .29009 L
s
.808 1 0 r
.64463 .65412 m
.63896 .65809 L
s
.64502 .64728 m
.64463 .65412 L
s
1 .095 0 r
.697 .25968 m
.69643 .25977 L
s
.69638 .25889 m
.697 .25968 L
s
.697 .25968 m
.696 .25963 L
s
.6968 .25903 m
.697 .25968 L
s
.69398 .25791 m
.697 .25968 L
s
1 .233 0 r
.52612 .22761 m
.52617 .22752 L
s
.52617 .22752 m
.52819 .22854 L
s
1 .095 0 r
.696 .25963 m
.69643 .25977 L
s
.69638 .25889 m
.696 .25963 L
s
.6968 .25903 m
.69638 .25889 L
s
1 .172 0 r
.30671 .62343 m
.30649 .62351 L
s
.30661 .62172 m
.30671 .62343 L
s
.30671 .62343 m
.30549 .62264 L
s
.30761 .6226 m
.30671 .62343 L
s
.30591 .61934 m
.30671 .62343 L
s
1 .59 0 r
.63401 .55817 m
.63777 .56111 L
s
.63046 .56124 m
.63401 .55817 L
s
.63401 .55817 m
.63414 .55826 L
s
1 .168 0 r
.41508 .22886 m
.4138 .2301 L
s
.4133 .2287 m
.41508 .22886 L
s
.4138 .2301 m
.4133 .2287 L
s
1 0 0 r
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
1 .051 0 r
.87684 .65363 m
.87731 .65244 L
s
1 .825 0 r
.63469 .59294 m
.63485 .57278 L
s
1 0 0 r
.69747 .4412 m
.69747 .4412 L
s
1 .047 0 r
.45532 .38051 m
.45709 .3799 L
s
1 .233 0 r
.5181 .22877 m
.52819 .22854 L
s
1 .012 0 r
.21318 .31981 m
.21337 .31952 L
s
1 .095 0 r
.69643 .25977 m
.6968 .25903 L
s
1 .168 0 r
.63237 .22862 m
.63287 .22875 L
s
.63281 .22721 m
.63237 .22862 L
s
.63414 .22839 m
.63237 .22862 L
s
1 .012 0 r
.21333 .31952 m
.2134 .3196 L
s
.21326 .31955 m
.21333 .31952 L
s
.21333 .31952 m
.21337 .31952 L
s
.2134 .3196 m
.21332 .31963 L
s
.21337 .31952 m
.2134 .3196 L
s
1 .233 0 r
.52819 .22854 m
.52617 .22966 L
s
.52612 .22761 m
.52819 .22854 L
s
1 .012 0 r
.21332 .31963 m
.21326 .31955 L
s
.21326 .31955 m
.21337 .31952 L
s
1 .168 0 r
.63331 .22734 m
.63281 .22721 L
s
.63281 .22721 m
.63414 .22839 L
s
1 .012 0 r
.21337 .31952 m
.21332 .31963 L
s
1 .172 0 r
.30661 .62172 m
.30549 .62264 L
s
.30761 .6226 m
.30661 .62172 L
s
1 .047 0 r
.45688 .38018 m
.45673 .38024 L
s
.45674 .37979 m
.45688 .38018 L
s
.45709 .3799 m
.45688 .38018 L
s
1 .168 0 r
.63414 .22839 m
.63287 .22875 L
s
.63331 .22734 m
.63414 .22839 L
s
.62764 .22632 m
.63414 .22839 L
s
1 .047 0 r
.45659 .37986 m
.45674 .37979 L
s
.45674 .37979 m
.45709 .3799 L
s
1 .136 0 r
.43221 .50156 m
.43283 .50167 L
s
.43287 .50031 m
.43221 .50156 L
s
.43221 .50156 m
.43215 .50071 L
s
.43355 .50127 m
.43221 .50156 L
s
.43543 .49872 m
.43221 .50156 L
s
.43287 .50031 m
.43215 .50071 L
s
.43355 .50127 m
.43287 .50031 L
s
1 .047 0 r
.45709 .3799 m
.45673 .38024 L
s
.45659 .37986 m
.45709 .3799 L
s
.45673 .38024 m
.45659 .37986 L
s
1 .136 0 r
.43283 .50167 m
.43355 .50127 L
s
0 .813 1 r
.66993 .56195 m
.64571 .58566 L
s
.63643 .55957 m
.66993 .56195 L
s
1 .172 0 r
.30549 .62264 m
.30649 .62351 L
s
.30649 .62351 m
.30761 .6226 L
s
1 .013 0 r
.32593 .50115 m
.32596 .50115 L
s
.32596 .50102 m
.32593 .50115 L
s
.32593 .50115 m
.32588 .50107 L
s
.32604 .5011 m
.32593 .50115 L
s
.32606 .50084 m
.32593 .50115 L
s
.32596 .50102 m
.32588 .50107 L
s
.32604 .5011 m
.32596 .50102 L
s
1 .233 0 r
.52617 .22966 m
.52612 .22761 L
s
1 .013 0 r
.32596 .50115 m
.32604 .5011 L
s
.32588 .50107 m
.32596 .50115 L
s
1 .168 0 r
.76839 .65159 m
.76947 .65255 L
s
.76744 .65238 m
.76839 .65159 L
s
.76839 .65159 m
.76879 .65169 L
s
1 .051 0 r
.87718 .65241 m
.87753 .65269 L
s
.8769 .65266 m
.87718 .65241 L
s
.87718 .65241 m
.87731 .65244 L
s
1 .045 0 r
.19691 .62239 m
.19683 .62241 L
s
.19688 .62194 m
.19691 .62239 L
s
.19691 .62239 m
.19658 .62218 L
s
.19714 .62217 m
.19691 .62239 L
s
.19663 .62132 m
.19691 .62239 L
s
1 .005 0 r
.63133 .40984 m
.6313 .40984 L
s
.6313 .40979 m
.63133 .40984 L
s
.63133 .40984 m
.63128 .40983 L
s
.63132 .4098 m
.63133 .40984 L
s
.63117 .40974 m
.63133 .40984 L
s
.6313 .40979 m
.63128 .40983 L
s
.63132 .4098 m
.6313 .40979 L
s
.63128 .40983 m
.6313 .40984 L
s
.6313 .40984 m
.63132 .4098 L
s
1 .051 0 r
.87753 .65269 m
.87724 .65295 L
s
.87731 .65244 m
.87753 .65269 L
s
1 .073 0 r
.81065 .6223 m
.81109 .62056 L
s
1 0 0 r
.87346 .47047 m
.87346 .47047 L
s
0 .813 1 r
.56835 .56157 m
.50164 .48956 L
s
1 .043 0 r
.38887 .34901 m
.39019 .3482 L
s
1 0 0 r
.08376 .44011 m
.08376 .44011 L
s
1 .011 0 r
.14658 .28828 m
.14674 .28799 L
s
1 0 0 r
.87346 .47047 m
.87346 .47047 L
s
.87346 .47047 m
.87346 .47047 L
s
.87346 .47047 m
.87346 .47047 L
s
.87346 .47047 m
.87346 .47047 L
s
.87346 .47047 m
.87346 .47047 L
s
.87346 .47047 m
.87346 .47047 L
s
.87346 .47047 m
.87346 .47047 L
s
.87346 .47047 m
.87346 .47047 L
s
1 .051 0 r
.87724 .65295 m
.8769 .65266 L
s
.8769 .65266 m
.87731 .65244 L
s
1 .045 0 r
.19688 .62194 m
.19658 .62218 L
s
.19714 .62217 m
.19688 .62194 L
s
1 .168 0 r
.63287 .22875 m
.63331 .22734 L
s
1 .051 0 r
.87731 .65244 m
.87724 .65295 L
s
1 .168 0 r
.76947 .65255 m
.76852 .65334 L
s
.76879 .65169 m
.76947 .65255 L
s
1 .045 0 r
.19658 .62218 m
.19683 .62241 L
s
1 .136 0 r
.43215 .50071 m
.43283 .50167 L
s
1 .045 0 r
.19683 .62241 m
.19714 .62217 L
s
1 .011 0 r
.14671 .28799 m
.14677 .28807 L
s
.14664 .28802 m
.14671 .28799 L
s
.14671 .28799 m
.14674 .28799 L
s
.14677 .28807 m
.1467 .2881 L
s
.14674 .28799 m
.14677 .28807 L
s
.1467 .2881 m
.14664 .28802 L
s
.14664 .28802 m
.14674 .28799 L
s
.14674 .28799 m
.1467 .2881 L
s
1 .168 0 r
.76852 .65334 m
.76744 .65238 L
s
.76744 .65238 m
.76879 .65169 L
s
1 .59 0 r
.63421 .56418 m
.63046 .56124 L
s
.63046 .56124 m
.63414 .55826 L
s
0 .813 1 r
.64571 .58566 m
.63643 .55957 L
s
1 .59 0 r
.63777 .56111 m
.63421 .56418 L
s
.63414 .55826 m
.63777 .56111 L
s
1 .043 0 r
.39012 .34849 m
.38992 .34857 L
s
.38994 .34816 m
.39012 .34849 L
s
.39019 .3482 m
.39012 .34849 L
s
.38974 .34823 m
.38994 .34816 L
s
.38994 .34816 m
.39019 .3482 L
s
1 .058 0 r
.56661 .37882 m
.56672 .37889 L
s
.56671 .37832 m
.56661 .37882 L
s
.5672 .3787 m
.56661 .37882 L
s
1 .229 0 r
.34843 .59142 m
.34843 .5915 L
s
.34855 .58915 m
.34843 .59142 L
s
.34843 .59142 m
.34707 .59025 L
s
.34991 .59039 m
.34843 .59142 L
s
.34874 .5859 m
.34843 .59142 L
s
1 .058 0 r
.56682 .37839 m
.56671 .37832 L
s
.56671 .37832 m
.5672 .3787 L
s
.5672 .3787 m
.56672 .37889 L
s
.56682 .37839 m
.5672 .3787 L
s
.56479 .37824 m
.5672 .3787 L
s
1 .168 0 r
.76879 .65169 m
.76852 .65334 L
s
1 .043 0 r
.38992 .34857 m
.38974 .34823 L
s
.39019 .3482 m
.38992 .34857 L
s
.38974 .34823 m
.39019 .3482 L
s
1 .058 0 r
.56672 .37889 m
.56682 .37839 L
s
1 .001 0 r
.25948 .46941 m
.25948 .46941 L
s
.25948 .4694 m
.25948 .46941 L
s
.25948 .46941 m
.25948 .4694 L
s
.25949 .46941 m
.25948 .46941 L
s
.25949 .46939 m
.25948 .46941 L
s
.25948 .4694 m
.25948 .4694 L
s
.25949 .46941 m
.25948 .4694 L
s
.25948 .46941 m
.25949 .46941 L
s
.25948 .4694 m
.25948 .46941 L
s
1 .116 0 r
.74437 .59093 m
.74458 .58813 L
s
1 0 0 r
.80723 .43901 m
.80723 .43901 L
s
1 .035 0 r
.32234 .31747 m
.32323 .31671 L
s
1 .229 0 r
.34855 .58915 m
.34707 .59025 L
s
.34991 .59039 m
.34855 .58915 L
s
1 .073 0 r
.81097 .62053 m
.81145 .62092 L
s
.81055 .6209 m
.81097 .62053 L
s
.81097 .62053 m
.81109 .62056 L
s
1 .038 0 r
.80465 .25637 m
.8045 .25637 L
s
.80447 .25603 m
.80465 .25637 L
s
.80465 .25637 m
.80428 .25629 L
s
.80468 .25611 m
.80465 .25637 L
s
.80381 .2555 m
.80465 .25637 L
s
.80447 .25603 m
.80428 .25629 L
s
.80468 .25611 m
.80447 .25603 L
s
.80428 .25629 m
.8045 .25637 L
s
1 .073 0 r
.81145 .62092 m
.81104 .62129 L
s
.81109 .62056 m
.81145 .62092 L
s
.81104 .62129 m
.81055 .6209 L
s
.81055 .6209 m
.81109 .62056 L
s
1 .035 0 r
.32306 .3167 m
.32323 .31696 L
s
.32288 .31678 m
.32306 .3167 L
s
.32306 .3167 m
.32323 .31671 L
s
.32323 .31696 m
.32304 .31703 L
s
.32323 .31671 m
.32323 .31696 L
s
1 .038 0 r
.8045 .25637 m
.80468 .25611 L
s
1 .229 0 r
.34843 .5915 m
.34991 .59039 L
s
1 .035 0 r
.32304 .31703 m
.32288 .31678 L
s
.32288 .31678 m
.32323 .31671 L
s
1 .073 0 r
.81109 .62056 m
.81104 .62129 L
s
1 .035 0 r
.32323 .31671 m
.32304 .31703 L
s
1 .014 0 r
.13001 .59027 m
.12999 .59028 L
s
.13001 .59013 m
.13001 .59027 L
s
.13001 .59027 m
.12991 .5902 L
s
.13009 .59021 m
.13001 .59027 L
s
.12994 .58993 m
.13001 .59027 L
s
1 .229 0 r
.34707 .59025 m
.34843 .5915 L
s
1 .08 0 r
.73981 .22548 m
.73936 .22553 L
s
.73931 .22479 m
.73981 .22548 L
s
.73981 .22548 m
.73897 .22541 L
s
.7397 .22491 m
.73981 .22548 L
s
.73745 .22386 m
.73981 .22548 L
s
1 .014 0 r
.13001 .59013 m
.12991 .5902 L
s
.13009 .59021 m
.13001 .59013 L
s
.12999 .59028 m
.13009 .59021 L
s
.12991 .5902 m
.12999 .59028 L
s
1 .08 0 r
.73931 .22479 m
.73897 .22541 L
s
.7397 .22491 m
.73931 .22479 L
s
.73897 .22541 m
.73936 .22553 L
s
1 .59 0 r
.63414 .55826 m
.63421 .56418 L
s
1 .001 0 r
.74093 .40753 m
.74093 .40753 L
s
.74093 .40752 m
.74093 .40753 L
s
.74093 .40753 m
.74092 .40753 L
s
.74093 .40752 m
.74093 .40753 L
s
.74091 .40751 m
.74093 .40753 L
s
.74093 .40752 m
.74092 .40753 L
s
.74093 .40752 m
.74093 .40752 L
s
.74092 .40753 m
.74093 .40753 L
s
.74093 .40753 m
.74093 .40752 L
s
1 .303 0 r
.38856 .55953 m
.38912 .55964 L
s
.38925 .55655 m
.38856 .55953 L
s
.38856 .55953 m
.38736 .55779 L
s
.39101 .5584 m
.38856 .55953 L
s
.39173 .55233 m
.38856 .55953 L
s
1 .111 0 r
.50223 .34671 m
.5021 .3468 L
s
.50211 .34575 m
.50223 .34671 L
s
.50305 .34617 m
.50223 .34671 L
s
1 .023 0 r
.92061 .62033 m
.92077 .61977 L
s
1 .215 0 r
.67802 .55952 m
.67687 .55428 L
s
1 .111 0 r
.49832 .3467 m
.50305 .34617 L
s
1 0 0 r
.19284 .43791 m
.19284 .43791 L
s
1 .028 0 r
.25573 .2859 m
.25634 .28523 L
s
1 .111 0 r
.50198 .34584 m
.50211 .34575 L
s
.50211 .34575 m
.50305 .34617 L
s
1 .08 0 r
.73936 .22553 m
.7397 .22491 L
s
1 .028 0 r
.25623 .28523 m
.25637 .28543 L
s
.25607 .2853 m
.25623 .28523 L
s
.25623 .28523 m
.25634 .28523 L
s
.25637 .28543 m
.25621 .2855 L
s
.25634 .28523 m
.25637 .28543 L
s
1 .023 0 r
.92072 .61976 m
.92088 .61989 L
s
.92059 .61988 m
.92072 .61976 L
s
.92072 .61976 m
.92077 .61977 L
s
.92088 .61989 m
.92075 .62001 L
s
.92077 .61977 m
.92088 .61989 L
s
.92075 .62001 m
.92059 .61988 L
s
.92059 .61988 m
.92077 .61977 L
s
1 .111 0 r
.50305 .34617 m
.5021 .3468 L
s
.50198 .34584 m
.50305 .34617 L
s
1 .028 0 r
.25621 .2855 m
.25607 .2853 L
s
.25607 .2853 m
.25634 .28523 L
s
1 .023 0 r
.92077 .61977 m
.92075 .62001 L
s
1 .028 0 r
.25634 .28523 m
.25621 .2855 L
s
1 .303 0 r
.38925 .55655 m
.38736 .55779 L
s
.39101 .5584 m
.38925 .55655 L
s
1 .111 0 r
.5021 .3468 m
.50198 .34584 L
s
1 .014 0 r
.67491 .37626 m
.67483 .37627 L
s
.67483 .37613 m
.67491 .37626 L
s
.67491 .37626 m
.67476 .37624 L
s
.6749 .37616 m
.67491 .37626 L
s
.67452 .37597 m
.67491 .37626 L
s
.425 1 0 r
.5424 .48583 m
.55108 .49093 L
s
.53382 .49644 m
.5424 .48583 L
s
.5424 .48583 m
.53596 .48653 L
s
1 .014 0 r
.67483 .37613 m
.67476 .37624 L
s
.6749 .37616 m
.67483 .37613 L
s
.67476 .37624 m
.67483 .37627 L
s
.67483 .37627 m
.6749 .37616 L
s
1 .047 0 r
.23931 .58905 m
.23927 .58906 L
s
.23931 .58858 m
.23931 .58905 L
s
.23931 .58905 m
.239 .58882 L
s
.23958 .58883 m
.23931 .58905 L
s
.23921 .58792 m
.23931 .58905 L
s
1 .003 0 r
.36878 .46731 m
.3688 .46731 L
s
.3688 .46728 m
.36878 .46731 L
s
.36878 .46731 m
.36878 .46729 L
s
.36881 .4673 m
.36878 .46731 L
s
.36884 .46724 m
.36878 .46731 L
s
.3688 .46728 m
.36878 .46729 L
s
.36881 .4673 m
.3688 .46728 L
s
1 .116 0 r
.7445 .58809 m
.74526 .58868 L
s
.74382 .5887 m
.7445 .58809 L
s
.7445 .58809 m
.74458 .58813 L
s
1 .003 0 r
.3688 .46731 m
.36881 .4673 L
s
.36878 .46729 m
.3688 .46731 L
s
1 .047 0 r
.23931 .58858 m
.239 .58882 L
s
.23958 .58883 m
.23931 .58858 L
s
1 .028 0 r
.85432 .58892 m
.85442 .58824 L
s
1 .481 0 r
.61158 .52808 m
.60212 .51736 L
s
1 .1 0 r
.43178 .31513 m
.43551 .31378 L
s
1 0 0 r
.1261 .40639 m
.1261 .40639 L
s
1 .023 0 r
.18904 .25428 m
.18947 .2537 L
s
1 0 0 r
.1261 .40639 m
.1261 .40639 L
s
.1261 .40639 m
.1261 .40639 L
s
.1261 .40639 m
.1261 .40639 L
s
.1261 .40639 m
.1261 .40639 L
s
.1261 .40639 m
.1261 .40639 L
s
.1261 .40639 m
.1261 .40639 L
s
.1261 .40639 m
.1261 .40639 L
s
.1261 .40639 m
.1261 .40639 L
s
1 .047 0 r
.23927 .58906 m
.23958 .58883 L
s
1 .303 0 r
.38912 .55964 m
.39101 .5584 L
s
1 .047 0 r
.239 .58882 m
.23927 .58906 L
s
1 .07 0 r
.60994 .34537 m
.61016 .34546 L
s
.61015 .34479 m
.60994 .34537 L
s
.61068 .34531 m
.60994 .34537 L
s
.61037 .34488 m
.61015 .34479 L
s
.61015 .34479 m
.61068 .34531 L
s
.808 1 0 r
.63896 .65809 m
.63287 .64957 L
s
.63287 .64957 m
.64502 .64728 L
s
1 .07 0 r
.61068 .34531 m
.61016 .34546 L
s
.61037 .34488 m
.61068 .34531 L
s
.60804 .34439 m
.61068 .34531 L
s
1 .116 0 r
.74458 .58928 m
.74382 .5887 L
s
.74382 .5887 m
.74458 .58813 L
s
.74526 .58868 m
.74458 .58928 L
s
.74458 .58813 m
.74526 .58868 L
s
1 .023 0 r
.1894 .25371 m
.18952 .25387 L
s
.18925 .25377 m
.1894 .25371 L
s
.1894 .25371 m
.18947 .2537 L
s
.18952 .25387 m
.18937 .25393 L
s
.18947 .2537 m
.18952 .25387 L
s
.285 1 0 r
.60878 .54493 m
.61912 .55539 L
s
.59886 .55191 m
.60878 .54493 L
s
.60878 .54493 m
.61368 .54544 L
s
1 .323 0 r
.70256 .61647 m
.70463 .61825 L
s
.70066 .61804 m
.70256 .61647 L
s
.70256 .61647 m
.70307 .61661 L
s
1 .023 0 r
.18937 .25393 m
.18925 .25377 L
s
.18925 .25377 m
.18947 .2537 L
s
.18947 .2537 m
.18937 .25393 L
s
1 .028 0 r
.85439 .58823 m
.85458 .58837 L
s
.85423 .58838 m
.85439 .58823 L
s
.85439 .58823 m
.85442 .58824 L
s
1 .116 0 r
.74458 .58813 m
.74458 .58928 L
s
1 .028 0 r
.85442 .58852 m
.85423 .58838 L
s
.85423 .58838 m
.85442 .58824 L
s
1 .07 0 r
.61016 .34546 m
.61037 .34488 L
s
1 .028 0 r
.85458 .58837 m
.85442 .58852 L
s
.85442 .58824 m
.85458 .58837 L
s
1 .1 0 r
.43508 .31441 m
.43475 .31452 L
s
.43478 .31358 m
.43508 .31441 L
s
.43551 .31378 m
.43508 .31441 L
s
1 .028 0 r
.85442 .58824 m
.85442 .58852 L
s
1 .1 0 r
.43445 .3137 m
.43478 .31358 L
s
.43478 .31358 m
.43551 .31378 L
s
1 .303 0 r
.38736 .55779 m
.38912 .55964 L
s
.808 1 0 r
.64502 .64728 m
.63896 .65809 L
s
1 0 0 r
.85093 .40528 m
.85093 .40528 L
s
.85093 .40528 m
.85093 .40528 L
s
.85093 .40528 m
.85093 .40528 L
s
.85093 .40528 m
.85093 .40528 L
s
.85093 .40527 m
.85093 .40528 L
s
.85093 .40528 m
.85093 .40528 L
s
.85093 .40528 m
.85093 .40528 L
s
.85093 .40528 m
.85093 .40528 L
s
.85093 .40528 m
.85093 .40528 L
s
1 .035 0 r
.78796 .55747 m
.78792 .55662 L
s
1 .606 0 r
.54507 .49659 m
.51983 .49215 L
s
1 0 0 r
.30218 .43571 m
.30218 .43571 L
s
1 .075 0 r
.36515 .28351 m
.36752 .28214 L
s
1 0 0 r
.05929 .37483 m
.05929 .37482 L
s
.05929 .37482 m
.05929 .37482 L
s
.05929 .37482 m
.05929 .37482 L
s
.05929 .37482 m
.05929 .37482 L
s
.05929 .37482 m
.05929 .37483 L
s
.05929 .37482 m
.05929 .37482 L
s
.05929 .37483 m
.05929 .37482 L
s
.05929 .37482 m
.05929 .37482 L
s
.05929 .37482 m
.05929 .37483 L
s
1 .323 0 r
.70463 .61825 m
.70273 .61982 L
s
.70307 .61661 m
.70463 .61825 L
s
.425 1 0 r
.54248 .50159 m
.53382 .49644 L
s
.53382 .49644 m
.53596 .48653 L
s
1 .1 0 r
.43551 .31378 m
.43475 .31452 L
s
.43445 .3137 m
.43551 .31378 L
s
.43475 .31452 m
.43445 .3137 L
s
1 .141 0 r
.54627 .31364 m
.54636 .31374 L
s
.54635 .3124 m
.54627 .31364 L
s
.54757 .31314 m
.54627 .31364 L
s
1 .323 0 r
.70273 .61982 m
.70066 .61804 L
s
.70066 .61804 m
.70307 .61661 L
s
1 .141 0 r
.54644 .3125 m
.54635 .3124 L
s
.54635 .3124 m
.54757 .31314 L
s
1 .035 0 r
.78791 .55661 m
.78814 .55677 L
s
.78771 .5568 m
.78791 .55661 L
s
.78791 .55661 m
.78792 .55662 L
s
1 .032 0 r
.4775 .46555 m
.4776 .46549 L
s
.4776 .46549 m
.47751 .46523 L
s
.4776 .46549 m
.47727 .46547 L
s
.47751 .46523 m
.47741 .46528 L
s
.47751 .46523 m
.47727 .46547 L
s
.47727 .46547 m
.4775 .46555 L
s
.47727 .46547 m
.47741 .46528 L
s
.47847 .46507 m
.47727 .46547 L
s
1 .035 0 r
.78794 .55697 m
.78771 .5568 L
s
.78771 .5568 m
.78792 .55662 L
s
.78814 .55677 m
.78794 .55697 L
s
.78792 .55662 m
.78814 .55677 L
s
1 .141 0 r
.54757 .31314 m
.54636 .31374 L
s
.54644 .3125 m
.54757 .31314 L
s
.54148 .31278 m
.54757 .31314 L
s
1 .012 0 r
.17243 .55674 m
.17242 .55674 L
s
.17244 .55662 m
.17243 .55674 L
s
.17243 .55674 m
.17236 .55668 L
s
.17251 .55668 m
.17243 .55674 L
s
.17242 .55645 m
.17243 .55674 L
s
1 .075 0 r
.36736 .28265 m
.36703 .28276 L
s
.36707 .28207 m
.36736 .28265 L
s
.36752 .28214 m
.36736 .28265 L
s
.36673 .28218 m
.36707 .28207 L
s
.36707 .28207 m
.36752 .28214 L
s
1 .012 0 r
.17244 .55662 m
.17236 .55668 L
s
.17251 .55668 m
.17244 .55662 L
s
1 .035 0 r
.78792 .55662 m
.78794 .55697 L
s
1 .012 0 r
.17242 .55674 m
.17251 .55668 L
s
.17236 .55668 m
.17242 .55674 L
s
1 .032 0 r
.47741 .46528 m
.4775 .46555 L
s
1 .003 0 r
.78457 .37377 m
.78456 .37377 L
s
.78456 .37374 m
.78457 .37377 L
s
.78457 .37377 m
.78454 .37376 L
s
.78458 .37375 m
.78457 .37377 L
s
.78452 .37369 m
.78457 .37377 L
s
.78456 .37374 m
.78454 .37376 L
s
.78458 .37375 m
.78456 .37374 L
s
.78454 .37376 m
.78456 .37377 L
s
.78456 .37377 m
.78458 .37375 L
s
1 .043 0 r
.72151 .52599 m
.72116 .52493 L
s
1 .055 0 r
.29844 .25186 m
.29995 .25067 L
s
1 0 0 r
.23543 .40415 m
.23543 .40415 L
s
.23543 .40415 m
.23544 .40415 L
s
.23543 .40415 m
.23543 .40415 L
s
.23543 .40415 m
.23543 .40415 L
s
.23544 .40415 m
.23543 .40415 L
s
.23543 .40415 m
.23544 .40415 L
s
.23543 .40415 m
.23543 .40415 L
s
.23543 .40415 m
.23543 .40415 L
s
.23543 .40415 m
.23543 .40415 L
s
1 .323 0 r
.70307 .61661 m
.70273 .61982 L
s
1 .141 0 r
.54636 .31374 m
.54644 .3125 L
s
1 .075 0 r
.36703 .28276 m
.36673 .28218 L
s
.36752 .28214 m
.36703 .28276 L
s
.36673 .28218 m
.36752 .28214 L
s
1 .344 0 r
.42667 .52579 m
.42825 .5261 L
s
.42836 .52262 m
.42667 .52579 L
s
.42667 .52579 m
.42651 .52365 L
s
.4301 .52508 m
.42667 .52579 L
s
.43487 .51864 m
.42667 .52579 L
s
1 .606 0 r
.52489 .49608 m
.52382 .49518 L
s
.52382 .49518 m
.52489 .49001 L
s
.52382 .49518 m
.51983 .49215 L
s
1 .215 0 r
.67705 .55423 m
.67843 .5552 L
s
.67578 .55546 m
.67705 .55423 L
s
.67705 .55423 m
.67687 .55428 L
s
1 .02 0 r
.71853 .3425 m
.71843 .34251 L
s
.71842 .34232 m
.71853 .3425 L
s
.71853 .3425 m
.71833 .34247 L
s
.71853 .34236 m
.71853 .3425 L
s
.71802 .34208 m
.71853 .3425 L
s
1 .055 0 r
.29967 .25065 m
.29992 .25107 L
s
.29938 .25075 m
.29967 .25065 L
s
.29967 .25065 m
.29995 .25067 L
s
0 .197 1 r
.3742 .61482 m
.38562 .646 L
s
1 .055 0 r
.29992 .25107 m
.29963 .25117 L
s
.29995 .25067 m
.29992 .25107 L
s
1 .02 0 r
.71842 .34232 m
.71833 .34247 L
s
.71853 .34236 m
.71842 .34232 L
s
.71833 .34247 m
.71843 .34251 L
s
1 .344 0 r
.42836 .52262 m
.42651 .52365 L
s
.4301 .52508 m
.42836 .52262 L
s
1 .043 0 r
.72122 .52493 m
.72149 .52511 L
s
.72097 .52518 m
.72122 .52493 L
s
.72122 .52493 m
.72116 .52493 L
s
1 .02 0 r
.71843 .34251 m
.71853 .34236 L
s
1 .043 0 r
.72124 .52536 m
.72097 .52518 L
s
.72097 .52518 m
.72116 .52493 L
s
1 .606 0 r
.52489 .49001 m
.52596 .4909 L
s
.52489 .49001 m
.51983 .49215 L
s
1 .043 0 r
.72149 .52511 m
.72124 .52536 L
s
.72116 .52493 m
.72149 .52511 L
s
1 .344 0 r
.42825 .5261 m
.4301 .52508 L
s
1 .046 0 r
.28181 .55551 m
.28182 .55552 L
s
.28185 .55506 m
.28181 .55551 L
s
.28181 .55551 m
.28155 .55526 L
s
.28212 .55531 m
.28181 .55551 L
s
.28194 .55439 m
.28181 .55551 L
s
1 .055 0 r
.29963 .25117 m
.29938 .25075 L
s
.29938 .25075 m
.29995 .25067 L
s
1 .043 0 r
.72116 .52493 m
.72124 .52536 L
s
1 .055 0 r
.29995 .25067 m
.29963 .25117 L
s
1 .003 0 r
.10555 .52501 m
.10555 .52501 L
s
.10556 .52498 m
.10555 .52501 L
s
.10555 .52501 m
.10554 .52499 L
s
.10557 .525 m
.10555 .52501 L
s
.10555 .52494 m
.10555 .52501 L
s
.10556 .52498 m
.10554 .52499 L
s
.10557 .525 m
.10556 .52498 L
s
.10555 .52501 m
.10557 .525 L
s
.10554 .52499 m
.10555 .52501 L
s
1 .215 0 r
.67715 .55643 m
.67578 .55546 L
s
.67578 .55546 m
.67687 .55428 L
s
1 .01 0 r
.89816 .55542 m
.89818 .55518 L
s
0 1 .511 r
.59193 .64685 m
.62663 .58832 L
s
1 .047 0 r
.65498 .49447 m
.65408 .4934 L
s
1 0 0 r
.41179 .43351 m
.41179 .43351 L
s
1 .151 0 r
.47484 .28112 m
.48115 .28004 L
s
1 .001 0 r
.1686 .37255 m
.16861 .37253 L
s
1 .043 0 r
.23165 .22017 m
.23265 .21917 L
s
1 .046 0 r
.28185 .55506 m
.28155 .55526 L
s
.28212 .55531 m
.28185 .55506 L
s
1 .001 0 r
.16861 .37253 m
.16862 .37253 L
s
.1686 .37253 m
.16861 .37253 L
s
.16861 .37253 m
.16861 .37253 L
s
.16862 .37253 m
.16861 .37254 L
s
.16861 .37253 m
.16862 .37253 L
s
.16861 .37254 m
.1686 .37253 L
s
.1686 .37253 m
.16861 .37253 L
s
.16861 .37253 m
.16861 .37254 L
s
.285 1 0 r
.61912 .55539 m
.60923 .56242 L
s
.61368 .54544 m
.61912 .55539 L
s
1 .068 0 r
.65307 .31153 m
.65334 .31163 L
s
.65331 .31099 m
.65307 .31153 L
s
.65379 .31153 m
.65307 .31153 L
s
.65379 .31153 m
.65334 .31163 L
s
.65331 .31099 m
.65379 .31153 L
s
.65358 .31108 m
.65379 .31153 L
s
.65145 .31042 m
.65379 .31153 L
s
.65358 .31108 m
.65331 .31099 L
s
1 .046 0 r
.28182 .55552 m
.28212 .55531 L
s
.28155 .55526 m
.28182 .55552 L
s
1 .01 0 r
.89817 .55518 m
.89824 .55523 L
s
.89812 .55523 m
.89817 .55518 L
s
.89817 .55518 m
.89818 .55518 L
s
.89818 .55528 m
.89812 .55523 L
s
.89812 .55523 m
.89818 .55518 L
s
.89824 .55523 m
.89818 .55528 L
s
.89818 .55518 m
.89824 .55523 L
s
.89818 .55518 m
.89818 .55528 L
s
1 .215 0 r
.67843 .5552 m
.67715 .55643 L
s
.67687 .55428 m
.67843 .5552 L
s
1 .151 0 r
.48013 .28086 m
.47988 .28096 L
s
.4799 .27955 m
.48013 .28086 L
s
.48115 .28004 m
.48013 .28086 L
s
.47964 .27965 m
.4799 .27955 L
s
.4799 .27955 m
.48115 .28004 L
s
1 .068 0 r
.65334 .31163 m
.65358 .31108 L
s
0 .197 1 r
.67625 .61594 m
.66684 .62438 L
s
.66516 .58472 m
.67625 .61594 L
s
.6962 .5956 m
.67625 .61594 L
s
1 .043 0 r
.23247 .21918 m
.23268 .21948 L
s
.23223 .21926 m
.23247 .21918 L
s
.23247 .21918 m
.23265 .21917 L
s
.23268 .21948 m
.23243 .21957 L
s
.23265 .21917 m
.23268 .21948 L
s
1 .215 0 r
.67687 .55428 m
.67715 .55643 L
s
1 .047 0 r
.65425 .49338 m
.65452 .49353 L
s
.654 .4937 m
.65425 .49338 L
s
.65425 .49338 m
.65408 .4934 L
s
.65427 .49385 m
.654 .4937 L
s
.654 .4937 m
.65408 .4934 L
s
1 .043 0 r
.23243 .21957 m
.23223 .21926 L
s
.23223 .21926 m
.23265 .21917 L
s
.23265 .21917 m
.23243 .21957 L
s
1 .137 0 r
.58909 .28018 m
.58936 .28027 L
s
.58934 .27899 m
.58909 .28018 L
s
.59049 .27986 m
.58909 .28018 L
s
1 .741 0 r
.66599 .64033 m
.67051 .64493 L
s
.6618 .64351 m
.66599 .64033 L
s
.66599 .64033 m
.66829 .64087 L
s
1 .047 0 r
.65452 .49353 m
.65427 .49385 L
s
.65408 .4934 m
.65452 .49353 L
s
1 .137 0 r
.58961 .27909 m
.58934 .27899 L
s
.58934 .27899 m
.59049 .27986 L
s
1 .151 0 r
.48115 .28004 m
.47988 .28096 L
s
.47964 .27965 m
.48115 .28004 L
s
1 .047 0 r
.65408 .4934 m
.65427 .49385 L
s
1 .009 0 r
.8317 .5239 m
.83167 .52368 L
s
1 .021 0 r
.58836 .4629 m
.58764 .46259 L
s
1 .001 0 r
.34503 .40191 m
.34506 .40188 L
s
1 .121 0 r
.40811 .24943 m
.41266 .24773 L
s
1 .002 0 r
.10169 .34092 m
.10171 .34086 L
s
1 .001 0 r
.34505 .40188 m
.34506 .40189 L
s
.34504 .40188 m
.34505 .40188 L
s
.34505 .40188 m
.34506 .40188 L
s
.34506 .40189 m
.34505 .40189 L
s
.34506 .40188 m
.34506 .40189 L
s
.34505 .40189 m
.34504 .40188 L
s
.34504 .40188 m
.34506 .40188 L
s
.34506 .40188 m
.34505 .40189 L
s
1 .002 0 r
.10171 .34087 m
.10172 .34088 L
s
.10169 .34087 m
.10171 .34087 L
s
.10171 .34087 m
.10171 .34086 L
s
.10172 .34088 m
.1017 .34088 L
s
.10171 .34086 m
.10172 .34088 L
s
.1017 .34088 m
.10169 .34087 L
s
.10169 .34087 m
.10171 .34086 L
s
.10171 .34086 m
.1017 .34088 L
s
1 .137 0 r
.59049 .27986 m
.58936 .28027 L
s
.58961 .27909 m
.59049 .27986 L
s
.58479 .27873 m
.59049 .27986 L
s
1 .151 0 r
.47988 .28096 m
.47964 .27965 L
s
1 .009 0 r
.83168 .52368 m
.83173 .52372 L
s
.83163 .52373 m
.83168 .52368 L
s
.83168 .52368 m
.83167 .52368 L
s
.83168 .52377 m
.83163 .52373 L
s
.83163 .52373 m
.83167 .52368 L
s
.83173 .52372 m
.83168 .52377 L
s
.83167 .52368 m
.83173 .52372 L
s
1 .021 0 r
.58778 .46276 m
.58771 .46272 L
s
.58771 .46272 m
.58778 .46255 L
s
.58771 .46272 m
.58764 .46259 L
s
.58778 .46255 m
.58786 .46259 L
s
.58778 .46255 m
.58764 .46259 L
s
1 .009 0 r
.83167 .52368 m
.83168 .52377 L
s
1 .344 0 r
.42651 .52365 m
.42825 .5261 L
s
1 .021 0 r
.58786 .46259 m
.58778 .46276 L
s
.58764 .46259 m
.58778 .46276 L
s
.58764 .46259 m
.58786 .46259 L
s
1 .233 0 r
.30565 .64551 m
.30535 .64564 L
s
.30551 .64319 m
.30565 .64551 L
s
.30565 .64551 m
.30399 .64444 L
s
.30688 .64439 m
.30565 .64551 L
s
.30456 .64002 m
.30565 .64551 L
s
1 .137 0 r
.58936 .28027 m
.58961 .27909 L
s
1 .121 0 r
.41213 .24852 m
.41173 .24863 L
s
.41177 .24751 m
.41213 .24852 L
s
.41266 .24773 m
.41213 .24852 L
s
1 .008 0 r
.21503 .52305 m
.21503 .52305 L
s
.21504 .52297 m
.21503 .52305 L
s
.21503 .52305 m
.21498 .52301 L
s
.21509 .52302 m
.21503 .52305 L
s
.21506 .52285 m
.21503 .52305 L
s
1 .121 0 r
.41136 .24762 m
.41177 .24751 L
s
.41177 .24751 m
.41266 .24773 L
s
1 .008 0 r
.21504 .52297 m
.21498 .52301 L
s
.21509 .52302 m
.21504 .52297 L
s
.21503 .52305 m
.21509 .52302 L
s
.21498 .52301 m
.21503 .52305 L
s
1 .006 0 r
.82838 .3399 m
.82836 .3399 L
s
.82836 .33984 m
.82838 .3399 L
s
.82838 .3399 m
.82833 .33988 L
s
.82839 .33986 m
.82838 .3399 L
s
.82828 .33976 m
.82838 .3399 L
s
.82836 .33984 m
.82833 .33988 L
s
.82839 .33986 m
.82836 .33984 L
s
.82833 .33988 m
.82836 .3399 L
s
.82836 .3399 m
.82839 .33986 L
s
1 .233 0 r
.30551 .64319 m
.30399 .64444 L
s
.30688 .64439 m
.30551 .64319 L
s
1 .741 0 r
.67051 .64493 m
.66632 .64811 L
s
.66829 .64087 m
.67051 .64493 L
s
1 .417 0 r
.70203 .64491 m
.7048 .63507 L
s
1 .006 0 r
.76516 .49233 m
.7651 .49218 L
s
1 0 0 r
.52167 .4313 m
.52167 .4313 L
s
1 .091 0 r
.34131 .2177 m
.34428 .21603 L
s
1 .004 0 r
.27818 .37027 m
.27825 .37018 L
s
.27824 .37018 m
.27826 .37021 L
s
.27822 .37019 m
.27824 .37018 L
s
.27824 .37018 m
.27825 .37018 L
s
.27826 .37021 m
.27824 .37022 L
s
.27825 .37018 m
.27826 .37021 L
s
.27824 .37022 m
.27822 .37019 L
s
.27822 .37019 m
.27825 .37018 L
s
.27825 .37018 m
.27824 .37022 L
s
1 .006 0 r
.76511 .49218 m
.76515 .4922 L
s
.76507 .49222 m
.76511 .49218 L
s
.76511 .49218 m
.7651 .49218 L
s
.76511 .49224 m
.76507 .49222 L
s
.76507 .49222 m
.7651 .49218 L
s
.76515 .4922 m
.76511 .49224 L
s
.7651 .49218 m
.76515 .4922 L
s
.7651 .49218 m
.76511 .49224 L
s
1 .606 0 r
.51983 .49215 m
.52489 .49608 L
s
.51983 .49215 m
.52596 .4909 L
s
1 .323 0 r
.34721 .61416 m
.34721 .6143 L
s
.34739 .61093 m
.34721 .61416 L
s
.34721 .61416 m
.34528 .61251 L
s
.34931 .61272 m
.34721 .61416 L
s
.34765 .6064 m
.34721 .61416 L
s
0 .197 1 r
.6556 .59276 m
.66516 .58472 L
s
.66516 .58472 m
.6962 .5956 L
s
1 .121 0 r
.41266 .24773 m
.41173 .24863 L
s
.41136 .24762 m
.41266 .24773 L
s
1 .457 0 r
.3861 .58345 m
.38696 .58366 L
s
.38715 .57895 m
.3861 .58345 L
s
.3861 .58345 m
.38429 .58085 L
s
.38982 .58176 m
.3861 .58345 L
s
.3909 .57267 m
.3861 .58345 L
s
1 .121 0 r
.41173 .24863 m
.41136 .24762 L
s
1 .233 0 r
.30399 .64444 m
.30535 .64564 L
s
1 .172 0 r
.52409 .24758 m
.52405 .24766 L
s
.52405 .24606 m
.52409 .24758 L
s
.52555 .24682 m
.52409 .24758 L
s
1 .233 0 r
.30535 .64564 m
.30688 .64439 L
s
1 .022 0 r
.76223 .30856 m
.76213 .30857 L
s
.76211 .30836 m
.76223 .30856 L
s
.76223 .30856 m
.76201 .30852 L
s
.76224 .3084 m
.76223 .30856 L
s
.76169 .30806 m
.76223 .30856 L
s
.76211 .30836 m
.76201 .30852 L
s
.76224 .3084 m
.76211 .30836 L
s
.76201 .30852 m
.76213 .30857 L
s
1 .172 0 r
.52402 .24613 m
.52405 .24606 L
s
.52405 .24606 m
.52555 .24682 L
s
1 .022 0 r
.76213 .30857 m
.76224 .3084 L
s
1 .091 0 r
.34406 .21667 m
.34366 .21678 L
s
.34371 .21595 m
.34406 .21667 L
s
.34428 .21603 m
.34406 .21667 L
s
.34331 .21606 m
.34371 .21595 L
s
.34371 .21595 m
.34428 .21603 L
s
1 .606 0 r
.52596 .4909 m
.52489 .49608 L
s
1 .323 0 r
.34739 .61093 m
.34528 .61251 L
s
.34931 .61272 m
.34739 .61093 L
s
1 .001 0 r
.14809 .49129 m
.14809 .49129 L
s
.14809 .49128 m
.14809 .49129 L
s
.14809 .49129 m
.14808 .49128 L
s
.14809 .49129 m
.14809 .49129 L
s
.14809 .49126 m
.14809 .49129 L
s
.14809 .49128 m
.14808 .49128 L
s
.14809 .49129 m
.14809 .49128 L
s
.14809 .49129 m
.14809 .49129 L
s
.14808 .49128 m
.14809 .49129 L
s
.973 1 0 r
.63536 .6134 m
.63558 .58839 L
s
1 .002 0 r
.69853 .46073 m
.69849 .46068 L
s
1 .172 0 r
.51806 .24699 m
.52555 .24682 L
s
1 .007 0 r
.45489 .39966 m
.45514 .39957 L
s
1 .005 0 r
.21126 .33859 m
.21134 .33846 L
s
1 .002 0 r
.6985 .46068 m
.69851 .46068 L
s
.69849 .46069 m
.6985 .46068 L
s
.6985 .46068 m
.69849 .46068 L
s
.6985 .4607 m
.69849 .46069 L
s
.69849 .46069 m
.69849 .46068 L
s
.69851 .46068 m
.6985 .4607 L
s
.69849 .46068 m
.69851 .46068 L
s
1 .007 0 r
.45511 .39961 m
.45509 .39962 L
s
.45509 .39956 m
.45511 .39961 L
s
.45514 .39957 m
.45511 .39961 L
s
1 .002 0 r
.69849 .46068 m
.6985 .4607 L
s
1 .007 0 r
.45507 .39957 m
.45509 .39956 L
s
.45509 .39956 m
.45514 .39957 L
s
1 .062 0 r
.69699 .27747 m
.69661 .27753 L
s
.69658 .27695 m
.69699 .27747 L
s
.69699 .27747 m
.69634 .27744 L
s
.69686 .27704 m
.69699 .27747 L
s
.69502 .27632 m
.69699 .27747 L
s
.69634 .27744 m
.69661 .27753 L
s
.69658 .27695 m
.69634 .27744 L
s
1 .007 0 r
.45514 .39957 m
.45509 .39962 L
s
.45507 .39957 m
.45514 .39957 L
s
1 .005 0 r
.21133 .33846 m
.21135 .3385 L
s
.21129 .33848 m
.21133 .33846 L
s
.21133 .33846 m
.21134 .33846 L
s
1 .007 0 r
.45509 .39962 m
.45507 .39957 L
s
1 .005 0 r
.21135 .3385 m
.21132 .33851 L
s
.21134 .33846 m
.21135 .3385 L
s
1 .062 0 r
.69686 .27704 m
.69658 .27695 L
s
1 .005 0 r
.21132 .33851 m
.21129 .33848 L
s
.21129 .33848 m
.21134 .33846 L
s
1 .039 0 r
.32446 .52169 m
.32452 .5217 L
s
.32454 .5213 m
.32446 .52169 L
s
.32446 .52169 m
.3243 .52146 L
s
.32477 .52154 m
.32446 .52169 L
s
.32483 .52074 m
.32446 .52169 L
s
1 .005 0 r
.21134 .33846 m
.21132 .33851 L
s
1 .172 0 r
.52555 .24682 m
.52405 .24766 L
s
.52402 .24613 m
.52555 .24682 L
s
1 .039 0 r
.32454 .5213 m
.3243 .52146 L
s
.32477 .52154 m
.32454 .5213 L
s
.32452 .5217 m
.32477 .52154 L
s
1 .091 0 r
.34366 .21678 m
.34331 .21606 L
s
.34428 .21603 m
.34366 .21678 L
s
.425 1 0 r
.55108 .49093 m
.54248 .50159 L
s
.53596 .48653 m
.55108 .49093 L
s
1 .039 0 r
.3243 .52146 m
.32452 .5217 L
s
1 .091 0 r
.34331 .21606 m
.34428 .21603 L
s
1 .457 0 r
.38715 .57895 m
.38429 .58085 L
s
.38982 .58176 m
.38715 .57895 L
s
1 .062 0 r
.69661 .27753 m
.69686 .27704 L
s
.285 1 0 r
.60923 .56242 m
.59886 .55191 L
s
.59886 .55191 m
.61368 .54544 L
s
1 .066 0 r
.19502 .64353 m
.19491 .64356 L
s
.19497 .64287 m
.19502 .64353 L
s
.19502 .64353 m
.19453 .64322 L
s
.19535 .64321 m
.19502 .64353 L
s
.19461 .64198 m
.19502 .64353 L
s
1 .741 0 r
.66632 .64811 m
.6618 .64351 L
s
.6618 .64351 m
.66829 .64087 L
s
1 .172 0 r
.52405 .24766 m
.52402 .24613 L
s
1 .066 0 r
.19497 .64287 m
.19453 .64322 L
s
.19535 .64321 m
.19497 .64287 L
s
1 .121 0 r
.63171 .24621 m
.63207 .24631 L
s
.63203 .24518 m
.63171 .24621 L
s
.633 .24604 m
.63171 .24621 L
s
1 .323 0 r
.34721 .6143 m
.34931 .61272 L
s
1 .121 0 r
.63239 .24528 m
.63203 .24518 L
s
.63203 .24518 m
.633 .24604 L
s
1 .066 0 r
.19453 .64322 m
.19491 .64356 L
s
.19491 .64356 m
.19535 .64321 L
s
1 .121 0 r
.633 .24604 m
.63207 .24631 L
s
.63239 .24528 m
.633 .24604 L
s
.62827 .24455 m
.633 .24604 L
s
1 .323 0 r
.34528 .61251 m
.34721 .6143 L
s
1 .481 0 r
.60397 .51709 m
.6067 .51869 L
s
.60135 .52035 m
.60397 .51709 L
s
.60397 .51709 m
.60212 .51736 L
s
1 0 0 r
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
1 .104 0 r
.8124 .64295 m
.81305 .6405 L
s
1 .002 0 r
.87561 .49019 m
.8756 .49015 L
s
0 .434 1 r
.56862 .58185 m
.49314 .50136 L
s
1 0 0 r
.63182 .42909 m
.63182 .42909 L
s
1 .014 0 r
.38803 .36798 m
.38847 .36772 L
s
1 .158 0 r
.45124 .21522 m
.45778 .21382 L
s
1 .006 0 r
.14425 .30688 m
.14433 .30672 L
s
1 .002 0 r
.8756 .49015 m
.87561 .49016 L
s
.87559 .49016 m
.8756 .49015 L
s
.8756 .49015 m
.8756 .49015 L
s
.8756 .49017 m
.87559 .49016 L
s
.87559 .49016 m
.8756 .49015 L
s
.87561 .49016 m
.8756 .49017 L
s
.8756 .49015 m
.87561 .49016 L
s
.8756 .49015 m
.8756 .49017 L
s
1 .457 0 r
.38696 .58366 m
.38982 .58176 L
s
1 .006 0 r
.14432 .30672 m
.14435 .30676 L
s
.14428 .30674 m
.14432 .30672 L
s
.14432 .30672 m
.14433 .30672 L
s
.14435 .30676 m
.14431 .30678 L
s
.14433 .30672 m
.14435 .30676 L
s
.14431 .30678 m
.14428 .30674 L
s
.14428 .30674 m
.14433 .30672 L
s
.14433 .30672 m
.14431 .30678 L
s
1 .014 0 r
.38844 .36781 m
.38838 .36784 L
s
.38838 .3677 m
.38844 .36781 L
s
.38847 .36772 m
.38844 .36781 L
s
.38832 .36773 m
.38838 .3677 L
s
.38838 .3677 m
.38847 .36772 L
s
.38838 .36784 m
.38832 .36773 L
s
.38847 .36772 m
.38838 .36784 L
s
.38832 .36773 m
.38847 .36772 L
s
1 .121 0 r
.63207 .24631 m
.63239 .24528 L
s
1 .59 0 r
.42022 .55095 m
.42293 .55155 L
s
.42311 .54552 m
.42022 .55095 L
s
.42022 .55095 m
.41993 .54733 L
s
.42611 .54974 m
.42022 .55095 L
s
.43431 .5388 m
.42022 .55095 L
s
1 .481 0 r
.60409 .52195 m
.60135 .52035 L
s
.60135 .52035 m
.60212 .51736 L
s
1 .158 0 r
.45678 .21475 m
.45646 .21483 L
s
.45649 .21337 m
.45678 .21475 L
s
.45778 .21382 m
.45678 .21475 L
s
.45616 .21345 m
.45649 .21337 L
s
.45649 .21337 m
.45778 .21382 L
s
1 .741 0 r
.66829 .64087 m
.66632 .64811 L
s
.425 1 0 r
.53596 .48653 m
.54248 .50159 L
s
1 .004 0 r
.25781 .48922 m
.25782 .48922 L
s
.25782 .48918 m
.25781 .48922 L
s
.25781 .48922 m
.25779 .4892 L
s
.25785 .48921 m
.25781 .48922 L
s
.25785 .48912 m
.25781 .48922 L
s
.25782 .48918 m
.25779 .4892 L
s
.25785 .48921 m
.25782 .48918 L
s
.25782 .48922 m
.25785 .48921 L
s
1 .008 0 r
.56529 .39749 m
.56531 .3975 L
s
.5653 .39742 m
.56529 .39749 L
s
.56537 .39747 m
.56529 .39749 L
s
1 .004 0 r
.25779 .4892 m
.25782 .48922 L
s
1 .008 0 r
.56532 .39743 m
.5653 .39742 L
s
.5653 .39742 m
.56537 .39747 L
s
.56537 .39747 m
.56531 .3975 L
s
.56532 .39743 m
.56537 .39747 L
s
.56503 .39741 m
.56537 .39747 L
s
1 .168 0 r
.56706 .21404 m
.56724 .21409 L
s
.56721 .21255 m
.56706 .21404 L
s
.56867 .21347 m
.56706 .21404 L
s
1 .008 0 r
.56531 .3975 m
.56532 .39743 L
s
1 .457 0 r
.38429 .58085 m
.38696 .58366 L
s
1 .172 0 r
.74572 .61141 m
.74604 .60725 L
s
1 0 0 r
.80897 .45855 m
.80896 .45854 L
s
1 .016 0 r
.32109 .33626 m
.3215 .33592 L
s
1 0 0 r
.80896 .45854 m
.80896 .45854 L
s
.80896 .45854 m
.80896 .45854 L
s
.80896 .45854 m
.80896 .45854 L
s
.80896 .45854 m
.80896 .45854 L
s
.80896 .45854 m
.80896 .45854 L
s
.80896 .45854 m
.80896 .45854 L
s
.80896 .45854 m
.80896 .45854 L
s
.80896 .45854 m
.80896 .45854 L
s
1 .168 0 r
.56739 .21261 m
.56721 .21255 L
s
.56721 .21255 m
.56867 .21347 L
s
1 .158 0 r
.45778 .21382 m
.45646 .21483 L
s
.45616 .21345 m
.45778 .21382 L
s
1 .59 0 r
.42311 .54552 m
.41993 .54733 L
s
.42611 .54974 m
.42311 .54552 L
s
1 .016 0 r
.32142 .33591 m
.3215 .33603 L
s
.32134 .33594 m
.32142 .33591 L
s
.32142 .33591 m
.3215 .33592 L
s
.3215 .33603 m
.32141 .33606 L
s
.3215 .33592 m
.3215 .33603 L
s
.32141 .33606 m
.32134 .33594 L
s
.32134 .33594 m
.3215 .33592 L
s
.3215 .33592 m
.32141 .33606 L
s
1 .158 0 r
.45646 .21483 m
.45616 .21345 L
s
1 .168 0 r
.56867 .21347 m
.56724 .21409 L
s
.56739 .21261 m
.56867 .21347 L
s
.56144 .21273 m
.56867 .21347 L
s
1 .023 0 r
.12762 .61097 m
.12758 .61098 L
s
.12761 .61074 m
.12762 .61097 L
s
.12762 .61097 m
.12745 .61086 L
s
.12774 .61086 m
.12762 .61097 L
s
.1275 .61041 m
.12762 .61097 L
s
.12761 .61074 m
.12745 .61086 L
s
.12774 .61086 m
.12761 .61074 L
s
1 .59 0 r
.42293 .55155 m
.42611 .54974 L
s
1 .023 0 r
.12758 .61098 m
.12774 .61086 L
s
.80605 .27446 m
.80596 .27446 L
s
.80594 .27424 m
.80605 .27446 L
s
.80605 .27446 m
.80582 .27441 L
s
.80607 .27429 m
.80605 .27446 L
s
.80552 .27391 m
.80605 .27446 L
s
.12745 .61086 m
.12758 .61098 L
s
.80594 .27424 m
.80582 .27441 L
s
.80607 .27429 m
.80594 .27424 L
s
.80582 .27441 m
.80596 .27446 L
s
.80596 .27446 m
.80607 .27429 L
s
1 .104 0 r
.81287 .64044 m
.81356 .64101 L
s
.81227 .64098 m
.81287 .64044 L
s
.81287 .64044 m
.81305 .6405 L
s
1 .168 0 r
.56724 .21409 m
.56739 .21261 L
s
1 .481 0 r
.6067 .51869 m
.60409 .52195 L
s
.60212 .51736 m
.6067 .51869 L
s
1 .104 0 r
.81356 .64101 m
.81296 .64154 L
s
.81305 .6405 m
.81356 .64101 L
s
1 0 0 r
.19078 .45746 m
.19078 .45746 L
s
.19078 .45746 m
.19078 .45746 L
s
.19078 .45746 m
.19078 .45746 L
s
.19079 .45746 m
.19078 .45746 L
s
.19079 .45746 m
.19078 .45746 L
s
.19078 .45746 m
.19078 .45746 L
s
.19079 .45746 m
.19078 .45746 L
s
.19078 .45746 m
.19079 .45746 L
s
.19078 .45746 m
.19078 .45746 L
s
1 .039 0 r
.49952 .36569 m
.49948 .36572 L
s
.49948 .36535 m
.49952 .36569 L
s
.49981 .3655 m
.49952 .36569 L
s
1 .035 0 r
.92305 .641 m
.92329 .64017 L
s
1 .336 0 r
.67896 .57982 m
.67716 .57166 L
s
1 0 0 r
.74224 .42687 m
.74224 .42687 L
s
1 .039 0 r
.49816 .36569 m
.49981 .3655 L
s
1 .015 0 r
.25407 .3045 m
.2544 .30414 L
s
1 .104 0 r
.81296 .64154 m
.81227 .64098 L
s
.81227 .64098 m
.81305 .6405 L
s
1 .039 0 r
.49944 .36539 m
.49948 .36535 L
s
.49948 .36535 m
.49981 .3655 L
s
.285 1 0 r
.61368 .54544 m
.60923 .56242 L
s
1 .055 0 r
.7404 .24322 m
.74009 .24325 L
s
.74006 .24274 m
.7404 .24322 L
s
.7404 .24322 m
.73982 .24317 L
s
.74033 .24282 m
.7404 .24322 L
s
.73876 .2421 m
.7404 .24322 L
s
.74006 .24274 m
.73982 .24317 L
s
.74033 .24282 m
.74006 .24274 L
s
.73982 .24317 m
.74009 .24325 L
s
1 .039 0 r
.49981 .3655 m
.49948 .36572 L
s
.49944 .36539 m
.49981 .3655 L
s
1 .015 0 r
.25434 .30414 m
.25442 .30425 L
s
.25425 .30418 m
.25434 .30414 L
s
.25434 .30414 m
.2544 .30414 L
s
.25442 .30425 m
.25433 .30429 L
s
.2544 .30414 m
.25442 .30425 L
s
1 .039 0 r
.49948 .36572 m
.49944 .36539 L
s
1 .073 0 r
.23761 .61017 m
.23755 .6102 L
s
.23761 .60944 m
.23761 .61017 L
s
.23761 .61017 m
.23712 .60981 L
s
.23804 .60983 m
.23761 .61017 L
s
.23744 .60841 m
.23761 .61017 L
s
1 .104 0 r
.81305 .6405 m
.81296 .64154 L
s
1 .015 0 r
.25433 .30429 m
.25425 .30418 L
s
.25425 .30418 m
.2544 .30414 L
s
.2544 .30414 m
.25433 .30429 L
s
1 .481 0 r
.60212 .51736 m
.60409 .52195 L
s
1 .073 0 r
.23761 .60944 m
.23712 .60981 L
s
.23804 .60983 m
.23761 .60944 L
s
1 .055 0 r
.74009 .24325 m
.74033 .24282 L
s
1 .024 0 r
.36745 .48751 m
.36753 .48752 L
s
.36754 .48729 m
.36745 .48751 L
s
.36745 .48751 m
.3674 .48736 L
s
.36767 .48745 m
.36745 .48751 L
s
.36788 .48697 m
.36745 .48751 L
s
.36754 .48729 m
.3674 .48736 L
s
.36767 .48745 m
.36754 .48729 L
s
.36753 .48752 m
.36767 .48745 L
s
1 .199 0 r
.4721 .48779 m
.47273 .48744 L
s
.47273 .48744 m
.47213 .48579 L
s
.47273 .48744 m
.4706 .48728 L
s
1 .073 0 r
.23755 .6102 m
.23804 .60983 L
s
1 .035 0 r
.92322 .64016 m
.92346 .64034 L
s
.92302 .64034 m
.92322 .64016 L
s
.92322 .64016 m
.92329 .64017 L
s
1 .073 0 r
.23712 .60981 m
.23755 .6102 L
s
1 .024 0 r
.3674 .48736 m
.36753 .48752 L
s
1 .199 0 r
.47213 .48579 m
.4715 .48614 L
s
.47213 .48579 m
.4706 .48728 L
s
1 .104 0 r
.67459 .2119 m
.67497 .212 L
s
.67492 .21104 m
.67459 .2119 L
s
.67571 .21184 m
.67459 .2119 L
s
1 .035 0 r
.92346 .64034 m
.92326 .64052 L
s
.92329 .64017 m
.92346 .64034 L
s
.92326 .64052 m
.92302 .64034 L
s
.92302 .64034 m
.92329 .64017 L
s
1 .199 0 r
.4706 .48728 m
.4721 .48779 L
s
.4706 .48728 m
.4715 .48614 L
s
.47818 .48482 m
.4706 .48728 L
s
1 .104 0 r
.67531 .21113 m
.67492 .21104 L
s
.67492 .21104 m
.67571 .21184 L
s
.67571 .21184 m
.67497 .212 L
s
.67531 .21113 m
.67571 .21184 L
s
.67191 .21024 m
.67571 .21184 L
s
1 .035 0 r
.92329 .64017 m
.92326 .64052 L
s
1 .825 0 r
.63468 .5726 m
.63997 .57675 L
s
.62967 .57695 m
.63468 .5726 L
s
.63468 .5726 m
.63485 .57278 L
s
1 .002 0 r
.67549 .39518 m
.67548 .39518 L
s
.67548 .39517 m
.67549 .39518 L
s
.67549 .39518 m
.67547 .39518 L
s
.67549 .39517 m
.67549 .39518 L
s
.67544 .39514 m
.67549 .39518 L
s
.67548 .39517 m
.67547 .39518 L
s
.67549 .39517 m
.67548 .39517 L
s
.67547 .39518 m
.67548 .39518 L
s
.67548 .39518 m
.67549 .39517 L
s
1 .045 0 r
.85635 .60941 m
.85651 .60832 L
s
1 .787 0 r
.61212 .54819 m
.59648 .53068 L
s
1 .048 0 r
.4312 .33393 m
.43302 .33328 L
s
1 0 0 r
.12364 .42575 m
.12364 .42575 L
s
1 .014 0 r
.18696 .27271 m
.18723 .27235 L
s
.18718 .27236 m
.18726 .27245 L
s
.18709 .27239 m
.18718 .27236 L
s
.18718 .27236 m
.18723 .27235 L
s
.18726 .27245 m
.18717 .27249 L
s
.18723 .27235 m
.18726 .27245 L
s
1 .104 0 r
.67497 .212 m
.67531 .21113 L
s
1 .014 0 r
.18717 .27249 m
.18709 .27239 L
s
.18709 .27239 m
.18723 .27235 L
s
.18723 .27235 m
.18717 .27249 L
s
1 .048 0 r
.43281 .33358 m
.43265 .33364 L
s
.43266 .33318 m
.43281 .33358 L
s
.43302 .33328 m
.43281 .33358 L
s
.4325 .33324 m
.43266 .33318 L
s
.43266 .33318 m
.43302 .33328 L
s
.43302 .33328 m
.43265 .33364 L
s
.4325 .33324 m
.43302 .33328 L
s
.43265 .33364 m
.4325 .33324 L
s
1 .199 0 r
.4715 .48614 m
.4721 .48779 L
s
1 .024 0 r
.60919 .36371 m
.60927 .36374 L
s
.60926 .36352 m
.60919 .36371 L
s
.60945 .36369 m
.60919 .36371 L
s
.60934 .36355 m
.60926 .36352 L
s
.60926 .36352 m
.60945 .36369 L
s
.60945 .36369 m
.60927 .36374 L
s
.60934 .36355 m
.60945 .36369 L
s
.60855 .36338 m
.60945 .36369 L
s
1 .045 0 r
.85646 .6083 m
.85676 .60853 L
s
.8562 .60854 m
.85646 .6083 L
s
.85646 .6083 m
.85651 .60832 L
s
1 .59 0 r
.41993 .54733 m
.42293 .55155 L
s
1 .024 0 r
.60927 .36374 m
.60934 .36355 L
s
1 .045 0 r
.8565 .60877 m
.8562 .60854 L
s
.8562 .60854 m
.85651 .60832 L
s
.85676 .60853 m
.8565 .60877 L
s
.85651 .60832 m
.85676 .60853 L
s
1 .172 0 r
.74592 .60719 m
.74705 .60807 L
s
.7449 .60811 m
.74592 .60719 L
s
.74592 .60719 m
.74604 .60725 L
s
0 .434 1 r
.68572 .57781 m
.65841 .60458 L
s
.64794 .57515 m
.68572 .57781 L
s
1 .001 0 r
.30079 .45529 m
.30079 .45529 L
s
.30079 .45528 m
.30079 .45529 L
s
.30079 .45529 m
.30078 .45528 L
s
.30079 .45529 m
.30079 .45529 L
s
.3008 .45527 m
.30079 .45529 L
s
.30079 .45528 m
.30078 .45528 L
s
.30079 .45529 m
.30079 .45528 L
s
.30079 .45529 m
.30079 .45529 L
s
1 .045 0 r
.85651 .60832 m
.8565 .60877 L
s
1 .001 0 r
.30078 .45528 m
.30079 .45529 L
s
1 .062 0 r
.78958 .57778 m
.78951 .57627 L
s
1 0 0 r
.85294 .42464 m
.85294 .42464 L
s
.787 1 0 r
.54519 .51652 m
.49424 .50766 L
s
1 .043 0 r
.36416 .30213 m
.36552 .30135 L
s
1 0 0 r
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
1 .172 0 r
.74604 .60898 m
.7449 .60811 L
s
.7449 .60811 m
.74604 .60725 L
s
.74705 .60807 m
.74604 .60898 L
s
.74604 .60725 m
.74705 .60807 L
s
1 .043 0 r
.36543 .30164 m
.36524 .3017 L
s
.36526 .3013 m
.36543 .30164 L
s
.36552 .30135 m
.36543 .30164 L
s
.36507 .30137 m
.36526 .3013 L
s
.36526 .3013 m
.36552 .30135 L
s
1 .022 0 r
.17027 .57729 m
.17025 .5773 L
s
.17027 .57707 m
.17027 .57729 L
s
.17027 .57729 m
.17013 .57718 L
s
.1704 .57719 m
.17027 .57729 L
s
.17024 .57676 m
.17027 .57729 L
s
.17027 .57707 m
.17013 .57718 L
s
.1704 .57719 m
.17027 .57707 L
s
.17025 .5773 m
.1704 .57719 L
s
.17013 .57718 m
.17025 .5773 L
s
0 .04 1 r
.36807 .63648 m
.38004 .66909 L
s
1 .043 0 r
.36524 .3017 m
.36507 .30137 L
s
.36552 .30135 m
.36524 .3017 L
s
1 .07 0 r
.54397 .33201 m
.54402 .33206 L
s
.54401 .33139 m
.54397 .33201 L
s
.54462 .33177 m
.54397 .33201 L
s
1 .043 0 r
.36507 .30137 m
.36552 .30135 L
s
1 .07 0 r
.54406 .33145 m
.54401 .33139 L
s
.54401 .33139 m
.54462 .33177 L
s
1 .172 0 r
.74604 .60725 m
.74604 .60898 L
s
0 .434 1 r
.65841 .60458 m
.64794 .57515 L
s
1 .825 0 r
.63496 .58111 m
.62967 .57695 L
s
.62967 .57695 m
.63485 .57278 L
s
1 .07 0 r
.54462 .33177 m
.54402 .33206 L
s
.54406 .33145 m
.54462 .33177 L
s
.54158 .33158 m
.54462 .33177 L
s
1 .417 0 r
.70412 .63485 m
.70682 .63718 L
s
.70166 .63692 m
.70412 .63485 L
s
.70412 .63485 m
.7048 .63507 L
s
1 .607 0 r
.38368 .60744 m
.38481 .60779 L
s
.38508 .60146 m
.38368 .60744 L
s
.38368 .60744 m
.38126 .60402 L
s
.38863 .60522 m
.38368 .60744 L
s
.39006 .59326 m
.38368 .60744 L
s
1 0 0 r
.78613 .39289 m
.78612 .39289 L
s
.78612 .39288 m
.78613 .39289 L
s
.78613 .39289 m
.78612 .39289 L
s
.78613 .39289 m
.78613 .39289 L
s
.78612 .39288 m
.78613 .39289 L
s
.78612 .39288 m
.78612 .39289 L
s
.78613 .39289 m
.78612 .39288 L
s
.78612 .39289 m
.78612 .39289 L
s
.78612 .39289 m
.78613 .39289 L
s
1 .09 0 r
.72272 .54611 m
.722 .54393 L
s
1 0 0 r
.23364 .42353 m
.23364 .42353 L
s
1 .035 0 r
.29704 .27029 m
.298 .26954 L
s
1 .825 0 r
.63997 .57675 m
.63496 .58111 L
s
.63485 .57278 m
.63997 .57675 L
s
1 .062 0 r
.7895 .57625 m
.78991 .57655 L
s
.78913 .5766 m
.7895 .57625 L
s
.7895 .57625 m
.78951 .57627 L
s
1 .07 0 r
.54402 .33206 m
.54406 .33145 L
s
1 .08 0 r
.28021 .57666 m
.28023 .57668 L
s
.28029 .57586 m
.28021 .57666 L
s
.28021 .57666 m
.27976 .57623 L
s
.28075 .57631 m
.28021 .57666 L
s
.28043 .57472 m
.28021 .57666 L
s
1 .05 0 r
.78404 .20882 m
.78378 .20883 L
s
.78374 .20838 m
.78404 .20882 L
s
.78404 .20882 m
.78352 .20875 L
s
.784 .20845 m
.78404 .20882 L
s
.78265 .20775 m
.78404 .20882 L
s
1 .062 0 r
.78955 .57689 m
.78913 .5766 L
s
.78913 .5766 m
.78951 .57627 L
s
1 .05 0 r
.78374 .20838 m
.78352 .20875 L
s
.784 .20845 m
.78374 .20838 L
s
.78352 .20875 m
.78378 .20883 L
s
1 .062 0 r
.78991 .57655 m
.78955 .57689 L
s
.78951 .57627 m
.78991 .57655 L
s
1 .08 0 r
.28029 .57586 m
.27976 .57623 L
s
.28075 .57631 m
.28029 .57586 L
s
1 .062 0 r
.78951 .57627 m
.78955 .57689 L
s
1 .035 0 r
.29782 .26953 m
.29798 .26979 L
s
.29763 .26959 m
.29782 .26953 L
s
.29782 .26953 m
.298 .26954 L
s
.29798 .26979 m
.29779 .26986 L
s
.298 .26954 m
.29798 .26979 L
s
1 .05 0 r
.78378 .20883 m
.784 .20845 L
s
1 .08 0 r
.28023 .57668 m
.28075 .57631 L
s
.27976 .57623 m
.28023 .57668 L
s
1 .035 0 r
.29779 .26986 m
.29763 .26959 L
s
.29763 .26959 m
.298 .26954 L
s
.298 .26954 m
.29779 .26986 L
s
1 .825 0 r
.41399 .57605 m
.41777 .57698 L
s
.41804 .56845 m
.41399 .57605 L
s
.41399 .57605 m
.41356 .57104 L
s
.42224 .57438 m
.41399 .57605 L
s
.43374 .55922 m
.41399 .57605 L
s
1 .006 0 r
.10296 .54522 m
.10296 .54522 L
s
.10297 .54516 m
.10296 .54522 L
s
.10296 .54522 m
.10292 .54519 L
s
.103 .5452 m
.10296 .54522 L
s
.10296 .54507 m
.10296 .54522 L
s
.10297 .54516 m
.10292 .54519 L
s
.103 .5452 m
.10297 .54516 L
s
.10296 .54522 m
.103 .5452 L
s
.71938 .36121 m
.71935 .36121 L
s
.71934 .36115 m
.71938 .36121 L
s
.71938 .36121 m
.71931 .3612 L
s
.71938 .36117 m
.71938 .36121 L
s
.71922 .36108 m
.71938 .36121 L
s
.10292 .54519 m
.10296 .54522 L
s
.71934 .36115 m
.71931 .3612 L
s
.71938 .36117 m
.71934 .36115 L
s
1 .417 0 r
.70682 .63718 m
.70436 .63924 L
s
.7048 .63507 m
.70682 .63718 L
s
1 .006 0 r
.71931 .3612 m
.71935 .36121 L
s
1 .005 0 r
.41093 .45318 m
.41096 .45318 L
s
.41096 .45313 m
.41093 .45318 L
s
.41093 .45318 m
.41094 .45314 L
s
.41099 .45317 m
.41093 .45318 L
s
.41109 .45307 m
.41093 .45318 L
s
.41096 .45313 m
.41094 .45314 L
s
.41099 .45317 m
.41096 .45313 L
s
.41096 .45318 m
.41099 .45317 L
s
1 .006 0 r
.71935 .36121 m
.71938 .36117 L
s
1 .005 0 r
.41094 .45314 m
.41096 .45318 L
s
1 .417 0 r
.34598 .6371 m
.34598 .63732 L
s
.34621 .63293 m
.34598 .6371 L
s
.34598 .6371 m
.34348 .63499 L
s
.34871 .63525 m
.34598 .6371 L
s
.34654 .62717 m
.34598 .6371 L
s
1 .018 0 r
.90047 .57574 m
.9005 .5753 L
s
1 .133 0 r
.65578 .51441 m
.65323 .51142 L
s
1 .09 0 r
.47453 .29975 m
.47831 .2991 L
s
1 0 0 r
.1664 .39174 m
.1664 .39174 L
s
1 .029 0 r
.22983 .23841 m
.23052 .23774 L
s
1 0 0 r
.1664 .39174 m
.1664 .39174 L
s
.1664 .39174 m
.1664 .39174 L
s
.1664 .39174 m
.1664 .39174 L
s
.1664 .39174 m
.1664 .39174 L
s
.1664 .39174 m
.1664 .39174 L
s
.1664 .39174 m
.1664 .39174 L
s
.1664 .39174 m
.1664 .39174 L
s
.1664 .39174 m
.1664 .39174 L
s
1 .09 0 r
.4777 .29959 m
.47755 .29966 L
s
.47756 .29881 m
.4777 .29959 L
s
.47831 .2991 m
.4777 .29959 L
s
1 .417 0 r
.70436 .63924 m
.70166 .63692 L
s
.70166 .63692 m
.7048 .63507 L
s
1 .09 0 r
.47741 .29887 m
.47756 .29881 L
s
.47756 .29881 m
.47831 .2991 L
s
1 .607 0 r
.38508 .60146 m
.38126 .60402 L
s
.38863 .60522 m
.38508 .60146 L
s
1 .018 0 r
.90048 .5753 m
.9006 .57538 L
s
.90038 .5754 m
.90048 .5753 L
s
.90048 .5753 m
.9005 .5753 L
s
.9005 .57548 m
.90038 .5754 L
s
.90038 .5754 m
.9005 .5753 L
s
.9006 .57538 m
.9005 .57548 L
s
.9005 .5753 m
.9006 .57538 L
s
1 .029 0 r
.23039 .23774 m
.23053 .23795 L
s
.23023 .2378 m
.23039 .23774 L
s
.23039 .23774 m
.23052 .23774 L
s
.23053 .23795 m
.23037 .23801 L
s
.23052 .23774 m
.23053 .23795 L
s
1 .018 0 r
.9005 .5753 m
.9005 .57548 L
s
1 .09 0 r
.72211 .54391 m
.72269 .54429 L
s
.72159 .54445 m
.72211 .54391 L
s
.72211 .54391 m
.722 .54393 L
s
1 .029 0 r
.23037 .23801 m
.23023 .2378 L
s
.23023 .2378 m
.23052 .23774 L
s
.23052 .23774 m
.23037 .23801 L
s
1 .09 0 r
.47831 .2991 m
.47755 .29966 L
s
.47741 .29887 m
.47831 .2991 L
s
1 .032 0 r
.653 .32976 m
.65313 .32981 L
s
.65312 .3295 m
.653 .32976 L
s
.65334 .32976 m
.653 .32976 L
s
.65334 .32976 m
.65313 .32981 L
s
.65312 .3295 m
.65334 .32976 L
s
.65324 .32955 m
.65334 .32976 L
s
.65223 .32924 m
.65334 .32976 L
s
.65324 .32955 m
.65312 .3295 L
s
1 .09 0 r
.72217 .54483 m
.72159 .54445 L
s
.72159 .54445 m
.722 .54393 L
s
.47755 .29966 m
.47741 .29887 L
s
.787 1 0 r
.50443 .51561 m
.50236 .5137 L
s
.50236 .5137 m
.50451 .50329 L
s
.50236 .5137 m
.49424 .50766 L
s
1 .032 0 r
.65313 .32981 m
.65324 .32955 L
s
1 .09 0 r
.72269 .54429 m
.72217 .54483 L
s
.722 .54393 m
.72269 .54429 L
s
1 .825 0 r
.41804 .56845 m
.41356 .57104 L
s
.42224 .57438 m
.41804 .56845 L
s
1 .09 0 r
.722 .54393 m
.72217 .54483 L
s
1 .417 0 r
.34621 .63293 m
.34348 .63499 L
s
.34871 .63525 m
.34621 .63293 L
s
1 .825 0 r
.63485 .57278 m
.63496 .58111 L
s
1 .019 0 r
.8336 .54403 m
.83354 .54355 L
s
1 .136 0 r
.58875 .48266 m
.58396 .48063 L
s
1 0 0 r
.34391 .42129 m
.34391 .42129 L
s
1 .08 0 r
.40739 .26787 m
.41039 .26676 L
s
1 .001 0 r
.09907 .35992 m
.09908 .35991 L
s
.09907 .35991 m
.09908 .35991 L
s
.09907 .35991 m
.09907 .35991 L
s
.09907 .35991 m
.09908 .35991 L
s
.09908 .35991 m
.09907 .35991 L
s
.09908 .35991 m
.09908 .35991 L
s
.09907 .35991 m
.09907 .35991 L
s
.09907 .35991 m
.09908 .35991 L
s
.09908 .35991 m
.09907 .35991 L
s
1 .417 0 r
.7048 .63507 m
.70436 .63924 L
s
1 .607 0 r
.38481 .60779 m
.38863 .60522 L
s
1 .081 0 r
.58772 .29821 m
.58789 .29828 L
s
.58787 .29751 m
.58772 .29821 L
s
.58856 .29803 m
.58772 .29821 L
s
1 .019 0 r
.83354 .54355 m
.83367 .54364 L
s
.83343 .54366 m
.83354 .54355 L
s
.83354 .54355 m
.83354 .54355 L
s
1 .825 0 r
.41777 .57698 m
.42224 .57438 L
s
1 .081 0 r
.58803 .29757 m
.58787 .29751 L
s
.58787 .29751 m
.58856 .29803 L
s
1 .019 0 r
.83356 .54375 m
.83343 .54366 L
s
.83343 .54366 m
.83354 .54355 L
s
.83367 .54364 m
.83356 .54375 L
s
.83354 .54355 m
.83367 .54364 L
s
0 .04 1 r
.68256 .63569 m
.67277 .64482 L
s
.67095 .60299 m
.68256 .63569 L
s
.70357 .61461 m
.68256 .63569 L
s
1 .019 0 r
.83354 .54355 m
.83356 .54375 L
s
1 .081 0 r
.58856 .29803 m
.58789 .29828 L
s
.58803 .29757 m
.58856 .29803 L
s
.58516 .29736 m
.58856 .29803 L
s
1 .08 0 r
.41004 .26727 m
.40977 .26735 L
s
.4098 .2666 m
.41004 .26727 L
s
.41039 .26676 m
.41004 .26727 L
s
.40953 .26668 m
.4098 .2666 L
s
.4098 .2666 m
.41039 .26676 L
s
1 .336 0 r
.67744 .57156 m
.67961 .57309 L
s
.67543 .5735 m
.67744 .57156 L
s
.67744 .57156 m
.67716 .57166 L
s
1 .018 0 r
.21308 .54344 m
.21308 .54345 L
s
.2131 .54326 m
.21308 .54344 L
s
.21308 .54344 m
.21297 .54334 L
s
.2132 .54337 m
.21308 .54344 L
s
.21314 .54299 m
.21308 .54344 L
s
.2131 .54326 m
.21297 .54334 L
s
.2132 .54337 m
.2131 .54326 L
s
.787 1 0 r
.50451 .50329 m
.50659 .50515 L
s
.50451 .50329 m
.49424 .50766 L
s
1 .018 0 r
.21308 .54345 m
.2132 .54337 L
s
.21297 .54334 m
.21308 .54345 L
s
1 .081 0 r
.58789 .29828 m
.58803 .29757 L
s
1 .417 0 r
.34598 .63732 m
.34871 .63525 L
s
1 .08 0 r
.41039 .26676 m
.40977 .26735 L
s
.40953 .26668 m
.41039 .26676 L
s
1 .021 0 r
.52092 .45099 m
.52093 .45097 L
s
.52093 .45097 m
.52092 .45079 L
s
.52093 .45097 m
.52074 .45089 L
s
1 .133 0 r
.65372 .51134 m
.65449 .51178 L
s
.653 .51225 m
.65372 .51134 L
s
.65372 .51134 m
.65323 .51142 L
s
1 .08 0 r
.40977 .26735 m
.40953 .26668 L
s
1 .021 0 r
.52092 .45079 m
.52092 .45081 L
s
.52092 .45079 m
.52074 .45089 L
s
1 .002 0 r
.83019 .35881 m
.83018 .35881 L
s
.83018 .35879 m
.83019 .35881 L
s
.83019 .35881 m
.83017 .3588 L
s
.83019 .3588 m
.83019 .35881 L
s
.83016 .35876 m
.83019 .35881 L
s
.83018 .35879 m
.83017 .3588 L
s
.83019 .3588 m
.83018 .35879 L
s
.83017 .3588 m
.83018 .35881 L
s
.83018 .35881 m
.83019 .3588 L
s
1 .021 0 r
.52074 .45089 m
.52092 .45099 L
s
.52074 .45089 m
.52092 .45081 L
s
.52165 .45088 m
.52074 .45089 L
s
1 .02 0 r
.76664 .51228 m
.76645 .5118 L
s
1 .063 0 r
.34017 .23595 m
.34225 .23479 L
s
1 0 0 r
.27665 .38947 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
1 .133 0 r
.65377 .51269 m
.653 .51225 L
s
.653 .51225 m
.65323 .51142 L
s
1 .021 0 r
.52092 .45081 m
.52092 .45099 L
s
1 .417 0 r
.34348 .63499 m
.34598 .63732 L
s
1 .136 0 r
.58493 .48172 m
.58442 .48145 L
s
.58442 .48145 m
.58491 .48036 L
s
.58442 .48145 m
.58396 .48063 L
s
1 .081 0 r
.32281 .54287 m
.32294 .54289 L
s
.32299 .54206 m
.32281 .54287 L
s
.32281 .54287 m
.32246 .54239 L
s
.32346 .54256 m
.32281 .54287 L
s
.32359 .5409 m
.32281 .54287 L
s
1 .136 0 r
.58491 .48036 m
.58542 .48062 L
s
.58491 .48036 m
.58396 .48063 L
s
1 .336 0 r
.6776 .57503 m
.67543 .5735 L
s
.67543 .5735 m
.67716 .57166 L
s
1 .081 0 r
.32299 .54206 m
.32246 .54239 L
s
.32346 .54256 m
.32299 .54206 L
s
1 .02 0 r
.76648 .5118 m
.76661 .51188 L
s
.76637 .51192 m
.76648 .5118 L
s
.76648 .5118 m
.76645 .5118 L
s
.7665 .512 m
.76637 .51192 L
s
.76637 .51192 m
.76645 .5118 L
s
1 .607 0 r
.38126 .60402 m
.38481 .60779 L
s
1 .02 0 r
.76661 .51188 m
.7665 .512 L
s
.76645 .5118 m
.76661 .51188 L
s
.76645 .5118 m
.7665 .512 L
s
1 .081 0 r
.32294 .54289 m
.32346 .54256 L
s
1 .133 0 r
.65449 .51178 m
.65377 .51269 L
s
.65323 .51142 m
.65449 .51178 L
s
1 .081 0 r
.32246 .54239 m
.32294 .54289 L
s
1 .063 0 r
.3421 .23523 m
.34182 .23532 L
s
.34185 .23473 m
.3421 .23523 L
s
.34225 .23479 m
.3421 .23523 L
s
1 .336 0 r
.67961 .57309 m
.6776 .57503 L
s
.67716 .57166 m
.67961 .57309 L
s
1 .133 0 r
.65323 .51142 m
.65377 .51269 L
s
1 .063 0 r
.34157 .23481 m
.34185 .23473 L
s
.34185 .23473 m
.34225 .23479 L
s
1 .116 0 r
.52209 .26583 m
.52207 .26589 L
s
.52207 .26481 m
.52209 .26583 L
s
.52308 .26533 m
.52209 .26583 L
s
.52204 .26486 m
.52207 .26481 L
s
.52207 .26481 m
.52308 .26533 L
s
1 .01 0 r
.7634 .32711 m
.76336 .32711 L
s
.76335 .32702 m
.7634 .32711 L
s
.7634 .32711 m
.7633 .32709 L
s
.7634 .32704 m
.7634 .32711 L
s
.76316 .32688 m
.7634 .32711 L
s
.76335 .32702 m
.7633 .32709 L
s
.7634 .32704 m
.76335 .32702 L
s
.7633 .32709 m
.76336 .32711 L
s
1 .136 0 r
.58542 .48062 m
.58493 .48172 L
s
.58396 .48063 m
.58493 .48172 L
s
1 .01 0 r
.76336 .32711 m
.7634 .32704 L
s
1 .136 0 r
.58396 .48063 m
.58542 .48062 L
s
1 .004 0 r
.14574 .51132 m
.14574 .51132 L
s
.14575 .51128 m
.14574 .51132 L
s
.14574 .51132 m
.14572 .51129 L
s
.14577 .5113 m
.14574 .51132 L
s
.14575 .51122 m
.14574 .51132 L
s
1 .063 0 r
.34182 .23532 m
.34157 .23481 L
s
.34225 .23479 m
.34182 .23532 L
s
1 .004 0 r
.14575 .51128 m
.14572 .51129 L
s
.14577 .5113 m
.14575 .51128 L
s
1 .063 0 r
.34157 .23481 m
.34225 .23479 L
s
1 .004 0 r
.14574 .51132 m
.14577 .5113 L
s
.14572 .51129 m
.14574 .51132 L
s
.808 1 0 r
.63605 .63411 m
.63631 .6052 L
s
1 .016 0 r
.6996 .4805 m
.69931 .48013 L
s
1 0 0 r
.45446 .41905 m
.45446 .41905 L
s
1 .116 0 r
.51801 .26544 m
.52308 .26533 L
s
1 .002 0 r
.20931 .35761 m
.20934 .35757 L
s
1 .05 0 r
.27287 .20399 m
.27429 .20294 L
s
1 .002 0 r
.20933 .35757 m
.20934 .35758 L
s
.20932 .35757 m
.20933 .35757 L
s
.20933 .35757 m
.20934 .35757 L
s
.20934 .35758 m
.20933 .35758 L
s
.20934 .35757 m
.20934 .35758 L
s
.20933 .35758 m
.20932 .35757 L
s
.20932 .35757 m
.20934 .35757 L
s
.20934 .35757 m
.20933 .35758 L
s
1 .116 0 r
.52308 .26533 m
.52207 .26589 L
s
.52204 .26486 m
.52308 .26533 L
s
1 .481 0 r
.46313 .51198 m
.46467 .51109 L
s
.46467 .51109 m
.46322 .5071 L
s
.46467 .51109 m
.45951 .51072 L
s
0 1 .077 r
.61322 .55637 m
.62588 .56919 L
s
.6011 .56497 m
.61322 .55637 L
s
.61322 .55637 m
.61927 .5571 L
s
1 .016 0 r
.69936 .48013 m
.69946 .48018 L
s
.69927 .48023 m
.69936 .48013 L
s
.69936 .48013 m
.69931 .48013 L
s
1 .336 0 r
.67716 .57166 m
.6776 .57503 L
s
1 .016 0 r
.69937 .48029 m
.69927 .48023 L
s
.69927 .48023 m
.69931 .48013 L
s
.69946 .48018 m
.69937 .48029 L
s
.69931 .48013 m
.69946 .48018 L
s
.69931 .48013 m
.69937 .48029 L
s
1 .481 0 r
.46322 .5071 m
.46168 .50798 L
s
.46322 .5071 m
.45951 .51072 L
s
1 .116 0 r
.52207 .26589 m
.52204 .26486 L
s
0 .04 1 r
.66099 .61167 m
.67095 .60299 L
s
.67095 .60299 m
.70357 .61461 L
s
1 .035 0 r
.69719 .29561 m
.69698 .29564 L
s
.69696 .29531 m
.69719 .29561 L
s
.69719 .29561 m
.69682 .29559 L
s
.69712 .29537 m
.69719 .29561 L
s
.69608 .29496 m
.69719 .29561 L
s
1 .481 0 r
.45951 .51072 m
.46313 .51198 L
s
.45951 .51072 m
.46168 .50798 L
s
.47789 .50481 m
.45951 .51072 L
s
1 .035 0 r
.69682 .29559 m
.69698 .29564 L
s
.69696 .29531 m
.69682 .29559 L
s
.69712 .29537 m
.69696 .29531 L
s
1 .05 0 r
.27403 .20292 m
.27425 .2033 L
s
.27377 .20299 m
.27403 .20292 L
s
.27403 .20292 m
.27429 .20294 L
s
.27425 .2033 m
.27399 .20338 L
s
.27429 .20294 m
.27425 .2033 L
s
1 .035 0 r
.69698 .29564 m
.69712 .29537 L
s
1 .05 0 r
.27399 .20338 m
.27377 .20299 L
s
.27377 .20299 m
.27429 .20294 L
s
.27429 .20294 m
.27399 .20338 L
s
1 .001 0 r
.07829 .47943 m
.07829 .47943 L
s
.07829 .47942 m
.07829 .47943 L
s
.07829 .47943 m
.07828 .47943 L
s
.07829 .47943 m
.07829 .47943 L
s
.07829 .47941 m
.07829 .47943 L
s
.07829 .47942 m
.07828 .47943 L
s
.07829 .47943 m
.07829 .47942 L
s
.07829 .47943 m
.07829 .47943 L
s
.07828 .47943 m
.07829 .47943 L
s
1 .005 0 r
.87778 .51016 m
.87776 .51003 L
s
0 .197 1 r
.56888 .60238 m
.48759 .51676 L
s
1 .005 0 r
.63248 .44867 m
.63231 .44857 L
s
1 .002 0 r
.38718 .38719 m
.38724 .38715 L
s
1 .114 0 r
.45078 .23348 m
.45552 .23248 L
s
1 .003 0 r
.14189 .3257 m
.14192 .32564 L
s
1 .002 0 r
.38724 .38717 m
.38723 .38717 L
s
.38723 .38715 m
.38724 .38717 L
s
.38724 .38715 m
.38724 .38717 L
s
.38722 .38715 m
.38723 .38715 L
s
.38723 .38715 m
.38724 .38715 L
s
.38723 .38717 m
.38722 .38715 L
s
.38724 .38715 m
.38723 .38717 L
s
.38722 .38715 m
.38724 .38715 L
s
1 .003 0 r
.14192 .32564 m
.14193 .32566 L
s
.1419 .32565 m
.14192 .32564 L
s
.14192 .32564 m
.14192 .32564 L
s
.14193 .32566 m
.14191 .32566 L
s
.14192 .32564 m
.14193 .32566 L
s
.14191 .32566 m
.1419 .32565 L
s
.1419 .32565 m
.14192 .32564 L
s
.14192 .32564 m
.14191 .32566 L
s
1 .005 0 r
.63235 .44857 m
.63237 .44858 L
s
.63232 .44861 m
.63235 .44857 L
s
.63235 .44857 m
.63231 .44857 L
s
.63235 .44862 m
.63232 .44861 L
s
.63232 .44861 m
.63231 .44857 L
s
.87776 .51003 m
.87779 .51005 L
s
.87773 .51006 m
.87776 .51003 L
s
.87776 .51003 m
.87776 .51003 L
s
.63237 .44858 m
.63235 .44862 L
s
.63231 .44857 m
.63237 .44858 L
s
.63231 .44857 m
.63235 .44862 L
s
.87776 .51008 m
.87773 .51006 L
s
.87773 .51006 m
.87776 .51003 L
s
.87779 .51005 m
.87776 .51008 L
s
.87776 .51003 m
.87779 .51005 L
s
.87776 .51003 m
.87776 .51008 L
s
1 .08 0 r
.63118 .26409 m
.63142 .26416 L
s
.6314 .26341 m
.63118 .26409 L
s
.63203 .26398 m
.63118 .26409 L
s
.63163 .26348 m
.6314 .26341 L
s
.6314 .26341 m
.63203 .26398 L
s
.63203 .26398 m
.63142 .26416 L
s
.63163 .26348 m
.63203 .26398 L
s
.62891 .263 m
.63203 .26398 L
s
1 .114 0 r
.45479 .23314 m
.45455 .23321 L
s
.45458 .23215 m
.45479 .23314 L
s
.45552 .23248 m
.45479 .23314 L
s
.45434 .23221 m
.45458 .23215 L
s
.45458 .23215 m
.45552 .23248 L
s
1 .08 0 r
.63142 .26416 m
.63163 .26348 L
s
1 .825 0 r
.41356 .57104 m
.41777 .57698 L
s
1 .013 0 r
.25608 .50942 m
.25609 .50942 L
s
.2561 .50928 m
.25608 .50942 L
s
.25608 .50942 m
.25602 .50934 L
s
.25618 .50937 m
.25608 .50942 L
s
.25619 .50909 m
.25608 .50942 L
s
.2561 .50928 m
.25602 .50934 L
s
.25618 .50937 m
.2561 .50928 L
s
.25609 .50942 m
.25618 .50937 L
s
.25602 .50934 m
.25609 .50942 L
s
1 .114 0 r
.45552 .23248 m
.45455 .23321 L
s
.45434 .23221 m
.45552 .23248 L
s
.45455 .23321 m
.45434 .23221 L
s
1 .233 0 r
.74709 .63213 m
.74753 .62655 L
s
1 .003 0 r
.81072 .47833 m
.81069 .47825 L
s
1 0 0 r
.56527 .41681 m
.56527 .41681 L
s
1 .095 0 r
.38346 .20148 m
.38703 .20011 L
s
1 .005 0 r
.31983 .35528 m
.31996 .35518 L
s
1 .003 0 r
.8107 .47825 m
.81072 .47826 L
s
.81068 .47827 m
.8107 .47825 L
s
.8107 .47825 m
.81069 .47825 L
s
.8107 .47828 m
.81068 .47827 L
s
.81068 .47827 m
.81069 .47825 L
s
.81072 .47826 m
.8107 .47828 L
s
.81069 .47825 m
.81072 .47826 L
s
1 .005 0 r
.31993 .35517 m
.31995 .35521 L
s
.3199 .35519 m
.31993 .35517 L
s
.31993 .35517 m
.31996 .35518 L
s
.31995 .35521 m
.31993 .35522 L
s
.31996 .35518 m
.31995 .35521 L
s
1 .003 0 r
.81069 .47825 m
.8107 .47828 L
s
1 .005 0 r
.31993 .35522 m
.3199 .35519 L
s
.3199 .35519 m
.31996 .35518 L
s
.31996 .35518 m
.31993 .35522 L
s
1 .035 0 r
.12521 .63198 m
.12515 .63199 L
s
.1252 .63163 m
.12521 .63198 L
s
.12521 .63198 m
.12496 .63181 L
s
.1254 .63181 m
.12521 .63198 L
s
.12504 .63114 m
.12521 .63198 L
s
.1252 .63163 m
.12496 .63181 L
s
.1254 .63181 m
.1252 .63163 L
s
1 .121 0 r
.56574 .23194 m
.56587 .23199 L
s
.56586 .23086 m
.56574 .23194 L
s
.56692 .23153 m
.56574 .23194 L
s
1 .035 0 r
.12515 .63199 m
.1254 .63181 L
s
.12496 .63181 m
.12515 .63199 L
s
1 .121 0 r
.56599 .23091 m
.56586 .23086 L
s
.56586 .23086 m
.56692 .23153 L
s
1 .104 0 r
.2359 .63165 m
.23581 .6317 L
s
.2359 .6306 m
.2359 .63165 L
s
.2359 .63165 m
.2352 .63113 L
s
.23651 .63117 m
.2359 .63165 L
s
.23565 .62916 m
.2359 .63165 L
s
1 .07 0 r
.36561 .50855 m
.36585 .50859 L
s
.36589 .50787 m
.36561 .50855 L
s
.36561 .50855 m
.36547 .50811 L
s
.36627 .50835 m
.36561 .50855 L
s
.3669 .50695 m
.36561 .50855 L
s
1 .121 0 r
.56692 .23153 m
.56587 .23199 L
s
.56599 .23091 m
.56692 .23153 L
s
.56166 .231 m
.56692 .23153 L
s
1 .095 0 r
.38662 .20074 m
.3863 .20082 L
s
.38634 .19995 m
.38662 .20074 L
s
.38703 .20011 m
.38662 .20074 L
s
1 .07 0 r
.36589 .50787 m
.36547 .50811 L
s
.36627 .50835 m
.36589 .50787 L
s
1 .095 0 r
.38601 .20002 m
.38634 .19995 L
s
.38634 .19995 m
.38703 .20011 L
s
1 .07 0 r
.36585 .50859 m
.36627 .50835 L
s
.973 1 0 r
.40849 .60066 m
.4132 .60192 L
s
.41356 .59119 m
.40849 .60066 L
s
.40849 .60066 m
.40794 .59448 L
s
.4188 .59861 m
.40849 .60066 L
s
.43317 .57989 m
.40849 .60066 L
s
1 .104 0 r
.2359 .6306 m
.2352 .63113 L
s
.23651 .63117 m
.2359 .6306 L
s
1 .013 0 r
.80755 .29286 m
.8075 .29286 L
s
.80749 .29274 m
.80755 .29286 L
s
.80755 .29286 m
.80743 .29283 L
s
.80756 .29277 m
.80755 .29286 L
s
.80726 .29256 m
.80755 .29286 L
s
.80749 .29274 m
.80743 .29283 L
s
.80756 .29277 m
.80749 .29274 L
s
.80743 .29283 m
.8075 .29286 L
s
1 .481 0 r
.46168 .50798 m
.46313 .51198 L
s
1 .013 0 r
.8075 .29286 m
.80756 .29277 L
s
1 .741 0 r
.38139 .63128 m
.38278 .63178 L
s
.38311 .62397 m
.38139 .63128 L
s
.38139 .63128 m
.37842 .62715 L
s
.38747 .6286 m
.38139 .63128 L
s
.38922 .6141 m
.38139 .63128 L
s
1 .07 0 r
.36547 .50811 m
.36585 .50859 L
s
1 .002 0 r
.1887 .47729 m
.1887 .47729 L
s
.1887 .47727 m
.1887 .47729 L
s
.1887 .47729 m
.18869 .47728 L
s
.18871 .47728 m
.1887 .47729 L
s
.18871 .47724 m
.1887 .47729 L
s
1 .121 0 r
.56587 .23199 m
.56599 .23091 L
s
1 .002 0 r
.1887 .47727 m
.18869 .47728 L
s
.18871 .47728 m
.1887 .47727 L
s
.1887 .47729 m
.18871 .47728 L
s
.18869 .47728 m
.1887 .47729 L
s
1 .104 0 r
.23581 .6317 m
.23651 .63117 L
s
1 .005 0 r
.49818 .3849 m
.49817 .38491 L
s
.49817 .38486 m
.49818 .3849 L
s
.49822 .38488 m
.49818 .3849 L
s
1 .459 0 r
.67991 .60036 m
.67744 .58926 L
s
1 .001 0 r
.74359 .44646 m
.74357 .44644 L
s
1 .005 0 r
.49799 .3849 m
.49822 .38488 L
s
1 .007 0 r
.25239 .32334 m
.25254 .32318 L
s
1 .005 0 r
.49817 .38486 m
.49817 .38486 L
s
.49817 .38486 m
.49822 .38488 L
s
1 .104 0 r
.2352 .63113 m
.23581 .6317 L
s
1 .001 0 r
.74358 .44644 m
.74358 .44644 L
s
.74357 .44645 m
.74358 .44644 L
s
.74358 .44644 m
.74357 .44644 L
s
.74358 .44645 m
.74357 .44645 L
s
.74357 .44645 m
.74357 .44644 L
s
.74358 .44644 m
.74358 .44645 L
s
.74357 .44644 m
.74358 .44644 L
s
.74357 .44644 m
.74358 .44645 L
s
1 .005 0 r
.49822 .38488 m
.49817 .38491 L
s
.49817 .38486 m
.49822 .38488 L
s
.49817 .38491 m
.49817 .38486 L
s
1 .095 0 r
.38703 .20011 m
.3863 .20082 L
s
.38601 .20002 m
.38703 .20011 L
s
1 .007 0 r
.25251 .32318 m
.25254 .32323 L
s
.25247 .3232 m
.25251 .32318 L
s
.25251 .32318 m
.25254 .32318 L
s
.25254 .32323 m
.2525 .32325 L
s
.25254 .32318 m
.25254 .32323 L
s
1 .095 0 r
.3863 .20082 m
.38601 .20002 L
s
1 .007 0 r
.2525 .32325 m
.25247 .3232 L
s
.25247 .3232 m
.25254 .32318 L
s
.25254 .32318 m
.2525 .32325 L
s
.787 1 0 r
.49424 .50766 m
.50443 .51561 L
s
.49424 .50766 m
.50659 .50515 L
s
0 1 .077 r
.62588 .56919 m
.61379 .57787 L
s
.61927 .5571 m
.62588 .56919 L
s
1 .035 0 r
.74113 .26127 m
.74093 .26129 L
s
.74091 .26096 m
.74113 .26127 L
s
.74113 .26127 m
.74076 .26123 L
s
.74108 .26102 m
.74113 .26127 L
s
.74008 .26056 m
.74113 .26127 L
s
.74091 .26096 m
.74076 .26123 L
s
.74108 .26102 m
.74091 .26096 L
s
.74076 .26123 m
.74093 .26129 L
s
.74093 .26129 m
.74108 .26102 L
s
1 .134 0 r
.4991 .19916 m
.49899 .1992 L
s
.499 .19797 m
.4991 .19916 L
s
.50016 .19849 m
.4991 .19916 L
s
.49889 .19801 m
.499 .19797 L
s
.499 .19797 m
.50016 .19849 L
s
1 0 0 r
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
1 .066 0 r
.85841 .63015 m
.85864 .62858 L
s
.939 1 0 r
.61266 .56855 m
.5914 .54503 L
s
1 0 0 r
.67637 .41456 m
.67637 .41456 L
s
1 .016 0 r
.43062 .35296 m
.43122 .35275 L
s
1 .134 0 r
.49433 .19896 m
.50016 .19849 L
s
1 .008 0 r
.18486 .29136 m
.18501 .29117 L
s
1 .073 0 r
.67471 .22968 m
.67498 .22975 L
s
.67495 .22907 m
.67471 .22968 L
s
.6755 .22963 m
.67471 .22968 L
s
.67522 .22914 m
.67495 .22907 L
s
.67495 .22907 m
.6755 .22963 L
s
1 .016 0 r
.43115 .35284 m
.4311 .35286 L
s
.4311 .35271 m
.43115 .35284 L
s
.43122 .35275 m
.43115 .35284 L
s
1 .073 0 r
.6755 .22963 m
.67498 .22975 L
s
.67522 .22914 m
.6755 .22963 L
s
.67282 .22852 m
.6755 .22963 L
s
1 .016 0 r
.43105 .35273 m
.4311 .35271 L
s
.4311 .35271 m
.43122 .35275 L
s
1 .008 0 r
.18498 .29117 m
.18502 .29122 L
s
.18493 .29119 m
.18498 .29117 L
s
.18498 .29117 m
.18501 .29117 L
s
.18502 .29122 m
.18497 .29124 L
s
.18501 .29117 m
.18502 .29122 L
s
.18497 .29124 m
.18493 .29119 L
s
.18493 .29119 m
.18501 .29117 L
s
.18501 .29117 m
.18497 .29124 L
s
.973 1 0 r
.41356 .59119 m
.40794 .59448 L
s
.4188 .59861 m
.41356 .59119 L
s
1 .016 0 r
.43122 .35275 m
.4311 .35286 L
s
.43105 .35273 m
.43122 .35275 L
s
.4311 .35286 m
.43105 .35273 L
s
1 .134 0 r
.50016 .19849 m
.49899 .1992 L
s
.49889 .19801 m
.50016 .19849 L
s
1 .741 0 r
.38311 .62397 m
.37842 .62715 L
s
.38747 .6286 m
.38311 .62397 L
s
1 .073 0 r
.67498 .22975 m
.67522 .22914 L
s
1 .134 0 r
.49899 .1992 m
.49889 .19801 L
s
.973 1 0 r
.4132 .60192 m
.4188 .59861 L
s
.787 1 0 r
.50659 .50515 m
.50443 .51561 L
s
1 .007 0 r
.2993 .47523 m
.29932 .47523 L
s
.29933 .47516 m
.2993 .47523 L
s
.2993 .47523 m
.29928 .47518 L
s
.29936 .4752 m
.2993 .47523 L
s
.29941 .47507 m
.2993 .47523 L
s
.29933 .47516 m
.29928 .47518 L
s
.29936 .4752 m
.29933 .47516 L
s
.29932 .47523 m
.29936 .4752 L
s
.29928 .47518 m
.29932 .47523 L
s
1 .003 0 r
.60915 .38265 m
.60916 .38266 L
s
.60916 .38263 m
.60915 .38265 L
s
.60919 .38265 m
.60915 .38265 L
s
.60917 .38263 m
.60916 .38263 L
s
.60916 .38263 m
.60919 .38265 L
s
.60919 .38265 m
.60916 .38266 L
s
.60917 .38263 m
.60919 .38265 L
s
.60907 .38261 m
.60919 .38265 L
s
.60916 .38266 m
.60917 .38263 L
s
1 .115 0 r
.60908 .19771 m
.60932 .19776 L
s
.60929 .19671 m
.60908 .19771 L
s
.61027 .19743 m
.60908 .19771 L
s
1 .095 0 r
.79122 .59834 m
.79111 .59602 L
s
1 0 0 r
.85497 .44425 m
.85497 .44424 L
s
.285 1 0 r
.54531 .5367 m
.47271 .52422 L
s
1 .02 0 r
.36316 .32097 m
.36379 .32061 L
s
1 0 0 r
.0535 .41343 m
.0535 .41343 L
s
.85497 .44424 m
.85497 .44424 L
s
.85497 .44424 m
.85497 .44424 L
s
.85497 .44424 m
.85497 .44424 L
s
.85497 .44424 m
.85497 .44424 L
s
.85497 .44424 m
.85497 .44424 L
s
.85497 .44424 m
.85497 .44424 L
s
.85497 .44424 m
.85497 .44424 L
s
.85497 .44424 m
.85497 .44424 L
s
1 .115 0 r
.60953 .19676 m
.60929 .19671 L
s
.60929 .19671 m
.61027 .19743 L
s
1 .066 0 r
.85856 .62854 m
.85901 .62888 L
s
.85818 .6289 m
.85856 .62854 L
s
.85856 .62854 m
.85864 .62858 L
s
1 .121 0 r
.27857 .59823 m
.27859 .59828 L
s
.27869 .59701 m
.27857 .59823 L
s
.27857 .59823 m
.27788 .59758 L
s
.2794 .59771 m
.27857 .59823 L
s
.27891 .59529 m
.27857 .59823 L
s
1 .035 0 r
.16808 .59818 m
.16805 .59819 L
s
.16809 .59782 m
.16808 .59818 L
s
.16808 .59818 m
.16785 .598 L
s
.16829 .59802 m
.16808 .59818 L
s
.16803 .59732 m
.16808 .59818 L
s
1 .02 0 r
.36375 .32075 m
.36366 .32078 L
s
.36367 .32059 m
.36375 .32075 L
s
.36379 .32061 m
.36375 .32075 L
s
.36358 .32062 m
.36367 .32059 L
s
.36367 .32059 m
.36379 .32061 L
s
1 .115 0 r
.61027 .19743 m
.60932 .19776 L
s
.60953 .19676 m
.61027 .19743 L
s
.60547 .19644 m
.61027 .19743 L
s
1 .035 0 r
.16809 .59782 m
.16785 .598 L
s
.16829 .59802 m
.16809 .59782 L
s
1 .066 0 r
.85863 .62924 m
.85818 .6289 L
s
.85818 .6289 m
.85864 .62858 L
s
.85901 .62888 m
.85863 .62924 L
s
.85864 .62858 m
.85901 .62888 L
s
1 .02 0 r
.36366 .32078 m
.36358 .32062 L
s
.36379 .32061 m
.36366 .32078 L
s
.36358 .32062 m
.36379 .32061 L
s
1 .035 0 r
.16805 .59819 m
.16829 .59802 L
s
.16785 .598 m
.16805 .59819 L
s
1 .787 0 r
.59954 .53018 m
.60405 .53285 L
s
.59522 .53558 m
.59954 .53018 L
s
.59954 .53018 m
.59648 .53068 L
s
1 .121 0 r
.27869 .59701 m
.27788 .59758 L
s
.2794 .59771 m
.27869 .59701 L
s
1 .066 0 r
.85864 .62858 m
.85863 .62924 L
s
1 .741 0 r
.38278 .63178 m
.38747 .6286 L
s
1 .121 0 r
.27859 .59828 m
.2794 .59771 L
s
1 .115 0 r
.60932 .19776 m
.60953 .19676 L
s
1 .121 0 r
.27788 .59758 m
.27859 .59828 L
s
1 .024 0 r
.54249 .35077 m
.54251 .35079 L
s
.5425 .35056 m
.54249 .35077 L
s
.54271 .35069 m
.54249 .35077 L
s
.54252 .35058 m
.5425 .35056 L
s
.5425 .35056 m
.54271 .35069 L
s
1 .233 0 r
.74736 .62644 m
.74891 .62764 L
s
.74597 .62769 m
.74736 .62644 L
s
.74736 .62644 m
.74753 .62655 L
s
1 .024 0 r
.54271 .35069 m
.54251 .35079 L
s
.54252 .35058 m
.54271 .35069 L
s
.54168 .35063 m
.54271 .35069 L
s
1 0 0 r
.23182 .44315 m
.23182 .44315 L
s
.23182 .44314 m
.23182 .44315 L
s
.23182 .44315 m
.23182 .44314 L
s
.23183 .44314 m
.23182 .44315 L
s
.23183 .44314 m
.23182 .44315 L
s
.23182 .44314 m
.23182 .44314 L
s
.23183 .44314 m
.23182 .44314 L
s
.23182 .44315 m
.23183 .44314 L
s
.23182 .44314 m
.23182 .44315 L
s
.78774 .4123 m
.78774 .4123 L
s
1 .151 0 r
.72395 .56649 m
.72273 .56284 L
s
1 .019 0 r
.29562 .28895 m
.29615 .28854 L
s
1 .024 0 r
.54251 .35079 m
.54252 .35058 L
s
1 .787 0 r
.59973 .53826 m
.59522 .53558 L
s
.59522 .53558 m
.59648 .53068 L
s
1 .019 0 r
.29605 .28853 m
.29614 .28868 L
s
.29595 .28857 m
.29605 .28853 L
s
.29605 .28853 m
.29615 .28854 L
s
.29614 .28868 m
.29604 .28871 L
s
.29615 .28854 m
.29614 .28868 L
s
.29604 .28871 m
.29595 .28857 L
s
.29595 .28857 m
.29615 .28854 L
s
1 .039 0 r
.40926 .47363 m
.40948 .47367 L
s
.40949 .47328 m
.40926 .47363 L
s
.40926 .47363 m
.4093 .47338 L
s
.40967 .47358 m
.40926 .47363 L
s
.41038 .47288 m
.40926 .47363 L
s
1 .019 0 r
.29615 .28854 m
.29604 .28871 L
s
1 .039 0 r
.40949 .47328 m
.4093 .47338 L
s
.40967 .47358 m
.40949 .47328 L
s
.40948 .47367 m
.40967 .47358 L
s
1 .787 0 r
.45332 .53678 m
.45587 .53525 L
s
.45587 .53525 m
.4535 .5287 L
s
.45587 .53525 m
.44739 .53465 L
s
1 .034 0 r
.7852 .22676 m
.78503 .22677 L
s
.785 .22645 m
.7852 .22676 L
s
.7852 .22676 m
.78485 .22671 L
s
.78518 .22651 m
.7852 .22676 L
s
.78425 .22603 m
.7852 .22676 L
s
.785 .22645 m
.78485 .22671 L
s
.78518 .22651 m
.785 .22645 L
s
.78485 .22671 m
.78503 .22677 L
s
1 .233 0 r
.74752 .6289 m
.74597 .62769 L
s
.74597 .62769 m
.74753 .62655 L
s
.74891 .62764 m
.74752 .6289 L
s
.74753 .62655 m
.74891 .62764 L
s
1 .039 0 r
.4093 .47338 m
.40948 .47367 L
s
1 .095 0 r
.79109 .59599 m
.79173 .59645 L
s
.79053 .59652 m
.79109 .59599 L
s
.79109 .59599 m
.79111 .59602 L
s
1 .034 0 r
.78503 .22677 m
.78518 .22651 L
s
1 .011 0 r
.10034 .56573 m
.10033 .56573 L
s
.10035 .56562 m
.10034 .56573 L
s
.10034 .56573 m
.10027 .56567 L
s
.10041 .56568 m
.10034 .56573 L
s
.10033 .56545 m
.10034 .56573 L
s
.10035 .56562 m
.10027 .56567 L
s
.10041 .56568 m
.10035 .56562 L
s
1 .787 0 r
.4535 .5287 m
.45094 .53021 L
s
.4535 .5287 m
.44739 .53465 L
s
1 .011 0 r
.10033 .56573 m
.10041 .56568 L
s
.10027 .56567 m
.10033 .56573 L
s
1 .095 0 r
.79117 .59698 m
.79053 .59652 L
s
.79053 .59652 m
.79111 .59602 L
s
.79173 .59645 m
.79117 .59698 L
s
.79111 .59602 m
.79173 .59645 L
s
1 .787 0 r
.44739 .53465 m
.45332 .53678 L
s
.44739 .53465 m
.45094 .53021 L
s
.47759 .52506 m
.44739 .53465 L
s
1 .001 0 r
.72044 .38033 m
.72044 .38033 L
s
.72044 .38032 m
.72044 .38033 L
s
.72044 .38033 m
.72043 .38033 L
s
.72044 .38032 m
.72044 .38033 L
s
.72042 .38031 m
.72044 .38033 L
s
.72044 .38032 m
.72043 .38033 L
s
.72044 .38032 m
.72044 .38032 L
s
.72043 .38033 m
.72044 .38033 L
s
.72044 .38033 m
.72044 .38032 L
s
1 .029 0 r
.9028 .59631 m
.90285 .59561 L
s
1 .253 0 r
.65659 .5346 m
.6517 .52891 L
s
1 .043 0 r
.47421 .3186 m
.47604 .31829 L
s
1 0 0 r
.16416 .41117 m
.16416 .41117 L
s
1 .018 0 r
.228 .25689 m
.22842 .25647 L
s
1 .741 0 r
.37842 .62715 m
.38278 .63178 L
s
1 .043 0 r
.47575 .31852 m
.47567 .31856 L
s
.47568 .31815 m
.47575 .31852 L
s
.47604 .31829 m
.47575 .31852 L
s
1 .095 0 r
.79111 .59602 m
.79117 .59698 L
s
1 .233 0 r
.74753 .62655 m
.74752 .6289 L
s
1 .066 0 r
.71844 .19506 m
.71872 .19513 L
s
.71868 .19453 m
.71844 .19506 L
s
.71915 .19506 m
.71844 .19506 L
s
.71915 .19506 m
.71872 .19513 L
s
.71868 .19453 m
.71915 .19506 L
s
.71896 .19459 m
.71915 .19506 L
s
.71689 .19391 m
.71915 .19506 L
s
1 .043 0 r
.4756 .31818 m
.47568 .31815 L
s
.47568 .31815 m
.47604 .31829 L
s
1 .066 0 r
.71896 .19459 m
.71868 .19453 L
s
.973 1 0 r
.63536 .58809 m
.64201 .59334 L
s
.62907 .59357 m
.63536 .58809 L
s
.63536 .58809 m
.63558 .58839 L
s
1 .018 0 r
.22834 .25647 m
.22843 .2566 L
s
.22824 .25651 m
.22834 .25647 L
s
.22834 .25647 m
.22842 .25647 L
s
.22843 .2566 m
.22833 .25664 L
s
.22842 .25647 m
.22843 .2566 L
s
1 .043 0 r
.47604 .31829 m
.47567 .31856 L
s
.4756 .31818 m
.47604 .31829 L
s
1 .018 0 r
.22833 .25664 m
.22824 .25651 L
s
.22824 .25651 m
.22842 .25647 L
s
.22842 .25647 m
.22833 .25664 L
s
1 .043 0 r
.47567 .31856 m
.4756 .31818 L
s
1 .066 0 r
.71872 .19513 m
.71896 .19459 L
s
0 1 .077 r
.61379 .57787 m
.6011 .56497 L
s
.6011 .56497 m
.61927 .5571 L
s
1 .029 0 r
.90282 .5956 m
.90302 .59574 L
s
.90266 .59576 m
.90282 .5956 L
s
.90282 .5956 m
.90285 .59561 L
s
.90286 .5959 m
.90266 .59576 L
s
.90266 .59576 m
.90285 .59561 L
s
.90302 .59574 m
.90286 .5959 L
s
.90285 .59561 m
.90302 .59574 L
s
.90285 .59561 m
.90286 .5959 L
s
0 .197 1 r
.6962 .5956 m
.66684 .62438 L
s
.6556 .59276 m
.6962 .5956 L
s
1 .137 0 r
.32101 .5646 m
.32123 .56465 L
s
.32132 .56323 m
.32101 .5646 L
s
.32101 .5646 m
.32043 .5638 L
s
.32212 .56408 m
.32101 .5646 L
s
.32233 .5613 m
.32101 .5646 L
s
1 .01 0 r
.65327 .34845 m
.65331 .34847 L
s
.65331 .34837 m
.65327 .34845 L
s
.65338 .34845 m
.65327 .34845 L
s
.65338 .34845 m
.65331 .34847 L
s
.65331 .34837 m
.65338 .34845 L
s
.65335 .34839 m
.65338 .34845 L
s
.65302 .34829 m
.65338 .34845 L
s
.65335 .34839 m
.65331 .34837 L
s
.65331 .34847 m
.65335 .34839 L
s
1 .001 0 r
.34275 .44094 m
.34276 .44094 L
s
.34276 .44093 m
.34275 .44094 L
s
.34275 .44094 m
.34275 .44093 L
s
.34277 .44094 m
.34275 .44094 L
s
.34278 .44091 m
.34275 .44094 L
s
.34276 .44093 m
.34275 .44093 L
s
.34277 .44094 m
.34276 .44093 L
s
.34276 .44094 m
.34277 .44094 L
s
.34275 .44093 m
.34276 .44094 L
s
1 .035 0 r
.83551 .56442 m
.83541 .56356 L
s
1 .344 0 r
.58915 .50267 m
.57688 .49753 L
s
1 .046 0 r
.40666 .28653 m
.40838 .2859 L
s
1 0 0 r
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
0 1 .566 r
.52603 .48259 m
.54032 .49103 L
s
.51182 .50015 m
.52603 .48259 L
s
.52603 .48259 m
.51516 .48373 L
s
1 .137 0 r
.32132 .56323 m
.32043 .5638 L
s
.32212 .56408 m
.32132 .56323 L
s
1 .033 0 r
.21109 .5642 m
.21109 .56421 L
s
.21112 .56387 m
.21109 .5642 L
s
.21109 .5642 m
.2109 .56402 L
s
.21132 .56406 m
.21109 .5642 L
s
.21119 .56338 m
.21109 .5642 L
s
.21112 .56387 m
.2109 .56402 L
s
.21132 .56406 m
.21112 .56387 L
s
1 .046 0 r
.40819 .28619 m
.40803 .28624 L
s
.40805 .28581 m
.40819 .28619 L
s
.40838 .2859 m
.40819 .28619 L
s
.40789 .28586 m
.40805 .28581 L
s
.40805 .28581 m
.40838 .2859 L
s
1 .137 0 r
.32123 .56465 m
.32212 .56408 L
s
1 .033 0 r
.21109 .56421 m
.21132 .56406 L
s
.2109 .56402 m
.21109 .56421 L
s
1 .151 0 r
.72293 .56279 m
.72391 .56344 L
s
.72204 .56371 m
.72293 .56279 L
s
.72293 .56279 m
.72273 .56284 L
s
1 .136 0 r
.51685 .47147 m
.51688 .4713 L
s
.51688 .4713 m
.51685 .47011 L
s
.51688 .4713 m
.51566 .47081 L
s
1 .046 0 r
.40838 .2859 m
.40803 .28624 L
s
.40789 .28586 m
.40838 .2859 L
s
.40803 .28624 m
.40789 .28586 L
s
0 .197 1 r
.66684 .62438 m
.6556 .59276 L
s
1 .136 0 r
.51685 .47011 m
.51682 .47028 L
s
.51685 .47011 m
.51566 .47081 L
s
1 .035 0 r
.83541 .56355 m
.83565 .56371 L
s
.83521 .56375 m
.83541 .56355 L
s
.83541 .56355 m
.83541 .56356 L
s
1 .137 0 r
.32043 .5638 m
.32123 .56465 L
s
1 .035 0 r
.83545 .56391 m
.83521 .56375 L
s
.83521 .56375 m
.83541 .56356 L
s
1 .787 0 r
.60405 .53285 m
.59973 .53826 L
s
.59648 .53068 m
.60405 .53285 L
s
1 .039 0 r
.58677 .31663 m
.58685 .31666 L
s
.58684 .31629 m
.58677 .31663 L
s
.58717 .31654 m
.58677 .31663 L
s
1 .151 0 r
.72302 .56435 m
.72204 .56371 L
s
.72204 .56371 m
.72273 .56284 L
s
1 .035 0 r
.83565 .56371 m
.83545 .56391 L
s
.83541 .56356 m
.83565 .56371 L
s
1 .039 0 r
.58692 .31632 m
.58684 .31629 L
s
.58684 .31629 m
.58717 .31654 L
s
.58717 .31654 m
.58685 .31666 L
s
.58692 .31632 m
.58717 .31654 L
s
.58554 .31622 m
.58717 .31654 L
s
1 .035 0 r
.83541 .56356 m
.83545 .56391 L
s
.285 1 0 r
.48721 .53557 m
.48437 .53273 L
s
.48437 .53273 m
.48742 .51794 L
s
.48437 .53273 m
.47271 .52422 L
s
.973 1 0 r
.40794 .59448 m
.4132 .60192 L
s
1 .039 0 r
.58685 .31666 m
.58692 .31632 L
s
1 .136 0 r
.51566 .47081 m
.51685 .47147 L
s
.51566 .47081 m
.51682 .47028 L
s
.52162 .4707 m
.51566 .47081 L
s
1 .151 0 r
.72391 .56344 m
.72302 .56435 L
s
.72273 .56284 m
.72391 .56344 L
s
1 0 0 r
.83206 .37802 m
.83206 .37802 L
s
.83206 .37801 m
.83206 .37802 L
s
.83206 .37802 m
.83206 .37801 L
s
.83206 .37801 m
.83206 .37802 L
s
.83205 .37801 m
.83206 .37802 L
s
.83206 .37801 m
.83206 .37801 L
s
.83206 .37801 m
.83206 .37801 L
s
.83206 .37801 m
.83206 .37802 L
s
.83206 .37802 m
.83206 .37801 L
s
1 .043 0 r
.76814 .53249 m
.76774 .53145 L
s
1 .04 0 r
.33902 .25443 m
.34035 .2537 L
s
1 0 0 r
.2751 .40891 m
.2751 .40891 L
s
1 .151 0 r
.72273 .56284 m
.72302 .56435 L
s
1 .136 0 r
.51682 .47028 m
.51685 .47147 L
s
1 .787 0 r
.59648 .53068 m
.59973 .53826 L
s
1 .04 0 r
.34025 .25398 m
.34007 .25403 L
s
.34009 .25365 m
.34025 .25398 L
s
.34035 .2537 m
.34025 .25398 L
s
.33991 .25371 m
.34009 .25365 L
s
.34009 .25365 m
.34035 .2537 L
s
.808 1 0 r
.40382 .62473 m
.40929 .62632 L
s
.40972 .61372 m
.40382 .62473 L
s
.40382 .62473 m
.40316 .61764 L
s
.41583 .62237 m
.40382 .62473 L
s
.43259 .60083 m
.40382 .62473 L
s
1 .04 0 r
.34007 .25403 m
.33991 .25371 L
s
.34035 .2537 m
.34007 .25403 L
s
.33991 .25371 m
.34035 .2537 L
s
1 .043 0 r
.7678 .53144 m
.76808 .53161 L
s
.76756 .5317 m
.7678 .53144 L
s
.7678 .53144 m
.76774 .53145 L
s
.973 1 0 r
.63571 .59883 m
.62907 .59357 L
s
.62907 .59357 m
.63558 .58839 L
s
1 .043 0 r
.76784 .53187 m
.76756 .5317 L
s
.76756 .5317 m
.76774 .53145 L
s
1 .009 0 r
.14336 .53165 m
.14336 .53165 L
s
.14337 .53156 m
.14336 .53165 L
s
.14336 .53165 m
.14331 .5316 L
s
.14342 .53161 m
.14336 .53165 L
s
.14339 .53143 m
.14336 .53165 L
s
1 .068 0 r
.52037 .28434 m
.52036 .28438 L
s
.52036 .28374 m
.52037 .28434 L
s
.52095 .28405 m
.52037 .28434 L
s
1 .009 0 r
.14337 .53156 m
.14331 .5316 L
s
.14342 .53161 m
.14337 .53156 L
s
1 .043 0 r
.76808 .53161 m
.76784 .53187 L
s
.76774 .53145 m
.76808 .53161 L
s
1 .009 0 r
.14336 .53165 m
.14342 .53161 L
s
.14331 .5316 m
.14336 .53165 L
s
1 .068 0 r
.52034 .28378 m
.52036 .28374 L
s
.52036 .28374 m
.52095 .28405 L
s
1 .043 0 r
.76774 .53145 m
.76784 .53187 L
s
1 .007 0 r
.45381 .43879 m
.45383 .43877 L
s
.45383 .43877 m
.45381 .43872 L
s
.45383 .43877 m
.45376 .43877 L
s
.973 1 0 r
.64201 .59334 m
.63571 .59883 L
s
.63558 .58839 m
.64201 .59334 L
s
1 .007 0 r
.45381 .43872 m
.45379 .43873 L
s
.45381 .43872 m
.45376 .43877 L
s
.45376 .43877 m
.45381 .43879 L
s
.45376 .43877 m
.45379 .43873 L
s
.45401 .43868 m
.45376 .43877 L
s
1 .003 0 r
.76472 .34601 m
.7647 .34601 L
s
.7647 .34598 m
.76472 .34601 L
s
.76472 .34601 m
.76468 .34601 L
s
.76472 .34599 m
.76472 .34601 L
s
.76464 .34594 m
.76472 .34601 L
s
.7647 .34598 m
.76468 .34601 L
s
.76472 .34599 m
.7647 .34598 L
s
.76468 .34601 m
.7647 .34601 L
s
1 .007 0 r
.45379 .43873 m
.45381 .43879 L
s
1 .003 0 r
.7647 .34601 m
.76472 .34599 L
s
1 .048 0 r
.70069 .50051 m
.69979 .49941 L
s
1 .068 0 r
.51797 .28411 m
.52095 .28405 L
s
1 0 0 r
.20734 .37686 m
.20735 .37685 L
s
1 .034 0 r
.27129 .22228 m
.27227 .22157 L
s
1 0 0 r
.20735 .37685 m
.20735 .37685 L
s
.20734 .37685 m
.20735 .37685 L
s
.20735 .37685 m
.20735 .37685 L
s
.20735 .37685 m
.20735 .37685 L
s
.20735 .37685 m
.20735 .37685 L
s
.20735 .37685 m
.20734 .37685 L
s
.20734 .37685 m
.20735 .37685 L
s
.20735 .37685 m
.20735 .37685 L
s
1 .068 0 r
.52095 .28405 m
.52036 .28438 L
s
.52034 .28378 m
.52095 .28405 L
s
.285 1 0 r
.48742 .51794 m
.49028 .52068 L
s
.48742 .51794 m
.47271 .52422 L
s
1 .068 0 r
.52036 .28438 m
.52034 .28378 L
s
0 1 .566 r
.52604 .50872 m
.51182 .50015 L
s
.51182 .50015 m
.51516 .48373 L
s
1 .034 0 r
.27209 .22156 m
.27224 .22182 L
s
.27191 .22161 m
.27209 .22156 L
s
.27209 .22156 m
.27227 .22157 L
s
.27224 .22182 m
.27206 .22187 L
s
.27227 .22157 m
.27224 .22182 L
s
.27206 .22187 m
.27191 .22161 L
s
.27191 .22161 m
.27227 .22157 L
s
.27227 .22157 m
.27206 .22187 L
s
1 .459 0 r
.67783 .58909 m
.68082 .59121 L
s
.67506 .59177 m
.67783 .58909 L
s
.67783 .58909 m
.67744 .58926 L
s
1 .253 0 r
.65263 .52875 m
.65412 .52961 L
s
.65124 .53049 m
.65263 .52875 L
s
.65263 .52875 m
.6517 .52891 L
s
0 1 .077 r
.61927 .5571 m
.61379 .57787 L
s
1 .048 0 r
.69995 .49939 m
.70024 .49955 L
s
.69969 .49972 m
.69995 .49939 L
s
.69995 .49939 m
.69979 .49941 L
s
.69998 .49988 m
.69969 .49972 L
s
.69969 .49972 m
.69979 .49941 L
s
1 .787 0 r
.45094 .53021 m
.45332 .53678 L
s
1 .016 0 r
.69766 .31413 m
.69756 .31415 L
s
.69755 .31399 m
.69766 .31413 L
s
.69766 .31413 m
.69748 .31412 L
s
.69762 .31402 m
.69766 .31413 L
s
.69714 .31383 m
.69766 .31413 L
s
.69748 .31412 m
.69756 .31415 L
s
.69755 .31399 m
.69748 .31412 L
s
.69762 .31402 m
.69755 .31399 L
s
1 .344 0 r
.57937 .50031 m
.57806 .49961 L
s
.57806 .49961 m
.57931 .49681 L
s
.57806 .49961 m
.57688 .49753 L
s
1 .016 0 r
.69756 .31415 m
.69762 .31402 L
s
1 .253 0 r
.65273 .53135 m
.65124 .53049 L
s
.65124 .53049 m
.6517 .52891 L
s
1 .048 0 r
.70024 .49955 m
.69998 .49988 L
s
.69979 .49941 m
.70024 .49955 L
s
.69979 .49941 m
.69998 .49988 L
s
1 .344 0 r
.57931 .49681 m
.58062 .49751 L
s
.57931 .49681 m
.57688 .49753 L
s
1 .002 0 r
.0755 .49949 m
.0755 .49949 L
s
.0755 .49947 m
.0755 .49949 L
s
.0755 .49949 m
.07549 .49947 L
s
.07551 .49948 m
.0755 .49949 L
s
.0755 .49944 m
.0755 .49949 L
s
.0755 .49947 m
.07549 .49947 L
s
.07551 .49948 m
.0755 .49947 L
s
.0755 .49949 m
.07551 .49948 L
s
.07549 .49947 m
.0755 .49949 L
s
1 .141 0 r
.3633 .53038 m
.36379 .53046 L
s
.36386 .52902 m
.3633 .53038 L
s
.3633 .53038 m
.36302 .5295 L
s
.36463 .52998 m
.3633 .53038 L
s
.36591 .52718 m
.3633 .53038 L
s
1 .011 0 r
.87997 .53037 m
.87992 .53009 L
s
0 .04 1 r
.56916 .62317 m
.48379 .53439 L
s
1 .039 0 r
.63315 .4685 m
.63195 .4678 L
s
1 0 0 r
.38632 .40663 m
.38632 .40663 L
s
1 .075 0 r
.45031 .25197 m
.45343 .25131 L
s
1 .001 0 r
.1395 .34477 m
.13951 .34475 L
s
.13951 .34475 m
.13951 .34475 L
s
.1395 .34475 m
.13951 .34475 L
s
.13951 .34475 m
.13951 .34475 L
s
.13951 .34475 m
.1395 .34476 L
s
.13951 .34475 m
.13951 .34475 L
s
.1395 .34476 m
.1395 .34475 L
s
.1395 .34475 m
.13951 .34475 L
s
.13951 .34475 m
.1395 .34476 L
s
.808 1 0 r
.40972 .61372 m
.40316 .61764 L
s
.41583 .62237 m
.40972 .61372 L
s
1 .075 0 r
.45296 .25175 m
.4528 .25179 L
s
.45282 .25109 m
.45296 .25175 L
s
.45343 .25131 m
.45296 .25175 L
s
1 .011 0 r
.87993 .53008 m
.88001 .53013 L
s
.87986 .53015 m
.87993 .53008 L
s
.87993 .53008 m
.87992 .53009 L
s
.87994 .5302 m
.87986 .53015 L
s
.87986 .53015 m
.87992 .53009 L
s
.88001 .53013 m
.87994 .5302 L
s
.87992 .53009 m
.88001 .53013 L
s
1 .075 0 r
.45266 .25114 m
.45282 .25109 L
s
.45282 .25109 m
.45343 .25131 L
s
1 .141 0 r
.36386 .52902 m
.36302 .5295 L
s
.36463 .52998 m
.36386 .52902 L
s
1 .011 0 r
.87992 .53009 m
.87994 .5302 L
s
1 .029 0 r
.25426 .53002 m
.2543 .53003 L
s
.25432 .52973 m
.25426 .53002 L
s
.25426 .53002 m
.25413 .52985 L
s
.25449 .52991 m
.25426 .53002 L
s
.25451 .52931 m
.25426 .53002 L
s
1 .141 0 r
.36379 .53046 m
.36463 .52998 L
s
1 .029 0 r
.25432 .52973 m
.25413 .52985 L
s
.25449 .52991 m
.25432 .52973 L
s
1 .039 0 r
.63218 .46775 m
.63236 .46784 L
s
.63201 .46805 m
.63218 .46775 L
s
.63218 .46775 m
.63195 .4678 L
s
.63219 .46814 m
.63201 .46805 L
s
.63201 .46805 m
.63195 .4678 L
s
1 .029 0 r
.2543 .53003 m
.25449 .52991 L
s
1 .459 0 r
.67805 .5939 m
.67506 .59177 L
s
.67506 .59177 m
.67744 .58926 L
s
1 .029 0 r
.25413 .52985 m
.2543 .53003 L
s
1 .046 0 r
.63087 .28231 m
.631 .28235 L
s
.63099 .28192 m
.63087 .28231 L
s
.63136 .28224 m
.63087 .28231 L
s
.63113 .28196 m
.63099 .28192 L
s
.63099 .28192 m
.63136 .28224 L
s
1 .075 0 r
.45343 .25131 m
.4528 .25179 L
s
.45266 .25114 m
.45343 .25131 L
s
1 .046 0 r
.63136 .28224 m
.631 .28235 L
s
.63113 .28196 m
.63136 .28224 L
s
.62956 .28169 m
.63136 .28224 L
s
1 .039 0 r
.63236 .46784 m
.63219 .46814 L
s
.63195 .4678 m
.63236 .46784 L
s
.63195 .4678 m
.63219 .46814 L
s
1 .075 0 r
.4528 .25179 m
.45266 .25114 L
s
1 .253 0 r
.65412 .52961 m
.65273 .53135 L
s
.6517 .52891 m
.65412 .52961 L
s
1 .046 0 r
.631 .28235 m
.63113 .28196 L
s
.808 1 0 r
.40929 .62632 m
.41583 .62237 L
s
1 .141 0 r
.36302 .5295 m
.36379 .53046 L
s
1 .253 0 r
.6517 .52891 m
.65273 .53135 L
s
1 .01 0 r
.8125 .49836 m
.8124 .49811 L
s
1 .008 0 r
.56552 .43645 m
.56517 .43639 L
s
1 .066 0 r
.38258 .21978 m
.38509 .21882 L
s
1 .001 0 r
.31854 .37454 m
.31856 .37453 L
s
1 .459 0 r
.68082 .59121 m
.67805 .5939 L
s
.67744 .58926 m
.68082 .59121 L
s
1 .001 0 r
.31856 .37453 m
.31856 .37454 L
s
.31855 .37453 m
.31856 .37453 L
s
.31856 .37453 m
.31856 .37453 L
s
.31856 .37454 m
.31856 .37454 L
s
.31856 .37453 m
.31856 .37454 L
s
.31856 .37454 m
.31855 .37453 L
s
.31855 .37453 m
.31856 .37453 L
s
.31856 .37453 m
.31856 .37454 L
s
1 .008 0 r
.56524 .43644 m
.56523 .43643 L
s
.56523 .43643 m
.56524 .43636 L
s
.56523 .43643 m
.56517 .43639 L
s
.56524 .43636 m
.56526 .43637 L
s
.56524 .43636 m
.56517 .43639 L
s
.56517 .43639 m
.56524 .43644 L
s
.56517 .43639 m
.56526 .43637 L
s
.56526 .43637 m
.56524 .43644 L
s
1 .01 0 r
.81242 .49811 m
.81248 .49815 L
s
.81236 .49817 m
.81242 .49811 L
s
.81242 .49811 m
.8124 .49811 L
s
.81243 .49821 m
.81236 .49817 L
s
.81236 .49817 m
.8124 .49811 L
s
.81248 .49815 m
.81243 .49821 L
s
.8124 .49811 m
.81248 .49815 L
s
.8124 .49811 m
.81243 .49821 L
s
.973 1 0 r
.63558 .58839 m
.63571 .59883 L
s
1 .066 0 r
.3848 .21927 m
.38457 .21932 L
s
.3846 .21871 m
.3848 .21927 L
s
.38509 .21882 m
.3848 .21927 L
s
.38437 .21876 m
.3846 .21871 L
s
.3846 .21871 m
.38509 .21882 L
s
1 .08 0 r
.56459 .25011 m
.56467 .25015 L
s
.56466 .2494 m
.56459 .25011 L
s
.56536 .24985 m
.56459 .25011 L
s
.56475 .24944 m
.56466 .2494 L
s
.56466 .2494 m
.56536 .24985 L
s
1 .344 0 r
.58062 .49751 m
.57937 .50031 L
s
.57688 .49753 m
.57937 .50031 L
s
1 .08 0 r
.56536 .24985 m
.56467 .25015 L
s
.56475 .24944 m
.56536 .24985 L
s
.56189 .2495 m
.56536 .24985 L
s
1 .066 0 r
.38509 .21882 m
.38457 .21932 L
s
.38437 .21876 m
.38509 .21882 L
s
1 .344 0 r
.57688 .49753 m
.58062 .49751 L
s
1 .066 0 r
.38457 .21932 m
.38437 .21876 L
s
1 .006 0 r
.18657 .49742 m
.18657 .49742 L
s
.18658 .49736 m
.18657 .49742 L
s
.18657 .49742 m
.18654 .49738 L
s
.18661 .49739 m
.18657 .49742 L
s
.18661 .49728 m
.18657 .49742 L
s
.18658 .49736 m
.18654 .49738 L
s
.18661 .49739 m
.18658 .49736 L
s
1 .459 0 r
.67744 .58926 m
.67805 .5939 L
s
1 .006 0 r
.18657 .49742 m
.18661 .49739 L
s
.80915 .31157 m
.80913 .31157 L
s
.80912 .31152 m
.80915 .31157 L
s
.80915 .31157 m
.8091 .31156 L
s
.80916 .31153 m
.80915 .31157 L
s
.80902 .31144 m
.80915 .31157 L
s
.80912 .31152 m
.8091 .31156 L
s
.80916 .31153 m
.80912 .31152 L
s
.8091 .31156 m
.80913 .31157 L
s
.18654 .49738 m
.18657 .49742 L
s
.80913 .31157 m
.80916 .31153 L
s
1 .08 0 r
.56467 .25015 m
.56475 .24944 L
s
1 .575 0 r
.68088 .62116 m
.67776 .60732 L
s
1 .007 0 r
.74495 .4663 m
.74483 .46615 L
s
1 0 0 r
.49782 .40436 m
.49782 .40436 L
s
1 .002 0 r
.25068 .34241 m
.25073 .34236 L
s
1 .055 0 r
.31475 .18755 m
.3166 .18655 L
s
1 .002 0 r
.25072 .34236 m
.25073 .34238 L
s
.25071 .34237 m
.25072 .34236 L
s
.25072 .34236 m
.25073 .34236 L
s
.25073 .34238 m
.25072 .34239 L
s
.25073 .34236 m
.25073 .34238 L
s
.25072 .34239 m
.25071 .34237 L
s
.25071 .34237 m
.25073 .34236 L
s
.939 1 0 r
.44444 .56134 m
.44792 .55918 L
s
.44792 .55918 m
.44471 .55032 L
s
.44792 .55918 m
.43645 .55837 L
s
1 .002 0 r
.25073 .34236 m
.25072 .34239 L
s
1 .007 0 r
.74485 .46614 m
.74489 .46617 L
s
.74481 .46619 m
.74485 .46614 L
s
.74485 .46614 m
.74483 .46615 L
s
.74486 .46621 m
.74481 .46619 L
s
.74481 .46619 m
.74483 .46615 L
s
.74489 .46617 m
.74486 .46621 L
s
.74483 .46615 m
.74489 .46617 L
s
.74483 .46615 m
.74486 .46621 L
s
1 .055 0 r
.31646 .18694 m
.31621 .187 L
s
.31625 .18649 m
.31646 .18694 L
s
.3166 .18655 m
.31646 .18694 L
s
.31601 .18655 m
.31625 .18649 L
s
.31625 .18649 m
.3166 .18655 L
s
.939 1 0 r
.44471 .55032 m
.44121 .55245 L
s
.44471 .55032 m
.43645 .55837 L
s
1 .019 0 r
.742 .27964 m
.74189 .27965 L
s
.74188 .27947 m
.742 .27964 L
s
.742 .27964 m
.7418 .27962 L
s
.74198 .2795 m
.742 .27964 L
s
.74142 .27925 m
.742 .27964 L
s
.74188 .27947 m
.7418 .27962 L
s
.74198 .2795 m
.74188 .27947 L
s
.7418 .27962 m
.74189 .27965 L
s
1 .055 0 r
.31621 .187 m
.31601 .18655 L
s
.3166 .18655 m
.31621 .187 L
s
.31601 .18655 m
.3166 .18655 L
s
1 .019 0 r
.74189 .27965 m
.74198 .2795 L
s
.939 1 0 r
.43645 .55837 m
.44444 .56134 L
s
.43645 .55837 m
.44121 .55245 L
s
.47729 .54555 m
.43645 .55837 L
s
1 .095 0 r
.49756 .21741 m
.49748 .21745 L
s
.49748 .21656 m
.49756 .21741 L
s
.49832 .21694 m
.49756 .21741 L
s
.4974 .21659 m
.49748 .21656 L
s
.49748 .21656 m
.49832 .21694 L
s
1 .001 0 r
.11862 .46522 m
.11862 .46522 L
s
.11862 .46521 m
.11862 .46522 L
s
.11862 .46522 m
.11861 .46522 L
s
.11862 .46522 m
.11862 .46522 L
s
.11862 .4652 m
.11862 .46522 L
s
.11862 .46521 m
.11861 .46522 L
s
.11862 .46522 m
.11862 .46521 L
s
.11862 .46522 m
.11862 .46522 L
s
.11861 .46522 m
.11862 .46522 L
s
1 .168 0 r
.2769 .62017 m
.27693 .62025 L
s
.27706 .61847 m
.2769 .62017 L
s
.2769 .62017 m
.27593 .61928 L
s
.27806 .61945 m
.2769 .62017 L
s
.27737 .61613 m
.2769 .62017 L
s
.717 1 0 r
.6132 .58917 m
.58725 .5608 L
s
1 .002 0 r
.67731 .43421 m
.67726 .43417 L
s
1 .095 0 r
.49414 .21727 m
.49832 .21694 L
s
1 .002 0 r
.43002 .37223 m
.43011 .3722 L
s
1 .003 0 r
.18274 .31024 m
.1828 .31016 L
s
1 .002 0 r
.4301 .37221 m
.43009 .37221 L
s
.43009 .37219 m
.4301 .37221 L
s
.43011 .3722 m
.4301 .37221 L
s
.43008 .3722 m
.43009 .37219 L
s
.43009 .37219 m
.43011 .3722 L
s
.67727 .43417 m
.67728 .43418 L
s
.67726 .43419 m
.67727 .43417 L
s
.67727 .43417 m
.67726 .43417 L
s
.67727 .43419 m
.67726 .43419 L
s
.67726 .43419 m
.67726 .43417 L
s
.43011 .3722 m
.43009 .37221 L
s
.43008 .3722 m
.43011 .3722 L
s
.43009 .37221 m
.43008 .3722 L
s
.67728 .43418 m
.67727 .43419 L
s
.67726 .43417 m
.67728 .43418 L
s
.67726 .43417 m
.67727 .43419 L
s
1 .003 0 r
.18279 .31016 m
.18281 .31018 L
s
.18277 .31017 m
.18279 .31016 L
s
.18279 .31016 m
.1828 .31016 L
s
.18281 .31018 m
.18278 .31019 L
s
.1828 .31016 m
.18281 .31018 L
s
.18278 .31019 m
.18277 .31017 L
s
.18277 .31017 m
.1828 .31016 L
s
.1828 .31016 m
.18278 .31019 L
s
0 1 .331 r
.61655 .57068 m
.6309 .58523 L
s
.60284 .5805 m
.61655 .57068 L
s
.61655 .57068 m
.62344 .57166 L
s
1 .095 0 r
.49832 .21694 m
.49748 .21745 L
s
.4974 .21659 m
.49832 .21694 L
s
1 .168 0 r
.27706 .61847 m
.27593 .61928 L
s
.27806 .61945 m
.27706 .61847 L
s
1 .047 0 r
.67496 .24776 m
.67513 .24781 L
s
.67511 .24737 m
.67496 .24776 L
s
.67547 .24773 m
.67496 .24776 L
s
.67529 .24742 m
.67511 .24737 L
s
.67511 .24737 m
.67547 .24773 L
s
.67547 .24773 m
.67513 .24781 L
s
.67529 .24742 m
.67547 .24773 L
s
.67374 .24702 m
.67547 .24773 L
s
1 .095 0 r
.49748 .21745 m
.4974 .21659 L
s
1 .021 0 r
.29767 .49561 m
.29773 .49562 L
s
.29774 .4954 m
.29767 .49561 L
s
.29767 .49561 m
.29761 .49548 L
s
.29786 .49554 m
.29767 .49561 L
s
.29799 .49511 m
.29767 .49561 L
s
.29774 .4954 m
.29761 .49548 L
s
.29786 .49554 m
.29774 .4954 L
s
.29773 .49562 m
.29786 .49554 L
s
1 .047 0 r
.67513 .24781 m
.67529 .24742 L
s
1 .021 0 r
.29761 .49548 m
.29773 .49562 L
s
1 .168 0 r
.27693 .62025 m
.27806 .61945 L
s
1 .051 0 r
.16587 .61939 m
.16583 .61941 L
s
.16589 .61887 m
.16587 .61939 L
s
.16587 .61939 m
.16553 .61913 L
s
.16618 .61916 m
.16587 .61939 L
s
.1658 .61815 m
.16587 .61939 L
s
1 .168 0 r
.27593 .61928 m
.27693 .62025 L
s
1 .051 0 r
.16589 .61887 m
.16553 .61913 L
s
.16618 .61916 m
.16589 .61887 L
s
.16583 .61941 m
.16618 .61916 L
s
1 0 0 r
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
1 .134 0 r
.79288 .61915 m
.79273 .61592 L
s
1 .002 0 r
.85703 .4641 m
.85701 .46406 L
s
0 1 .077 r
.54544 .55713 m
.45679 .54207 L
s
1 0 0 r
.60959 .40208 m
.60959 .40208 L
s
1 .006 0 r
.36215 .34006 m
.36235 .33994 L
s
1 .091 0 r
.4263 .185 m
.43005 .18409 L
s
1 .002 0 r
.85702 .46406 m
.85703 .46406 L
s
.85701 .46407 m
.85702 .46406 L
s
.85702 .46406 m
.85701 .46406 L
s
1 .051 0 r
.16553 .61913 m
.16583 .61941 L
s
1 .002 0 r
.85702 .46407 m
.85701 .46407 L
s
.85701 .46407 m
.85701 .46406 L
s
.85703 .46406 m
.85702 .46407 L
s
.85701 .46406 m
.85703 .46406 L
s
.85701 .46406 m
.85702 .46407 L
s
1 .111 0 r
.40645 .49506 m
.40707 .4952 L
s
.40711 .49407 m
.40645 .49506 L
s
.40645 .49506 m
.40656 .49435 L
s
.40762 .49492 m
.40645 .49506 L
s
.40966 .49294 m
.40645 .49506 L
s
1 .006 0 r
.36234 .33998 m
.36231 .33999 L
s
.36231 .33993 m
.36234 .33998 L
s
.36235 .33994 m
.36234 .33998 L
s
.36228 .33995 m
.36231 .33993 L
s
.36231 .33993 m
.36235 .33994 L
s
.36231 .33999 m
.36228 .33995 L
s
.36235 .33994 m
.36231 .33999 L
s
.36228 .33995 m
.36235 .33994 L
s
1 .111 0 r
.40711 .49407 m
.40656 .49435 L
s
.40762 .49492 m
.40711 .49407 L
s
.40707 .4952 m
.40762 .49492 L
s
1 .091 0 r
.42951 .18465 m
.42929 .18469 L
s
.42932 .18385 m
.42951 .18465 L
s
.43005 .18409 m
.42951 .18465 L
s
1 .081 0 r
.60854 .21565 m
.60871 .21569 L
s
.60869 .21494 m
.60854 .21565 L
s
.60938 .21545 m
.60854 .21565 L
s
1 .091 0 r
.4291 .18389 m
.42932 .18385 L
s
.42932 .18385 m
.43005 .18409 L
s
1 .081 0 r
.60886 .21498 m
.60869 .21494 L
s
.60869 .21494 m
.60938 .21545 L
s
.60938 .21545 m
.60871 .21569 L
s
.60886 .21498 m
.60938 .21545 L
s
.60597 .21475 m
.60938 .21545 L
s
1 .111 0 r
.40656 .49435 m
.40707 .4952 L
s
1 .091 0 r
.43005 .18409 m
.42929 .18469 L
s
.4291 .18389 m
.43005 .18409 L
s
1 .081 0 r
.60871 .21569 m
.60886 .21498 L
s
1 .091 0 r
.42929 .18469 m
.4291 .18389 L
s
1 .003 0 r
.22996 .46306 m
.22996 .46306 L
s
.22997 .46303 m
.22996 .46306 L
s
.22996 .46306 m
.22995 .46304 L
s
.22998 .46305 m
.22996 .46306 L
s
.22999 .46299 m
.22996 .46306 L
s
.22997 .46303 m
.22995 .46304 L
s
.22998 .46305 m
.22997 .46303 L
s
.22996 .46306 m
.22998 .46305 L
s
.22995 .46304 m
.22996 .46306 L
s
.54189 .36992 m
.5419 .36993 L
s
.5419 .36989 m
.54189 .36992 L
s
.54192 .36991 m
.54189 .36992 L
s
.5419 .3699 m
.5419 .36989 L
s
.5419 .36989 m
.54192 .36991 L
s
.54192 .36991 m
.5419 .36993 L
s
.5419 .3699 m
.54192 .36991 L
s
.54178 .3699 m
.54192 .36991 L
s
1 0 0 r
.78938 .43196 m
.78937 .43195 L
s
1 .22 0 r
.72519 .58712 m
.7234 .58182 L
s
1 .009 0 r
.29418 .30784 m
.29442 .30766 L
s
1 .003 0 r
.5419 .36993 m
.5419 .3699 L
s
1 0 0 r
.78937 .43195 m
.78938 .43196 L
s
.78937 .43196 m
.78937 .43195 L
s
.78937 .43195 m
.78937 .43195 L
s
.78937 .43196 m
.78937 .43196 L
s
.78937 .43196 m
.78937 .43195 L
s
.78938 .43196 m
.78937 .43196 L
s
.78937 .43195 m
.78938 .43196 L
s
.78937 .43195 m
.78937 .43196 L
s
1 .009 0 r
.29438 .30766 m
.29442 .30772 L
s
.29433 .30767 m
.29438 .30766 L
s
.29438 .30766 m
.29442 .30766 L
s
.29442 .30772 m
.29437 .30774 L
s
.29442 .30766 m
.29442 .30772 L
s
.29437 .30774 m
.29433 .30767 L
s
.29433 .30767 m
.29442 .30766 L
s
.29442 .30766 m
.29437 .30774 L
s
1 .202 0 r
.31911 .58678 m
.31943 .58688 L
s
.31956 .58476 m
.31911 .58678 L
s
.31911 .58678 m
.31824 .58561 L
s
.32075 .58602 m
.31911 .58678 L
s
.32106 .58196 m
.31911 .58678 L
s
.808 1 0 r
.40316 .61764 m
.40929 .62632 L
s
1 .104 0 r
.54177 .18301 m
.54181 .18303 L
s
.5418 .18208 m
.54177 .18301 L
s
.54273 .18258 m
.54177 .18301 L
s
1 .018 0 r
.09769 .58654 m
.09767 .58655 L
s
.0977 .58636 m
.09769 .58654 L
s
.09769 .58654 m
.09757 .58644 L
s
.0978 .58646 m
.09769 .58654 L
s
.09767 .58609 m
.09769 .58654 L
s
.0977 .58636 m
.09757 .58644 L
s
.0978 .58646 m
.0977 .58636 L
s
.09767 .58655 m
.0978 .58646 L
s
1 .021 0 r
.78647 .24499 m
.78636 .245 L
s
.78634 .2448 m
.78647 .24499 L
s
.78647 .24499 m
.78624 .24496 L
s
.78645 .24484 m
.78647 .24499 L
s
.78588 .24454 m
.78647 .24499 L
s
1 .104 0 r
.54184 .1821 m
.5418 .18208 L
s
.5418 .18208 m
.54273 .18258 L
s
1 .018 0 r
.09757 .58644 m
.09767 .58655 L
s
1 .021 0 r
.78634 .2448 m
.78624 .24496 L
s
.78645 .24484 m
.78634 .2448 L
s
.78624 .24496 m
.78636 .245 L
s
1 .202 0 r
.31956 .58476 m
.31824 .58561 L
s
.32075 .58602 m
.31956 .58476 L
s
1 .021 0 r
.78636 .245 m
.78645 .24484 L
s
.285 1 0 r
.47271 .52422 m
.48721 .53557 L
s
.47271 .52422 m
.49028 .52068 L
s
1 .104 0 r
.54273 .18258 m
.54181 .18303 L
s
.54184 .1821 m
.54273 .18258 L
s
.53812 .18244 m
.54273 .18258 L
s
1 0 0 r
.1619 .43084 m
.1619 .43084 L
s
.1619 .43084 m
.1619 .43084 L
s
.1619 .43084 m
.1619 .43084 L
s
.1619 .43084 m
.1619 .43084 L
s
.16191 .43084 m
.1619 .43084 L
s
.1619 .43084 m
.1619 .43084 L
s
.1619 .43084 m
.1619 .43084 L
s
.1619 .43084 m
.1619 .43084 L
s
.1619 .43084 m
.1619 .43084 L
s
1 .043 0 r
.90516 .61714 m
.90523 .6161 L
s
1 .39 0 r
.65741 .55504 m
.64984 .54633 L
s
1 0 0 r
.72164 .39979 m
.72164 .39979 L
s
1 .014 0 r
.47389 .33769 m
.47449 .33759 L
s
1 .01 0 r
.22614 .27559 m
.22637 .27537 L
s
1 .014 0 r
.4744 .33767 m
.47437 .33768 L
s
.47437 .33754 m
.4744 .33767 L
s
.47449 .33759 m
.4744 .33767 L
s
.47435 .33755 m
.47437 .33754 L
s
.47437 .33754 m
.47449 .33759 L
s
1 .202 0 r
.31943 .58688 m
.32075 .58602 L
s
1 .014 0 r
.47449 .33759 m
.47437 .33768 L
s
.47435 .33755 m
.47449 .33759 L
s
.47437 .33768 m
.47435 .33755 L
s
1 .01 0 r
.22633 .27537 m
.22637 .27544 L
s
.22627 .27539 m
.22633 .27537 L
s
.22633 .27537 m
.22637 .27537 L
s
.22637 .27544 m
.22632 .27546 L
s
.22637 .27537 m
.22637 .27544 L
s
.22632 .27546 m
.22627 .27539 L
s
.22627 .27539 m
.22637 .27537 L
s
.22637 .27537 m
.22632 .27546 L
s
1 .104 0 r
.54181 .18303 m
.54184 .1821 L
s
1 .134 0 r
.79271 .61586 m
.79361 .61651 L
s
.79191 .61662 m
.79271 .61586 L
s
.79271 .61586 m
.79273 .61592 L
s
1 .045 0 r
.71916 .21302 m
.71936 .21307 L
s
.71933 .21265 m
.71916 .21302 L
s
.71966 .21302 m
.71916 .21302 L
s
.71966 .21302 m
.71936 .21307 L
s
.71933 .21265 m
.71966 .21302 L
s
.71952 .2127 m
.71966 .21302 L
s
.71809 .21223 m
.71966 .21302 L
s
.71952 .2127 m
.71933 .21265 L
s
1 .202 0 r
.31824 .58561 m
.31943 .58688 L
s
1 .134 0 r
.79282 .61727 m
.79191 .61662 L
s
.79191 .61662 m
.79273 .61592 L
s
1 .344 0 r
.50939 .49276 m
.50948 .49229 L
s
.50948 .49229 m
.5094 .48924 L
s
.50948 .49229 m
.50634 .49106 L
s
1 .045 0 r
.71936 .21307 m
.71952 .2127 L
s
1 .134 0 r
.79361 .61651 m
.79282 .61727 L
s
.79273 .61592 m
.79361 .61651 L
s
1 .043 0 r
.90519 .61609 m
.90549 .6163 L
s
.90495 .61632 m
.90519 .61609 L
s
.90519 .61609 m
.90523 .6161 L
s
1 .053 0 r
.20906 .58533 m
.20906 .58535 L
s
.20912 .58479 m
.20906 .58533 L
s
.20906 .58533 m
.20875 .58503 L
s
.20943 .5851 m
.20906 .58533 L
s
.20922 .58403 m
.20906 .58533 L
s
1 .01 0 r
.3414 .46101 m
.34145 .46102 L
s
.34145 .46091 m
.3414 .46101 L
s
.3414 .46101 m
.34139 .46094 L
s
.3415 .46099 m
.3414 .46101 L
s
.34164 .46078 m
.3414 .46101 L
s
1 .043 0 r
.90525 .61654 m
.90495 .61632 L
s
.90495 .61632 m
.90523 .6161 L
s
1 .01 0 r
.34145 .46091 m
.34139 .46094 L
s
.3415 .46099 m
.34145 .46091 L
s
.34145 .46102 m
.3415 .46099 L
s
1 .043 0 r
.90549 .6163 m
.90525 .61654 L
s
.90523 .6161 m
.90549 .6163 L
s
0 1 .331 r
.6309 .58523 m
.61723 .59515 L
s
.62344 .57166 m
.6309 .58523 L
s
1 .053 0 r
.20912 .58479 m
.20875 .58503 L
s
.20943 .5851 m
.20912 .58479 L
s
1 .01 0 r
.34139 .46094 m
.34145 .46102 L
s
1 .134 0 r
.79273 .61592 m
.79282 .61727 L
s
1 .344 0 r
.5094 .48924 m
.50931 .48971 L
s
.5094 .48924 m
.50634 .49106 L
s
1 .043 0 r
.90523 .6161 m
.90525 .61654 L
s
1 .053 0 r
.20906 .58535 m
.20943 .5851 L
s
1 .001 0 r
.65385 .3676 m
.65386 .3676 L
s
.65386 .36759 m
.65385 .3676 L
s
.65387 .3676 m
.65385 .3676 L
s
.65387 .3676 m
.65386 .3676 L
s
.65386 .36759 m
.65387 .3676 L
s
.65386 .36759 m
.65387 .3676 L
s
.65382 .36757 m
.65387 .3676 L
s
.65386 .36759 m
.65386 .36759 L
s
.65386 .3676 m
.65386 .36759 L
s
1 .055 0 r
.83746 .58506 m
.83729 .5837 L
s
1 .59 0 r
.58955 .52292 m
.56835 .51415 L
s
1 .021 0 r
.40591 .30544 m
.40672 .30514 L
s
1 0 0 r
.09373 .39864 m
.09373 .39864 L
s
1 .053 0 r
.20875 .58503 m
.20906 .58535 L
s
1 .021 0 r
.40663 .30528 m
.40655 .3053 L
s
.40656 .3051 m
.40663 .30528 L
s
.40672 .30514 m
.40663 .30528 L
s
.40649 .30513 m
.40656 .3051 L
s
.40656 .3051 m
.40672 .30514 L
s
1 .077 0 r
.65248 .18093 m
.6527 .18097 L
s
.65267 .18026 m
.65248 .18093 L
s
.6533 .1808 m
.65248 .18093 L
s
.6529 .1803 m
.65267 .18026 L
s
.65267 .18026 m
.6533 .1808 L
s
1 .021 0 r
.40672 .30514 m
.40655 .3053 L
s
.40649 .30513 m
.40672 .30514 L
s
.40655 .3053 m
.40649 .30513 L
s
1 .077 0 r
.6533 .1808 m
.6527 .18097 L
s
.6529 .1803 m
.6533 .1808 L
s
.65023 .17988 m
.6533 .1808 L
s
.6527 .18097 m
.6529 .1803 L
s
1 .344 0 r
.50634 .49106 m
.50939 .49276 L
s
.50634 .49106 m
.50931 .48971 L
s
.5216 .49076 m
.50634 .49106 L
s
0 1 .566 r
.54032 .49103 m
.52604 .50872 L
s
.51516 .48373 m
.54032 .49103 L
s
.285 1 0 r
.49028 .52068 m
.48721 .53557 L
s
1 .013 0 r
.58632 .33545 m
.58634 .33546 L
s
.58634 .33534 m
.58632 .33545 L
s
.58645 .33542 m
.58632 .33545 L
s
.58637 .33535 m
.58634 .33534 L
s
.58634 .33534 m
.58645 .33542 L
s
.58645 .33542 m
.58634 .33546 L
s
.58637 .33535 m
.58645 .33542 L
s
.58591 .33532 m
.58645 .33542 L
s
1 .055 0 r
.83729 .58368 m
.83767 .58394 L
s
.83697 .58401 m
.83729 .58368 L
s
.83729 .58368 m
.83729 .5837 L
s
.939 1 0 r
.44121 .55245 m
.44444 .56134 L
s
1 .013 0 r
.58634 .33546 m
.58637 .33535 L
s
1 0 0 r
.27353 .4286 m
.27353 .4286 L
s
.27353 .42859 m
.27353 .4286 L
s
.27353 .4286 m
.27353 .42859 L
s
.27353 .4286 m
.27353 .4286 L
s
.27354 .42859 m
.27353 .4286 L
s
.27353 .42859 m
.27353 .42859 L
s
.27353 .4286 m
.27353 .42859 L
s
.27353 .4286 m
.27353 .4286 L
s
.27353 .42859 m
.27353 .4286 L
s
.83398 .3975 m
.83398 .3975 L
s
1 .075 0 r
.76966 .55294 m
.76895 .55113 L
s
1 .022 0 r
.33785 .27314 m
.33859 .27274 L
s
1 .055 0 r
.83735 .58426 m
.83697 .58401 L
s
.83697 .58401 m
.83729 .5837 L
s
.83767 .58394 m
.83735 .58426 L
s
.83729 .5837 m
.83767 .58394 L
s
1 .229 0 r
.36066 .55281 m
.36145 .55297 L
s
.36157 .5506 m
.36066 .55281 L
s
.36066 .55281 m
.36019 .5514 L
s
.36283 .55217 m
.36066 .55281 L
s
.36491 .54767 m
.36066 .55281 L
s
1 .055 0 r
.83729 .5837 m
.83735 .58426 L
s
1 .022 0 r
.33854 .27289 m
.33844 .27292 L
s
.33845 .27271 m
.33854 .27289 L
s
.33859 .27274 m
.33854 .27289 L
s
.33835 .27274 m
.33845 .27271 L
s
.33845 .27271 m
.33859 .27274 L
s
.939 1 0 r
.59558 .54428 m
.6017 .54795 L
s
.58971 .55162 m
.59558 .54428 L
s
.59558 .54428 m
.5914 .54503 L
s
1 .022 0 r
.33844 .27292 m
.33835 .27274 L
s
.33859 .27274 m
.33844 .27292 L
s
.33835 .27274 m
.33859 .27274 L
s
1 .047 0 r
.45212 .45928 m
.45227 .4592 L
s
.45227 .4592 m
.45213 .45881 L
s
.45227 .4592 m
.45176 .45916 L
s
.45213 .45881 m
.45197 .45889 L
s
.45213 .45881 m
.45176 .45916 L
s
.45176 .45916 m
.45212 .45928 L
s
.45176 .45916 m
.45197 .45889 L
s
.45357 .45856 m
.45176 .45916 L
s
0 .04 1 r
.70357 .61461 m
.67277 .64482 L
s
.66099 .61167 m
.70357 .61461 L
s
1 .229 0 r
.36157 .5506 m
.36019 .5514 L
s
.36283 .55217 m
.36157 .5506 L
s
1 .22 0 r
.72369 .58173 m
.72514 .58269 L
s
.72239 .58307 m
.72369 .58173 L
s
.72369 .58173 m
.7234 .58182 L
s
0 1 .077 r
.47448 .55596 m
.47112 .55235 L
s
.47112 .55235 m
.47482 .53432 L
s
.47112 .55235 m
.45679 .54207 L
s
1 .016 0 r
.14095 .55229 m
.14095 .55229 L
s
.14097 .55213 m
.14095 .55229 L
s
.14095 .55229 m
.14085 .5522 L
s
.14106 .55222 m
.14095 .55229 L
s
.141 .55189 m
.14095 .55229 L
s
1 .344 0 r
.50931 .48971 m
.50939 .49276 L
s
1 .016 0 r
.14097 .55213 m
.14085 .5522 L
s
.14106 .55222 m
.14097 .55213 L
s
.14095 .55229 m
.14106 .55222 L
s
1 .047 0 r
.45197 .45889 m
.45212 .45928 L
s
1 .016 0 r
.14085 .5522 m
.14095 .55229 L
s
1 .229 0 r
.36145 .55297 m
.36283 .55217 L
s
1 .032 0 r
.51906 .30313 m
.51906 .30315 L
s
.51906 .30285 m
.51906 .30313 L
s
.51934 .30299 m
.51906 .30313 L
s
1 .22 0 r
.72383 .58404 m
.72239 .58307 L
s
.72239 .58307 m
.7234 .58182 L
s
1 .032 0 r
.51905 .30287 m
.51906 .30285 L
s
.51906 .30285 m
.51934 .30299 L
s
.808 1 0 r
.63605 .60475 m
.64383 .61093 L
s
.62868 .6112 m
.63605 .60475 L
s
.63605 .60475 m
.63631 .6052 L
s
1 0 0 r
.76615 .36525 m
.76615 .36525 L
s
.76615 .36525 m
.76615 .36525 L
s
.76615 .36525 m
.76615 .36525 L
s
.76615 .36525 m
.76615 .36525 L
s
.76614 .36524 m
.76615 .36525 L
s
.76615 .36525 m
.76615 .36525 L
s
.76615 .36525 m
.76615 .36525 L
s
.76615 .36525 m
.76615 .36525 L
s
.76615 .36525 m
.76615 .36525 L
s
1 .1 0 r
.70179 .52078 m
.69991 .51851 L
s
1 .032 0 r
.51792 .30302 m
.51934 .30299 L
s
1 0 0 r
.20535 .39635 m
.20535 .39635 L
s
1 .021 0 r
.2697 .24081 m
.27031 .24037 L
s
1 .032 0 r
.51934 .30299 m
.51906 .30315 L
s
.51905 .30287 m
.51934 .30299 L
s
.51906 .30315 m
.51905 .30287 L
s
1 .075 0 r
.76907 .55111 m
.76956 .55141 L
s
.76863 .55157 m
.76907 .55111 L
s
.76907 .55111 m
.76895 .55113 L
s
1 .021 0 r
.2702 .24036 m
.27029 .24052 L
s
.27009 .24039 m
.2702 .24036 L
s
.2702 .24036 m
.27031 .24037 L
s
.27029 .24052 m
.27018 .24055 L
s
.27031 .24037 m
.27029 .24052 L
s
.939 1 0 r
.59581 .55531 m
.58971 .55162 L
s
.58971 .55162 m
.5914 .54503 L
s
1 .075 0 r
.76912 .55188 m
.76863 .55157 L
s
.76863 .55157 m
.76895 .55113 L
s
1 .22 0 r
.72514 .58269 m
.72383 .58404 L
s
.7234 .58182 m
.72514 .58269 L
s
.717 1 0 r
.43703 .5854 m
.44129 .58267 L
s
.44129 .58267 m
.43739 .57191 L
s
.44129 .58267 m
.42735 .5817 L
s
1 .021 0 r
.27018 .24055 m
.27009 .24039 L
s
.27009 .24039 m
.27031 .24037 L
s
.27031 .24037 m
.27018 .24055 L
s
1 .043 0 r
.764 .17813 m
.76374 .17816 L
s
.7637 .17776 m
.764 .17813 L
s
.764 .17813 m
.76354 .17811 L
s
.76391 .17781 m
.764 .17813 L
s
.76261 .1773 m
.764 .17813 L
s
.76354 .17811 m
.76374 .17816 L
s
.7637 .17776 m
.76354 .17811 L
s
.76391 .17781 m
.7637 .17776 L
s
0 .04 1 r
.67277 .64482 m
.66099 .61167 L
s
1 .075 0 r
.76956 .55141 m
.76912 .55188 L
s
.76895 .55113 m
.76956 .55141 L
s
1 .229 0 r
.36019 .5514 m
.36145 .55297 L
s
1 .075 0 r
.76895 .55113 m
.76912 .55188 L
s
1 .043 0 r
.76374 .17816 m
.76391 .17781 L
s
1 .22 0 r
.7234 .58182 m
.72383 .58404 L
s
1 .052 0 r
.25236 .55105 m
.25243 .55107 L
s
.25247 .55053 m
.25236 .55105 L
s
.25236 .55105 m
.25213 .55074 L
s
.25278 .55085 m
.25236 .55105 L
s
.25281 .54978 m
.25236 .55105 L
s
1 .005 0 r
.07267 .51982 m
.07267 .51983 L
s
.07268 .51978 m
.07267 .51982 L
s
.07267 .51982 m
.07264 .5198 L
s
.0727 .51981 m
.07267 .51982 L
s
.07268 .51971 m
.07267 .51982 L
s
.07268 .51978 m
.07264 .5198 L
s
.0727 .51981 m
.07268 .51978 L
s
1 .052 0 r
.25247 .55053 m
.25213 .55074 L
s
.25278 .55085 m
.25247 .55053 L
s
1 .005 0 r
.07267 .51983 m
.0727 .51981 L
s
.07264 .5198 m
.07267 .51983 L
s
.69838 .33304 m
.69835 .33304 L
s
.69835 .33299 m
.69838 .33304 L
s
.69838 .33304 m
.69833 .33303 L
s
.69837 .333 m
.69838 .33304 L
s
.69822 .33294 m
.69838 .33304 L
s
.69833 .33303 m
.69835 .33304 L
s
.69835 .33299 m
.69833 .33303 L
s
.69837 .333 m
.69835 .33299 L
s
.69835 .33304 m
.69837 .333 L
s
.717 1 0 r
.43739 .57191 m
.4331 .5746 L
s
.43739 .57191 m
.42735 .5817 L
s
1 .002 0 r
.38539 .42636 m
.3854 .42636 L
s
.3854 .42634 m
.38539 .42636 L
s
.38539 .42636 m
.38539 .42635 L
s
.38541 .42636 m
.38539 .42636 L
s
.38545 .42633 m
.38539 .42636 L
s
.3854 .42636 m
.38541 .42636 L
s
.38541 .42636 m
.3854 .42634 L
s
.3854 .42634 m
.38539 .42635 L
s
.38539 .42635 m
.3854 .42636 L
s
1 .052 0 r
.25243 .55107 m
.25278 .55085 L
s
1 .021 0 r
.8822 .55084 m
.88211 .55032 L
s
1 .111 0 r
.63382 .48858 m
.63035 .48658 L
s
1 .043 0 r
.44984 .27069 m
.45163 .27032 L
s
1 0 0 r
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
0 1 .566 r
.51516 .48373 m
.52604 .50872 L
s
1 .052 0 r
.25213 .55074 m
.25243 .55107 L
s
1 .043 0 r
.45136 .27056 m
.45127 .27059 L
s
.45128 .27019 m
.45136 .27056 L
s
.45163 .27032 m
.45136 .27056 L
s
.45119 .27022 m
.45128 .27019 L
s
.45128 .27019 m
.45163 .27032 L
s
0 1 .077 r
.47482 .53432 m
.47821 .5378 L
s
.47482 .53432 m
.45679 .54207 L
s
.717 1 0 r
.42735 .5817 m
.43703 .5854 L
s
.42735 .5817 m
.4331 .5746 L
s
.47699 .56631 m
.42735 .5817 L
s
1 .043 0 r
.45163 .27032 m
.45127 .27059 L
s
.45119 .27022 m
.45163 .27032 L
s
1 .021 0 r
.88211 .55031 m
.88226 .5504 L
s
.88199 .55044 m
.88211 .55031 L
s
.88211 .55031 m
.88211 .55032 L
s
1 .043 0 r
.45127 .27059 m
.45119 .27022 L
s
1 .021 0 r
.88214 .55053 m
.88199 .55044 L
s
.88199 .55044 m
.88211 .55032 L
s
.88226 .5504 m
.88214 .55053 L
s
.88211 .55032 m
.88226 .5504 L
s
1 .1 0 r
.70026 .51845 m
.70086 .51879 L
s
.69972 .51914 m
.70026 .51845 L
s
.70026 .51845 m
.69991 .51851 L
s
1 .021 0 r
.88211 .55032 m
.88214 .55053 L
s
1 .1 0 r
.70032 .51948 m
.69972 .51914 L
s
.69972 .51914 m
.69991 .51851 L
s
1 .021 0 r
.63082 .30089 m
.63089 .30091 L
s
.63088 .30071 m
.63082 .30089 L
s
.63105 .30086 m
.63082 .30089 L
s
.63094 .30073 m
.63088 .30071 L
s
.63088 .30071 m
.63105 .30086 L
s
.63105 .30086 m
.63089 .30091 L
s
.63094 .30073 m
.63105 .30086 L
s
.63021 .3006 m
.63105 .30086 L
s
1 .1 0 r
.70086 .51879 m
.70032 .51948 L
s
.69991 .51851 m
.70086 .51879 L
s
1 .021 0 r
.63089 .30091 m
.63094 .30073 L
s
1 .1 0 r
.69991 .51851 m
.70032 .51948 L
s
1 .022 0 r
.81431 .51863 m
.81408 .51809 L
s
1 .058 0 r
.56578 .45634 m
.5633 .45589 L
s
1 .042 0 r
.38168 .23831 m
.38329 .2377 L
s
1 0 0 r
.31725 .39405 m
.31725 .39405 L
s
1 .058 0 r
.5638 .45628 m
.56369 .4562 L
s
.56369 .4562 m
.56379 .45569 L
s
.56369 .4562 m
.5633 .45589 L
s
.56379 .45569 m
.56391 .45577 L
s
.56379 .45569 m
.5633 .45589 L
s
1 .111 0 r
.63103 .48642 m
.63155 .48668 L
s
.63055 .48729 m
.63103 .48642 L
s
.63103 .48642 m
.63035 .48658 L
s
.63107 .48755 m
.63055 .48729 L
s
.63055 .48729 m
.63035 .48658 L
s
1 .042 0 r
.3831 .23799 m
.38296 .23802 L
s
.38298 .23763 m
.3831 .23799 L
s
.38329 .2377 m
.3831 .23799 L
s
.38283 .23766 m
.38298 .23763 L
s
.38298 .23763 m
.38329 .2377 L
s
1 .022 0 r
.81411 .51808 m
.81426 .51817 L
s
.81398 .51822 m
.81411 .51808 L
s
.81411 .51808 m
.81408 .51809 L
s
.81413 .51831 m
.81398 .51822 L
s
.81398 .51822 m
.81408 .51809 L
s
1 .058 0 r
.5633 .45589 m
.5638 .45628 L
s
.5633 .45589 m
.56391 .45577 L
s
0 1 .331 r
.61723 .59515 m
.60284 .5805 L
s
.60284 .5805 m
.62344 .57166 L
s
1 .022 0 r
.81426 .51817 m
.81413 .51831 L
s
.81408 .51809 m
.81426 .51817 L
s
.81408 .51809 m
.81413 .51831 L
s
1 .058 0 r
.56391 .45577 m
.5638 .45628 L
s
1 .575 0 r
.67825 .60706 m
.68202 .60976 L
s
.67476 .61046 m
.67825 .60706 L
s
.67825 .60706 m
.67776 .60732 L
s
1 .042 0 r
.38329 .2377 m
.38296 .23802 L
s
.38283 .23766 m
.38329 .2377 L
s
.38296 .23802 m
.38283 .23766 L
s
1 .39 0 r
.65128 .54605 m
.65359 .54741 L
s
.64913 .54876 m
.65128 .54605 L
s
.65128 .54605 m
.64984 .54633 L
s
1 .013 0 r
.18439 .51788 m
.1844 .51788 L
s
.18441 .51775 m
.18439 .51788 L
s
.18439 .51788 m
.18433 .5178 L
s
.18448 .51783 m
.18439 .51788 L
s
.18448 .51756 m
.18439 .51788 L
s
1 .046 0 r
.56367 .26858 m
.56372 .2686 L
s
.56372 .26817 m
.56367 .26858 L
s
.56412 .26843 m
.56367 .26858 L
s
1 .013 0 r
.18441 .51775 m
.18433 .5178 L
s
.18448 .51783 m
.18441 .51775 L
s
1 .111 0 r
.63155 .48668 m
.63107 .48755 L
s
.63035 .48658 m
.63155 .48668 L
s
.63035 .48658 m
.63107 .48755 L
s
1 .013 0 r
.1844 .51788 m
.18448 .51783 L
s
1 .046 0 r
.56377 .26819 m
.56372 .26817 L
s
.56372 .26817 m
.56412 .26843 L
s
1 .013 0 r
.18433 .5178 m
.1844 .51788 L
s
1 .046 0 r
.56412 .26843 m
.56372 .2686 L
s
.56377 .26819 m
.56412 .26843 L
s
.56212 .26823 m
.56412 .26843 L
s
.808 1 0 r
.63647 .6174 m
.62868 .6112 L
s
.62868 .6112 m
.63631 .6052 L
s
1 .59 0 r
.57265 .51896 m
.57041 .5177 L
s
.57041 .5177 m
.57256 .51287 L
s
.57041 .5177 m
.56835 .51415 L
s
1 .005 0 r
.49746 .42411 m
.49746 .4241 L
s
.49746 .4241 m
.49746 .42405 L
s
.49746 .4241 m
.49741 .42409 L
s
1 .002 0 r
.81084 .3306 m
.81084 .3306 L
s
.81084 .33058 m
.81084 .3306 L
s
.81084 .3306 m
.81083 .3306 L
s
.81085 .33059 m
.81084 .3306 L
s
.8108 .33056 m
.81084 .3306 L
s
1 .005 0 r
.49746 .42405 m
.49745 .42406 L
s
.49746 .42405 m
.49741 .42409 L
s
1 .002 0 r
.81084 .33058 m
.81083 .3306 L
s
.81085 .33059 m
.81084 .33058 L
s
.81083 .3306 m
.81084 .3306 L
s
1 .39 0 r
.65144 .55011 m
.64913 .54876 L
s
.64913 .54876 m
.64984 .54633 L
s
1 .002 0 r
.81084 .3306 m
.81085 .33059 L
s
1 .005 0 r
.49741 .42409 m
.49746 .42411 L
s
.49741 .42409 m
.49745 .42406 L
s
.49764 .42406 m
.49741 .42409 L
s
1 .046 0 r
.56372 .2686 m
.56377 .26819 L
s
1 .005 0 r
.49745 .42406 m
.49746 .42411 L
s
1 .021 0 r
.74633 .48639 m
.74595 .4859 L
s
1 0 0 r
.24896 .36173 m
.24896 .36172 L
s
1 .038 0 r
.31343 .20589 m
.3147 .20521 L
s
1 0 0 r
.24896 .36172 m
.24896 .36172 L
s
.24896 .36172 m
.24896 .36172 L
s
.24896 .36172 m
.24896 .36172 L
s
.24896 .36172 m
.24896 .36172 L
s
.24896 .36172 m
.24896 .36172 L
s
.24896 .36172 m
.24896 .36172 L
s
.24896 .36172 m
.24896 .36172 L
s
.24896 .36172 m
.24896 .36172 L
s
1 .59 0 r
.57256 .51287 m
.57481 .51411 L
s
.57256 .51287 m
.56835 .51415 L
s
.808 1 0 r
.64383 .61093 m
.63647 .6174 L
s
.63631 .6052 m
.64383 .61093 L
s
1 .215 0 r
.40267 .51733 m
.40388 .51763 L
s
.40396 .51541 m
.40267 .51733 L
s
.40267 .51733 m
.40288 .51597 L
s
.40496 .51706 m
.40267 .51733 L
s
.40893 .51325 m
.40267 .51733 L
s
1 .021 0 r
.74601 .48589 m
.74615 .48596 L
s
.7459 .48604 m
.74601 .48589 L
s
.74601 .48589 m
.74595 .4859 L
s
.74603 .48611 m
.7459 .48604 L
s
.7459 .48604 m
.74595 .4859 L
s
1 .038 0 r
.3146 .20548 m
.31443 .20552 L
s
.31446 .20517 m
.3146 .20548 L
s
.3147 .20521 m
.3146 .20548 L
s
.31429 .20521 m
.31446 .20517 L
s
.31446 .20517 m
.3147 .20521 L
s
1 .021 0 r
.74615 .48596 m
.74603 .48611 L
s
.74595 .4859 m
.74615 .48596 L
s
.74595 .4859 m
.74603 .48611 L
s
1 .215 0 r
.40396 .51541 m
.40288 .51597 L
s
.40496 .51706 m
.40396 .51541 L
s
.40388 .51763 m
.40496 .51706 L
s
1 .038 0 r
.31443 .20552 m
.31429 .20521 L
s
.3147 .20521 m
.31443 .20552 L
s
.31429 .20521 m
.3147 .20521 L
s
1 .575 0 r
.67853 .61316 m
.67476 .61046 L
s
.67476 .61046 m
.67776 .60732 L
s
.939 1 0 r
.6017 .54795 m
.59581 .55531 L
s
.5914 .54503 m
.6017 .54795 L
s
1 .009 0 r
.74304 .29835 m
.74299 .29836 L
s
.74299 .29828 m
.74304 .29835 L
s
.74304 .29835 m
.74295 .29834 L
s
.74303 .29829 m
.74304 .29835 L
s
.74278 .29818 m
.74304 .29835 L
s
.74299 .29828 m
.74295 .29834 L
s
.74303 .29829 m
.74299 .29828 L
s
.74295 .29834 m
.74299 .29836 L
s
.74299 .29836 m
.74303 .29829 L
s
1 .062 0 r
.49617 .2359 m
.49612 .23593 L
s
.49612 .23534 m
.49617 .2359 L
s
.49666 .23559 m
.49617 .2359 L
s
1 .003 0 r
.11605 .48537 m
.11605 .48537 L
s
.11605 .48534 m
.11605 .48537 L
s
.11605 .48537 m
.11604 .48535 L
s
.11607 .48536 m
.11605 .48537 L
s
.11607 .4853 m
.11605 .48537 L
s
.11605 .48534 m
.11604 .48535 L
s
.11607 .48536 m
.11605 .48534 L
s
.11605 .48537 m
.11607 .48536 L
s
.11604 .48535 m
.11605 .48537 L
s
1 .062 0 r
.49607 .23537 m
.49612 .23534 L
s
.49612 .23534 m
.49666 .23559 L
s
1 .046 0 r
.29586 .51648 m
.29599 .5165 L
s
.29602 .51603 m
.29586 .51648 L
s
.29586 .51648 m
.29573 .5162 L
s
.29628 .51634 m
.29586 .51648 L
s
.29657 .51541 m
.29586 .51648 L
s
.542 1 0 r
.61375 .61004 m
.58402 .57794 L
s
1 .014 0 r
.67827 .45411 m
.67787 .45383 L
s
1 0 0 r
.42943 .39174 m
.42943 .39174 L
s
1 .062 0 r
.49394 .23581 m
.49666 .23559 L
s
1 .001 0 r
.18058 .32937 m
.1806 .32934 L
s
.1806 .32934 m
.1806 .32935 L
s
.18059 .32934 m
.1806 .32934 L
s
.1806 .32934 m
.1806 .32934 L
s
.1806 .32935 m
.1806 .32935 L
s
.1806 .32934 m
.1806 .32935 L
s
.1806 .32935 m
.18059 .32934 L
s
.18059 .32934 m
.1806 .32934 L
s
.1806 .32934 m
.1806 .32935 L
s
1 .046 0 r
.29602 .51603 m
.29573 .5162 L
s
.29628 .51634 m
.29602 .51603 L
s
.29599 .5165 m
.29628 .51634 L
s
1 .014 0 r
.67794 .45382 m
.67802 .45385 L
s
.67788 .45392 m
.67794 .45382 L
s
.67794 .45382 m
.67787 .45383 L
s
.67795 .45396 m
.67788 .45392 L
s
.67788 .45392 m
.67787 .45383 L
s
1 .062 0 r
.49666 .23559 m
.49612 .23593 L
s
.49607 .23537 m
.49666 .23559 L
s
1 .014 0 r
.67802 .45385 m
.67795 .45396 L
s
.67787 .45383 m
.67802 .45385 L
s
.67787 .45383 m
.67795 .45396 L
s
1 .39 0 r
.65359 .54741 m
.65144 .55011 L
s
.64984 .54633 m
.65359 .54741 L
s
1 .046 0 r
.29573 .5162 m
.29599 .5165 L
s
1 .575 0 r
.68202 .60976 m
.67853 .61316 L
s
.67776 .60732 m
.68202 .60976 L
s
1 .062 0 r
.49612 .23593 m
.49607 .23537 L
s
1 .215 0 r
.40288 .51597 m
.40388 .51763 L
s
1 .39 0 r
.64984 .54633 m
.65144 .55011 L
s
1 .026 0 r
.67536 .26617 m
.67546 .2662 L
s
.67544 .26595 m
.67536 .26617 L
s
.67564 .26615 m
.67536 .26617 L
s
.939 1 0 r
.5914 .54503 m
.59581 .55531 L
s
1 .026 0 r
.67554 .26598 m
.67544 .26595 L
s
.67544 .26595 m
.67564 .26615 L
s
.67564 .26615 m
.67546 .2662 L
s
.67554 .26598 m
.67564 .26615 L
s
.67468 .26576 m
.67564 .26615 L
s
1 .271 0 r
.31715 .60929 m
.31758 .60945 L
s
.31776 .60657 m
.31715 .60929 L
s
.31715 .60929 m
.31598 .60774 L
s
.31935 .60828 m
.31715 .60929 L
s
.31977 .60289 m
.31715 .60929 L
s
1 .026 0 r
.67546 .2662 m
.67554 .26598 L
s
1 0 0 r
.04756 .45301 m
.04756 .45301 L
s
.04756 .453 m
.04756 .45301 L
s
.04756 .45301 m
.04756 .453 L
s
.04757 .453 m
.04756 .45301 L
s
.04757 .45299 m
.04756 .45301 L
s
.04756 .453 m
.04756 .453 L
s
.04757 .453 m
.04756 .453 L
s
.04756 .45301 m
.04757 .453 L
s
.04756 .453 m
.04756 .45301 L
s
1 .006 0 r
.85912 .4842 m
.85906 .48406 L
s
0 1 .331 r
.54556 .57782 m
.44533 .561 L
s
1 .003 0 r
.61012 .42179 m
.61 .42175 L
s
1 .001 0 r
.36112 .35938 m
.36115 .35936 L
s
1 .063 0 r
.42568 .20335 m
.42831 .20271 L
s
1 .001 0 r
.36115 .35937 m
.36114 .35937 L
s
.36114 .35936 m
.36115 .35937 L
s
.36115 .35936 m
.36115 .35937 L
s
.36114 .35936 m
.36114 .35936 L
s
.36114 .35936 m
.36115 .35936 L
s
.36114 .35937 m
.36114 .35936 L
s
.36115 .35936 m
.36114 .35937 L
s
.36114 .35936 m
.36115 .35936 L
s
1 .003 0 r
.61002 .42177 m
.61001 .42177 L
s
.61001 .42177 m
.61002 .42174 L
s
.61001 .42177 m
.61 .42175 L
s
.61002 .42174 m
.61003 .42174 L
s
.61002 .42174 m
.61 .42175 L
s
.61 .42175 m
.61002 .42177 L
s
.61 .42175 m
.61003 .42174 L
s
.61003 .42174 m
.61002 .42177 L
s
1 .006 0 r
.85907 .48406 m
.85911 .48408 L
s
.85904 .4841 m
.85907 .48406 L
s
.85907 .48406 m
.85906 .48406 L
s
.85907 .48412 m
.85904 .4841 L
s
.85904 .4841 m
.85906 .48406 L
s
.85911 .48408 m
.85907 .48412 L
s
.85906 .48406 m
.85911 .48408 L
s
.85906 .48406 m
.85907 .48412 L
s
1 .063 0 r
.42793 .2031 m
.42778 .20314 L
s
.42779 .20254 m
.42793 .2031 L
s
.42831 .20271 m
.42793 .2031 L
s
.42764 .20258 m
.42779 .20254 L
s
.42779 .20254 m
.42831 .20271 L
s
1 .271 0 r
.31776 .60657 m
.31598 .60774 L
s
.31935 .60828 m
.31776 .60657 L
s
1 .575 0 r
.67776 .60732 m
.67853 .61316 L
s
1 .063 0 r
.42831 .20271 m
.42778 .20314 L
s
.42764 .20258 m
.42831 .20271 L
s
1 .052 0 r
.60814 .23387 m
.60825 .2339 L
s
.60824 .23341 m
.60814 .23387 L
s
.60868 .23375 m
.60814 .23387 L
s
1 .063 0 r
.42778 .20314 m
.42764 .20258 L
s
1 .052 0 r
.60835 .23344 m
.60824 .23341 L
s
.60824 .23341 m
.60868 .23375 L
s
.60868 .23375 m
.60825 .2339 L
s
.60835 .23344 m
.60868 .23375 L
s
.60648 .2333 m
.60868 .23375 L
s
1 .271 0 r
.31758 .60945 m
.31935 .60828 L
s
1 .008 0 r
.22803 .4833 m
.22804 .48331 L
s
.22805 .48322 m
.22803 .4833 L
s
.22803 .4833 m
.228 .48325 L
s
.2281 .48328 m
.22803 .4833 L
s
.22813 .4831 m
.22803 .4833 L
s
.22805 .48322 m
.228 .48325 L
s
.2281 .48328 m
.22805 .48322 L
s
.22804 .48331 m
.2281 .48328 L
s
1 .052 0 r
.60825 .2339 m
.60835 .23344 L
s
1 .008 0 r
.228 .48325 m
.22804 .48331 L
s
1 .003 0 r
.79104 .45188 m
.79098 .4518 L
s
1 .293 0 r
.72645 .608 m
.72406 .60099 L
s
1 0 0 r
.54189 .38943 m
.54189 .38943 L
s
1 .003 0 r
.29273 .32697 m
.29281 .32692 L
s
1 .057 0 r
.35733 .17085 m
.35949 .17 L
s
.808 1 0 r
.63631 .6052 m
.63647 .6174 L
s
0 1 .331 r
.62344 .57166 m
.61723 .59515 L
s
1 .59 0 r
.57481 .51411 m
.57265 .51896 L
s
.56835 .51415 m
.57265 .51896 L
s
1 .003 0 r
.29279 .32692 m
.2928 .32694 L
s
.29278 .32692 m
.29279 .32692 L
s
.29279 .32692 m
.29281 .32692 L
s
.2928 .32694 m
.29279 .32694 L
s
.29281 .32692 m
.2928 .32694 L
s
.29279 .32694 m
.29278 .32692 L
s
.29278 .32692 m
.29281 .32692 L
s
.29281 .32692 m
.29279 .32694 L
s
.79099 .4518 m
.79101 .45181 L
s
.79098 .45182 m
.79099 .4518 L
s
.79099 .4518 m
.79098 .4518 L
s
.791 .45183 m
.79098 .45182 L
s
.79098 .45182 m
.79098 .4518 L
s
.79101 .45181 m
.791 .45183 L
s
.79098 .4518 m
.79101 .45181 L
s
.79098 .4518 m
.791 .45183 L
s
1 .59 0 r
.56835 .51415 m
.57481 .51411 L
s
1 .271 0 r
.31598 .60774 m
.31758 .60945 L
s
1 .028 0 r
.09501 .60766 m
.09498 .60767 L
s
.09502 .60738 m
.09501 .60766 L
s
.09501 .60766 m
.09482 .60751 L
s
.09518 .60754 m
.09501 .60766 L
s
.09498 .60698 m
.09501 .60766 L
s
1 .057 0 r
.35924 .17039 m
.35904 .17043 L
s
.35907 .16991 m
.35924 .17039 L
s
.35949 .17 m
.35924 .17039 L
s
.35886 .16994 m
.35907 .16991 L
s
.35907 .16991 m
.35949 .17 L
s
1 .028 0 r
.09502 .60738 m
.09482 .60751 L
s
.09518 .60754 m
.09502 .60738 L
s
.09498 .60767 m
.09518 .60754 L
s
.09482 .60751 m
.09498 .60767 L
s
1 .59 0 r
.50051 .51454 m
.50068 .51369 L
s
.50068 .51369 m
.50055 .50844 L
s
.50068 .51369 m
.49527 .51159 L
s
1 .057 0 r
.35949 .17 m
.35904 .17043 L
s
.35886 .16994 m
.35949 .17 L
s
.35904 .17043 m
.35886 .16994 L
s
1 .073 0 r
.54078 .2012 m
.54081 .20122 L
s
.54081 .20053 m
.54078 .2012 L
s
.54146 .20089 m
.54078 .2012 L
s
.54083 .20055 m
.54081 .20053 L
s
.54081 .20053 m
.54146 .20089 L
s
1 .011 0 r
.78784 .26353 m
.78778 .26353 L
s
.78777 .26343 m
.78784 .26353 L
s
.78784 .26353 m
.78772 .26351 L
s
.78783 .26345 m
.78784 .26353 L
s
.78752 .26329 m
.78784 .26353 L
s
.78777 .26343 m
.78772 .26351 L
s
.78783 .26345 m
.78777 .26343 L
s
.78772 .26351 m
.78778 .26353 L
s
.78778 .26353 m
.78783 .26345 L
s
1 .073 0 r
.54146 .20089 m
.54081 .20122 L
s
.54083 .20055 m
.54146 .20089 L
s
.5382 .2008 m
.54146 .20089 L
s
1 .001 0 r
.1596 .45079 m
.15961 .45079 L
s
.15961 .45077 m
.1596 .45079 L
s
.1596 .45079 m
.1596 .45078 L
s
.15961 .45078 m
.1596 .45079 L
s
.15962 .45076 m
.1596 .45079 L
s
.15961 .45077 m
.1596 .45078 L
s
.15961 .45078 m
.15961 .45077 L
s
.15961 .45079 m
.15961 .45078 L
s
.1596 .45078 m
.15961 .45079 L
s
1 .525 0 r
.65824 .57574 m
.64796 .56406 L
s
1 .001 0 r
.72288 .41951 m
.72286 .41949 L
s
1 .002 0 r
.47357 .35702 m
.47365 .35701 L
s
1 .004 0 r
.22425 .29453 m
.22436 .29443 L
s
1 .002 0 r
.47363 .35702 m
.47363 .35702 L
s
.47363 .357 m
.47363 .35702 L
s
.47365 .35701 m
.47363 .35702 L
s
.47363 .357 m
.47363 .357 L
s
.47363 .357 m
.47365 .35701 L
s
1 .001 0 r
.72286 .41949 m
.72287 .4195 L
s
.72286 .4195 m
.72286 .41949 L
s
.72286 .41949 m
.72286 .41949 L
s
.72286 .4195 m
.72286 .4195 L
s
.72286 .4195 m
.72286 .41949 L
s
1 .002 0 r
.47365 .35701 m
.47363 .35702 L
s
.47363 .357 m
.47365 .35701 L
s
.47363 .35702 m
.47363 .357 L
s
1 .001 0 r
.72287 .4195 m
.72286 .4195 L
s
.72286 .41949 m
.72287 .4195 L
s
.72286 .41949 m
.72286 .4195 L
s
0 .813 1 r
.51549 .48805 m
.5334 .49873 L
s
.4976 .51015 m
.51549 .48805 L
s
.51549 .48805 m
.50164 .48956 L
s
1 .004 0 r
.22434 .29443 m
.22436 .29446 L
s
.22431 .29444 m
.22434 .29443 L
s
.22434 .29443 m
.22436 .29443 L
s
.22436 .29446 m
.22433 .29447 L
s
.22436 .29443 m
.22436 .29446 L
s
.22433 .29447 m
.22431 .29444 L
s
.22431 .29444 m
.22436 .29443 L
s
.22436 .29443 m
.22433 .29447 L
s
0 1 .511 r
.61911 .58707 m
.6347 .60291 L
s
.60423 .59783 m
.61911 .58707 L
s
.61911 .58707 m
.62663 .58832 L
s
1 .323 0 r
.35786 .57563 m
.35898 .57589 L
s
.35915 .57249 m
.35786 .57563 L
s
.35786 .57563 m
.35719 .57365 L
s
.36094 .57473 m
.35786 .57563 L
s
.3639 .56841 m
.35786 .57563 L
s
1 .073 0 r
.54081 .20122 m
.54083 .20055 L
s
1 .59 0 r
.50055 .50844 m
.50037 .50928 L
s
.50055 .50844 m
.49527 .51159 L
s
1 .077 0 r
.20699 .6068 m
.207 .60684 L
s
.20708 .60602 m
.20699 .6068 L
s
.20699 .6068 m
.20655 .60638 L
s
.20753 .60648 m
.20699 .6068 L
s
.20723 .60494 m
.20699 .6068 L
s
.20708 .60602 m
.20655 .60638 L
s
.20753 .60648 m
.20708 .60602 L
s
1 .032 0 r
.33974 .4816 m
.33988 .48162 L
s
.3399 .4813 m
.33974 .4816 L
s
.33974 .4816 m
.33971 .48139 L
s
.34006 .48153 m
.33974 .4816 L
s
.34048 .4809 m
.33974 .4816 L
s
.3399 .4813 m
.33971 .48139 L
s
.34006 .48153 m
.3399 .4813 L
s
.33988 .48162 m
.34006 .48153 L
s
.717 1 0 r
.4331 .5746 m
.43703 .5854 L
s
1 .077 0 r
.207 .60684 m
.20753 .60648 L
s
1 .032 0 r
.33971 .48139 m
.33988 .48162 L
s
1 .077 0 r
.20655 .60638 m
.207 .60684 L
s
1 .028 0 r
.71998 .23128 m
.7201 .23131 L
s
.72009 .23104 m
.71998 .23128 L
s
.72029 .23127 m
.71998 .23128 L
s
.72029 .23127 m
.7201 .23131 L
s
.72009 .23104 m
.72029 .23127 L
s
.72021 .23108 m
.72029 .23127 L
s
.71931 .23078 m
.72029 .23127 L
s
.72021 .23108 m
.72009 .23104 L
s
1 .323 0 r
.35915 .57249 m
.35719 .57365 L
s
.36094 .57473 m
.35915 .57249 L
s
1 .028 0 r
.7201 .23131 m
.72021 .23108 L
s
1 .323 0 r
.35898 .57589 m
.36094 .57473 L
s
1 .08 0 r
.47273 .16826 m
.47263 .16827 L
s
.47264 .16753 m
.47273 .16826 L
s
.47334 .16782 m
.47273 .16826 L
s
1 0 0 r
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
1 .08 0 r
.83942 .60596 m
.83918 .60401 L
s
1 .825 0 r
.58995 .54343 m
.56008 .53122 L
s
1 0 0 r
.65463 .38711 m
.65463 .38711 L
s
1 .08 0 r
.46984 .16825 m
.47334 .16782 L
s
1 .007 0 r
.40516 .32458 m
.40542 .32448 L
s
.40539 .32453 m
.40537 .32454 L
s
.40537 .32447 m
.40539 .32453 L
s
.40542 .32448 m
.40539 .32453 L
s
.40534 .32448 m
.40537 .32447 L
s
.40537 .32447 m
.40542 .32448 L
s
1 .08 0 r
.47254 .16755 m
.47264 .16753 L
s
.47264 .16753 m
.47334 .16782 L
s
1 .007 0 r
.40542 .32448 m
.40537 .32454 L
s
.40534 .32448 m
.40542 .32448 L
s
.40537 .32454 m
.40534 .32448 L
s
.542 1 0 r
.43102 .60901 m
.43593 .60577 L
s
.43593 .60577 m
.43146 .5935 L
s
.43593 .60577 m
.42 .60468 L
s
1 .08 0 r
.47334 .16782 m
.47263 .16827 L
s
.47254 .16755 m
.47334 .16782 L
s
1 .133 0 r
.44899 .48072 m
.44943 .48049 L
s
.44943 .48049 m
.44902 .47936 L
s
.44943 .48049 m
.44798 .48038 L
s
1 .053 0 r
.65258 .19896 m
.65274 .199 L
s
.65272 .1985 m
.65258 .19896 L
s
.65316 .19888 m
.65258 .19896 L
s
1 .133 0 r
.44902 .47936 m
.44858 .4796 L
s
.44902 .47936 m
.44798 .48038 L
s
1 .053 0 r
.65287 .19853 m
.65272 .1985 L
s
.65272 .1985 m
.65316 .19888 L
s
1 .08 0 r
.47263 .16827 m
.47254 .16755 L
s
1 .133 0 r
.44798 .48038 m
.44899 .48072 L
s
.44798 .48038 m
.44858 .4796 L
s
.45312 .47869 m
.44798 .48038 L
s
1 .053 0 r
.65316 .19888 m
.65274 .199 L
s
.65287 .19853 m
.65316 .19888 L
s
.65101 .19824 m
.65316 .19888 L
s
1 .59 0 r
.49527 .51159 m
.50051 .51454 L
s
.49527 .51159 m
.50037 .50928 L
s
.52158 .51108 m
.49527 .51159 L
s
1 .053 0 r
.65274 .199 m
.65287 .19853 L
s
.542 1 0 r
.43146 .5935 m
.42653 .59668 L
s
.43146 .5935 m
.42 .60468 L
s
1 .004 0 r
.27188 .4486 m
.27189 .4486 L
s
.27189 .44856 m
.27188 .4486 L
s
.27188 .4486 m
.27187 .44858 L
s
.27191 .44859 m
.27188 .4486 L
s
.27195 .44851 m
.27188 .4486 L
s
.27189 .44856 m
.27187 .44858 L
s
.27191 .44859 m
.27189 .44856 L
s
.27189 .4486 m
.27191 .44859 L
s
.27187 .44858 m
.27189 .4486 L
s
1 .002 0 r
.58635 .35468 m
.58635 .35468 L
s
.58635 .35466 m
.58635 .35468 L
s
.58637 .35467 m
.58635 .35468 L
s
.58636 .35466 m
.58635 .35466 L
s
.58635 .35466 m
.58637 .35467 L
s
.58637 .35467 m
.58635 .35468 L
s
.58636 .35466 m
.58637 .35467 L
s
.5863 .35466 m
.58637 .35467 L
s
.58635 .35468 m
.58636 .35466 L
s
1 .114 0 r
.7712 .57365 m
.77011 .57091 L
s
1 0 0 r
.83592 .41723 m
.83592 .41722 L
s
1 .01 0 r
.33667 .29209 m
.337 .29191 L
s
1 0 0 r
.83592 .41722 m
.83592 .41722 L
s
.83592 .41723 m
.83592 .41722 L
s
.83592 .41722 m
.83592 .41722 L
s
.83592 .41723 m
.83592 .41723 L
s
.83592 .41723 m
.83592 .41722 L
s
.83592 .41722 m
.83592 .41723 L
s
.83592 .41722 m
.83592 .41722 L
s
.83592 .41722 m
.83592 .41723 L
s
1 .323 0 r
.35719 .57365 m
.35898 .57589 L
s
1 .01 0 r
.33698 .29198 m
.33693 .29199 L
s
.33694 .2919 m
.33698 .29198 L
s
.337 .29191 m
.33698 .29198 L
s
.33689 .29191 m
.33694 .2919 L
s
.33694 .2919 m
.337 .29191 L
s
1 .133 0 r
.44858 .4796 m
.44899 .48072 L
s
1 .01 0 r
.33693 .29199 m
.33689 .29191 L
s
.337 .29191 m
.33693 .29199 L
s
.33689 .29191 m
.337 .29191 L
s
.542 1 0 r
.42 .60468 m
.43102 .60901 L
s
.42 .60468 m
.42653 .59668 L
s
.47668 .58733 m
.42 .60468 L
s
0 1 .077 r
.45679 .54207 m
.47448 .55596 L
s
.45679 .54207 m
.47821 .5378 L
s
1 .08 0 r
.83919 .60398 m
.83974 .60436 L
s
.83872 .60445 m
.83919 .60398 L
s
.83919 .60398 m
.83918 .60401 L
s
1 .026 0 r
.13849 .57326 m
.13849 .57327 L
s
.13852 .57299 m
.13849 .57326 L
s
.13849 .57326 m
.13834 .57311 L
s
.13868 .57315 m
.13849 .57326 L
s
.13857 .57261 m
.13849 .57326 L
s
.13852 .57299 m
.13834 .57311 L
s
.13868 .57315 m
.13852 .57299 L
s
1 .08 0 r
.83927 .60483 m
.83872 .60445 L
s
.83872 .60445 m
.83918 .60401 L
s
1 .077 0 r
.58522 .16633 m
.58533 .16635 L
s
.58531 .16564 m
.58522 .16633 L
s
.58599 .16608 m
.58522 .16633 L
s
1 .026 0 r
.13849 .57327 m
.13868 .57315 L
s
.13834 .57311 m
.13849 .57327 L
s
1 .077 0 r
.58542 .16565 m
.58531 .16564 L
s
.58531 .16564 m
.58599 .16608 L
s
1 .08 0 r
.83974 .60436 m
.83927 .60483 L
s
.83918 .60401 m
.83974 .60436 L
s
1 .077 0 r
.58599 .16608 m
.58533 .16635 L
s
.58542 .16565 m
.58599 .16608 L
s
.58263 .16565 m
.58599 .16608 L
s
1 .08 0 r
.83918 .60401 m
.83927 .60483 L
s
0 .813 1 r
.51539 .52103 m
.4976 .51015 L
s
.4976 .51015 m
.50164 .48956 L
s
1 .077 0 r
.58533 .16635 m
.58542 .16565 L
s
1 .01 0 r
.51825 .32221 m
.51824 .32222 L
s
.51824 .32211 m
.51825 .32221 L
s
.51834 .32216 m
.51825 .32221 L
s
.51824 .32212 m
.51824 .32211 L
s
.51824 .32211 m
.51834 .32216 L
s
1 0 0 r
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
1 .166 0 r
.7029 .5413 m
.69976 .53755 L
s
1 0 0 r
.76766 .38478 m
.76766 .38478 L
s
1 .01 0 r
.51787 .32217 m
.51834 .32216 L
s
1 .011 0 r
.26809 .25956 m
.26842 .25933 L
s
1 .01 0 r
.51834 .32216 m
.51824 .32222 L
s
.51824 .32212 m
.51834 .32216 L
s
.51824 .32222 m
.51824 .32212 L
s
1 .59 0 r
.50037 .50928 m
.50051 .51454 L
s
0 1 .331 r
.46532 .57674 m
.4616 .57248 L
s
.4616 .57248 m
.46576 .55213 L
s
.4616 .57248 m
.44533 .561 L
s
1 .011 0 r
.26836 .25932 m
.26841 .25941 L
s
.2683 .25934 m
.26836 .25932 L
s
.26836 .25932 m
.26842 .25933 L
s
.26841 .25941 m
.26835 .25943 L
s
.26842 .25933 m
.26841 .25941 L
s
1 .081 0 r
.25039 .57247 m
.25049 .57251 L
s
.25056 .57166 m
.25039 .57247 L
s
.25039 .57247 m
.25002 .572 L
s
.25104 .57217 m
.25039 .57247 L
s
.25109 .57051 m
.25039 .57247 L
s
1 .011 0 r
.26835 .25943 m
.2683 .25934 L
s
.2683 .25934 m
.26842 .25933 L
s
.26842 .25933 m
.26835 .25943 L
s
1 .081 0 r
.25056 .57166 m
.25002 .572 L
s
.25104 .57217 m
.25056 .57166 L
s
.25049 .57251 m
.25104 .57217 L
s
1 .029 0 r
.76505 .19623 m
.76488 .19625 L
s
.76485 .19598 m
.76505 .19623 L
s
.76505 .19623 m
.76474 .19621 L
s
.76499 .19601 m
.76505 .19623 L
s
.76411 .19567 m
.76505 .19623 L
s
.76474 .19621 m
.76488 .19625 L
s
.76485 .19598 m
.76474 .19621 L
s
1 .081 0 r
.25002 .572 m
.25049 .57251 L
s
1 .029 0 r
.76499 .19601 m
.76485 .19598 L
s
.76488 .19625 m
.76499 .19601 L
s
1 .293 0 r
.72444 .60084 m
.72638 .60214 L
s
.7227 .60266 m
.72444 .60084 L
s
.72444 .60084 m
.72406 .60099 L
s
1 .014 0 r
.38412 .44652 m
.38421 .44654 L
s
.38421 .4464 m
.38412 .44652 L
s
.38412 .44652 m
.38415 .44643 L
s
.38428 .44651 m
.38412 .44652 L
s
.38457 .44626 m
.38412 .44652 L
s
.38421 .44654 m
.38428 .44651 L
s
.38428 .44651 m
.38421 .4464 L
s
.38421 .4464 m
.38415 .44643 L
s
1 .009 0 r
.0698 .54045 m
.0698 .54046 L
s
.06981 .54037 m
.0698 .54045 L
s
.0698 .54045 m
.06975 .5404 L
s
.06986 .54042 m
.0698 .54045 L
s
.06983 .54024 m
.0698 .54045 L
s
1 .114 0 r
.77029 .57086 m
.77104 .57133 L
s
.76962 .57158 m
.77029 .57086 L
s
.77029 .57086 m
.77011 .57091 L
s
1 .009 0 r
.06981 .54037 m
.06975 .5404 L
s
.06986 .54042 m
.06981 .54037 L
s
.0698 .54046 m
.06986 .54042 L
s
.06975 .5404 m
.0698 .54046 L
s
1 .014 0 r
.38415 .44643 m
.38421 .44654 L
s
0 1 .511 r
.6347 .60291 m
.61987 .61378 L
s
.62663 .58832 m
.6347 .60291 L
s
1 .114 0 r
.77038 .57206 m
.76962 .57158 L
s
.76962 .57158 m
.77011 .57091 L
s
1 .001 0 r
.69933 .3523 m
.69933 .35231 L
s
.69933 .3523 m
.69933 .3523 L
s
.69933 .3523 m
.69932 .3523 L
s
.69933 .3523 m
.69933 .3523 L
s
.69931 .35229 m
.69933 .3523 L
s
.69932 .3523 m
.69933 .35231 L
s
.69933 .3523 m
.69932 .3523 L
s
.69933 .3523 m
.69933 .3523 L
s
.69933 .35231 m
.69933 .3523 L
s
1 .034 0 r
.88445 .57156 m
.88431 .57073 L
s
1 .215 0 r
.63451 .50891 m
.62773 .50505 L
s
1 .02 0 r
.44937 .28964 m
.4502 .28947 L
s
1 0 0 r
.13463 .38362 m
.13463 .38362 L
s
1 .02 0 r
.45007 .28959 m
.45003 .2896 L
s
.45004 .28941 m
.45007 .28959 L
s
.4502 .28947 m
.45007 .28959 L
s
.44999 .28943 m
.45004 .28941 L
s
.45004 .28941 m
.4502 .28947 L
s
1 .336 0 r
.39837 .54015 m
.40026 .54064 L
s
.4004 .53713 m
.39837 .54015 L
s
.39837 .54015 m
.3987 .53804 L
s
.40196 .53973 m
.39837 .54015 L
s
.40819 .53381 m
.39837 .54015 L
s
1 .02 0 r
.4502 .28947 m
.45003 .2896 L
s
.44999 .28943 m
.4502 .28947 L
s
.45003 .2896 m
.44999 .28943 L
s
1 .114 0 r
.77104 .57133 m
.77038 .57206 L
s
.77011 .57091 m
.77104 .57133 L
s
1 .293 0 r
.72463 .60396 m
.7227 .60266 L
s
.7227 .60266 m
.72406 .60099 L
s
1 .051 0 r
.69712 .16385 m
.6973 .16389 L
s
.69728 .16341 m
.69712 .16385 L
s
.69768 .1638 m
.69712 .16385 L
s
1 .114 0 r
.77011 .57091 m
.77038 .57206 L
s
1 .051 0 r
.69746 .16344 m
.69728 .16341 L
s
.69728 .16341 m
.69768 .1638 L
s
1 .336 0 r
.4004 .53713 m
.3987 .53804 L
s
.40196 .53973 m
.4004 .53713 L
s
1 .051 0 r
.69768 .1638 m
.6973 .16389 L
s
.69746 .16344 m
.69768 .1638 L
s
.69571 .16304 m
.69768 .1638 L
s
1 .336 0 r
.40026 .54064 m
.40196 .53973 L
s
1 .034 0 r
.88432 .57072 m
.88455 .57087 L
s
.88412 .57092 m
.88432 .57072 L
s
.88432 .57072 m
.88431 .57073 L
s
.88435 .57107 m
.88412 .57092 L
s
.88412 .57092 m
.88431 .57073 L
s
.88455 .57087 m
.88435 .57107 L
s
.88431 .57073 m
.88455 .57087 L
s
1 .051 0 r
.6973 .16389 m
.69746 .16344 L
s
0 1 .077 r
.47821 .5378 m
.47448 .55596 L
s
1 .034 0 r
.88431 .57073 m
.88435 .57107 L
s
1 .293 0 r
.72638 .60214 m
.72463 .60396 L
s
.72406 .60099 m
.72638 .60214 L
s
1 .007 0 r
.63107 .31985 m
.63109 .31986 L
s
.63109 .3198 m
.63107 .31985 L
s
.63114 .31984 m
.63107 .31985 L
s
.63111 .3198 m
.63109 .3198 L
s
.63109 .3198 m
.63114 .31984 L
s
.63114 .31984 m
.63109 .31986 L
s
.63111 .3198 m
.63114 .31984 L
s
.63087 .31976 m
.63114 .31984 L
s
0 1 .331 r
.46576 .55213 m
.46953 .55622 L
s
.46576 .55213 m
.44533 .561 L
s
1 .007 0 r
.63109 .31986 m
.63111 .3198 L
s
1 .001 0 r
.31592 .41381 m
.31592 .41381 L
s
.31592 .4138 m
.31592 .41381 L
s
.31592 .41381 m
.31592 .4138 L
s
.31592 .41381 m
.31592 .41381 L
s
.31593 .41379 m
.31592 .41381 L
s
.31592 .4138 m
.31592 .4138 L
s
.31592 .41381 m
.31592 .4138 L
s
.31592 .41381 m
.31592 .41381 L
s
.31592 .4138 m
.31592 .41381 L
s
1 .04 0 r
.81613 .53917 m
.81572 .53819 L
s
1 .162 0 r
.56603 .47648 m
.55912 .47525 L
s
1 .023 0 r
.38077 .25707 m
.38167 .25674 L
s
.38157 .25689 m
.38149 .25692 L
s
.3815 .25669 m
.38157 .25689 L
s
.38167 .25674 m
.38157 .25689 L
s
.38141 .25672 m
.3815 .25669 L
s
.3815 .25669 m
.38167 .25674 L
s
1 .293 0 r
.72406 .60099 m
.72463 .60396 L
s
1 .023 0 r
.38167 .25674 m
.38149 .25692 L
s
.38141 .25672 m
.38167 .25674 L
s
.38149 .25692 m
.38141 .25672 L
s
1 .162 0 r
.56051 .47632 m
.56019 .47609 L
s
.56019 .47609 m
.56049 .47467 L
s
.56019 .47609 m
.55912 .47525 L
s
1 .166 0 r
.70035 .53744 m
.70135 .53801 L
s
.69943 .53859 m
.70035 .53744 L
s
.70035 .53744 m
.69976 .53755 L
s
1 .023 0 r
.18215 .53868 m
.18217 .53868 L
s
.1822 .53844 m
.18215 .53868 L
s
.18215 .53868 m
.18204 .53854 L
s
.18233 .53859 m
.18215 .53868 L
s
.18233 .5381 m
.18215 .53868 L
s
1 .162 0 r
.56049 .47467 m
.56081 .4749 L
s
.56049 .47467 m
.55912 .47525 L
s
1 .023 0 r
.1822 .53844 m
.18204 .53854 L
s
.18233 .53859 m
.1822 .53844 L
s
.717 1 0 r
.59237 .5598 m
.59983 .56433 L
s
.58521 .56877 m
.59237 .5598 L
s
.59237 .5598 m
.58725 .5608 L
s
1 .166 0 r
.70044 .53917 m
.69943 .53859 L
s
.69943 .53859 m
.69976 .53755 L
s
1 .023 0 r
.18217 .53868 m
.18233 .53859 L
s
.18204 .53854 m
.18217 .53868 L
s
1 .04 0 r
.81578 .53818 m
.81605 .53834 L
s
.81555 .53843 m
.81578 .53818 L
s
.81578 .53818 m
.81572 .53819 L
s
.81582 .5386 m
.81555 .53843 L
s
.81555 .53843 m
.81572 .53819 L
s
1 .039 0 r
.49611 .44435 m
.49616 .4443 L
s
.49616 .4443 m
.49611 .44396 L
s
.49616 .4443 m
.49577 .44419 L
s
.49611 .44396 m
.49607 .44401 L
s
.49611 .44396 m
.49577 .44419 L
s
1 .04 0 r
.81605 .53834 m
.81582 .5386 L
s
.81572 .53819 m
.81605 .53834 L
s
.81572 .53819 m
.81582 .5386 L
s
1 .039 0 r
.49577 .44419 m
.49611 .44435 L
s
.49577 .44419 m
.49607 .44401 L
s
.49747 .44401 m
.49577 .44419 L
s
1 .021 0 r
.56308 .28735 m
.5631 .28737 L
s
.5631 .28716 m
.56308 .28735 L
s
.56328 .28728 m
.56308 .28735 L
s
.56312 .28718 m
.5631 .28716 L
s
.5631 .28716 m
.56328 .28728 L
s
.56328 .28728 m
.5631 .28737 L
s
.56312 .28718 m
.56328 .28728 L
s
.56235 .28719 m
.56328 .28728 L
s
1 .039 0 r
.49607 .44401 m
.49611 .44435 L
s
1 .021 0 r
.5631 .28737 m
.56312 .28718 L
s
1 0 0 r
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
1 .046 0 r
.74773 .50674 m
.74689 .50568 L
s
1 0 0 r
.24721 .38128 m
.24721 .38128 L
s
1 .023 0 r
.31209 .22446 m
.31289 .22404 L
s
1 .336 0 r
.3987 .53804 m
.40026 .54064 L
s
1 .166 0 r
.70135 .53801 m
.70044 .53917 L
s
.69976 .53755 m
.70135 .53801 L
s
1 .162 0 r
.55912 .47525 m
.56051 .47632 L
s
.55912 .47525 m
.56081 .4749 L
s
1 .023 0 r
.31282 .22421 m
.31272 .22423 L
s
.31274 .22401 m
.31282 .22421 L
s
.31289 .22404 m
.31282 .22421 L
s
.31263 .22404 m
.31274 .22401 L
s
.31274 .22401 m
.31289 .22404 L
s
1 .166 0 r
.69976 .53755 m
.70044 .53917 L
s
1 .08 0 r
.29388 .53783 m
.2941 .53787 L
s
.29416 .53704 m
.29388 .53783 L
s
.29388 .53783 m
.29365 .53733 L
s
.29461 .53758 m
.29388 .53783 L
s
.29512 .53596 m
.29388 .53783 L
s
1 .215 0 r
.62905 .50471 m
.63006 .50523 L
s
.62811 .50641 m
.62905 .50471 L
s
.62905 .50471 m
.62773 .50505 L
s
.62912 .50694 m
.62811 .50641 L
s
.62811 .50641 m
.62773 .50505 L
s
1 .162 0 r
.56081 .4749 m
.56051 .47632 L
s
1 .023 0 r
.31272 .22423 m
.31263 .22404 L
s
.31289 .22404 m
.31272 .22423 L
s
.31263 .22404 m
.31289 .22404 L
s
1 .08 0 r
.29416 .53704 m
.29365 .53733 L
s
.29461 .53758 m
.29416 .53704 L
s
.2941 .53787 m
.29461 .53758 L
s
1 .046 0 r
.74704 .50566 m
.74733 .50581 L
s
.74679 .50598 m
.74704 .50566 L
s
.74704 .50566 m
.74689 .50568 L
s
.717 1 0 r
.59265 .57333 m
.58521 .56877 L
s
.58521 .56877 m
.58725 .5608 L
s
1 .046 0 r
.74707 .50613 m
.74679 .50598 L
s
.74679 .50598 m
.74689 .50568 L
s
1 .08 0 r
.29365 .53733 m
.2941 .53787 L
s
1 .046 0 r
.74733 .50581 m
.74707 .50613 L
s
.74689 .50568 m
.74733 .50581 L
s
1 .006 0 r
.11344 .50581 m
.11344 .50581 L
s
.11345 .50574 m
.11344 .50581 L
s
.11344 .50581 m
.11341 .50577 L
s
.11349 .50578 m
.11344 .50581 L
s
.11348 .50565 m
.11344 .50581 L
s
.11345 .50574 m
.11341 .50577 L
s
.11349 .50578 m
.11345 .50574 L
s
.11344 .50581 m
.11349 .50578 L
s
.11341 .50577 m
.11344 .50581 L
s
1 .046 0 r
.74689 .50568 m
.74707 .50613 L
s
1 .003 0 r
.74424 .3174 m
.74422 .3174 L
s
.74422 .31738 m
.74424 .3174 L
s
.74424 .3174 m
.74421 .3174 L
s
.74424 .31738 m
.74424 .3174 L
s
.74416 .31735 m
.74424 .3174 L
s
.74422 .31738 m
.74421 .3174 L
s
.74424 .31738 m
.74422 .31738 L
s
.74421 .3174 m
.74422 .3174 L
s
1 .035 0 r
.49501 .25463 m
.49498 .25465 L
s
.49498 .25432 m
.49501 .25463 L
s
.49529 .25446 m
.49501 .25463 L
s
1 .003 0 r
.74422 .3174 m
.74424 .31738 L
s
1 .002 0 r
.42875 .41153 m
.42876 .41153 L
s
.42876 .41153 m
.42875 .41151 L
s
.42876 .41153 m
.42874 .41153 L
s
.42875 .41151 m
.42875 .41151 L
s
.42875 .41151 m
.42874 .41153 L
s
.42874 .41153 m
.42875 .41153 L
s
.42874 .41153 m
.42875 .41151 L
s
.42882 .4115 m
.42874 .41153 L
s
.42875 .41151 m
.42875 .41153 L
s
1 .035 0 r
.49495 .25433 m
.49498 .25432 L
s
.49498 .25432 m
.49529 .25446 L
s
1 .043 0 r
.67924 .47426 m
.67801 .47341 L
s
1 .035 0 r
.49374 .25458 m
.49529 .25446 L
s
1 0 0 r
.1784 .34873 m
.17841 .34873 L
s
.1784 .34873 m
.17841 .34873 L
s
.1784 .34873 m
.1784 .34873 L
s
.1784 .34873 m
.17841 .34873 L
s
.17841 .34873 m
.1784 .34873 L
s
.17841 .34873 m
.17841 .34873 L
s
.1784 .34873 m
.1784 .34873 L
s
.1784 .34873 m
.17841 .34873 L
s
.17841 .34873 m
.1784 .34873 L
s
1 .035 0 r
.49529 .25446 m
.49498 .25465 L
s
.49495 .25433 m
.49529 .25446 L
s
.49498 .25465 m
.49495 .25433 L
s
1 .215 0 r
.63006 .50523 m
.62912 .50694 L
s
.62773 .50505 m
.63006 .50523 L
s
.62773 .50505 m
.62912 .50694 L
s
1 .043 0 r
.67824 .47336 m
.67846 .47347 L
s
.67804 .47369 m
.67824 .47336 L
s
.67824 .47336 m
.67801 .47341 L
s
.67826 .4738 m
.67804 .47369 L
s
.67804 .47369 m
.67801 .47341 L
s
1 .525 0 r
.64993 .56364 m
.65305 .5655 L
s
.64701 .56731 m
.64993 .56364 L
s
.64993 .56364 m
.64796 .56406 L
s
1 .043 0 r
.67846 .47347 m
.67826 .4738 L
s
.67801 .47341 m
.67846 .47347 L
s
.67801 .47341 m
.67826 .4738 L
s
1 .825 0 r
.56614 .53799 m
.563 .53617 L
s
.563 .53617 m
.56603 .52937 L
s
.563 .53617 m
.56008 .53122 L
s
1 .012 0 r
.67593 .28492 m
.67598 .28493 L
s
.67597 .28482 m
.67593 .28492 L
s
.67606 .28491 m
.67593 .28492 L
s
.67602 .28483 m
.67597 .28482 L
s
.67597 .28482 m
.67606 .28491 L
s
.67606 .28491 m
.67598 .28493 L
s
.67602 .28483 m
.67606 .28491 L
s
.67562 .28473 m
.67606 .28491 L
s
.67598 .28493 m
.67602 .28483 L
s
1 .002 0 r
.04453 .47319 m
.04454 .47319 L
s
.04454 .47318 m
.04453 .47319 L
s
.04453 .47319 m
.04453 .47318 L
s
.04455 .47319 m
.04453 .47319 L
s
.04454 .47315 m
.04453 .47319 L
s
.04454 .47318 m
.04453 .47318 L
s
.04455 .47319 m
.04454 .47318 L
s
.04454 .47319 m
.04455 .47319 L
s
.04453 .47318 m
.04454 .47319 L
s
1 .013 0 r
.86123 .50456 m
.8611 .50424 L
s
0 1 .511 r
.54569 .59877 m
.43697 .58075 L
s
1 .024 0 r
.61066 .44175 m
.60974 .44145 L
s
1 0 0 r
.36008 .37894 m
.36008 .37894 L
s
1 .04 0 r
.42505 .22193 m
.42673 .22152 L
s
1 .825 0 r
.56603 .52937 m
.56918 .53117 L
s
.56603 .52937 m
.56008 .53122 L
s
1 .525 0 r
.65014 .56918 m
.64701 .56731 L
s
.64701 .56731 m
.64796 .56406 L
s
1 .417 0 r
.35505 .59867 m
.35649 .59905 L
s
.35672 .5946 m
.35505 .59867 L
s
.35505 .59867 m
.35417 .59613 L
s
.35904 .59752 m
.35505 .59867 L
s
.36287 .58942 m
.35505 .59867 L
s
1 .04 0 r
.42648 .22177 m
.42639 .2218 L
s
.4264 .22142 m
.42648 .22177 L
s
.42673 .22152 m
.42648 .22177 L
s
1 .024 0 r
.60992 .44163 m
.60985 .44159 L
s
.60985 .44159 m
.60992 .44139 L
s
.60985 .44159 m
.60974 .44145 L
s
1 .04 0 r
.4263 .22144 m
.4264 .22142 L
s
.4264 .22142 m
.42673 .22152 L
s
1 .024 0 r
.60992 .44139 m
.61 .44143 L
s
.60992 .44139 m
.60974 .44145 L
s
1 .013 0 r
.86112 .50424 m
.8612 .50429 L
s
.86104 .50432 m
.86112 .50424 L
s
.86112 .50424 m
.8611 .50424 L
s
.86113 .50437 m
.86104 .50432 L
s
.86104 .50432 m
.8611 .50424 L
s
.8612 .50429 m
.86113 .50437 L
s
.8611 .50424 m
.8612 .50429 L
s
.8611 .50424 m
.86113 .50437 L
s
1 .024 0 r
.60974 .44145 m
.60992 .44163 L
s
.60974 .44145 m
.61 .44143 L
s
.61 .44143 m
.60992 .44163 L
s
1 .04 0 r
.42673 .22152 m
.42639 .2218 L
s
.4263 .22144 m
.42673 .22152 L
s
.42639 .2218 m
.4263 .22144 L
s
1 .018 0 r
.22601 .50391 m
.22605 .50392 L
s
.22607 .50373 m
.22601 .50391 L
s
.22601 .50391 m
.22594 .5038 L
s
.22617 .50385 m
.22601 .50391 L
s
.22625 .50346 m
.22601 .50391 L
s
.22607 .50373 m
.22594 .5038 L
s
.22617 .50385 m
.22607 .50373 L
s
1 .825 0 r
.49191 .53654 m
.49219 .53528 L
s
.49219 .53528 m
.492 .52792 L
s
.49219 .53528 m
.48456 .53236 L
s
1 .018 0 r
.22605 .50392 m
.22617 .50385 L
s
.22594 .5038 m
.22605 .50392 L
s
1 .029 0 r
.60793 .2524 m
.60799 .25242 L
s
.60799 .25214 m
.60793 .2524 L
s
.60824 .25233 m
.60793 .2524 L
s
.60805 .25216 m
.60799 .25214 L
s
.60799 .25214 m
.60824 .25233 L
s
.60824 .25233 m
.60799 .25242 L
s
.60805 .25216 m
.60824 .25233 L
s
.607 .25208 m
.60824 .25233 L
s
1 .417 0 r
.35672 .5946 m
.35417 .59613 L
s
.35904 .59752 m
.35672 .5946 L
s
0 1 .511 r
.61987 .61378 m
.60423 .59783 L
s
.60423 .59783 m
.62663 .58832 L
s
1 .029 0 r
.60799 .25242 m
.60805 .25216 L
s
1 .003 0 r
.54188 .4092 m
.54188 .4092 L
s
.54188 .4092 m
.54188 .40917 L
s
.54188 .4092 m
.54185 .40919 L
s
.54188 .40917 m
.54188 .40918 L
s
.54188 .40917 m
.54185 .40919 L
s
1 .011 0 r
.79273 .47204 m
.79254 .47179 L
s
1 .003 0 r
.54199 .40919 m
.54185 .40919 L
s
1 0 0 r
.29126 .34635 m
.29127 .34634 L
s
1 .039 0 r
.35626 .18923 m
.35775 .18865 L
s
1 0 0 r
.29127 .34634 m
.29127 .34634 L
s
.29126 .34634 m
.29127 .34634 L
s
.29127 .34634 m
.29127 .34634 L
s
.29127 .34634 m
.29127 .34634 L
s
.29127 .34634 m
.29127 .34634 L
s
.29127 .34634 m
.29126 .34634 L
s
.29126 .34634 m
.29127 .34634 L
s
.29127 .34634 m
.29127 .34634 L
s
1 .003 0 r
.54185 .40919 m
.54188 .4092 L
s
.54185 .40919 m
.54188 .40918 L
s
.54188 .40918 m
.54188 .4092 L
s
1 .011 0 r
.79257 .47179 m
.79264 .47182 L
s
.79251 .47186 m
.79257 .47179 L
s
.79257 .47179 m
.79254 .47179 L
s
.79258 .47189 m
.79251 .47186 L
s
.79251 .47186 m
.79254 .47179 L
s
.79264 .47182 m
.79258 .47189 L
s
.79254 .47179 m
.79264 .47182 L
s
1 .417 0 r
.35649 .59905 m
.35904 .59752 L
s
1 .011 0 r
.79254 .47179 m
.79258 .47189 L
s
1 .039 0 r
.35758 .18892 m
.35744 .18895 L
s
.35746 .18859 m
.35758 .18892 L
s
.35775 .18865 m
.35758 .18892 L
s
.35732 .18862 m
.35746 .18859 L
s
.35746 .18859 m
.35775 .18865 L
s
.542 1 0 r
.42653 .59668 m
.43102 .60901 L
s
1 .825 0 r
.492 .52792 m
.49172 .52916 L
s
.492 .52792 m
.48456 .53236 L
s
1 .039 0 r
.35775 .18865 m
.35744 .18895 L
s
.35732 .18862 m
.35775 .18865 L
s
.35744 .18895 m
.35732 .18862 L
s
1 .068 0 r
.33773 .50274 m
.33802 .5028 L
s
.33806 .5021 m
.33773 .50274 L
s
.33773 .50274 m
.33767 .5023 L
s
.33842 .5026 m
.33773 .50274 L
s
.33931 .50127 m
.33773 .50274 L
s
.33806 .5021 m
.33767 .5023 L
s
.33842 .5026 m
.33806 .5021 L
s
1 .525 0 r
.65305 .5655 m
.65014 .56918 L
s
.64796 .56406 m
.65305 .5655 L
s
1 .068 0 r
.33802 .5028 m
.33842 .5026 L
s
1 .047 0 r
.53995 .21964 m
.53996 .21965 L
s
.53996 .21921 m
.53995 .21964 L
s
.54038 .21944 m
.53995 .21964 L
s
.53997 .21923 m
.53996 .21921 L
s
.53996 .21921 m
.54038 .21944 L
s
1 .253 0 r
.44474 .50295 m
.44558 .50248 L
s
.44558 .50248 m
.4448 .50032 L
s
.44558 .50248 m
.4428 .50227 L
s
1 .005 0 r
.78932 .28237 m
.78929 .28238 L
s
.78929 .28233 m
.78932 .28237 L
s
.78932 .28237 m
.78927 .28237 L
s
.78932 .28234 m
.78932 .28237 L
s
.78918 .28227 m
.78932 .28237 L
s
1 .004 0 r
.15726 .47102 m
.15726 .47102 L
s
.15727 .47098 m
.15726 .47102 L
s
.15726 .47102 m
.15724 .471 L
s
.15729 .47101 m
.15726 .47102 L
s
.1573 .47093 m
.15726 .47102 L
s
1 .005 0 r
.78929 .28233 m
.78927 .28237 L
s
.78932 .28234 m
.78929 .28233 L
s
.78927 .28237 m
.78929 .28238 L
s
1 .004 0 r
.15727 .47098 m
.15724 .471 L
s
.15729 .47101 m
.15727 .47098 L
s
.15726 .47102 m
.15729 .47101 L
s
.15724 .471 m
.15726 .47102 L
s
1 .005 0 r
.78929 .28238 m
.78932 .28234 L
s
1 .047 0 r
.54038 .21944 m
.53996 .21965 L
s
.53997 .21923 m
.54038 .21944 L
s
.53829 .21938 m
.54038 .21944 L
s
1 .65 0 r
.65909 .5967 m
.64626 .58231 L
s
1 .006 0 r
.72413 .43948 m
.72397 .43935 L
s
1 0 0 r
.47324 .3766 m
.47324 .3766 L
s
1 .001 0 r
.22235 .31371 m
.22238 .31368 L
s
.22237 .31368 m
.22238 .31369 L
s
.22236 .31368 m
.22237 .31368 L
s
.22237 .31368 m
.22238 .31368 L
s
.22238 .31369 m
.22237 .31369 L
s
.22238 .31368 m
.22238 .31369 L
s
.22237 .31369 m
.22236 .31368 L
s
.22236 .31368 m
.22238 .31368 L
s
.22238 .31368 m
.22237 .31369 L
s
1 .253 0 r
.4448 .50032 m
.44396 .50079 L
s
.4448 .50032 m
.4428 .50227 L
s
1 .068 0 r
.33767 .5023 m
.33802 .5028 L
s
1 .006 0 r
.724 .43935 m
.72403 .43936 L
s
.72397 .43939 m
.724 .43935 L
s
.724 .43935 m
.72397 .43935 L
s
1 .047 0 r
.53996 .21965 m
.53997 .21923 L
s
1 .006 0 r
.724 .43941 m
.72397 .43939 L
s
.72397 .43939 m
.72397 .43935 L
s
1 .253 0 r
.4428 .50227 m
.44474 .50295 L
s
.4428 .50227 m
.44396 .50079 L
s
.45266 .49908 m
.4428 .50227 L
s
1 .006 0 r
.72403 .43936 m
.724 .43941 L
s
.72397 .43935 m
.72403 .43936 L
s
.72397 .43935 m
.724 .43941 L
s
1 .525 0 r
.64796 .56406 m
.65014 .56918 L
s
1 .417 0 r
.35417 .59613 m
.35649 .59905 L
s
1 .015 0 r
.72091 .24984 m
.72098 .24986 L
s
.72097 .24971 m
.72091 .24984 L
s
.72108 .24984 m
.72091 .24984 L
s
.72108 .24984 m
.72098 .24986 L
s
.72097 .24971 m
.72108 .24984 L
s
.72103 .24973 m
.72108 .24984 L
s
.72054 .24957 m
.72108 .24984 L
s
.72103 .24973 m
.72097 .24971 L
s
.72098 .24986 m
.72103 .24973 L
s
.717 1 0 r
.59983 .56433 m
.59265 .57333 L
s
.58725 .5608 m
.59983 .56433 L
s
1 .001 0 r
.08825 .43836 m
.08825 .43836 L
s
.08826 .43836 m
.08825 .43836 L
s
.08825 .43836 m
.08825 .43836 L
s
.08826 .43836 m
.08825 .43836 L
s
.08826 .43835 m
.08825 .43836 L
s
.08826 .43836 m
.08825 .43836 L
s
.08826 .43836 m
.08826 .43836 L
s
.08825 .43836 m
.08826 .43836 L
s
.08825 .43836 m
.08825 .43836 L
s
1 .055 0 r
.47151 .18665 m
.47144 .18666 L
s
.47144 .18614 m
.47151 .18665 L
s
.47193 .18634 m
.47151 .18665 L
s
.973 1 0 r
.59036 .5642 m
.55287 .54906 L
s
1 .001 0 r
.65545 .40689 m
.6554 .40686 L
s
1 .055 0 r
.46949 .18664 m
.47193 .18634 L
s
1 .001 0 r
.4044 .34396 m
.40443 .34395 L
s
.40443 .34395 m
.40443 .34395 L
s
.40443 .34395 m
.40443 .34395 L
s
.40443 .34395 m
.40443 .34395 L
s
.40442 .34395 m
.40443 .34395 L
s
.40443 .34395 m
.40443 .34395 L
s
.40443 .34395 m
.40443 .34395 L
s
.40442 .34395 m
.40443 .34395 L
s
.40443 .34395 m
.40442 .34395 L
s
.65541 .40687 m
.65541 .40687 L
s
.65541 .40687 m
.65541 .40686 L
s
.65541 .40687 m
.6554 .40686 L
s
.65541 .40686 m
.65542 .40686 L
s
.65541 .40686 m
.6554 .40686 L
s
.65542 .40686 m
.65541 .40687 L
s
.6554 .40686 m
.65541 .40687 L
s
.6554 .40686 m
.65542 .40686 L
s
1 .055 0 r
.47137 .18616 m
.47144 .18614 L
s
.47144 .18614 m
.47193 .18634 L
s
.47193 .18634 m
.47144 .18666 L
s
.47137 .18616 m
.47193 .18634 L
s
1 .253 0 r
.44396 .50079 m
.44474 .50295 L
s
1 .055 0 r
.47144 .18666 m
.47137 .18616 L
s
1 .825 0 r
.48456 .53236 m
.49191 .53654 L
s
.48456 .53236 m
.49172 .52916 L
s
.52155 .53166 m
.48456 .53236 L
s
1 .033 0 r
.65281 .21729 m
.65291 .21731 L
s
.65289 .21699 m
.65281 .21729 L
s
.65317 .21723 m
.65281 .21729 L
s
.65299 .21702 m
.65289 .21699 L
s
.65289 .21699 m
.65317 .21723 L
s
.65317 .21723 m
.65291 .21731 L
s
.65299 .21702 m
.65317 .21723 L
s
.65181 .21683 m
.65317 .21723 L
s
1 .012 0 r
.27011 .46897 m
.27015 .46897 L
s
.27016 .46885 m
.27011 .46897 L
s
.27011 .46897 m
.27009 .46889 L
s
.27023 .46894 m
.27011 .46897 L
s
.27034 .4687 m
.27011 .46897 L
s
.27016 .46885 m
.27009 .46889 L
s
.27023 .46894 m
.27016 .46885 L
s
.27015 .46897 m
.27023 .46894 L
s
.27009 .46889 m
.27015 .46897 L
s
1 .033 0 r
.65291 .21731 m
.65299 .21702 L
s
1 .459 0 r
.39396 .56324 m
.39655 .56395 L
s
.39674 .5591 m
.39396 .56324 L
s
.39396 .56324 m
.3944 .56038 L
s
.39888 .56267 m
.39396 .56324 L
s
.40745 .55464 m
.39396 .56324 L
s
1 .002 0 r
.83789 .43721 m
.83786 .43717 L
s
1 .158 0 r
.77277 .59463 m
.77124 .59083 L
s
1 0 0 r
.58668 .37425 m
.58668 .37425 L
s
1 .003 0 r
.33547 .31128 m
.33558 .31122 L
s
1 .055 0 r
.4006 .15386 m
.40288 .15326 L
s
.717 1 0 r
.58725 .5608 m
.59265 .57333 L
s
1 .002 0 r
.83787 .43717 m
.83788 .43717 L
s
.83786 .43718 m
.83787 .43717 L
s
.83787 .43717 m
.83786 .43717 L
s
.83787 .43719 m
.83786 .43718 L
s
.83786 .43718 m
.83786 .43717 L
s
1 .003 0 r
.33557 .31124 m
.33556 .31125 L
s
.33556 .31122 m
.33557 .31124 L
s
.33558 .31122 m
.33557 .31124 L
s
.33554 .31122 m
.33556 .31122 L
s
.33556 .31122 m
.33558 .31122 L
s
1 .002 0 r
.83788 .43717 m
.83787 .43719 L
s
.83786 .43717 m
.83788 .43717 L
s
.83786 .43717 m
.83787 .43719 L
s
1 .003 0 r
.33556 .31125 m
.33554 .31122 L
s
.33558 .31122 m
.33556 .31125 L
s
.33554 .31122 m
.33558 .31122 L
s
1 .039 0 r
.136 .59455 m
.136 .59456 L
s
.13605 .59415 m
.136 .59455 L
s
.136 .59455 m
.13577 .59433 L
s
.13628 .59438 m
.136 .59455 L
s
.13612 .59359 m
.136 .59455 L
s
.13605 .59415 m
.13577 .59433 L
s
.13628 .59438 m
.13605 .59415 L
s
1 .055 0 r
.40256 .15361 m
.40241 .15363 L
s
.40244 .15312 m
.40256 .15361 L
s
.40288 .15326 m
.40256 .15361 L
s
1 .825 0 r
.56918 .53117 m
.56614 .53799 L
s
.56008 .53122 m
.56614 .53799 L
s
1 .055 0 r
.40229 .15314 m
.40244 .15312 L
s
.40244 .15312 m
.40288 .15326 L
s
1 .039 0 r
.136 .59456 m
.13628 .59438 L
s
.13577 .59433 m
.136 .59456 L
s
1 .115 0 r
.24835 .59427 m
.2485 .59433 L
s
.2486 .5931 m
.24835 .59427 L
s
.24835 .59427 m
.24782 .5936 L
s
.24927 .59383 m
.24835 .59427 L
s
.24935 .59151 m
.24835 .59427 L
s
1 .459 0 r
.39674 .5591 m
.3944 .56038 L
s
.39888 .56267 m
.39674 .5591 L
s
1 .825 0 r
.56008 .53122 m
.56918 .53117 L
s
1 .459 0 r
.39655 .56395 m
.39888 .56267 L
s
1 .055 0 r
.40288 .15326 m
.40241 .15363 L
s
.40229 .15314 m
.40288 .15326 L
s
.40241 .15363 m
.40229 .15314 L
s
1 .115 0 r
.2486 .5931 m
.24782 .5936 L
s
.24927 .59383 m
.2486 .5931 L
s
1 .053 0 r
.5848 .18452 m
.58488 .18453 L
s
.58486 .18404 m
.5848 .18452 L
s
.58534 .18434 m
.5848 .18452 L
s
.58494 .18405 m
.58486 .18404 L
s
.58486 .18404 m
.58534 .18434 L
s
1 .115 0 r
.2485 .59433 m
.24927 .59383 L
s
1 .053 0 r
.58534 .18434 m
.58488 .18453 L
s
.58494 .18405 m
.58534 .18434 L
s
.583 .18405 m
.58534 .18434 L
s
0 1 .511 r
.62663 .58832 m
.61987 .61378 L
s
1 .053 0 r
.58488 .18453 m
.58494 .18405 L
s
1 .002 0 r
.20126 .43611 m
.20127 .43611 L
s
.20127 .4361 m
.20126 .43611 L
s
.20126 .43611 m
.20126 .4361 L
s
.20128 .43611 m
.20126 .43611 L
s
.20129 .43607 m
.20126 .43611 L
s
.20127 .4361 m
.20126 .4361 L
s
.20128 .43611 m
.20127 .4361 L
s
.20127 .43611 m
.20128 .43611 L
s
.20126 .4361 m
.20127 .43611 L
s
1 .115 0 r
.24782 .5936 m
.2485 .59433 L
s
1 .001 0 r
.51788 .34157 m
.51788 .34157 L
s
.51788 .34156 m
.51788 .34157 L
s
.51789 .34156 m
.51788 .34157 L
s
.51788 .34156 m
.51788 .34156 L
s
.51788 .34156 m
.51789 .34156 L
s
1 0 0 r
.7692 .40457 m
.76919 .40456 L
s
1 .241 0 r
.70403 .56209 m
.69945 .55667 L
s
1 .001 0 r
.51783 .34156 m
.51789 .34156 L
s
1 .005 0 r
.26646 .27856 m
.2666 .27845 L
s
1 .001 0 r
.51789 .34156 m
.51788 .34157 L
s
.51788 .34156 m
.51789 .34156 L
s
.51788 .34157 m
.51788 .34156 L
s
1 0 0 r
.76919 .40456 m
.76919 .40456 L
s
.76919 .40456 m
.76919 .40456 L
s
.76919 .40456 m
.76919 .40456 L
s
.76919 .40457 m
.76919 .40456 L
s
.76919 .40456 m
.76919 .40456 L
s
.76919 .40456 m
.76919 .40457 L
s
.76919 .40456 m
.76919 .40456 L
s
.76919 .40456 m
.76919 .40457 L
s
1 .005 0 r
.26658 .27845 m
.2666 .27849 L
s
.26655 .27846 m
.26658 .27845 L
s
.26658 .27845 m
.2666 .27845 L
s
.2666 .27849 m
.26657 .2785 L
s
.2666 .27845 m
.2666 .27849 L
s
.26657 .2785 m
.26655 .27846 L
s
.26655 .27846 m
.2666 .27845 L
s
.2666 .27845 m
.26657 .2785 L
s
1 .043 0 r
.38231 .46725 m
.38257 .46731 L
s
.38259 .46687 m
.38231 .46725 L
s
.38231 .46725 m
.38238 .46696 L
s
.38278 .46721 m
.38231 .46725 L
s
.38367 .46646 m
.38231 .46725 L
s
0 .813 1 r
.5334 .49873 m
.51539 .52103 L
s
.50164 .48956 m
.5334 .49873 L
s
1 .043 0 r
.38257 .46731 m
.38278 .46721 L
s
.38278 .46721 m
.38259 .46687 L
s
.38259 .46687 m
.38238 .46696 L
s
0 1 .511 r
.45864 .59787 m
.45466 .59306 L
s
.45466 .59306 m
.45918 .57102 L
s
.45466 .59306 m
.43697 .58075 L
s
1 .043 0 r
.38238 .46696 m
.38257 .46731 L
s
1 .825 0 r
.49172 .52916 m
.49191 .53654 L
s
1 .014 0 r
.0669 .56138 m
.06689 .56139 L
s
.06691 .56124 m
.0669 .56138 L
s
.0669 .56138 m
.06681 .5613 L
s
.067 .56132 m
.0669 .56138 L
s
.06693 .56103 m
.0669 .56138 L
s
.06691 .56124 m
.06681 .5613 L
s
.067 .56132 m
.06691 .56124 L
s
.06689 .56139 m
.067 .56132 L
s
1 .018 0 r
.76621 .21461 m
.7661 .21463 L
s
.76609 .21446 m
.76621 .21461 L
s
.76621 .21461 m
.76602 .21461 L
s
.76617 .21448 m
.76621 .21461 L
s
.76563 .21427 m
.76621 .21461 L
s
.76602 .21461 m
.7661 .21463 L
s
.76609 .21446 m
.76602 .21461 L
s
1 .014 0 r
.06681 .5613 m
.06689 .56139 L
s
1 .018 0 r
.76617 .21448 m
.76609 .21446 L
s
1 .066 0 r
.51647 .15147 m
.51646 .15148 L
s
.51646 .15087 m
.51647 .15147 L
s
.51705 .15116 m
.51647 .15147 L
s
1 .018 0 r
.7661 .21463 m
.76617 .21448 L
s
1 .066 0 r
.51644 .15087 m
.51646 .15087 L
s
.51646 .15087 m
.51705 .15116 L
s
1 0 0 r
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
1 .05 0 r
.88673 .59255 m
.88652 .59133 L
s
1 .336 0 r
.6352 .5295 m
.62453 .5235 L
s
1 0 0 r
.70042 .37189 m
.70042 .37189 L
s
1 .066 0 r
.5141 .15123 m
.51705 .15116 L
s
1 .006 0 r
.44889 .30884 m
.44915 .30879 L
s
.44911 .30882 m
.4491 .30883 L
s
.4491 .30877 m
.44911 .30882 L
s
.44915 .30879 m
.44911 .30882 L
s
.44908 .30877 m
.4491 .30877 L
s
.4491 .30877 m
.44915 .30879 L
s
0 1 .331 r
.44533 .561 m
.46532 .57674 L
s
.44533 .561 m
.46953 .55622 L
s
1 .006 0 r
.44915 .30879 m
.4491 .30883 L
s
.44908 .30877 m
.44915 .30879 L
s
.4491 .30883 m
.44908 .30877 L
s
1 .066 0 r
.51705 .15116 m
.51646 .15148 L
s
.51644 .15087 m
.51705 .15116 L
s
.51646 .15148 m
.51644 .15087 L
s
1 .158 0 r
.77148 .59075 m
.77254 .59142 L
s
.77055 .59176 m
.77148 .59075 L
s
.77148 .59075 m
.77124 .59083 L
s
1 .035 0 r
.69776 .182 m
.69789 .18202 L
s
.69787 .1817 m
.69776 .182 L
s
.69815 .18196 m
.69776 .182 L
s
.69799 .18172 m
.69787 .1817 L
s
.69787 .1817 m
.69815 .18196 L
s
.69815 .18196 m
.69789 .18202 L
s
.69799 .18172 m
.69815 .18196 L
s
.6968 .18145 m
.69815 .18196 L
s
1 .459 0 r
.3944 .56038 m
.39655 .56395 L
s
1 .158 0 r
.77161 .59244 m
.77055 .59176 L
s
.77055 .59176 m
.77124 .59083 L
s
1 .035 0 r
.69789 .18202 m
.69799 .18172 L
s
1 .05 0 r
.88653 .59131 m
.88688 .59154 L
s
.88624 .59161 m
.88653 .59131 L
s
.88653 .59131 m
.88652 .59133 L
s
.88659 .59184 m
.88624 .59161 L
s
.88624 .59161 m
.88652 .59133 L
s
1 .005 0 r
.31447 .4339 m
.31449 .4339 L
s
.3145 .43385 m
.31447 .4339 L
s
.31447 .4339 m
.31447 .43387 L
s
.31452 .43389 m
.31447 .4339 L
s
.3146 .43379 m
.31447 .4339 L
s
.3145 .43385 m
.31447 .43387 L
s
.31452 .43389 m
.3145 .43385 L
s
.31449 .4339 m
.31452 .43389 L
s
.31447 .43387 m
.31449 .4339 L
s
1 .05 0 r
.88688 .59154 m
.88659 .59184 L
s
.88652 .59133 m
.88688 .59154 L
s
1 .001 0 r
.63157 .33918 m
.63157 .33918 L
s
.63157 .33917 m
.63157 .33918 L
s
.63158 .33917 m
.63157 .33918 L
s
.63158 .33917 m
.63157 .33917 L
s
.63157 .33917 m
.63158 .33917 L
s
.63158 .33917 m
.63157 .33918 L
s
.63158 .33917 m
.63158 .33917 L
s
.63154 .33916 m
.63158 .33917 L
s
.63157 .33918 m
.63158 .33917 L
s
1 .063 0 r
.81798 .55997 m
.81732 .55843 L
s
1 .303 0 r
.56629 .49688 m
.55326 .49458 L
s
1 .011 0 r
.37986 .27608 m
.38026 .27593 L
s
1 .05 0 r
.88652 .59133 m
.88659 .59184 L
s
1 .011 0 r
.38022 .276 m
.38018 .27601 L
s
.38018 .27591 m
.38022 .276 L
s
.38026 .27593 m
.38022 .276 L
s
.38015 .27592 m
.38018 .27591 L
s
.38018 .27591 m
.38026 .27593 L
s
1 .158 0 r
.77254 .59142 m
.77161 .59244 L
s
.77124 .59083 m
.77254 .59142 L
s
1 .011 0 r
.38026 .27593 m
.38018 .27601 L
s
.38015 .27592 m
.38026 .27593 L
s
.38018 .27601 m
.38015 .27592 L
s
1 .038 0 r
.17986 .55983 m
.17989 .55984 L
s
.17994 .55944 m
.17986 .55983 L
s
.17986 .55983 m
.17968 .5596 L
s
.18015 .55968 m
.17986 .55983 L
s
.18015 .5589 m
.17986 .55983 L
s
.17994 .55944 m
.17968 .5596 L
s
.18015 .55968 m
.17994 .55944 L
s
1 .111 0 r
.49336 .4652 m
.4935 .46505 L
s
.4935 .46505 m
.49337 .46406 L
s
.4935 .46505 m
.49239 .46474 L
s
1 .038 0 r
.17989 .55984 m
.18015 .55968 L
s
1 .158 0 r
.77124 .59083 m
.77161 .59244 L
s
1 .121 0 r
.29176 .5596 m
.2921 .55968 L
s
.29219 .5584 m
.29176 .5596 L
s
.29176 .5596 m
.29141 .55885 L
s
.29288 .55922 m
.29176 .5596 L
s
.29365 .55678 m
.29176 .5596 L
s
1 .038 0 r
.17968 .5596 m
.17989 .55984 L
s
1 .111 0 r
.49337 .46406 m
.49324 .46421 L
s
.49337 .46406 m
.49239 .46474 L
s
0 1 .511 r
.45918 .57102 m
.4632 .57563 L
s
.45918 .57102 m
.43697 .58075 L
s
0 .434 1 r
.50891 .49947 m
.5291 .51165 L
s
.48869 .52446 m
.50891 .49947 L
s
.50891 .49947 m
.49314 .50136 L
s
1 .055 0 r
.62965 .14922 m
.62977 .14924 L
s
.62975 .14873 m
.62965 .14922 L
s
.63023 .14908 m
.62965 .14922 L
s
1 .111 0 r
.49239 .46474 m
.49336 .4652 L
s
.49239 .46474 m
.49324 .46421 L
s
.49729 .46421 m
.49239 .46474 L
s
1 .055 0 r
.62987 .14874 m
.62975 .14873 L
s
.62975 .14873 m
.63023 .14908 L
s
1 .121 0 r
.29219 .5584 m
.29141 .55885 L
s
.29288 .55922 m
.29219 .5584 L
s
1 .055 0 r
.63023 .14908 m
.62977 .14924 L
s
.62987 .14874 m
.63023 .14908 L
s
.62788 .14858 m
.63023 .14908 L
s
1 .303 0 r
.55589 .49661 m
.5553 .49615 L
s
.5553 .49615 m
.55586 .49347 L
s
.5553 .49615 m
.55326 .49458 L
s
1 .121 0 r
.2921 .55968 m
.29288 .55922 L
s
1 .055 0 r
.62977 .14924 m
.62987 .14874 L
s
1 .303 0 r
.55586 .49347 m
.55645 .49394 L
s
.55586 .49347 m
.55326 .49458 L
s
1 .111 0 r
.49324 .46421 m
.49336 .4652 L
s
1 .007 0 r
.56282 .30645 m
.56283 .30645 L
s
.56283 .30639 m
.56282 .30645 L
s
.56289 .30643 m
.56282 .30645 L
s
.56283 .30639 m
.56283 .30639 L
s
.56283 .30639 m
.56289 .30643 L
s
.56289 .30643 m
.56283 .30645 L
s
.56283 .30639 m
.56289 .30643 L
s
.56259 .3064 m
.56289 .30643 L
s
1 0 0 r
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
1 .063 0 r
.81743 .5584 m
.81785 .55866 L
s
.81706 .55881 m
.81743 .5584 L
s
.81743 .5584 m
.81732 .55843 L
s
1 .007 0 r
.56283 .30645 m
.56283 .30639 L
s
1 .08 0 r
.74914 .52734 m
.74767 .52551 L
s
1 0 0 r
.81444 .36952 m
.81444 .36952 L
s
1 .013 0 r
.31074 .24327 m
.31117 .24304 L
s
1 .121 0 r
.29141 .55885 m
.2921 .55968 L
s
1 .063 0 r
.81748 .55907 m
.81706 .55881 L
s
.81706 .55881 m
.81732 .55843 L
s
1 .013 0 r
.31114 .24313 m
.31108 .24315 L
s
.31109 .24303 m
.31114 .24313 L
s
.31117 .24304 m
.31114 .24313 L
s
.31103 .24304 m
.31109 .24303 L
s
.31109 .24303 m
.31117 .24304 L
s
0 .813 1 r
.50164 .48956 m
.51539 .52103 L
s
1 .013 0 r
.31108 .24315 m
.31103 .24304 L
s
.31117 .24304 m
.31108 .24315 L
s
.31103 .24304 m
.31117 .24304 L
s
1 .063 0 r
.81785 .55866 m
.81748 .55907 L
s
.81732 .55843 m
.81785 .55866 L
s
.81732 .55843 m
.81748 .55907 L
s
1 .241 0 r
.7003 .55648 m
.70177 .55733 L
s
.69896 .55817 m
.7003 .55648 L
s
.7003 .55648 m
.69945 .55667 L
s
.70043 .55903 m
.69896 .55817 L
s
.69896 .55817 m
.69945 .55667 L
s
0 1 .331 r
.46953 .55622 m
.46532 .57674 L
s
1 .012 0 r
.11078 .52655 m
.11079 .52656 L
s
.1108 .52643 m
.11078 .52655 L
s
.11078 .52655 m
.11072 .52648 L
s
.11087 .52651 m
.11078 .52655 L
s
.11086 .52626 m
.11078 .52655 L
s
.1108 .52643 m
.11072 .52648 L
s
.11087 .52651 m
.1108 .52643 L
s
.11079 .52656 m
.11087 .52651 L
s
.11072 .52648 m
.11079 .52656 L
s
1 .016 0 r
.42771 .43176 m
.42776 .43173 L
s
.42776 .43173 m
.42771 .43159 L
s
.42776 .43173 m
.42759 .43172 L
s
.42771 .43159 m
.42766 .43162 L
s
.42771 .43159 m
.42759 .43172 L
s
.42759 .43172 m
.42771 .43176 L
s
.42759 .43172 m
.42766 .43162 L
s
.42821 .43151 m
.42759 .43172 L
s
.42766 .43162 m
.42771 .43176 L
s
.49413 .27361 m
.49411 .27362 L
s
.49411 .27347 m
.49413 .27361 L
s
.49426 .27354 m
.49413 .27361 L
s
1 0 0 r
.74556 .33676 m
.74556 .33676 L
s
.74556 .33676 m
.74556 .33676 L
s
.74556 .33676 m
.74556 .33676 L
s
.74556 .33676 m
.74556 .33676 L
s
.74555 .33676 m
.74556 .33676 L
s
.74556 .33676 m
.74556 .33676 L
s
.74556 .33676 m
.74556 .33676 L
s
.74556 .33676 m
.74556 .33676 L
s
1 .016 0 r
.4941 .27348 m
.49411 .27347 L
s
.49411 .27347 m
.49426 .27354 L
s
1 0 0 r
.74556 .33676 m
.74556 .33676 L
s
1 .09 0 r
.68022 .49467 m
.67764 .49291 L
s
1 .016 0 r
.49354 .27359 m
.49426 .27354 L
s
1 0 0 r
.17619 .36834 m
.17619 .36834 L
s
1 .016 0 r
.49426 .27354 m
.49411 .27362 L
s
.4941 .27348 m
.49426 .27354 L
s
.49411 .27362 m
.4941 .27348 L
s
1 .303 0 r
.55326 .49458 m
.55589 .49661 L
s
.55326 .49458 m
.55645 .49394 L
s
1 .08 0 r
.74794 .52546 m
.74844 .52573 L
s
.7475 .52602 m
.74794 .52546 L
s
.74794 .52546 m
.74767 .52551 L
s
.748 .52629 m
.7475 .52602 L
s
.7475 .52602 m
.74767 .52551 L
s
1 .303 0 r
.55645 .49394 m
.55589 .49661 L
s
1 .241 0 r
.70177 .55733 m
.70043 .55903 L
s
.69945 .55667 m
.70177 .55733 L
s
1 .08 0 r
.74844 .52573 m
.748 .52629 L
s
.74767 .52551 m
.74844 .52573 L
s
1 .035 0 r
.74284 .14654 m
.74299 .14656 L
s
.74296 .14624 m
.74284 .14654 L
s
.74323 .14652 m
.74284 .14654 L
s
1 .08 0 r
.74767 .52551 m
.748 .52629 L
s
1 .035 0 r
.74323 .14652 m
.74299 .14656 L
s
.74296 .14624 m
.74323 .14652 L
s
.74311 .14627 m
.74323 .14652 L
s
.74196 .14593 m
.74323 .14652 L
s
.74311 .14627 m
.74296 .14624 L
s
1 .336 0 r
.62662 .52294 m
.6282 .52378 L
s
.62514 .52562 m
.62662 .52294 L
s
.62662 .52294 m
.62453 .5235 L
s
.62673 .52646 m
.62514 .52562 L
s
.62514 .52562 m
.62453 .5235 L
s
1 .241 0 r
.69945 .55667 m
.70043 .55903 L
s
1 .035 0 r
.74299 .14656 m
.74311 .14627 L
s
.973 1 0 r
.48439 .55864 m
.48476 .55697 L
s
.48476 .55697 m
.48452 .54777 L
s
.48476 .55697 m
.47519 .55337 L
s
1 .003 0 r
.04146 .49366 m
.04146 .49366 L
s
.04147 .49362 m
.04146 .49366 L
s
.04146 .49366 m
.04144 .49364 L
s
.04149 .49364 m
.04146 .49366 L
s
.04148 .49357 m
.04146 .49366 L
s
.04147 .49362 m
.04144 .49364 L
s
.04149 .49364 m
.04147 .49362 L
s
.04146 .49366 m
.04149 .49364 L
s
.04144 .49364 m
.04146 .49366 L
s
1 .004 0 r
.67668 .30401 m
.67669 .30401 L
s
.67669 .30397 m
.67668 .30401 L
s
.67672 .304 m
.67668 .30401 L
s
.6767 .30398 m
.67669 .30397 L
s
.67669 .30397 m
.67672 .304 L
s
.67672 .304 m
.67669 .30401 L
s
.6767 .30398 m
.67672 .304 L
s
.67658 .30395 m
.67672 .304 L
s
.67669 .30401 m
.6767 .30398 L
s
1 .001 0 r
.359 .39877 m
.35901 .39877 L
s
.35901 .39877 m
.359 .39877 L
s
.359 .39877 m
.359 .39877 L
s
.35901 .39877 m
.359 .39877 L
s
.35903 .39876 m
.359 .39877 L
s
.35901 .39877 m
.35901 .39877 L
s
.35901 .39877 m
.35901 .39877 L
s
.35901 .39877 m
.359 .39877 L
s
.359 .39877 m
.35901 .39877 L
s
1 .023 0 r
.86337 .52517 m
.86312 .5246 L
s
1 .07 0 r
.6112 .46197 m
.60845 .46108 L
s
1 .022 0 r
.42441 .24074 m
.42535 .24052 L
s
1 .09 0 r
.67813 .49279 m
.6786 .49303 L
s
.67771 .49349 m
.67813 .49279 L
s
.67813 .49279 m
.67764 .49291 L
s
.542 1 0 r
.58991 .57668 m
.59844 .58194 L
s
.5817 .58697 m
.58991 .57668 L
s
.58991 .57668 m
.58402 .57794 L
s
1 .022 0 r
.42521 .24066 m
.42516 .24067 L
s
.42516 .24046 m
.42521 .24066 L
s
.42535 .24052 m
.42521 .24066 L
s
1 .09 0 r
.67818 .49373 m
.67771 .49349 L
s
.67771 .49349 m
.67764 .49291 L
s
1 .022 0 r
.42511 .24047 m
.42516 .24046 L
s
.42516 .24046 m
.42535 .24052 L
s
.42535 .24052 m
.42516 .24067 L
s
.42511 .24047 m
.42535 .24052 L
s
.42516 .24067 m
.42511 .24047 L
s
1 .39 0 r
.43995 .52567 m
.44126 .52491 L
s
.44126 .52491 m
.44005 .52159 L
s
.44126 .52491 m
.43696 .5246 L
s
1 .033 0 r
.2239 .52489 m
.22398 .52491 L
s
.22401 .52456 m
.2239 .52489 L
s
.2239 .52489 m
.22378 .52468 L
s
.2242 .52478 m
.2239 .52489 L
s
.22435 .52409 m
.2239 .52489 L
s
.22401 .52456 m
.22378 .52468 L
s
.2242 .52478 m
.22401 .52456 L
s
.22398 .52491 m
.2242 .52478 L
s
1 .023 0 r
.86316 .52459 m
.86332 .52468 L
s
.86302 .52474 m
.86316 .52459 L
s
.86316 .52459 m
.86312 .5246 L
s
.86318 .52484 m
.86302 .52474 L
s
.86302 .52474 m
.86312 .5246 L
s
1 .07 0 r
.60901 .46161 m
.60878 .46149 L
s
.60878 .46149 m
.60899 .46089 L
s
.60878 .46149 m
.60845 .46108 L
s
1 .39 0 r
.44005 .52159 m
.43874 .52235 L
s
.44005 .52159 m
.43696 .5246 L
s
1 .033 0 r
.22378 .52468 m
.22398 .52491 L
s
1 .023 0 r
.86332 .52468 m
.86318 .52484 L
s
.86312 .5246 m
.86332 .52468 L
s
1 .07 0 r
.60899 .46089 m
.60923 .46101 L
s
.60899 .46089 m
.60845 .46108 L
s
1 .023 0 r
.86312 .5246 m
.86318 .52484 L
s
1 .09 0 r
.6786 .49303 m
.67818 .49373 L
s
.67764 .49291 m
.6786 .49303 L
s
.67764 .49291 m
.67818 .49373 L
s
1 .39 0 r
.43696 .5246 m
.43995 .52567 L
s
.43696 .5246 m
.43874 .52235 L
s
.45219 .51973 m
.43696 .5246 L
s
0 .434 1 r
.50872 .5369 m
.48869 .52446 L
s
.48869 .52446 m
.49314 .50136 L
s
1 .116 0 r
.33541 .5244 m
.33591 .52451 L
s
.33598 .52329 m
.33541 .5244 L
s
.33541 .5244 m
.33531 .52365 L
s
.33659 .52415 m
.33541 .5244 L
s
.33813 .52191 m
.33541 .5244 L
s
.973 1 0 r
.48452 .54777 m
.48415 .5494 L
s
.48452 .54777 m
.47519 .55337 L
s
1 .07 0 r
.60845 .46108 m
.60901 .46161 L
s
.60845 .46108 m
.60923 .46101 L
s
.60923 .46101 m
.60901 .46161 L
s
1 .116 0 r
.33598 .52329 m
.33531 .52365 L
s
.33659 .52415 m
.33598 .52329 L
s
1 .013 0 r
.60795 .27124 m
.60797 .27125 L
s
.60797 .27112 m
.60795 .27124 L
s
.60809 .27121 m
.60795 .27124 L
s
.608 .27113 m
.60797 .27112 L
s
.60797 .27112 m
.60809 .27121 L
s
.60809 .27121 m
.60797 .27125 L
s
.608 .27113 m
.60809 .27121 L
s
.60752 .2711 m
.60809 .27121 L
s
1 .116 0 r
.33591 .52451 m
.33659 .52415 L
s
1 .013 0 r
.60797 .27125 m
.608 .27113 L
s
1 .024 0 r
.54125 .42929 m
.54124 .42926 L
s
.54124 .42926 m
.54125 .42905 L
s
.54124 .42926 m
.54104 .42916 L
s
.54125 .42905 m
.54127 .42907 L
s
.54125 .42905 m
.54104 .42916 L
s
1 .023 0 r
.79443 .49246 m
.79401 .49191 L
s
1 .024 0 r
.5421 .42921 m
.54104 .42916 L
s
1 0 0 r
.28977 .36597 m
.28977 .36597 L
s
1 .024 0 r
.35519 .20785 m
.35612 .20749 L
s
.54104 .42916 m
.54125 .42929 L
s
.54104 .42916 m
.54127 .42907 L
s
.54127 .42907 m
.54125 .42929 L
s
.35601 .20766 m
.35592 .20768 L
s
.35594 .20745 m
.35601 .20766 L
s
.35612 .20749 m
.35601 .20766 L
s
.35585 .20747 m
.35594 .20745 L
s
.35594 .20745 m
.35612 .20749 L
s
1 .336 0 r
.6282 .52378 m
.62673 .52646 L
s
.62453 .5235 m
.6282 .52378 L
s
1 .024 0 r
.35612 .20749 m
.35592 .20768 L
s
.35585 .20747 m
.35612 .20749 L
s
1 .336 0 r
.62453 .5235 m
.62673 .52646 L
s
1 .024 0 r
.35592 .20768 m
.35585 .20747 L
s
1 .023 0 r
.79408 .4919 m
.79423 .49198 L
s
.79395 .49206 m
.79408 .4919 L
s
.79408 .4919 m
.79401 .49191 L
s
.542 1 0 r
.59021 .59227 m
.5817 .58697 L
s
.5817 .58697 m
.58402 .57794 L
s
1 .023 0 r
.7941 .49214 m
.79395 .49206 L
s
.79395 .49206 m
.79401 .49191 L
s
1 .65 0 r
.64872 .58174 m
.65262 .58409 L
s
.64508 .58632 m
.64872 .58174 L
s
.64872 .58174 m
.64626 .58231 L
s
1 .116 0 r
.33531 .52365 m
.33591 .52451 L
s
1 .023 0 r
.79423 .49198 m
.7941 .49214 L
s
.79401 .49191 m
.79423 .49198 L
s
.79401 .49191 m
.7941 .49214 L
s
.973 1 0 r
.56048 .55756 m
.55657 .55521 L
s
.55657 .55521 m
.56037 .54668 L
s
.55657 .55521 m
.55287 .54906 L
s
.56037 .54668 m
.5643 .549 L
s
.56037 .54668 m
.55287 .54906 L
s
1 .009 0 r
.15485 .49157 m
.15487 .49157 L
s
.15488 .49148 m
.15485 .49157 L
s
.15485 .49157 m
.15482 .49151 L
s
.15493 .49154 m
.15485 .49157 L
s
.15495 .49135 m
.15485 .49157 L
s
.15488 .49148 m
.15482 .49151 L
s
.15493 .49154 m
.15488 .49148 L
s
.15487 .49157 m
.15493 .49154 L
s
.15482 .49151 m
.15487 .49157 L
s
1 .575 0 r
.38971 .58642 m
.39296 .58738 L
s
.39321 .58122 m
.38971 .58642 L
s
.38971 .58642 m
.39026 .58287 L
s
.39591 .58572 m
.38971 .58642 L
s
.40669 .57574 m
.38971 .58642 L
s
1 .026 0 r
.5393 .23835 m
.53931 .23836 L
s
.53931 .23811 m
.5393 .23835 L
s
.53954 .23824 m
.5393 .23835 L
s
.53932 .23812 m
.53931 .23811 L
s
.53931 .23811 m
.53954 .23824 L
s
1 .65 0 r
.64898 .58868 m
.64508 .58632 L
s
.64508 .58632 m
.64626 .58231 L
s
1 .026 0 r
.53954 .23824 m
.53931 .23836 L
s
.53932 .23812 m
.53954 .23824 L
s
.53837 .2382 m
.53954 .23824 L
s
1 .002 0 r
.7909 .30152 m
.7909 .30153 L
s
.7909 .30151 m
.7909 .30152 L
s
.7909 .30152 m
.79089 .30152 L
s
.7909 .30151 m
.7909 .30152 L
s
.79086 .30149 m
.7909 .30152 L
s
.7909 .30151 m
.79089 .30152 L
s
.7909 .30151 m
.7909 .30151 L
s
.79089 .30152 m
.7909 .30153 L
s
.7909 .30153 m
.7909 .30151 L
s
.47284 .39644 m
.47284 .39644 L
s
.47284 .39644 m
.47284 .39642 L
s
.47284 .39644 m
.47283 .39644 L
s
.47284 .39642 m
.47284 .39643 L
s
.47284 .39642 m
.47283 .39644 L
s
.47283 .39644 m
.47284 .39644 L
s
.47283 .39644 m
.47284 .39643 L
s
.47291 .39642 m
.47283 .39644 L
s
.47284 .39643 m
.47284 .39644 L
s
1 .02 0 r
.7254 .45971 m
.72488 .4593 L
s
1 0 0 r
.22041 .33314 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
1 .026 0 r
.53931 .23836 m
.53932 .23812 L
s
1 .02 0 r
.72498 .45928 m
.72509 .45933 L
s
.72488 .45943 m
.72498 .45928 L
s
.72498 .45928 m
.72488 .4593 L
s
.72499 .45948 m
.72488 .45943 L
s
.72488 .45943 m
.72488 .4593 L
s
.72509 .45933 m
.72499 .45948 L
s
.72488 .4593 m
.72509 .45933 L
s
.72488 .4593 m
.72499 .45948 L
s
1 .39 0 r
.43874 .52235 m
.43995 .52567 L
s
1 .575 0 r
.39321 .58122 m
.39026 .58287 L
s
.39591 .58572 m
.39321 .58122 L
s
.39296 .58738 m
.39591 .58572 L
s
1 .007 0 r
.72195 .26872 m
.72198 .26873 L
s
.72198 .26866 m
.72195 .26872 L
s
.72203 .26872 m
.72195 .26872 L
s
.72203 .26872 m
.72198 .26873 L
s
.72198 .26866 m
.72203 .26872 L
s
.72201 .26867 m
.72203 .26872 L
s
.72178 .2686 m
.72203 .26872 L
s
.72201 .26867 m
.72198 .26866 L
s
.72198 .26873 m
.72201 .26867 L
s
1 .002 0 r
.08545 .45863 m
.08545 .45863 L
s
.08546 .45861 m
.08545 .45863 L
s
.08545 .45863 m
.08544 .45862 L
s
.08547 .45862 m
.08545 .45863 L
s
.08547 .45858 m
.08545 .45863 L
s
.08546 .45861 m
.08544 .45862 L
s
.08547 .45862 m
.08546 .45861 L
s
.08545 .45863 m
.08547 .45862 L
s
.08544 .45862 m
.08545 .45863 L
s
1 .035 0 r
.47041 .20527 m
.47037 .20528 L
s
.47037 .20495 m
.47041 .20527 L
s
.47068 .20508 m
.47041 .20527 L
s
.808 1 0 r
.59078 .58524 m
.54691 .56774 L
s
1 .01 0 r
.65628 .42692 m
.65591 .42675 L
s
1 .035 0 r
.46913 .20527 m
.47068 .20508 L
s
1 0 0 r
.40363 .36359 m
.40363 .36359 L
s
1 .035 0 r
.47033 .20496 m
.47037 .20495 L
s
.47037 .20495 m
.47068 .20508 L
s
1 .01 0 r
.65599 .42684 m
.65594 .42682 L
s
.65594 .42682 m
.65598 .42673 L
s
.65594 .42682 m
.65591 .42675 L
s
.65598 .42673 m
.65603 .42675 L
s
.65598 .42673 m
.65591 .42675 L
s
.65603 .42675 m
.65599 .42684 L
s
.65591 .42675 m
.65599 .42684 L
s
.65591 .42675 m
.65603 .42675 L
s
1 .035 0 r
.47068 .20508 m
.47037 .20528 L
s
.47033 .20496 m
.47068 .20508 L
s
.973 1 0 r
.47519 .55337 m
.48439 .55864 L
s
.47519 .55337 m
.48415 .5494 L
s
.52153 .5525 m
.47519 .55337 L
s
1 .035 0 r
.47037 .20528 m
.47033 .20496 L
s
1 .026 0 r
.2682 .48974 m
.2683 .48975 L
s
.26832 .48948 m
.2682 .48974 L
s
.2682 .48974 m
.26815 .48956 L
s
.26846 .48967 m
.2682 .48974 L
s
.26872 .48913 m
.2682 .48974 L
s
.26832 .48948 m
.26815 .48956 L
s
.26846 .48967 m
.26832 .48948 L
s
.2683 .48975 m
.26846 .48967 L
s
.26815 .48956 m
.2683 .48975 L
s
1 .018 0 r
.65317 .23591 m
.65323 .23593 L
s
.65322 .23575 m
.65317 .23591 L
s
.65337 .23588 m
.65317 .23591 L
s
.65327 .23576 m
.65322 .23575 L
s
.65322 .23575 m
.65337 .23588 L
s
.65337 .23588 m
.65323 .23593 L
s
.65327 .23576 m
.65337 .23588 L
s
.65262 .23566 m
.65337 .23588 L
s
.65323 .23593 m
.65327 .23576 L
s
1 .006 0 r
.83989 .45745 m
.83979 .45731 L
s
1 .002 0 r
.58708 .39408 m
.587 .39407 L
s
1 0 0 r
.33426 .33071 m
.33427 .33071 L
s
1 .038 0 r
.3998 .17229 m
.40137 .17188 L
s
1 0 0 r
.33427 .33071 m
.33427 .33071 L
s
.33427 .33071 m
.33427 .33071 L
s
.33427 .33071 m
.33427 .33071 L
s
1 .002 0 r
.58702 .39408 m
.58701 .39408 L
s
.58701 .39408 m
.58702 .39406 L
s
.58701 .39408 m
.587 .39407 L
s
1 0 0 r
.33427 .33071 m
.33427 .33071 L
s
.33427 .33071 m
.33427 .33071 L
s
1 .002 0 r
.58702 .39406 m
.58702 .39406 L
s
.58702 .39406 m
.587 .39407 L
s
1 0 0 r
.33427 .33071 m
.33427 .33071 L
s
.33427 .33071 m
.33427 .33071 L
s
.33427 .33071 m
.33427 .33071 L
s
1 .002 0 r
.587 .39407 m
.58702 .39408 L
s
.587 .39407 m
.58702 .39406 L
s
.58702 .39406 m
.58702 .39408 L
s
1 .006 0 r
.83981 .45731 m
.83984 .45733 L
s
.83977 .45735 m
.83981 .45731 L
s
.83981 .45731 m
.83979 .45731 L
s
.83981 .45737 m
.83977 .45735 L
s
.83977 .45735 m
.83979 .45731 L
s
1 .65 0 r
.65262 .58409 m
.64898 .58868 L
s
.64626 .58231 m
.65262 .58409 L
s
1 .006 0 r
.83984 .45733 m
.83981 .45737 L
s
.83979 .45731 m
.83984 .45733 L
s
.83979 .45731 m
.83981 .45737 L
s
1 .038 0 r
.40115 .17212 m
.40105 .17214 L
s
.40106 .17179 m
.40115 .17212 L
s
.40137 .17188 m
.40115 .17212 L
s
.40096 .1718 m
.40106 .17179 L
s
.40106 .17179 m
.40137 .17188 L
s
.40137 .17188 m
.40105 .17214 L
s
.40096 .1718 m
.40137 .17188 L
s
.40105 .17214 m
.40096 .1718 L
s
1 .09 0 r
.37991 .48854 m
.38046 .48868 L
s
.3805 .48775 m
.37991 .48854 L
s
.37991 .48854 m
.38007 .48796 L
s
.38089 .48847 m
.37991 .48854 L
s
.38277 .48691 m
.37991 .48854 L
s
.38046 .48868 m
.38089 .48847 L
s
.38089 .48847 m
.3805 .48775 L
s
.3805 .48775 m
.38007 .48796 L
s
1 .65 0 r
.64626 .58231 m
.64898 .58868 L
s
1 .033 0 r
.58451 .20298 m
.58456 .20299 L
s
.58455 .20267 m
.58451 .20298 L
s
.58485 .20287 m
.58451 .20298 L
s
.5846 .20268 m
.58455 .20267 L
s
.58455 .20267 m
.58485 .20287 L
s
.58485 .20287 m
.58456 .20299 L
s
.5846 .20268 m
.58485 .20287 L
s
.58337 .20268 m
.58485 .20287 L
s
1 .005 0 r
.19913 .45644 m
.19915 .45645 L
s
.19915 .45639 m
.19913 .45644 L
s
.19913 .45644 m
.19912 .45641 L
s
.19918 .45643 m
.19913 .45644 L
s
.19922 .45632 m
.19913 .45644 L
s
.19915 .45639 m
.19912 .45641 L
s
.19918 .45643 m
.19915 .45639 L
s
.19915 .45645 m
.19918 .45643 L
s
.19912 .45641 m
.19915 .45645 L
s
1 .033 0 r
.58456 .20299 m
.5846 .20268 L
s
1 .318 0 r
.70517 .58313 m
.69907 .57601 L
s
1 .003 0 r
.77076 .42461 m
.77068 .42454 L
s
1 0 0 r
.51778 .3612 m
.51778 .3612 L
s
1 .002 0 r
.2648 .2978 m
.26485 .29776 L
s
.26484 .29776 m
.26485 .29777 L
s
.26483 .29777 m
.26484 .29776 L
s
.26484 .29776 m
.26485 .29776 L
s
.26485 .29777 m
.26484 .29778 L
s
.26485 .29776 m
.26485 .29777 L
s
.26484 .29778 m
.26483 .29777 L
s
.26483 .29777 m
.26485 .29776 L
s
.26485 .29776 m
.26484 .29778 L
s
1 .003 0 r
.77069 .42454 m
.77071 .42455 L
s
.77068 .42457 m
.77069 .42454 L
s
.77069 .42454 m
.77068 .42454 L
s
.7707 .42457 m
.77068 .42457 L
s
.77068 .42457 m
.77068 .42454 L
s
.77071 .42455 m
.7707 .42457 L
s
.77068 .42454 m
.77071 .42455 L
s
.77068 .42454 m
.7707 .42457 L
s
1 .09 0 r
.38007 .48796 m
.38046 .48868 L
s
1 .575 0 r
.39026 .58287 m
.39296 .58738 L
s
1 .022 0 r
.06395 .58262 m
.06394 .58263 L
s
.06397 .5824 m
.06395 .58262 L
s
.06395 .58262 m
.06382 .58249 L
s
.0641 .58253 m
.06395 .58262 L
s
.064 .58208 m
.06395 .58262 L
s
.06397 .5824 m
.06382 .58249 L
s
.0641 .58253 m
.06397 .5824 L
s
.06394 .58263 m
.0641 .58253 L
s
.06382 .58249 m
.06394 .58263 L
s
1 .01 0 r
.76748 .23329 m
.76742 .2333 L
s
.76741 .23321 m
.76748 .23329 L
s
.76748 .23329 m
.76738 .23329 L
s
.76746 .23322 m
.76748 .23329 L
s
.76716 .23311 m
.76748 .23329 L
s
.76738 .23329 m
.76742 .2333 L
s
.76741 .23321 m
.76738 .23329 L
s
.76746 .23322 m
.76741 .23321 L
s
1 .045 0 r
.51567 .16983 m
.51566 .16984 L
s
.51566 .16941 m
.51567 .16983 L
s
.51607 .16961 m
.51567 .16983 L
s
1 .01 0 r
.76742 .2333 m
.76746 .23322 L
s
1 .045 0 r
.51565 .16942 m
.51566 .16941 L
s
.51566 .16941 m
.51607 .16961 L
s
.973 1 0 r
.48415 .5494 m
.48439 .55864 L
s
1 .001 0 r
.12962 .42348 m
.12962 .42348 L
s
.12962 .42347 m
.12962 .42348 L
s
.12962 .42348 m
.12962 .42347 L
s
.12963 .42348 m
.12962 .42348 L
s
.12963 .42346 m
.12962 .42348 L
s
.12962 .42347 m
.12962 .42347 L
s
.12963 .42348 m
.12962 .42347 L
s
.12962 .42348 m
.12963 .42348 L
s
.12962 .42347 m
.12962 .42348 L
s
1 .459 0 r
.63591 .55036 m
.62121 .54219 L
s
1 .001 0 r
.70153 .39173 m
.70151 .39172 L
s
1 .045 0 r
.51403 .16966 m
.51607 .16961 L
s
1 .001 0 r
.4484 .32829 m
.44843 .32828 L
s
.44843 .32828 m
.44842 .32828 L
s
.44842 .32828 m
.44843 .32828 L
s
.44843 .32828 m
.44843 .32828 L
s
.44842 .32828 m
.44842 .32828 L
s
.44842 .32828 m
.44843 .32828 L
s
.44843 .32828 m
.44842 .32828 L
s
.44842 .32828 m
.44843 .32828 L
s
.70152 .39173 m
.70151 .39173 L
s
.70151 .39173 m
.70152 .39172 L
s
.70151 .39173 m
.70151 .39172 L
s
.70152 .39172 m
.70152 .39172 L
s
.70152 .39172 m
.70151 .39172 L
s
.44842 .32828 m
.44842 .32828 L
s
.70152 .39172 m
.70152 .39173 L
s
.70151 .39172 m
.70152 .39173 L
s
.70151 .39172 m
.70152 .39172 L
s
1 .045 0 r
.51607 .16961 m
.51566 .16984 L
s
.51565 .16942 m
.51607 .16961 L
s
.542 1 0 r
.59844 .58194 m
.59021 .59227 L
s
.58402 .57794 m
.59844 .58194 L
s
1 .045 0 r
.51566 .16984 m
.51565 .16942 L
s
1 .168 0 r
.28954 .58175 m
.29 .58187 L
s
.29013 .58007 m
.28954 .58175 L
s
.28954 .58175 m
.28904 .58072 L
s
.29109 .58123 m
.28954 .58175 L
s
.29217 .57786 m
.28954 .58175 L
s
1 .215 0 r
.48944 .4866 m
.48971 .4863 L
s
.48971 .4863 m
.48947 .48436 L
s
.48971 .4863 m
.48754 .48568 L
s
1 .168 0 r
.29013 .58007 m
.28904 .58072 L
s
.29109 .58123 m
.29013 .58007 L
s
1 .016 0 r
.31283 .45438 m
.31291 .4544 L
s
.31292 .45424 m
.31283 .45438 L
s
.31283 .45438 m
.31283 .45428 L
s
.313 .45436 m
.31283 .45438 L
s
.31325 .45405 m
.31283 .45438 L
s
.31292 .45424 m
.31283 .45428 L
s
.313 .45436 m
.31292 .45424 L
s
.31291 .4544 m
.313 .45436 L
s
1 .055 0 r
.17751 .58131 m
.17757 .58134 L
s
.17763 .58075 m
.17751 .58131 L
s
.17751 .58131 m
.17724 .58099 L
s
.17795 .5811 m
.17751 .58131 L
s
.17794 .57997 m
.17751 .58131 L
s
1 .215 0 r
.48947 .48436 m
.48919 .48467 L
s
.48947 .48436 m
.48754 .48568 L
s
1 .022 0 r
.6985 .20043 m
.69857 .20045 L
s
.69856 .20024 m
.6985 .20043 L
s
.69874 .20041 m
.6985 .20043 L
s
.69864 .20026 m
.69856 .20024 L
s
.69856 .20024 m
.69874 .20041 L
s
.69874 .20041 m
.69857 .20045 L
s
.69864 .20026 m
.69874 .20041 L
s
.6979 .20009 m
.69874 .20041 L
s
1 .016 0 r
.31283 .45428 m
.31291 .4544 L
s
1 .168 0 r
.29 .58187 m
.29109 .58123 L
s
1 .055 0 r
.17763 .58075 m
.17724 .58099 L
s
.17795 .5811 m
.17763 .58075 L
s
1 .022 0 r
.69857 .20045 m
.69864 .20026 L
s
1 .055 0 r
.17757 .58134 m
.17795 .5811 L
s
.973 1 0 r
.5643 .549 m
.56048 .55756 L
s
.55287 .54906 m
.56048 .55756 L
s
1 .091 0 r
.81985 .58103 m
.81891 .57884 L
s
1 .457 0 r
.56655 .51754 m
.54675 .51409 L
s
1 0 0 r
.63222 .35881 m
.63222 .35881 L
s
1 .003 0 r
.37892 .29532 m
.37905 .29528 L
s
1 .05 0 r
.4446 .1366 m
.44678 .13625 L
s
1 .003 0 r
.37904 .2953 m
.37903 .2953 L
s
.37903 .29527 m
.37904 .2953 L
s
.37905 .29528 m
.37904 .2953 L
s
.37902 .29527 m
.37903 .29527 L
s
.37903 .29527 m
.37905 .29528 L
s
1 .055 0 r
.17724 .58099 m
.17757 .58134 L
s
1 .003 0 r
.37905 .29528 m
.37903 .2953 L
s
.37902 .29527 m
.37905 .29528 L
s
.37903 .2953 m
.37902 .29527 L
s
1 .05 0 r
.44642 .13655 m
.44634 .13655 L
s
.44635 .13609 m
.44642 .13655 L
s
.44678 .13625 m
.44642 .13655 L
s
.44627 .1361 m
.44635 .13609 L
s
.44635 .13609 m
.44678 .13625 L
s
1 .215 0 r
.48754 .48568 m
.48944 .4866 L
s
.48754 .48568 m
.48919 .48467 L
s
.49711 .48468 m
.48754 .48568 L
s
.973 1 0 r
.55287 .54906 m
.5643 .549 L
s
0 1 .511 r
.43697 .58075 m
.45864 .59787 L
s
.43697 .58075 m
.4632 .57563 L
s
1 .05 0 r
.44678 .13625 m
.44634 .13655 L
s
.44627 .1361 m
.44678 .13625 L
s
1 .168 0 r
.28904 .58072 m
.29 .58187 L
s
1 .05 0 r
.44634 .13655 m
.44627 .1361 L
s
.542 1 0 r
.58402 .57794 m
.59021 .59227 L
s
1 .038 0 r
.62975 .16746 m
.62983 .16747 L
s
.62982 .16712 m
.62975 .16746 L
s
.63015 .16737 m
.62975 .16746 L
s
.62991 .16713 m
.62982 .16712 L
s
.62982 .16712 m
.63015 .16737 L
s
.63015 .16737 m
.62983 .16747 L
s
.62991 .16713 m
.63015 .16737 L
s
.62854 .16702 m
.63015 .16737 L
s
1 .215 0 r
.48919 .48467 m
.48944 .4866 L
s
1 .038 0 r
.62983 .16747 m
.62991 .16713 L
s
1 .002 0 r
.2436 .4212 m
.24361 .4212 L
s
.24361 .42117 m
.2436 .4212 L
s
.2436 .4212 m
.2436 .42118 L
s
.24363 .42119 m
.2436 .4212 L
s
.24365 .42115 m
.2436 .4212 L
s
.24361 .42117 m
.2436 .42118 L
s
.24363 .42119 m
.24361 .42117 L
s
.24361 .4212 m
.24363 .42119 L
s
.2436 .42118 m
.24361 .4212 L
s
1 .001 0 r
.56286 .32586 m
.56286 .32586 L
s
.56286 .32585 m
.56286 .32586 L
s
.56287 .32585 m
.56286 .32586 L
s
.56286 .32585 m
.56286 .32585 L
s
.56286 .32585 m
.56287 .32585 L
s
.56287 .32585 m
.56286 .32586 L
s
.56286 .32585 m
.56287 .32585 L
s
.56283 .32585 m
.56287 .32585 L
s
.56286 .32586 m
.56286 .32585 L
s
1 0 0 r
.81629 .38938 m
.81628 .38938 L
s
1 .121 0 r
.75058 .54821 m
.74833 .54543 L
s
1 .006 0 r
.30936 .26232 m
.30956 .26222 L
s
1 0 0 r
.81628 .38938 m
.81629 .38938 L
s
.81628 .38938 m
.81628 .38938 L
s
.81628 .38938 m
.81628 .38938 L
s
.81628 .38938 m
.81628 .38938 L
s
.81628 .38938 m
.81628 .38938 L
s
.81629 .38938 m
.81628 .38938 L
s
.81628 .38938 m
.81629 .38938 L
s
.81628 .38938 m
.81628 .38938 L
s
1 .457 0 r
.55074 .51718 m
.54985 .51644 L
s
.54985 .51644 m
.5507 .51238 L
s
.54985 .51644 m
.54675 .51409 L
s
1 .006 0 r
.30954 .26226 m
.30952 .26227 L
s
.30952 .26221 m
.30954 .26226 L
s
.30956 .26222 m
.30954 .26226 L
s
.30949 .26222 m
.30952 .26221 L
s
.30952 .26221 m
.30956 .26222 L
s
.30952 .26227 m
.30949 .26222 L
s
.30956 .26222 m
.30952 .26227 L
s
.30949 .26222 m
.30956 .26222 L
s
1 .457 0 r
.5507 .51238 m
.55159 .51312 L
s
.5507 .51238 m
.54675 .51409 L
s
1 .048 0 r
.42607 .45253 m
.42623 .45244 L
s
.42623 .45244 m
.42608 .45203 L
s
.42623 .45244 m
.4257 .4524 L
s
1 .091 0 r
.81905 .57879 m
.81967 .57917 L
s
.81852 .57938 m
.81905 .57879 L
s
.81905 .57879 m
.81891 .57884 L
s
1 .048 0 r
.42608 .45203 m
.42592 .45211 L
s
.42608 .45203 m
.4257 .4524 L
s
.4257 .4524 m
.42607 .45253 L
s
.4257 .4524 m
.42592 .45211 L
s
.42758 .45177 m
.4257 .4524 L
s
1 .019 0 r
.10807 .54761 m
.10809 .54762 L
s
.10811 .54741 m
.10807 .54761 L
s
.10807 .54761 m
.10797 .5475 L
s
.10823 .54754 m
.10807 .54761 L
s
.1082 .54713 m
.10807 .54761 L
s
1 .091 0 r
.81914 .57976 m
.81852 .57938 L
s
.81852 .57938 m
.81891 .57884 L
s
1 .525 0 r
.43513 .54865 m
.43691 .54758 L
s
.43691 .54758 m
.43528 .54308 L
s
.43691 .54758 m
.43109 .54716 L
s
1 .019 0 r
.10811 .54741 m
.10797 .5475 L
s
.10823 .54754 m
.10811 .54741 L
s
.10809 .54762 m
.10823 .54754 L
s
.10797 .5475 m
.10809 .54762 L
s
1 .048 0 r
.42592 .45211 m
.42607 .45253 L
s
1 .051 0 r
.56091 .13428 m
.56095 .13428 L
s
.56094 .1338 m
.56091 .13428 L
s
.56141 .13407 m
.56091 .13428 L
s
1 .091 0 r
.81967 .57917 m
.81914 .57976 L
s
.81891 .57884 m
.81967 .57917 L
s
1 .051 0 r
.56098 .1338 m
.56094 .1338 L
s
.56094 .1338 m
.56141 .13407 L
s
1 .525 0 r
.43528 .54308 m
.43349 .54414 L
s
.43528 .54308 m
.43109 .54716 L
s
1 .051 0 r
.56141 .13407 m
.56095 .13428 L
s
.56098 .1338 m
.56141 .13407 L
s
.55909 .13392 m
.56141 .13407 L
s
1 .091 0 r
.81891 .57884 m
.81914 .57976 L
s
1 .525 0 r
.43109 .54716 m
.43513 .54865 L
s
.43109 .54716 m
.43349 .54414 L
s
.45172 .54064 m
.43109 .54716 L
s
1 .005 0 r
.49352 .29285 m
.49352 .29286 L
s
.49352 .29281 m
.49352 .29285 L
s
.49356 .29283 m
.49352 .29285 L
s
1 0 0 r
.17396 .38821 m
.17396 .38821 L
s
.17396 .3882 m
.17396 .38821 L
s
.17396 .38821 m
.17396 .3882 L
s
.17396 .3882 m
.17396 .38821 L
s
.17396 .3882 m
.17396 .38821 L
s
.17396 .3882 m
.17396 .3882 L
s
.17396 .3882 m
.17396 .3882 L
s
.17396 .38821 m
.17396 .3882 L
s
.17396 .3882 m
.17396 .38821 L
s
1 .005 0 r
.49351 .29281 m
.49352 .29281 L
s
.49352 .29281 m
.49356 .29283 L
s
1 .151 0 r
.68121 .51534 m
.67686 .5124 L
s
1 0 0 r
.74696 .35642 m
.74696 .35642 L
s
1 .005 0 r
.49334 .29285 m
.49356 .29283 L
s
.49356 .29283 m
.49352 .29286 L
s
.49351 .29281 m
.49356 .29283 L
s
.49352 .29286 m
.49351 .29281 L
s
1 .051 0 r
.56095 .13428 m
.56098 .1338 L
s
.808 1 0 r
.4781 .58082 m
.47856 .57877 L
s
.47856 .57877 m
.47828 .56803 L
s
.47856 .57877 m
.46736 .57461 L
s
1 .318 0 r
.70021 .57573 m
.70217 .57688 L
s
.69843 .57799 m
.70021 .57573 L
s
.70021 .57573 m
.69907 .57601 L
s
1 .172 0 r
.33286 .54649 m
.33361 .54667 L
s
.33372 .54484 m
.33286 .54649 L
s
.33286 .54649 m
.33271 .54538 L
s
.33462 .54612 m
.33286 .54649 L
s
.33692 .54281 m
.33286 .54649 L
s
1 .023 0 r
.74394 .16479 m
.74404 .16481 L
s
.74403 .16459 m
.74394 .16479 L
s
.74421 .16477 m
.74394 .16479 L
s
.74421 .16477 m
.74404 .16481 L
s
.74403 .16459 m
.74421 .16477 L
s
.74412 .1646 m
.74421 .16477 L
s
.74334 .16438 m
.74421 .16477 L
s
.74412 .1646 m
.74403 .16459 L
s
1 .121 0 r
.74873 .54534 m
.7495 .54577 L
s
.74806 .5462 m
.74873 .54534 L
s
.74873 .54534 m
.74833 .54543 L
s
1 .053 0 r
.22171 .54625 m
.22182 .54627 L
s
.22188 .54571 m
.22171 .54625 L
s
.22171 .54625 m
.22152 .54591 L
s
.22218 .54607 m
.22171 .54625 L
s
.22242 .54497 m
.22171 .54625 L
s
1 .023 0 r
.74404 .16481 m
.74412 .1646 L
s
1 .172 0 r
.33372 .54484 m
.33271 .54538 L
s
.33462 .54612 m
.33372 .54484 L
s
1 .007 0 r
.03834 .51441 m
.03835 .51441 L
s
.03836 .51435 m
.03834 .51441 L
s
.03834 .51441 m
.03831 .51437 L
s
.03839 .51439 m
.03834 .51441 L
s
.03838 .51425 m
.03834 .51441 L
s
1 .121 0 r
.74882 .54663 m
.74806 .5462 L
s
.74806 .5462 m
.74833 .54543 L
s
1 .007 0 r
.03836 .51435 m
.03831 .51437 L
s
.03839 .51439 m
.03836 .51435 L
s
.03835 .51441 m
.03839 .51439 L
s
1 .318 0 r
.70039 .57914 m
.69843 .57799 L
s
.69843 .57799 m
.69907 .57601 L
s
1 .007 0 r
.03831 .51437 m
.03835 .51441 L
s
1 .006 0 r
.35776 .41894 m
.3578 .41895 L
s
.3578 .41889 m
.35776 .41894 L
s
.35776 .41894 m
.35777 .4189 L
s
.35783 .41894 m
.35776 .41894 L
s
.35796 .41883 m
.35776 .41894 L
s
.3578 .41895 m
.35783 .41894 L
s
.35783 .41894 m
.3578 .41889 L
s
.3578 .41889 m
.35777 .4189 L
s
1 .053 0 r
.22188 .54571 m
.22152 .54591 L
s
.22218 .54607 m
.22188 .54571 L
s
1 .172 0 r
.33361 .54667 m
.33462 .54612 L
s
1 .006 0 r
.35777 .4189 m
.3578 .41895 L
s
1 .053 0 r
.22182 .54627 m
.22218 .54607 L
s
1 0 0 r
.67756 .32342 m
.67756 .32342 L
s
.67756 .32341 m
.67756 .32342 L
s
.67757 .32342 m
.67756 .32342 L
s
.67756 .32341 m
.67756 .32341 L
s
.67756 .32341 m
.67757 .32342 L
s
.67757 .32342 m
.67756 .32342 L
s
.67756 .32341 m
.67757 .32342 L
s
.67755 .32341 m
.67757 .32342 L
s
.67756 .32342 m
.67756 .32341 L
s
1 .038 0 r
.86554 .54605 m
.86513 .54513 L
s
1 .141 0 r
.61175 .48244 m
.60618 .48066 L
s
1 .01 0 r
.42376 .2598 m
.42419 .2597 L
s
.42413 .25976 m
.4241 .25977 L
s
.4241 .25967 m
.42413 .25976 L
s
.42419 .2597 m
.42413 .25976 L
s
.42408 .25968 m
.4241 .25967 L
s
.4241 .25967 m
.42419 .2597 L
s
.42419 .2597 m
.4241 .25977 L
s
.42408 .25968 m
.42419 .2597 L
s
.4241 .25977 m
.42408 .25968 L
s
1 .053 0 r
.22152 .54591 m
.22182 .54627 L
s
1 .457 0 r
.54675 .51409 m
.55074 .51718 L
s
.54675 .51409 m
.55159 .51312 L
s
0 1 .511 r
.4632 .57563 m
.45864 .59787 L
s
.808 1 0 r
.47828 .56803 m
.47781 .57004 L
s
.47828 .56803 m
.46736 .57461 L
s
1 .121 0 r
.7495 .54577 m
.74882 .54663 L
s
.74833 .54543 m
.7495 .54577 L
s
.74833 .54543 m
.74882 .54663 L
s
1 .038 0 r
.86519 .54512 m
.86545 .54527 L
s
.86498 .54537 m
.86519 .54512 L
s
.86519 .54512 m
.86513 .54513 L
s
1 .039 0 r
.67507 .13177 m
.67518 .13179 L
s
.67516 .13142 m
.67507 .13177 L
s
.67549 .1317 m
.67507 .13177 L
s
1 .172 0 r
.33271 .54538 m
.33361 .54667 L
s
1 .039 0 r
.67528 .13144 m
.67516 .13142 L
s
.67516 .13142 m
.67549 .1317 L
s
1 .038 0 r
.86523 .54552 m
.86498 .54537 L
s
.86498 .54537 m
.86513 .54513 L
s
1 .039 0 r
.67549 .1317 m
.67518 .13179 L
s
.67528 .13144 m
.67549 .1317 L
s
.67388 .13123 m
.67549 .1317 L
s
1 .457 0 r
.55159 .51312 m
.55074 .51718 L
s
1 .038 0 r
.86545 .54527 m
.86523 .54552 L
s
.86513 .54513 m
.86545 .54527 L
s
1 .151 0 r
.67769 .5122 m
.67848 .5126 L
s
.67698 .51337 m
.67769 .5122 L
s
.67769 .5122 m
.67686 .5124 L
s
1 .038 0 r
.86513 .54513 m
.86523 .54552 L
s
1 .151 0 r
.67777 .51378 m
.67698 .51337 L
s
.67698 .51337 m
.67686 .5124 L
s
1 .039 0 r
.67518 .13179 m
.67528 .13144 L
s
1 .141 0 r
.60731 .48175 m
.60685 .4815 L
s
.60685 .4815 m
.60728 .48028 L
s
.60685 .4815 m
.60618 .48066 L
s
1 .07 0 r
.53968 .44971 m
.53963 .44963 L
s
.53963 .44963 m
.53967 .44899 L
s
.53963 .44963 m
.53904 .44932 L
s
1 .459 0 r
.62409 .54139 m
.62627 .54258 L
s
.62205 .54508 m
.62409 .54139 L
s
.62409 .54139 m
.62121 .54219 L
s
.62423 .54627 m
.62205 .54508 L
s
.62205 .54508 m
.62121 .54219 L
s
1 .141 0 r
.60728 .48028 m
.60775 .48053 L
s
.60728 .48028 m
.60618 .48066 L
s
1 .318 0 r
.70217 .57688 m
.70039 .57914 L
s
.69907 .57601 m
.70217 .57688 L
s
0 .197 1 r
.50466 .51447 m
.52635 .52774 L
s
.48289 .5414 m
.50466 .51447 L
s
.50466 .51447 m
.48759 .51676 L
s
1 .07 0 r
.53967 .44899 m
.53972 .44908 L
s
.53967 .44899 m
.53904 .44932 L
s
1 .004 0 r
.60818 .29041 m
.60819 .29041 L
s
.60819 .29037 m
.60818 .29041 L
s
.60822 .2904 m
.60818 .29041 L
s
.6082 .29037 m
.60819 .29037 L
s
.60819 .29037 m
.60822 .2904 L
s
.60822 .2904 m
.60819 .29041 L
s
.6082 .29037 m
.60822 .2904 L
s
.60804 .29036 m
.60822 .2904 L
s
.60819 .29041 m
.6082 .29037 L
s
1 0 0 r
.28825 .38585 m
.28825 .38585 L
s
.28825 .38584 m
.28825 .38585 L
s
.28825 .38585 m
.28825 .38584 L
s
.28825 .38585 m
.28825 .38585 L
s
.28826 .38584 m
.28825 .38585 L
s
.28825 .38584 m
.28825 .38584 L
s
.28825 .38585 m
.28825 .38584 L
s
.28825 .38585 m
.28825 .38585 L
s
.28825 .38584 m
.28825 .38585 L
s
1 .042 0 r
.79616 .51315 m
.7954 .51216 L
s
1 .07 0 r
.54221 .44949 m
.53904 .44932 L
s
1 .013 0 r
.35409 .22671 m
.3546 .22651 L
s
.35455 .2266 m
.3545 .22662 L
s
.35451 .22649 m
.35455 .2266 L
s
.3546 .22651 m
.35455 .2266 L
s
.35446 .2265 m
.35451 .22649 L
s
.35451 .22649 m
.3546 .22651 L
s
.3546 .22651 m
.3545 .22662 L
s
.35446 .2265 m
.3546 .22651 L
s
1 .07 0 r
.53904 .44932 m
.53968 .44971 L
s
.53904 .44932 m
.53972 .44908 L
s
1 .013 0 r
.3545 .22662 m
.35446 .2265 L
s
1 .318 0 r
.69907 .57601 m
.70039 .57914 L
s
1 .07 0 r
.53972 .44908 m
.53968 .44971 L
s
1 .151 0 r
.67848 .5126 m
.67777 .51378 L
s
.67686 .5124 m
.67848 .5126 L
s
1 .525 0 r
.43349 .54414 m
.43513 .54865 L
s
1 .151 0 r
.67686 .5124 m
.67777 .51378 L
s
1 .141 0 r
.60618 .48066 m
.60731 .48175 L
s
.60618 .48066 m
.60775 .48053 L
s
1 .042 0 r
.79553 .51213 m
.7958 .51228 L
s
.7953 .51243 m
.79553 .51213 L
s
.79553 .51213 m
.7954 .51216 L
s
1 .141 0 r
.60775 .48053 m
.60731 .48175 L
s
1 .016 0 r
.15239 .51244 m
.15242 .51245 L
s
.15244 .51228 m
.15239 .51244 L
s
.15239 .51244 m
.15233 .51234 L
s
.15253 .51239 m
.15239 .51244 L
s
.15258 .51204 m
.15239 .51244 L
s
1 .042 0 r
.79557 .51258 m
.7953 .51243 L
s
.7953 .51243 m
.7954 .51216 L
s
1 .016 0 r
.15244 .51228 m
.15233 .51234 L
s
.15253 .51239 m
.15244 .51228 L
s
.15242 .51245 m
.15253 .51239 L
s
.15233 .51234 m
.15242 .51245 L
s
1 .042 0 r
.7958 .51228 m
.79557 .51258 L
s
.7954 .51216 m
.7958 .51228 L
s
.7954 .51216 m
.79557 .51258 L
s
1 .014 0 r
.47207 .41665 m
.4721 .41664 L
s
.4721 .41664 m
.47208 .41651 L
s
.4721 .41664 m
.47195 .4166 L
s
.47208 .41651 m
.47205 .41653 L
s
.47208 .41651 m
.47195 .4166 L
s
.47195 .4166 m
.47207 .41665 L
s
.47195 .4166 m
.47205 .41653 L
s
.47257 .4165 m
.47195 .4166 L
s
1 .012 0 r
.53888 .25733 m
.53888 .25734 L
s
.53888 .25722 m
.53888 .25733 L
s
.53899 .25729 m
.53888 .25733 L
s
.53888 .25723 m
.53888 .25722 L
s
.53888 .25722 m
.53899 .25729 L
s
1 .014 0 r
.47205 .41653 m
.47207 .41665 L
s
1 .012 0 r
.53899 .25729 m
.53888 .25734 L
s
.53888 .25723 m
.53899 .25729 L
s
.53845 .25727 m
.53899 .25729 L
s
1 0 0 r
.79257 .32097 m
.79257 .32097 L
s
.79257 .32097 m
.79257 .32097 L
s
.79257 .32097 m
.79257 .32097 L
s
.79257 .32097 m
.79257 .32097 L
s
.79256 .32096 m
.79257 .32097 L
s
.79257 .32097 m
.79257 .32097 L
s
.79257 .32097 m
.79257 .32097 L
s
.79257 .32097 m
.79257 .32097 L
s
.79257 .32097 m
.79257 .32097 L
s
1 .043 0 r
.72668 .4802 m
.72555 .47931 L
s
1 0 0 r
.21846 .35281 m
.21846 .35281 L
s
1 .012 0 r
.53888 .25734 m
.53888 .25723 L
s
0 .434 1 r
.5291 .51165 m
.50872 .5369 L
s
.49314 .50136 m
.5291 .51165 L
s
1 .043 0 r
.72576 .47927 m
.726 .47938 L
s
.72555 .47959 m
.72576 .47927 L
s
.72576 .47927 m
.72555 .47931 L
s
.72579 .47971 m
.72555 .47959 L
s
.72555 .47959 m
.72555 .47931 L
s
.726 .47938 m
.72579 .47971 L
s
.72555 .47931 m
.726 .47938 L
s
.72555 .47931 m
.72579 .47971 L
s
.808 1 0 r
.55582 .57768 m
.55126 .57486 L
s
.55126 .57486 m
.5557 .56488 L
s
.55126 .57486 m
.54691 .56774 L
s
1 .005 0 r
.0826 .47919 m
.08261 .47919 L
s
.08261 .47914 m
.0826 .47919 L
s
.0826 .47919 m
.08258 .47916 L
s
.08264 .47917 m
.0826 .47919 L
s
.08265 .47907 m
.0826 .47919 L
s
.08261 .47914 m
.08258 .47916 L
s
.08264 .47917 m
.08261 .47914 L
s
.08261 .47919 m
.08264 .47917 L
s
.08258 .47916 m
.08261 .47919 L
s
1 .002 0 r
.7231 .28791 m
.72311 .28791 L
s
.72311 .28789 m
.7231 .28791 L
s
.72312 .28791 m
.7231 .28791 L
s
.72312 .28791 m
.72311 .28791 L
s
.72311 .28789 m
.72312 .28791 L
s
.72312 .28789 m
.72312 .28791 L
s
.72305 .28787 m
.72312 .28791 L
s
.72312 .28789 m
.72311 .28789 L
s
.72311 .28791 m
.72312 .28789 L
s
1 .001 0 r
.40282 .38349 m
.40282 .38348 L
s
.40282 .38348 m
.40282 .38348 L
s
.40282 .38348 m
.40281 .38348 L
s
.40282 .38348 m
.40282 .38348 L
s
.40282 .38348 m
.40281 .38348 L
s
.40281 .38348 m
.40282 .38349 L
s
.40281 .38348 m
.40282 .38348 L
s
.40285 .38347 m
.40281 .38348 L
s
.40282 .38348 m
.40282 .38349 L
s
1 .019 0 r
.46948 .22414 m
.46946 .22414 L
s
.46946 .22396 m
.46948 .22414 L
s
.46963 .22403 m
.46948 .22414 L
s
1 .032 0 r
.65712 .44721 m
.65597 .4467 L
s
1 .019 0 r
.46877 .22414 m
.46963 .22403 L
s
.46943 .22397 m
.46946 .22396 L
s
.46946 .22396 m
.46963 .22403 L
s
1 .047 0 r
.26615 .51091 m
.26631 .51094 L
s
.26635 .51045 m
.26615 .51091 L
s
.26615 .51091 m
.26606 .5106 L
s
.26661 .51078 m
.26615 .51091 L
s
.26707 .50984 m
.26615 .51091 L
s
.808 1 0 r
.46736 .57461 m
.4781 .58082 L
s
.46736 .57461 m
.47781 .57004 L
s
.52151 .57361 m
.46736 .57461 L
s
1 .019 0 r
.46963 .22403 m
.46946 .22414 L
s
.46943 .22397 m
.46963 .22403 L
s
1 .047 0 r
.26635 .51045 m
.26606 .5106 L
s
.26661 .51078 m
.26635 .51045 L
s
1 .019 0 r
.46946 .22414 m
.46943 .22397 L
s
1 .047 0 r
.26631 .51094 m
.26661 .51078 L
s
.808 1 0 r
.5557 .56488 m
.56028 .56767 L
s
.5557 .56488 m
.54691 .56774 L
s
1 .459 0 r
.62627 .54258 m
.62423 .54627 L
s
.62121 .54219 m
.62627 .54258 L
s
.62121 .54219 m
.62423 .54627 L
s
1 .032 0 r
.65621 .44697 m
.65607 .4469 L
s
.65607 .4469 m
.65619 .44663 L
s
.65607 .4469 m
.65597 .4467 L
s
.65619 .44663 m
.65633 .4467 L
s
.65619 .44663 m
.65597 .4467 L
s
1 .047 0 r
.26606 .5106 m
.26631 .51094 L
s
1 .032 0 r
.65633 .4467 m
.65621 .44697 L
s
.65597 .4467 m
.65621 .44697 L
s
.65597 .4467 m
.65633 .4467 L
s
1 .151 0 r
.37703 .51034 m
.37796 .51059 L
s
.37803 .509 m
.37703 .51034 L
s
.37703 .51034 m
.3773 .50937 L
s
.37869 .51022 m
.37703 .51034 L
s
.38185 .50762 m
.37703 .51034 L
s
.37796 .51059 m
.37869 .51022 L
s
.37869 .51022 m
.37803 .509 L
s
.37803 .509 m
.3773 .50937 L
s
1 .008 0 r
.65369 .25485 m
.65371 .25485 L
s
.65371 .25477 m
.65369 .25485 L
s
.65378 .25483 m
.65369 .25485 L
s
.65373 .25478 m
.65371 .25477 L
s
.65371 .25477 m
.65378 .25483 L
s
.65378 .25483 m
.65371 .25485 L
s
.65373 .25478 m
.65378 .25483 L
s
.65344 .25473 m
.65378 .25483 L
s
.65371 .25485 m
.65373 .25478 L
s
1 .013 0 r
.84191 .47795 m
.84168 .47763 L
s
.58747 .41417 m
.58692 .41407 L
s
1 0 0 r
.33303 .3504 m
.33303 .3504 L
s
1 .023 0 r
.399 .19096 m
.39998 .1907 L
s
1 .013 0 r
.58703 .41416 m
.58701 .41414 L
s
.58701 .41414 m
.58703 .41403 L
s
.58701 .41414 m
.58692 .41407 L
s
.58703 .41403 m
.58706 .41404 L
s
.58703 .41403 m
.58692 .41407 L
s
1 .023 0 r
.39984 .19085 m
.39978 .19086 L
s
.39979 .19064 m
.39984 .19085 L
s
.39998 .1907 m
.39984 .19085 L
s
1 .013 0 r
.58692 .41407 m
.58703 .41416 L
s
.58692 .41407 m
.58706 .41404 L
s
1 .023 0 r
.39972 .19065 m
.39979 .19064 L
s
.39979 .19064 m
.39998 .1907 L
s
1 .013 0 r
.58706 .41404 m
.58703 .41416 L
s
.84172 .47763 m
.84181 .47767 L
s
.84165 .47772 m
.84172 .47763 L
s
.84172 .47763 m
.84168 .47763 L
s
1 .023 0 r
.39998 .1907 m
.39978 .19086 L
s
.39972 .19065 m
.39998 .1907 L
s
1 .013 0 r
.84174 .47776 m
.84165 .47772 L
s
.84165 .47772 m
.84168 .47763 L
s
1 .023 0 r
.39978 .19086 m
.39972 .19065 L
s
1 .013 0 r
.84181 .47767 m
.84174 .47776 L
s
.84168 .47763 m
.84181 .47767 L
s
.84168 .47763 m
.84174 .47776 L
s
0 .197 1 r
.5044 .55497 m
.48289 .5414 L
s
.48289 .5414 m
.48759 .51676 L
s
1 .151 0 r
.3773 .50937 m
.37796 .51059 L
s
1 .012 0 r
.19692 .4771 m
.19696 .47711 L
s
.19697 .47699 m
.19692 .4771 L
s
.19692 .4771 m
.19689 .47703 L
s
.19703 .47707 m
.19692 .4771 L
s
.19712 .47682 m
.19692 .4771 L
s
.19697 .47699 m
.19689 .47703 L
s
.19703 .47707 m
.19697 .47699 L
s
.19696 .47711 m
.19703 .47707 L
s
.19689 .47703 m
.19696 .47711 L
s
1 .018 0 r
.58437 .22172 m
.5844 .22173 L
s
.5844 .22155 m
.58437 .22172 L
s
.58456 .22166 m
.58437 .22172 L
s
.58442 .22156 m
.5844 .22155 L
s
.5844 .22155 m
.58456 .22166 L
s
.58456 .22166 m
.5844 .22173 L
s
.58442 .22156 m
.58456 .22166 L
s
.58374 .22156 m
.58456 .22166 L
s
.5844 .22173 m
.58442 .22156 L
s
1 .001 0 r
.51768 .3811 m
.51768 .3811 L
s
.51768 .3811 m
.51768 .38109 L
s
.51768 .3811 m
.51767 .3811 L
s
.51768 .38109 m
.51768 .38109 L
s
.51768 .38109 m
.51767 .3811 L
s
.51767 .3811 m
.51768 .3811 L
s
.51767 .3811 m
.51768 .38109 L
s
.51773 .3811 m
.51767 .3811 L
s
1 .01 0 r
.77234 .44491 m
.77208 .44469 L
s
1 0 0 r
.26313 .31728 m
.26313 .31728 L
s
.26313 .31728 m
.26313 .31728 L
s
.26313 .31728 m
.26313 .31728 L
s
.26313 .31728 m
.26313 .31728 L
s
.26313 .31728 m
.26313 .31728 L
s
.26313 .31728 m
.26313 .31728 L
s
1 .001 0 r
.51768 .38109 m
.51768 .3811 L
s
1 0 0 r
.26313 .31728 m
.26313 .31728 L
s
.26313 .31728 m
.26313 .31728 L
s
.26313 .31728 m
.26313 .31728 L
s
1 .01 0 r
.77213 .44469 m
.77219 .44471 L
s
.77208 .44476 m
.77213 .44469 L
s
.77213 .44469 m
.77208 .44469 L
s
.77214 .44479 m
.77208 .44476 L
s
.77208 .44476 m
.77208 .44469 L
s
.77219 .44471 m
.77214 .44479 L
s
.77208 .44469 m
.77219 .44471 L
s
.77208 .44469 m
.77214 .44479 L
s
0 .434 1 r
.49314 .50136 m
.50872 .5369 L
s
1 .336 0 r
.48487 .50842 m
.4853 .50792 L
s
.4853 .50792 m
.48492 .50489 L
s
.4853 .50792 m
.48189 .50697 L
s
1 .028 0 r
.51499 .18844 m
.51498 .18845 L
s
.51498 .18818 m
.51499 .18844 L
s
.51524 .18831 m
.51499 .18844 L
s
1 .004 0 r
.76886 .25227 m
.76883 .25228 L
s
.76883 .25224 m
.76886 .25227 L
s
.76886 .25227 m
.76881 .25227 L
s
.76885 .25224 m
.76886 .25227 L
s
.76872 .25219 m
.76886 .25227 L
s
.76881 .25227 m
.76883 .25228 L
s
.76883 .25224 m
.76881 .25227 L
s
.76885 .25224 m
.76883 .25224 L
s
1 .003 0 r
.12705 .44383 m
.12705 .44383 L
s
.12706 .4438 m
.12705 .44383 L
s
.12705 .44383 m
.12704 .44381 L
s
.12707 .44382 m
.12705 .44383 L
s
.12708 .44376 m
.12705 .44383 L
s
1 .028 0 r
.51498 .18818 m
.51498 .18818 L
s
.51498 .18818 m
.51524 .18831 L
s
1 .003 0 r
.12706 .4438 m
.12704 .44381 L
s
.12707 .44382 m
.12706 .4438 L
s
.12705 .44383 m
.12707 .44382 L
s
.12704 .44381 m
.12705 .44383 L
s
1 .004 0 r
.76883 .25228 m
.76885 .25224 L
s
1 .575 0 r
.63662 .57148 m
.61806 .56129 L
s
1 .005 0 r
.70267 .41184 m
.7025 .41175 L
s
1 .028 0 r
.51395 .18833 m
.51524 .18831 L
s
1 0 0 r
.4479 .34798 m
.4479 .34798 L
s
1 .028 0 r
.51524 .18831 m
.51498 .18845 L
s
.51498 .18818 m
.51524 .18831 L
s
1 .336 0 r
.48492 .50489 m
.48448 .50539 L
s
.48492 .50489 m
.48189 .50697 L
s
1 .005 0 r
.70254 .41179 m
.70251 .41178 L
s
.70251 .41178 m
.70253 .41174 L
s
.70251 .41178 m
.7025 .41175 L
s
.70253 .41174 m
.70256 .41175 L
s
.70253 .41174 m
.7025 .41175 L
s
.70256 .41175 m
.70254 .41179 L
s
.7025 .41175 m
.70254 .41179 L
s
.7025 .41175 m
.70256 .41175 L
s
1 .028 0 r
.51498 .18845 m
.51498 .18818 L
s
.808 1 0 r
.47781 .57004 m
.4781 .58082 L
s
1 .035 0 r
.31096 .4753 m
.31113 .47533 L
s
.31116 .47497 m
.31096 .4753 L
s
.31096 .4753 m
.31096 .47506 L
s
.31133 .47524 m
.31096 .4753 L
s
.31189 .47456 m
.31096 .4753 L
s
.31116 .47497 m
.31096 .47506 L
s
.31133 .47524 m
.31116 .47497 L
s
.31113 .47533 m
.31133 .47524 L
s
.31096 .47506 m
.31113 .47533 L
s
1 .336 0 r
.48189 .50697 m
.48487 .50842 L
s
.48189 .50697 m
.48448 .50539 L
s
.49693 .5054 m
.48189 .50697 L
s
1 .012 0 r
.69933 .21915 m
.69938 .21916 L
s
.69937 .21905 m
.69933 .21915 L
s
.69947 .21914 m
.69933 .21915 L
s
.69941 .21906 m
.69937 .21905 L
s
.69937 .21905 m
.69947 .21914 L
s
.69947 .21914 m
.69938 .21916 L
s
.69941 .21906 m
.69947 .21914 L
s
.69901 .21897 m
.69947 .21914 L
s
.69938 .21916 m
.69941 .21906 L
s
1 .001 0 r
.63291 .37872 m
.63288 .37871 L
s
1 .607 0 r
.56682 .53846 m
.54037 .53391 L
s
1 0 0 r
.37798 .31482 m
.378 .31481 L
s
1 .034 0 r
.44408 .15507 m
.44557 .15484 L
s
1 0 0 r
.378 .31481 m
.378 .31481 L
s
.378 .31481 m
.378 .31481 L
s
.378 .31481 m
.378 .31481 L
s
.37799 .31481 m
.378 .31481 L
s
.378 .31481 m
.378 .31481 L
s
1 .001 0 r
.63288 .37871 m
.63288 .37871 L
s
.63288 .37871 m
.63288 .3787 L
s
.63288 .37871 m
.63288 .37871 L
s
.63288 .3787 m
.63289 .3787 L
s
.63288 .3787 m
.63288 .37871 L
s
1 0 0 r
.378 .31481 m
.378 .31481 L
s
.37799 .31481 m
.378 .31481 L
s
.378 .31481 m
.37799 .31481 L
s
1 .001 0 r
.63288 .37871 m
.63288 .37871 L
s
.63288 .37871 m
.63289 .3787 L
s
.63289 .3787 m
.63288 .37871 L
s
1 .034 0 r
.44533 .15503 m
.44527 .15504 L
s
.44528 .15472 m
.44533 .15503 L
s
.44557 .15484 m
.44533 .15503 L
s
.44522 .15473 m
.44528 .15472 L
s
.44528 .15472 m
.44557 .15484 L
s
1 .65 0 r
.43058 .57174 m
.43281 .57035 L
s
.43281 .57035 m
.43078 .56476 L
s
.43281 .57035 m
.42556 .56984 L
s
1 .034 0 r
.44557 .15484 m
.44527 .15504 L
s
.44522 .15473 m
.44557 .15484 L
s
.44527 .15504 m
.44522 .15473 L
s
1 .65 0 r
.43078 .56476 m
.42854 .56613 L
s
.43078 .56476 m
.42556 .56984 L
s
.42556 .56984 m
.43058 .57174 L
s
.42556 .56984 m
.42854 .56613 L
s
.45125 .56182 m
.42556 .56984 L
s
1 .336 0 r
.48448 .50539 m
.48487 .50842 L
s
1 .1 0 r
.4238 .47386 m
.42415 .47368 L
s
.42415 .47368 m
.42383 .47282 L
s
.42415 .47368 m
.42303 .4736 L
s
1 .023 0 r
.62996 .18597 m
.63001 .18598 L
s
.63001 .18576 m
.62996 .18597 L
s
.63021 .18592 m
.62996 .18597 L
s
.63006 .18577 m
.63001 .18576 L
s
.63001 .18576 m
.63021 .18592 L
s
1 .1 0 r
.42383 .47282 m
.42349 .473 L
s
.42383 .47282 m
.42303 .4736 L
s
1 .023 0 r
.63021 .18592 m
.63001 .18598 L
s
.63006 .18577 m
.63021 .18592 L
s
.6292 .1857 m
.63021 .18592 L
s
1 .1 0 r
.42303 .4736 m
.4238 .47386 L
s
.42303 .4736 m
.42349 .473 L
s
.42695 .4723 m
.42303 .4736 L
s
1 .007 0 r
.24168 .44162 m
.24171 .44162 L
s
.24172 .44155 m
.24168 .44162 L
s
.24168 .44162 m
.24167 .44157 L
s
.24175 .4416 m
.24168 .44162 L
s
.24184 .44146 m
.24168 .44162 L
s
.24172 .44155 m
.24167 .44157 L
s
.24175 .4416 m
.24172 .44155 L
s
.24171 .44162 m
.24175 .4416 L
s
.24167 .44157 m
.24171 .44162 L
s
1 .023 0 r
.63001 .18598 m
.63006 .18577 L
s
1 .168 0 r
.75203 .56934 m
.74889 .56552 L
s
1 .002 0 r
.81816 .40949 m
.81812 .40945 L
s
1 0 0 r
.56307 .34555 m
.56307 .34555 L
s
1 .002 0 r
.30797 .28161 m
.30803 .28158 L
s
.30803 .28159 m
.30802 .2816 L
s
.30802 .28158 m
.30803 .28159 L
s
.30803 .28158 m
.30803 .28159 L
s
.30801 .28158 m
.30802 .28158 L
s
.30802 .28158 m
.30803 .28158 L
s
.81813 .40945 m
.81814 .40946 L
s
.81812 .40947 m
.81813 .40945 L
s
.81813 .40945 m
.81812 .40945 L
s
.81813 .40947 m
.81812 .40947 L
s
.81812 .40947 m
.81812 .40945 L
s
.30802 .2816 m
.30801 .28158 L
s
.30803 .28158 m
.30802 .2816 L
s
.30801 .28158 m
.30803 .28158 L
s
.81814 .40946 m
.81813 .40947 L
s
.81812 .40945 m
.81814 .40946 L
s
.81812 .40945 m
.81813 .40947 L
s
1 .029 0 r
.10532 .56899 m
.10534 .56901 L
s
.10538 .56869 m
.10532 .56899 L
s
.10532 .56899 m
.10517 .56882 L
s
.10555 .56888 m
.10532 .56899 L
s
.10552 .56827 m
.10532 .56899 L
s
1 .607 0 r
.54569 .53805 m
.54452 .53701 L
s
.54452 .53701 m
.54565 .53159 L
s
.54452 .53701 m
.54037 .53391 L
s
1 .1 0 r
.42349 .473 m
.4238 .47386 L
s
1 .029 0 r
.10538 .56869 m
.10517 .56882 L
s
.10555 .56888 m
.10538 .56869 L
s
1 .233 0 r
.33017 .56892 m
.3312 .56919 L
s
.33135 .56668 m
.33017 .56892 L
s
.33017 .56892 m
.32997 .56744 L
s
.33258 .56843 m
.33017 .56892 L
s
.33571 .56398 m
.33017 .56892 L
s
1 .029 0 r
.10534 .56901 m
.10555 .56888 L
s
.10517 .56882 m
.10534 .56901 L
s
1 .233 0 r
.33135 .56668 m
.32997 .56744 L
s
.33258 .56843 m
.33135 .56668 L
s
1 .607 0 r
.54565 .53159 m
.54683 .53263 L
s
.54565 .53159 m
.54037 .53391 L
s
1 .035 0 r
.56056 .15264 m
.56058 .15264 L
s
.56058 .15231 m
.56056 .15264 L
s
.5609 .1525 m
.56056 .15264 L
s
.5606 .15232 m
.56058 .15231 L
s
.56058 .15231 m
.5609 .1525 L
s
1 .233 0 r
.3312 .56919 m
.33258 .56843 L
s
1 .035 0 r
.5609 .1525 m
.56058 .15264 L
s
.5606 .15232 m
.5609 .1525 L
s
.55931 .1524 m
.5609 .1525 L
s
1 .001 0 r
.17167 .40834 m
.17168 .40834 L
s
.17168 .40833 m
.17167 .40834 L
s
.17167 .40834 m
.17167 .40834 L
s
.17168 .40834 m
.17167 .40834 L
s
.17169 .40832 m
.17167 .40834 L
s
.17168 .40833 m
.17167 .40834 L
s
.17168 .40834 m
.17168 .40833 L
s
.17168 .40834 m
.17168 .40834 L
s
.17167 .40834 m
.17168 .40834 L
s
.49316 .31235 m
.49316 .31235 L
s
.49316 .31234 m
.49316 .31235 L
s
.49316 .31235 m
.49316 .31235 L
s
.49316 .31234 m
.49316 .31234 L
s
.49316 .31234 m
.49316 .31235 L
s
1 .22 0 r
.68221 .53628 m
.67582 .532 L
s
1 0 0 r
.74839 .37633 m
.74838 .37632 L
s
1 .001 0 r
.49313 .31235 m
.49316 .31235 L
s
.49316 .31235 m
.49316 .31235 L
s
.49316 .31234 m
.49316 .31235 L
s
.49316 .31235 m
.49316 .31234 L
s
1 0 0 r
.74838 .37632 m
.74838 .37632 L
s
.74838 .37632 m
.74838 .37632 L
s
.74838 .37632 m
.74838 .37632 L
s
.74838 .37633 m
.74838 .37632 L
s
.74838 .37632 m
.74838 .37632 L
s
.74838 .37632 m
.74838 .37633 L
s
.74838 .37632 m
.74838 .37632 L
s
.74838 .37632 m
.74838 .37633 L
s
1 .035 0 r
.56058 .15264 m
.5606 .15232 L
s
.808 1 0 r
.56028 .56767 m
.55582 .57768 L
s
.54691 .56774 m
.55582 .57768 L
s
1 .077 0 r
.21943 .56796 m
.2196 .568 L
s
.21968 .56718 m
.21943 .56796 L
s
.21943 .56796 m
.21916 .56748 L
s
.22012 .5677 m
.21943 .56796 L
s
.22046 .56613 m
.21943 .56796 L
s
.21968 .56718 m
.21916 .56748 L
s
.22012 .5677 m
.21968 .56718 L
s
.808 1 0 r
.54691 .56774 m
.56028 .56767 L
s
1 .077 0 r
.2196 .568 m
.22012 .5677 L
s
1 .02 0 r
.35623 .43951 m
.35635 .43954 L
s
.35637 .43933 m
.35623 .43951 L
s
.35623 .43951 m
.35627 .43938 L
s
.35645 .4395 m
.35623 .43951 L
s
.35689 .43916 m
.35623 .43951 L
s
.35635 .43954 m
.35645 .4395 L
s
.35645 .4395 m
.35637 .43933 L
s
.35637 .43933 m
.35627 .43938 L
s
1 .077 0 r
.21916 .56748 m
.2196 .568 L
s
1 .011 0 r
.03518 .53547 m
.03518 .53547 L
s
.0352 .53535 m
.03518 .53547 L
s
.03518 .53547 m
.03512 .5354 L
s
.03526 .53542 m
.03518 .53547 L
s
.03524 .53519 m
.03518 .53547 L
s
.0352 .53535 m
.03512 .5354 L
s
.03526 .53542 m
.0352 .53535 L
s
1 .233 0 r
.32997 .56744 m
.3312 .56919 L
s
1 .011 0 r
.03518 .53547 m
.03526 .53542 L
s
1 .02 0 r
.35627 .43938 m
.35635 .43954 L
s
1 .011 0 r
.03512 .5354 m
.03518 .53547 L
s
1 .014 0 r
.74512 .18332 m
.74518 .18333 L
s
.74517 .18319 m
.74512 .18332 L
s
.74528 .18331 m
.74512 .18332 L
s
.74528 .18331 m
.74518 .18333 L
s
.74517 .18319 m
.74528 .18331 L
s
.74523 .1832 m
.74528 .18331 L
s
.74475 .18307 m
.74528 .18331 L
s
.74523 .1832 m
.74517 .18319 L
s
.74518 .18333 m
.74523 .1832 L
s
1 .043 0 r
.4909 .11914 m
.49087 .11914 L
s
.49088 .11874 m
.4909 .11914 L
s
.49126 .11892 m
.4909 .11914 L
s
.49085 .11874 m
.49088 .11874 L
s
.49088 .11874 m
.49126 .11892 L
s
1 .055 0 r
.86773 .5672 m
.86714 .56586 L
s
1 .229 0 r
.61231 .50318 m
.60322 .5003 L
s
1 0 0 r
.67853 .34312 m
.67853 .34312 L
s
1 .003 0 r
.42311 .2791 m
.42324 .27907 L
s
1 .043 0 r
.48933 .11904 m
.49126 .11892 L
s
1 .003 0 r
.42322 .27909 m
.42321 .27909 L
s
.42321 .27906 m
.42322 .27909 L
s
.42324 .27907 m
.42322 .27909 L
s
.42321 .27906 m
.42321 .27906 L
s
.42321 .27906 m
.42324 .27907 L
s
.42324 .27907 m
.42321 .27909 L
s
.42321 .27906 m
.42324 .27907 L
s
.42321 .27909 m
.42321 .27906 L
s
1 .043 0 r
.49126 .11892 m
.49087 .11914 L
s
.49085 .11874 m
.49126 .11892 L
s
.49087 .11914 m
.49085 .11874 L
s
1 .168 0 r
.74946 .56538 m
.75052 .56599 L
s
.74852 .56658 m
.74946 .56538 L
s
.74946 .56538 m
.74889 .56552 L
s
.74958 .56719 m
.74852 .56658 L
s
.74852 .56658 m
.74889 .56552 L
s
1 .65 0 r
.42854 .56613 m
.43058 .57174 L
s
1 .026 0 r
.67565 .15008 m
.67572 .15009 L
s
.67571 .14984 m
.67565 .15008 L
s
.67594 .15003 m
.67565 .15008 L
s
.67579 .14985 m
.67571 .14984 L
s
.67571 .14984 m
.67594 .15003 L
s
.67594 .15003 m
.67572 .15009 L
s
.67579 .14985 m
.67594 .15003 L
s
.67484 .14971 m
.67594 .15003 L
s
1 .141 0 r
.53719 .47049 m
.5371 .4703 L
s
.5371 .4703 m
.53718 .46901 L
s
.5371 .4703 m
.5359 .46968 L
s
1 .055 0 r
.86723 .56584 m
.86761 .56606 L
s
.8669 .5662 m
.86723 .56584 L
s
.86723 .56584 m
.86714 .56586 L
s
1 .026 0 r
.67572 .15009 m
.67579 .14985 L
s
1 .141 0 r
.53718 .46901 m
.53727 .4692 L
s
.53718 .46901 m
.5359 .46968 L
s
1 .055 0 r
.86729 .56643 m
.8669 .5662 L
s
.8669 .5662 m
.86714 .56586 L
s
1 .003 0 r
.28665 .40602 m
.28666 .40603 L
s
.28667 .406 m
.28665 .40602 L
s
.28665 .40602 m
.28665 .40601 L
s
.28668 .40602 m
.28665 .40602 L
s
.28673 .40597 m
.28665 .40602 L
s
.28667 .406 m
.28665 .40601 L
s
.28668 .40602 m
.28667 .406 L
s
.28666 .40603 m
.28668 .40602 L
s
.28665 .40601 m
.28666 .40603 L
s
1 .001 0 r
.6086 .30988 m
.6086 .30988 L
s
.6086 .30987 m
.6086 .30988 L
s
.6086 .30988 m
.6086 .30988 L
s
.6086 .30987 m
.6086 .30987 L
s
.6086 .30987 m
.6086 .30988 L
s
.6086 .30988 m
.6086 .30988 L
s
.6086 .30987 m
.6086 .30988 L
s
.60858 .30987 m
.6086 .30988 L
s
.6086 .30988 m
.6086 .30987 L
s
1 .066 0 r
.7979 .5341 m
.79671 .53255 L
s
1 .141 0 r
.54232 .47003 m
.5359 .46968 L
s
1 .006 0 r
.35299 .24581 m
.35322 .24572 L
s
.35319 .24576 m
.35317 .24577 L
s
.35317 .24571 m
.35319 .24576 L
s
.35322 .24572 m
.35319 .24576 L
s
.35315 .24572 m
.35317 .24571 L
s
.35317 .24571 m
.35322 .24572 L
s
1 .055 0 r
.86761 .56606 m
.86729 .56643 L
s
.86714 .56586 m
.86761 .56606 L
s
1 .006 0 r
.35322 .24572 m
.35317 .24577 L
s
.35315 .24572 m
.35322 .24572 L
s
.35317 .24577 m
.35315 .24572 L
s
1 .168 0 r
.75052 .56599 m
.74958 .56719 L
s
.74889 .56552 m
.75052 .56599 L
s
1 .055 0 r
.86714 .56586 m
.86729 .56643 L
s
1 .607 0 r
.54037 .53391 m
.54569 .53805 L
s
.54037 .53391 m
.54683 .53263 L
s
1 .168 0 r
.74889 .56552 m
.74958 .56719 L
s
1 .141 0 r
.5359 .46968 m
.53719 .47049 L
s
.5359 .46968 m
.53727 .4692 L
s
1 .229 0 r
.60507 .50208 m
.6043 .50166 L
s
.6043 .50166 m
.60501 .49967 L
s
.6043 .50166 m
.60322 .5003 L
s
1 .026 0 r
.14987 .53365 m
.14991 .53366 L
s
.14994 .53338 m
.14987 .53365 L
s
.14987 .53365 m
.14976 .53348 L
s
.1501 .53355 m
.14987 .53365 L
s
.15017 .533 m
.14987 .53365 L
s
.14994 .53338 m
.14976 .53348 L
s
.1501 .53355 m
.14994 .53338 L
s
1 .229 0 r
.60501 .49967 m
.60577 .5001 L
s
.60501 .49967 m
.60322 .5003 L
s
1 .026 0 r
.14991 .53366 m
.1501 .53355 L
s
.14976 .53348 m
.14991 .53366 L
s
1 .22 0 r
.67704 .53168 m
.67821 .53229 L
s
.67599 .53342 m
.67704 .53168 L
s
.67704 .53168 m
.67582 .532 L
s
1 .141 0 r
.53727 .4692 m
.53719 .47049 L
s
1 .22 0 r
.67715 .53403 m
.67599 .53342 L
s
.67599 .53342 m
.67582 .532 L
s
1 .043 0 r
.47071 .43731 m
.47078 .43725 L
s
.47078 .43725 m
.47071 .43686 L
s
.47078 .43725 m
.47033 .43714 L
s
.47071 .43686 m
.47063 .43692 L
s
.47071 .43686 m
.47033 .43714 L
s
1 .039 0 r
.60618 .1167 m
.60624 .1167 L
s
.60623 .11634 m
.60618 .1167 L
s
.60658 .11657 m
.60618 .1167 L
s
1 .043 0 r
.47033 .43714 m
.47071 .43731 L
s
.47033 .43714 m
.47063 .43692 L
s
.47223 .43684 m
.47033 .43714 L
s
1 .039 0 r
.60629 .11634 m
.60623 .11634 L
s
.60623 .11634 m
.60658 .11657 L
s
.60658 .11657 m
.60624 .1167 L
s
.60629 .11634 m
.60658 .11657 L
s
.60484 .11632 m
.60658 .11657 L
s
1 .607 0 r
.54683 .53263 m
.54569 .53805 L
s
1 .043 0 r
.47063 .43692 m
.47071 .43731 L
s
1 .039 0 r
.60624 .1167 m
.60629 .11634 L
s
1 .066 0 r
.79692 .53251 m
.79735 .53274 L
s
.79655 .53298 m
.79692 .53251 L
s
.79692 .53251 m
.79671 .53255 L
s
1 .004 0 r
.53867 .2766 m
.53867 .2766 L
s
.53867 .27657 m
.53867 .2766 L
s
.53871 .27659 m
.53867 .2766 L
s
.53867 .27657 m
.53867 .27657 L
s
.53867 .27657 m
.53871 .27659 L
s
.53871 .27659 m
.53867 .2766 L
s
.53867 .27657 m
.53871 .27659 L
s
.53854 .27658 m
.53871 .27659 L
s
1 0 0 r
.21647 .37274 m
.21647 .37274 L
s
.21647 .37274 m
.21647 .37274 L
s
.21647 .37274 m
.21647 .37274 L
s
.21647 .37274 m
.21647 .37274 L
s
.21648 .37274 m
.21647 .37274 L
s
.21647 .37274 m
.21647 .37274 L
s
.21647 .37274 m
.21647 .37274 L
s
.21647 .37274 m
.21647 .37274 L
s
.21647 .37274 m
.21647 .37274 L
s
1 .075 0 r
.72798 .50095 m
.72599 .4994 L
s
1 0 0 r
.79429 .34069 m
.79429 .34069 L
s
1 .004 0 r
.53867 .2766 m
.53867 .27657 L
s
1 .066 0 r
.79698 .53321 m
.79655 .53298 L
s
.79655 .53298 m
.79671 .53255 L
s
1 .575 0 r
.6217 .56025 m
.62446 .56178 L
s
.61913 .5649 m
.6217 .56025 L
s
.6217 .56025 m
.61806 .56129 L
s
.62188 .56644 m
.61913 .5649 L
s
.61913 .5649 m
.61806 .56129 L
s
1 .066 0 r
.79735 .53274 m
.79698 .53321 L
s
.79671 .53255 m
.79735 .53274 L
s
.79671 .53255 m
.79698 .53321 L
s
1 .22 0 r
.37384 .53254 m
.3752 .53293 L
s
.37531 .53059 m
.37384 .53254 L
s
.37384 .53254 m
.37423 .53114 L
s
.37628 .53237 m
.37384 .53254 L
s
.38092 .5286 m
.37384 .53254 L
s
1 .073 0 r
.26395 .53247 m
.26421 .53253 L
s
.26427 .53175 m
.26395 .53247 L
s
.26395 .53247 m
.26381 .532 L
s
.26467 .53228 m
.26395 .53247 L
s
.2654 .53081 m
.26395 .53247 L
s
1 .22 0 r
.3752 .53293 m
.37628 .53237 L
s
.37628 .53237 m
.37531 .53059 L
s
.37531 .53059 m
.37423 .53114 L
s
1 .229 0 r
.60322 .5003 m
.60507 .50208 L
s
.60322 .5003 m
.60577 .5001 L
s
1 .073 0 r
.26427 .53175 m
.26381 .532 L
s
.26467 .53228 m
.26427 .53175 L
s
1 .229 0 r
.60577 .5001 m
.60507 .50208 L
s
1 .22 0 r
.67821 .53229 m
.67715 .53403 L
s
.67582 .532 m
.67821 .53229 L
s
1 .073 0 r
.26421 .53253 m
.26467 .53228 L
s
1 .22 0 r
.67582 .532 m
.67715 .53403 L
s
1 .009 0 r
.0797 .50005 m
.07971 .50005 L
s
.07972 .49996 m
.0797 .50005 L
s
.0797 .50005 m
.07966 .49999 L
s
.07977 .50002 m
.0797 .50005 L
s
.07979 .49983 m
.0797 .50005 L
s
.07972 .49996 m
.07966 .49999 L
s
.07977 .50002 m
.07972 .49996 L
s
.07971 .50005 m
.07977 .50002 L
s
.07966 .49999 m
.07971 .50005 L
s
1 .073 0 r
.26381 .532 m
.26421 .53253 L
s
1 .075 0 r
.72636 .49932 m
.72678 .49953 L
s
.72599 .4999 m
.72636 .49932 L
s
.72636 .49932 m
.72599 .4994 L
s
1 .007 0 r
.40184 .40372 m
.40187 .40371 L
s
.40187 .40371 m
.40185 .40365 L
s
.40187 .40371 m
.40179 .4037 L
s
.40185 .40365 m
.40182 .40366 L
s
.40185 .40365 m
.40179 .4037 L
s
.40179 .4037 m
.40184 .40372 L
s
.40179 .4037 m
.40182 .40366 L
s
.40206 .40361 m
.40179 .4037 L
s
1 .075 0 r
.72641 .5001 m
.72599 .4999 L
s
.72599 .4999 m
.72599 .4994 L
s
1 .007 0 r
.40182 .40366 m
.40184 .40372 L
s
1 0 0 r
.72433 .3074 m
.72433 .3074 L
s
.72433 .30739 m
.72433 .3074 L
s
.72433 .3074 m
.72433 .3074 L
s
.72433 .3074 m
.72433 .3074 L
s
.72433 .30739 m
.72433 .3074 L
s
.72433 .30739 m
.72433 .3074 L
s
.72432 .30739 m
.72433 .3074 L
s
.72433 .30739 m
.72433 .30739 L
s
.72433 .3074 m
.72433 .30739 L
s
1 .009 0 r
.46873 .24324 m
.46871 .24325 L
s
.46872 .24317 m
.46873 .24324 L
s
.46879 .2432 m
.46873 .24324 L
s
1 .068 0 r
.65797 .46776 m
.65551 .46669 L
s
1 .009 0 r
.4684 .24324 m
.46879 .2432 L
s
.4687 .24317 m
.46872 .24317 L
s
.46872 .24317 m
.46879 .2432 L
s
.46879 .2432 m
.46871 .24325 L
s
.4687 .24317 m
.46879 .2432 L
s
.46871 .24325 m
.4687 .24317 L
s
0 .04 1 r
.50177 .53168 m
.52451 .5458 L
s
.47891 .55998 m
.50177 .53168 L
s
.50177 .53168 m
.48379 .53439 L
s
1 .075 0 r
.72678 .49953 m
.72641 .5001 L
s
.72599 .4994 m
.72678 .49953 L
s
.72599 .4994 m
.72641 .5001 L
s
1 .068 0 r
.65602 .46726 m
.65574 .46712 L
s
.65574 .46712 m
.65599 .46655 L
s
.65574 .46712 m
.65551 .46669 L
s
.65599 .46655 m
.65628 .46668 L
s
.65599 .46655 m
.65551 .46669 L
s
1 .028 0 r
.72145 .11402 m
.72155 .11403 L
s
.72153 .11378 m
.72145 .11402 L
s
.72176 .11399 m
.72145 .11402 L
s
1 .22 0 r
.37423 .53114 m
.3752 .53293 L
s
1 .028 0 r
.72163 .11379 m
.72153 .11378 L
s
.72153 .11378 m
.72176 .11399 L
s
.72176 .11399 m
.72155 .11403 L
s
.72163 .11379 m
.72176 .11399 L
s
.72066 .11358 m
.72176 .11399 L
s
.72155 .11403 m
.72163 .11379 L
s
1 .068 0 r
.65628 .46668 m
.65602 .46726 L
s
.65551 .46669 m
.65602 .46726 L
s
.65551 .46669 m
.65628 .46668 L
s
1 .003 0 r
.65434 .27409 m
.65435 .27409 L
s
.65435 .27407 m
.65434 .27409 L
s
.65437 .27408 m
.65434 .27409 L
s
.65436 .27407 m
.65435 .27407 L
s
.65435 .27407 m
.65437 .27408 L
s
.65437 .27408 m
.65435 .27409 L
s
.65436 .27407 m
.65437 .27408 L
s
.65427 .27405 m
.65437 .27408 L
s
.65435 .27409 m
.65436 .27407 L
s
1 0 0 r
.33178 .37034 m
.33178 .37034 L
s
.33178 .37034 m
.33178 .37034 L
s
.33178 .37034 m
.33178 .37034 L
s
.33178 .37034 m
.33178 .37034 L
s
.33179 .37034 m
.33178 .37034 L
s
.33178 .37034 m
.33178 .37034 L
s
.33178 .37034 m
.33178 .37034 L
s
.33178 .37034 m
.33178 .37034 L
s
.33178 .37034 m
.33178 .37034 L
s
1 .024 0 r
.84396 .49871 m
.84354 .49814 L
s
1 .039 0 r
.58787 .43452 m
.58618 .43421 L
s
1 .013 0 r
.39818 .20987 m
.39872 .20973 L
s
.39864 .20981 m
.39861 .20982 L
s
.39861 .20969 m
.39864 .20981 L
s
.39872 .20973 m
.39864 .20981 L
s
.39858 .2097 m
.39861 .20969 L
s
.39861 .20969 m
.39872 .20973 L
s
1 .039 0 r
.58652 .43448 m
.58644 .43442 L
s
.58644 .43442 m
.58651 .43407 L
s
.58644 .43442 m
.58618 .43421 L
s
1 .013 0 r
.39872 .20973 m
.39861 .20982 L
s
.39858 .2097 m
.39872 .20973 L
s
1 .039 0 r
.58651 .43407 m
.5866 .43413 L
s
.58651 .43407 m
.58618 .43421 L
s
1 .013 0 r
.39861 .20982 m
.39858 .2097 L
s
1 .039 0 r
.58618 .43421 m
.58652 .43448 L
s
.58618 .43421 m
.5866 .43413 L
s
.5866 .43413 m
.58652 .43448 L
s
1 .024 0 r
.84361 .49812 m
.84377 .49821 L
s
.84347 .4983 m
.84361 .49812 L
s
.84361 .49812 m
.84354 .49814 L
s
.84363 .49838 m
.84347 .4983 L
s
.84347 .4983 m
.84354 .49814 L
s
.84377 .49821 m
.84363 .49838 L
s
.84354 .49814 m
.84377 .49821 L
s
.84354 .49814 m
.84363 .49838 L
s
1 .022 0 r
.19463 .49811 m
.19469 .49812 L
s
.19472 .49789 m
.19463 .49811 L
s
.19463 .49811 m
.19457 .49797 L
s
.19484 .49805 m
.19463 .49811 L
s
.195 .49759 m
.19463 .49811 L
s
.19472 .49789 m
.19457 .49797 L
s
.19484 .49805 m
.19472 .49789 L
s
.19469 .49812 m
.19484 .49805 L
s
.19457 .49797 m
.19469 .49812 L
s
1 .459 0 r
.48016 .53055 m
.48076 .52981 L
s
.48076 .52981 m
.48023 .52565 L
s
.48076 .52981 m
.47606 .52852 L
s
1 .008 0 r
.5844 .24075 m
.58442 .24075 L
s
.58441 .24067 m
.5844 .24075 L
s
.58449 .24072 m
.5844 .24075 L
s
.58443 .24067 m
.58441 .24067 L
s
.58441 .24067 m
.58449 .24072 L
s
1 .01 0 r
.5173 .40131 m
.51731 .4013 L
s
.51731 .4013 m
.5173 .4012 L
s
.51731 .4013 m
.51721 .40126 L
s
1 .008 0 r
.58449 .24072 m
.58442 .24075 L
s
.58443 .24067 m
.58449 .24072 L
s
.58412 .24067 m
.58449 .24072 L
s
1 .01 0 r
.5173 .4012 m
.5173 .40121 L
s
.5173 .4012 m
.51721 .40126 L
s
.51721 .40126 m
.5173 .40131 L
s
.51721 .40126 m
.5173 .40121 L
s
.51768 .40125 m
.51721 .40126 L
s
1 .008 0 r
.58442 .24075 m
.58443 .24067 L
s
1 .022 0 r
.77393 .46548 m
.77337 .46499 L
s
1 0 0 r
.26143 .33702 m
.26143 .33702 L
s
1 .01 0 r
.5173 .40121 m
.5173 .40131 L
s
1 .575 0 r
.62446 .56178 m
.62188 .56644 L
s
.61806 .56129 m
.62446 .56178 L
s
.61806 .56129 m
.62188 .56644 L
s
1 .022 0 r
.77348 .46497 m
.77361 .46503 L
s
.77336 .46514 m
.77348 .46497 L
s
.77348 .46497 m
.77337 .46499 L
s
.7735 .4652 m
.77336 .46514 L
s
.77336 .46514 m
.77337 .46499 L
s
1 .459 0 r
.48023 .52565 m
.47962 .52638 L
s
.48023 .52565 m
.47606 .52852 L
s
1 .022 0 r
.77361 .46503 m
.7735 .4652 L
s
.77337 .46499 m
.77361 .46503 L
s
.77337 .46499 m
.7735 .4652 L
s
1 .062 0 r
.30886 .49663 m
.30916 .4967 L
s
.30921 .49605 m
.30886 .49663 L
s
.30886 .49663 m
.30886 .49622 L
s
.30952 .49653 m
.30886 .49663 L
s
.31051 .49535 m
.30886 .49663 L
s
1 .006 0 r
.12442 .46448 m
.12443 .46448 L
s
.12444 .46442 m
.12442 .46448 L
s
.12442 .46448 m
.1244 .46444 L
s
.12447 .46446 m
.12442 .46448 L
s
.12451 .46433 m
.12442 .46448 L
s
.12444 .46442 m
.1244 .46444 L
s
.12447 .46446 m
.12444 .46442 L
s
.12443 .46448 m
.12447 .46446 L
s
.1244 .46444 m
.12443 .46448 L
s
1 .062 0 r
.30921 .49605 m
.30886 .49622 L
s
.30952 .49653 m
.30921 .49605 L
s
.30916 .4967 m
.30952 .49653 L
s
1 .015 0 r
.51445 .20731 m
.51445 .20731 L
s
.51445 .20716 m
.51445 .20731 L
s
.51459 .20723 m
.51445 .20731 L
s
.51444 .20717 m
.51445 .20716 L
s
.51445 .20716 m
.51459 .20723 L
s
1 .001 0 r
.77034 .27154 m
.77033 .27155 L
s
.77033 .27153 m
.77034 .27154 L
s
.77034 .27154 m
.77033 .27154 L
s
.77034 .27154 m
.77034 .27154 L
s
.7703 .27152 m
.77034 .27154 L
s
.77033 .27154 m
.77033 .27155 L
s
.77033 .27153 m
.77033 .27154 L
s
.77034 .27154 m
.77033 .27153 L
s
.77033 .27155 m
.77034 .27154 L
s
.44737 .36794 m
.44737 .36794 L
s
.44737 .36794 m
.44737 .36793 L
s
.44737 .36794 m
.44737 .36793 L
s
.44737 .36793 m
.44737 .36793 L
s
.44737 .36793 m
.44737 .36793 L
s
.44737 .36793 m
.44737 .36794 L
s
.44737 .36793 m
.44737 .36793 L
s
.4474 .36793 m
.44737 .36793 L
s
.44737 .36793 m
.44737 .36794 L
s
1 .016 0 r
.70382 .4322 m
.70328 .43191 L
s
1 .015 0 r
.51388 .20725 m
.51459 .20723 L
s
.51459 .20723 m
.51445 .20731 L
s
.51444 .20717 m
.51459 .20723 L
s
.51445 .20731 m
.51444 .20717 L
s
1 .459 0 r
.47606 .52852 m
.48016 .53055 L
s
.47606 .52852 m
.47962 .52638 L
s
.49675 .5264 m
.47606 .52852 L
s
1 .016 0 r
.70339 .43205 m
.70332 .43202 L
s
.70332 .43202 m
.70339 .43189 L
s
.70332 .43202 m
.70328 .43191 L
s
.70339 .43189 m
.70346 .43192 L
s
.70339 .43189 m
.70328 .43191 L
s
1 .062 0 r
.30886 .49622 m
.30916 .4967 L
s
1 .016 0 r
.70346 .43192 m
.70339 .43205 L
s
.70328 .43191 m
.70339 .43205 L
s
.70328 .43191 m
.70346 .43192 L
s
0 .04 1 r
.50146 .57444 m
.47891 .55998 L
s
.47891 .55998 m
.48379 .53439 L
s
0 .197 1 r
.52635 .52774 m
.5044 .55497 L
s
.48759 .51676 m
.52635 .52774 L
s
1 .005 0 r
.70028 .23818 m
.7003 .23818 L
s
.70029 .23813 m
.70028 .23818 L
s
.70034 .23817 m
.70028 .23818 L
s
.70031 .23814 m
.70029 .23813 L
s
.70029 .23813 m
.70034 .23817 L
s
.70034 .23817 m
.7003 .23818 L
s
.70031 .23814 m
.70034 .23817 L
s
.70013 .2381 m
.70034 .23817 L
s
.7003 .23818 m
.70031 .23814 L
s
1 .166 0 r
.42104 .49569 m
.42162 .49538 L
s
.42162 .49538 m
.42109 .49393 L
s
.42162 .49538 m
.41975 .49524 L
s
1 .741 0 r
.56709 .55966 m
.53455 .55413 L
s
1 .007 0 r
.63361 .39888 m
.63334 .3988 L
s
1 0 0 r
.37703 .33456 m
.37703 .33456 L
s
1 .021 0 r
.44355 .17378 m
.44448 .17364 L
s
.44433 .17376 m
.44429 .17377 L
s
.4443 .17357 m
.44433 .17376 L
s
.44448 .17364 m
.44433 .17376 L
s
1 .007 0 r
.63339 .39885 m
.63337 .39884 L
s
.63337 .39884 m
.63339 .39878 L
s
.63337 .39884 m
.63334 .3988 L
s
1 .021 0 r
.44426 .17357 m
.4443 .17357 L
s
.4443 .17357 m
.44448 .17364 L
s
1 .007 0 r
.63339 .39878 m
.63341 .39879 L
s
.63339 .39878 m
.63334 .3988 L
s
1 .166 0 r
.42109 .49393 m
.42051 .49425 L
s
.42109 .49393 m
.41975 .49524 L
s
1 .007 0 r
.63334 .3988 m
.63339 .39885 L
s
.63334 .3988 m
.63341 .39879 L
s
.63341 .39879 m
.63339 .39885 L
s
1 .166 0 r
.41975 .49524 m
.42104 .49569 L
s
.41975 .49524 m
.42051 .49425 L
s
.42632 .49309 m
.41975 .49524 L
s
1 .021 0 r
.44448 .17364 m
.44429 .17377 L
s
.44426 .17357 m
.44448 .17364 L
s
.44429 .17377 m
.44426 .17357 L
s
1 .459 0 r
.47962 .52638 m
.48016 .53055 L
s
1 .015 0 r
.23965 .46239 m
.23971 .46241 L
s
.23973 .46224 m
.23965 .46239 L
s
.23965 .46239 m
.23963 .46229 L
s
.23981 .46236 m
.23965 .46239 L
s
.24 .46204 m
.23965 .46239 L
s
.23973 .46224 m
.23963 .46229 L
s
.23981 .46236 m
.23973 .46224 L
s
.23971 .46241 m
.23981 .46236 L
s
.23963 .46229 m
.23971 .46241 L
s
1 .013 0 r
.63029 .20477 m
.63032 .20478 L
s
.63032 .20466 m
.63029 .20477 L
s
.63043 .20474 m
.63029 .20477 L
s
1 .166 0 r
.42051 .49425 m
.42104 .49569 L
s
1 .013 0 r
.63035 .20466 m
.63032 .20466 L
s
.63032 .20466 m
.63043 .20474 L
s
.63043 .20474 m
.63032 .20478 L
s
.63035 .20466 m
.63043 .20474 L
s
.62988 .20463 m
.63043 .20474 L
s
.63032 .20478 m
.63035 .20466 L
s
1 .001 0 r
.56328 .36551 m
.56328 .36551 L
s
.56328 .36551 m
.56328 .3655 L
s
.56328 .36551 m
.56327 .36551 L
s
1 .006 0 r
.82006 .42987 m
.81993 .42974 L
s
1 .001 0 r
.56331 .36551 m
.56327 .36551 L
s
1 0 0 r
.30656 .30116 m
.30657 .30115 L
s
1 .001 0 r
.56328 .3655 m
.56328 .36551 L
s
.56328 .3655 m
.56327 .36551 L
s
1 0 0 r
.30657 .30116 m
.30657 .30116 L
s
.30657 .30115 m
.30657 .30116 L
s
.30657 .30115 m
.30657 .30116 L
s
.30657 .30115 m
.30657 .30115 L
s
.30657 .30115 m
.30657 .30115 L
s
.30657 .30116 m
.30657 .30115 L
s
.30657 .30115 m
.30657 .30116 L
s
1 .001 0 r
.56327 .36551 m
.56328 .36551 L
s
.56327 .36551 m
.56328 .36551 L
s
1 0 0 r
.30657 .30115 m
.30657 .30115 L
s
1 .001 0 r
.56328 .36551 m
.56328 .36551 L
s
1 .006 0 r
.81995 .42974 m
.81999 .42975 L
s
.81992 .42978 m
.81995 .42974 L
s
.81995 .42974 m
.81993 .42974 L
s
.81996 .42979 m
.81992 .42978 L
s
.81992 .42978 m
.81993 .42974 L
s
.81999 .42975 m
.81996 .42979 L
s
.81993 .42974 m
.81999 .42975 L
s
.81993 .42974 m
.81996 .42979 L
s
1 .741 0 r
.5411 .55924 m
.53967 .55789 L
s
.53967 .55789 m
.54106 .55124 L
s
.53967 .55789 m
.53455 .55413 L
s
1 .022 0 r
.56031 .17126 m
.56033 .17127 L
s
.56032 .17106 m
.56031 .17126 L
s
.56052 .17118 m
.56031 .17126 L
s
.56034 .17107 m
.56032 .17106 L
s
.56032 .17106 m
.56052 .17118 L
s
1 .003 0 r
.16933 .42878 m
.16935 .42878 L
s
.16935 .42875 m
.16933 .42878 L
s
.16933 .42878 m
.16933 .42876 L
s
.16937 .42877 m
.16933 .42878 L
s
.1694 .4287 m
.16933 .42878 L
s
.16935 .42875 m
.16933 .42876 L
s
.16937 .42877 m
.16935 .42875 L
s
.16935 .42878 m
.16937 .42877 L
s
.16933 .42876 m
.16935 .42878 L
s
1 .022 0 r
.56052 .17118 m
.56033 .17127 L
s
.56034 .17107 m
.56052 .17118 L
s
.55953 .17111 m
.56052 .17118 L
s
1 .293 0 r
.68323 .55749 m
.67466 .55182 L
s
1 .003 0 r
.74984 .3965 m
.74976 .39645 L
s
1 0 0 r
.49292 .3321 m
.49292 .3321 L
s
1 .022 0 r
.56033 .17127 m
.56034 .17107 L
s
1 .003 0 r
.74977 .39644 m
.74979 .39645 L
s
.74976 .39647 m
.74977 .39644 L
s
.74977 .39644 m
.74976 .39645 L
s
.74977 .39647 m
.74976 .39647 L
s
.74976 .39647 m
.74976 .39645 L
s
.74979 .39645 m
.74977 .39647 L
s
.74976 .39645 m
.74979 .39645 L
s
.74976 .39645 m
.74977 .39647 L
s
1 .741 0 r
.54106 .55124 m
.54249 .55257 L
s
.54106 .55124 m
.53455 .55413 L
s
1 .043 0 r
.35436 .4605 m
.35464 .46057 L
s
.35466 .46013 m
.35436 .4605 L
s
.35436 .4605 m
.35446 .46022 L
s
.35484 .46048 m
.35436 .4605 L
s
.35579 .45975 m
.35436 .4605 L
s
.35464 .46057 m
.35484 .46048 L
s
.35484 .46048 m
.35466 .46013 L
s
.35466 .46013 m
.35446 .46022 L
s
.35446 .46022 m
.35464 .46057 L
s
1 .017 0 r
.03196 .55682 m
.03197 .55683 L
s
.032 .55665 m
.03196 .55682 L
s
.03196 .55682 m
.03187 .55672 L
s
.03209 .55676 m
.03196 .55682 L
s
.03206 .55641 m
.03196 .55682 L
s
.032 .55665 m
.03187 .55672 L
s
.03209 .55676 m
.032 .55665 L
s
.03197 .55683 m
.03209 .55676 L
s
.03187 .55672 m
.03197 .55683 L
s
1 .008 0 r
.74638 .20213 m
.74641 .20214 L
s
.7464 .20206 m
.74638 .20213 L
s
.74646 .20213 m
.74638 .20213 L
s
.74646 .20213 m
.74641 .20214 L
s
.7464 .20206 m
.74646 .20213 L
s
.74644 .20207 m
.74646 .20213 L
s
.74618 .202 m
.74646 .20213 L
s
.74644 .20207 m
.7464 .20206 L
s
.74641 .20214 m
.74644 .20207 L
s
1 .029 0 r
.49017 .13762 m
.49014 .13762 L
s
.49015 .13735 m
.49017 .13762 L
s
.49041 .13747 m
.49017 .13762 L
s
.49013 .13736 m
.49015 .13735 L
s
.49015 .13735 m
.49041 .13747 L
s
1 .323 0 r
.61287 .52419 m
.59992 .52014 L
s
1 0 0 r
.67953 .36309 m
.67951 .36308 L
s
.42244 .29865 m
.42246 .29865 L
s
1 .029 0 r
.48909 .13756 m
.49041 .13747 L
s
1 0 0 r
.42246 .29865 m
.42246 .29865 L
s
.42246 .29865 m
.42246 .29865 L
s
.42246 .29865 m
.42246 .29865 L
s
.42246 .29865 m
.42246 .29865 L
s
.42246 .29865 m
.42246 .29865 L
s
.42246 .29865 m
.42246 .29865 L
s
.42246 .29865 m
.42246 .29865 L
s
.67951 .36309 m
.67951 .36309 L
s
.67951 .36309 m
.67951 .36308 L
s
.67951 .36309 m
.67951 .36308 L
s
.67951 .36308 m
.67951 .36308 L
s
.67951 .36308 m
.67951 .36308 L
s
.42246 .29865 m
.42246 .29865 L
s
.67951 .36308 m
.67951 .36309 L
s
.67951 .36308 m
.67951 .36308 L
s
.67951 .36308 m
.67951 .36309 L
s
1 .029 0 r
.49041 .13747 m
.49014 .13762 L
s
.49013 .13736 m
.49041 .13747 L
s
.49014 .13762 m
.49013 .13736 L
s
0 .197 1 r
.48759 .51676 m
.5044 .55497 L
s
1 .229 0 r
.53406 .49159 m
.53392 .49127 L
s
.53392 .49127 m
.53405 .48917 L
s
.53392 .49127 m
.53196 .49027 L
s
.53405 .48917 m
.5342 .48949 L
s
.53405 .48917 m
.53196 .49027 L
s
1 .016 0 r
.67631 .16866 m
.67636 .16867 L
s
.67635 .16852 m
.67631 .16866 L
s
.67649 .16863 m
.67631 .16866 L
s
.6764 .16852 m
.67635 .16852 L
s
.67635 .16852 m
.67649 .16863 L
s
1 .009 0 r
.28493 .42654 m
.28497 .42655 L
s
.28498 .42646 m
.28493 .42654 L
s
.28493 .42654 m
.28493 .42648 L
s
.28502 .42652 m
.28493 .42654 L
s
.28518 .42636 m
.28493 .42654 L
s
1 .016 0 r
.67649 .16863 m
.67636 .16867 L
s
.6764 .16852 m
.67649 .16863 L
s
.67581 .16844 m
.67649 .16863 L
s
1 .009 0 r
.28498 .42646 m
.28493 .42648 L
s
.28502 .42652 m
.28498 .42646 L
s
.28497 .42655 m
.28502 .42652 L
s
.28493 .42648 m
.28497 .42655 L
s
1 .016 0 r
.67636 .16867 m
.6764 .16852 L
s
1 .095 0 r
.79968 .55532 m
.79795 .55312 L
s
1 .229 0 r
.54243 .49084 m
.53196 .49027 L
s
1 0 0 r
.60912 .32964 m
.60912 .32964 L
s
1 .002 0 r
.35187 .26516 m
.35194 .26513 L
s
.35193 .26514 m
.35193 .26515 L
s
.35193 .26513 m
.35193 .26514 L
s
.35194 .26513 m
.35193 .26514 L
s
.35192 .26513 m
.35193 .26513 L
s
.35193 .26513 m
.35194 .26513 L
s
.35194 .26513 m
.35193 .26515 L
s
.35192 .26513 m
.35194 .26513 L
s
.35193 .26515 m
.35192 .26513 L
s
1 .039 0 r
.14728 .55518 m
.14735 .5552 L
s
.1474 .55478 m
.14728 .55518 L
s
.14728 .55518 m
.14712 .55494 L
s
.14762 .55504 m
.14728 .55518 L
s
.14773 .55423 m
.14728 .55518 L
s
.1474 .55478 m
.14712 .55494 L
s
.14762 .55504 m
.1474 .55478 L
s
1 .293 0 r
.3705 .55507 m
.37232 .55561 L
s
.37247 .55245 m
.3705 .55507 L
s
.3705 .55507 m
.37102 .55322 L
s
.37377 .55484 m
.3705 .55507 L
s
.37998 .54986 m
.3705 .55507 L
s
1 .039 0 r
.14735 .5552 m
.14762 .55504 L
s
1 .09 0 r
.46869 .45841 m
.46886 .45829 L
s
.46886 .45829 m
.46871 .45747 L
s
.46886 .45829 m
.4679 .45807 L
s
.46871 .45747 m
.46854 .4576 L
s
.46871 .45747 m
.4679 .45807 L
s
1 .039 0 r
.14712 .55494 m
.14735 .5552 L
s
1 .293 0 r
.37232 .55561 m
.37377 .55484 L
s
.37377 .55484 m
.37247 .55245 L
s
.37247 .55245 m
.37102 .55322 L
s
1 .09 0 r
.4679 .45807 m
.46869 .45841 L
s
.4679 .45807 m
.46854 .4576 L
s
.47189 .45745 m
.4679 .45807 L
s
1 .229 0 r
.53196 .49027 m
.53406 .49159 L
s
.53196 .49027 m
.5342 .48949 L
s
1 .09 0 r
.46854 .4576 m
.46869 .45841 L
s
1 .026 0 r
.60627 .1351 m
.60631 .1351 L
s
.6063 .13485 m
.60627 .1351 L
s
.60654 .13501 m
.60627 .1351 L
s
.60634 .13485 m
.6063 .13485 L
s
.6063 .13485 m
.60654 .13501 L
s
1 .104 0 r
.26164 .55441 m
.262 .5545 L
s
.26209 .55337 m
.26164 .55441 L
s
.26164 .55441 m
.26143 .55374 L
s
.26267 .55413 m
.26164 .55441 L
s
.26371 .55205 m
.26164 .55441 L
s
1 .026 0 r
.60654 .13501 m
.60631 .1351 L
s
.60634 .13485 m
.60654 .13501 L
s
.60536 .13484 m
.60654 .13501 L
s
1 .323 0 r
.60256 .52268 m
.60148 .52204 L
s
.60148 .52204 m
.60248 .51922 L
s
.60148 .52204 m
.59992 .52014 L
s
1 .026 0 r
.60631 .1351 m
.60634 .13485 L
s
1 .001 0 r
.21444 .39295 m
.21444 .39295 L
s
.21444 .39294 m
.21444 .39295 L
s
.21444 .39295 m
.21444 .39294 L
s
.21445 .39295 m
.21444 .39295 L
s
.21447 .39292 m
.21444 .39295 L
s
.21444 .39294 m
.21444 .39294 L
s
.21445 .39295 m
.21444 .39294 L
s
.21444 .39295 m
.21445 .39295 L
s
1 .229 0 r
.5342 .48949 m
.53406 .49159 L
s
1 .001 0 r
.21444 .39294 m
.21444 .39295 L
s
1 0 0 r
.53864 .29614 m
.53864 .29615 L
s
.53864 .29614 m
.53864 .29614 L
s
.53865 .29614 m
.53864 .29614 L
s
.53864 .29614 m
.53864 .29614 L
s
.53864 .29614 m
.53865 .29614 L
s
.53865 .29614 m
.53864 .29615 L
s
.53864 .29614 m
.53865 .29614 L
s
.53862 .29614 m
.53865 .29614 L
s
1 .114 0 r
.7293 .52197 m
.72623 .51962 L
s
1 0 0 r
.79604 .36066 m
.79603 .36066 L
s
.53864 .29615 m
.53864 .29614 L
s
.79604 .36066 m
.79604 .36066 L
s
.79603 .36066 m
.79604 .36066 L
s
.79604 .36066 m
.79603 .36066 L
s
.79604 .36066 m
.79603 .36066 L
s
.79603 .36066 m
.79603 .36066 L
s
.79604 .36066 m
.79604 .36066 L
s
.79603 .36066 m
.79604 .36066 L
s
.79603 .36066 m
.79604 .36066 L
s
1 .104 0 r
.26209 .55337 m
.26143 .55374 L
s
.26267 .55413 m
.26209 .55337 L
s
.262 .5545 m
.26267 .55413 L
s
1 .741 0 r
.53455 .55413 m
.5411 .55924 L
s
.53455 .55413 m
.54249 .55257 L
s
1 .323 0 r
.60248 .51922 m
.60356 .51985 L
s
.60248 .51922 m
.59992 .52014 L
s
1 .095 0 r
.79826 .55305 m
.79887 .55339 L
s
.79772 .55373 m
.79826 .55305 L
s
.79826 .55305 m
.79795 .55312 L
s
1 .293 0 r
.6763 .55138 m
.67787 .55221 L
s
.67489 .5537 m
.6763 .55138 L
s
.6763 .55138 m
.67466 .55182 L
s
1 .104 0 r
.26143 .55374 m
.262 .5545 L
s
1 .095 0 r
.79834 .55408 m
.79772 .55373 L
s
.79772 .55373 m
.79795 .55312 L
s
1 .293 0 r
.67645 .55454 m
.67489 .5537 L
s
.67489 .5537 m
.67466 .55182 L
s
1 .014 0 r
.07675 .52122 m
.07676 .52122 L
s
.07679 .52107 m
.07675 .52122 L
s
.07675 .52122 m
.07668 .52112 L
s
.07687 .52116 m
.07675 .52122 L
s
.07689 .52086 m
.07675 .52122 L
s
.07679 .52107 m
.07668 .52112 L
s
.07687 .52116 m
.07679 .52107 L
s
.07676 .52122 m
.07687 .52116 L
s
1 .021 0 r
.40058 .42435 m
.40066 .42432 L
s
.40066 .42432 m
.40059 .42413 L
s
.40066 .42432 m
.40042 .4243 L
s
.40059 .42413 m
.40051 .42416 L
s
.40059 .42413 m
.40042 .4243 L
s
.40042 .4243 m
.40058 .42435 L
s
.40042 .4243 m
.40051 .42416 L
s
.40125 .42401 m
.40042 .4243 L
s
1 .014 0 r
.07668 .52112 m
.07676 .52122 L
s
1 .095 0 r
.79887 .55339 m
.79834 .55408 L
s
.79795 .55312 m
.79887 .55339 L
s
.79795 .55312 m
.79834 .55408 L
s
1 .021 0 r
.40051 .42416 m
.40058 .42435 L
s
1 .035 0 r
.53609 .10138 m
.5361 .10138 L
s
.5361 .10105 m
.53609 .10138 L
s
.53642 .10122 m
.53609 .10138 L
s
.53611 .10105 m
.5361 .10105 L
s
.5361 .10105 m
.53642 .10122 L
s
1 .293 0 r
.37102 .55322 m
.37232 .55561 L
s
1 .741 0 r
.54249 .55257 m
.5411 .55924 L
s
1 .035 0 r
.53642 .10122 m
.5361 .10138 L
s
.53611 .10105 m
.53642 .10122 L
s
.53482 .10119 m
.53642 .10122 L
s
1 .003 0 r
.46814 .2626 m
.46813 .2626 L
s
.46813 .26258 m
.46814 .2626 L
s
.46816 .26259 m
.46814 .2626 L
s
1 0 0 r
.72562 .32717 m
.72562 .32717 L
s
1 .116 0 r
.65884 .48858 m
.65461 .48676 L
s
1 .003 0 r
.46803 .2626 m
.46816 .26259 L
s
.46813 .26258 m
.46813 .26258 L
s
.46813 .26258 m
.46816 .26259 L
s
.46816 .26259 m
.46813 .2626 L
s
.46813 .26258 m
.46816 .26259 L
s
.46813 .2626 m
.46813 .26258 L
s
1 .035 0 r
.5361 .10138 m
.53611 .10105 L
s
1 .114 0 r
.72681 .51948 m
.72745 .51981 L
s
.72623 .52037 m
.72681 .51948 L
s
.72681 .51948 m
.72623 .51962 L
s
.72688 .5207 m
.72623 .52037 L
s
.72623 .52037 m
.72623 .51962 L
s
1 .323 0 r
.59992 .52014 m
.60256 .52268 L
s
.59992 .52014 m
.60356 .51985 L
s
.60356 .51985 m
.60256 .52268 L
s
1 .018 0 r
.72246 .1324 m
.72253 .13241 L
s
.72252 .13224 m
.72246 .1324 L
s
.72267 .13238 m
.72246 .1324 L
s
.72258 .13225 m
.72252 .13224 L
s
.72252 .13224 m
.72267 .13238 L
s
.72267 .13238 m
.72253 .13241 L
s
.72258 .13225 m
.72267 .13238 L
s
.72193 .13211 m
.72267 .13238 L
s
1 .293 0 r
.67787 .55221 m
.67645 .55454 L
s
.67466 .55182 m
.67787 .55221 L
s
1 .018 0 r
.72253 .13241 m
.72258 .13225 L
s
1 .293 0 r
.67466 .55182 m
.67645 .55454 L
s
1 .114 0 r
.72745 .51981 m
.72688 .5207 L
s
.72623 .51962 m
.72745 .51981 L
s
1 .003 0 r
.33042 .39059 m
.33044 .39059 L
s
.33044 .39056 m
.33042 .39059 L
s
.33042 .39059 m
.33043 .39057 L
s
.33046 .39059 m
.33042 .39059 L
s
.33053 .39053 m
.33042 .39059 L
s
1 .116 0 r
.65548 .48774 m
.65499 .48749 L
s
.65499 .48749 m
.65543 .48651 L
s
.65499 .48749 m
.65461 .48676 L
s
1 .003 0 r
.33044 .39059 m
.33046 .39059 L
s
.33046 .39059 m
.33044 .39056 L
s
.33044 .39056 m
.33043 .39057 L
s
.33043 .39057 m
.33044 .39059 L
s
1 .114 0 r
.72623 .51962 m
.72688 .5207 L
s
1 .116 0 r
.65543 .48651 m
.65592 .48675 L
s
.65543 .48651 m
.65461 .48676 L
s
1 0 0 r
.65512 .29363 m
.65512 .29363 L
s
.65512 .29363 m
.65512 .29363 L
s
.65512 .29363 m
.65512 .29363 L
s
.65512 .29363 m
.65512 .29363 L
s
.65512 .29363 m
.65512 .29363 L
s
.65512 .29363 m
.65512 .29363 L
s
.65512 .29363 m
.65512 .29363 L
s
.65511 .29362 m
.65512 .29363 L
s
.65512 .29363 m
.65512 .29363 L
s
1 .039 0 r
.84603 .51974 m
.84535 .51883 L
s
1 .081 0 r
.58828 .45514 m
.58471 .45449 L
s
1 .006 0 r
.39735 .22902 m
.39759 .22896 L
s
.39756 .22899 m
.39754 .229 L
s
.39755 .22894 m
.39756 .22899 L
s
.39759 .22896 m
.39756 .22899 L
s
.39753 .22895 m
.39755 .22894 L
s
.39755 .22894 m
.39759 .22896 L
s
.39759 .22896 m
.39754 .229 L
s
.39753 .22895 m
.39759 .22896 L
s
.39754 .229 m
.39753 .22895 L
s
1 .575 0 r
.47564 .5529 m
.47641 .55192 L
s
.47641 .55192 m
.47573 .54668 L
s
.47641 .55192 m
.47048 .55031 L
s
1 .081 0 r
.58543 .45505 m
.58526 .45493 L
s
.58526 .45493 m
.58542 .4542 L
s
.58526 .45493 m
.58471 .45449 L
s
.58542 .4542 m
.58559 .45431 L
s
.58542 .4542 m
.58471 .45449 L
s
1 .035 0 r
.19225 .51946 m
.19235 .51948 L
s
.19239 .51911 m
.19225 .51946 L
s
.19225 .51946 m
.19216 .51923 L
s
.19259 .51936 m
.19225 .51946 L
s
.19285 .51863 m
.19225 .51946 L
s
.19239 .51911 m
.19216 .51923 L
s
.19259 .51936 m
.19239 .51911 L
s
.19235 .51948 m
.19259 .51936 L
s
.19216 .51923 m
.19235 .51948 L
s
1 .081 0 r
.58471 .45449 m
.58543 .45505 L
s
.58471 .45449 m
.58559 .45431 L
s
1 .039 0 r
.84547 .5188 m
.84573 .51894 L
s
.84525 .51908 m
.84547 .5188 L
s
.84547 .5188 m
.84535 .51883 L
s
1 .116 0 r
.65592 .48675 m
.65548 .48774 L
s
.65461 .48676 m
.65548 .48774 L
s
1 .039 0 r
.84551 .51922 m
.84525 .51908 L
s
.84525 .51908 m
.84535 .51883 L
s
1 .116 0 r
.65461 .48676 m
.65592 .48675 L
s
1 .575 0 r
.47573 .54668 m
.47496 .54764 L
s
.47573 .54668 m
.47048 .55031 L
s
1 .081 0 r
.58559 .45431 m
.58543 .45505 L
s
1 .039 0 r
.84573 .51894 m
.84551 .51922 L
s
.84535 .51883 m
.84573 .51894 L
s
1 .029 0 r
.65232 .09878 m
.65239 .09878 L
s
.65238 .09851 m
.65232 .09878 L
s
.65264 .0987 m
.65232 .09878 L
s
1 .039 0 r
.84535 .51883 m
.84551 .51922 L
s
1 .029 0 r
.65245 .09851 m
.65238 .09851 L
s
.65238 .09851 m
.65264 .0987 L
s
.65264 .0987 m
.65239 .09878 L
s
.65245 .09851 m
.65264 .0987 L
s
.65137 .09842 m
.65264 .0987 L
s
1 .032 0 r
.51645 .42185 m
.51646 .42181 L
s
.51646 .42181 m
.51645 .42152 L
s
.51646 .42181 m
.51616 .42169 L
s
.51645 .42152 m
.51645 .42155 L
s
.51645 .42152 m
.51616 .42169 L
s
1 .029 0 r
.65239 .09878 m
.65245 .09851 L
s
1 .032 0 r
.51616 .42169 m
.51645 .42185 L
s
.51616 .42169 m
.51645 .42155 L
s
.51763 .42166 m
.51616 .42169 L
s
1 .003 0 r
.58459 .26006 m
.58459 .26006 L
s
.58459 .26004 m
.58459 .26006 L
s
.58462 .26005 m
.58459 .26006 L
s
.5846 .26004 m
.58459 .26004 L
s
.58459 .26004 m
.58462 .26005 L
s
.58462 .26005 m
.58459 .26006 L
s
.5846 .26004 m
.58462 .26005 L
s
.5845 .26004 m
.58462 .26005 L
s
1 0 0 r
.25971 .35702 m
.25971 .35702 L
s
.25971 .35701 m
.25971 .35702 L
s
.25971 .35702 m
.25971 .35701 L
s
.25971 .35702 m
.25971 .35702 L
s
.25971 .35701 m
.25971 .35702 L
s
.25971 .35701 m
.25971 .35701 L
s
.25971 .35702 m
.25971 .35701 L
s
.25971 .35702 m
.25971 .35702 L
s
1 .003 0 r
.58459 .26006 m
.5846 .26004 L
s
1 0 0 r
.25971 .35701 m
.25971 .35702 L
s
1 .04 0 r
.77555 .48631 m
.77454 .48544 L
s
1 .032 0 r
.51645 .42155 m
.51645 .42185 L
s
1 .095 0 r
.30654 .51837 m
.30702 .51849 L
s
.30709 .51747 m
.30654 .51837 L
s
.30654 .51837 m
.30654 .51774 L
s
.30757 .51821 m
.30654 .51837 L
s
.30911 .5164 m
.30654 .51837 L
s
.30709 .51747 m
.30654 .51774 L
s
.30757 .51821 m
.30709 .51747 L
s
.30702 .51849 m
.30757 .51821 L
s
1 .04 0 r
.77473 .4854 m
.77496 .48551 L
s
.77452 .48571 m
.77473 .4854 L
s
.77473 .4854 m
.77454 .48544 L
s
.77476 .48582 m
.77452 .48571 L
s
.77452 .48571 m
.77454 .48544 L
s
1 .575 0 r
.47048 .55031 m
.47564 .5529 L
s
.47048 .55031 m
.47496 .54764 L
s
.49656 .54767 m
.47048 .55031 L
s
1 .04 0 r
.77496 .48551 m
.77476 .48582 L
s
.77454 .48544 m
.77496 .48551 L
s
.77454 .48544 m
.77476 .48582 L
s
1 .011 0 r
.12173 .48545 m
.12176 .48545 L
s
.12177 .48533 m
.12173 .48545 L
s
.12173 .48545 m
.12169 .48537 L
s
.12183 .48541 m
.12173 .48545 L
s
.12189 .48517 m
.12173 .48545 L
s
.12177 .48533 m
.12169 .48537 L
s
.12183 .48541 m
.12177 .48533 L
s
.12176 .48545 m
.12183 .48541 L
s
1 .095 0 r
.30654 .51774 m
.30702 .51849 L
s
1 .011 0 r
.12169 .48537 m
.12176 .48545 L
s
1 .006 0 r
.44668 .38821 m
.44669 .3882 L
s
.44669 .3882 m
.44668 .38815 L
s
.44669 .3882 m
.44662 .38819 L
s
.44668 .38815 m
.44666 .38815 L
s
.44668 .38815 m
.44662 .38819 L
s
.44662 .38819 m
.44668 .38821 L
s
.44662 .38819 m
.44666 .38815 L
s
.44689 .38814 m
.44662 .38819 L
s
.44666 .38815 m
.44668 .38821 L
s
1 .007 0 r
.51406 .22644 m
.51406 .22644 L
s
.51406 .22637 m
.51406 .22644 L
s
.51412 .2264 m
.51406 .22644 L
s
.51406 .22637 m
.51406 .22637 L
s
.51406 .22637 m
.51412 .2264 L
s
1 0 0 r
.7719 .2911 m
.7719 .2911 L
s
.7719 .2911 m
.7719 .2911 L
s
.7719 .2911 m
.7719 .2911 L
s
.7719 .2911 m
.7719 .2911 L
s
.77189 .2911 m
.7719 .2911 L
s
.7719 .2911 m
.7719 .2911 L
s
.7719 .2911 m
.7719 .2911 L
s
.7719 .2911 m
.7719 .2911 L
s
.7719 .2911 m
.7719 .2911 L
s
1 .035 0 r
.70498 .45283 m
.70381 .4522 L
s
1 .007 0 r
.51381 .22641 m
.51412 .2264 L
s
.51412 .2264 m
.51406 .22644 L
s
.51406 .22637 m
.51412 .2264 L
s
.51406 .22644 m
.51406 .22637 L
s
1 .241 0 r
.41796 .51792 m
.41881 .51745 L
s
.41881 .51745 m
.41805 .51535 L
s
.41881 .51745 m
.41609 .51725 L
s
.41805 .51535 m
.4172 .51582 L
s
.41805 .51535 m
.41609 .51725 L
s
.41609 .51725 m
.41796 .51792 L
s
.41609 .51725 m
.4172 .51582 L
s
.42567 .51416 m
.41609 .51725 L
s
1 .035 0 r
.70405 .45251 m
.70388 .45243 L
s
.70388 .45243 m
.70403 .45214 L
s
.70388 .45243 m
.70381 .4522 L
s
.70403 .45214 m
.7042 .45222 L
s
.70403 .45214 m
.70381 .4522 L
s
.7042 .45222 m
.70405 .45251 L
s
.70381 .4522 m
.70405 .45251 L
s
.70381 .4522 m
.7042 .45222 L
s
1 .002 0 r
.70132 .25749 m
.70132 .2575 L
s
.70132 .25748 m
.70132 .25749 L
s
.70134 .25749 m
.70132 .25749 L
s
.70133 .25748 m
.70132 .25748 L
s
.70132 .25748 m
.70134 .25749 L
s
.70134 .25749 m
.70132 .2575 L
s
.70133 .25748 m
.70134 .25749 L
s
.70127 .25747 m
.70134 .25749 L
s
.70132 .2575 m
.70133 .25748 L
s
1 0 0 r
.37605 .35458 m
.37605 .35457 L
s
.37605 .35457 m
.37605 .35457 L
s
.37605 .35457 m
.37604 .35457 L
s
.37605 .35457 m
.37605 .35457 L
s
.37605 .35457 m
.37604 .35457 L
s
.37604 .35457 m
.37605 .35458 L
s
.37604 .35457 m
.37605 .35457 L
s
.37606 .35457 m
.37604 .35457 L
s
.37605 .35457 m
.37605 .35458 L
s
1 .021 0 r
.63432 .4193 m
.63345 .41905 L
s
1 .011 0 r
.44302 .19274 m
.44353 .19266 L
s
.44344 .19273 m
.44342 .19273 L
s
.44343 .19262 m
.44344 .19273 L
s
.44353 .19266 m
.44344 .19273 L
s
.44341 .19262 m
.44343 .19262 L
s
.44343 .19262 m
.44353 .19266 L
s
.44353 .19266 m
.44342 .19273 L
s
.44341 .19262 m
.44353 .19266 L
s
.44342 .19273 m
.44341 .19262 L
s
1 .021 0 r
.63362 .41921 m
.63356 .41918 L
s
.63356 .41918 m
.63362 .41899 L
s
.63356 .41918 m
.63345 .41905 L
s
.63362 .41899 m
.63368 .41902 L
s
.63362 .41899 m
.63345 .41905 L
s
.63345 .41905 m
.63362 .41921 L
s
.63345 .41905 m
.63368 .41902 L
s
.63368 .41902 m
.63362 .41921 L
s
1 .241 0 r
.4172 .51582 m
.41796 .51792 L
s
1 .028 0 r
.23749 .48353 m
.23761 .48355 L
s
.23764 .48325 m
.23749 .48353 L
s
.23749 .48353 m
.23746 .48334 L
s
.23779 .48347 m
.23749 .48353 L
s
.23814 .48289 m
.23749 .48353 L
s
.23764 .48325 m
.23746 .48334 L
s
.23779 .48347 m
.23764 .48325 L
s
.23761 .48355 m
.23779 .48347 L
s
1 .575 0 r
.47496 .54764 m
.47564 .5529 L
s
1 .028 0 r
.23746 .48334 m
.23761 .48355 L
s
1 .006 0 r
.63075 .22386 m
.63076 .22386 L
s
.63076 .22381 m
.63075 .22386 L
s
.63081 .22385 m
.63075 .22386 L
s
.63077 .22381 m
.63076 .22381 L
s
.63076 .22381 m
.63081 .22385 L
s
.63081 .22385 m
.63076 .22386 L
s
.63077 .22381 m
.63081 .22385 L
s
.63056 .2238 m
.63081 .22385 L
s
.63076 .22386 m
.63077 .22381 L
s
1 .007 0 r
.56332 .38574 m
.56331 .38574 L
s
.56331 .38574 m
.56332 .38567 L
s
.56331 .38574 m
.56325 .3857 L
s
1 .013 0 r
.82199 .45051 m
.82168 .45022 L
s
1 .007 0 r
.56356 .38573 m
.56325 .3857 L
s
1 0 0 r
.30514 .32096 m
.30514 .32096 L
s
1 .007 0 r
.56332 .38567 m
.56332 .38568 L
s
.56332 .38567 m
.56325 .3857 L
s
.56325 .3857 m
.56332 .38574 L
s
.56325 .3857 m
.56332 .38568 L
s
.56332 .38568 m
.56332 .38574 L
s
1 .013 0 r
.82174 .45021 m
.82182 .45025 L
s
.82167 .45031 m
.82174 .45021 L
s
.82174 .45021 m
.82168 .45022 L
s
.82175 .45034 m
.82167 .45031 L
s
.82167 .45031 m
.82168 .45022 L
s
.82182 .45025 m
.82175 .45034 L
s
.82168 .45022 m
.82182 .45025 L
s
.82168 .45022 m
.82175 .45034 L
s
1 .008 0 r
.16692 .44953 m
.16695 .44953 L
s
.16696 .44945 m
.16692 .44953 L
s
.16692 .44953 m
.16691 .44947 L
s
.167 .44951 m
.16692 .44953 L
s
.16708 .44934 m
.16692 .44953 L
s
1 .075 0 r
.35216 .48192 m
.35265 .48206 L
s
.35269 .48127 m
.35216 .48192 L
s
.35216 .48192 m
.35233 .48143 L
s
.35301 .48189 m
.35216 .48192 L
s
.35468 .48061 m
.35216 .48192 L
s
1 .008 0 r
.16696 .44945 m
.16691 .44947 L
s
.167 .44951 m
.16696 .44945 L
s
.16695 .44953 m
.167 .44951 L
s
1 .075 0 r
.35265 .48206 m
.35301 .48189 L
s
.35301 .48189 m
.35269 .48127 L
s
1 .008 0 r
.16691 .44947 m
.16695 .44953 L
s
1 .075 0 r
.35269 .48127 m
.35233 .48143 L
s
1 .012 0 r
.56018 .19016 m
.56019 .19016 L
s
.56019 .19005 m
.56018 .19016 L
s
.5603 .19011 m
.56018 .19016 L
s
.5602 .19005 m
.56019 .19005 L
s
.56019 .19005 m
.5603 .19011 L
s
.5603 .19011 m
.56019 .19016 L
s
.5602 .19005 m
.5603 .19011 L
s
.55976 .19008 m
.5603 .19011 L
s
1 .001 0 r
.49269 .35212 m
.49269 .35212 L
s
.49269 .35212 m
.49269 .35212 L
s
.49269 .35212 m
.49268 .35212 L
s
.49269 .35212 m
.49269 .35212 L
s
.49269 .35212 m
.49268 .35212 L
s
.49268 .35212 m
.49269 .35212 L
s
.49268 .35212 m
.49269 .35212 L
s
.49271 .35212 m
.49268 .35212 L
s
1 .009 0 r
.75131 .41694 m
.75103 .41677 L
s
1 .001 0 r
.49269 .35212 m
.49269 .35212 L
s
1 .012 0 r
.56019 .19016 m
.5602 .19005 L
s
1 .009 0 r
.75109 .41676 m
.75113 .41677 L
s
.75105 .41683 m
.75109 .41676 L
s
.75109 .41676 m
.75103 .41677 L
s
.75109 .41685 m
.75105 .41683 L
s
.75105 .41683 m
.75103 .41677 L
s
.75113 .41677 m
.75109 .41685 L
s
.75103 .41677 m
.75113 .41677 L
s
.75103 .41677 m
.75109 .41685 L
s
1 .075 0 r
.35233 .48143 m
.35265 .48206 L
s
0 .04 1 r
.52451 .5458 m
.50146 .57444 L
s
.48379 .53439 m
.52451 .5458 L
s
1 .003 0 r
.74771 .22123 m
.74772 .22123 L
s
.74772 .2212 m
.74771 .22123 L
s
.74775 .22123 m
.74771 .22123 L
s
.74775 .22123 m
.74772 .22123 L
s
.74772 .2212 m
.74775 .22123 L
s
.74773 .22121 m
.74775 .22123 L
s
.74762 .22117 m
.74775 .22123 L
s
.74773 .22121 m
.74772 .2212 L
s
1 .018 0 r
.48952 .15635 m
.48951 .15636 L
s
.48951 .15619 m
.48952 .15635 L
s
.48967 .15626 m
.48952 .15635 L
s
1 .003 0 r
.74772 .22123 m
.74773 .22121 L
s
1 .018 0 r
.4895 .15619 m
.48951 .15619 L
s
.48951 .15619 m
.48967 .15626 L
s
1 .417 0 r
.61345 .54547 m
.5966 .54027 L
s
1 .004 0 r
.68053 .38332 m
.68039 .38327 L
s
1 0 0 r
.42177 .31846 m
.42177 .31846 L
s
1 .018 0 r
.48886 .15631 m
.48967 .15626 L
s
1 .004 0 r
.68042 .3833 m
.68041 .38329 L
s
.68041 .38329 m
.68042 .38326 L
s
.68041 .38329 m
.68039 .38327 L
s
.68042 .38326 m
.68043 .38326 L
s
.68042 .38326 m
.68039 .38327 L
s
1 .018 0 r
.48967 .15626 m
.48951 .15636 L
s
.4895 .15619 m
.48967 .15626 L
s
1 .004 0 r
.68039 .38327 m
.68042 .3833 L
s
.68039 .38327 m
.68043 .38326 L
s
.68043 .38326 m
.68042 .3833 L
s
1 .018 0 r
.48951 .15636 m
.4895 .15619 L
s
1 .323 0 r
.53063 .51301 m
.53042 .51252 L
s
.53042 .51252 m
.53062 .50954 L
s
.53042 .51252 m
.52764 .51111 L
s
1 .019 0 r
.28305 .44741 m
.28315 .44743 L
s
.28317 .44723 m
.28305 .44741 L
s
.28305 .44741 m
.28306 .44728 L
s
.28326 .44738 m
.28305 .44741 L
s
.28361 .44701 m
.28305 .44741 L
s
.28317 .44723 m
.28306 .44728 L
s
.28326 .44738 m
.28317 .44723 L
s
.28315 .44743 m
.28326 .44738 L
s
1 .323 0 r
.53062 .50954 m
.53082 .51003 L
s
.53062 .50954 m
.52764 .51111 L
s
1 .019 0 r
.28306 .44728 m
.28315 .44743 L
s
1 .151 0 r
.46615 .47995 m
.46643 .47972 L
s
.46643 .47972 m
.46618 .47835 L
s
.46643 .47972 m
.46482 .47936 L
s
.46618 .47835 m
.46589 .47857 L
s
.46618 .47835 m
.46482 .47936 L
s
1 .009 0 r
.67707 .18753 m
.67709 .18753 L
s
.67709 .18745 m
.67707 .18753 L
s
.67717 .18751 m
.67707 .18753 L
s
.67712 .18745 m
.67709 .18745 L
s
.67709 .18745 m
.67717 .18751 L
s
.67717 .18751 m
.67709 .18753 L
s
.67712 .18745 m
.67717 .18751 L
s
.6768 .18741 m
.67717 .18751 L
s
.67709 .18753 m
.67712 .18745 L
s
1 .323 0 r
.54254 .51192 m
.52764 .51111 L
s
1 .001 0 r
.60967 .34966 m
.60964 .34966 L
s
1 0 0 r
.35074 .28476 m
.35075 .28476 L
s
1 .001 0 r
.60965 .34966 m
.60965 .34966 L
s
.60965 .34966 m
.60965 .34966 L
s
.60965 .34966 m
.60964 .34966 L
s
1 0 0 r
.35074 .28476 m
.35074 .28476 L
s
.35074 .28476 m
.35074 .28476 L
s
.35075 .28476 m
.35074 .28476 L
s
.35074 .28476 m
.35074 .28476 L
s
.35074 .28476 m
.35075 .28476 L
s
1 .001 0 r
.60965 .34966 m
.60965 .34966 L
s
.60965 .34966 m
.60964 .34966 L
s
1 0 0 r
.35075 .28476 m
.35074 .28476 L
s
.35074 .28476 m
.35075 .28476 L
s
.35074 .28476 m
.35074 .28476 L
s
1 .001 0 r
.60964 .34966 m
.60965 .34966 L
s
.60964 .34966 m
.60965 .34966 L
s
.60965 .34966 m
.60965 .34966 L
s
1 .151 0 r
.46482 .47936 m
.46615 .47995 L
s
.46482 .47936 m
.46589 .47857 L
s
.47154 .47832 m
.46482 .47936 L
s
.46589 .47857 m
.46615 .47995 L
s
1 .323 0 r
.52764 .51111 m
.53063 .51301 L
s
.52764 .51111 m
.53082 .51003 L
s
1 .016 0 r
.60644 .15376 m
.60647 .15376 L
s
.60647 .15361 m
.60644 .15376 L
s
.60661 .1537 m
.60644 .15376 L
s
.60649 .15361 m
.60647 .15361 L
s
.60647 .15361 m
.60661 .1537 L
s
1 .004 0 r
.21233 .41347 m
.21235 .41347 L
s
.21235 .41343 m
.21233 .41347 L
s
.21233 .41347 m
.21233 .41344 L
s
.21237 .41346 m
.21233 .41347 L
s
.21244 .41338 m
.21233 .41347 L
s
1 .016 0 r
.60661 .1537 m
.60647 .15376 L
s
.60649 .15361 m
.60661 .1537 L
s
.60589 .1536 m
.60661 .1537 L
s
1 .004 0 r
.21235 .41343 m
.21233 .41344 L
s
.21237 .41346 m
.21235 .41343 L
s
.21235 .41347 m
.21237 .41346 L
s
.21233 .41344 m
.21235 .41347 L
s
1 .016 0 r
.60647 .15376 m
.60649 .15361 L
s
1 .002 0 r
.79781 .3809 m
.79777 .38087 L
s
1 .158 0 r
.73064 .54326 m
.72634 .54002 L
s
1 0 0 r
.53871 .31596 m
.53871 .31596 L
s
1 .002 0 r
.79778 .38087 m
.79778 .38087 L
s
.79777 .38088 m
.79778 .38087 L
s
.79778 .38087 m
.79777 .38087 L
s
.79778 .38089 m
.79777 .38088 L
s
.79777 .38088 m
.79777 .38087 L
s
.79778 .38087 m
.79778 .38089 L
s
.79777 .38087 m
.79778 .38087 L
s
.79777 .38087 m
.79778 .38089 L
s
1 .323 0 r
.53082 .51003 m
.53063 .51301 L
s
1 .046 0 r
.39898 .44541 m
.39914 .44533 L
s
.39914 .44533 m
.399 .44493 L
s
.39914 .44533 m
.39863 .44529 L
s
.399 .44493 m
.39883 .44501 L
s
.399 .44493 m
.39863 .44529 L
s
.39863 .44529 m
.39898 .44541 L
s
.39863 .44529 m
.39883 .44501 L
s
.40044 .44468 m
.39863 .44529 L
s
1 .417 0 r
.60003 .54358 m
.59862 .54272 L
s
.59862 .54272 m
.59993 .53905 L
s
.59862 .54272 m
.5966 .54027 L
s
1 .022 0 r
.07374 .5427 m
.07376 .54271 L
s
.0738 .54247 m
.07374 .5427 L
s
.07374 .5427 m
.07364 .54256 L
s
.07392 .54262 m
.07374 .5427 L
s
.07395 .54216 m
.07374 .5427 L
s
.0738 .54247 m
.07364 .54256 L
s
.07392 .54262 m
.0738 .54247 L
s
.07376 .54271 m
.07392 .54262 L
s
.07364 .54256 m
.07376 .54271 L
s
1 .046 0 r
.39883 .44501 m
.39898 .44541 L
s
1 .417 0 r
.59993 .53905 m
.60133 .5399 L
s
.59993 .53905 m
.5966 .54027 L
s
1 .023 0 r
.53574 .11987 m
.53575 .11987 L
s
.53575 .11965 m
.53574 .11987 L
s
.53596 .11977 m
.53574 .11987 L
s
.53575 .11965 m
.53575 .11965 L
s
.53575 .11965 m
.53596 .11977 L
s
.53596 .11977 m
.53575 .11987 L
s
.53575 .11965 m
.53596 .11977 L
s
.53488 .11975 m
.53596 .11977 L
s
1 0 0 r
.46767 .28221 m
.46767 .28221 L
s
.46767 .28221 m
.46767 .28221 L
s
.46768 .28221 m
.46767 .28221 L
s
.72693 .3472 m
.72692 .3472 L
s
1 .172 0 r
.65971 .50967 m
.65338 .50698 L
s
1 0 0 r
.46766 .28221 m
.46768 .28221 L
s
.46767 .28221 m
.46767 .28221 L
s
.46767 .28221 m
.46768 .28221 L
s
.46768 .28221 m
.46767 .28221 L
s
.46767 .28221 m
.46768 .28221 L
s
.46767 .28221 m
.46767 .28221 L
s
.72692 .3472 m
.72692 .3472 L
s
.72692 .3472 m
.72692 .3472 L
s
.72692 .3472 m
.72692 .3472 L
s
.72692 .3472 m
.72692 .3472 L
s
.72692 .3472 m
.72692 .3472 L
s
.72692 .3472 m
.72692 .3472 L
s
.72692 .3472 m
.72692 .3472 L
s
.72692 .3472 m
.72692 .3472 L
s
1 .023 0 r
.53575 .11987 m
.53575 .11965 L
s
0 .04 1 r
.48379 .53439 m
.50146 .57444 L
s
1 .01 0 r
.32891 .41117 m
.32897 .41119 L
s
.32898 .41109 m
.32891 .41117 L
s
.32891 .41117 m
.32893 .41111 L
s
.32902 .41117 m
.32891 .41117 L
s
.32925 .411 m
.32891 .41117 L
s
.32897 .41119 m
.32902 .41117 L
s
.32902 .41117 m
.32898 .41109 L
s
.32898 .41109 m
.32893 .41111 L
s
1 .011 0 r
.72355 .15106 m
.72359 .15106 L
s
.72358 .15096 m
.72355 .15106 L
s
.72367 .15104 m
.72355 .15106 L
s
.72362 .15096 m
.72358 .15096 L
s
.72358 .15096 m
.72367 .15104 L
s
.72367 .15104 m
.72359 .15106 L
s
.72362 .15096 m
.72367 .15104 L
s
.72322 .15088 m
.72367 .15104 L
s
1 .051 0 r
.18979 .54116 m
.18994 .5412 L
s
.19 .54064 m
.18979 .54116 L
s
.18979 .54116 m
.18965 .54083 L
s
.19029 .54101 m
.18979 .54116 L
s
.19067 .53995 m
.18979 .54116 L
s
1 .01 0 r
.32893 .41111 m
.32897 .41119 L
s
1 .011 0 r
.72359 .15106 m
.72362 .15096 L
s
1 .158 0 r
.72714 .53981 m
.72805 .54028 L
s
.72635 .54105 m
.72714 .53981 L
s
.72714 .53981 m
.72634 .54002 L
s
1 .051 0 r
.19 .54064 m
.18965 .54083 L
s
.19029 .54101 m
.19 .54064 L
s
1 .057 0 r
.84814 .54105 m
.84713 .53972 L
s
1 .137 0 r
.58869 .47602 m
.58263 .47494 L
s
1 0 0 r
.65596 .31345 m
.65596 .31345 L
s
1 .002 0 r
.39652 .24842 m
.39659 .2484 L
s
1 .158 0 r
.72725 .54153 m
.72635 .54105 L
s
.72635 .54105 m
.72634 .54002 L
s
1 .002 0 r
.39658 .24842 m
.39658 .24842 L
s
.39658 .2484 m
.39658 .24842 L
s
.39659 .2484 m
.39658 .24842 L
s
.39657 .2484 m
.39658 .2484 L
s
.39658 .2484 m
.39659 .2484 L
s
.39659 .2484 m
.39658 .24842 L
s
.39657 .2484 m
.39659 .2484 L
s
.39658 .24842 m
.39657 .2484 L
s
1 .051 0 r
.18994 .5412 m
.19029 .54101 L
s
.18965 .54083 m
.18994 .5412 L
s
1 .137 0 r
.58385 .47589 m
.58356 .47568 L
s
.58356 .47568 m
.58383 .47443 L
s
.58356 .47568 m
.58263 .47494 L
s
.58383 .47443 m
.58412 .47463 L
s
.58383 .47443 m
.58263 .47494 L
s
1 .172 0 r
.65468 .50844 m
.65395 .50807 L
s
.65395 .50807 m
.65461 .50659 L
s
.65395 .50807 m
.65338 .50698 L
s
.65461 .50659 m
.65534 .50697 L
s
.65461 .50659 m
.65338 .50698 L
s
1 .134 0 r
.30407 .54048 m
.30474 .54066 L
s
.30484 .53921 m
.30407 .54048 L
s
.30407 .54048 m
.30407 .5396 L
s
.30552 .54026 m
.30407 .54048 L
s
.30769 .53773 m
.30407 .54048 L
s
.30484 .53921 m
.30407 .5396 L
s
.30552 .54026 m
.30484 .53921 L
s
1 .158 0 r
.72805 .54028 m
.72725 .54153 L
s
.72634 .54002 m
.72805 .54028 L
s
1 .417 0 r
.5966 .54027 m
.60003 .54358 L
s
.5966 .54027 m
.60133 .5399 L
s
1 .134 0 r
.30474 .54066 m
.30552 .54026 L
s
1 .068 0 r
.51507 .44275 m
.51509 .44266 L
s
.51509 .44266 m
.51507 .44203 L
s
.51509 .44266 m
.51444 .4424 L
s
1 .158 0 r
.72634 .54002 m
.72725 .54153 L
s
1 .068 0 r
.51507 .44203 m
.51505 .44212 L
s
.51507 .44203 m
.51444 .4424 L
s
1 .417 0 r
.60133 .5399 m
.60003 .54358 L
s
1 .057 0 r
.8473 .53968 m
.84769 .53988 L
s
.84698 .54009 m
.8473 .53968 L
s
.8473 .53968 m
.84713 .53972 L
s
1 .019 0 r
.65284 .11722 m
.65288 .11722 L
s
.65288 .11704 m
.65284 .11722 L
s
.65305 .11717 m
.65284 .11722 L
s
.65292 .11704 m
.65288 .11704 L
s
.65288 .11704 m
.65305 .11717 L
s
.65305 .11717 m
.65288 .11722 L
s
.65292 .11704 m
.65305 .11717 L
s
.6522 .11698 m
.65305 .11717 L
s
1 .057 0 r
.84736 .54029 m
.84698 .54009 L
s
.84698 .54009 m
.84713 .53972 L
s
1 .019 0 r
.65288 .11722 m
.65292 .11704 L
s
1 .137 0 r
.58263 .47494 m
.58385 .47589 L
s
.58263 .47494 m
.58412 .47463 L
s
1 .068 0 r
.51444 .4424 m
.51507 .44275 L
s
.51444 .4424 m
.51505 .44212 L
s
.51758 .44234 m
.51444 .4424 L
s
1 .002 0 r
.25793 .3773 m
.25793 .3773 L
s
.25794 .37728 m
.25793 .3773 L
s
.25793 .3773 m
.25793 .37729 L
s
.25794 .3773 m
.25793 .3773 L
s
.25797 .37727 m
.25793 .3773 L
s
.25794 .37728 m
.25793 .37729 L
s
.25794 .3773 m
.25794 .37728 L
s
.25793 .3773 m
.25794 .3773 L
s
.25793 .37729 m
.25793 .3773 L
s
1 0 0 r
.5849 .27966 m
.5849 .27966 L
s
.5849 .27966 m
.5849 .27966 L
s
.58491 .27966 m
.5849 .27966 L
s
.5849 .27966 m
.5849 .27966 L
s
.5849 .27966 m
.58491 .27966 L
s
.58491 .27966 m
.5849 .27966 L
s
.5849 .27966 m
.58491 .27966 L
s
.58489 .27966 m
.58491 .27966 L
s
.5849 .27966 m
.5849 .27966 L
s
1 .063 0 r
.77719 .50741 m
.77559 .50605 L
s
1 .057 0 r
.84769 .53988 m
.84736 .54029 L
s
.84713 .53972 m
.84769 .53988 L
s
1 .137 0 r
.58412 .47463 m
.58385 .47589 L
s
1 .057 0 r
.84713 .53972 m
.84736 .54029 L
s
1 .318 0 r
.41476 .54048 m
.4159 .53982 L
s
.4159 .53982 m
.41488 .53703 L
s
.4159 .53982 m
.41228 .53956 L
s
1 .068 0 r
.51505 .44212 m
.51507 .44275 L
s
1 .318 0 r
.41488 .53703 m
.41375 .53768 L
s
.41488 .53703 m
.41228 .53956 L
s
1 .134 0 r
.30407 .5396 m
.30474 .54066 L
s
1 .172 0 r
.65534 .50697 m
.65468 .50844 L
s
.65338 .50698 m
.65468 .50844 L
s
1 .318 0 r
.41228 .53956 m
.41476 .54048 L
s
.41228 .53956 m
.41375 .53768 L
s
.42501 .5355 m
.41228 .53956 L
s
1 .172 0 r
.65338 .50698 m
.65534 .50697 L
s
1 .018 0 r
.11898 .50673 m
.11902 .50674 L
s
.11904 .50654 m
.11898 .50673 L
s
.11898 .50673 m
.11891 .50661 L
s
.11915 .50667 m
.11898 .50673 L
s
.11925 .50628 m
.11898 .50673 L
s
.11904 .50654 m
.11891 .50661 L
s
.11915 .50667 m
.11904 .50654 L
s
.11902 .50674 m
.11915 .50667 L
s
.11891 .50661 m
.11902 .50674 L
s
1 .063 0 r
.77588 .50598 m
.77626 .50617 L
s
.77555 .50647 m
.77588 .50598 L
s
.77588 .50598 m
.77559 .50605 L
s
1 .02 0 r
.44569 .40884 m
.44573 .40882 L
s
.44573 .40882 m
.44569 .40864 L
s
.44573 .40882 m
.44552 .40878 L
s
1 .063 0 r
.77593 .50666 m
.77555 .50647 L
s
.77555 .50647 m
.77559 .50605 L
s
1 .02 0 r
.44569 .40864 m
.44565 .40867 L
s
.44569 .40864 m
.44552 .40878 L
s
1 .028 0 r
.58207 .08326 m
.5821 .08326 L
s
.5821 .083 m
.58207 .08326 L
s
.58235 .08315 m
.58207 .08326 L
s
1 .02 0 r
.44552 .40878 m
.44569 .40884 L
s
.44552 .40878 m
.44565 .40867 L
s
.44638 .40861 m
.44552 .40878 L
s
1 .028 0 r
.58213 .083 m
.5821 .083 L
s
.5821 .083 m
.58235 .08315 L
s
.58235 .08315 m
.5821 .08326 L
s
.58213 .083 m
.58235 .08315 L
s
.58108 .08304 m
.58235 .08315 L
s
1 .02 0 r
.44565 .40867 m
.44569 .40884 L
s
1 .002 0 r
.51381 .24583 m
.51381 .24583 L
s
.51381 .24581 m
.51381 .24583 L
s
.51383 .24582 m
.51381 .24583 L
s
.51381 .24581 m
.51381 .24581 L
s
.51381 .24581 m
.51383 .24582 L
s
1 0 0 r
.77351 .31094 m
.77351 .31094 L
s
1 .062 0 r
.70616 .47372 m
.70407 .47262 L
s
1 .002 0 r
.51373 .24582 m
.51383 .24582 L
s
.51383 .24582 m
.51381 .24583 L
s
.51381 .24581 m
.51383 .24582 L
s
1 .028 0 r
.5821 .08326 m
.58213 .083 L
s
1 .002 0 r
.51381 .24583 m
.51381 .24581 L
s
1 .063 0 r
.77626 .50617 m
.77593 .50666 L
s
.77559 .50605 m
.77626 .50617 L
s
.77559 .50605 m
.77593 .50666 L
s
1 .062 0 r
.70451 .47317 m
.70421 .47303 L
s
.70421 .47303 m
.70447 .47252 L
s
.70421 .47303 m
.70407 .47262 L
s
.70447 .47252 m
.70477 .47266 L
s
.70447 .47252 m
.70407 .47262 L
s
1 .318 0 r
.41375 .53768 m
.41476 .54048 L
s
1 .062 0 r
.70477 .47266 m
.70451 .47317 L
s
.70407 .47262 m
.70451 .47317 L
s
.70407 .47262 m
.70477 .47266 L
s
1 .003 0 r
.37498 .37489 m
.37499 .37488 L
s
.37499 .37488 m
.37498 .37485 L
s
.37499 .37488 m
.37495 .37488 L
s
.37498 .37485 m
.37497 .37486 L
s
.37498 .37485 m
.37495 .37488 L
s
.37495 .37488 m
.37498 .37489 L
s
.37495 .37488 m
.37497 .37486 L
s
.37508 .37483 m
.37495 .37488 L
s
.37497 .37486 m
.37498 .37489 L
s
1 0 0 r
.70243 .2771 m
.70243 .2771 L
s
.70243 .2771 m
.70243 .2771 L
s
.70244 .2771 m
.70243 .2771 L
s
.70244 .2771 m
.70243 .2771 L
s
.70243 .2771 m
.70244 .2771 L
s
.70244 .2771 m
.70243 .2771 L
s
.70244 .2771 m
.70244 .2771 L
s
.70243 .2771 m
.70244 .2771 L
s
.70243 .2771 m
.70244 .2771 L
s
1 .046 0 r
.63503 .43999 m
.63314 .43945 L
s
1 .005 0 r
.44248 .21194 m
.4427 .21191 L
s
.44267 .21194 m
.44266 .21194 L
s
.44266 .21189 m
.44267 .21194 L
s
.4427 .21191 m
.44267 .21194 L
s
.44265 .21189 m
.44266 .21189 L
s
.44266 .21189 m
.4427 .21191 L
s
.4427 .21191 m
.44266 .21194 L
s
.44265 .21189 m
.4427 .21191 L
s
.44266 .21194 m
.44265 .21189 L
s
1 .045 0 r
.23522 .50503 m
.2354 .50507 L
s
.23544 .50458 m
.23522 .50503 L
s
.23522 .50503 m
.23516 .50472 L
s
.23569 .50493 m
.23522 .50503 L
s
.23625 .50402 m
.23522 .50503 L
s
.23544 .50458 m
.23516 .50472 L
s
.23569 .50493 m
.23544 .50458 L
s
.2354 .50507 m
.23569 .50493 L
s
1 .046 0 r
.63353 .4398 m
.63338 .43973 L
s
.63338 .43973 m
.63351 .43932 L
s
.63338 .43973 m
.63314 .43945 L
s
.63351 .43932 m
.63366 .43939 L
s
.63351 .43932 m
.63314 .43945 L
s
1 .045 0 r
.23516 .50472 m
.2354 .50507 L
s
1 .046 0 r
.63314 .43945 m
.63353 .4398 L
s
.63314 .43945 m
.63366 .43939 L
s
.63366 .43939 m
.63353 .4398 L
s
1 .022 0 r
.69936 .08053 m
.69943 .08053 L
s
.69942 .08033 m
.69936 .08053 L
s
.69961 .08048 m
.69936 .08053 L
s
.69948 .08033 m
.69942 .08033 L
s
.69942 .08033 m
.69961 .08048 L
s
.69961 .08048 m
.69943 .08053 L
s
.69948 .08033 m
.69961 .08048 L
s
.69869 .08022 m
.69961 .08048 L
s
.69943 .08053 m
.69948 .08033 L
s
1 .002 0 r
.63131 .24324 m
.63131 .24324 L
s
.63131 .24322 m
.63131 .24324 L
s
.63133 .24323 m
.63131 .24324 L
s
.63132 .24322 m
.63131 .24322 L
s
.63131 .24322 m
.63133 .24323 L
s
1 .021 0 r
.56304 .40625 m
.56301 .40623 L
s
.56301 .40623 m
.56304 .40603 L
s
.56301 .40623 m
.56284 .40613 L
s
1 .002 0 r
.63133 .24323 m
.63131 .24324 L
s
.63132 .24322 m
.63133 .24323 L
s
.63125 .24322 m
.63133 .24323 L
s
.63131 .24324 m
.63132 .24322 L
s
1 0 0 r
.30368 .34102 m
.30368 .34102 L
s
.30368 .34102 m
.30368 .34102 L
s
.30368 .34102 m
.30368 .34102 L
s
.30368 .34102 m
.30368 .34102 L
s
.30369 .34102 m
.30368 .34102 L
s
.30368 .34102 m
.30368 .34102 L
s
.30368 .34102 m
.30368 .34102 L
s
.30368 .34102 m
.30368 .34102 L
s
.30368 .34102 m
.30368 .34102 L
s
1 .023 0 r
.82394 .47142 m
.82338 .47089 L
s
1 .021 0 r
.56381 .40622 m
.56284 .40613 L
s
.56304 .40603 m
.56306 .40606 L
s
.56304 .40603 m
.56284 .40613 L
s
.56284 .40613 m
.56304 .40625 L
s
.56284 .40613 m
.56306 .40606 L
s
.56306 .40606 m
.56304 .40625 L
s
1 .114 0 r
.34969 .50374 m
.35043 .50395 L
s
.3505 .50273 m
.34969 .50374 L
s
.34969 .50374 m
.34994 .503 L
s
.35098 .50368 m
.34969 .50374 L
s
.35356 .50175 m
.34969 .50374 L
s
.35043 .50395 m
.35098 .50368 L
s
.35098 .50368 m
.3505 .50273 L
s
1 .023 0 r
.82348 .47087 m
.82362 .47094 L
s
.82336 .47105 m
.82348 .47087 L
s
.82348 .47087 m
.82338 .47089 L
s
1 .114 0 r
.3505 .50273 m
.34994 .503 L
s
1 .023 0 r
.8235 .47112 m
.82336 .47105 L
s
.82336 .47105 m
.82338 .47089 L
s
.82362 .47094 m
.8235 .47112 L
s
.82338 .47089 m
.82362 .47094 L
s
.82338 .47089 m
.8235 .47112 L
s
1 .014 0 r
.16444 .4706 m
.16449 .47061 L
s
.1645 .47046 m
.16444 .4706 L
s
.16444 .4706 m
.16441 .4705 L
s
.16458 .47056 m
.16444 .4706 L
s
.16472 .47026 m
.16444 .4706 L
s
.1645 .47046 m
.16441 .4705 L
s
.16458 .47056 m
.1645 .47046 L
s
.16449 .47061 m
.16458 .47056 L
s
.16441 .4705 m
.16449 .47061 L
s
1 .114 0 r
.34994 .503 m
.35043 .50395 L
s
1 .005 0 r
.49231 .37244 m
.49232 .37243 L
s
.49232 .37243 m
.49231 .37238 L
s
.49232 .37243 m
.49227 .37241 L
s
.56017 .20932 m
.56018 .20933 L
s
.56017 .20928 m
.56017 .20932 L
s
.56022 .2093 m
.56017 .20932 L
s
.49231 .37238 m
.49231 .37239 L
s
.49231 .37238 m
.49227 .37241 L
s
.56018 .20928 m
.56017 .20928 L
s
.56017 .20928 m
.56022 .2093 L
s
.49227 .37241 m
.49231 .37244 L
s
.49227 .37241 m
.49231 .37239 L
s
.4925 .3724 m
.49227 .37241 L
s
.56022 .2093 m
.56018 .20933 L
s
.56018 .20928 m
.56022 .2093 L
s
.55998 .20929 m
.56022 .2093 L
s
1 .019 0 r
.75279 .43764 m
.75218 .43726 L
s
1 .005 0 r
.49231 .37239 m
.49231 .37244 L
s
.56018 .20933 m
.56018 .20928 L
s
1 .019 0 r
.7523 .43724 m
.7524 .43728 L
s
.75221 .4374 m
.7523 .43724 L
s
.7523 .43724 m
.75218 .43726 L
s
.75231 .43744 m
.75221 .4374 L
s
.75221 .4374 m
.75218 .43726 L
s
.7524 .43728 m
.75231 .43744 L
s
.75218 .43726 m
.7524 .43728 L
s
.75218 .43726 m
.75231 .43744 L
s
1 .01 0 r
.48898 .17534 m
.48897 .17534 L
s
.48897 .17525 m
.48898 .17534 L
s
.48906 .17529 m
.48898 .17534 L
s
1 .001 0 r
.74911 .24062 m
.74911 .24062 L
s
.74911 .24061 m
.74911 .24062 L
s
.74912 .24062 m
.74911 .24062 L
s
.74912 .24062 m
.74911 .24062 L
s
.74911 .24061 m
.74912 .24062 L
s
.74912 .24061 m
.74912 .24062 L
s
.74908 .2406 m
.74912 .24062 L
s
.74912 .24061 m
.74911 .24061 L
s
.74911 .24062 m
.74912 .24061 L
s
1 .01 0 r
.48897 .17525 m
.48897 .17525 L
s
.48897 .17525 m
.48906 .17529 L
s
1 0 0 r
.42108 .33854 m
.42108 .33854 L
s
.42108 .33854 m
.42108 .33853 L
s
.42108 .33854 m
.42107 .33854 L
s
.42108 .33853 m
.42107 .33853 L
s
.42108 .33853 m
.42107 .33854 L
s
.42107 .33854 m
.42108 .33854 L
s
.42107 .33854 m
.42107 .33853 L
s
.42109 .33853 m
.42107 .33854 L
s
.42107 .33853 m
.42108 .33854 L
s
1 .012 0 r
.68155 .40382 m
.6811 .40364 L
s
1 .01 0 r
.48862 .17532 m
.48906 .17529 L
s
.48906 .17529 m
.48897 .17534 L
s
.48897 .17525 m
.48906 .17529 L
s
.48897 .17534 m
.48897 .17525 L
s
1 .012 0 r
.68119 .40374 m
.68114 .40372 L
s
.68114 .40372 m
.68118 .40362 L
s
.68114 .40372 m
.6811 .40364 L
s
.68118 .40362 m
.68123 .40364 L
s
.68118 .40362 m
.6811 .40364 L
s
.6811 .40364 m
.68119 .40374 L
s
.6811 .40364 m
.68123 .40364 L
s
.68123 .40364 m
.68119 .40374 L
s
1 .22 0 r
.46326 .50186 m
.46367 .50151 L
s
.46367 .50151 m
.4633 .49949 L
s
.46367 .50151 m
.46131 .50097 L
s
1 .417 0 r
.52716 .53472 m
.52691 .53405 L
s
.52691 .53405 m
.52716 .53018 L
s
.52691 .53405 m
.52329 .53224 L
s
1 .035 0 r
.281 .46866 m
.28119 .4687 L
s
.28122 .46833 m
.281 .46866 L
s
.281 .46866 m
.28102 .46842 L
s
.28139 .46861 m
.281 .46866 L
s
.28202 .46794 m
.281 .46866 L
s
1 .22 0 r
.4633 .49949 m
.46289 .49984 L
s
.4633 .49949 m
.46131 .50097 L
s
1 .035 0 r
.28122 .46833 m
.28102 .46842 L
s
.28139 .46861 m
.28122 .46833 L
s
.28119 .4687 m
.28139 .46861 L
s
.28102 .46842 m
.28119 .4687 L
s
1 .22 0 r
.46131 .50097 m
.46326 .50186 L
s
.46131 .50097 m
.46289 .49984 L
s
.47118 .49947 m
.46131 .50097 L
s
1 .417 0 r
.52716 .53018 m
.52742 .53085 L
s
.52716 .53018 m
.52329 .53224 L
s
1 .004 0 r
.67792 .20668 m
.67793 .20668 L
s
.67793 .20665 m
.67792 .20668 L
s
.67796 .20667 m
.67792 .20668 L
s
.67794 .20665 m
.67793 .20665 L
s
.67793 .20665 m
.67796 .20667 L
s
.67796 .20667 m
.67793 .20668 L
s
.67794 .20665 m
.67796 .20667 L
s
.6778 .20663 m
.67796 .20667 L
s
.67793 .20668 m
.67794 .20665 L
s
.61022 .36995 m
.61004 .36992 L
s
1 .417 0 r
.54265 .53327 m
.52329 .53224 L
s
1 0 0 r
.34959 .30462 m
.34959 .30462 L
s
1 .004 0 r
.61008 .36994 m
.61007 .36994 L
s
.61007 .36994 m
.61008 .3699 L
s
.61007 .36994 m
.61004 .36992 L
s
.61008 .3699 m
.61009 .36991 L
s
.61008 .3699 m
.61004 .36992 L
s
.61004 .36992 m
.61008 .36994 L
s
.61004 .36992 m
.61009 .36991 L
s
.61009 .36991 m
.61008 .36994 L
s
1 .22 0 r
.46289 .49984 m
.46326 .50186 L
s
1 .01 0 r
.21013 .43431 m
.21018 .43432 L
s
.21019 .43422 m
.21013 .43431 L
s
.21013 .43431 m
.21013 .43424 L
s
.21024 .43429 m
.21013 .43431 L
s
.21037 .4341 m
.21013 .43431 L
s
.21019 .43422 m
.21013 .43424 L
s
.21024 .43429 m
.21019 .43422 L
s
.21018 .43432 m
.21024 .43429 L
s
.21013 .43424 m
.21018 .43432 L
s
1 .417 0 r
.52329 .53224 m
.52716 .53472 L
s
.52329 .53224 m
.52742 .53085 L
s
1 .009 0 r
.60672 .17269 m
.60673 .1727 L
s
.60673 .17261 m
.60672 .17269 L
s
.60681 .17267 m
.60672 .17269 L
s
.60675 .17262 m
.60673 .17261 L
s
.60673 .17261 m
.60681 .17267 L
s
.60681 .17267 m
.60673 .1727 L
s
.60675 .17262 m
.60681 .17267 L
s
.60642 .17261 m
.60681 .17267 L
s
.60673 .1727 m
.60675 .17262 L
s
1 0 0 r
.53878 .33604 m
.53878 .33604 L
s
.53878 .33604 m
.53878 .33604 L
s
.53878 .33604 m
.53878 .33604 L
s
.53878 .33604 m
.53878 .33604 L
s
.53878 .33604 m
.53878 .33604 L
s
1 .005 0 r
.79961 .40141 m
.79946 .40131 L
s
1 0 0 r
.5388 .33604 m
.53878 .33604 L
s
.53878 .33604 m
.53878 .33604 L
s
.53878 .33604 m
.53878 .33604 L
s
.53878 .33604 m
.53878 .33604 L
s
1 .08 0 r
.39705 .4669 m
.39734 .46675 L
s
.39734 .46675 m
.39708 .46605 L
s
.39734 .46675 m
.39643 .46668 L
s
1 .005 0 r
.79949 .4013 m
.79951 .40131 L
s
.79946 .40134 m
.79949 .4013 L
s
.79949 .4013 m
.79946 .40131 L
s
.79949 .40135 m
.79946 .40134 L
s
.79946 .40134 m
.79946 .40131 L
s
1 .08 0 r
.39708 .46605 m
.39679 .46619 L
s
.39708 .46605 m
.39643 .46668 L
s
1 .005 0 r
.79951 .40131 m
.79949 .40135 L
s
.79946 .40131 m
.79951 .40131 L
s
.79946 .40131 m
.79949 .40135 L
s
1 .08 0 r
.39643 .46668 m
.39705 .4669 L
s
.39643 .46668 m
.39679 .46619 L
s
.39962 .46562 m
.39643 .46668 L
s
.39679 .46619 m
.39705 .4669 L
s
1 .417 0 r
.52742 .53085 m
.52716 .53472 L
s
1 .014 0 r
.53547 .13862 m
.53548 .13862 L
s
.53548 .13849 m
.53547 .13862 L
s
.53561 .13856 m
.53547 .13862 L
s
.53548 .13849 m
.53548 .13849 L
s
.53548 .13849 m
.53561 .13856 L
s
.53561 .13856 m
.53548 .13862 L
s
.53548 .13849 m
.53561 .13856 L
s
.53494 .13855 m
.53561 .13856 L
s
1 .002 0 r
.72826 .3675 m
.72818 .36746 L
s
1 .233 0 r
.6606 .53104 m
.65196 .52742 L
s
1 0 0 r
.46728 .30208 m
.46728 .30208 L
s
1 .002 0 r
.7282 .36748 m
.72819 .36748 L
s
.72819 .36748 m
.7282 .36746 L
s
.72819 .36748 m
.72818 .36746 L
s
.7282 .36746 m
.72821 .36746 L
s
.7282 .36746 m
.72818 .36746 L
s
.72821 .36746 m
.7282 .36748 L
s
.72818 .36746 m
.7282 .36748 L
s
.72818 .36746 m
.72821 .36746 L
s
1 .014 0 r
.53548 .13862 m
.53548 .13849 L
s
1 .022 0 r
.32718 .43212 m
.32733 .43216 L
s
.32735 .43192 m
.32718 .43212 L
s
.32718 .43212 m
.32724 .43197 L
s
.32744 .43211 m
.32718 .43212 L
s
.32796 .43173 m
.32718 .43212 L
s
.32733 .43216 m
.32744 .43211 L
s
.32744 .43211 m
.32735 .43192 L
s
.32735 .43192 m
.32724 .43197 L
s
.32724 .43197 m
.32733 .43216 L
s
1 .006 0 r
.7247 .16999 m
.72472 .16999 L
s
.72472 .16994 m
.7247 .16999 L
s
.72477 .16998 m
.7247 .16999 L
s
.72474 .16994 m
.72472 .16994 L
s
.72472 .16994 m
.72477 .16998 L
s
.72477 .16998 m
.72472 .16999 L
s
.72474 .16994 m
.72477 .16998 L
s
.72453 .1699 m
.72477 .16998 L
s
.72472 .16999 m
.72474 .16994 L
s
1 .202 0 r
.58911 .49719 m
.58012 .4956 L
s
1 0 0 r
.65682 .33354 m
.65681 .33354 L
s
.39567 .26808 m
.39568 .26808 L
s
.39568 .26808 m
.39567 .26808 L
s
.39567 .26808 m
.39568 .26808 L
s
.39568 .26808 m
.39568 .26808 L
s
.39567 .26808 m
.39567 .26808 L
s
.39567 .26808 m
.39568 .26808 L
s
.65681 .33354 m
.65681 .33354 L
s
.65681 .33354 m
.65681 .33354 L
s
.65681 .33354 m
.65681 .33354 L
s
.65681 .33354 m
.65681 .33354 L
s
.65681 .33354 m
.65681 .33354 L
s
.39568 .26808 m
.39567 .26808 L
s
.39567 .26808 m
.39568 .26808 L
s
.39567 .26808 m
.39567 .26808 L
s
.65681 .33354 m
.65681 .33354 L
s
.65681 .33354 m
.65681 .33354 L
s
.65681 .33354 m
.65681 .33354 L
s
1 .202 0 r
.58194 .497 m
.58151 .49668 L
s
.58151 .49668 m
.5819 .49483 L
s
.58151 .49668 m
.58012 .4956 L
s
1 .116 0 r
.51321 .46399 m
.51324 .46384 L
s
.51324 .46384 m
.51321 .46276 L
s
.51324 .46384 m
.51213 .4634 L
s
1 .202 0 r
.5819 .49483 m
.58233 .49515 L
s
.5819 .49483 m
.58012 .4956 L
s
1 .116 0 r
.51321 .46276 m
.51318 .46291 L
s
.51321 .46276 m
.51213 .4634 L
s
1 .012 0 r
.65343 .13593 m
.65346 .13593 L
s
.65345 .13582 m
.65343 .13593 L
s
.65356 .1359 m
.65343 .13593 L
s
.65348 .13582 m
.65345 .13582 L
s
.65345 .13582 m
.65356 .1359 L
s
1 .116 0 r
.51213 .4634 m
.51321 .46399 L
s
.51213 .4634 m
.51318 .46291 L
s
.51753 .46329 m
.51213 .4634 L
s
1 .005 0 r
.25606 .39789 m
.25608 .3979 L
s
.25609 .39785 m
.25606 .39789 L
s
.25606 .39789 m
.25606 .39786 L
s
.25611 .39789 m
.25606 .39789 L
s
.25621 .39779 m
.25606 .39789 L
s
1 .012 0 r
.65356 .1359 m
.65346 .13593 L
s
.65348 .13582 m
.65356 .1359 L
s
.65303 .13579 m
.65356 .1359 L
s
1 .005 0 r
.25609 .39785 m
.25606 .39786 L
s
.25611 .39789 m
.25609 .39785 L
s
.25608 .3979 m
.25611 .39789 L
s
1 .233 0 r
.65374 .52941 m
.65274 .52888 L
s
.65274 .52888 m
.65364 .52687 L
s
.65274 .52888 m
.65196 .52742 L
s
1 .005 0 r
.25606 .39786 m
.25608 .3979 L
s
1 .012 0 r
.65346 .13593 m
.65348 .13582 L
s
1 .233 0 r
.65364 .52687 m
.65464 .5274 L
s
.65364 .52687 m
.65196 .52742 L
s
1 .091 0 r
.77886 .52879 m
.77654 .52685 L
s
1 0 0 r
.58528 .29954 m
.58528 .29954 L
s
1 .116 0 r
.51318 .46291 m
.51321 .46399 L
s
1 .202 0 r
.58012 .4956 m
.58194 .497 L
s
.58012 .4956 m
.58233 .49515 L
s
1 .028 0 r
.11616 .52835 m
.11622 .52836 L
s
.11626 .52806 m
.11616 .52835 L
s
.11616 .52835 m
.11606 .52816 L
s
.11642 .52826 m
.11616 .52835 L
s
.11657 .52767 m
.11616 .52835 L
s
.11626 .52806 m
.11606 .52816 L
s
.11642 .52826 m
.11626 .52806 L
s
.11622 .52836 m
.11642 .52826 L
s
.11606 .52816 m
.11622 .52836 L
s
1 .043 0 r
.44435 .42986 m
.44444 .42981 L
s
.44444 .42981 m
.44436 .42942 L
s
.44444 .42981 m
.44398 .42971 L
s
1 .202 0 r
.58233 .49515 m
.58194 .497 L
s
1 .043 0 r
.44436 .42942 m
.44426 .42947 L
s
.44436 .42942 m
.44398 .42971 L
s
.44398 .42971 m
.44435 .42986 L
s
.44398 .42971 m
.44426 .42947 L
s
.44586 .42935 m
.44398 .42971 L
s
.44426 .42947 m
.44435 .42986 L
s
1 .018 0 r
.58212 .10178 m
.58214 .10178 L
s
.58213 .10161 m
.58212 .10178 L
s
.5823 .10171 m
.58212 .10178 L
s
.58215 .1016 m
.58213 .10161 L
s
.58213 .10161 m
.5823 .10171 L
s
.5823 .10171 m
.58214 .10178 L
s
.58215 .1016 m
.5823 .10171 L
s
.58145 .10163 m
.5823 .10171 L
s
1 0 0 r
.51366 .26549 m
.51366 .26549 L
s
.51366 .26549 m
.51366 .26549 L
s
.51367 .26549 m
.51366 .26549 L
s
.51366 .26549 m
.51366 .26549 L
s
.51366 .26549 m
.51367 .26549 L
s
.77515 .33104 m
.77515 .33103 L
s
1 .095 0 r
.70736 .4949 m
.7041 .49321 L
s
1 0 0 r
.51365 .26549 m
.51367 .26549 L
s
.51367 .26549 m
.51366 .26549 L
s
.51366 .26549 m
.51367 .26549 L
s
.51366 .26549 m
.51366 .26549 L
s
.77515 .33103 m
.77515 .33103 L
s
.77515 .33103 m
.77515 .33103 L
s
.77515 .33103 m
.77515 .33103 L
s
.77515 .33103 m
.77515 .33103 L
s
.77515 .33103 m
.77515 .33103 L
s
.77515 .33103 m
.77515 .33103 L
s
.77515 .33103 m
.77515 .33103 L
s
.77515 .33103 m
.77515 .33103 L
s
1 .018 0 r
.58214 .10178 m
.58215 .1016 L
s
1 .091 0 r
.77696 .52674 m
.77751 .52702 L
s
.77649 .52745 m
.77696 .52674 L
s
.77696 .52674 m
.77654 .52685 L
s
1 .233 0 r
.65464 .5274 m
.65374 .52941 L
s
.65196 .52742 m
.65374 .52941 L
s
1 .091 0 r
.77704 .52773 m
.77649 .52745 L
s
.77649 .52745 m
.77654 .52685 L
s
1 .233 0 r
.65196 .52742 m
.65464 .5274 L
s
1 .091 0 r
.77751 .52702 m
.77704 .52773 L
s
.77654 .52685 m
.77751 .52702 L
s
.77654 .52685 m
.77704 .52773 L
s
1 .066 0 r
.23283 .52688 m
.2331 .52695 L
s
.23316 .52623 m
.23283 .52688 L
s
.23283 .52688 m
.23274 .52644 L
s
.23351 .52674 m
.23283 .52688 L
s
.23434 .52542 m
.23283 .52688 L
s
.23316 .52623 m
.23274 .52644 L
s
.23351 .52674 m
.23316 .52623 L
s
.2331 .52695 m
.23351 .52674 L
s
1 .011 0 r
.37375 .39554 m
.37379 .39553 L
s
.37379 .39553 m
.37375 .39543 L
s
.37379 .39553 m
.37367 .39552 L
s
.37375 .39543 m
.37371 .39545 L
s
.37375 .39543 m
.37367 .39552 L
s
.37367 .39552 m
.37375 .39554 L
s
.37367 .39552 m
.37371 .39545 L
s
.37409 .39537 m
.37367 .39552 L
s
1 .095 0 r
.70478 .49406 m
.70432 .49384 L
s
.70432 .49384 m
.70473 .49303 L
s
.70432 .49384 m
.7041 .49321 L
s
1 .011 0 r
.37371 .39545 m
.37375 .39554 L
s
1 .095 0 r
.70473 .49303 m
.70519 .49326 L
s
.70473 .49303 m
.7041 .49321 L
s
1 .08 0 r
.63576 .46096 m
.63243 .46002 L
s
1 0 0 r
.7036 .29699 m
.7036 .29699 L
s
1 .002 0 r
.44193 .2314 m
.442 .23139 L
s
.44199 .2314 m
.44198 .2314 L
s
.44199 .23138 m
.44199 .2314 L
s
.442 .23139 m
.44199 .2314 L
s
.44198 .23138 m
.44199 .23138 L
s
.44199 .23138 m
.442 .23139 L
s
.442 .23139 m
.44198 .2314 L
s
.44198 .23138 m
.442 .23139 L
s
.44198 .2314 m
.44198 .23138 L
s
1 .066 0 r
.23274 .52644 m
.2331 .52695 L
s
1 .08 0 r
.63311 .46063 m
.63286 .4605 L
s
.63286 .4605 m
.63308 .45978 L
s
.63286 .4605 m
.63243 .46002 L
s
1 .095 0 r
.70519 .49326 m
.70478 .49406 L
s
.7041 .49321 m
.70478 .49406 L
s
.7041 .49321 m
.70519 .49326 L
s
1 .08 0 r
.63308 .45978 m
.63334 .45991 L
s
.63308 .45978 m
.63243 .46002 L
s
1 .158 0 r
.34701 .52592 m
.34804 .52623 L
s
.34814 .52451 m
.34701 .52592 L
s
.34701 .52592 m
.34737 .52489 L
s
.34882 .52584 m
.34701 .52592 L
s
.35242 .52316 m
.34701 .52592 L
s
.34804 .52623 m
.34882 .52584 L
s
.34882 .52584 m
.34814 .52451 L
s
.34814 .52451 m
.34737 .52489 L
s
1 .08 0 r
.63243 .46002 m
.63311 .46063 L
s
.63243 .46002 m
.63334 .45991 L
s
.63334 .45991 m
.63311 .46063 L
s
1 .014 0 r
.70029 .09902 m
.70033 .09902 L
s
.70032 .09889 m
.70029 .09902 L
s
.70045 .09899 m
.70029 .09902 L
s
.70037 .09889 m
.70032 .09889 L
s
.70032 .09889 m
.70045 .09899 L
s
.70045 .09899 m
.70033 .09902 L
s
.70037 .09889 m
.70045 .09899 L
s
.69984 .09882 m
.70045 .09899 L
s
.70033 .09902 m
.70037 .09889 L
s
1 .046 0 r
.56238 .42706 m
.56233 .427 L
s
.56233 .427 m
.56238 .42658 L
s
.56233 .427 m
.56196 .42678 L
s
1 .002 0 r
.30216 .36137 m
.30217 .36137 L
s
.30218 .36136 m
.30216 .36137 L
s
.30216 .36137 m
.30217 .36136 L
s
.30218 .36137 m
.30216 .36137 L
s
.30222 .36134 m
.30216 .36137 L
s
.30217 .36137 m
.30218 .36137 L
s
.30218 .36137 m
.30218 .36136 L
s
.30218 .36136 m
.30217 .36136 L
s
.30217 .36136 m
.30217 .36137 L
s
1 0 0 r
.63196 .2629 m
.63196 .2629 L
s
.63196 .26289 m
.63196 .2629 L
s
.63196 .2629 m
.63196 .2629 L
s
.63196 .26289 m
.63196 .26289 L
s
.63196 .26289 m
.63196 .2629 L
s
.63196 .2629 m
.63196 .2629 L
s
.63196 .26289 m
.63196 .2629 L
s
.63195 .26289 m
.63196 .2629 L
s
.63196 .2629 m
.63196 .26289 L
s
1 .038 0 r
.82591 .4926 m
.82501 .49177 L
s
1 .046 0 r
.56407 .42697 m
.56196 .42678 L
s
.56238 .42658 m
.56243 .42663 L
s
.56238 .42658 m
.56196 .42678 L
s
.56196 .42678 m
.56238 .42706 L
s
.56196 .42678 m
.56243 .42663 L
s
.56243 .42663 m
.56238 .42706 L
s
1 .158 0 r
.34737 .52489 m
.34804 .52623 L
s
1 .038 0 r
.82517 .49173 m
.82541 .49185 L
s
.82497 .49202 m
.82517 .49173 L
s
.82517 .49173 m
.82501 .49177 L
s
.82521 .49214 m
.82497 .49202 L
s
.82497 .49202 m
.82501 .49177 L
s
1 .023 0 r
.16187 .49201 m
.16195 .49202 L
s
.16198 .49177 m
.16187 .49201 L
s
.16187 .49201 m
.16182 .49185 L
s
.16211 .49194 m
.16187 .49201 L
s
.16234 .49145 m
.16187 .49201 L
s
.16198 .49177 m
.16182 .49185 L
s
.16211 .49194 m
.16198 .49177 L
s
.16195 .49202 m
.16211 .49194 L
s
.16182 .49185 m
.16195 .49202 L
s
1 .038 0 r
.82541 .49185 m
.82521 .49214 L
s
.82501 .49177 m
.82541 .49185 L
s
.82501 .49177 m
.82521 .49214 L
s
1 .022 0 r
.62889 .0648 m
.62893 .0648 L
s
.62892 .06459 m
.62889 .0648 L
s
.62912 .06473 m
.62889 .0648 L
s
.62896 .06459 m
.62892 .06459 L
s
.62892 .06459 m
.62912 .06473 L
s
.62912 .06473 m
.62893 .0648 L
s
.62896 .06459 m
.62912 .06473 L
s
.62814 .06457 m
.62912 .06473 L
s
1 .016 0 r
.49169 .39307 m
.4917 .39305 L
s
.4917 .39305 m
.49169 .3929 L
s
.4917 .39305 m
.49154 .393 L
s
.49169 .3929 m
.49167 .39292 L
s
.49169 .3929 m
.49154 .393 L
s
.49154 .393 m
.49169 .39307 L
s
.49154 .393 m
.49167 .39292 L
s
.49228 .39294 m
.49154 .393 L
s
1 .022 0 r
.62893 .0648 m
.62896 .06459 L
s
1 .002 0 r
.56027 .22877 m
.56027 .22877 L
s
.56027 .22875 m
.56027 .22877 L
s
.56029 .22876 m
.56027 .22877 L
s
.56027 .22875 m
.56027 .22875 L
s
.56027 .22875 m
.56029 .22876 L
s
.56029 .22876 m
.56027 .22877 L
s
.56027 .22875 m
.56029 .22876 L
s
.56021 .22876 m
.56029 .22876 L
s
1 .035 0 r
.7543 .45862 m
.75319 .45794 L
s
1 .002 0 r
.56027 .22877 m
.56027 .22875 L
s
1 .016 0 r
.49167 .39292 m
.49169 .39307 L
s
1 .035 0 r
.7534 .45789 m
.75358 .45797 L
s
.75324 .45818 m
.7534 .45789 L
s
.7534 .45789 m
.75319 .45794 L
s
.75342 .45826 m
.75324 .45818 L
s
.75324 .45818 m
.75319 .45794 L
s
.75358 .45797 m
.75342 .45826 L
s
.75319 .45794 m
.75358 .45797 L
s
.75319 .45794 m
.75342 .45826 L
s
1 .293 0 r
.46021 .52408 m
.46077 .52359 L
s
.46077 .52359 m
.46027 .5209 L
s
.46077 .52359 m
.4576 .52289 L
s
.46027 .5209 m
.45971 .52138 L
s
.46027 .5209 m
.4576 .52289 L
s
1 .003 0 r
.42029 .35891 m
.4203 .3589 L
s
.4203 .3589 m
.42029 .35887 L
s
.4203 .3589 m
.42026 .3589 L
s
.42029 .35887 m
.42028 .35888 L
s
.42029 .35887 m
.42026 .3589 L
s
.42026 .3589 m
.42029 .35891 L
s
.42026 .3589 m
.42028 .35888 L
s
.4204 .35887 m
.42026 .3589 L
s
.42028 .35888 m
.42029 .35891 L
s
1 .004 0 r
.48854 .19458 m
.48853 .19458 L
s
.48853 .19454 m
.48854 .19458 L
s
.48857 .19456 m
.48854 .19458 L
s
.48853 .19454 m
.48853 .19454 L
s
.48853 .19454 m
.48857 .19456 L
s
1 0 0 r
.75057 .26029 m
.75057 .26029 L
s
.75057 .26029 m
.75057 .26029 L
s
.75057 .26029 m
.75057 .26029 L
s
.75057 .26029 m
.75057 .26029 L
s
.75057 .26029 m
.75057 .26029 L
s
.75057 .26029 m
.75057 .26029 L
s
.75056 .26029 m
.75057 .26029 L
s
.75057 .26029 m
.75057 .26029 L
s
.75057 .26029 m
.75057 .26029 L
s
1 .026 0 r
.68259 .42458 m
.68157 .4242 L
s
1 .004 0 r
.48838 .19457 m
.48857 .19456 L
s
.48857 .19456 m
.48853 .19458 L
s
.48853 .19454 m
.48857 .19456 L
s
.48853 .19458 m
.48853 .19454 L
s
1 .055 0 r
.27879 .49027 m
.27909 .49035 L
s
.27913 .48975 m
.27879 .49027 L
s
.27879 .49027 m
.27882 .4899 L
s
.2794 .4902 m
.27879 .49027 L
s
.2804 .48915 m
.27879 .49027 L
s
.27913 .48975 m
.27882 .4899 L
s
.2794 .4902 m
.27913 .48975 L
s
.27909 .49035 m
.2794 .4902 L
s
1 .026 0 r
.68178 .42442 m
.68168 .42437 L
s
.68168 .42437 m
.68177 .42414 L
s
.68168 .42437 m
.68157 .4242 L
s
.68177 .42414 m
.68187 .42419 L
s
.68177 .42414 m
.68157 .4242 L
s
1 .293 0 r
.4576 .52289 m
.46021 .52408 L
s
.4576 .52289 m
.45971 .52138 L
s
.47082 .5209 m
.4576 .52289 L
s
1 .026 0 r
.68157 .4242 m
.68178 .42442 L
s
.68157 .4242 m
.68187 .42419 L
s
.68187 .42419 m
.68178 .42442 L
s
1 .055 0 r
.27882 .4899 m
.27909 .49035 L
s
1 .001 0 r
.67884 .22612 m
.67885 .22612 L
s
.67885 .22611 m
.67884 .22612 L
s
.67886 .22612 m
.67884 .22612 L
s
.67885 .22611 m
.67885 .22611 L
s
.67885 .22611 m
.67886 .22612 L
s
.67886 .22612 m
.67885 .22612 L
s
.67885 .22611 m
.67886 .22612 L
s
.67881 .2261 m
.67886 .22612 L
s
.67885 .22612 m
.67885 .22611 L
s
1 0 0 r
.34842 .32475 m
.34842 .32475 L
s
.34842 .32475 m
.34842 .32475 L
s
.34842 .32475 m
.34841 .32475 L
s
.34842 .32475 m
.34842 .32475 L
s
.34842 .32475 m
.34841 .32475 L
s
.34841 .32475 m
.34842 .32475 L
s
.34841 .32475 m
.34842 .32475 L
s
.34842 .32475 m
.34841 .32475 L
s
.34842 .32475 m
.34842 .32475 L
s
1 .013 0 r
.61079 .39051 m
.6102 .3904 L
s
.61032 .39049 m
.61029 .39047 L
s
.61029 .39047 m
.61031 .39035 L
s
.61029 .39047 m
.6102 .3904 L
s
.61031 .39035 m
.61034 .39036 L
s
.61031 .39035 m
.6102 .3904 L
s
.6102 .3904 m
.61032 .39049 L
s
.6102 .3904 m
.61034 .39036 L
s
.61034 .39036 m
.61032 .39049 L
s
1 .293 0 r
.45971 .52138 m
.46021 .52408 L
s
1 .121 0 r
.39485 .48878 m
.39529 .48855 L
s
.39529 .48855 m
.3949 .48747 L
s
.39529 .48855 m
.3939 .48845 L
s
.3949 .48747 m
.39446 .4877 L
s
.3949 .48747 m
.3939 .48845 L
s
.3939 .48845 m
.39485 .48878 L
s
.3939 .48845 m
.39446 .4877 L
s
.39879 .48684 m
.3939 .48845 L
s
1 .018 0 r
.20784 .45549 m
.20792 .4555 L
s
.20794 .45531 m
.20784 .45549 L
s
.20784 .45549 m
.20783 .45536 L
s
.20803 .45545 m
.20784 .45549 L
s
.20829 .45509 m
.20784 .45549 L
s
.20794 .45531 m
.20783 .45536 L
s
.20803 .45545 m
.20794 .45531 L
s
.20792 .4555 m
.20803 .45545 L
s
.20783 .45536 m
.20792 .4555 L
s
1 .004 0 r
.60709 .19191 m
.60709 .19191 L
s
.60709 .19187 m
.60709 .19191 L
s
.60713 .1919 m
.60709 .19191 L
s
.6071 .19187 m
.60709 .19187 L
s
.60709 .19187 m
.60713 .1919 L
s
.60713 .1919 m
.60709 .19191 L
s
.6071 .19187 m
.60713 .1919 L
s
.60695 .19187 m
.60713 .1919 L
s
.53875 .3564 m
.53875 .3564 L
s
.53875 .3564 m
.53875 .35636 L
s
.53875 .3564 m
.53872 .35638 L
s
.53875 .35636 m
.53875 .35637 L
s
.53875 .35636 m
.53872 .35638 L
s
.60709 .19191 m
.6071 .19187 L
s
1 .011 0 r
.80143 .42219 m
.80109 .42196 L
s
1 .004 0 r
.53889 .35638 m
.53872 .35638 L
s
.53872 .35638 m
.53875 .3564 L
s
.53872 .35638 m
.53875 .35637 L
s
.53875 .35637 m
.53875 .3564 L
s
1 .011 0 r
.80115 .42194 m
.80122 .42197 L
s
.8011 .42203 m
.80115 .42194 L
s
.80115 .42194 m
.80109 .42196 L
s
.80116 .42206 m
.8011 .42203 L
s
.8011 .42203 m
.80109 .42196 L
s
.80122 .42197 m
.80116 .42206 L
s
.80109 .42196 m
.80122 .42197 L
s
.80109 .42196 m
.80116 .42206 L
s
1 .121 0 r
.39446 .4877 m
.39485 .48878 L
s
1 .008 0 r
.53529 .15764 m
.5353 .15764 L
s
.5353 .15756 m
.53529 .15764 L
s
.53537 .1576 m
.53529 .15764 L
s
.5353 .15756 m
.5353 .15756 L
s
.5353 .15756 m
.53537 .1576 L
s
.53537 .1576 m
.5353 .15764 L
s
.5353 .15756 m
.53537 .1576 L
s
.53501 .1576 m
.53537 .1576 L
s
1 0 0 r
.46688 .32222 m
.46688 .32222 L
s
.46688 .32222 m
.46688 .32222 L
s
.46688 .32222 m
.46688 .32222 L
s
.46688 .32222 m
.46688 .32222 L
s
.46688 .32222 m
.46688 .32222 L
s
.46688 .32222 m
.46688 .32222 L
s
.46688 .32222 m
.46688 .32222 L
s
.4669 .32222 m
.46688 .32222 L
s
.46688 .32222 m
.46688 .32222 L
s
1 .007 0 r
.72961 .38807 m
.72935 .38795 L
s
1 .008 0 r
.5353 .15764 m
.5353 .15756 L
s
1 .007 0 r
.72941 .38801 m
.72938 .388 L
s
.72938 .388 m
.7294 .38794 L
s
.72938 .388 m
.72935 .38795 L
s
.7294 .38794 m
.72943 .38795 L
s
.7294 .38794 m
.72935 .38795 L
s
.72943 .38795 m
.72941 .38801 L
s
.72935 .38795 m
.72941 .38801 L
s
.72935 .38795 m
.72943 .38795 L
s
1 .04 0 r
.32524 .45344 m
.32551 .45351 L
s
.32553 .45308 m
.32524 .45344 L
s
.32524 .45344 m
.32534 .45317 L
s
.3257 .45343 m
.32524 .45344 L
s
.32665 .45274 m
.32524 .45344 L
s
.32551 .45351 m
.3257 .45343 L
s
.3257 .45343 m
.32553 .45308 L
s
.32553 .45308 m
.32534 .45317 L
s
.32534 .45317 m
.32551 .45351 L
s
1 .003 0 r
.72592 .18921 m
.72593 .18921 L
s
.72593 .18918 m
.72592 .18921 L
s
.72596 .1892 m
.72592 .18921 L
s
.72594 .18918 m
.72593 .18918 L
s
.72593 .18918 m
.72596 .1892 L
s
.72596 .1892 m
.72593 .18921 L
s
.72594 .18918 m
.72596 .1892 L
s
.72585 .18917 m
.72596 .1892 L
s
.72593 .18921 m
.72594 .18918 L
s
1 .271 0 r
.58954 .51863 m
.57742 .51651 L
s
1 .003 0 r
.65769 .3539 m
.65758 .35387 L
s
1 0 0 r
.39481 .288 m
.39481 .288 L
s
1 .003 0 r
.65761 .35389 m
.6576 .35388 L
s
.6576 .35388 m
.65761 .35386 L
s
.6576 .35388 m
.65758 .35387 L
s
.65761 .35386 m
.65761 .35386 L
s
.65761 .35386 m
.65758 .35387 L
s
.65758 .35387 m
.65761 .35389 L
s
.65758 .35387 m
.65761 .35386 L
s
.65761 .35386 m
.65761 .35389 L
s
1 .172 0 r
.51101 .48558 m
.51105 .48534 L
s
.51105 .48534 m
.51101 .48372 L
s
.51105 .48534 m
.50939 .48468 L
s
.51101 .48372 m
.51097 .48396 L
s
.51101 .48372 m
.50939 .48468 L
s
1 .271 0 r
.57987 .51841 m
.57929 .51795 L
s
.57929 .51795 m
.57982 .51546 L
s
.57929 .51795 m
.57742 .51651 L
s
.57982 .51546 m
.58039 .51592 L
s
.57982 .51546 m
.57742 .51651 L
s
1 .011 0 r
.25407 .41882 m
.25414 .41883 L
s
.25415 .41871 m
.25407 .41882 L
s
.25407 .41882 m
.25408 .41874 L
s
.2542 .41881 m
.25407 .41882 L
s
.25442 .41859 m
.25407 .41882 L
s
.25415 .41871 m
.25408 .41874 L
s
.2542 .41881 m
.25415 .41871 L
s
.25414 .41883 m
.2542 .41881 L
s
1 .172 0 r
.50939 .48468 m
.51101 .48558 L
s
.50939 .48468 m
.51097 .48396 L
s
.51748 .48452 m
.50939 .48468 L
s
1 .011 0 r
.25408 .41874 m
.25414 .41883 L
s
1 .006 0 r
.65409 .15492 m
.65411 .15492 L
s
.65411 .15486 m
.65409 .15492 L
s
.65417 .1549 m
.65409 .15492 L
s
.65412 .15486 m
.65411 .15486 L
s
.65411 .15486 m
.65417 .1549 L
s
.65417 .1549 m
.65411 .15492 L
s
.65412 .15486 m
.65417 .1549 L
s
.65388 .15484 m
.65417 .1549 L
s
.65411 .15492 m
.65412 .15486 L
s
1 0 0 r
.58568 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
1 .172 0 r
.51097 .48396 m
.51101 .48558 L
s
1 .075 0 r
.44266 .45127 m
.44283 .45116 L
s
.44283 .45116 m
.44268 .45048 L
s
.44283 .45116 m
.44201 .451 L
s
.44268 .45048 m
.44251 .45058 L
s
.44268 .45048 m
.44201 .451 L
s
.44201 .451 m
.44266 .45127 L
s
.44201 .451 m
.44251 .45058 L
s
.44533 .45037 m
.44201 .451 L
s
.44251 .45058 m
.44266 .45127 L
s
1 .271 0 r
.57742 .51651 m
.57987 .51841 L
s
.57742 .51651 m
.58039 .51592 L
s
1 .011 0 r
.58223 .12056 m
.58224 .12056 L
s
.58224 .12046 m
.58223 .12056 L
s
.58235 .12052 m
.58223 .12056 L
s
.58225 .12046 m
.58224 .12046 L
s
.58224 .12046 m
.58235 .12052 L
s
.58235 .12052 m
.58224 .12056 L
s
.58225 .12046 m
.58235 .12052 L
s
.58182 .12047 m
.58235 .12052 L
s
1 .001 0 r
.77681 .3514 m
.77677 .35138 L
s
1 .134 0 r
.70857 .51635 m
.70397 .514 L
s
1 0 0 r
.51358 .28542 m
.51358 .28542 L
s
1 .011 0 r
.58224 .12056 m
.58225 .12046 L
s
1 .001 0 r
.77678 .35139 m
.77677 .35139 L
s
.77677 .35139 m
.77678 .35138 L
s
.77677 .35139 m
.77677 .35138 L
s
.77678 .35138 m
.77678 .35138 L
s
.77678 .35138 m
.77677 .35138 L
s
.77678 .35138 m
.77678 .35139 L
s
.77677 .35138 m
.77678 .35139 L
s
.77677 .35138 m
.77678 .35138 L
s
1 .271 0 r
.58039 .51592 m
.57987 .51841 L
s
1 .023 0 r
.37232 .41656 m
.37241 .41652 L
s
.37241 .41652 m
.37233 .41631 L
s
.37241 .41652 m
.37214 .4165 L
s
.37233 .41631 m
.37225 .41635 L
s
.37233 .41631 m
.37214 .4165 L
s
.37214 .4165 m
.37232 .41656 L
s
.37214 .4165 m
.37225 .41635 L
s
.37308 .41618 m
.37214 .4165 L
s
.37225 .41635 m
.37232 .41656 L
s
1 .121 0 r
.63649 .4822 m
.63139 .48078 L
s
1 0 0 r
.70479 .31714 m
.70478 .31714 L
s
.44137 .25112 m
.44138 .25112 L
s
.44138 .25112 m
.44138 .25112 L
s
.44138 .25112 m
.44138 .25112 L
s
.44138 .25112 m
.44138 .25112 L
s
.44138 .25112 m
.44138 .25112 L
s
.44138 .25112 m
.44138 .25112 L
s
.44138 .25112 m
.44138 .25112 L
s
.44138 .25112 m
.44138 .25112 L
s
.70478 .31714 m
.70478 .31714 L
s
.70478 .31714 m
.70478 .31714 L
s
.70478 .31714 m
.70478 .31714 L
s
.44138 .25112 m
.44138 .25112 L
s
.70478 .31714 m
.70478 .31714 L
s
.70478 .31714 m
.70478 .31714 L
s
.70478 .31714 m
.70478 .31714 L
s
.70478 .31714 m
.70478 .31714 L
s
.70478 .31714 m
.70478 .31714 L
s
1 .134 0 r
.70493 .5152 m
.70427 .51487 L
s
.70427 .51487 m
.70485 .51374 L
s
.70427 .51487 m
.70397 .514 L
s
.70485 .51374 m
.70551 .51406 L
s
.70485 .51374 m
.70397 .514 L
s
1 .121 0 r
.63243 .48172 m
.63204 .48151 L
s
.63204 .48151 m
.63239 .48041 L
s
.63204 .48151 m
.63139 .48078 L
s
.63239 .48041 m
.63278 .48062 L
s
.63239 .48041 m
.63139 .48078 L
s
1 .009 0 r
.70127 .11779 m
.7013 .11779 L
s
.70129 .11771 m
.70127 .11779 L
s
.70137 .11777 m
.70127 .11779 L
s
.70132 .11771 m
.70129 .11771 L
s
.70129 .11771 m
.70137 .11777 L
s
1 .006 0 r
.30054 .38204 m
.30058 .38204 L
s
.30058 .38199 m
.30054 .38204 L
s
.30054 .38204 m
.30055 .382 L
s
.3006 .38203 m
.30054 .38204 L
s
.30074 .38194 m
.30054 .38204 L
s
.30058 .38204 m
.3006 .38203 L
s
.3006 .38203 m
.30058 .38199 L
s
.30058 .38199 m
.30055 .382 L
s
1 .009 0 r
.70137 .11777 m
.7013 .11779 L
s
.70132 .11771 m
.70137 .11777 L
s
.701 .11766 m
.70137 .11777 L
s
1 .006 0 r
.30055 .382 m
.30058 .38204 L
s
1 .08 0 r
.56137 .44816 m
.56128 .44806 L
s
.56128 .44806 m
.56136 .44731 L
s
.56128 .44806 m
.56062 .44767 L
s
1 .009 0 r
.7013 .11779 m
.70132 .11771 L
s
1 .134 0 r
.70551 .51406 m
.70493 .5152 L
s
.70397 .514 m
.70493 .5152 L
s
1 .055 0 r
.82791 .51407 m
.82658 .51285 L
s
1 .08 0 r
.56433 .448 m
.56062 .44767 L
s
1 0 0 r
.63266 .28283 m
.63266 .28283 L
s
1 .134 0 r
.70397 .514 m
.70551 .51406 L
s
1 .08 0 r
.56136 .44731 m
.56145 .44741 L
s
.56136 .44731 m
.56062 .44767 L
s
1 .121 0 r
.63139 .48078 m
.63243 .48172 L
s
.63139 .48078 m
.63278 .48062 L
s
1 .08 0 r
.56062 .44767 m
.56137 .44816 L
s
.56062 .44767 m
.56145 .44741 L
s
1 .121 0 r
.63278 .48062 m
.63243 .48172 L
s
1 .035 0 r
.15922 .51375 m
.15934 .51377 L
s
.15938 .51339 m
.15922 .51375 L
s
.15922 .51375 m
.15915 .51351 L
s
.15958 .51366 m
.15922 .51375 L
s
.15992 .51293 m
.15922 .51375 L
s
.15938 .51339 m
.15915 .51351 L
s
.15958 .51366 m
.15938 .51339 L
s
.15934 .51377 m
.15958 .51366 L
s
1 .08 0 r
.56145 .44741 m
.56137 .44816 L
s
1 .035 0 r
.15915 .51351 m
.15934 .51377 L
s
1 .055 0 r
.82682 .5128 m
.82717 .51297 L
s
.82653 .51323 m
.82682 .5128 L
s
.82682 .5128 m
.82658 .51285 L
s
.82688 .5134 m
.82653 .51323 L
s
.82653 .51323 m
.82658 .51285 L
s
1 .035 0 r
.49075 .41404 m
.49079 .414 L
s
.49079 .414 m
.49076 .41367 L
s
.49079 .414 m
.49043 .41388 L
s
.49076 .41367 m
.49073 .41371 L
s
.49076 .41367 m
.49043 .41388 L
s
1 .014 0 r
.62933 .08335 m
.62935 .08335 L
s
.62935 .08322 m
.62933 .08335 L
s
.62948 .0833 m
.62933 .08335 L
s
1 .035 0 r
.49043 .41388 m
.49075 .41404 L
s
.49043 .41388 m
.49073 .41371 L
s
.49206 .41376 m
.49043 .41388 L
s
1 .014 0 r
.62937 .08322 m
.62935 .08322 L
s
.62935 .08322 m
.62948 .0833 L
s
.62948 .0833 m
.62935 .08335 L
s
.62937 .08322 m
.62948 .0833 L
s
.62883 .0832 m
.62948 .0833 L
s
1 .055 0 r
.82717 .51297 m
.82688 .5134 L
s
.82658 .51285 m
.82717 .51297 L
s
1 .014 0 r
.62935 .08335 m
.62937 .08322 L
s
1 .055 0 r
.82658 .51285 m
.82688 .5134 L
s
1 0 0 r
.56045 .24848 m
.56045 .24848 L
s
.56045 .24848 m
.56045 .24848 L
s
.56045 .24848 m
.56045 .24848 L
s
.56045 .24848 m
.56045 .24848 L
s
.56045 .24848 m
.56045 .24848 L
s
.56045 .24848 m
.56045 .24848 L
s
.56045 .24848 m
.56045 .24848 L
s
.56044 .24848 m
.56045 .24848 L
s
1 .055 0 r
.75582 .47987 m
.75405 .47881 L
s
1 0 0 r
.56045 .24848 m
.56045 .24848 L
s
1 .035 0 r
.49073 .41371 m
.49075 .41404 L
s
1 .055 0 r
.75439 .47872 m
.75469 .47886 L
s
.75413 .47918 m
.75439 .47872 L
s
.75439 .47872 m
.75405 .47881 L
s
.75443 .47932 m
.75413 .47918 L
s
.75413 .47918 m
.75405 .47881 L
s
1 .08 0 r
.27642 .51225 m
.27686 .51237 L
s
.27693 .51149 m
.27642 .51225 L
s
.27642 .51225 m
.27647 .51171 L
s
.27732 .51214 m
.27642 .51225 L
s
.27877 .51064 m
.27642 .51225 L
s
.27693 .51149 m
.27647 .51171 L
s
.27732 .51214 m
.27693 .51149 L
s
.27686 .51237 m
.27732 .51214 L
s
1 .055 0 r
.75469 .47886 m
.75443 .47932 L
s
.75405 .47881 m
.75469 .47886 L
s
.75405 .47881 m
.75443 .47932 L
s
1 .01 0 r
.41934 .3796 m
.41937 .37959 L
s
.41937 .37959 m
.41935 .3795 L
s
.41937 .37959 m
.41926 .37957 L
s
.41935 .3795 m
.41932 .37951 L
s
.41935 .3795 m
.41926 .37957 L
s
.41926 .37957 m
.41934 .3796 L
s
.41926 .37957 m
.41932 .37951 L
s
.4197 .37947 m
.41926 .37957 L
s
.41932 .37951 m
.41934 .3796 L
s
1 .001 0 r
.48818 .21408 m
.48818 .21409 L
s
.48818 .21407 m
.48818 .21408 L
s
.48819 .21408 m
.48818 .21408 L
s
.48818 .21407 m
.48818 .21407 L
s
.48818 .21407 m
.48819 .21408 L
s
1 .047 0 r
.68364 .44563 m
.6818 .44495 L
s
1 0 0 r
.75207 .28024 m
.75207 .28024 L
s
1 .001 0 r
.48813 .21408 m
.48819 .21408 L
s
.48819 .21408 m
.48818 .21409 L
s
.48818 .21407 m
.48819 .21408 L
s
.48818 .21409 m
.48818 .21407 L
s
1 .08 0 r
.27647 .51171 m
.27686 .51237 L
s
1 .047 0 r
.68218 .44533 m
.68199 .44525 L
s
.68199 .44525 m
.68216 .44483 L
s
.68199 .44525 m
.6818 .44495 L
s
.68216 .44483 m
.68234 .44492 L
s
.68216 .44483 m
.6818 .44495 L
s
.6818 .44495 m
.68218 .44533 L
s
.6818 .44495 m
.68234 .44492 L
s
.68234 .44492 m
.68218 .44533 L
s
1 .168 0 r
.39245 .51103 m
.39308 .5107 L
s
.39308 .5107 m
.39253 .5092 L
s
.39308 .5107 m
.39113 .51056 L
s
1 .002 0 r
.34719 .34517 m
.34719 .34517 L
s
.34719 .34517 m
.34719 .34515 L
s
.34719 .34517 m
.34717 .34516 L
s
.34719 .34515 m
.34718 .34515 L
s
.34719 .34515 m
.34717 .34516 L
s
.34717 .34516 m
.34719 .34517 L
s
.34717 .34516 m
.34718 .34515 L
s
.34724 .34514 m
.34717 .34516 L
s
.34718 .34515 m
.34719 .34517 L
s
1 0 0 r
.67984 .24584 m
.67984 .24584 L
s
.67984 .24584 m
.67984 .24584 L
s
.67984 .24584 m
.67984 .24584 L
s
.67984 .24584 m
.67984 .24584 L
s
.67984 .24584 m
.67984 .24584 L
s
.67984 .24584 m
.67984 .24584 L
s
.67984 .24584 m
.67984 .24584 L
s
.67983 .24584 m
.67984 .24584 L
s
.67984 .24584 m
.67984 .24584 L
s
1 .029 0 r
.61136 .41134 m
.61005 .41109 L
s
1 .168 0 r
.39253 .5092 m
.39191 .50953 L
s
.39253 .5092 m
.39113 .51056 L
s
1 .029 0 r
.61031 .4113 m
.61025 .41126 L
s
.61025 .41126 m
.61031 .41099 L
s
.61025 .41126 m
.61005 .41109 L
s
1 .168 0 r
.39113 .51056 m
.39245 .51103 L
s
.39113 .51056 m
.39191 .50953 L
s
.39794 .50834 m
.39113 .51056 L
s
1 .029 0 r
.61031 .41099 m
.61037 .41103 L
s
.61031 .41099 m
.61005 .41109 L
s
.61005 .41109 m
.61031 .4113 L
s
.61005 .41109 m
.61037 .41103 L
s
.61037 .41103 m
.61031 .4113 L
s
.20544 .47701 m
.20557 .47703 L
s
.2056 .47672 m
.20544 .47701 L
s
.20544 .47701 m
.20542 .47681 L
s
.20575 .47695 m
.20544 .47701 L
s
.20617 .47637 m
.20544 .47701 L
s
.2056 .47672 m
.20542 .47681 L
s
.20575 .47695 m
.2056 .47672 L
s
.20557 .47703 m
.20575 .47695 L
s
.20542 .47681 m
.20557 .47703 L
s
1 .017 0 r
.67658 .04599 m
.67662 .04599 L
s
.67661 .04584 m
.67658 .04599 L
s
.67676 .04595 m
.67658 .04599 L
s
.67665 .04583 m
.67661 .04584 L
s
.67661 .04584 m
.67676 .04595 L
s
1 .168 0 r
.39191 .50953 m
.39245 .51103 L
s
1 .017 0 r
.67676 .04595 m
.67662 .04599 L
s
.67665 .04583 m
.67676 .04595 L
s
.67602 .04578 m
.67676 .04595 L
s
.67662 .04599 m
.67665 .04583 L
s
1 .012 0 r
.53853 .37705 m
.53853 .37704 L
s
.53853 .37704 m
.53853 .37693 L
s
.53853 .37704 m
.53842 .37699 L
s
.53853 .37693 m
.53854 .37694 L
s
.53853 .37693 m
.53842 .37699 L
s
1 .001 0 r
.60754 .2114 m
.60754 .2114 L
s
.60754 .21139 m
.60754 .2114 L
s
.60755 .2114 m
.60754 .2114 L
s
.60754 .21139 m
.60754 .21139 L
s
.60754 .21139 m
.60755 .2114 L
s
.60755 .2114 m
.60754 .2114 L
s
.60754 .21139 m
.60755 .2114 L
s
.6075 .21139 m
.60755 .2114 L
s
.60754 .2114 m
.60754 .21139 L
s
1 .021 0 r
.80327 .44325 m
.80264 .44282 L
s
1 .012 0 r
.53898 .377 m
.53842 .37699 L
s
.53842 .37699 m
.53853 .37705 L
s
.53842 .37699 m
.53854 .37694 L
s
.53854 .37694 m
.53853 .37705 L
s
1 .021 0 r
.80276 .44279 m
.80288 .44284 L
s
.80266 .44296 m
.80276 .44279 L
s
.80276 .44279 m
.80264 .44282 L
s
.80278 .44301 m
.80266 .44296 L
s
.80266 .44296 m
.80264 .44282 L
s
.80288 .44284 m
.80278 .44301 L
s
.80264 .44282 m
.80288 .44284 L
s
.80264 .44282 m
.80278 .44301 L
s
1 .003 0 r
.46641 .34265 m
.46641 .34264 L
s
.46641 .34264 m
.46641 .34262 L
s
.46641 .34264 m
.46638 .34263 L
s
.46641 .34262 m
.4664 .34262 L
s
.46641 .34262 m
.46638 .34263 L
s
.5352 .17692 m
.5352 .17692 L
s
.5352 .17688 m
.5352 .17692 L
s
.53523 .1769 m
.5352 .17692 L
s
.46638 .34263 m
.46641 .34265 L
s
.46638 .34263 m
.4664 .34262 L
s
.46651 .34262 m
.46638 .34263 L
s
.5352 .17688 m
.5352 .17688 L
s
.5352 .17688 m
.53523 .1769 L
s
.4664 .34262 m
.46641 .34265 L
s
.53523 .1769 m
.5352 .17692 L
s
.5352 .17688 m
.53523 .1769 L
s
.53507 .1769 m
.53523 .1769 L
s
1 .015 0 r
.73097 .40891 m
.7304 .40865 L
s
1 .003 0 r
.5352 .17692 m
.5352 .17688 L
s
1 .063 0 r
.32309 .47513 m
.32351 .47525 L
s
.32355 .47456 m
.32309 .47513 L
s
.32309 .47513 m
.32325 .4747 L
s
.32382 .47511 m
.32309 .47513 L
s
.32532 .47402 m
.32309 .47513 L
s
.32351 .47525 m
.32382 .47511 L
s
.32382 .47511 m
.32355 .47456 L
s
.32355 .47456 m
.32325 .4747 L
s
1 .015 0 r
.73052 .40878 m
.73045 .40875 L
s
.73045 .40875 m
.73051 .40862 L
s
.73045 .40875 m
.7304 .40865 L
s
.73051 .40862 m
.73058 .40865 L
s
.73051 .40862 m
.7304 .40865 L
s
.73058 .40865 m
.73052 .40878 L
s
.7304 .40865 m
.73052 .40878 L
s
.7304 .40865 m
.73058 .40865 L
s
1 .063 0 r
.32325 .4747 m
.32351 .47525 L
s
1 .001 0 r
.72721 .20871 m
.72722 .20871 L
s
.72721 .2087 m
.72721 .20871 L
s
.72722 .2087 m
.72721 .20871 L
s
.72722 .2087 m
.72721 .2087 L
s
.72721 .2087 m
.72722 .2087 L
s
.72722 .2087 m
.72722 .20871 L
s
.72722 .2087 m
.72722 .2087 L
s
.72719 .20869 m
.72722 .2087 L
s
.72722 .20871 m
.72722 .2087 L
s
1 0 0 r
.39393 .3082 m
.39393 .3082 L
s
.39393 .3082 m
.39393 .30819 L
s
.39393 .3082 m
.39392 .30819 L
s
.39393 .30819 m
.39393 .30819 L
s
.39393 .30819 m
.39392 .30819 L
s
.39392 .30819 m
.39393 .3082 L
s
.39392 .30819 m
.39393 .30819 L
s
.39393 .30819 m
.39392 .30819 L
s
.39393 .30819 m
.39393 .3082 L
s
1 .008 0 r
.65858 .37453 m
.65822 .37443 L
s
.6583 .37449 m
.65827 .37448 L
s
.65827 .37448 m
.65829 .37441 L
s
.65827 .37448 m
.65822 .37443 L
s
.65829 .37441 m
.65832 .37442 L
s
.65829 .37441 m
.65822 .37443 L
s
1 .233 0 r
.5086 .50748 m
.50867 .50713 L
s
.50867 .50713 m
.50861 .50493 L
s
.50867 .50713 m
.5064 .50625 L
s
1 .008 0 r
.65822 .37443 m
.6583 .37449 L
s
.65822 .37443 m
.65832 .37442 L
s
.65832 .37442 m
.6583 .37449 L
s
1 .233 0 r
.50861 .50493 m
.50855 .50528 L
s
.50861 .50493 m
.5064 .50625 L
s
1 .021 0 r
.25197 .44009 m
.25208 .44011 L
s
.2521 .43989 m
.25197 .44009 L
s
.25197 .44009 m
.25199 .43994 L
s
.2522 .44006 m
.25197 .44009 L
s
.25261 .43966 m
.25197 .44009 L
s
.2521 .43989 m
.25199 .43994 L
s
.2522 .44006 m
.2521 .43989 L
s
.25208 .44011 m
.2522 .44006 L
s
.25199 .43994 m
.25208 .44011 L
s
1 .233 0 r
.5064 .50625 m
.5086 .50748 L
s
.5064 .50625 m
.50855 .50528 L
s
.51743 .50604 m
.5064 .50625 L
s
1 .003 0 r
.65484 .17419 m
.65484 .17419 L
s
.65484 .17416 m
.65484 .17419 L
s
.65487 .17418 m
.65484 .17419 L
s
1 .114 0 r
.44069 .47305 m
.44096 .47288 L
s
.44096 .47288 m
.44072 .47182 L
s
.44096 .47288 m
.43969 .47263 L
s
1 .003 0 r
.65485 .17416 m
.65484 .17416 L
s
.65484 .17416 m
.65487 .17418 L
s
.65487 .17418 m
.65484 .17419 L
s
.65485 .17416 m
.65487 .17418 L
s
.65474 .17415 m
.65487 .17418 L
s
.65484 .17419 m
.65485 .17416 L
s
.58609 .3401 m
.58597 .34008 L
s
.58599 .3401 m
.58599 .3401 L
s
.58599 .3401 m
.58599 .34007 L
s
.58599 .3401 m
.58597 .34008 L
s
.58599 .34007 m
.58599 .34007 L
s
.58599 .34007 m
.58597 .34008 L
s
.58597 .34008 m
.58599 .3401 L
s
.58597 .34008 m
.58599 .34007 L
s
.58599 .34007 m
.58599 .3401 L
s
1 .114 0 r
.44072 .47182 m
.44046 .47199 L
s
.44072 .47182 m
.43969 .47263 L
s
.43969 .47263 m
.44069 .47305 L
s
.43969 .47263 m
.44046 .47199 L
s
.4448 .47167 m
.43969 .47263 L
s
1 .233 0 r
.50855 .50528 m
.5086 .50748 L
s
1 .114 0 r
.44046 .47199 m
.44069 .47305 L
s
1 .006 0 r
.58242 .13961 m
.58243 .13961 L
s
.58243 .13956 m
.58242 .13961 L
s
.58248 .13959 m
.58242 .13961 L
s
.58243 .13956 m
.58243 .13956 L
s
.58243 .13956 m
.58248 .13959 L
s
.58248 .13959 m
.58243 .13961 L
s
.58243 .13956 m
.58248 .13959 L
s
.5822 .13957 m
.58248 .13959 L
s
1 0 0 r
.51349 .30562 m
.51349 .30562 L
s
.51349 .30562 m
.51349 .30562 L
s
.51349 .30562 m
.51349 .30562 L
s
.51349 .30562 m
.51349 .30562 L
s
.51349 .30562 m
.51349 .30562 L
s
.51349 .30562 m
.51349 .30562 L
s
.51349 .30562 m
.51349 .30562 L
s
.5135 .30562 m
.51349 .30562 L
s
1 .004 0 r
.7785 .37204 m
.77835 .37196 L
s
1 0 0 r
.51349 .30562 m
.51349 .30562 L
s
1 .006 0 r
.58243 .13961 m
.58243 .13956 L
s
1 .004 0 r
.77838 .372 m
.77836 .37199 L
s
.77836 .37199 m
.77838 .37196 L
s
.77836 .37199 m
.77835 .37196 L
s
.77838 .37196 m
.7784 .37196 L
s
.77838 .37196 m
.77835 .37196 L
s
.7784 .37196 m
.77838 .372 L
s
.77835 .37196 m
.77838 .372 L
s
.77835 .37196 m
.7784 .37196 L
s
1 .042 0 r
.37069 .43796 m
.37085 .43788 L
s
.37085 .43788 m
.37071 .4375 L
s
.37085 .43788 m
.37035 .43785 L
s
.37071 .4375 m
.37055 .43758 L
s
.37071 .4375 m
.37035 .43785 L
s
.37035 .43785 m
.37069 .43796 L
s
.37035 .43785 m
.37055 .43758 L
s
.37206 .43726 m
.37035 .43785 L
s
.37055 .43758 m
.37069 .43796 L
s
1 .002 0 r
.70599 .33756 m
.70592 .33754 L
s
1 .168 0 r
.63724 .50373 m
.63012 .50177 L
s
1 0 0 r
.44081 .2711 m
.44081 .2711 L
s
1 .002 0 r
.70594 .33755 m
.70593 .33755 L
s
.70593 .33755 m
.70594 .33754 L
s
.70593 .33755 m
.70592 .33754 L
s
.70594 .33754 m
.70594 .33754 L
s
.70594 .33754 m
.70592 .33754 L
s
.70592 .33754 m
.70594 .33755 L
s
.70592 .33754 m
.70594 .33754 L
s
.70594 .33754 m
.70594 .33755 L
s
1 .013 0 r
.29878 .40303 m
.29887 .40305 L
s
.29888 .40292 m
.29878 .40303 L
s
.29878 .40303 m
.29881 .40294 L
s
.29893 .40303 m
.29878 .40303 L
s
.29924 .40281 m
.29878 .40303 L
s
.29887 .40305 m
.29893 .40303 L
s
.29893 .40303 m
.29888 .40292 L
s
.29888 .40292 m
.29881 .40294 L
s
1 .168 0 r
.63158 .50308 m
.63103 .50277 L
s
.63103 .50277 m
.63152 .50124 L
s
.63103 .50277 m
.63012 .50177 L
s
1 .013 0 r
.29881 .40294 m
.29887 .40305 L
s
1 .121 0 r
.56005 .46957 m
.55991 .4694 L
s
.55991 .4694 m
.56004 .46826 L
s
.55991 .4694 m
.55891 .46881 L
s
1 .168 0 r
.63152 .50124 m
.63206 .50155 L
s
.63152 .50124 m
.63012 .50177 L
s
1 .005 0 r
.70232 .13683 m
.70234 .13683 L
s
.70234 .13679 m
.70232 .13683 L
s
.70238 .13682 m
.70232 .13683 L
s
.70235 .13679 m
.70234 .13679 L
s
.70234 .13679 m
.70238 .13682 L
s
.70238 .13682 m
.70234 .13683 L
s
.70235 .13679 m
.70238 .13682 L
s
.70218 .13676 m
.70238 .13682 L
s
.70234 .13683 m
.70235 .13679 L
s
1 .121 0 r
.56459 .46932 m
.55891 .46881 L
s
1 0 0 r
.63338 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
1 .121 0 r
.56004 .46826 m
.56017 .46842 L
s
.56004 .46826 m
.55891 .46881 L
s
.55891 .46881 m
.56005 .46957 L
s
.55891 .46881 m
.56017 .46842 L
s
.56017 .46842 m
.56005 .46957 L
s
1 .062 0 r
.48951 .43536 m
.48957 .43528 L
s
.48957 .43528 m
.48952 .43469 L
s
.48957 .43528 m
.48893 .43507 L
s
1 .168 0 r
.63012 .50177 m
.63158 .50308 L
s
.63012 .50177 m
.63206 .50155 L
s
1 .062 0 r
.48952 .43469 m
.48946 .43477 L
s
.48952 .43469 m
.48893 .43507 L
s
1 .168 0 r
.63206 .50155 m
.63158 .50308 L
s
1 .062 0 r
.48893 .43507 m
.48951 .43536 L
s
.48893 .43507 m
.48946 .43477 L
s
.49184 .43486 m
.48893 .43507 L
s
1 .009 0 r
.62983 .10217 m
.62984 .10217 L
s
.62984 .10209 m
.62983 .10217 L
s
.62992 .10215 m
.62983 .10217 L
s
.62985 .10209 m
.62984 .10209 L
s
.62984 .10209 m
.62992 .10215 L
s
.62992 .10215 m
.62984 .10217 L
s
.62985 .10209 m
.62992 .10215 L
s
.62952 .10208 m
.62992 .10215 L
s
.62984 .10217 m
.62985 .10209 L
s
1 .08 0 r
.75737 .50141 m
.7548 .49989 L
s
1 0 0 r
.56068 .26847 m
.56068 .26847 L
s
1 .062 0 r
.48946 .43477 m
.48951 .43536 L
s
1 .022 0 r
.4182 .40065 m
.41826 .40062 L
s
.41826 .40062 m
.41821 .40041 L
s
.41826 .40062 m
.418 .40057 L
s
.41821 .40041 m
.41815 .40044 L
s
.41821 .40041 m
.418 .40057 L
s
.418 .40057 m
.4182 .40065 L
s
.418 .40057 m
.41815 .40044 L
s
.41899 .40035 m
.418 .40057 L
s
1 .08 0 r
.75529 .49975 m
.75572 .49996 L
s
.75491 .50042 m
.75529 .49975 L
s
.75529 .49975 m
.7548 .49989 L
s
.75535 .50063 m
.75491 .50042 L
s
.75491 .50042 m
.7548 .49989 L
s
1 .022 0 r
.41815 .40044 m
.4182 .40065 L
s
1 0 0 r
.48789 .23386 m
.48789 .23386 L
s
.48789 .23385 m
.48789 .23386 L
s
.48789 .23385 m
.48789 .23386 L
s
.48789 .23385 m
.48789 .23385 L
s
.48789 .23385 m
.48789 .23385 L
s
.75359 .30045 m
.75358 .30045 L
s
1 .073 0 r
.6847 .46695 m
.68181 .46589 L
s
1 0 0 r
.48788 .23385 m
.48789 .23385 L
s
.48789 .23385 m
.48789 .23386 L
s
.48789 .23385 m
.48789 .23385 L
s
.48789 .23386 m
.48789 .23385 L
s
.75358 .30045 m
.75358 .30045 L
s
.75358 .30045 m
.75358 .30045 L
s
.75358 .30045 m
.75358 .30045 L
s
.75358 .30045 m
.75358 .30045 L
s
.75358 .30045 m
.75358 .30045 L
s
.75358 .30045 m
.75358 .30045 L
s
.75358 .30045 m
.75358 .30045 L
s
.75358 .30045 m
.75358 .30045 L
s
1 .08 0 r
.75572 .49996 m
.75535 .50063 L
s
.7548 .49989 m
.75572 .49996 L
s
.7548 .49989 m
.75535 .50063 L
s
1 .073 0 r
.6824 .4665 m
.68211 .46636 L
s
.68211 .46636 m
.68237 .46571 L
s
.68211 .46636 m
.68181 .46589 L
s
.68237 .46571 m
.68266 .46585 L
s
.68237 .46571 m
.68181 .46589 L
s
.68181 .46589 m
.6824 .4665 L
s
.68181 .46589 m
.68266 .46585 L
s
.68266 .46585 m
.6824 .4665 L
s
1 .006 0 r
.34586 .3659 m
.34588 .36589 L
s
.34588 .36589 m
.34586 .36584 L
s
.34588 .36589 m
.34581 .36589 L
s
.34586 .36584 m
.34584 .36585 L
s
.34586 .36584 m
.34581 .36589 L
s
.34581 .36589 m
.34586 .3659 L
s
.34581 .36589 m
.34584 .36585 L
s
.34605 .3658 m
.34581 .36589 L
s
.34584 .36585 m
.34586 .3659 L
s
1 0 0 r
.68087 .26584 m
.68087 .26584 L
s
1 .052 0 r
.61194 .43245 m
.60959 .43202 L
s
.61006 .43238 m
.60995 .43231 L
s
.60995 .43231 m
.61005 .43182 L
s
.60995 .43231 m
.60959 .43202 L
s
.61005 .43182 m
.61017 .4319 L
s
.61005 .43182 m
.60959 .43202 L
s
1 .043 0 r
.20294 .49887 m
.20314 .49891 L
s
.20318 .49845 m
.20294 .49887 L
s
.20294 .49887 m
.20291 .49857 L
s
.20341 .49879 m
.20294 .49887 L
s
.20403 .49793 m
.20294 .49887 L
s
.20318 .49845 m
.20291 .49857 L
s
.20341 .49879 m
.20318 .49845 L
s
.20314 .49891 m
.20341 .49879 L
s
1 .052 0 r
.60959 .43202 m
.61006 .43238 L
s
.60959 .43202 m
.61017 .4319 L
s
.61017 .4319 m
.61006 .43238 L
s
1 .043 0 r
.20291 .49857 m
.20314 .49891 L
s
1 .011 0 r
.6774 .06459 m
.67743 .06459 L
s
.67742 .06448 m
.6774 .06459 L
s
.67752 .06456 m
.6774 .06459 L
s
.67745 .06448 m
.67742 .06448 L
s
.67742 .06448 m
.67752 .06456 L
s
.67752 .06456 m
.67743 .06459 L
s
.67745 .06448 m
.67752 .06456 L
s
.67703 .06445 m
.67752 .06456 L
s
1 .026 0 r
.53808 .39801 m
.53807 .39798 L
s
.53807 .39798 m
.53808 .39773 L
s
.53807 .39798 m
.53783 .39786 L
s
.53808 .39773 m
.53809 .39776 L
s
.53808 .39773 m
.53783 .39786 L
s
1 .011 0 r
.67743 .06459 m
.67745 .06448 L
s
1 0 0 r
.60806 .23117 m
.60806 .23117 L
s
.60806 .23117 m
.60806 .23117 L
s
.60806 .23117 m
.60806 .23117 L
s
.60806 .23117 m
.60806 .23117 L
s
.60806 .23117 m
.60806 .23117 L
s
.60806 .23117 m
.60806 .23117 L
s
.60806 .23117 m
.60806 .23117 L
s
.60805 .23117 m
.60806 .23117 L
s
.60806 .23117 m
.60806 .23117 L
s
1 .034 0 r
.80514 .46459 m
.80412 .46389 L
s
1 .026 0 r
.53907 .3979 m
.53783 .39786 L
s
.53783 .39786 m
.53808 .39801 L
s
.53783 .39786 m
.53809 .39776 L
s
.53809 .39776 m
.53808 .39801 L
s
1 .034 0 r
.80431 .46385 m
.8045 .46393 L
s
.80414 .46413 m
.80431 .46385 L
s
.80431 .46385 m
.80412 .46389 L
s
.80434 .46422 m
.80414 .46413 L
s
.80414 .46413 m
.80412 .46389 L
s
.8045 .46393 m
.80434 .46422 L
s
.80412 .46389 m
.8045 .46393 L
s
.80412 .46389 m
.80434 .46422 L
s
1 .091 0 r
.32075 .49717 m
.32136 .49735 L
s
.32143 .49636 m
.32075 .49717 L
s
.32075 .49717 m
.32098 .49657 L
s
.32181 .49714 m
.32075 .49717 L
s
.32398 .4956 m
.32075 .49717 L
s
.32136 .49735 m
.32181 .49714 L
s
.32181 .49714 m
.32143 .49636 L
s
.32143 .49636 m
.32098 .49657 L
s
1 .009 0 r
.46579 .36338 m
.4658 .36337 L
s
.4658 .36337 m
.46579 .36329 L
s
.4658 .36337 m
.46571 .36334 L
s
.46579 .36329 m
.46578 .3633 L
s
.46579 .36329 m
.46571 .36334 L
s
.46571 .36334 m
.46579 .36338 L
s
.46571 .36334 m
.46578 .3633 L
s
.46611 .3633 m
.46571 .36334 L
s
.46578 .3633 m
.46579 .36338 L
s
1 .001 0 r
.53518 .19647 m
.53518 .19647 L
s
.53518 .19646 m
.53518 .19647 L
s
.53519 .19646 m
.53518 .19647 L
s
.53518 .19646 m
.53518 .19646 L
s
.53518 .19646 m
.53519 .19646 L
s
.53519 .19646 m
.53518 .19647 L
s
.53518 .19646 m
.53519 .19646 L
s
.53514 .19646 m
.53519 .19646 L
s
1 .028 0 r
.73235 .43003 m
.73131 .42956 L
s
1 .001 0 r
.53518 .19647 m
.53518 .19646 L
s
1 .091 0 r
.32098 .49657 m
.32136 .49735 L
s
1 .028 0 r
.73153 .4298 m
.7314 .42975 L
s
.7314 .42975 m
.73151 .4295 L
s
.7314 .42975 m
.73131 .42956 L
s
.73151 .4295 m
.73164 .42956 L
s
.73151 .4295 m
.73131 .42956 L
s
.73164 .42956 m
.73153 .4298 L
s
.73131 .42956 m
.73153 .4298 L
s
.73131 .42956 m
.73164 .42956 L
s
1 .002 0 r
.39299 .32868 m
.39299 .32867 L
s
.39299 .32867 m
.39299 .32866 L
s
.39299 .32867 m
.39297 .32867 L
s
.39299 .32866 m
.39299 .32866 L
s
.39299 .32866 m
.39297 .32867 L
s
.39297 .32867 m
.39299 .32868 L
s
.39297 .32867 m
.39299 .32866 L
s
.39305 .32865 m
.39297 .32867 L
s
.39299 .32866 m
.39299 .32868 L
s
1 0 0 r
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
1 .018 0 r
.65947 .39543 m
.65868 .39522 L
s
.65884 .39536 m
.65879 .39533 L
s
.65879 .39533 m
.65884 .39516 L
s
.65879 .39533 m
.65868 .39522 L
s
.65884 .39516 m
.65889 .39519 L
s
.65884 .39516 m
.65868 .39522 L
s
.65868 .39522 m
.65884 .39536 L
s
.65868 .39522 m
.65889 .39519 L
s
.65889 .39519 m
.65884 .39536 L
s
1 .034 0 r
.24973 .4617 m
.24992 .46175 L
s
.24995 .46138 m
.24973 .4617 L
s
.24973 .4617 m
.24976 .46146 L
s
.25011 .46166 m
.24973 .4617 L
s
.25077 .46102 m
.24973 .4617 L
s
.24995 .46138 m
.24976 .46146 L
s
.25011 .46166 m
.24995 .46138 L
s
.24992 .46175 m
.25011 .46166 L
s
1 .158 0 r
.43851 .49518 m
.43888 .49492 L
s
.43888 .49492 m
.43856 .49345 L
s
.43888 .49492 m
.43711 .49458 L
s
1 .034 0 r
.24976 .46146 m
.24992 .46175 L
s
1 .158 0 r
.43856 .49345 m
.43819 .49371 L
s
.43856 .49345 m
.43711 .49458 L
s
.43711 .49458 m
.43851 .49518 L
s
.43711 .49458 m
.43819 .49371 L
s
.44425 .49326 m
.43711 .49458 L
s
1 .001 0 r
.65564 .19373 m
.65565 .19373 L
s
.65565 .19373 m
.65564 .19373 L
s
.65565 .19373 m
.65564 .19373 L
s
.65565 .19373 m
.65565 .19373 L
s
.65565 .19373 m
.65565 .19373 L
s
.65565 .19373 m
.65565 .19373 L
s
.65565 .19373 m
.65565 .19373 L
s
.65562 .19372 m
.65565 .19373 L
s
.65565 .19373 m
.65565 .19373 L
s
1 .008 0 r
.5865 .36078 m
.58611 .36074 L
s
.58619 .36079 m
.58618 .36078 L
s
.58618 .36078 m
.58619 .3607 L
s
.58618 .36078 m
.58611 .36074 L
s
.58619 .3607 m
.5862 .36071 L
s
.58619 .3607 m
.58611 .36074 L
s
.58611 .36074 m
.58619 .36079 L
s
.58611 .36074 m
.5862 .36071 L
s
.5862 .36071 m
.58619 .36079 L
s
1 .158 0 r
.43819 .49371 m
.43851 .49518 L
s
1 .003 0 r
.58268 .15894 m
.58268 .15894 L
s
.58268 .15891 m
.58268 .15894 L
s
.58271 .15893 m
.58268 .15894 L
s
.58269 .15891 m
.58268 .15891 L
s
.58268 .15891 m
.58271 .15893 L
s
1 .002 0 r
.51334 .3261 m
.51334 .3261 L
s
.51334 .3261 m
.51334 .32608 L
s
.51334 .3261 m
.51332 .32609 L
s
1 .003 0 r
.58271 .15893 m
.58268 .15894 L
s
.58269 .15891 m
.58271 .15893 L
s
.58258 .15892 m
.58271 .15893 L
s
1 .002 0 r
.51334 .32608 m
.51334 .32608 L
s
.51334 .32608 m
.51332 .32609 L
s
.51332 .32609 m
.51334 .3261 L
s
.51332 .32609 m
.51334 .32608 L
s
.51342 .32609 m
.51332 .32609 L
s
1 .01 0 r
.7802 .39296 m
.77987 .39278 L
s
1 .003 0 r
.58268 .15894 m
.58269 .15891 L
s
1 .002 0 r
.51334 .32608 m
.51334 .3261 L
s
1 .01 0 r
.77994 .39287 m
.77989 .39285 L
s
.77989 .39285 m
.77993 .39277 L
s
.77989 .39285 m
.77987 .39278 L
s
.77993 .39277 m
.77998 .39278 L
s
.77993 .39277 m
.77987 .39278 L
s
.77998 .39278 m
.77994 .39287 L
s
.77987 .39278 m
.77994 .39287 L
s
.77987 .39278 m
.77998 .39278 L
s
1 .066 0 r
.36885 .45972 m
.3691 .4596 L
s
.3691 .4596 m
.36888 .459 L
s
.3691 .4596 m
.36833 .45955 L
s
.36888 .459 m
.36863 .45912 L
s
.36888 .459 m
.36833 .45955 L
s
.36833 .45955 m
.36885 .45972 L
s
.36833 .45955 m
.36863 .45912 L
s
.37103 .45863 m
.36833 .45955 L
s
.36863 .45912 m
.36885 .45972 L
s
1 0 0 r
.44024 .29135 m
.44024 .29135 L
s
.44024 .29135 m
.44024 .29135 L
s
.44024 .29135 m
.44023 .29135 L
s
.44024 .29135 m
.44024 .29135 L
s
.44024 .29135 m
.44023 .29135 L
s
.44023 .29135 m
.44024 .29135 L
s
.44023 .29135 m
.44024 .29135 L
s
.44024 .29135 m
.44023 .29135 L
s
.44024 .29135 m
.44024 .29135 L
s
1 .005 0 r
.70721 .35826 m
.70699 .35819 L
s
.70704 .35823 m
.70702 .35822 L
s
.70702 .35822 m
.70703 .35818 L
s
.70702 .35822 m
.70699 .35819 L
s
.70703 .35818 m
.70705 .35818 L
s
.70703 .35818 m
.70699 .35819 L
s
.70699 .35819 m
.70704 .35823 L
s
.70699 .35819 m
.70705 .35818 L
s
.70705 .35818 m
.70704 .35823 L
s
1 .023 0 r
.29687 .42437 m
.29703 .42441 L
s
.29704 .42416 m
.29687 .42437 L
s
.29687 .42437 m
.29693 .42421 L
s
.29714 .42437 m
.29687 .42437 L
s
.29771 .42396 m
.29687 .42437 L
s
.29703 .42441 m
.29714 .42437 L
s
.29714 .42437 m
.29704 .42416 L
s
.29704 .42416 m
.29693 .42421 L
s
.29693 .42421 m
.29703 .42441 L
s
1 .168 0 r
.55853 .49128 m
.55834 .49103 L
s
.55834 .49103 m
.55851 .48944 L
s
.55834 .49103 m
.55693 .49022 L
s
1 .002 0 r
.70343 .15615 m
.70344 .15615 L
s
.70344 .15613 m
.70343 .15615 L
s
.70346 .15615 m
.70343 .15615 L
s
.70345 .15613 m
.70344 .15613 L
s
.70344 .15613 m
.70346 .15615 L
s
.70346 .15615 m
.70344 .15615 L
s
.70345 .15613 m
.70346 .15615 L
s
.70337 .15612 m
.70346 .15615 L
s
.70344 .15615 m
.70345 .15613 L
s
.63411 .32352 m
.63403 .32351 L
s
1 .168 0 r
.56485 .49092 m
.55693 .49022 L
s
1 .002 0 r
.63405 .32352 m
.63405 .32352 L
s
.63405 .32352 m
.63405 .3235 L
s
.63405 .32352 m
.63403 .32351 L
s
.63405 .3235 m
.63405 .3235 L
s
.63405 .3235 m
.63403 .32351 L
s
.63403 .32351 m
.63405 .32352 L
s
.63403 .32351 m
.63405 .3235 L
s
.63405 .3235 m
.63405 .32352 L
s
1 .168 0 r
.55851 .48944 m
.5587 .48969 L
s
.55851 .48944 m
.55693 .49022 L
s
1 .095 0 r
.48799 .45702 m
.48808 .45689 L
s
.48808 .45689 m
.48801 .45598 L
s
.48808 .45689 m
.4871 .45656 L
s
.48801 .45598 m
.48792 .45611 L
s
.48801 .45598 m
.4871 .45656 L
s
1 .168 0 r
.55693 .49022 m
.55853 .49128 L
s
.55693 .49022 m
.5587 .48969 L
s
1 .095 0 r
.4871 .45656 m
.48799 .45702 L
s
.4871 .45656 m
.48792 .45611 L
s
.49161 .45624 m
.4871 .45656 L
s
1 .168 0 r
.5587 .48969 m
.55853 .49128 L
s
1 .005 0 r
.63039 .12127 m
.6304 .12127 L
s
.63039 .12122 m
.63039 .12127 L
s
.63044 .12125 m
.63039 .12127 L
s
.6304 .12122 m
.63039 .12122 L
s
.63039 .12122 m
.63044 .12125 L
s
.63044 .12125 m
.6304 .12127 L
s
.6304 .12122 m
.63044 .12125 L
s
.63022 .12122 m
.63044 .12125 L
s
.6304 .12127 m
.6304 .12122 L
s
1 0 0 r
.56091 .28873 m
.56091 .28873 L
s
.56091 .28873 m
.56091 .28873 L
s
.56091 .28873 m
.56091 .28873 L
s
.56091 .28873 m
.56091 .28873 L
s
.56091 .28873 m
.56091 .28873 L
s
.56092 .28873 m
.56091 .28873 L
s
.56091 .28873 m
.56091 .28873 L
s
.56091 .28873 m
.56091 .28873 L
s
.56091 .28873 m
.56091 .28873 L
s
1 .095 0 r
.48792 .45611 m
.48799 .45702 L
s
1 .04 0 r
.41683 .42204 m
.41694 .42199 L
s
.41694 .42199 m
.41685 .42161 L
s
.41694 .42199 m
.41648 .42191 L
s
.41685 .42161 m
.41674 .42167 L
s
.41685 .42161 m
.41648 .42191 L
s
.41648 .42191 m
.41683 .42204 L
s
.41648 .42191 m
.41674 .42167 L
s
.41827 .42152 m
.41648 .42191 L
s
.41674 .42167 m
.41683 .42204 L
s
1 .104 0 r
.68578 .48857 m
.68163 .48706 L
s
1 .001 0 r
.75513 .32094 m
.75509 .32093 L
s
1 0 0 r
.48763 .25389 m
.48763 .25389 L
s
1 .001 0 r
.7551 .32094 m
.75509 .32094 L
s
.75509 .32094 m
.7551 .32093 L
s
.75509 .32094 m
.75509 .32093 L
s
.7551 .32093 m
.7551 .32093 L
s
.7551 .32093 m
.75509 .32093 L
s
.7551 .32093 m
.7551 .32094 L
s
.75509 .32093 m
.7551 .32094 L
s
.75509 .32093 m
.7551 .32093 L
s
1 .104 0 r
.68249 .48794 m
.68206 .48773 L
s
.68206 .48773 m
.68243 .48679 L
s
.68206 .48773 m
.68163 .48706 L
s
.68243 .48679 m
.68285 .487 L
s
.68243 .48679 m
.68163 .48706 L
s
1 .013 0 r
.3444 .38697 m
.34446 .38695 L
s
.34446 .38695 m
.34441 .38683 L
s
.34446 .38695 m
.3443 .38694 L
s
.34441 .38683 m
.34436 .38685 L
s
.34441 .38683 m
.3443 .38694 L
s
.3443 .38694 m
.3444 .38697 L
s
.3443 .38694 m
.34436 .38685 L
s
.34484 .38675 m
.3443 .38694 L
s
.34436 .38685 m
.3444 .38697 L
s
1 0 0 r
.68192 .28611 m
.68191 .2861 L
s
1 .081 0 r
.61252 .45384 m
.60884 .45318 L
s
1 0 0 r
.68192 .28611 m
.68192 .28611 L
s
.68192 .28611 m
.68192 .2861 L
s
.68192 .28611 m
.68191 .2861 L
s
.68192 .2861 m
.68192 .2861 L
s
.68192 .2861 m
.68191 .2861 L
s
.68191 .2861 m
.68192 .28611 L
s
.68191 .2861 m
.68192 .2861 L
s
.68192 .2861 m
.68192 .28611 L
s
1 .081 0 r
.60959 .45375 m
.6094 .45363 L
s
.6094 .45363 m
.60956 .45287 L
s
.6094 .45363 m
.60884 .45318 L
s
.60956 .45287 m
.60975 .45299 L
s
.60956 .45287 m
.60884 .45318 L
s
1 .104 0 r
.68163 .48706 m
.68249 .48794 L
s
.68163 .48706 m
.68285 .487 L
s
.68285 .487 m
.68249 .48794 L
s
1 .081 0 r
.60884 .45318 m
.60959 .45375 L
s
.60884 .45318 m
.60975 .45299 L
s
.60975 .45299 m
.60959 .45375 L
s
1 .047 0 r
.53738 .41928 m
.53736 .41922 L
s
.53736 .41922 m
.53738 .41877 L
s
.53736 .41922 m
.53693 .41901 L
s
.53738 .41877 m
.53739 .41883 L
s
.53738 .41877 m
.53693 .41901 L
s
1 .007 0 r
.67828 .08345 m
.6783 .08345 L
s
.6783 .08339 m
.67828 .08345 L
s
.67836 .08344 m
.67828 .08345 L
s
.67831 .08339 m
.6783 .08339 L
s
.6783 .08339 m
.67836 .08344 L
s
.67836 .08344 m
.6783 .08345 L
s
.67831 .08339 m
.67836 .08344 L
s
.67806 .08337 m
.67836 .08344 L
s
.6783 .08345 m
.67831 .08339 L
s
1 .05 0 r
.80703 .48621 m
.80553 .4852 L
s
1 0 0 r
.60861 .25122 m
.60861 .25122 L
s
1 .047 0 r
.53917 .41907 m
.53693 .41901 L
s
.53693 .41901 m
.53738 .41928 L
s
.53693 .41901 m
.53739 .41883 L
s
.53739 .41883 m
.53738 .41928 L
s
1 .05 0 r
.8058 .48513 m
.80609 .48526 L
s
.80556 .48555 m
.8058 .48513 L
s
.8058 .48513 m
.80553 .4852 L
s
.80585 .48568 m
.80556 .48555 L
s
.80556 .48555 m
.80553 .4852 L
s
.80609 .48526 m
.80585 .48568 L
s
.80553 .4852 m
.80609 .48526 L
s
.80553 .4852 m
.80585 .48568 L
s
1 .019 0 r
.46498 .38444 m
.46501 .38442 L
s
.46501 .38442 m
.46499 .38423 L
s
.46501 .38442 m
.4648 .38436 L
s
.46499 .38423 m
.46496 .38425 L
s
.46499 .38423 m
.4648 .38436 L
s
.4648 .38436 m
.46498 .38444 L
s
.4648 .38436 m
.46496 .38425 L
s
.46571 .38425 m
.4648 .38436 L
s
.46496 .38425 m
.46498 .38444 L
s
1 0 0 r
.53521 .21629 m
.53521 .21629 L
s
.53521 .21629 m
.53521 .21629 L
s
.53521 .21629 m
.53521 .21629 L
s
.53521 .21629 m
.53521 .21629 L
s
.53521 .21629 m
.53521 .21629 L
s
.53521 .21629 m
.53521 .21629 L
s
.53521 .21629 m
.53521 .21629 L
s
.5352 .21629 m
.53521 .21629 L
s
1 .045 0 r
.73376 .45144 m
.73207 .45069 L
s
1 0 0 r
.53521 .21629 m
.53521 .21629 L
s
1 .045 0 r
.73242 .45108 m
.73221 .45099 L
s
.73221 .45099 m
.73239 .45059 L
s
.73221 .45099 m
.73207 .45069 L
s
.73239 .45059 m
.7326 .45068 L
s
.73239 .45059 m
.73207 .45069 L
s
.7326 .45068 m
.73242 .45108 L
s
.73207 .45069 m
.73242 .45108 L
s
.73207 .45069 m
.7326 .45068 L
s
1 .006 0 r
.39195 .34947 m
.39197 .34946 L
s
.39197 .34946 m
.39196 .34941 L
s
.39197 .34946 m
.39191 .34945 L
s
.39196 .34941 m
.39194 .34941 L
s
.39196 .34941 m
.39191 .34945 L
s
.39191 .34945 m
.39195 .34947 L
s
.39191 .34945 m
.39194 .34941 L
s
.39216 .34939 m
.39191 .34945 L
s
.39194 .34941 m
.39195 .34947 L
s
1 .033 0 r
.66038 .41662 m
.65893 .41623 L
s
1 0 0 r
.72992 .24854 m
.72992 .24854 L
s
1 .033 0 r
.65923 .41649 m
.65913 .41644 L
s
.65913 .41644 m
.65922 .41613 L
s
.65913 .41644 m
.65893 .41623 L
s
1 .05 0 r
.24736 .48366 m
.24765 .48374 L
s
.2477 .48319 m
.24736 .48366 L
s
.24736 .48366 m
.24741 .48332 L
s
.24794 .48361 m
.24736 .48366 L
s
.24891 .48267 m
.24736 .48366 L
s
1 .033 0 r
.65922 .41613 m
.65932 .41618 L
s
.65922 .41613 m
.65893 .41623 L
s
1 .05 0 r
.2477 .48319 m
.24741 .48332 L
s
.24794 .48361 m
.2477 .48319 L
s
.24765 .48374 m
.24794 .48361 L
s
1 .033 0 r
.65893 .41623 m
.65923 .41649 L
s
.65893 .41623 m
.65932 .41618 L
s
.65932 .41618 m
.65923 .41649 L
s
1 .05 0 r
.24741 .48332 m
.24765 .48374 L
s
1 0 0 r
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
1 .018 0 r
.58691 .38175 m
.58604 .38165 L
s
.58622 .38177 m
.58619 .38175 L
s
.58619 .38175 m
.58622 .38157 L
s
.58619 .38175 m
.58604 .38165 L
s
.58622 .38157 m
.58624 .38159 L
s
.58622 .38157 m
.58604 .38165 L
s
.58604 .38165 m
.58622 .38177 L
s
.58604 .38165 m
.58624 .38159 L
s
.58624 .38159 m
.58622 .38177 L
s
1 .095 0 r
.36684 .48185 m
.36721 .48167 L
s
.36721 .48167 m
.36689 .48081 L
s
.36721 .48167 m
.36609 .48159 L
s
.36689 .48081 m
.36653 .48099 L
s
.36689 .48081 m
.36609 .48159 L
s
.36609 .48159 m
.36684 .48185 L
s
.36609 .48159 m
.36653 .48099 L
s
.36998 .4803 m
.36609 .48159 L
s
1 .007 0 r
.51307 .34688 m
.51308 .34687 L
s
.51308 .34687 m
.51307 .34681 L
s
.51308 .34687 m
.51301 .34684 L
s
.51307 .34681 m
.51307 .34681 L
s
.51307 .34681 m
.51301 .34684 L
s
.51301 .34684 m
.51307 .34688 L
s
.51301 .34684 m
.51307 .34681 L
s
.51334 .34684 m
.51301 .34684 L
s
1 .001 0 r
.583 .17854 m
.583 .17854 L
s
.583 .17853 m
.583 .17854 L
s
.58301 .17853 m
.583 .17854 L
s
.583 .17853 m
.583 .17853 L
s
.583 .17853 m
.58301 .17853 L
s
.58301 .17853 m
.583 .17854 L
s
.583 .17853 m
.58301 .17853 L
s
.58297 .17853 m
.58301 .17853 L
s
1 .018 0 r
.78193 .41416 m
.78131 .41383 L
s
1 .001 0 r
.583 .17854 m
.583 .17853 L
s
1 .007 0 r
.51307 .34681 m
.51307 .34688 L
s
1 .018 0 r
.78144 .41399 m
.78135 .41396 L
s
.78135 .41396 m
.78143 .4138 L
s
.78135 .41396 m
.78131 .41383 L
s
.78143 .4138 m
.78152 .41384 L
s
.78143 .4138 m
.78131 .41383 L
s
.78152 .41384 m
.78144 .41399 L
s
.78131 .41383 m
.78144 .41399 L
s
.78131 .41383 m
.78152 .41384 L
s
1 .095 0 r
.36653 .48099 m
.36684 .48185 L
s
1 .002 0 r
.43961 .31189 m
.43961 .31189 L
s
.43961 .31189 m
.43961 .31187 L
s
.43961 .31189 m
.43959 .31188 L
s
.43961 .31187 m
.43961 .31188 L
s
.43961 .31187 m
.43959 .31188 L
s
.43959 .31188 m
.43961 .31189 L
s
.43959 .31188 m
.43961 .31188 L
s
.43967 .31187 m
.43959 .31188 L
s
.43961 .31188 m
.43961 .31189 L
s
1 .012 0 r
.70844 .37924 m
.70796 .37908 L
s
.70806 .37917 m
.70801 .37915 L
s
.70801 .37915 m
.70805 .37905 L
s
.70801 .37915 m
.70796 .37908 L
s
.70805 .37905 m
.7081 .37906 L
s
.70805 .37905 m
.70796 .37908 L
s
.70796 .37908 m
.70806 .37917 L
s
.70796 .37908 m
.7081 .37906 L
s
.7081 .37906 m
.70806 .37917 L
s
1 .038 0 r
.2948 .44605 m
.29506 .44613 L
s
.29509 .44572 m
.2948 .44605 L
s
.2948 .44605 m
.2949 .4458 L
s
.29524 .44605 m
.2948 .44605 L
s
.29616 .4454 m
.2948 .44605 L
s
.29506 .44613 m
.29524 .44605 L
s
.29524 .44605 m
.29509 .44572 L
s
.29509 .44572 m
.2949 .4458 L
s
.2949 .4458 m
.29506 .44613 L
s
1 .001 0 r
.7046 .17575 m
.7046 .17575 L
s
.7046 .17575 m
.7046 .17575 L
s
.70461 .17575 m
.7046 .17575 L
s
.7046 .17575 m
.7046 .17575 L
s
.7046 .17575 m
.70461 .17575 L
s
.70461 .17575 m
.7046 .17575 L
s
.7046 .17575 m
.70461 .17575 L
s
.70458 .17574 m
.70461 .17575 L
s
.7046 .17575 m
.7046 .17575 L
s
1 .006 0 r
.63485 .34428 m
.63459 .34423 L
s
.63465 .34427 m
.63463 .34426 L
s
.63463 .34426 m
.63464 .34421 L
s
.63463 .34426 m
.63459 .34423 L
s
.63464 .34421 m
.63466 .34422 L
s
.63464 .34421 m
.63459 .34423 L
s
.63459 .34423 m
.63465 .34427 L
s
.63459 .34423 m
.63466 .34422 L
s
.63466 .34422 m
.63465 .34427 L
s
1 .134 0 r
.48627 .47901 m
.48639 .47882 L
s
.48639 .47882 m
.48628 .47754 L
s
.48639 .47882 m
.485 .47836 L
s
.48628 .47754 m
.48616 .47773 L
s
.48628 .47754 m
.485 .47836 L
s
.485 .47836 m
.48627 .47901 L
s
.485 .47836 m
.48616 .47773 L
s
.49138 .47792 m
.485 .47836 L
s
1 .002 0 r
.63101 .14064 m
.63101 .14064 L
s
.63101 .14062 m
.63101 .14064 L
s
.63103 .14063 m
.63101 .14064 L
s
.63102 .14062 m
.63101 .14062 L
s
.63101 .14062 m
.63103 .14063 L
s
.63103 .14063 m
.63101 .14064 L
s
.63102 .14062 m
.63103 .14063 L
s
.63094 .14062 m
.63103 .14063 L
s
.63101 .14064 m
.63102 .14062 L
s
.5611 .30927 m
.5611 .30927 L
s
.5611 .30927 m
.5611 .30925 L
s
.5611 .30927 m
.56108 .30926 L
s
.5611 .30925 m
.5611 .30926 L
s
.5611 .30925 m
.56108 .30926 L
s
.56116 .30927 m
.56108 .30926 L
s
.56108 .30926 m
.5611 .30927 L
s
.56108 .30926 m
.5611 .30926 L
s
.5611 .30926 m
.5611 .30927 L
s
1 .134 0 r
.48616 .47773 m
.48627 .47901 L
s
1 .063 0 r
.41526 .4438 m
.41543 .44371 L
s
.41543 .44371 m
.41528 .44311 L
s
.41543 .44371 m
.4147 .44358 L
s
.41528 .44311 m
.41511 .4432 L
s
.41528 .44311 m
.4147 .44358 L
s
.4147 .44358 m
.41526 .4438 L
s
.4147 .44358 m
.41511 .4432 L
s
.41755 .44297 m
.4147 .44358 L
s
.41511 .4432 m
.41526 .4438 L
s
1 0 0 r
.48736 .27421 m
.48736 .27421 L
s
.48736 .27421 m
.48736 .27421 L
s
.48736 .27421 m
.48736 .27421 L
s
.48736 .27421 m
.48736 .27421 L
s
.48736 .27421 m
.48736 .27421 L
s
.48736 .27421 m
.48736 .27421 L
s
.48736 .27421 m
.48736 .27421 L
s
.48737 .27421 m
.48736 .27421 L
s
1 .003 0 r
.75669 .34171 m
.75656 .34166 L
s
1 0 0 r
.48736 .27421 m
.48736 .27421 L
s
1 .003 0 r
.75659 .34169 m
.75658 .34168 L
s
.75658 .34168 m
.75659 .34165 L
s
.75658 .34168 m
.75656 .34166 L
s
.75659 .34165 m
.7566 .34166 L
s
.75659 .34165 m
.75656 .34166 L
s
.7566 .34166 m
.75659 .34169 L
s
.75656 .34166 m
.75659 .34169 L
s
.75656 .34166 m
.7566 .34166 L
s
1 .024 0 r
.34281 .40839 m
.3429 .40835 L
s
.3429 .40835 m
.34282 .40813 L
s
.3429 .40835 m
.34262 .40833 L
s
.34282 .40813 m
.34273 .40817 L
s
.34282 .40813 m
.34262 .40833 L
s
.34262 .40833 m
.34281 .40839 L
s
.34262 .40833 m
.34273 .40817 L
s
.34361 .40798 m
.34262 .40833 L
s
.34273 .40817 m
.34281 .40839 L
s
1 .001 0 r
.68299 .30665 m
.68294 .30664 L
s
1 .115 0 r
.61311 .47553 m
.60786 .47459 L
s
1 .001 0 r
.68295 .30665 m
.68294 .30665 L
s
.68294 .30665 m
.68295 .30664 L
s
.68294 .30665 m
.68294 .30664 L
s
.68295 .30664 m
.68295 .30664 L
s
.68295 .30664 m
.68294 .30664 L
s
.68294 .30664 m
.68295 .30665 L
s
.68294 .30664 m
.68295 .30664 L
s
.68295 .30664 m
.68295 .30665 L
s
1 .115 0 r
.60893 .47541 m
.60867 .47523 L
s
.60867 .47523 m
.6089 .47415 L
s
.60867 .47523 m
.60786 .47459 L
s
.6089 .47415 m
.60916 .47433 L
s
.6089 .47415 m
.60786 .47459 L
s
.60786 .47459 m
.60893 .47541 L
s
.60786 .47459 m
.60916 .47433 L
s
1 .073 0 r
.53644 .44086 m
.53642 .44077 L
s
.53642 .44077 m
.53644 .44006 L
s
.53642 .44077 m
.53574 .44044 L
s
.53644 .44006 m
.53647 .44016 L
s
.53644 .44006 m
.53574 .44044 L
s
1 .115 0 r
.60916 .47433 m
.60893 .47541 L
s
1 .003 0 r
.67922 .10259 m
.67923 .10259 L
s
.67923 .10256 m
.67922 .10259 L
s
.67926 .10258 m
.67922 .10259 L
s
.67923 .10256 m
.67923 .10256 L
s
.67923 .10256 m
.67926 .10258 L
s
.67926 .10258 m
.67923 .10259 L
s
.67923 .10256 m
.67926 .10258 L
s
.6791 .10255 m
.67926 .10258 L
s
.67923 .10259 m
.67923 .10256 L
s
1 0 0 r
.60918 .27154 m
.60917 .27154 L
s
1 .073 0 r
.53926 .44054 m
.53574 .44044 L
s
1 0 0 r
.60917 .27154 m
.60917 .27154 L
s
.60917 .27154 m
.60917 .27154 L
s
.60917 .27154 m
.60917 .27154 L
s
.60917 .27154 m
.60917 .27154 L
s
.60917 .27154 m
.60917 .27154 L
s
.60917 .27154 m
.60917 .27154 L
s
.60917 .27154 m
.60917 .27154 L
s
.60917 .27154 m
.60917 .27154 L
s
1 .073 0 r
.53574 .44044 m
.53644 .44086 L
s
.53574 .44044 m
.53647 .44016 L
s
.53647 .44016 m
.53644 .44086 L
s
1 .035 0 r
.46398 .40583 m
.46403 .40579 L
s
.46403 .40579 m
.46398 .40545 L
s
.46403 .40579 m
.46365 .40568 L
s
.46398 .40545 m
.46393 .40549 L
s
.46398 .40545 m
.46365 .40568 L
s
.46365 .40568 m
.46398 .40583 L
s
.46365 .40568 m
.46393 .40549 L
s
.4653 .4055 m
.46365 .40568 L
s
.46393 .40549 m
.46398 .40583 L
s
1 .066 0 r
.73518 .47314 m
.73271 .47205 L
s
1 0 0 r
.53527 .23639 m
.53527 .23639 L
s
1 .066 0 r
.73323 .47263 m
.73292 .47249 L
s
.73292 .47249 m
.73318 .47191 L
s
.73292 .47249 m
.73271 .47205 L
s
.73318 .47191 m
.73349 .47205 L
s
.73318 .47191 m
.73271 .47205 L
s
1 .013 0 r
.39079 .37058 m
.39083 .37057 L
s
.39083 .37057 m
.3908 .37045 L
s
.39083 .37057 m
.39068 .37054 L
s
.3908 .37045 m
.39076 .37046 L
s
.3908 .37045 m
.39068 .37054 L
s
1 .066 0 r
.73349 .47205 m
.73323 .47263 L
s
.73271 .47205 m
.73323 .47263 L
s
1 .013 0 r
.39068 .37054 m
.39079 .37058 L
s
.39068 .37054 m
.39076 .37046 L
s
.39125 .37041 m
.39068 .37054 L
s
1 .066 0 r
.73271 .47205 m
.73349 .47205 L
s
1 .013 0 r
.39076 .37046 m
.39079 .37058 L
s
1 .053 0 r
.6613 .4381 m
.65899 .43749 L
s
1 0 0 r
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
1 .053 0 r
.65946 .4379 m
.65929 .43782 L
s
.65929 .43782 m
.65944 .43732 L
s
.65929 .43782 m
.65899 .43749 L
s
.65944 .43732 m
.65961 .4374 L
s
.65944 .43732 m
.65899 .43749 L
s
.65899 .43749 m
.65946 .4379 L
s
.65899 .43749 m
.65961 .4374 L
s
.65961 .4374 m
.65946 .4379 L
s
1 0 0 r
.65739 .23367 m
.65739 .23367 L
s
1 .033 0 r
.58733 .40301 m
.58575 .40283 L
s
.58607 .40304 m
.58602 .403 L
s
.58602 .403 m
.58606 .40268 L
s
.58602 .403 m
.58575 .40283 L
s
.58606 .40268 m
.58611 .40272 L
s
.58606 .40268 m
.58575 .40283 L
s
.58575 .40283 m
.58607 .40304 L
s
.58575 .40283 m
.58611 .40272 L
s
.58611 .40272 m
.58607 .40304 L
s
1 .015 0 r
.51266 .36796 m
.51266 .36795 L
s
.51266 .36795 m
.51266 .3678 L
s
.51266 .36795 m
.51251 .36788 L
s
.51266 .3678 m
.51265 .36781 L
s
.51266 .3678 m
.51251 .36788 L
s
.51251 .36788 m
.51266 .36796 L
s
.51251 .36788 m
.51265 .36781 L
s
.51326 .36787 m
.51251 .36788 L
s
1 0 0 r
.58337 .19841 m
.58337 .19841 L
s
.58337 .19841 m
.58337 .19841 L
s
.58337 .19841 m
.58337 .19841 L
s
.58337 .19841 m
.58337 .19841 L
s
.58337 .19841 m
.58337 .19841 L
s
.58337 .19841 m
.58337 .19841 L
s
.58337 .19841 m
.58337 .19841 L
s
.58337 .19841 m
.58337 .19841 L
s
1 .029 0 r
.78368 .43565 m
.78267 .43512 L
s
1 0 0 r
.58337 .19841 m
.58337 .19841 L
s
1 .015 0 r
.51265 .36781 m
.51266 .36796 L
s
1 .029 0 r
.78288 .43538 m
.78273 .43532 L
s
.78273 .43532 m
.78286 .43507 L
s
.78273 .43532 m
.78267 .43512 L
s
.78286 .43507 m
.78301 .43513 L
s
.78286 .43507 m
.78267 .43512 L
s
.78301 .43513 m
.78288 .43538 L
s
.78267 .43512 m
.78288 .43538 L
s
.78267 .43512 m
.78301 .43513 L
s
1 .005 0 r
.43889 .33273 m
.4389 .33273 L
s
.4389 .33273 m
.43889 .33268 L
s
.4389 .33273 m
.43885 .33271 L
s
.43889 .33268 m
.43888 .33269 L
s
.43889 .33268 m
.43885 .33271 L
s
.43885 .33271 m
.43889 .33273 L
s
.43885 .33271 m
.43888 .33269 L
s
.43908 .33268 m
.43885 .33271 L
s
.43888 .33269 m
.43889 .33273 L
s
1 .022 0 r
.70969 .40051 m
.7088 .4002 L
s
.70898 .40038 m
.7089 .40035 L
s
.7089 .40035 m
.70897 .40015 L
s
.7089 .40035 m
.7088 .4002 L
s
.70897 .40015 m
.70905 .40018 L
s
.70897 .40015 m
.7088 .4002 L
s
1 .055 0 r
.29259 .46809 m
.29297 .4682 L
s
.29301 .46759 m
.29259 .46809 L
s
.29259 .46809 m
.29274 .46771 L
s
.29324 .46808 m
.29259 .46809 L
s
.2946 .46713 m
.29259 .46809 L
s
.29297 .4682 m
.29324 .46808 L
s
.29324 .46808 m
.29301 .46759 L
s
.29301 .46759 m
.29274 .46771 L
s
1 .022 0 r
.7088 .4002 m
.70898 .40038 L
s
.7088 .4002 m
.70905 .40018 L
s
.70905 .40018 m
.70898 .40038 L
s
1 .055 0 r
.29274 .46771 m
.29297 .4682 L
s
1 0 0 r
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
1 .013 0 r
.6356 .36532 m
.63502 .36521 L
s
.63514 .3653 m
.63511 .36528 L
s
.63511 .36528 m
.63513 .36516 L
s
.63511 .36528 m
.63502 .36521 L
s
.63513 .36516 m
.63516 .36518 L
s
.63513 .36516 m
.63502 .36521 L
s
.63502 .36521 m
.63514 .3653 L
s
.63502 .36521 m
.63516 .36518 L
s
.63516 .36518 m
.63514 .3653 L
s
1 .005 0 r
.56121 .3301 m
.5612 .33009 L
s
.5612 .33009 m
.56121 .33004 L
s
.5612 .33009 m
.56116 .33007 L
s
1 .001 0 r
.63168 .16029 m
.63168 .16029 L
s
.63168 .16028 m
.63168 .16029 L
s
.63169 .16028 m
.63168 .16029 L
s
.63169 .16028 m
.63168 .16028 L
s
.63168 .16028 m
.63169 .16028 L
s
1 .005 0 r
.56121 .33004 m
.56121 .33005 L
s
.56121 .33004 m
.56116 .33007 L
s
1 .001 0 r
.63169 .16028 m
.63168 .16029 L
s
.63169 .16028 m
.63169 .16028 L
s
.63166 .16028 m
.63169 .16028 L
s
.63168 .16029 m
.63169 .16028 L
s
1 .005 0 r
.56141 .33008 m
.56116 .33007 L
s
.56116 .33007 m
.56121 .3301 L
s
.56116 .33007 m
.56121 .33005 L
s
.56121 .33005 m
.56121 .3301 L
s
1 .091 0 r
.4135 .46591 m
.41375 .46577 L
s
.41375 .46577 m
.41354 .46491 L
s
.41375 .46577 m
.4127 .46558 L
s
.41354 .46491 m
.4133 .46505 L
s
.41354 .46491 m
.4127 .46558 L
s
.4127 .46558 m
.4135 .46591 L
s
.4127 .46558 m
.4133 .46505 L
s
.41681 .46472 m
.4127 .46558 L
s
.4133 .46505 m
.4135 .46591 L
s
1 .001 0 r
.48706 .29481 m
.48706 .29481 L
s
.48706 .29481 m
.48706 .29479 L
s
.48706 .29481 m
.48705 .2948 L
s
.48706 .29479 m
.48706 .2948 L
s
.48706 .29479 m
.48705 .2948 L
s
.48705 .2948 m
.48706 .29481 L
s
.48705 .2948 m
.48706 .2948 L
s
.48711 .2948 m
.48705 .2948 L
s
1 .008 0 r
.75828 .36277 m
.75798 .36264 L
s
1 .001 0 r
.48706 .2948 m
.48706 .29481 L
s
1 .008 0 r
.75804 .36271 m
.75801 .36269 L
s
.75801 .36269 m
.75803 .36262 L
s
.75801 .36269 m
.75798 .36264 L
s
.75803 .36262 m
.75807 .36264 L
s
.75803 .36262 m
.75798 .36264 L
s
.75807 .36264 m
.75804 .36271 L
s
.75798 .36264 m
.75804 .36271 L
s
.75798 .36264 m
.75807 .36264 L
s
1 .039 0 r
.34107 .43016 m
.34123 .43009 L
s
.34123 .43009 m
.34109 .42973 L
s
.34123 .43009 m
.34076 .43005 L
s
.34109 .42973 m
.34094 .4298 L
s
.34109 .42973 m
.34076 .43005 L
s
.34076 .43005 m
.34107 .43016 L
s
.34076 .43005 m
.34094 .4298 L
s
.34236 .4295 m
.34076 .43005 L
s
.34094 .4298 m
.34107 .43016 L
s
1 .004 0 r
.68407 .32748 m
.6839 .32743 L
s
.68393 .32746 m
.68392 .32746 L
s
.68392 .32746 m
.68393 .32742 L
s
.68392 .32746 m
.6839 .32743 L
s
.68393 .32742 m
.68394 .32743 L
s
.68393 .32742 m
.6839 .32743 L
s
.6839 .32743 m
.68393 .32746 L
s
.6839 .32743 m
.68394 .32743 L
s
.68394 .32743 m
.68393 .32746 L
s
1 .104 0 r
.53532 .46277 m
.53528 .46263 L
s
.53528 .46263 m
.53532 .46161 L
s
.53528 .46263 m
.53431 .46216 L
s
.53532 .46161 m
.53535 .46176 L
s
.53532 .46161 m
.53431 .46216 L
s
1 .002 0 r
.68021 .12201 m
.68021 .12201 L
s
.68021 .12199 m
.68021 .12201 L
s
.68022 .12201 m
.68021 .12201 L
s
.68021 .12199 m
.68021 .12199 L
s
.68021 .12199 m
.68022 .12201 L
s
.68022 .12201 m
.68021 .12201 L
s
.68021 .12199 m
.68022 .12201 L
s
.68015 .12199 m
.68022 .12201 L
s
.68021 .12201 m
.68021 .12199 L
s
1 .001 0 r
.60975 .29214 m
.6097 .29214 L
s
1 .104 0 r
.53936 .4623 m
.53431 .46216 L
s
1 .001 0 r
.60971 .29214 m
.60971 .29214 L
s
.60971 .29214 m
.60971 .29213 L
s
.60971 .29214 m
.6097 .29214 L
s
.60971 .29213 m
.60971 .29213 L
s
.60971 .29213 m
.6097 .29214 L
s
.6097 .29214 m
.60971 .29214 L
s
.6097 .29214 m
.60971 .29213 L
s
.60971 .29213 m
.60971 .29214 L
s
1 .104 0 r
.53431 .46216 m
.53532 .46277 L
s
.53431 .46216 m
.53535 .46176 L
s
.53535 .46176 m
.53532 .46277 L
s
1 .055 0 r
.46277 .42756 m
.46285 .42749 L
s
.46285 .42749 m
.46279 .42696 L
s
.46285 .42749 m
.46225 .42732 L
s
.46279 .42696 m
.4627 .42703 L
s
.46279 .42696 m
.46225 .42732 L
s
.46225 .42732 m
.46277 .42756 L
s
.46225 .42732 m
.4627 .42703 L
s
.46489 .42703 m
.46225 .42732 L
s
.4627 .42703 m
.46277 .42756 L
s
1 0 0 r
.53533 .25676 m
.53533 .25676 L
s
.53533 .25676 m
.53533 .25676 L
s
.53533 .25676 m
.53533 .25676 L
s
.53533 .25676 m
.53533 .25676 L
s
.53533 .25676 m
.53533 .25676 L
s
.53534 .25676 m
.53533 .25676 L
s
.53533 .25676 m
.53533 .25676 L
s
.53533 .25676 m
.53533 .25676 L
s
.53533 .25676 m
.53533 .25676 L
s
1 .023 0 r
.38949 .39204 m
.38955 .39201 L
s
.38955 .39201 m
.3895 .39179 L
s
.38955 .39201 m
.38928 .39196 L
s
.3895 .39179 m
.38943 .39182 L
s
.3895 .39179 m
.38928 .39196 L
s
.38928 .39196 m
.38949 .39204 L
s
.38928 .39196 m
.38943 .39182 L
s
.39033 .39172 m
.38928 .39196 L
s
.38943 .39182 m
.38949 .39204 L
s
1 .001 0 r
.73273 .28948 m
.7327 .28947 L
s
1 .077 0 r
.66224 .45987 m
.65887 .45899 L
s
1 .001 0 r
.73271 .28948 m
.73271 .28948 L
s
.73271 .28948 m
.73271 .28947 L
s
.73271 .28948 m
.7327 .28947 L
s
.73271 .28947 m
.73271 .28947 L
s
.73271 .28947 m
.7327 .28947 L
s
.7327 .28947 m
.73271 .28948 L
s
.7327 .28947 m
.73271 .28947 L
s
.73271 .28947 m
.73271 .28948 L
s
1 .077 0 r
.65956 .45959 m
.65931 .45947 L
s
.65931 .45947 m
.65953 .45874 L
s
.65931 .45947 m
.65887 .45899 L
s
.65953 .45874 m
.65977 .45887 L
s
.65953 .45874 m
.65887 .45899 L
s
.65887 .45899 m
.65956 .45959 L
s
.65887 .45899 m
.65977 .45887 L
s
.65977 .45887 m
.65956 .45959 L
s
1 0 0 r
.6583 .25405 m
.6583 .25405 L
s
1 .053 0 r
.58776 .42455 m
.58522 .42427 L
s
1 0 0 r
.6583 .25405 m
.6583 .25405 L
s
.6583 .25405 m
.6583 .25405 L
s
.6583 .25405 m
.6583 .25405 L
s
.6583 .25405 m
.6583 .25405 L
s
.6583 .25405 m
.6583 .25405 L
s
.6583 .25405 m
.6583 .25405 L
s
.6583 .25405 m
.6583 .25405 L
s
.6583 .25405 m
.6583 .25405 L
s
1 .053 0 r
.58574 .42462 m
.58566 .42455 L
s
.58566 .42455 m
.58573 .42404 L
s
.58566 .42455 m
.58522 .42427 L
s
.58573 .42404 m
.5858 .4241 L
s
.58573 .42404 m
.58522 .42427 L
s
.58522 .42427 m
.58574 .42462 L
s
.58522 .42427 m
.5858 .4241 L
s
.5858 .4241 m
.58574 .42462 L
s
1 .028 0 r
.51207 .38936 m
.51208 .38933 L
s
.51208 .38933 m
.51207 .38906 L
s
.51208 .38933 m
.5118 .38922 L
s
.51207 .38906 m
.51207 .38909 L
s
.51207 .38906 m
.5118 .38922 L
s
.5118 .38922 m
.51207 .38936 L
s
.5118 .38922 m
.51207 .38909 L
s
.51317 .38919 m
.5118 .38922 L
s
1 .043 0 r
.78546 .45744 m
.78395 .45666 L
s
1 0 0 r
.58377 .21857 m
.58377 .21857 L
s
1 .028 0 r
.51207 .38909 m
.51207 .38936 L
s
1 .043 0 r
.78427 .45705 m
.78405 .45695 L
s
.78405 .45695 m
.78423 .45658 L
s
.78405 .45695 m
.78395 .45666 L
s
.78423 .45658 m
.78446 .45667 L
s
.78423 .45658 m
.78395 .45666 L
s
.78446 .45667 m
.78427 .45705 L
s
.78395 .45666 m
.78427 .45705 L
s
.78395 .45666 m
.78446 .45667 L
s
1 .011 0 r
.43806 .35389 m
.43808 .35388 L
s
.43808 .35388 m
.43806 .35377 L
s
.43808 .35388 m
.43795 .35385 L
s
.43806 .35377 m
.43804 .35378 L
s
.43806 .35377 m
.43795 .35385 L
s
.43795 .35385 m
.43806 .35389 L
s
.43795 .35385 m
.43804 .35378 L
s
.43849 .35377 m
.43795 .35385 L
s
.43804 .35378 m
.43806 .35389 L
s
1 .035 0 r
.71096 .42207 m
.7095 .42158 L
s
.70981 .42187 m
.70967 .42181 L
s
.70967 .42181 m
.70978 .42148 L
s
.70967 .42181 m
.7095 .42158 L
s
.70978 .42148 m
.70992 .42154 L
s
.70978 .42148 m
.7095 .42158 L
s
.7095 .42158 m
.70981 .42187 L
s
.7095 .42158 m
.70992 .42154 L
s
.70992 .42154 m
.70981 .42187 L
s
1 .023 0 r
.63636 .38665 m
.63528 .38645 L
s
1 0 0 r
.70705 .2158 m
.70705 .2158 L
s
1 .023 0 r
.6355 .38662 m
.63545 .38659 L
s
.63545 .38659 m
.63549 .38636 L
s
.63545 .38659 m
.63528 .38645 L
s
.63549 .38636 m
.63555 .38639 L
s
.63549 .38636 m
.63528 .38645 L
s
.63528 .38645 m
.6355 .38662 L
s
.63528 .38645 m
.63555 .38639 L
s
.63555 .38639 m
.6355 .38662 L
s
1 .012 0 r
.5612 .35122 m
.56119 .35121 L
s
.56119 .35121 m
.5612 .3511 L
s
.56119 .35121 m
.56108 .35115 L
s
.5612 .3511 m
.56121 .35111 L
s
.5612 .3511 m
.56108 .35115 L
s
1 0 0 r
.6324 .18021 m
.6324 .18021 L
s
.6324 .18021 m
.6324 .18021 L
s
.6324 .18021 m
.6324 .18021 L
s
.6324 .18021 m
.6324 .18021 L
s
.6324 .18021 m
.6324 .18021 L
s
.6324 .18021 m
.6324 .18021 L
s
.6324 .18021 m
.6324 .18021 L
s
.63239 .18021 m
.6324 .18021 L
s
.6324 .18021 m
.6324 .18021 L
s
1 .012 0 r
.56166 .35119 m
.56108 .35115 L
s
.56108 .35115 m
.5612 .35122 L
s
.56108 .35115 m
.56121 .35111 L
s
.56121 .35111 m
.5612 .35122 L
s
1 .004 0 r
.48668 .31571 m
.48669 .3157 L
s
.48669 .3157 m
.48668 .31566 L
s
.48669 .3157 m
.48664 .31569 L
s
.48668 .31566 m
.48668 .31566 L
s
.48668 .31566 m
.48664 .31569 L
s
.48664 .31569 m
.48668 .31571 L
s
.48664 .31569 m
.48668 .31566 L
s
.48685 .31567 m
.48664 .31569 L
s
1 .014 0 r
.75989 .38411 m
.75932 .38388 L
s
1 .004 0 r
.48668 .31566 m
.48668 .31571 L
s
1 .014 0 r
.75944 .384 m
.75937 .38398 L
s
.75937 .38398 m
.75943 .38385 L
s
.75937 .38398 m
.75932 .38388 L
s
.75943 .38385 m
.75949 .38387 L
s
.75943 .38385 m
.75932 .38388 L
s
.75949 .38387 m
.75944 .384 L
s
.75932 .38388 m
.75944 .384 L
s
.75932 .38388 m
.75949 .38387 L
s
1 .057 0 r
.3392 .45228 m
.33942 .45217 L
s
.33942 .45217 m
.33923 .45165 L
s
.33942 .45217 m
.33874 .45212 L
s
.33923 .45165 m
.339 .45175 L
s
.33923 .45165 m
.33874 .45212 L
s
.33874 .45212 m
.3392 .45228 L
s
.33874 .45212 m
.339 .45175 L
s
.3411 .45132 m
.33874 .45212 L
s
.339 .45175 m
.3392 .45228 L
s
1 .009 0 r
.68516 .34859 m
.68478 .34849 L
s
.68486 .34856 m
.68483 .34855 L
s
.68483 .34855 m
.68485 .34847 L
s
.68483 .34855 m
.68478 .34849 L
s
.68485 .34847 m
.68488 .34848 L
s
.68485 .34847 m
.68478 .34849 L
s
.68478 .34849 m
.68486 .34856 L
s
.68478 .34849 m
.68488 .34848 L
s
.68488 .34848 m
.68486 .34856 L
s
1 0 0 r
.68124 .14171 m
.68124 .14171 L
s
.68124 .1417 m
.68124 .14171 L
s
.68124 .1417 m
.68124 .14171 L
s
.68124 .1417 m
.68124 .1417 L
s
.68124 .1417 m
.68124 .1417 L
s
.68124 .1417 m
.68124 .14171 L
s
.68124 .1417 m
.68124 .1417 L
s
.68122 .1417 m
.68124 .1417 L
s
.68124 .14171 m
.68124 .1417 L
s
1 .004 0 r
.61034 .31303 m
.61016 .31301 L
s
.61019 .31303 m
.61019 .31303 L
s
.61019 .31303 m
.61019 .31299 L
s
.61019 .31303 m
.61016 .31301 L
s
.61019 .31299 m
.6102 .31299 L
s
.61019 .31299 m
.61016 .31301 L
s
.61016 .31301 m
.61019 .31303 L
s
.61016 .31301 m
.6102 .31299 L
s
.6102 .31299 m
.61019 .31303 L
s
1 .08 0 r
.4614 .44964 m
.46152 .44953 L
s
.46152 .44953 m
.46142 .44875 L
s
.46152 .44953 m
.46064 .44927 L
s
.46142 .44875 m
.4613 .44886 L
s
.46142 .44875 m
.46064 .44927 L
s
.46064 .44927 m
.4614 .44964 L
s
.46064 .44927 m
.4613 .44886 L
s
.46448 .44886 m
.46064 .44927 L
s
.4613 .44886 m
.4614 .44964 L
s
1 .001 0 r
.53537 .27742 m
.53537 .27742 L
s
.53537 .27742 m
.53537 .27741 L
s
.53537 .27742 m
.53536 .27741 L
s
.53537 .27741 m
.53537 .27741 L
s
.53537 .27741 m
.53536 .27741 L
s
.53541 .27742 m
.53536 .27741 L
s
.53536 .27741 m
.53537 .27742 L
s
.53536 .27741 m
.53537 .27741 L
s
.53537 .27741 m
.53537 .27742 L
s
1 .038 0 r
.38803 .41384 m
.38814 .41379 L
s
.38814 .41379 m
.38805 .41343 L
s
.38814 .41379 m
.3877 .41371 L
s
.38805 .41343 m
.38794 .41348 L
s
.38805 .41343 m
.3877 .41371 L
s
.3877 .41371 m
.38803 .41384 L
s
.3877 .41371 m
.38794 .41348 L
s
.38939 .41332 m
.3877 .41371 L
s
.38794 .41348 m
.38803 .41384 L
s
1 .003 0 r
.73417 .31038 m
.73406 .31034 L
s
.73408 .31036 m
.73407 .31036 L
s
.73407 .31036 m
.73408 .31033 L
s
.73407 .31036 m
.73406 .31034 L
s
.73408 .31033 m
.73409 .31034 L
s
.73408 .31033 m
.73406 .31034 L
s
.73406 .31034 m
.73408 .31036 L
s
.73406 .31034 m
.73409 .31034 L
s
.73409 .31034 m
.73408 .31036 L
s
1 .001 0 r
.65922 .27471 m
.65918 .27471 L
s
1 .077 0 r
.58819 .4464 m
.58451 .44599 L
s
1 .001 0 r
.65919 .27471 m
.65919 .27471 L
s
.65919 .27471 m
.65919 .2747 L
s
.65919 .27471 m
.65918 .27471 L
s
1 .077 0 r
.58525 .4465 m
.58514 .44639 L
s
.58514 .44639 m
.58523 .44565 L
s
.58514 .44639 m
.58451 .44599 L
s
1 .001 0 r
.65919 .2747 m
.65919 .2747 L
s
.65919 .2747 m
.65918 .27471 L
s
.65918 .27471 m
.65919 .27471 L
s
.65918 .27471 m
.65919 .2747 L
s
.65919 .2747 m
.65919 .27471 L
s
1 .077 0 r
.58523 .44565 m
.58535 .44575 L
s
.58523 .44565 m
.58451 .44599 L
s
.58451 .44599 m
.58525 .4465 L
s
.58451 .44599 m
.58535 .44575 L
s
.58535 .44575 m
.58525 .4465 L
s
1 .045 0 r
.51132 .41109 m
.51133 .41103 L
s
.51133 .41103 m
.51132 .41059 L
s
.51133 .41103 m
.51088 .41085 L
s
.51132 .41059 m
.51131 .41064 L
s
.51132 .41059 m
.51088 .41085 L
s
.51088 .41085 m
.51132 .41109 L
s
.51088 .41085 m
.51131 .41064 L
s
.51309 .4108 m
.51088 .41085 L
s
1 0 0 r
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
1 .045 0 r
.51131 .41064 m
.51132 .41109 L
s
1 .021 0 r
.43709 .37538 m
.43713 .37536 L
s
.43713 .37536 m
.43709 .37516 L
s
.43713 .37536 m
.43689 .3753 L
s
.43709 .37516 m
.43705 .37518 L
s
.43709 .37516 m
.43689 .3753 L
s
.43689 .3753 m
.43709 .37538 L
s
.43689 .3753 m
.43705 .37518 L
s
.43789 .37516 m
.43689 .3753 L
s
.43705 .37518 m
.43709 .37538 L
s
1 .051 0 r
.71225 .44393 m
.71009 .44321 L
s
.71054 .44364 m
.71034 .44355 L
s
.71034 .44355 m
.71051 .44307 L
s
.71034 .44355 m
.71009 .44321 L
s
.71051 .44307 m
.71071 .44316 L
s
.71051 .44307 m
.71009 .44321 L
s
.71009 .44321 m
.71054 .44364 L
s
.71009 .44321 m
.71071 .44316 L
s
.71071 .44316 m
.71054 .44364 L
s
1 .038 0 r
.63713 .40828 m
.63538 .40795 L
s
1 0 0 r
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
1 .038 0 r
.63574 .40823 m
.63565 .40818 L
s
.63565 .40818 m
.63573 .40781 L
s
.63565 .40818 m
.63538 .40795 L
s
.63573 .40781 m
.63582 .40786 L
s
.63573 .40781 m
.63538 .40795 L
s
.63538 .40795 m
.63574 .40823 L
s
.63538 .40795 m
.63582 .40786 L
s
.63582 .40786 m
.63574 .40823 L
s
1 .022 0 r
.56106 .37265 m
.56104 .37263 L
s
.56104 .37263 m
.56106 .37242 L
s
.56104 .37263 m
.56085 .37252 L
s
.56106 .37242 m
.56108 .37244 L
s
.56106 .37242 m
.56085 .37252 L
s
.56191 .37258 m
.56085 .37252 L
s
1 0 0 r
.63314 .20042 m
.63314 .20042 L
s
1 .022 0 r
.56085 .37252 m
.56106 .37265 L
s
.56085 .37252 m
.56108 .37244 L
s
.56108 .37244 m
.56106 .37265 L
s
1 .01 0 r
.48621 .33691 m
.48621 .3369 L
s
.48621 .3369 m
.48621 .33681 L
s
.48621 .3369 m
.48611 .33687 L
s
.48621 .33681 m
.4862 .33682 L
s
.48621 .33681 m
.48611 .33687 L
s
.48611 .33687 m
.48621 .33691 L
s
.48611 .33687 m
.4862 .33682 L
s
.48658 .33684 m
.48611 .33687 L
s
1 .023 0 r
.76151 .40575 m
.76059 .40537 L
s
1 .01 0 r
.4862 .33682 m
.48621 .33691 L
s
1 .023 0 r
.76078 .40558 m
.76067 .40553 L
s
.76067 .40553 m
.76076 .40532 L
s
.76067 .40553 m
.76059 .40537 L
s
.76076 .40532 m
.76087 .40536 L
s
.76076 .40532 m
.76059 .40537 L
s
.76087 .40536 m
.76078 .40558 L
s
.76059 .40537 m
.76078 .40558 L
s
.76059 .40537 m
.76087 .40536 L
s
1 .016 0 r
.68627 .37 m
.68555 .36982 L
s
.6857 .36994 m
.68565 .36992 L
s
.68565 .36992 m
.68569 .36976 L
s
.68565 .36992 m
.68555 .36982 L
s
.68569 .36976 m
.68574 .36979 L
s
.68569 .36976 m
.68555 .36982 L
s
.68555 .36982 m
.6857 .36994 L
s
.68555 .36982 m
.68574 .36979 L
s
.68574 .36979 m
.6857 .36994 L
s
1 0 0 r
.68231 .16169 m
.68231 .16169 L
s
.68231 .16169 m
.68231 .16169 L
s
.68231 .16169 m
.68231 .16169 L
s
.68231 .16169 m
.68231 .16169 L
s
.68231 .16169 m
.68231 .16169 L
s
.68231 .16169 m
.68231 .16169 L
s
.68231 .16169 m
.68231 .16169 L
s
.68231 .16168 m
.68231 .16169 L
s
.68231 .16169 m
.68231 .16169 L
s
1 .009 0 r
.61093 .3342 m
.61051 .33415 L
s
.6106 .33421 m
.61058 .3342 L
s
.61058 .3342 m
.61059 .33411 L
s
.61058 .3342 m
.61051 .33415 L
s
.61059 .33411 m
.61061 .33412 L
s
.61059 .33411 m
.61051 .33415 L
s
.61051 .33415 m
.6106 .33421 L
s
.61051 .33415 m
.61061 .33412 L
s
.61061 .33412 m
.6106 .33421 L
s
1 .003 0 r
.53535 .29837 m
.53535 .29837 L
s
.53535 .29837 m
.53535 .29834 L
s
.53535 .29837 m
.53531 .29836 L
s
.53535 .29834 m
.53535 .29834 L
s
.53535 .29834 m
.53531 .29836 L
s
.53548 .29836 m
.53531 .29836 L
s
.53531 .29836 m
.53535 .29837 L
s
.53531 .29836 m
.53535 .29834 L
s
.53535 .29834 m
.53535 .29837 L
s
1 .055 0 r
.38644 .43599 m
.3866 .4359 L
s
.3866 .4359 m
.38646 .43538 L
s
.3866 .4359 m
.38595 .4358 L
s
.38646 .43538 m
.3863 .43546 L
s
.38646 .43538 m
.38595 .4358 L
s
.38595 .4358 m
.38644 .43599 L
s
.38595 .4358 m
.3863 .43546 L
s
.38845 .43522 m
.38595 .4358 L
s
.3863 .43546 m
.38644 .43599 L
s
1 .006 0 r
.73562 .33157 m
.73537 .33148 L
s
.73542 .33153 m
.7354 .33152 L
s
.7354 .33152 m
.73542 .33147 L
s
.7354 .33152 m
.73537 .33148 L
s
.73542 .33147 m
.73544 .33147 L
s
.73542 .33147 m
.73537 .33148 L
s
.73537 .33148 m
.73542 .33153 L
s
.73537 .33148 m
.73544 .33147 L
s
.73544 .33147 m
.73542 .33153 L
s
1 .003 0 r
.66016 .29567 m
.66003 .29564 L
s
.66005 .29566 m
.66005 .29566 L
s
.66005 .29566 m
.66005 .29563 L
s
.66005 .29566 m
.66003 .29564 L
s
.66005 .29563 m
.66006 .29563 L
s
.66005 .29563 m
.66003 .29564 L
s
.66003 .29564 m
.66005 .29566 L
s
.66003 .29564 m
.66006 .29563 L
s
.66006 .29563 m
.66005 .29566 L
s
1 .066 0 r
.51041 .43314 m
.51043 .43305 L
s
.51043 .43305 m
.51041 .4324 L
s
.51043 .43305 m
.50977 .43278 L
s
.51041 .4324 m
.5104 .43249 L
s
.51041 .4324 m
.50977 .43278 L
s
.50977 .43278 m
.51041 .43314 L
s
.50977 .43278 m
.5104 .43249 L
s
.51301 .43272 m
.50977 .43278 L
s
1 .001 0 r
.58455 .25972 m
.58455 .25972 L
s
.58455 .25972 m
.58455 .25971 L
s
.58455 .25972 m
.58454 .25971 L
s
.58455 .25971 m
.58455 .25971 L
s
.58455 .25971 m
.58454 .25971 L
s
.58458 .25972 m
.58454 .25971 L
s
.58454 .25971 m
.58455 .25972 L
s
.58454 .25971 m
.58455 .25971 L
s
.58455 .25971 m
.58455 .25972 L
s
1 .066 0 r
.5104 .43249 m
.51041 .43314 L
s
1 .034 0 r
.43598 .39721 m
.43604 .39717 L
s
.43604 .39717 m
.43599 .39683 L
s
.43604 .39717 m
.43566 .39707 L
s
.43599 .39683 m
.43592 .39688 L
s
.43599 .39683 m
.43566 .39707 L
s
.43566 .39707 m
.43598 .39721 L
s
.43566 .39707 m
.43592 .39688 L
s
.43728 .39684 m
.43566 .39707 L
s
.43592 .39688 m
.43598 .39721 L
s
1 .001 0 r
.70959 .25697 m
.70956 .25696 L
s
1 .055 0 r
.63791 .43021 m
.63534 .42973 L
s
1 .001 0 r
.70957 .25696 m
.70956 .25696 L
s
.70956 .25696 m
.70957 .25696 L
s
.70956 .25696 m
.70956 .25696 L
s
.70957 .25696 m
.70957 .25696 L
s
.70957 .25696 m
.70956 .25696 L
s
.70956 .25696 m
.70957 .25696 L
s
.70956 .25696 m
.70957 .25696 L
s
.70957 .25696 m
.70957 .25696 L
s
1 .055 0 r
.63586 .43014 m
.63573 .43006 L
s
.63573 .43006 m
.63584 .42952 L
s
.63573 .43006 m
.63534 .42973 L
s
.63584 .42952 m
.63598 .4296 L
s
.63584 .42952 m
.63534 .42973 L
s
.63534 .42973 m
.63586 .43014 L
s
.63534 .42973 m
.63598 .4296 L
s
.63598 .4296 m
.63586 .43014 L
s
1 .035 0 r
.56079 .39439 m
.56076 .39435 L
s
.56076 .39435 m
.56078 .39401 L
s
.56076 .39435 m
.56044 .39418 L
s
.56078 .39401 m
.56081 .39405 L
s
.56078 .39401 m
.56044 .39418 L
s
.56216 .39428 m
.56044 .39418 L
s
1 0 0 r
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
1 .035 0 r
.56044 .39418 m
.56079 .39439 L
s
.56044 .39418 m
.56081 .39405 L
s
.56081 .39405 m
.56079 .39439 L
s
1 .018 0 r
.48561 .35844 m
.48563 .35842 L
s
.48563 .35842 m
.48561 .35824 L
s
.48563 .35842 m
.48544 .35835 L
s
.48561 .35824 m
.4856 .35826 L
s
.48561 .35824 m
.48544 .35835 L
s
.48544 .35835 m
.48561 .35844 L
s
.48544 .35835 m
.4856 .35826 L
s
.48631 .3583 m
.48544 .35835 L
s
1 .035 0 r
.76317 .42769 m
.76177 .42713 L
s
1 .018 0 r
.4856 .35826 m
.48561 .35844 L
s
1 .035 0 r
.76207 .42744 m
.7619 .42737 L
s
.7619 .42737 m
.76204 .42705 L
s
.7619 .42737 m
.76177 .42713 L
s
.76204 .42705 m
.7622 .42712 L
s
.76204 .42705 m
.76177 .42713 L
s
.7622 .42712 m
.76207 .42744 L
s
.76177 .42713 m
.76207 .42744 L
s
.76177 .42713 m
.7622 .42712 L
s
1 .026 0 r
.6874 .39171 m
.68622 .39141 L
s
.68646 .39161 m
.68638 .39158 L
s
.68638 .39158 m
.68645 .39132 L
s
.68638 .39158 m
.68622 .39141 L
s
.68645 .39132 m
.68653 .39136 L
s
.68645 .39132 m
.68622 .39141 L
s
.68622 .39141 m
.68646 .39161 L
s
.68622 .39141 m
.68653 .39136 L
s
.68653 .39136 m
.68646 .39161 L
s
1 .016 0 r
.61153 .35568 m
.61075 .35558 L
s
1 0 0 r
.68341 .18195 m
.68341 .18195 L
s
1 .016 0 r
.61091 .35568 m
.61088 .35567 L
s
.61088 .35567 m
.6109 .35551 L
s
.61088 .35567 m
.61075 .35558 L
s
.6109 .35551 m
.61093 .35552 L
s
.6109 .35551 m
.61075 .35558 L
s
.61075 .35558 m
.61091 .35568 L
s
.61075 .35558 m
.61093 .35552 L
s
.61093 .35552 m
.61091 .35568 L
s
1 .008 0 r
.53525 .31963 m
.53524 .31963 L
s
.53524 .31963 m
.53525 .31955 L
s
.53524 .31963 m
.53517 .31959 L
s
.53525 .31955 m
.53525 .31955 L
s
.53525 .31955 m
.53517 .31959 L
s
.53555 .31959 m
.53517 .31959 L
s
.53517 .31959 m
.53525 .31963 L
s
.53517 .31959 m
.53525 .31955 L
s
.53525 .31955 m
.53525 .31963 L
s
1 .011 0 r
.7371 .35305 m
.73661 .35289 L
s
.73672 .35299 m
.73667 .35297 L
s
.73667 .35297 m
.73671 .35286 L
s
.73667 .35297 m
.73661 .35289 L
s
.73671 .35286 m
.73675 .35288 L
s
.73671 .35286 m
.73661 .35289 L
s
.73661 .35289 m
.73672 .35299 L
s
.73661 .35289 m
.73675 .35288 L
s
.73675 .35288 m
.73672 .35299 L
s
1 .006 0 r
.6611 .31691 m
.6608 .31685 L
s
.66087 .3169 m
.66085 .31689 L
s
.66085 .31689 m
.66086 .31683 L
s
.66085 .31689 m
.6608 .31685 L
s
.66086 .31683 m
.66088 .31684 L
s
.66086 .31683 m
.6608 .31685 L
s
.6608 .31685 m
.66087 .3169 L
s
.6608 .31685 m
.66088 .31684 L
s
.66088 .31684 m
.66087 .3169 L
s
1 .003 0 r
.5849 .28073 m
.58489 .28073 L
s
.58489 .28073 m
.5849 .2807 L
s
.58489 .28073 m
.58487 .28072 L
s
.5849 .2807 m
.5849 .28071 L
s
.5849 .2807 m
.58487 .28072 L
s
.585 .28073 m
.58487 .28072 L
s
.58487 .28072 m
.5849 .28073 L
s
.58487 .28072 m
.5849 .28071 L
s
.5849 .28071 m
.5849 .28073 L
s
1 .05 0 r
.43473 .41937 m
.43483 .41931 L
s
.43483 .41931 m
.43475 .41881 L
s
.43483 .41931 m
.43426 .41916 L
s
.43475 .41881 m
.43465 .41888 L
s
.43475 .41881 m
.43426 .41916 L
s
.43426 .41916 m
.43473 .41937 L
s
.43426 .41916 m
.43465 .41888 L
s
.43666 .41883 m
.43426 .41916 L
s
.43465 .41888 m
.43473 .41937 L
s
1 .002 0 r
.71088 .27799 m
.71079 .27796 L
s
.71081 .27798 m
.71081 .27798 L
s
.71081 .27798 m
.71081 .27796 L
s
.71081 .27798 m
.71079 .27796 L
s
.71081 .27796 m
.71082 .27796 L
s
.71081 .27796 m
.71079 .27796 L
s
.71079 .27796 m
.71081 .27798 L
s
.71079 .27796 m
.71082 .27796 L
s
.71082 .27796 m
.71081 .27798 L
s
1 .051 0 r
.56039 .41645 m
.56035 .41639 L
s
.56035 .41639 m
.56038 .41588 L
s
.56035 .41639 m
.55988 .41613 L
s
.56038 .41588 m
.56042 .41594 L
s
.56038 .41588 m
.55988 .41613 L
s
1 .001 0 r
.63466 .2417 m
.63463 .24169 L
s
1 .051 0 r
.56242 .41628 m
.55988 .41613 L
s
1 .001 0 r
.63463 .2417 m
.63463 .2417 L
s
.63463 .2417 m
.63463 .24169 L
s
.63463 .2417 m
.63463 .24169 L
s
.63463 .24169 m
.63463 .24169 L
s
.63463 .24169 m
.63463 .24169 L
s
.63463 .24169 m
.63463 .2417 L
s
.63463 .24169 m
.63463 .24169 L
s
.63463 .24169 m
.63463 .2417 L
s
1 .051 0 r
.55988 .41613 m
.56039 .41645 L
s
.55988 .41613 m
.56042 .41594 L
s
.56042 .41594 m
.56039 .41645 L
s
1 .029 0 r
.48489 .38029 m
.48492 .38026 L
s
.48492 .38026 m
.4849 .37997 L
s
.48492 .38026 m
.48461 .38014 L
s
.4849 .37997 m
.48487 .38 L
s
.4849 .37997 m
.48461 .38014 L
s
.48461 .38014 m
.48489 .38029 L
s
.48461 .38014 m
.48487 .38 L
s
.48604 .38006 m
.48461 .38014 L
s
.48487 .38 m
.48489 .38029 L
s
1 .039 0 r
.68854 .41372 m
.68678 .41328 L
s
.68714 .41358 m
.68701 .41353 L
s
.68701 .41353 m
.68712 .41315 L
s
.68701 .41353 m
.68678 .41328 L
s
.68712 .41315 m
.68725 .41321 L
s
.68712 .41315 m
.68678 .41328 L
s
.68678 .41328 m
.68714 .41358 L
s
.68678 .41328 m
.68725 .41321 L
s
.68725 .41321 m
.68714 .41358 L
s
1 .026 0 r
.61214 .37745 m
.61086 .37729 L
s
1 0 0 r
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
1 .026 0 r
.61112 .37747 m
.61107 .37744 L
s
.61107 .37744 m
.61111 .37718 L
s
.61107 .37744 m
.61086 .37729 L
s
.61111 .37718 m
.61116 .37721 L
s
.61111 .37718 m
.61086 .37729 L
s
.61086 .37729 m
.61112 .37747 L
s
.61086 .37729 m
.61116 .37721 L
s
.61116 .37721 m
.61112 .37747 L
s
1 .014 0 r
.53505 .3412 m
.53505 .34119 L
s
.53505 .34119 m
.53505 .34104 L
s
.53505 .34119 m
.53491 .34112 L
s
.53505 .34104 m
.53505 .34106 L
s
.53505 .34104 m
.53491 .34112 L
s
.53562 .34113 m
.53491 .34112 L
s
.53491 .34112 m
.53505 .3412 L
s
.53491 .34112 m
.53505 .34106 L
s
.53505 .34106 m
.53505 .3412 L
s
1 .018 0 r
.73859 .37484 m
.73779 .37458 L
s
.73796 .37473 m
.73789 .37471 L
s
.73789 .37471 m
.73795 .37453 L
s
.73789 .37471 m
.73779 .37458 L
s
.73795 .37453 m
.73802 .37456 L
s
.73795 .37453 m
.73779 .37458 L
s
.73779 .37458 m
.73796 .37473 L
s
.73779 .37458 m
.73802 .37456 L
s
.73802 .37456 m
.73796 .37473 L
s
1 .012 0 r
.66206 .33846 m
.6615 .33835 L
s
.66162 .33844 m
.66159 .33843 L
s
.66159 .33843 m
.66161 .33831 L
s
.66159 .33843 m
.6615 .33835 L
s
.66161 .33831 m
.66164 .33832 L
s
.66161 .33831 m
.6615 .33835 L
s
.6615 .33835 m
.66162 .33844 L
s
.6615 .33835 m
.66164 .33832 L
s
.66164 .33832 m
.66162 .33844 L
s
1 .006 0 r
.58518 .30205 m
.58518 .30204 L
s
.58518 .30204 m
.58518 .30198 L
s
.58518 .30204 m
.58512 .30201 L
s
.58518 .30198 m
.58519 .30199 L
s
.58518 .30198 m
.58512 .30201 L
s
.58542 .30203 m
.58512 .30201 L
s
.58512 .30201 m
.58518 .30205 L
s
.58512 .30201 m
.58519 .30199 L
s
.58519 .30199 m
.58518 .30205 L
s
1 .005 0 r
.7122 .2993 m
.71199 .29925 L
s
.71203 .29928 m
.71202 .29928 L
s
.71202 .29928 m
.71203 .29923 L
s
.71202 .29928 m
.71199 .29925 L
s
.71203 .29923 m
.71204 .29924 L
s
.71203 .29923 m
.71199 .29925 L
s
.71199 .29925 m
.71203 .29928 L
s
.71199 .29925 m
.71204 .29924 L
s
.71204 .29924 m
.71203 .29928 L
s
1 .002 0 r
.63543 .26277 m
.63533 .26276 L
s
.63535 .26277 m
.63535 .26277 L
s
.63535 .26277 m
.63535 .26275 L
s
.63535 .26277 m
.63533 .26276 L
s
.63535 .26275 m
.63536 .26275 L
s
.63535 .26275 m
.63533 .26276 L
s
.63533 .26276 m
.63535 .26277 L
s
.63533 .26276 m
.63536 .26275 L
s
.63536 .26275 m
.63535 .26277 L
s
1 .043 0 r
.48405 .40247 m
.48409 .40242 L
s
.48409 .40242 m
.48406 .40199 L
s
.48409 .40242 m
.48363 .40225 L
s
.48406 .40199 m
.48403 .40204 L
s
.48406 .40199 m
.48363 .40225 L
s
.48363 .40225 m
.48405 .40247 L
s
.48363 .40225 m
.48403 .40204 L
s
.48576 .40213 m
.48363 .40225 L
s
.48403 .40204 m
.48405 .40247 L
s
1 0 0 r
.68565 .22334 m
.68563 .22334 L
s
1 .039 0 r
.61275 .39954 m
.61084 .3993 L
s
1 0 0 r
.68564 .22334 m
.68563 .22334 L
s
.68563 .22334 m
.68564 .22334 L
s
.68563 .22334 m
.68563 .22334 L
s
.68564 .22334 m
.68564 .22334 L
s
.68564 .22334 m
.68563 .22334 L
s
.68563 .22334 m
.68564 .22334 L
s
.68563 .22334 m
.68564 .22334 L
s
.68564 .22334 m
.68564 .22334 L
s
1 .039 0 r
.61123 .39956 m
.61116 .39952 L
s
.61116 .39952 m
.61122 .39912 L
s
.61116 .39952 m
.61084 .3993 L
s
.61122 .39912 m
.61129 .39917 L
s
.61122 .39912 m
.61084 .3993 L
s
.61084 .3993 m
.61123 .39956 L
s
.61084 .3993 m
.61129 .39917 L
s
.61129 .39917 m
.61123 .39956 L
s
1 .023 0 r
.53476 .36309 m
.53475 .36307 L
s
.53475 .36307 m
.53475 .36283 L
s
.53475 .36307 m
.53452 .36295 L
s
.53475 .36283 m
.53476 .36285 L
s
.53475 .36283 m
.53452 .36295 L
s
.5357 .36297 m
.53452 .36295 L
s
.53452 .36295 m
.53476 .36309 L
s
.53452 .36295 m
.53476 .36285 L
s
.53476 .36285 m
.53476 .36309 L
s
1 .028 0 r
.74011 .39693 m
.7389 .39655 L
s
.73916 .39678 m
.73904 .39674 L
s
.73904 .39674 m
.73913 .39647 L
s
.73904 .39674 m
.7389 .39655 L
s
.73913 .39647 m
.73925 .39652 L
s
.73913 .39647 m
.7389 .39655 L
s
.7389 .39655 m
.73916 .39678 L
s
.7389 .39655 m
.73925 .39652 L
s
.73925 .39652 m
.73916 .39678 L
s
1 .019 0 r
.66304 .36031 m
.66211 .36014 L
s
.6623 .36028 m
.66225 .36026 L
s
.66225 .36026 m
.66229 .36006 L
s
.66225 .36026 m
.66211 .36014 L
s
.66229 .36006 m
.66234 .36009 L
s
.66229 .36006 m
.66211 .36014 L
s
.66211 .36014 m
.6623 .36028 L
s
.66211 .36014 m
.66234 .36009 L
s
.66234 .36009 m
.6623 .36028 L
s
1 .011 0 r
.5854 .32367 m
.58539 .32366 L
s
.58539 .32366 m
.5854 .32355 L
s
.58539 .32366 m
.58529 .3236 L
s
.5854 .32355 m
.58541 .32355 L
s
.5854 .32355 m
.58529 .3236 L
s
.58585 .32364 m
.58529 .3236 L
s
.58529 .3236 m
.5854 .32367 L
s
.58529 .3236 m
.58541 .32355 L
s
.58541 .32355 m
.5854 .32367 L
s
1 .009 0 r
.71353 .32092 m
.71313 .32082 L
s
.71322 .32089 m
.71319 .32088 L
s
.71319 .32088 m
.71321 .3208 L
s
.71319 .32088 m
.71313 .32082 L
s
.71321 .3208 m
.71324 .32081 L
s
.71321 .3208 m
.71313 .32082 L
s
.71313 .32082 m
.71322 .32089 L
s
.71313 .32082 m
.71324 .32081 L
s
.71324 .32081 m
.71322 .32089 L
s
1 .005 0 r
.63622 .28415 m
.63599 .28411 L
s
.63604 .28415 m
.63603 .28414 L
s
.63603 .28414 m
.63604 .2841 L
s
.63603 .28414 m
.63599 .28411 L
s
.63604 .2841 m
.63604 .2841 L
s
.63604 .2841 m
.63599 .28411 L
s
.63599 .28411 m
.63604 .28415 L
s
.63599 .28411 m
.63604 .2841 L
s
.63604 .2841 m
.63604 .28415 L
s
1 .002 0 r
.6868 .24448 m
.68673 .24447 L
s
.68674 .24448 m
.68674 .24448 L
s
.68674 .24448 m
.68674 .24446 L
s
.68674 .24448 m
.68673 .24447 L
s
.68674 .24446 m
.68675 .24446 L
s
.68674 .24446 m
.68673 .24447 L
s
.68673 .24447 m
.68674 .24448 L
s
.68673 .24447 m
.68675 .24446 L
s
.68675 .24446 m
.68674 .24448 L
s
1 .035 0 r
.53436 .3853 m
.53435 .38526 L
s
.53435 .38526 m
.53436 .38491 L
s
.53435 .38526 m
.53401 .3851 L
s
.53436 .38491 m
.53437 .38495 L
s
.53436 .38491 m
.53401 .3851 L
s
.53577 .38513 m
.53401 .3851 L
s
.53401 .3851 m
.53436 .3853 L
s
.53401 .3851 m
.53437 .38495 L
s
.53437 .38495 m
.53436 .3853 L
s
1 .029 0 r
.66402 .38248 m
.66263 .38222 L
s
.66291 .38243 m
.66284 .3824 L
s
.66284 .3824 m
.6629 .38211 L
s
.66284 .3824 m
.66263 .38222 L
s
.6629 .38211 m
.66298 .38214 L
s
.6629 .38211 m
.66263 .38222 L
s
.66263 .38222 m
.66291 .38243 L
s
.66263 .38222 m
.66298 .38214 L
s
.66298 .38214 m
.66291 .38243 L
s
1 .018 0 r
.58554 .34561 m
.58552 .34559 L
s
.58552 .34559 m
.58554 .3454 L
s
.58552 .34559 m
.58536 .34549 L
s
.58554 .3454 m
.58556 .34542 L
s
.58554 .3454 m
.58536 .34549 L
s
.58628 .34556 m
.58536 .34549 L
s
.58536 .34549 m
.58554 .34561 L
s
.58536 .34549 m
.58556 .34542 L
s
.58556 .34542 m
.58554 .34561 L
s
1 .014 0 r
.71488 .34286 m
.71422 .34269 L
s
.71436 .3428 m
.71431 .34279 L
s
.71431 .34279 m
.71435 .34264 L
s
.71431 .34279 m
.71422 .34269 L
s
.71435 .34264 m
.7144 .34266 L
s
.71435 .34264 m
.71422 .34269 L
s
.71422 .34269 m
.71436 .3428 L
s
.71422 .34269 m
.7144 .34266 L
s
.7144 .34266 m
.71436 .3428 L
s
1 .009 0 r
.63701 .30583 m
.63659 .30577 L
s
.63667 .30583 m
.63666 .30582 L
s
.63666 .30582 m
.63667 .30573 L
s
.63666 .30582 m
.63659 .30577 L
s
.63667 .30573 m
.63669 .30574 L
s
.63667 .30573 m
.63659 .30577 L
s
.63659 .30577 m
.63667 .30583 L
s
.63659 .30577 m
.63669 .30574 L
s
.63669 .30574 m
.63667 .30583 L
s
1 .003 0 r
.68796 .26593 m
.6878 .26589 L
s
.68783 .26592 m
.68782 .26591 L
s
.68782 .26591 m
.68783 .26588 L
s
.68782 .26591 m
.6878 .26589 L
s
.68783 .26588 m
.68784 .26588 L
s
.68783 .26588 m
.6878 .26589 L
s
.6878 .26589 m
.68783 .26592 L
s
.6878 .26589 m
.68784 .26588 L
s
.68784 .26588 m
.68783 .26592 L
s
1 .028 0 r
.58561 .36787 m
.58557 .36784 L
s
.58557 .36784 m
.5856 .36755 L
s
.58557 .36784 m
.58532 .36769 L
s
.5856 .36755 m
.58563 .36758 L
s
.5856 .36755 m
.58532 .36769 L
s
.58672 .3678 m
.58532 .36769 L
s
.58532 .36769 m
.58561 .36787 L
s
.58532 .36769 m
.58563 .36758 L
s
.58563 .36758 m
.58561 .36787 L
s
1 .022 0 r
.71626 .36511 m
.71525 .36485 L
s
.71546 .36503 m
.71538 .365 L
s
.71538 .365 m
.71544 .36478 L
s
.71538 .365 m
.71525 .36485 L
s
.71544 .36478 m
.71552 .36481 L
s
.71544 .36478 m
.71525 .36485 L
s
.71525 .36485 m
.71546 .36503 L
s
.71525 .36485 m
.71552 .36481 L
s
.71552 .36481 m
.71546 .36503 L
s
1 .014 0 r
.63782 .32783 m
.63711 .32773 L
s
.63726 .32783 m
.63723 .32781 L
s
.63723 .32781 m
.63725 .32767 L
s
.63723 .32781 m
.63711 .32773 L
s
.63725 .32767 m
.63728 .32768 L
s
.63725 .32767 m
.63711 .32773 L
s
.63711 .32773 m
.63726 .32783 L
s
.63711 .32773 m
.63728 .32768 L
s
.63728 .32768 m
.63726 .32783 L
s
1 .007 0 r
.68914 .28768 m
.68882 .28762 L
s
.68889 .28767 m
.68887 .28766 L
s
.68887 .28766 m
.68889 .28759 L
s
.68887 .28766 m
.68882 .28762 L
s
.68889 .28759 m
.6889 .2876 L
s
.68889 .28759 m
.68882 .28762 L
s
.68882 .28762 m
.68889 .28767 L
s
.68882 .28762 m
.6889 .2876 L
s
.6889 .2876 m
.68889 .28767 L
s
1 .022 0 r
.63864 .35015 m
.63756 .35 L
s
.63778 .35015 m
.63774 .35013 L
s
.63774 .35013 m
.63778 .3499 L
s
.63774 .35013 m
.63756 .35 L
s
.63778 .3499 m
.63782 .34993 L
s
.63778 .3499 m
.63756 .35 L
s
.63756 .35 m
.63778 .35015 L
s
.63756 .35 m
.63782 .34993 L
s
.63782 .34993 m
.63778 .35015 L
s
1 .011 0 r
.69034 .30976 m
.68981 .30965 L
s
.68992 .30973 m
.68989 .30972 L
s
.68989 .30972 m
.68991 .30961 L
s
.68989 .30972 m
.68981 .30965 L
s
.68991 .30961 m
.68994 .30962 L
s
.68991 .30961 m
.68981 .30965 L
s
.68981 .30965 m
.68992 .30973 L
s
.68981 .30965 m
.68994 .30962 L
s
.68994 .30962 m
.68992 .30973 L
s
1 .017 0 r
.69156 .33215 m
.69074 .33199 L
s
.69091 .33212 m
.69086 .3321 L
s
.69086 .3321 m
.6909 .33193 L
s
.69086 .3321 m
.69074 .33199 L
s
.6909 .33193 m
.69094 .33195 L
s
.6909 .33193 m
.69074 .33199 L
s
.69074 .33199 m
.69091 .33212 L
s
.69074 .33199 m
.69094 .33195 L
s
.69094 .33195 m
.69091 .33212 L
s
0 g
.25 Mabswid
.68389 0 m
.95694 .42575 L
s
.95694 .42575 m
1 .74078 L
s
1 .74078 m
.70392 .345 L
s
.70392 .345 m
.68389 0 L
s
.05221 .25273 m
0 .58221 L
s
0 .58221 m
.70392 .345 L
s
.70392 .345 m
.68389 0 L
s
.68389 0 m
.05221 .25273 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 514.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009000020R000`400?l00000o`00003ooooonfZ9
oookJP;o0000]_oonfX00?oooo]ZQ_oonfX3o`000003oookJ_l0003ooo]Z0;Gooo]Z003ooookJXCo
oo]Z0_l00004oookJP;o0000]OoonfX00?oooo]ZPOoonfX3o`0000Kooo]Z00?o0000oookJ_l00000
]?oonfX00?oooo]ZOooonfX2o`0000Wooo]Z00?o0000oookJ_l00000]?oonfX00?oooo]ZO?oonfX3
o`0000_ooo]Z00Co0000oookJ_oonf[o0000/ooonfX00?oooo]ZN_oonfX2o`0000kooo]Z00Go0000
oookJ_oonf[ooo]Zo`00002boookJP00oooonfYgoookJP?o00004?oonfX01Ol0003ooo]ZoookJ_oo
nf[o00000;;ooo]Z003ooookJWGooo]Z0_l0000CoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX0[ooonfX00?oooo]ZL_oonfX3o`0001Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP2_oookJP00oooonfY`oookJP;o00006OoonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z0:kooo]Z003ooookJVgooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX0[OoonfX00?oooo]ZJooonfX2o`0001kooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP2]oookJP00oooonfYXoookJP?o00008?oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z0:cooo]Z003ooookJVKooo]Z0_l0000SoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX0ZooonfX00?oooo]ZHooonfX3o`0002Gooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP2[oookJP00oooonfYQoookJP;o0000:?oonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z0:[ooo]Z003ooookJUkooo]Z0ol0000ZoookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0ZOoonfX00?oooo]ZG?oonfX2o`0002gooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP2YoookJP00oooonfYJoookJP;o0000;ooonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0:Sooo]Z003ooookJUOooo]Z0ol0000aoookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0Z?oonfX00?oooo]ZEOoonfX2o`0003Cooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2WoookJP00oooonfYBoookJP?o0000=_oo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0:Kooo]Z003ooookJU3ooo]Z0_l0000i
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0Y_oonfX00?oooo]ZCOoonfX3o`00
03_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP2UoookJP00oooonfY;oookJP;o
0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z0:Cooo]Z003ooookJTSooo]Z
0ol0000koookJP03ool40?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
oookJP2ToookJP00oooonfY6oookJP;o0000?OoonfX2ool400Cooo]Z00?o0000oookJ_oonfX03Ooo
nfX00ol0003ooo]ZoookJP2SoookJP00oooonfY3oookJP?o0000A_oonfX00ol0003ooo]ZoookJP0=
oookJP03o`000?oonf[ooo]Z0:;ooo]Z003ooookJT7ooo]Z0_l00019oookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX0X_oonfX00?oooo]Z?_oonfX3o`0004_ooo]Z00?o0000oookJ_oo
nfX03_oonfX00ol0003ooo]ZoookJP2QoookJP00oooonfXloookJP;o0000C_oonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJSWooo]Z0ol0001@oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0X?oonfX00?oooo]Z=ooonfX2o`0005?ooo]Z00?o0000
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2OoookJP00oooonfXdoookJP?o0000EOoonfX00ol0
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z09oooo]Z003ooookJS;ooo]Z0_l0001HoookJP03
o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z;ooonfX3o`0005[ooo]Z
00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2MoookJP00oooonfX]oookJP;o0000>ooo
nfX00ooo1@3ooo]ZoookJP0IoookJP03ool20?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX04_oo
nfX00ol0003ooo]ZoookJP2MoookJP00oooonfXZoookJP?o0000?OoonfX00ooo1@3ooo]ZoookJP0O
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0W?oonfX00?oooo]Z:?oonfX2o`00
06;ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2KoookJP00oooonfXUoookJP?o
0000I?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z09_ooo]Z003ooookJR?ooo]Z
0_l0001WoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0V_oonfX00?oooo]Z8?oo
nfX3o`0006Wooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP2IoookJP00oooonfXN
oookJP;o0000K?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z09Wooo]Z003ooook
JQ_ooo]Z0ol0001^oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0V?oonfX00?oo
oo]Z6OoonfX2o`00077ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP2GoookJP00
oooonfXFoookJP?o0000M?oonfX00ol0003ooo]ZoookJP02oookJP;oo`D04ooonfX00ol0003ooo]Z
oookJP2GoookJP00oooonfXDoookJP;o0000MooonfX00ol0003ooo]ZoookJP03oookJP03ool50?oo
nf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0U_oonfX00?oooo]Z4OoonfX3o`0003_ooo]Z00?oo`L0
oookJ_oonfX06?oonfX2ool301[ooo]Z0_oo0@05oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX0U_oonfX00?oooo]Z3ooonfX2o`0007cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0
003ooo]ZoookJP2EoookJP00oooonfX<oookJP?o0000O_oonfX00ol0003ooo]ZoookJP0JoookJP03
o`000?oonf[ooo]Z09Cooo]Z003ooookJP[ooo]Z0_l00021oookJP03o`000?oonf[ooo]Z01[ooo]Z
00?o0000oookJ_oonfX0U?oonfX00?oooo]Z1ooonfX3o`0008?ooo]Z00?o0000oookJ_oonfX06ooo
nfX00ol0003ooo]ZoookJP2CoookJP00oooonfX5oookJP;o0000Q_oonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP;ooo]Z0ol00028oookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z0_l0002;oookJP03o`000?oonf[ooo]Z01go
oo]Z00?o0000oookJ_oonfX0TOoonfX00?gooo]Z0_l0002=oookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX0T?oonfX00?[ooo]Z0ol0001ioookJP;oo`L05?oonfX00ol0003ooo]Zoook
JP03oookJP03ool30?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0T?oonfX00?Sooo]Z0_l0000i
oookJP;oo`P06OoonfX00ooo103ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX0SooonfX00?Gooo]Z0ol0000loookJP03ool80?oonf[ooo]Z01Oooo]Z00?oo`@0oook
J_oonfX06?oonfX2ool201_ooo]Z00?oo`00oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0Ooook
JP03o`000?oonf[ooo]Z08oooo]Z003coookJP;o0000UooonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z08kooo]Z003`oookJP?o0000VOoonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z08gooo]Z003^oookJP;o0000W?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z08gooo]Z003[oookJP?o0000W_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o
oo]Z08cooo]Z003YoookJP;o0000X_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
08_ooo]Z003VoookJP?o0000Y?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z08_o
oo]Z003ToookJP;o0000YooonfX00ol0003ooo]ZoookJP0>oookJP03ool70?oonf[ooo]Z01;ooo]Z
00?o0000oookJ_oonfX0R_oonfX00>7ooo]Z0ol0001goookJP;oo`T06OoonfX2ool401Gooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP29oookJP00gooonfX2o`0003Wooo]Z00?oo`/0
oookJ_oonfX0F_oonfX00ooo103ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00?ooo]Z00?oo`80
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP29oookJP00g?oonfX3o`0003[ooo]Z0_oo2`0Hoook
JP;oo`D06OoonfX2ool203gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP28oook
JP00f_oonfX2o`0007;ooo]Z00?oo`80oookJ_oonfX06OoonfX00ooo0@3ooo]ZoookJP0JoookJP03
ool00?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP27oookJP00
eooonfX3o`000;?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP27oookJP00eOoo
nfX2o`000;Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP26oookJP00d_oonfX3
o`000;Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP26oookJP00d?oonfX2o`00
0;_ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP25oookJP00cOoonfX3o`000;go
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP24oookJP00booonfX2o`000;Kooo]Z
0_oo2@08oookJP03o`000?oonf[ooo]Z00oooo]Z00?oo`@0oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP24oookJP00b?oonfX3o`0007Kooo]Z0_oo3@1:oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX0PooonfX00<Kooo]Z0_l0000hoookJP03ool<0?oonf[ooo]Z05Wooo]Z00?oo`H0
oookJ_oonfX06?oonfX00ooo0`3ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX0P_oonfX00<?ooo]Z0ol0000ioookJP;oo``06?oonfX2ool707;ooo]Z00?o0000oook
J_oonfX00ooonfX2ool102Kooo]Z00?o0000oookJ_oonfX0P_oonfX00<7ooo]Z0_l0001`oookJP;o
o`<06OoonfX2ool103gooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP21oookJP00
__oonfX3o`0008gooo]Z00?oo`40oookJ_oonfX06OoonfX2ool001_ooo]Z00?oo`00oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z083ooo]Z002loookJP;o0000d?oo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z083ooo]Z002ioookJP?o0000d_oonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z07oooo]Z002goookJP;o0000eOoonfX00ol0
003ooo]ZoookJP0IoookJP;oo`P04ooonfX00ol0003ooo]ZoookJP1noookJP00]?oonfX3o`000=Oo
oo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1noookJP00/_oonfX2o`000;Gooo]Z
0_oo3P0IoookJP03ool60?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Z
oookJP1moookJP00[ooonfX3o`0007Gooo]Z0ooo401JoookJP03ool60?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX03_oonfX2ool201oooo]Z00?o0000oookJ_oonfX0OOoonfX00:gooo]Z0_l0000h
oookJP03ool>0?oonf[ooo]Z05Oooo]Z0_oo200IoookJP03ool40?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP1loookJP00Z_oonfX3o`0003Wooo]Z0_oo3P0Goook
JP;oo`P0FooonfX00ooo103ooo]ZoookJP0HoookJP;oo`405OoonfX00ol0003ooo]ZoookJP0aoook
JP03o`000?oonf[ooo]Z07_ooo]Z002XoookJP;o0000KooonfX00ooo103ooo]ZoookJP1boookJP03
o`000?oonf[ooo]Z00?ooo]Z00?oo`00oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1koookJP00
Y_oonfX2o`0008_ooo]Z0_oo0P0JoookJP03ool00?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP1joookJP00XooonfX3o`000:Sooo]Z0_oo000KoookJP03ool00?oo
nf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1ioookJP00XOoonfX2
o`000>Gooo]Z00?oo`00oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z07Wooo]Z002NoookJP?o0000kOoonfX01?l0003ooo]Zool=0?oo3@0coookJP03o`000?oonf[o
oo]Z07Sooo]Z002LoookJP;o0000/OoonfX2oolC03gooo]Z00?o0000oookJ_oonfX06_oonfX00ooo
1@3ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z07Oooo]Z002IoookJP?o0000]?oonfX00ooo4`3o
oo]ZoookJP0FoookJP;oo`T08ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z07Oo
oo]Z002GoookJP;o0000MOoonfX3oolD05Wooo]Z00?oo`T0oookJ_oonfX05ooonfX00ooo103ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0M_oonfX009Cooo]Z0ol0
000foookJP;oo`h0F?oonfX2ool;01Wooo]Z00?oo`D0oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0?oookJP03ool10?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0M_oonfX009;ooo]Z0_l0001A
oookJP;oo`T0F_oonfX2ool501Wooo]Z0_oo0P0`oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000
oookJ_oonfX0MOoonfX008oooo]Z0ol0001]oookJP03ool50?oonf[ooo]Z05[ooo]Z00?oo`80oook
J_oonfX06OoonfX00ooo003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oook
J_oonfX0M?oonfX008gooo]Z0_l00029oookJP;oo`80MOoonfX00ol0003ooo]ZoookJP03oookJP03
ool00?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0M?oonfX008[ooo]Z0ol0002VoookJP03ool0
0?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX09?oonfX2ool;01;ooo]Z00?o0000oookJ_oonfX0
LooonfX008Sooo]Z0_l00035oookJP03ool00?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09?oo
nfX2ool;01?ooo]Z00?o0000oookJ_oonfX0L_oonfX008Gooo]Z0ol0003SoookJP03ool00?oonf[o
oo]Z00Oooo]Z0ooo4`0GoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0L_oonfX0
08?ooo]Z0_l0002`oookJPCooaX0D?oonfX00ooo003ooo]ZoookJP03oookJP03o`000?oo203oo`P0
01[ooo]Z00?oo`<0oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP1aoookJP00P?oonfX3o`0007?o
oo]Z0_oo5`1GoookJP;oo`d0?_oonfX00ol0003ooo]ZoookJP0JoookJP03ool30?oonf[ooo]Z01ko
oo]Z00?o0000oookJ_oonfX0L?oonfX007kooo]Z0_l0000eoookJP;oo`h0?_oonfX00ooo5`3ooo]Z
oookJP0FoookJP;oo`h0FOoonfX2ool502Cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Z
oookJP1`oookJP00NooonfX3o`0003Oooo]Z00?oo`h0oookJ_oonfX0EOoonfX00ooo3P3ooo]Zool>
000HoookJP03ool70?oonf[ooo]Z05[ooo]Z00?oo`80oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP0loookJP03o`000?oonf[ooo]Z06oooo]Z001ioookJP;o0000DOoonfX2ool905Wooo]Z0_oo1`0I
oookJP03ool30?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX03ooonfX00ooo003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z06kooo]Z001foookJP?o0000K?oonfX2ool505[ooo]Z0_oo0`0Joook
JP03ool10?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1^oook
JP00M?oonfX2o`0008Sooo]Z0_oo0P1LoookJP;oo`406ooonfX00ooo003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0KOoonfX0077ooo]Z0ol0002ToookJP;oo`40
MOoonfX00ol0003ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z00?ooo]Z0_oo400boookJP03o`00
0?oonf[ooo]Z06gooo]Z001_oookJP;o0000`_oonfX00ooo003ooo]ZoookJP0VoookJP?ooad0<?oo
nfX00ol0003ooo]ZoookJP0UoookJP03ool70?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0K?oo
nfX006cooo]Z0ol0002_oookJP;oob80;ooonfX00ooo003ooo]ZoookJP0<oookJP03oolM0?oonf[o
oo]Z01Gooo]Z0_oo3@0GoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0JooonfX0
06[ooo]Z0_l0001aoookJP;ooaP0?OoonfX3oolR01Sooo]Z00?ooa80oookJ_oonfX0<_oonfX00ooo
003ooo]ZoookJP08oookJP03ool=0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo1@00@?oonfX00ol0
003ooo]ZoookJP1[oookJP00IooonfX3o`0007;ooo]Z00?ooaP0oookJ_oo6000E_oonfX3oolB057o
oo]Z00?oo`00oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0KoookJP03ool20?oonf[ooo]Z02?o
oo]Z00?o0000oookJ_oonfX0J_oonfX006Gooo]Z0_l0000foookJP03ool<0?oonf[ooo]Z05Cooo]Z
0ooo401HoookJP;oo`P0?_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z06Wooo]Z
001RoookJP?o0000=ooonfX00ooo303ooo]ZoookJP0EoookJP03ool90?oonf[ooo]Z05Kooo]Z0_oo
201KoookJP03ool30?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Zoook
JP1YoookJP00H?oonfX2o`0005;ooo]Z00?oo`T0oookJ_oonfX0L?oonfX2ool305cooo]Z0_oo0@09
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0J?oonfX005gooo]Z0ol0001/oook
JP03ool60?oonf[ooo]Z07?ooo]Z00?oo`40oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0?oook
JP03ool00?oonf[ooo]Z01cooo]Z0_oo300CoookJP03o`000?oonf[ooo]Z06Oooo]Z001KoookJP;o
0000QooonfX2ool305_ooo]Z0_oo0@0ooookJP;ooaX03?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z06Oooo]Z001HoookJP?o0000XooonfX00ooo0@3ooo]ZoookJP15oookJP03ool[
0?oonf[ooo]Z01Cooo]Z00?oo`00oookJ_oonfX08ooonfX2oolJ00_ooo]Z00?o0000oookJ_oonfX0
2OoonfX2ool;03Wooo]Z00?o0000oookJ_oonfX0I_oonfX005Kooo]Z0_l0002]oookJP?oobP04?oo
nfX00ooo003ooo]ZoookJP0WoookJPGoob/0<_oonfX00ooo003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?oo`/0oookJ_oonfX06?oonfX00ooo103ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z06Gooo]Z001CoookJP?o0000KooonfX00ooo5`3ooo]ZoookJP0koookJP;oobP000?ooo]Z
oolX0?oonfX0:ooonfX00ooo003ooo]ZoookJP0VoookJP?ooa@0<OoonfX00ol0003ooo]ZoookJP03
oookJP03ool00?oonf[ooo]Z01oooo]Z00?oo`@0oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP1U
oookJP00DOoonfX2o`00077ooo]Z0_oo5`1FoookJP?ooaP0EooonfX2ool801Sooo]Z00?o0000oook
J_oonfX0A_oonfX00ol0003ooo]ZoookJP1ToookJP00C_oonfX3o`0003Cooo]Z00?oo`/0oookJ_oo
nfX0EOoonfX00ooo403ooo]ZoookJP1EoookJP;oo``06?oonfX00ooo003ooo]ZoookJP0noookJP03
o`000?oo0`3oo`<004Kooo]Z00?o0000oookJ_oonfX0I?oonfX004cooo]Z0_l0000goookJP03ool;
0?oonf[ooo]Z05Cooo]Z00?ooa00oookJ_oonfX05_oonfX00ooo2P3ooo]ZoookJP0noookJP03ool<
0?oonf[ooo]Z01Oooo]Z00?oo`@0oookJ_oonfX06OoonfX00ooo003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z01[ooo]Z0_oo000[oookJP03o`000?oonf[ooo]Z06?ooo]Z001:oookJP;o0000D?oo
nfX00ooo203ooo]ZoookJP1EoookJP;oo`X0FOoonfX2ool403Wooo]Z00?oo`00oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z06;ooo]Z0017oookJP?o0000JOoonfX0
0ooo1@3ooo]ZoookJP1GoookJP;oo`@0FooonfX00ooo0@3ooo]ZoookJP0SoookJP03o`000?oonf[o
oo]Z01Cooo]Z0ooo500aoookJP03o`000?oonf[ooo]Z06;ooo]Z0015oookJP;o0000Q?oonfX2ool3
05[ooo]Z00?oo`40oookJ_oonfX0?_oonfX2ool[01cooo]Z00?oo`00oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP0EoookJP;ooa@06?oonfX2ool801Sooo]Z00?o0000oookJ_oonfX0HOoonfX004;o
oo]Z0ol00026oookJP03ool30?oonf[ooo]Z063ooo]Z00?ooc/0oookJ_oonfX04OoonfX00ooo003o
oo]ZoookJP0UoookJP?oob/08ooonfX00ol0003ooo]ZoookJP0@oookJP03ool00?oonf[ooo]Z01go
oo]Z00?oo`P0oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP1PoookJP00@?oonfX2o`000:;ooo]Z
00?oo`40oookJ_oonfX01_oonfX2ool[03[ooo]Z1ooo>`0BoookJP03ool00?oonf[ooo]Z02Kooo]Z
0_oo:`0EoookJP?ooa802ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z063ooo]Z
000moookJP?o0000ZooonfX3ool[013ooo]Z00?oo`00oookJ_oonfX0@OoonfX4oolN01Oooo]Z00?o
o`00oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0:oookJP;oo`L0?ooonfX00ol0003ooo]Zoook
JP1OoookJP00>ooonfX2o`00073ooo]Z00?ooa@0oookJ_oonfX0DooonfX3oolM01;ooo]Z00?oo`00
oookJ_oonfX0:_oonfX00ooo7P3ooo]ZoookJP0DoookJP;oo`d07?oonfX00ooo003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?oo`80oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP1N
oookJP00>?oonfX3o`0003?ooo]Z00?oo`P0oookJ_oonfX0>ooonfX00ooo503ooo]ZoookJP0Eoook
JP03ool@0?oonf[ooo]Z09Kooo]Z00?oo`d0oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP1<oook
JP03o`000?oonf[ooo]Z05kooo]Z000foookJP;o0000=OoonfX2ool805Cooo]Z0_oo401GoookJP;o
o`l05_oonfX00ooo003ooo]ZoookJP10oookJP03ool40?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oo
nfX01?oonfX00ooo003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05gooo]Z000coookJP?o0000
C_oonfX00ooo1`3ooo]ZoookJP1DoookJP;oo`X0F?oonfX2ool601Wooo]Z00?oo`00oookJ_oonfX0
?_oonfX00ol0003oo`40oookJP0ioookJP03ool>0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
GOoonfX0037ooo]Z0_l0001XoookJP03ool50?oonf[ooo]Z05Kooo]Z00?oo`D0oookJ_oonfX0FOoo
nfX00ooo0P3ooo]ZoookJP0koookJP;oob8000?ooo]Zo`000?oonfX06ooonfX00ooo003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z05cooo]Z000^oookJP?o0000J_oonfX00ooo1@3ooo]ZoookJP1F
oookJP03ool50?oonf[ooo]Z01oooo]Z0_ooB`0goookJP;oo`8000?oodD0oookJ_oonfX06?oonfX2
ool002;ooo]Z00?oob80o`000?oonfX05OoonfX00ooo3P3ooo]ZoookJP03oookJP03ool00?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX0FooonfX002cooo]Z0_l00024oookJP03ool30?oonf[ooo]Z
023ooo]Z00?oobP0oookJ_oonfX0=OoonfX00ooo0P3ooo]ZoookJP05oookJPCood/0>OoonfX4oom5
01Gooo]Z00?oo`00oookJ_oonfX08_oonfX00ooo8P3o0000oookJP0FoookJP03ool>0?oonf[ooo]Z
03Kooo]Z00?o0000oookJ_oonfX0FooonfX002Wooo]Z0ol0002OoookJP03ool10?oonf[ooo]Z00Ko
oo]Z0_oo:00koookJPCood/000?ooo]Zoom;0?ooB`003ooonfX00ooo003ooo]ZoookJP0ZoookJP?o
odD04_oonfX3oolN01_ooo]Z00?oo`00oookJ_oonfX00_oo0005oookJP03o`000?oonf[ooo]Z02oo
oo]Z0_oo1@0NoookJP03o`000?oonf[ooo]Z05[ooo]Z000WoookJP;o0000XOoonfX2ool100Oooo]Z
00?oobP0oookJ_oonfX0DOoonfX00ooo003ooo]Zool/0005ool/03cooo]Z00?ooah0oookJ_oonfX0
5OoonfX2ool<00cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1IoookJP009?oo
nfX3o`0006kooo]Z00?ooa00oookJ_oonfX0C?oonfX00ooo003ooo]ZoookJP05oookJP;ooah0?ooo
nfX00ooo;03ooo]ZoookJP0BoookJP03ool00?oonf[ooo]Z03oooo]Z00?oo``0oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP0?oookJP03ool00?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0FOoo
nfX002;ooo]Z0_l0001`oookJP03ool@0?oonf[ooo]Z01Gooo]Z00?oo`h0oookJ_oonfX0>ooonfX2
oolN01;ooo]Z00?oo`00oookJ_oonfX0@_oonfX3oolD01Sooo]Z00?oo`00oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP0:oookJP03ool30?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0F?oonfX0
01oooo]Z0ol0000doookJP;oo`L0DooonfX2ool>05Gooo]Z0ooo4`1HoookJP03ool70?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX09OoonfX2ool102_ooo]Z00?o0000oookJ_oonfX0EooonfX001ko
oo]Z0_l0001<oookJP;oo`D0EOoonfX00ooo2P3ooo]ZoookJP1BoookJP05ool00?oonf[ooo]Zoook
J_oo2000FooonfX00ooo0P3ooo]Zool0000FoookJP03o`000?oonf[ooo]Z01oooo]Z0_oo5`0aoook
JP03o`000?oonf[ooo]Z05Oooo]Z000NoookJP03o`000?oonf[o00000:7ooo]Z00?oo`X0oookJ_oo
nfX0>OoonfX3oomA01[ooo]Z0_oo201HoookJP;ooc/000?oo`80oookJ_oonfX05ooonfX00ol0003o
oo]ZoookJP0PoookJP03oolG0?oonf[ooo]Z01Oooo]Z00?oo`T0oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP1FoookJP007_oonfX01?l0003ooo]ZoookJ_l0001QoookJP03ool40?oonf[ooo]Z05Co
oo]Z0_oo1@0PoookJPCooe40<ooonfX2ool000;oo`<01_ooJP02oookJP;oofX0=_oonfX3oolk01Oo
oo]Z00?o0000oookJ_oo00001?oonfX00ooo003ooo]ZoookJP0coookJP03ool90?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX0EOoonfX001kooo]Z00Go0000oookJ_oonf[ooo]Zo`00001goookJP03
ool20?oonf[ooo]Z023ooo]Z00?oob80oookJ_oonfX0=?oonfX00ooo0P3ooo]ZoookJP03oookJP;o
oe400_oonfX00oooD@3ooo]ZoookJP0loookJPGoofX03_oonfX00ooo003ooo]ZoookJP0UoookJP;o
oc/05OoonfX2oolH0003o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0EOoonfX001gooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2FoookJP;oob80=OoonfX00ooo0P3ooo]Z
oookJP03oookJP03oomA0?oonf[ooo]Z01Sooo]Z0ooo>00XoookJP03oomZ0?oonf[ooo]Z00kooo]Z
00?oo`00oolc0?oo<`000_oo<`0koookJP03oolH0?l0003ooo]Z01Kooo]Z0_oo2004oookJP03ool0
0?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0E?oonfX001gooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP2:oookJP;oo`402?oonfX00ooo8P3ooo]ZoookJP0EoookJP;ooad0>?oo
nfX01?oo003ooo]ZoookJ_oonfX3oolh0003oookJ_oo>03ooo]Z03cooo]Z0_oo<`0DoookJP;ooa@0
00?oo`00oookJ_oo00008ooonfX00ol0003ooo]ZoookJP0aoookJP03ool20?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX0E?oonfX001gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP1EoookJP;oo`d0BooonfX00ooo003ooo]ZoookJP06oookJP;ooad0EooonfX00ooo7@3ooo]Zoook
JP0koookJP;ooa@09OoonfX00ol0003ooo]ZoookJP0`oookJP03ool20?oonf[ooo]Z02?ooo]Z00?o
0000oookJ_oonfX0DooonfX001gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0G
oookJP03ool50?oonf[ooo]Z057ooo]Z00?oo`/0oookJ_oonfX0<ooonfX00ooo003ooo]ZoookJP05
oookJP03oolM0?oonf[ooo]Z05;ooo]Z00?oo`00oookJ_oo7@000ooo7@1FoookJP;oo`H00_oonfX0
1Ooo003ooo]ZoookJ_oonf[oo`0000Gooo]Z00?o0000oookJ_oonfX0A?oonfX00ooo3P3ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z05;ooo]Z000MoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX05_oonfX00ooo1@3ooo]ZoookJP1AoookJP03ool;0?oonf[ooo]Z04cooo]Z00?oo`00
oookJ_oonfX01?oonfX2oolD03gooo]Z0_ooT`0GoookJP03ool00?oo2`3oo`/004cooo]Z00?o0000
oookJ_oonfX02ooonfX00ooo0@3ooo]ZoookJP0foookJP03ool>0?oonf[ooo]Z013ooo]Z00?o0000
oookJ_oonfX0D_oonfX001gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0Zoook
JP03ool40?oonf[ooo]Z05?ooo]Z00?oo`P0oookJ_oonfX0=_oonfX3oom;01cooo]Z00?oo`/0oook
J_oonfX08ooonfX3oonC01Sooo]Z00?oo`/0oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP05oook
JP;oobP00_oonfX2ool100Cooo]Z00?oo`00oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1Aoook
JP007?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z07kooo]Z00?oo`P0oookJ_oo
nfX0=ooonfX00oooB`3ooo]Zoom;000FoookJP03ool00?oonf[ooo]Z00;ooo]Z0_oo2`0QoookJPSo
oi<0;ooonfX00oooJP3oo`<0ool0000coookJP03o`000?oonf[ooo]Z00Kooo]Z0_oo:00GoookJP03
ool@0?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1@oookJP00
7?oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z03kooo]Z00?oo`<0oookJ_oonfX0
E?oonfX00ooo1@3ooo]ZoookJP0NoookJP03oom;0?oonf[ood/003Kooo]Z00?oo`@0oookJ_ooT`00
1_ooT`04oookJP;ooi<0=?oonfX3oomZ0003oookJ_ooJP3ooo]Z013ooo]Z0_oo;00KoookJP03o`00
0?oonf[ooo]Z00Oooo]Z00?oobP0oookJ_oonfX05OoonfX2ool@03Oooo]Z00?o0000oookJ_oonfX0
D?oonfX001cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP1DoookJP03ool20?oo
nf[ooo]Z023ooo]Z00?ooaX0oookJ_oonfX0>_oonfX00oooB`3ooo]ZoookJP0GoookJP?oocd06Ooo
nfX00ooo003ooo]ZoookJP02ool4023ooo]Z0_ooDP0SoookJP?oofX04_oonfX01Ooo;03oo`00oook
J_oonf[oo`0001Kooo]Z00?o0000oookJ_oonfX0>_oonfX00ooo1@3ooo]ZoookJP0LoookJP03o`00
0?oonf[ooo]Z04oooo]Z000LoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0Dooo
nfX00ooo0P3ooo]ZoookJP0OoookJP;ooaX0=?oonfX00ooo0P3ooo]ZoookJP04oookJP03oom;0?oo
nf[ooo]Z01Kooo]Z1?oo?@0foookJP03ool00?oo0@3ooo]Z00Wooe808_oonfX4oomZ01;ooo]Z0_oo
;00EoookJP;oo`l000Cooo]Zo`000?oonf[oo`00F_oonfX00ol0003ooo]ZoookJP1>oookJP007?oo
nfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z03Oooo]Z00?oo`T0oookJ_oonfX0;ooo
nfX00ooo0@3ooo]ZoookJP08oookJP03oolJ0?oonf[ooo]Z01Cooo]Z0_oo600foookJP03ool00?oo
nf[ooo]Z00;ooo]Z0_oo?@0GoookJP?oojH0:OoonfX00oooDP3ooo]ZoookJP0@oookJP?oob<0?Ooo
nfX00ooo3`3ooo]Zo`000005oookJP03ool00?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0C_oo
nfX001cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0foookJP03ool90?oonf[o
oo]Z057ooo]Z0_oo600foookJP03ool00?oonf[ooo]Z01[ooo]Z0oooYP02oolV03_ooo]Z00Coo`00
oookJ_oo8`3oob<0?_oonfX00ol0003ooo]ZoookJP0EoookJP03ool40?oonf[ooo]Z00?ooo]Z00?o
o`00oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1=oookJP007?oonfX00ol0003ooo]ZoookJP0;
oookJP03ool40?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0B_oonfX2ool803?ooo]Z00?oo`00
oookJ_oonfX01_oonfX00ooo603ooo]ZoookJP0EoookJP;ooa<0>OoonfX01?oo003ooo]ZoookJ_oo
YP04oolV03_ooo]Z00?oo`00oookJ_oonfX05_oonfX3ool;02Kooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ooo603ooo]ZoookJP05oookJP03ool10?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0COoo
nfX001_ooo]Z00?o0000oookJ_oonfX03?oonfX00ooo103ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z04Wooo]Z0_oo201CoookJP03oolC0?oonf[ooa<003Wooo]Z0oooYP001?oonf[oojH0oonV0?oo
YP0GoookJP03oolA0?oonf[ooo]Z03Cooo]Z1?l02_l4oookJP04ool;0?oonf[oo`00ool101?ooo]Z
00?ood/0oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0ZoookJP03oolH0?oonf[ooo]Z00?ooo]Z
00?oo`40oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1<oookJP006ooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z00[ooo]Z0_oo0`1CoookJP03ool70?oonf[ooo]Z03?ooo]Z00?o
o`00oookJ_oo>`000_oo>`0moookJP;oojH01?oonfX00oooYP3ooo]ZoookJP0CoookJP03ool00?oo
nf[ooa4000;ooa40=?oonfX2o`0:o`04oookJ_l02_oooo]ZoookJP?o00[o1?oonfX00ooo0@3ooo]Z
oookJP0BoookJP03oom;0?oonf[oo`<000?ooo]Z00?oo`00oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP14oookJP03ool90?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0BooonfX001_ooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP1NoookJP03ool70?oonf[ooo]Z03Kooo]Z0_oo
>`0KoookJP;oo`/07OoonfX3oonV01cooo]Z0_ooM@0JoookJP;oo`D00ooo_@09oookJP;ookd02ooo
nfX2o`0:o`Cooo]Z00?o00[ooookJ_oonfX00_oonfX4o`0:oaKooo]Z0_ooB`07oookJP03ool10?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01OoonfX2oolM00Cooo]Z00?oo`00oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP1;oookJP006ooonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[o
oo]Z01kooo]Z00?oo`80oookJ_oonfX0DooonfX00ooo103ooo]ZoookJP0NoookJP03oolk0?oonf[o
oo]Z01Gooo]Z00?oo`00oolh0?oonfX07OoonfX01Ooo1@3ooo]ZoookJ_oonf[oojH001kooo]Z1?oo
M@0HoookJP03ool00?oonf[ooo]Z00?ooo]Z1_oo_@03oookJP?ookd02?oonfX2oomB00Oo00[o2?oo
nfX3o`0:oaCooo]Z0_ooB`06oookJP03ool10?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01_oo
nfX2oolM00;ooo]Z0_oo0004oookJP03ool00?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0B_oo
nfX001_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0coookJP03ool20?oonf[o
oo]Z023ooo]Z00?ooa<0oookJ_oonfX0>_oonfX00ooo>`3ooo]ZoookJP0FoookJP;oocP00ooonfX<
o`0:o`Wooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo1@3ooo]ZoookJP0LoookJPGoogD000?ooo]Z
oome0?ooM@009OoonfX5oonm0003oookJ_oo_@3ooo]Z00Oooo]Z00Ooo`40oomB0?ooDP3ooe80oook
J_ooDP3ooo]Z00_o00[o00Cooo]Zo`0:ool02_oo00[o4OoonfX2oom;00cooo]Z00?o0000oookJ_oo
nfX08?oonfX00ooo2P3ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oo
nfX0BOoonfX001_ooo]Z00?o0000oookJ_oonfX05ooonfX2o`0003?ooo]Z00?oo`80oookJ_oonfX0
8?oonfX2oolC03;ooo]Z0_oo0P0OoookJP03oolh0?oonf[oocP000?ooo]Z00?o00[ooookJ_oonfX0
0ol02_l4oookJP03o`0:oooonf[o00[o00Cooi<08?oonfX2o`3oPP03oookJ_oo0@3ooo]Z00?oogD0
1_oonfX00oooM@3ooo]ZoookJP0VoookJP;ookd000Cooo]Zoonm0?oo_@3ookd02?oonfX00ooo003o
oo]ZoookJP02oomB00;ooo]Z00?o00[ooookJ_oonfX01ooonfX6o`0:o`03oookJ_oo7@3ooad001[o
oo]Z00?o0000oookJ_oonfX0>ooonfX00ooo0`3ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z04Wo
oo]Z000JoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX05_oonfX2ool702oooo]Z
00?oo`40oookJ_oonfX02OoonfX00ooo4`3ooo]ZoookJP0CoookJP;ooa80??oonfX00ooo>03ooo]Z
oookJP04oookJP;o00[o1?oonfX4o`0:o`?ooo]Z1?ooT`02oookJP;oobX06OoonfX2o`3oPP04ool0
0?oonf[o0?n2ool100oooo]Z1?n:o`08oookJPGoocX05?oonfX3oonm00_ooo]Z00?o00[ooookJ_oo
nfX00oooDP000ooonf[o00[ooookJP09oookJPGo00[o0_oonfX00ooo7@3oo`00oookJP0HoookJP03
o`000?oonf[ooo]Z03_ooo]Z00?oo`<0oookJ_oonfX03ooonfX00ooo3P3ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z04Sooo]Z000JoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0
5OoonfX00ooo1`3ooo]ZoookJP0]oookJP;oo`408OoonfX2oolB03Cooo]Z0_oo000=oookJP?o00[o
1OoonfX00ol02_oooo]Zo`0:o`02o`0:o`Cooi<00ooo:P0HoookJP?o0?n200?ooo]Zool00?l0oh80
0_l0oh8>oookJPSoR_l00ooonfX00ooo003ooo]ZoookJP03oookJP;oocX01OoonfX2olko01[ooo]Z
00?o00[ooookJ_oonfX01?oonfX00ol02_oooo]ZoookJP05oookJP?o00[o0_oonfX2o`0:o`Oooo]Z
00?oo`00oookJ_oonfX04_oonfX00ooo203ooo]Zo`00001?oookJP;oo`h04_oonfX00ol0003ooo]Z
oookJP17oookJP006_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z02Wooo]Z0_oo
1P0aoookJP03ool00?oonf[ooo]Z01oooo]Z00?oo`l0oookJ_oonfX0:ooonfX01?l02_oooo]Zo`0:
ool02_l3oookJP0:o`0:oooonf[ooo]ZoookJ_ooT`3ooo]Zo`0:ooooT`3o00[ooolZ00;o00[o5ooo
nfX3o`3oPPCooo]Z00?o0?n2oookJ_l0oh803_oonfX01On:o`3ooo]ZoookJ_n:o`3ooo]Z00CoR_l0
00?ooo]Zool00?oonfX03?oonfX01?o>o`3ooo]Zolko0?o>o`0:oookJP?ooa@03?oonfX00ol02_oo
oo]ZoookJP04oookJP04o`0:oooonf[ooo]ZoookJP?o00[o1?oonfX2o`0:oaoooo]Z00?o0000oook
J_oo00004?oonfX00ooo:`3ooo]ZoookJP03oookJP03ool20?oonf[ooo]Z04Sooo]Z00?o0000oook
J_oonfX0AooonfX001[ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0XoookJP03
ool60?oonf[ooo]Z05;ooo]Z00?oo`l0oookJ_oonfX0:_oonfX02?l02_oooo]ZoookJ_l02_oooo]Z
o`0:oooonf[o00[o0_oonfX2oonC0003ool00?oonf[ooo]Z00?ooo]Z1?l02_lAoookJPCoohH00_oo
5`04oookJP?o0?n200?ooo]Zo`3oP_oonfX03?oonfX00on:o`3ooo]ZoookJP06oh[o00;oo`003Ooo
nfX01?o>o`3ooo]ZoookJ_oonfX2olko00Sooo]Z00?oo`00oolD0?oo50003?oonfX00ol02_oooo]Z
oookJP04oookJP;o00[o0_ooT`06oookJP;o00[o8?oonfX00ol0003ooo]ZoookJP04oookJP03ool1
0?oonf[ooo]Z00[ooo]Z0_oo:`03oookJP03ool20?oonf[ooo]Z017ooo]Z00?ooa00oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP16oookJP006_oonfX00ol0003ooo]ZoookJP0;oookJP03ool20?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0?OoonfX2ool503?ooo]Z00Goo`00oookJ_oonf[ooo]Z
ool[000LoookJP;oo`/05?oonfX01?l02_oooo]ZoookJ_l02_l2oookJP;o00[o00?ooo]ZoonC0?oo
nfX02_oonfX2o`0:o`oooo]Z0oooQP03oolG00Gooo]Z0_l0oh801?oonf[o0?n2oookJ_l0oh8=oook
JP03oh[o0?o>o`3oc_l000;oc_l000?oR_l0olko0?o>o`005_o>o`0GoookJP04o`0:oooonf[ooo]Z
oookJP?o00[o0ooonfX00ooo1@3ooi<0oookJP02oookJP;o00[o8_oonfX00ol0003ooo]ZoookJP0@
oookJP;oob/02OoonfX00ooo003ooo]ZoookJP0;oookJP;ooa001OoonfX00ooo003ooo]ZoookJP0_
oookJP03o`000?oonf[ooo]Z04Gooo]Z000JoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000ool2
0?oonfX0M?oonfX2ool[01cooo]Z0_oo2`0DoookJP06o`0:oooonf[ooo]ZoookJ_l02_oooo]Z0_l0
2_l00oooT`3ooo]ZoookJP0;oookJP03o`0:oooonf[ooo]Z00[ooo]Z0_ooQP000ooo003ooo]Zo`3o
PP02oon600Oooo]Z00Co0?n2oookJ_oonf[ooo]Z0_l0oh8:oookJP04oh[o0?oo203oo`P0oh[o00;o
oo]Z0on:o`0AoookJP03olko0?oonf[oc_l000;oc_l02OoonfX00ooo0@3ooo]ZoookJP0=oookJPCo
00[o0ooonfX00ol02_oooo]ZoookJP02oookJP04ool00?oonf[o00[oo`0:oa7ooo]Z0_oo>00@oook
JP03o`000?oonf[ooo]Z033ooo]Z00?oo`00oookJ_oonfX04OoonfX00ooo1P3ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z04Gooo]Z000IoookJP03o`000?oonf[ooo]Z027ooo]Z00?oo`80oookJ_oo
nfX0D_oonfX00ooo0`3ooo]ZoookJP0NoookJP03ool[0?oonf[ooo]Z01?ooo]Z00?oo`00oookJ_oo
;0006ooonfX01?l02_oooo]ZoookJ_oonfX2o`0:o`;ooo]Z00?o00[ooookJ_oonfX02_oonfX00ol0
2_oooo]ZoookJP08oookJP?oohH00oo>o`02oookJP03o`3oP_oonf[ooo]Z00Gooo]Z0_l0oh84oook
JP;o0?n21ooonfX2oh[o00;ooo]Z00Ooo`P0oh[o0?oonf[ooo]Zoh[o0?oonf[oR_l0017ooo]Z0_o>
o`03oonK01Sooo]Z0_l02_l3o`0bo`?ooo]Z00?o00[ooookJ_oonfX00ooonfX01?l02_oooi<0oook
J_ooT`0BoookJP;oocP000?oo`40oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP05oookJP03oolC
0?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0A?oonfX001Wooo]Z00?o0000oookJ_oonfX08_oo
nfX00ol0003ooo]ZoookJP0BoookJP03ool10?oonf[ooo]Z023ooo]Z0_oo3P0koookJP03ool[0?oo
nf[ooo]Z01Cooo]Z0_oo;00KoookJP04o`0:oooonf[oo`D0oookJP;o00[o0ooonfX00ol02_oooo]Z
oookJP08oookJP03o`0:oooonf[ooo]Z00Sooo]Z00GoohH0olko0?o>o`3oc_l0oookJP02olko00?o
oo]Z00?o0?n2oookJ_oonfX01?oonfX2o`3oPPGooo]Z00?o0?n2oookJ_oonfX00_oonfX2oh[o0003
oomF0?oonf[oo`0000Cooo]Z1?n:o`0BoookJP03olko0?oo0@3ooo]Z00;ooo]Z1OooV`03oookJP;o
oi/02ooonfX01_l02_oo03;oo`0bool0<_oooo]Zo`0:o`;ooo]Z1?l0<_l4oookJP03o`0:oooonf[o
o`8000?ooi<04OoonfX3oolh00;ooo]Z00?oo`00oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP06
oookJP03oolC0?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0A?oonfX001Wooo]Z00?o0000oook
J_oonfX08ooonfX00ol0003ooo]ZoookJP0AoookJP03ool10?oonf[ooo]Z023ooo]Z00?oo`h0oook
J_oonfX0<?oonfX00ooo0P3ooo]ZoookJP0NoookJP03ool/0?oonf[ooo]Z00kooo]Z0_ooJP05oook
JP03ool00?oonf[ooo]Z00;ooo]Z00Ko00[ooookJ_oonf[o00[ooookJ_l02_l4oookJP03o`0:oooo
nf[ooo]Z00Kooo]Z00?o00[ooookJ_oonfX01OoonfX01Ooo0@3ooo]ZoookJ_oonf[oc_l000?ooo]Z
0oo>o`04oookJP03o`3oP_oonf[ooo]Z00;ooo]Z00?o0?n2oookJ_l0oh801OoonfX2o`3oPP;oR_l0
1OooEP05oookJP;oR_l07_oonfX6oonK00Oooo]Z0_l02_l2o`0bo`;oocX01?l0<_l5oookJP?o03;o
00Oo00[ooookJ_l02_oooo]ZoonC0?oonf[ooi<001Kooo]Z00?oo`00oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP0:oookJP03ool00?oonf[ooo]Z01;ooo]Z00?oo`D0oookJ_oonfX0@_oonfX00ol0
003ooo]ZoookJP13oookJP006OoonfX00ol0003ooo]ZoookJP0NoookJP03ool50?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX09_oonfX00ooo003ooo]ZoookJP0PoookJP03ool=0?oonf[ooo]Z03[o
oo]Z00?oob`0oookJ_oonfX03_oonfX3oomZ00Gooo]Z0_oo9P03oookJP04o`0:oooonf[ooo]Zo`0:
o`;ooo]Z00Go00[ooookJ_oonf[ooo]Zo`0:o`07oookJP03o`0:oooonf[ooo]Z00Kooo]Z00?oo`40
oookJ_oonfX00_oonfX01?o>o`3ooo]Zolko0?oonfX2olko00Gooo]Z00Co0?n2oookJ_oonf[ooo]Z
0_l0oh84oookJP;o0?n21?ooEP03oookJP03oomF0?oonf[ooo]Z01[ooo]Z00?oo`00oookJ_oonfX0
2OoonfX5oonK00?ooo]Z0ol02_l2oookJP04o`0boooonf[ooo]Zool000?oocX03_l0<_l3oonC01Wo
oo]Z00?oo`80oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0@oookJP03ool00?oonf[ooo]Z00go
oo]Z00?oo`D0oookJ_oonfX04?oonfX00ooo5`3ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z04;o
oo]Z000IoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09OoonfX00ooo003ooo]Z
oookJP0PoookJP03ool=0?oonf[ooo]Z037ooo]Z0_oo000IoookJP;oofX00ooonfX3oolV00?ooo]Z
00Co00[ooookJ_oonf[o00[o0ol0<_l00ol02_oo03;oo`0bo`02oookJP03o`0:oooonf[oogD000;o
ogD00_oonfX01Ol02_oooo]ZoookJ_oonf[oo`0000[ooo]Z00?oc_l0oookJ_o>o`000_o>o`06oook
JP05o`3oP_oonf[o0?n2oookJ_l0oh800_oonfX2o`3oPP;oR_l0<OoonfX2oonK00;ooo]Z0ol02_l6
oookJP04o`0boooonf[ooo]ZoookJP;oocX000?o00[ooookJ_oonfX00ooonfX2o`0:o`03oookJ_l0
2_oooo]Z00Go03;o1?oonfX2oolA01Cooo]Z00?ooe40oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP0@oookJP03ool00?oonf[ooo]Z01?ooo]Z00?oo`00oookJ_oonfX02_oonfX2oolG00Kooo]Z00?o
o`40oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP12oookJP006OoonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?oo`@0oookJ_oonfX0;_oonfX00ooo003ooo]ZoookJP0O
oookJP;oo``0=_oonfX00oooJP3ooo]ZoookJP09oookJP06o`0:oooonf[o00[ooookJ_l0<_oooo]Z
0ol0<_l01?oonf[o03;oo`0bool0<_l4oome0003oookJ_l02_oooo]Z00;ooo]Z00?oo`00oookJ_oo
nfX02?oonfX2olko0003oookJ_o>o`3ooo]Z00Sooo]Z0_l0oh801_oonf[o0?n2oh[o0?l0oh;oR_l0
ool001_ooo]Z1?oo9004oookJP;onOl03ooonfX2olko0003o`0:oooonf[ooo]Z00Oooo]Z00Co03;o
oookJ_oo0@3oo`400_oonfX00ol02_oo03;ooookJP03oookJP?o00[o0_oonfX5o`0bo`Oooo]Z00?o
o`00oookJ_oonfX04OoonfX00oooD@3ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z04gooo]Z00?o
o`T0oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP11oookJP006OoonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z05cooo]Z00?oo``0oookJ_oonfX0=?oonfX00ooo003oofX0oookJP0:
oookJP;o00[o0_oonfX2o`0bo`;ooo]Z00Oo00[oo`0bool0<_oo03;ooookJ_ooM@3o00[o00;oogD0
00Co00[ooolI0?oo6@3ooaT02ooonfX01?o>o`3ooo]ZoookJ_o>o`0;oookJP?o0?n200?oo`40o`3o
E?oonfX03OoonfX5okOo00gooo]Z00?oob@0oookJ_oonfX00_oonfX4ooWo00[ooo]Z0ol02_l2oook
JP;oc_l02?oonfX00ol0<_oooo]ZoookJP04oookJP04o`0:oooonf[ooo]ZoookJP?o00[o0ol0<_l2
oookJP;o03;o7OoonfX01_ooD@3ooo]Zool40?oo103ooo]Zo`0001;ooo]Z00?ooah0oookJ_oonfX0
E?oonfX00ol0003ooo]ZoookJP10oookJP006?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z01gooo]Z0_oo100aoookJP03ool00?oonf[ooo]Z00;ooo]Z00?ooad0oookJ_oonfX06_oo
nfX00ooo203ooo]ZoookJP0MoookJP03oomZ0?oonf[ooo]Z00[ooo]Z0_l02_l2oookJP?o03;o00?o
oo]Zo`0:oooonfX00_oonfX00oooM@3o03;ooome0002o`0:o`;o03;o3?oonfX00oo>o`3ooo]Zoook
JP0<oookJP06oh[o0?l0oeCo0?mDool10?oonf[o0?mD3OoonfX9okOo00Kooo]Z00?oo`00oookJ_oo
nfX01_oonfX00ooio`3ooo]ZooWo0002ooWo00Kooo]Z0ol02_l3oookJP;oo`T00_oonfX2olko00Oo
oo]Z00?o03;ooookJ_oonfX00ooonfX00ol02_oooo]ZoookJP02o`0:o`03o`0booooM@3oogD000?o
oo]Z0_l0<_l;oookJP;oo`404_oonfX2oomA00;ooo]Z00?o0000oookJ_oo00004?oonfX2oolN00Co
oo]Z00?oo`00oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP10oookJP006?oonfX00ol0003ooo]Z
oookJP0;oookJP;oo`407OoonfX00ol0003ooo]ZoookJP1DoookJP;ooad06ooonfX00ooo203ooo]Z
oookJP0LoookJP03oomZ0?oonf[ooo]Z00gooo]Z0_l02_l02Ol0<_oooo]Zo`0bool0<_oooo]Zo`0:
oooonf[oogD0ool00002oookJP?o03;o00?ooo]Zo`0boooonfX02OoonfX00oo>o`3ooo]ZoookJP06
oookJP03oomS0?oonf[ooo]Z00;oo`/000Gooo]Zo`3oE?l0oeCo0?mDoookJP04o`3oE0cooo]Z00?o
]ol0oookJ_oonfX00_ngo`02ooWo0003okOo0?oio`3onOl001ConOl00ooonfX2o`0:o`cooo]Z0_o>
o`05oookJP03o`0boooonf[ooo]Z00?ooo]Z00Co00[oo`0bool02_oo03;o1?oonfX01?ooM@3ooo]Z
o`0bool0<_lOoookJP?ooe400_oonfX00ol0003ooo]ZoookJP0AoookJP05oolN0?oonf[ooo]Zoook
J_oo00005?oonfX00ooo2P3ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z03oooo]Z000HoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ooo0`3ooo]ZoookJP0OoookJP03
oolM0?oonf[ooo]Z01Cooo]Z00?ooah0oookJ_oonfX06ooonfX00ooo1@3ooo]ZoookJP0EoookJP08
o`0bool02_oo00[oo`0boooonf[o03;oo`0:ooooM@04oookJP03o`0:oooonf[o00[o00Co03;o1ooo
nfX00oo>o`3ooo]ZoookJP06oookJP?oof<00_oonfX2o`3oE003o`3oP_oonf[ooo]Z00;ooo]Z00?o
0?mDoookJ_l0oe@03OoonfX3okOo00;ooo]Z0_ngo`04oookJP;oo`802_oonfX4ooWo00;ooo]Z0ol0
2_l8oookJP03ool00?oonf[ooo]Z00Gooo]Z0_o>o`03oookJP04o`0boooonf[ooo]ZoookJP?o03;o
00?o00[ooookJ_oonfX00ooonfX2ool10003o`0booooM@3o03;o01?ooo]Z00?oobH0oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP04oookJP03ool20?oonf[ooo]Z01Gooo]Z00?oo`00oookJ_oonfX0
B_oonfX00ol0003ooo]ZoookJP0noookJP006?oonfX00ol0003ooo]ZoookJP0QoookJP03ool10?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX05_oonfX00ooo2@3ooo]ZoookJP1<oookJP03ool00?oo
nf[ooo]Z00;ooah07?oonfX2ool501Oooo]Z00Co03;ooookJ_oonf[o03;o0_oonfX00oooM@3o00[o
oookJP02oookJP05o`0:oooonf[ooo]ZoookJ_l02_l00_oonfX3o`0bo`Cooo]Z00?oc_l0oookJ_oo
nfX01OoonfX2oomS0003ool00?ooH`3ooo]Z00;o0?mD0_oonfX01?l0oh;ooo]ZoookJ_oonfX3o`3o
E003oookJ_l0oeCooo]Z00Wooo]Z0ongo`02ool20003oookJ_ngo`3o]ol0017ooo]Z0_oio`000ooo
nf[o00[oo`0:o`04oomd01;ooo]Z0oo>o`001?oonf[o03;oo`0bool0<_l3oookJP03o`0boooonf[o
oo]Z00Cooo]Z00?o03;ooookJ_l0<_l00oooM@0BoookJP;oobH03_oonfX00ol0003ooo]ZoookJP04
oookJP03ool20?oonf[ooo]Z02[ooo]Z00?oo`00oookJ_oonfX04OoonfX00ooo0`3ooo]ZoookJP0>
oookJP;oo``04OoonfX00ol0003ooo]ZoookJP0noookJP006?oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z04Kooo]Z00?oo`40oookJ_oonfX07_oonfX00ooo7P3ooo]ZoookJP0doook
JP08o`0boooonf[ooo]ZoookJ_l0<_oo00[oo`0bool02_l2oookJP03o`0:oooonf[ooo]Z00?ooo]Z
00?o00[ooookJ_oonfX00_oonfX01?l0<_oooo]ZoookJ_o>o`05oookJP?oof<01?oonfX01Ol0oeCo
oo]ZoookJ_oonf[o0?n200Cooo]Z0_l0oe@00ooonf[o0?mDo`3oE007oookJP?o]ol00_oonfX00ong
o`3ooo]ZoookJP02okOo01;ooo]Z00?onOl0o`0:ool02_l01_oonfX6oomd00;ooo]Z00?oo`80oook
J_oonfX02OoonfX3o`0bo`?ooo]Z0oo>o`000ol0<_oooo]ZoookJP02oookJP03o`0boooonf[oo`00
00;ooo]Z0_ooM@0BoookJP;oobH000?oo`00oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP06oook
JP03ool;0?oonf[ooo]Z017ooo]Z00?oobP0oookJ_oonfX0>OoonfX00ooo303ooo]ZoookJP0Aoook
JP03o`000?oonf[ooo]Z03gooo]Z000HoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX01OoonfX00ooo003ooo]ZoookJP0QoookJP03ool90?oonf[ooo]Z04[ooo]Z00?oodD0oookJ_oo
nfX00ooonfX00ooo003ooad0oolM000MoookJP;oo`4000?ookd0oookJ_oonfX00_l0<_l2o`0:o`03
o`0bool02_oooo]Z00Kooo]Z00Oo00[ooookJ_oonf[ooo]Zo`0boooonf[oc_l000Gooo]Z00?oof<0
ooWo0?oio`000_oio`03oookJP05o`3oE?oonf[ooo]ZoookJ_l0oh801?oonfX01?l0oeCooo]Zoook
J_oonfX2o`3oE0?ooo]Z0ongo`04oookJP03ool00?oonf[o]ol000;o]ol04?oonfX3o`0:o`Cooo]Z
00?oo`00oookJ_oonfX01_oonfX3oomd00[ooo]Z0ol0<_l01_l0Koooob@0oolT0?oo903oc_l0oook
JP;oc_l000?ooo]Zo`0boooonfX00_oonfX00ol0<_oooo]Zo`0bo`02oookJP?oogD00ooonfX00ooo
YP3ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Kooo]Z00?oo`/0oookJ_oonfX04OoonfX00ooo
:03ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z03cooo]Z000GoookJP03o`000?oonf[ooo]Z01oo
oo]Z00?oo`<0oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP1KoookJP03ool00?oonf[ooo]Z01Ko
oo]Z0oooA@04oookJP03oolM0?oonf[ooo]Z01gooo]Z00?ookd0o`0boooo_@000_oonfX2o`0bo`;o
oo]Z00?o00[oo`0boooonfX01ooonfX01Ol02_oooo]Zo`0boooonf[oc_l000Cooo]Z1Ooio`000ooo
nf[onOl0oookJP03oookJP04o`3oE?oonf[ooo]Zo`3oPP?ooo]Z0_l0oe@4oookJP05o`3oE?ngo`3o
]ol0okOo0?oonfX00ooo=`03oookJP03ool00?oonf[o]ol000oooo]Z0ol02_l7oookJP03ool00?oo
nf[ooo]Z00Kooo]Z00?oog@0oookJ_oonfX01ooonfX3o`0bo`06oookJ_l0Kooo06oooookJ_l0Kooo
oo]Z0_oo9003o`1_o`07olko0?l0<_oooo]ZoookJ_l0<_oooo]Zo`0bo`03oookJP03ool30?oonf[o
oo]Z00?ooo]Z00?oojH0oookJ_oonfX04_oonfX00ooo0@3ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?oo`00oookJ_oonfX03?oonfX2oolX00Cooo]Z0_oo0P0BoookJP03ool@0?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX0??oonfX001Oooo]Z00?o0000oookJ_oonfX07ooonfX00ooo
0`3ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01[ooo]Z00?oo`00oookJ_oonfX08?oonfX00ooo
203ooo]ZoookJP0doookJP03oom50?oonf[ooo]Z01Cooo]Z0oooDP05oookJP;oo`001?oonfX00ooo
_@3ooo]Zo`0bo`02oonm0003o`0boooonf[o03;o00?ooo]Z00?o03;ooookJ_oonfX01_oonfX01?l0
2_oo03;ooookJ_o>o`03oookJP03ool00?oonf[onOl000;ooo]Z1?oio`05oookJP03o`3oE?l0oh;o
oo]Z00?ooo]Z0_l0oe@3oookJP03okOo0?l0oeCo0?mD00?oocL000?ooo]Zoolg0?oonfX04_oonfX3
o`0:o`?o0?n25ooonfX3o`0bo`?ooo]Z00?o06oooookJ_oonfX00_oonfX01_oo003oob@0oookJ_o>
o`3ooo]Zolko00?o06oo00Co03;ooookJ_oonf[o03;o0ooonfX00ooo0`3ooo]ZoookJP04oookJP03
oonV0?oonf[ooo]Z01Gooo]Z00?oocd0oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doookJP03
ool@0?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0>ooonfX001Oooo]Z00?o0000oookJ_oonfX0
<_oonfX2o`000003ool30?oonf[ooo]Z06oooo]Z00?oo`00oom50?oonfX05ooonfX2oomB00Cooo]Z
0_oo5`06oookJP05oonm0?l0<_oookd0oonm0?l0<_l00_oonfX01Ol0<_oooo]ZoookJ_oonf[o03;o
00Oooo]Z00?o03;oo`0:ooo>o`001ooonfX2ooWo0004oookJ_oio`3onOl0ooWo00Kooo]Z00Co0?mD
oookJ_oonf[ooo]Z0_l0oe@01Ooonf[o]ol0okOo0?ngo`3o0?mD01Sooo]Z0_l02_l6oookJPKo0?n2
00?oo`40oookJ_oonfX02ooonfX3o`0bo`Gooo]Z3?l0Kol01?oonf[oc_l0o`0boooonfX4o`1_o`[o
oo]Z00?oojH0ool80?oonfX05?oonfX00ooo?@3ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?oo`00oookJ_oonfX04_oonfX00ooo003ooo]ZoookJP0?oookJP03ool50?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX0>ooonfX001Oooo]Z00?o0000oookJ_oonfX0=?oonfX00ooo0`3ooo]Z
oookJP0^oookJP03ool00?oonf[ooo]Z00?ooo]Z0_oo4`0JoookJP;oo`H07_oonfX00oooA@3ooo]Z
oookJP0EoookJP03oomB0?oonf[ooo]Z00cooo]Z00Co03;ooonm0?oonf[o03;o0ooonfX01?l0<_oo
oo]ZoookJ_oonfX2oomF00Gooo]Z00Co03;ooookJ_oo0@3o00[o1ooonfX2ooWo0004oookJ_oio`3o
nOl0ooWo00Gooo]Z00?o0?n2oookJ_l0oe@00_oonfX01?ngo`3o0?mDokOo0?oonfX2o`3oE003ool0
0?oonf[ooo]Z01?ooo]Z0ol02_l3oookJP?ooa400_oonfX2oooC00Cooo]Z1Ol0oh86oookJP?o03;o
0_oio`06oookJP03o`1_oooonf[ooo]Z00?ooo]Z00?o06oooookJ_l0<_l00oo>o`0:o`1_o`Wooo]Z
00?oojH0oookJ_oonfX04ooonfX01Ooo103oocd0oolm0?oonf[oo`4000;ooo]Z00?o0000oookJ_oo
nfX03ooonfX2ool105_ooo]Z00?o0000oookJ_oonfX0>_oonfX001Oooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP0AoookJP03ool20?oonf[ooo]Z01Sooo]Z00?oo`00oookJ_oonfX0
1OoonfX00ooo4`3ooo]ZoookJP1?oookJP03oomB0?oo003ooo]Z00gooo]Z00?o03;ooookJ_l0<_l0
1?oonfX00ol0<_oooo]ZoookJP03oomF000:o`0boooonf[oo``0ool<0?oonf[o03;ooookJ_oo0@3o
oo]Zo`0:o`Gooo]Z00?onOl0oookJ_oonfX00_oio`07oookJP06o`3oP_oonf[ooo]Zo`3oE?ngo`3o
oo]Z0ol0oe@EoookJP?o00[o2_oonfX2oooC0003oookJ_ood`3ooo]Z00Oooo]Z0ol0oh83o`0bo`Go
oo]Z0_oio`04oookJP03o`1_oooonf[ooo]Z00Cooo]Z00?oo`80o`0boooonfX00_o>o`001Ol0<_oo
0?n2o`0bool0<_oo0?n200?o06oo00?ooo]Zo`1_oooonfX02OoonfX00oooYP3oo`00oookJP0Coook
JP?oocd000Coo`40oookJ_oonf[o00004_oonfX00ooo503ooo]ZoookJP1JoookJP03o`000?oonf[o
oo]Z03Wooo]Z000GoookJP03o`000?oonf[ooo]Z033ooo]Z00?oo`L0oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP0@oookJP03ool20?oonf[ooo]Z03Gooo]Z00?ooa@0oookJ_oonfX06_oonfX00ooo
103ooo]ZoookJP0LoookJP03oomB0?oonf[ooo]Z00kooo]Z0_l0<_l2oookJPCo06oo1?ooEP03o`1_
o`;ooo]Z00?o03;ooookJ_oonfX00ooonfX01Ol02_oooo]ZoookJ_oonf[onOl000_ooo]Z00?o0?n2
oookJ_oonfX00_oonfX3o`3oE0kooo]Z1?o`o`02oookJP?o00[o2?oonfX00ooo003ooo]ZoookJP02
oookJPGoom<02?oonfX2o`0bo`?ooo]Z0ol0oh82ool30003o`3oP_oonf[onOl000;onOl00_oonfX0
0ol0Kooooo]ZoookJP03oookJP04o`1_ool0<_oooo]ZoookJP?o03;o0ol0Kol01?ooEP3o06oooook
J_l0Kol;oookJPCoojH04ooonfX00ooo?@3ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02[ooo]Z
00?oo`D0oookJ_oonfX03ooonfX00ooo503ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03Wooo]Z
000FoookJP03o`000?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX08_oonfX00ooo1`3ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z04;ooo]Z00?oo`00oookJ_oonfX00_oonfX2oolD01_ooo]Z00?o
o`@0oookJ_oonfX0;OoonfX2o`0bo`;ooo]Z00Co06oooookJ_oonf[ooeH00_l0Kol3oookJP04o`1_
oooonf[o06ooo`0bo`Oooo]Z00?o00[ooookJ_oio`003?oonfX02Ol0oh;oo`<0ool30?oonf[o0?mD
oookJ_l0oeCooo]Zool2000<oookJPOol?l000?ooo]ZoooC0?ood`004oood`04oookJP?o03;o2ooo
nfX4o`3oPP;onOl000?o06oooookJ_oonfX00ooonfX00ol0Kooooo]Zo`0bo`02o`0bo`;o06oo0_oo
nfX00ol0oh;o06ooo`3oPP02oomF00cooo]Z00CoojH0oookJ_oonf[oo`<05ooonfX01Ol0003oo`00
ool00?oonf[ood/001?ooo]Z00?oo`00oookJ_oonfX04_oonfX00ooo1@3ooo]ZoookJP0?oookJP;o
oa@0<?oonfX00ol0003ooo]ZoookJP0hoookJP005_oonfX00ol0003ooo]ZoookJP0ioookJP03o`00
0?oonf[ooo]Z00[ooo]Z00?oo`H0oookJ_oonfX05ooonfX00ooo0@3ooo]ZoookJP0foookJP03oolD
0?oonf[ooo]Z01_ooo]Z00?oo`40oookJ_oonfX05?oonfX00ooo_@3ooo]ZoookJP02o`0bo`;o06oo
00GooeH0oookJ_oonf[o03;oool00002o`1_o`;ooo]Z0_l0<_l2o`1_o`Kooo]Z00?onOl0oookJ_oo
nfX01_oonfX2oom000?ooo]Z00Go0?n2oookJ_oonf[ooo]Zo`3oE002oookJP;o0?lC3?oonfX00oo`
o`3o00[ooo3o0004oo3o017ooo]Z0oood`03oookJP?o03;o3?oonfX00ooo003ooo]ZoookJP04oook
JP03o`3oP_l0KooonOl000?o0?n20_oonfX01Ol0Kooo03;oo`1_oooonf[o0?n200?ooo]Z00Go06oo
oookJ_l0Koooo`00o`3oPP02oomF00Wooo]Z1?ooYP000ooo0`3ooo]ZoookJP03oookJP?ooaL03ooo
nfX01Ol0003ooo]ZoookJ_oonf[ood/004?ooo]Z00?oo`40oookJ_oonfX03_oonfX2ool801Oooo]Z
00?o0000oookJ_oonfX0=ooonfX001Kooo]Z00?o0000oookJ_oonfX08OoonfX00ooo003ooo]Zoook
JP0FoookJP03o`000?oonf[ooo]Z00Wooo]Z00?oo`H0oookJ_oonfX0C?oonfX00ooo003ooo]Zoook
JP02oolD01gooo]Z00?oo`40oookJ_oonfX05?oonfX00ooo_@3ooo]ZoookJP02oookJP?o06oo0_oo
nfX01?l0<_ooc_l0o`1_oooonfX4o`1_o`03o`0boooonf[o06oo00Cooo]Z00?onOl0oookJ_l02_l0
1?oonfX5oom000;ooo]Z00?o0?n2oookJ_oonfX00_oonfX3o`3o4`03oookJ_l0oa?ooo]Z00Wooo]Z
00Go00[ooo3o0?o`o`3ol?l0oookJP03oo3o0003ool00?oonf[ooo]Z00Kooo]Z00?oo`<0oookJ_oo
nfX01_oonfX00oood`3ooo]ZoookJP03o`0bo`;ooo]Z1OooC@000ooonf[oodd0oookJP04oookJP;o
o`002?oonfX00ol0KooonOl0ooWo0004o`1_o`04o`3oP_oio`3o0?n2o`3oPP;ooo]Z00Co06oooook
J_oonf[o06oo0_oonfX3oomF00[ooo]Z0_ooYP07oookJP;ooaL03ooonfX01Ol0003ooo]ZoookJ_oo
nf[ood/001Sooo]Z00?ooad0oookJ_oo00005?oonfX00ooo003ooo]ZoookJP0AoookJP03ool10?oo
nf[ooo]Z00oooo]Z00?oo`P0oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0goookJP005_oonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01gooo]Z00?oo`D0oookJ_oonfX06OoonfX0
0ooo003ooo]ZoookJP0GoookJP;oob/01OoonfX00ooo503ooo]ZoookJP0coookJP05oonm0?oonf[o
oo]ZoookJ_l0Kol00_oonfX2o`1_o`;oc_l000Go03;ooookJ_o>o`3ooo]Zo`0bo`02oookJPGo06oo
00?ooo]ZooWo0?oonfX00_oonfX01?l02_oooo]ZoookJ_oo@003oookJP05oom00?oonf[oo`00oook
J_l0oh800_oonfX3o`3o4`03oookJ_l0oa?o0?lC00;o0?lC1ooonfX3oo3o00;ooo]Z00Col?l0oook
J_o`o`3ol?l04ooonfX3o`0bo`[ooo]Z0oooC@0>oookJP?o06oo0ooio`001?l0KooonOl0ooWo0?oo
nfX2o`3oPP04o`1_ool0oh;o0?n2o`1_o`Cooo]Z0_l0oh8FoookJP03ool00?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX00_oonfX00oooB`3oo`<0ool30002ool501?ooo]Z00?ooad0ool00?oo0000
DooonfX00ol0003ooo]ZoookJP0foookJP005_oonfX00ol0003ooo]ZoookJP0goookJP03ool00?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX07?oonfX00ooo1@3ooo]ZoookJP0doookJP03ool[0?oo
nf[ooo]Z01?ooo]Z00?ooc<0oookJ_oonfX00ooonfX00ooo003ooa40oolA000LoookJP03oonm0?oo
nf[oo`0000;ooo]Z00Co06oooookJ_oonf[o06oo0_l0<_l01Ol0Kooo03;ooookJ_oonf[o03;o00Co
oo]Z00?o03;ooookJ_l0Kol00ol0Kol4oookJP03o`0:oooonf[ooo]Z00Kooo]Z00?o0?n2oookJ_oo
nfX00_l0oa<01ol0oeCooo]ZoookJ_oonf[o0?lCoookJ_l0oa<01OoonfX2oo3o00Gooo]Z0oo`o`0A
oookJP?o03;o3OoonfX2oom=00cooo]Z1?l0Kol2oookJP;ooa400_oio`002?l0KooonOl0ooWo0?l0
oh;o06oooookJ_l0oh;o06oo0ol0oh82ool10003o`3oP_oonf[o0?n200Cooo]Z00?oohH0oookJ_oo
nfX07?oonfX01?l0003ooo]ZoookJ_oonfX3oom;01Kooo]Z0_oo7@0HoookJP03ool:0?oonf[ooo]Z
03[ooo]Z00?o0000oookJ_oonfX0=OoonfX001Kooo]Z00?o0000oookJ_oonfX07_oonfX2ool201go
oo]Z00?o0000oookJ_oonfX0C_oonfX01Ooo003ooo]ZoookJ_oonf[oob/001Gooo]Z0_oo<`04oook
JP03ool00?oo4@3ooo]Z01kooo]Z0_ooV`001Ooonf[o06oooookJ_oonf[oc_l000;o06oo0_l0<_l0
1?oonf[o03;oolko0?o>o`04oookJP04o`0boooonf[onOl0oookJP;o06oo0ooonfX00ol02_oooo]Z
oookJP06oookJP05o`3oP_l0oa?o0?lCoookJ_l0oe@00ooonfX3o`3o4`03oookJ_l0oa?ooo]Z00?o
l?l00_oonfX2oolL00?ooo]Z00?ol?l0oookJ_oo0@003_oonfX3o`0bo`?o0?mD2?oonfX00ooo003o
oo]ZoookJP09oookJP;oo`@00_oonfX3o`1_o`Cooo]Z00?o06oooookJ_oonfX00_oo4@001Ooonf[o
06ooooWo0?oio`3o06oo00;ooo]Z00?o06oooookJ_oonfX01OoonfX3o`3oPP?ooo]Z00?oohH0oook
J_oonfX06ooonfX2o`0000Cooo]Z00?ood/0oookJ_oonfX06ooonfX00ooo003ooo]ZoookJP0Aoook
JP03ool:0?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0=OoonfX001Kooo]Z00?o0000oookJ_oo
nfX0?_oonfX00ol0003ooo]ZoookJP0<oookJP03ool00?oonf[ooo]Z00Kooo]Z0_oo3@0IoookJP03
ool40?oonf[ooo]Z03?ooo]Z0_oo<`0=oookJP;oofX02?oonfX00ooo>P3ooo]ZoookJP04oookJP03
ool;0?oonf[ooo]Z00Cooo]Z0oooV`000ooonf[o06oooookJP02oookJP06o`1_oooonf[oc_l0o`1_
ool0<_ooc_l01ooonfX01_oio`3ooo]ZoookJ_oonf[o06ooool000;ooo]Z1?ood`04oookJP03o`3o
P_l0oa?ooo]Z00;ooo]Z00Co0?mDoookJ_oonf[ooo]Z0_l0oa<01?oonf[ol?l0oo3o0?o`o`03oook
JP?ooa`01OoonfX2ool100cooo]Z0_l0<_l6oookJPGo0?mD4?oonfX3o`1_o`Oooo]Z00?o06oooook
J_oonfX00ooio`001ol0KooonOl0o`1_oooio`3ooo]Zo`1_ool0oh800_oonfX6o`3oPPKooo]Z00?o
ohH0ool20?oonfX04?oonfX2ool200?ooo]Z00?oobX0oookJ_l000000_l000000ooonf[o0000oook
JP0<oookJP03ool00?oonf[ooo]Z057ooo]Z0_oo2`0AoookJP03o`000?oonf[ooo]Z03Cooo]Z000E
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?oo`40oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0E
oookJP03ool=0?oonf[ooo]Z04cooo]Z00?oo`00oolc0?oonfX03?oonfX4oomZ00Kooo]Z0_oo>P05
oookJP;oo`/000?oo`40oookJ_oonfX00_oonfX00oooV`3ooo]ZoonK0002oonK0004o`1_oooonf[o
oo]ZoookJP;o06oo0_o>o`000ol0Kooooo]ZoookJP07oookJP03o`0boooonf[o06oo00;ooo]Z1_oo
d`04oookJP05o`3oP_oonf[o0?lCoookJ_l0oe@00ooonfX01Ol0oa?ol?l0o`3o4oo`o`3ooo]Z00;o
0?lC5_oonfX3o`0bo`gooo]Z1Ol0oe@8oookJP?o06oo0_ood`03oookJPCo0=3o00Kooo]Zo`1_oooo
nf[ooo]Zool00?oonfX2ooWo0005o`1_ool0oeCo0?mDo`3oP_l0Kol00ol0oh801Ooonf[o0?n2o`3o
P_l0oh;oo`D000Sooo]Z00?oo`80oookJ_oonfX03ooonfX01?oo0P3ooo]ZoookJ_oonfX3o`0000Go
oo]Z00?o0000oookJ_oonfX08ooonfX00ooo8P3ooo]ZoookJP0EoookJP03ool00?oonf[ooo]Z00oo
oo]Z0_oo0`0?oookJP03ool;0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0=?oonfX001Gooo]Z
00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0XoookJP;oo`d06_oonfX2ool302gooo]Z
00?oofX0oookJ_oonfX01_oonfX2oolj00gooo]Z1?ooV`001_l0Kooooo]ZoookJ_l0Kooooo]Zo`1_
o`;oc_l000?ooo]Zo`1_oooonfX02?oonfX00ol0Kooooo]ZoookJP02oookJP03oooC0?oonf[oom<0
00;oom<01?oonfX01Ol0oh;ooo]ZoookJ_l0oa?o0?mD00?ooo]Z00?ol?l0o`3o4ooonfX00ooonfX0
0ol0oa?oo`00oookJP0AoookJP?o03;o1_oonfX2ool600Wooo]Z00Coo`<0oookJ_oonf[ooo]Z1Ol0
oe@3o`1_o`Gooo]Z0ol0d?l01?oonf[o0=3ooookJ_oonfX2o`3@o`05o`1_oooonf[ooo]ZoookJ_n:
o`000_l0Kol01?l0oh;o0?mDo`1_ool0oe@2oookJP;o0?n20ooonfX2ool500Sooo]Z0oooQP05oook
JP03oonC0?oonf[ooo]Z00Oooo]Z0ol000000ooonf[oobX0oolZ0006oookJP03o`000?oonf[ooo]Z
00kooo]Z0_oo2`0BoookJP04oolR0?oonf[ooo]Zool004_ooo]Z00?o0000oookJ_oonfX0<ooonfX0
01Gooo]Z00?o0000oookJ_oonfX0<OoonfX00ooo103ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z
00Gooo]Z00?oo`40oookJ_oonfX06?oonfX00ooo003ooo]ZoookJP05oookJP03ool=0?oonf[ooo]Z
04Oooo]Z00?oofX0oookJ_oonfX01_oonfX00ooo>P3ooo]ZoookJP0<oookJP;ooi/00_oonfX00ol0
Kooooo]Zo`1_o`03oookJP04oolg0?o>o`3ooo]Zo`1_o`;ooo]Z0_oo1003oookJP04ool20?l0Kooo
oo]Zo`0bo`Cooo]Z00Goom<0oookJ_ood`3oom<0o`0:o`02oookJP03o`3oP_oonf[ooo]Z00;ooo]Z
00Ko0?lCoookJ_oonf[o0?lCoookJ_l0oa<4oookJP;o0?lC3ooonfX3o`0bo`Wooo]Z0oooU`0>oook
JP?o06oo00?ooo]Zo`3oE?l0oe@00ol0oe@00ooonf[o0=3oo`3@o`05o`3@o`?ooo]Z00go06ooo`3@
ool0d?oo0=3oo`1_oon:o`3o06oooookJ_l0Kooo0?mDo`3oP_l0oeCo0?n200;oocL03OoonfX2oon6
0003ool00?ooQP3ooo]Z00?ooo]Z00?ooi<0oookJ_oonfX01?oonfX3o`0000Sooo]Z00?oo`00oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP0=oookJP03ool20?oo2`3ooo]Z017ooo]Z0_oo8P0Goook
JP03ool>0?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<_oonfX001Gooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ooo103ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Cooo]Z00?oo`40oookJ_oo
nfX0=OoonfX2ool=01_ooo]Z0_oo0@0FoookJP03oomZ0?oonf[ooo]Z00Gooo]Z00?oocX0ool00?oo
nfX03OoonfX01_ooV`3ooo]ZoookJ_l0Kooooo]Zo`1_o`?ooo]Z0_oo=`001?o>o`3ooo]ZoookJ_l0
Kol5oookJP;oo`800ooonfX01_l0<_oooo]ZoookJ_ood`3ooo]ZoooC00?ooo]Z00?o00[ooookJ_l0
oh800ooonfX01ol0oeCooo]Zo`3o4ooonf[o0?lCoookJ_l0oa<00_oonfX2o`3o4`kooo]Z0ol0<_l8
oookJPSooiL02_oonfX00ol02_oo06ooo`1_o`09oookJP03ool00?l0d?oo0?mD00;o0?mD00?ooo]Z
oooC0?l0d?l01_l0d?l00ooo103o0=3oo`3@o`02o`3@o`03oookJ_l0oeCo0?n200;o0?mD0_oonfX2
oolg00[ooo]Z0oooQP000ooo003oohH0oookJP03oookJP04oonC0?oonf[ooo]ZoookJP?o00004?oo
nfX00ol0003ooo]ZoookJP0XoookJP03ool20?oonf[ooo]Z00oooo]Z0_oo3P0eoookJP03o`000?oo
nf[ooo]Z03;ooo]Z000EoookJP03o`000?oonf[ooo]Z00_ooo]Z0_oo000goookJP03o`000?oonf[o
oo]Z03Kooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo3@3ooo]ZoookJP0boookJP03oomZ0?oonf[o
oo]Z01Gooo]Z00?ooi/0oookJ_oonfX00_l0Kol3oookJP04oolg0?oonf[o06ooolko00?ooo]Z00?o
06oooookJ_oonfX00_oonfX00ol0Kooooo]ZoookJP03oookJP03o`0booood`3ooo]Z00Kooo]Z00?o
0?n2oookJ_oonfX00_oonfX00ol0oeCoo`00oookJP02o`3o4`04oookJ_l0oa?ooo]Zo`3o4`gooo]Z
0ol0<_l4oookJPOooiL00_oonfX2ool100;ooiL02_oonfX3o`1_o`gooo]Z00?o0=3ooookJ_oonfX0
0_l0oe@01Ol0d?oo0?mDoooC0?ood`3ooo]Z00;o06oo00?oo`@0o`1_ool0d?l01?l0d?l2oookJP;o
0?mD0_oonfX2oolg00_ooo]Z0_ooQP05oookJP04oonC0?l0003o0000o`0001Cooo]Z00?o0000oook
J_oonfX04_oonfX00ooo003ooo]ZoookJP0ooookJP03ool50?oonf[ooo]Z01[ooo]Z00?o0000oook
J_oonfX0<OoonfX001Gooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003oo`@0oookJP0HoookJP03
ool00?oonf[ooo]Z01Wooo]Z0_oo6P0KoookJP03ool;0?oonf[ooo]Z01_ooo]Z00?oofX0oookJ_oo
nfX05?oonfX01?ooV`3ooo]ZoookJ_oonfX2o`1_o`;ooo]Z00GoocL0oookJ_oonf[oo`00o`1_o`04
oookJP04o`1_oooonf[ooo]Zo`1_o`Kooo]Z00?oom<0oookJ_oonfX01ooonfX01?l02_oooo]Zoook
J_l0oe@3oookJPGo0?lC00?oo`@0oookJ_oonfX01_oonfX4ooo90003o`0boooonf[ooo]Z013ooo]Z
00?ooiL0oookJ_oonfX01_oonfX3o`1_o`?ooo]Z00?o00[ooookJ_oonfX02_oonfX00ol0d?oooo]Z
oookJP03oookJP04o`3@oooonf[o0?mDoooC00;o06oo00?oom<0o`3oE?l0d?l00_l0d?l00ol0oeCo
0=3ooookJP02oookJP;o0?mD00?oo`00oolg0?oo=`004?oonfX3o`0000;ooo]Z00?oo`/0oookJ_oo
nfX04?oonfX01?oo0@3ooo]Zoolh0?l00013oookJP03ool00?oonf[ooo]Z00oooo]Z00?oo`D0oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0`oookJP005?oonfX00ol0003ooo]ZoookJP0RoookJP03
ool00?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0<ooonfX00ooo6P3ooo]ZoookJP0IoookJP;o
o`/07OoonfX00ooo003ooo]ZoookJP0DoookJP03oonK0?oonf[ooo]Z00?ooo]Z0_l0Kol3oookJP03
ool00?l0Kooooo]Z00Cooo]Z00?o06oooookJ_l0Kol01OoonfX00oood`3ooo]Zo`0bo`04oookJP;o
ob800ooonfX00ol02_oooo]Zo`3oE003oookJP03o`3o4ooonf[o0?lC00[ooo]Z1_oob@0HoookJP?o
06oo1?oonfX4oolY00Wooo]Z00?oo`80oookJ_l0d?l01OoonfX01Ol0d?oooo]ZoookJ_ood`3o]ol0
00?oom<000Go0?mDo`3@ool0oeCo0=3oo`3oE002oookJP;oR_l000?ooo]Zo`3oE?oonfX03_oonfX3
o`0000?ooo]Z00?ooi<0oookJ_oonfX05?oonfX2oolh0003o`000?oonf[ooo]Z01Gooo]Z00?ooa<0
oookJ_oonfX05?oonfX00ooo003ooo]ZoookJP0AoookJP03ool00?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX0<?oonfX001Cooo]Z00?o0000oookJ_oonfX0@ooonfX00ooo203ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z017ooo]Z00?oo`<0oookJ_oonfX06OoonfX00ooo003ooo]ZoookJP0Goook
JP;ooah00ooonfX00ooo003ooo]ZoookJP0doookJP03oonK0?oonf[ooo]Z00Kooo]Z0_l0Kol01?oo
nf[onOl0ooWo0?l0Kol5oookJP03o`1_oooonf[ooo]Z00?ooo]Z00Goom<0oookJ_oonf[ooo]Zo`0b
o`02oookJP03oolR0?oonf[oob8000Cooo]Z00Go0?mDoookJ_oonf[ooo]Zo`3o4`0=oookJPKoolT0
1?oonfX00ooo003ooo]ZoookJP0>oookJP?o06oo2_oonfX2oolY00Sooo]Z00Coo`80oookJ_oonf[o
0=3o1?oonfX00ol0d?oooo]Zo`3@o`05oooC0005o`3@oooonf[o0=3oo`3oE?n:o`001Ol0oe@00on:
o`3o0?mDoookJP07oookJP03oomS0?oonf[ooo]Z00?o00001OoonfX3oonC01Kooo]Z00GoocP0o`00
0?oonf[ooo]Zool1000DoookJP03oolC0?oonf[oo`8002Wooo]Z00?ooa00oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0_oookJP005?oonfX00ol0003ooo]ZoookJP0OoookJP03ool10?oonf[ooo]Z
01Kooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo203ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
04Oooo]Z00?ooah0oookJ_oonfX06_oonfX2ool801oooo]Z00?oo`00oookJ_oonfX01?oonfX01On:
o`3o0=3oo`3@ool0d?oo06oo00Co0=3o00?o06ooo`3@ool0Kol00ooonfX00oood`3ooo]ZoookJP03
oookJP03o`0boooonf[ooo]Z00Cooo]Z0_oo0P001Ol0oeCo00[ooookJ_oonf[o0?lC00_ooo]Z1?oo
b@000ooonf[oolT0ooo9000?oookJP;oo`D00_oonfX3o`1_o`;o0?lC3OoonfX00ol02_oooo]Zoook
JP08oookJP04o`3@oooonf[ooo]ZoookJP?o0=3o0_oonfX2ool60007okOo0?l0d?oo0?mDo`3@oooo
nf[o0?mDoookJP02oh[o0003oookJ_n:o`3ooo]Z00?o0?mD1ooonfX3o`0000Oooo]Z00Gooi<0oook
J_ooT`3ooo]ZoonC0002oookJP03ool00?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX01OoonfX0
0ooo>`3ooo]ZoookJP0=oookJP03ool20?oonf[ooo]Z01Kooo]Z00?oo`D0oookJ_oonfX03_oonfX2
ool@033ooo]Z00?o0000oookJ_oonfX0;_oonfX001Cooo]Z00?o0000oookJ_oonfX07ooonfX00ooo
0@3ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00[ooo]Z0_oo200IoookJP03ool20?oonf[ooo]Z
01[ooo]Z00Goo`00oookJ_oonf[ooo]ZoolN000EoookJP;oob<01OoonfX00ooo0@3ooo]ZoookJP0U
oookJP0;ooWo0?l0d?oo06ooo`1_ool0d?oo06ooo`3@oon:o`3o06ooo`3@oooonfX00_l0d?l00ooo
nf[oom<0oookJP06oookJP03o`0boooonf[ooo]Z00Cooo]Z00Go0?mDoookJ_l02_oooo]Zo`3o4`09
oookJP?oolT000Cooo]Zool90?oo2@3ooo]Z0_oob@0AoookJP?o06oo1OoonfX5o`3o4`;ooo]Z0_oo
0005oookJP03o`0:oooonf[ooo]Z00Oooo]Z1?l0d?l2oookJP03o`3@oooonf[ooo]Z00;ooo]Z00?o
0=3oo`3oE?l0d?l00_oonfX00ol0oeCooo]Zo`3oE005o`3oE003oookJ_oo0`3ooo]Z00?ooo]Z0ol0
00000ooonf[oof<0oookJP08oookJP?ooi<02ooonfX00ooo6@3ooo]ZoookJP0:oookJP03ool50?l0
003ooo]Z00Gooo]Z00?ooc/0oookJ_oonfX04_oonfX00ooo003ooo]ZoookJP0loookJP;oo`L05_oo
nfX00ol0003ooo]ZoookJP0^oookJP005?oonfX00ol0003ooo]ZoookJP1;oookJP;o00002_oonfX0
0ooo203ooo]ZoookJP0HoookJP03ool20?oonf[ooo]Z02cooo]Z0_oo>`06oookJP03oolS0?oonf[o
oo]Z00?ooo]Z0_oo0@0VoookJP05ooWo0?n:o`3o0=3oo`3@oon:o`000_l0Kol00ooio`3o0=3oo`3@
o`02o`3@o`;ooo]Z0_l0d?l8oookJP03o`0boooonf[ooo]Z00?ooo]Z00Go0?mDoookJ_oonf[o00[o
o`3o4`02oookJP;oB?l00_oonfX3ooo900gooo]Z00?oo`<0oookJ_oonfX01ooonfX3o`1_o`gooo]Z
1Ol0oa<4oookJP03o`0:oooonf[ooo]Z00?ooo]Z00?oo`L0oookJ_l0d?l00ol0d?l4oookJP08o`3@
oooonf[ooo]ZoookJ_l0d?oo0?lCo`3@oooonfX4o`3oE004oookJ_l0oeCo0?mDoh[o00;ooo]Z00?o
R_l0oookJ_oonfX00ol00005oookJP03oomS0?oo003ooo]Z00Oooo]Z00?ooi<0oookJ_oonfX02_oo
nfX2oolI00gooo]Z00?o0000oookJ_oonfX00_oonfX00ooo003ooc/0oookJP0GoookJP03oolH0?oo
nf[ooo]Z02Oooo]Z0_oo0@0?oookJP;oo`L05ooonfX00ol0003ooo]ZoookJP0]oookJP005?oonfX0
0ol0003ooo]ZoookJP0doookJP03ool00?oonf[ooo]Z01Kooo]Z00?o0000ool00?oonfX0DOoonfX0
0ooo>`3ooo]ZoookJP05oookJP03oolS0?oonf[ooo]Z00_ooo]Z0_ooDP07oookJP;oob@000?ooo]Z
oonC0?oonfX00ooonfX00ooo0`3ooo]ZoookJP04oookJP;oog@01ooonfX02Ooio`3o0=3oo`3@ool0
d?oonOl0oookJ_l0Kooo0=3ooh[o0002oookJPKo0=3o00?ooo]Zool00?oonfX01?oonfX00ol0<_oo
oo]ZoookJP02oookJP05o`3oE?oonf[ooo]Zo`3o4ol02_l00om8o`03ooo900oooo]Z0_oo0`06oook
JP?o06oo5OoonfX6o`3o4`?ooo]Z00Co0=3oool70?oo1`3ooiL00_oonfX00ol0d?oooo]ZoookJP03
oookJP07o`3@oooonf[o0=3oo`3o4ooonf[o0=3oo`3o4`05o`3oE003oookJ_n:o`3ooo]Z00;oR_l0
0ol00008oookJP03ool00?ooH`3oof<001Gooo]Z00?ooaT0oookJ_oonfX02ooonfX00ol0003ooo]Z
oookJP02oookJP03ool00?oo>`3ooo]Z01Oooo]Z00?ooaP0oookJ_oonfX05OoonfX00ooo003ooo]Z
oookJP0joookJP03o`000?oonf[ooo]Z02cooo]Z000CoookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX07?oonfX00ooo203ooo]ZoookJP0HoookJP;oo`406?oonfX00ooo>`3ooo]Zoook
JP03oookJP03ool00?oonf[ooo]Z00gooo]Z0_ooDP06oookJP;oob@00oooT`04oookJP03ool30?oo
nf[ooo]Z00;ooo]Z00?oog@0oookJ_ooM0001ooonfX00on:o`3o0=3oooWo0002o`3@o`03oookJ_l0
d?ooR_l000Kooo]Z00?o06ooo`3@ool0d?l00_l0d?l6oookJP04o`0boooonf[ooo]Zo`3oE0?ooo]Z
0_m8o`000ol02_oooo]Zooo90002odSo01Gooo]Z0ol0Kol9oookJP03ool00?oonf[ooo]Z01;ooo]Z
0ol0d?l2o`3o4`;ooo]Z0_ooU`000ol0d?oooo]ZoookJP03oookJP;o0=3o00?ooo]Zool10?oo0@00
0ol0oa<00ol0oeCooo]ZoookJP03oh[o00?o000000?oR_l0oookJ_oonfX02?oonfX3oomS00Kooo]Z
00?oogD0oookJ_oonfX01ooonfX00ooo103ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00;ooo]Z
00?ooc/0oookJ_oonfX00_oonfX00ooo1@3ooo]ZoookJP0AoookJP03oolH0?oonf[ooo]Z05;ooo]Z
00?o0000oookJ_oonfX0;?oonfX001?ooo]Z00?o0000oookJ_oonfX0<_oonfX00ooo0P3ooo]Zoook
JP0FoookJP03ool00?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX04ooonfX01?oo003ooo]Zool@
0?oo400ioookJP03oolk0?oonf[ooo]Z01?ooo]Z00?ooe80oookJ_oonfX01?oonfX01?oo903ooo]Z
oonC0?oonfX3oonC00Wooo]Z0oooM006oookJP05oh[o0?l0d?oonOl0o`3@oon:o`000_l0d?l00ooo
nf[oo`00oookJP05oookJP03o`1_oooonf[ooiL000;o0=3o0_ooU`03oookJP05o`0boooonf[ooo]Z
o`3oE?oonfX00_m8o`03oookJP03o`0:oom8o`3ooo]Z00;oB?l01?oonfX00ooo0@3ooo]ZoookJP0:
oookJP?o06oo1ooonfX2oomH00kooo]Z0_oo1@000ooonf[o03;ooookJP02oookJP?o0=3o00?ooo]Z
o`0:oooonfX00_oonfX4o`3o4`03oonG0?l0d?oooiL000;ooo]Z00OooiL0o`3@oooonf[o0?lCo`3@
oooonf[o0?lC00;ooo]Z00?o0?lCoookJ_oonfX00ol000000on:o`3ooa`0oolL000DoookJP03oome
0?oonf[ooo]Z00oooo]Z00?oo`00oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0MoookJP03ool1
0?oonf[ooo]Z01?ooo]Z0_oo200koookJP03o`000?oonf[ooo]Z02_ooo]Z000CoookJP03o`000?oo
nf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0DoookJP;ooa006Ooo
nfX2ool701cooo]Z00?oo`00oookJ_oonfX05?oonfX00oooDP3ooo]ZoookJP06oookJP03ool00?oo
nf[ooi<000;ooi<02_oonfX2oomd00Oooo]Z00Cooa`0o`3@oon:o`3onOl00ol0d?l9oookJP04o`1_
ooooU`3ooo]Zo`3@o`;ooiL01?oonfX01_l0<_oo0?mDoookJ_m8o`3ooo]Zo`3o4`?ooo]Z0_m8o`02
oookJP03odSo0?oonf[ooo]Z00cooo]Z0ol0Kol3oookJP[ooeP04?oonfX01?l0<_oo0=3oo`3@ool0
d?l5oookJP04o`0:oooonf[ooo]Zool000Cooo]Z00Ko0=3oo`3o4oooU`3ooiL0o`3@ooooU`02o`3@
o`03oookJ_l0oa?ooo]Z00;ooo]Z0ol00002oookJP03olko0?n:o`3oR_l000;ooa`03OoonfX00ooo
0P3ooo]ZoookJP04oookJP03oome0?oonf[ooo]Z01Gooo]Z00?oobH0oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP05oookJP03ool40?oonf[ooo]Z01Sooo]Z00?oo`00oookJ_oonfX0>_oonfX00ooo
203ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02_ooo]Z000CoookJP03o`000?oonf[ooo]Z04Oo
oo]Z00?oo`80oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0XoookJP03oolB0?oonf[ooo]Z03So
oo]Z00?ooe80oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP02oonC00[ooo]Z00?oog@0oookJ_oo
nfX01OoonfX2oolL00;ooo]Z00GonOl0o`3@oooonf[oR_l0o`3@o`04oookJP03ool50?oonf[ooo]Z
00;ooo]Z00?o06ooo`3@oooonfX00_ooU`05oookJP04o`0boooonf[ooo]ZodSo00;ooo]Z00Goo`00
oookJ_m8o`3oB?l0o`0:o`02oookJP03odSo0?oonf[ooo]Z00Sooo]Z0ol0Kol=oookJP03oomH0?oo
nf[ooo]Z00kooo]Z0ol0d?l00ol0<_oooo]ZoookJP06oookJP03o`0:oooonf[ooo]Z00Cooo]Z00Co
0=3ooookJ_oonf[o0=3o0_ooU`001?l0d?oo0?lCo`3o4ol0oa<3o`000004oookJ_ngo`3o0?lCo`3o
4`;o]ol04OoonfX00ooo0P3ooo]ZoookJP04oookJP04oome0?oonf[oo`<0ool301Cooo]Z0_oo9P05
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?oo`@0oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP0D
oookJP03oolJ0?oonf[ooo]Z02Sooo]Z00?oo`80oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0Z
oookJP004ooonfX00ol0003ooo]ZoookJP16oookJP03ool20?oonf[ooo]Z00[ooo]Z00?o0000oook
J_oonfX02ooonfX00ooo003ooo]ZoookJP0IoookJP03oolB0?oo003ooo]Z01[ooo]Z00?oo`D0oook
J_oonfX0:OoonfX00oooT`3ooo]ZoookJP07oookJP03oomd0?oonf[ooo]Z00Cooo]Z00?ooa`0oook
J_l0d?l00_oonfX01_l0d?oooo]Zo`3@oooonf[oR_l0o`3@o`Sooo]Z00?o0=3oo`1_ooooU`002?oo
nfX01?l0<_oooo]Zo`3o4om8o`03oookJP;oB?l000?ooo]Zo`0:oooonfX00_m8o`08oookJP03o`1_
oooonf[ooo]Z017ooo]Z00?oo`<0oookJ_oonfX02?oonfX3o`3@o`Cooo]Z00Co03;ooookJ_oonf[o
oo]Z1?l0oi000ol02_oooo]ZoookJP05oookJP?o0=3o0oooU`03o`000003oookJ_l0oa?o0?lC00?o
0?lC00?ooo]Zo`3o4oo>o`000_ngo`0FoookJP;oogD00_oo0`06oookJP03oomZ0?oonf[ooo]Z00_o
oo]Z0_oo9P06oookJP03o`000?oonf[ooo]Z00oooo]Z00?oo`/0oookJ_oonfX03ooonfX2oolJ01Oo
oo]Z00?oo`00oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0YoookJP004ooonfX00ol0003ooo]Z
oookJP0QoookJP03ool00?oonf[ooo]Z01oooo]Z00?oo`D0oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP0VoookJP03oolB0?oonf[ooo]Z01[ooo]Z00?oo`D0oookJ_oonfX07?oonfX00ooo003ooo]Z
oookJP0:oookJP03oonC0?oonf[ooo]Z00Kooo]Z00?oog@0oookJ_oonfX01ooonfX01_l0d?oooo]Z
ool20?l0d?oooo]Zo`3@o`;ooo]Z00?oR_l0o`3@oooonfX01OoonfX01?l0d?oooo]ZoookJ_l0Kol9
oookJP08o`3o4ooonf[ooo]ZodSo0?oonf[oB?l0oookJ_m8o`02oookJP03odSo0?oonf[ooo]Z02Co
oo]Z0ol0d?l4oookJP?oo`h000Kooo]Zo`0bool0oi3o0?n@oookJ_l0oi02oookJPCo0?n@1?oonfX0
0ol0d?oooo]ZoookJP03o`000003o`3o4oo`o`3o0?lC00Kooo]Z0ol0oa<2oookJP03okOo0?oo003o
oo]Z01;ooo]Z1?ooM@07oookJP03oomZ0?oonf[ooo]Z00Wooo]Z00?oo`<0oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0>oookJP03ool;0?oonf[ooo]Z02Wooo]Z00?oo`/0oookJ_oonfX0<_oonfX0
0ol0003ooo]ZoookJP0YoookJP004_oonfX00ol0003ooo]ZoookJP14oookJP03ool50?oonf[ooo]Z
00oooo]Z00?o0000oookJ_oonfX01?oonfX00ooo0@3ooo]ZoookJP0IoookJP03ool00?oonf[ooo]Z
01Sooo]Z00?ooa@0oookJ_oonfX0<?oonfX00oooT`3ooo]ZoookJP06oookJP03oomd0?oonf[ooo]Z
00Oooo]Z00Oo0=3ooookJ_l0d?oonOl0oookJ_l0d?oooo]Z00;o0?n200?oR_l0o`3@oooonfX00ooo
nfX00ol0d?oooo]ZoookJP02oookJP04o`1_oooonf[oo``0ool<00Gooo]Z00Co0?lCo`0boooonf[o
oo]Z0om8o`000ooonf[oB?l0odSo0002ool700?ooo]Z0oooN`0;oookJP03ool00?oonf[ooo]Z00ko
oo]Z0ol0d?l;oookJPWo0?n@00?oo`@0oookJ_l0oi000ol0oi03o`0000;ooo]Z00Co0?lCoookJ_oo
nf[o0?lC0_oonfX5o`3o4`;o]ol00_oonfX00ongo`3ooo]ZoookJP07oookJP03oom00?oonf[ooo]Z
00Wooo]Z0_ooM@08oookJP03oomZ0?oonf[ooo]Z013ooo]Z00?oo`00oookJ_oonfX00_oonfX00ol0
003oob`0oookJP0ToookJP03ool00?oonf[ooo]Z01;ooo]Z00?oo`/0oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP0XoookJP004_oonfX00ol0003ooo]ZoookJP0OoookJP;oo`00=_oonfX00ol0003o
oo]ZoookJP0coookJP;oob801OoonfX00ooo503ooo]ZoookJP02ool101Wooo]Z00?oo`80oookJ_oo
nfX04ooonfX00oooT`3ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z00Gooo]Z0_l0d?l2oookJP04
ooWo0?l0oh;o0=3ooookJP;o0?n200GoR_l0o`3@oooonf[ooo]Zo`3@o`06oookJP03o`1_oooonf[o
oo]Z00Gooo]Z00Co0?lCoookJ_l0<_oooo]Z1?m8o`07oookJPCoog/06?oonfX2o`3@o`CoB?l02ooo
nfX00ol0oi3ooo]Zo`0bo`02oookJP03o`3oT?oonf[ooo]Z00;oo`@00_l0oi03o`0000;o0?n@0ooo
nfX00ol0oa?ooo]Zool00005o`3o4`05oookJ_ngo`3ooo]ZokOo0?o>o`000ongo`0:oookJP03oom0
0?oonf[ooo]Z00?ooo]Z0_oo1`09oookJP05ool10?oonf[ooo]ZoookJ_ooJP005ooonfX00ol0003o
ob`0oookJP0WoookJP03ool20?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09ooonfX001;ooo]Z
00?o0000oookJ_oonfX0>?oonfX00ooo003ooo]ZoookJP0MoookJP03ool50?oonf[ooo]Z01Sooo]Z
00?oo`00oookJ_oonfX05ooonfX00ooo8P3ooo]ZoookJP0JoookJP;ooa@07?oonfX00oooT`3ooo]Z
oookJP07oookJP03ool00?oonf[ooo]Z00Gooo]Z0_l0d?l01_ood`3o]ol0ooWo0?ngo`3o0=3ooook
JP?o0?n200CoR_l0o`3@ooooU`3o0=3o1ooonfX00ol0Kooooo]ZoookJP03oookJP08ool40?oonf[o
oo]ZoookJ_l0<_ooB?l0oookJ_m8o`07oookJPCoog/000?oo`40oookJ_oonfX04_oonfX01?oo203o
0=3oo`3@ool0d?l6oookJPGoB?l01ooonfX01Ol0oi3o03;ooookJ_oonf[o0?n@00;ooo]Z00Co0?n2
o`000?l0003o00000ol0oi000ooonf[o0?n@odSo0002oookJPKo0?lC0_oonfX3okOo0004olko0?ng
o`3o]ol0okOo00cooo]Z0_oo@00>oookJP04ool10?oonf[ooo]ZoomZ00Cooo]Z00?oo``0oookJ_oo
nfX04OoonfX00ooo;03o0000oookJP0>oookJP03ool30?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oo
nfX0?OoonfX00ooo103ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02Oooo]Z000BoookJP03o`00
0?oonf[ooo]Z05Cooo]Z00?oo`/0oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0GoookJP03ool0
0?oonf[ooo]Z01Sooo]Z00Coob80oookJ_oonf[oo`004?oonfX2ool/00Kooo]Z00?ooa@0oookJ_oo
nfX0;OoonfX2o`3oPP;o0=3o00[onOl0okOo0?ngo`3o0=3ookOo0?oonf[o0?n2oookJ_n:o`3o0=3o
2?oonfX00ol0Kooooo]ZoookJP03oookJP06o`3o4ooonf[ooo]ZoookJ_m8o`3o03;o1_oonfX3oomk
0005oookJ_ooN`3oog/0oookJ_oo0@004_oonfX2o`3@o`;oo`P03OoonfX00om8o`3oo`40ool10003
odSo0004oookJ_l0oi3ooo]Zo`0bo`;ooo]Z0ol00002oomH0007o`3oT?l02_oo0?n@oookJ_l0oi3o
B?l0oookJP02odSo00;ooo]Z00Co0?lCoookJ_oonf[ol?l01?oonfX5okOo00;ooo]Z00?oo`D0oook
J_oonfX01ooonfX2oom0013ooo]Z0oooJP03oookJP03ool<0?oonf[ooo]Z017ooo]Z00?oob`0oook
J_l000005ooonfX00ooo3`3ooo]ZoookJP0XoookJP03ool00?oonf[ooo]Z02cooo]Z00?o0000oook
J_oonfX09_oonfX001;ooo]Z00?o0000oookJ_oonfX0=OoonfX00ooo003ooo]ZoookJP0GoookJP03
ool00?oonf[ooo]Z00;ooo]Z00?oo`/0oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0AoookJP03
ool40?oonf[ooo]Z03;ooo]Z00?oob`0oookJ_oonfX02_oonfX2ool300Oooo]Z00?oocX0oookJ_oo
nfX03OoonfX00ooo003ooo]ZoookJP0<oookJP?o0?n20_ood`001Ongo`3o0=3oo`3@oooonf[o0=3o
00;o]ol000Go0?n2oookJ_l0d?ooR_l0o`3@o`02oookJP;oo`401?oonfX01Ol0Kooooo]ZoookJ_oo
nf[o0?lC00Cooo]Z00?oB?l0o`0boooonfX00_oonfX3oomk01Oooo]Z0ol0d?lGoookJP03odSo0?l0
oi3oB?l000?o00000ol0oi02oookJP07oomH0?l0oi3ooeP0o`3oT?oonf[oB?l0oookJP03odSo00Go
oo]Z00Gol?l0oookJ_oonf[oc_l0oookJP04okOo0003olko0?oonf[oo`D000[ooo]Z00?oo`00oook
J_oonfX01_oonfX00oooEP3ooo]ZoookJP06oookJP03oomZ0?oonf[ooo]Z01Kooo]Z00Coo`40oook
J_oonf[o00000_oonfX00ooo0@3ooo]ZoookJP0@oookJP;oo`l0:OoonfX2ool=02oooo]Z00?o0000
oookJ_oonfX09OoonfX001;ooo]Z00?o0000oookJ_oonfX0<OoonfX00ooo0@3ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z013ooo]Z00?oo`@0oookJ_oonfX06OoonfX00ooo003ooo]ZoookJP0Foook
JP03ool/0?oonf[ooo]Z00[ooo]Z00?ood/0oookJ_oonfX01OoonfX3oolj00Kooo]Z0_oo4@02oook
JP;oogD04?oonfX3o`3oPP04oooC0?ngo`3oom<0okOo00;oom<000Ko0=3oo`3oP_l0d?oo]ol0o`3o
P_l0d?l2oookJP03o`3@oooonf[ooo]Z00Oooo]Z00Co06oooookJ_oonf[o0?lC0ooonfX01_m8o`3o
oo]ZoookJ_l0<_oooo]Zoomk01;ooo]Z0_oo1`03oookJP?o0=3o2OoonfX00ooo003ooo]ZoookJP0;
oookJP03o`1_oooonf[ooo]Z00?o00001?l0oi04odSo0003o`3oT?oonf[o0?n@00;ooeP00_oonfX0
1_m8o`3ooo]ZodSo0?m8o`3ooo]Zool300?ooo]Z00?ol?l0olko0?o>o`000_oonfX00ooio`3ooo]Z
oookJP02olko01Cooo]Z00?ooeH0oookJ_oonfX08_oonfX01?l0003ooo]ZoookJ_oo0@04oookJP03
ool[0?oonf[ooo]Z02Cooo]Z00?oo`00ool40?oo1000@?oonfX00ol0003ooo]ZoookJP0UoookJP00
4_oonfX00ol0003ooo]ZoookJP0aoookJP03ool10?oonf[ooo]Z01Kooo]Z00?oo`00oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP09oookJP;oo`/0?ooonfX00ooo003ooo]ZoookJP03oookJP?ood/0
1ooonfX00ooo>P3ooo]ZoookJP05oookJP07oolA0?oonf[ooo]ZoookJ_ooM@3ooo]Zoome0002oook
JP;oo`D01OoonfX00oooC@3ooo]ZoookJP05oookJP03o`3oP_oonf[oom<000;oom<00_ngo`001Ooo
nf[o0=3oool00?l0oh;o0=3o00Cooo]Z00?o0=3ooookJ_oonfX01ooonfX00ol0Kooo0?lCoookJP03
oookJP05odSo0?oonf[ooo]ZoookJ_l0<_l05OoonfX3o`3@oa[ooo]Z0ol00003o`3oT0?ooo]Z00So
03;oo`3oT?oonf[ooo]Zo`3oT?m8o`3o0?n@odSo00?ooeP000?oB?l0oookJ_oonfX00_oonfX2ool3
00Cooo]Z00?ol?l0olko0?o`o`000_o`o`000ooonf[oo`T0ool90008oookJP03oonm0?oonf[ooo]Z
00[ooo]Z00?ooeH0oookJ_oonfX01_oonfX2ool600Oooo]Z00?oo`00oookJ_oonfX01?oonfX00ooo
5`3ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00?ooo]Z0_oo:`1BoookJP03ool50?oonf[ooo]Z
01Gooo]Z00?o0000oookJ_oonfX09?oonfX0017ooo]Z00?o0000oookJ_oonfX03?oonfX00ooo003o
oo]ZoookJP1?oookJP03o`000?oonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX06_oonfX2ool302_o
oo]Z0_ooB`07oookJP03oolj0?oonf[ooo]Z00Sooo]Z0oooM@03oookJP;oo`D01?oonfX3oom=00Oo
oo]Z00Ko0?n2okOo0?ood`3ooo]ZokOo0?oonfX2okOo0004o`3oP_l0d?oo0?n2o`3oPPCooo]Z00?o
0=3ooookJ_oonfX01ooonfX00ol0Kooooo]ZoookJP02oookJP03odSo0?oonf[ooo]Z00;ooo]Z00?o
03;ooookJ_oonfX01?oonfX2ool400Wooo]Z0ol0d?l3oookJPGoob802OoonfX2o`0:o`Oooo]Z0ol0
0003o`3oT0;ooo]Z00[o0?n@oookJ_oonf[o0?n2oookJ_l0oi3ooo]Zo`3oT?oonf[o0?n@0_oonfX0
0oooF03oB?l0oookJP05odSo0003oookJ_m8o`3ooo]Z00?ooo]Z0oo`o`001?o>o`3onOl0oo3o0?o>
o`09oookJP03oonm0?oonf[ooo]Z00[ooo]Z0_ooEP0GoookJP03oolG0?oonf[ooo]Z00_ooo]Z00Co
0000oookJ_oonf[ooo]Z0_oo:`0BoookJP07ool20?oonf[ooo]ZoookJ_oo003ooo]ZoolB001Coook
JP03o`000?oonf[ooo]Z02?ooo]Z000AoookJP03o`000?oonf[ooo]Z04Oooo]Z00?oo`40oookJ_oo
nfX05OoonfX00ol0003ooo]ZoookJP0LoookJP;oo``08_oonfX00ooo003ooo]ZoookJP0=oookJP03
oom;0?oonf[ooo]Z00Gooo]Z00?oocX0oookJ_oonfX01_oonfX00ooo0P3ooo]ZoookJP02oome00Ko
oo]Z0oooYP02oom=00Kooo]Z0_oo2@000ooonf[o0?n2oooC0002okOo0005oookJ_ngo`3o]ol0oook
J_l0oh800_oonfX4o`3oPP;ooeP02OoonfX01?l0Kooooo]ZoookJ_m8o`06oookJP03o`0boooonf[o
oo]Z00_ooo]Z0ol0d?lAoookJP?o00[o1_oonfX3o`0000;oo`P000Co0?n@oookJ_oonf[o06oo0ooo
nfX01?l0oi3ooo]Zo`3oP_oonfX2o`3oT003ool00?l0oi3ooo]Z00?ooo]Z00?oB?l0o`0:oom8o`00
0ooonfX01?oob@3oB?l0odSo0?m8o`03oookJP;ol?l000Cooo]Zoo3o0?oio`3ol?l02OoonfX00ooo
_@3ooo]ZoookJP04oookJP;oo`@01?oonfX4oomF0003ool00?oonf[ooo]Z00Gooo]Z00?ooe80oook
J_oonfX02ooonfX00ooo5`3ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z01[ooo]Z00?ooa80oook
J_oonfX0:?oonfX00ooo0@3ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z02?ooo]Z000AoookJP03
o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oo00005_oonfX00ooo503ooo]ZoookJP03oookJP03
ool<0?oonf[ooo]Z01Wooo]Z00?oo`40oookJ_oonfX05OoonfX00oooB`3ooo]ZoookJP0<oookJP;o
o`800ooonfX00oooM@3ooo]ZoookJP04oookJP;oojH000?ooo]Zoom=0?ooYP002ooonfX01_ood`3o
0?n2okOo0?l0oh;ooo]ZokOo00;o0?n@0_oo2002o`3oT0?ooeP000?o0=3oo`3oP_l0oh800_l0oh85
oookJP03o`1_oooonf[oB?l000;ooo]Z00?oo`00oookJ_oonfX00_oonfX00ol0<_oooo]ZoookJP09
oookJP03o`3@oooonf[ooo]Z00oooo]Z0ol02_l6oookJP?o00000ol0oi03oookJP04ool20?oonf[o
oo]Zo`1_o`;ooo]Z00Co0?n@o`3oP_oonf[ooo]Z0ol0oi04oookJP03odSo0?oonf[ooo]Z00KoB?l0
1?oonfX2oo3o0003oookJ_o`o`3ol?l000;ol?l02?oonfX00ooo_@3ooo]ZoookJP05oookJP;oo`@0
1_oonfX00oooEP3ooo]ZoookJP07oookJP03oomB0?oonf[ooo]Z01Wooo]Z00?oo`L0o`000?oonfX0
1?oonfX01?oo003ooo]ZoookJ_oonfX2ool502[ooo]Z00?oo`00oookJ_oonfX0>OoonfX00ol0003o
oo]ZoookJP0RoookJP004OoonfX00ol0003ooo]ZoookJP0RoookJP03ool00?oonf[ooo]Z01kooo]Z
0_oo0`0LoookJP03o`000?oonf[ooo]Z01Gooo]Z00?ooa@0oookJ_oonfX00ooonfX00ooo0@3ooo]Z
oookJP0CoookJP03ool;0?oonf[ooo]Z00?ooo]Z00?oo`40oookJ_oonfX07?oonfX00ooo003ooo]Z
oookJP0:oookJP03oome0?oonf[ooo]Z00Cooo]Z0_ooYP000oooC@3oojH0oookJP0;oookJP04oooC
0?l0oh;o0?n2o`3oPP;ooo]Z00?o0?n@oookJ_oo20000ol0oi03oomH0003o`3oT?l0d?oooo]Z00;o
oo]Z1Ol0oh800ooonf[oB?l0oookJP04olWo00Cooo]Z00?o03;ooookJ_oonfX05ooonfX3o`0:o`;o
oo]Z00Coo`H0oookJ_oonf[ooo]Z0ol00003o`3oT0Gooo]Z0_oo0P03oookJP05o`1_oooonf[o0?n@
o`3oP_oonfX00ol0oi000ol0oeCooo]ZoookJP02oookJPKoB?l00_oonfX00ooob@3ooo]ZoookJP04
oookJPCol?l00ooonfX00ooo0@3ooo]ZoookJP03oookJP05oonm0?oonf[ooo]ZoookJ_oo8P005Ooo
nfX00oooDP3ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z03?ooo]Z00?oo`L0oookJ_oonfX09_oo
nfX00ooo1`3ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02;ooo]Z000AoookJP03o`000?oonf[o
oo]Z05gooo]Z00?oo`00oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0DoookJP03oolD0?oonf[o
oo]Z01Sooo]Z00?oo`/0oookJ_oonfX0<OoonfX00oooM@3ooo]ZoookJP05oookJP;oojH02_oonfX0
0ooo1@3ooo]ZoooC0002oookJP03o`3oP_oonf[o0?n200;o0?n@00Co0?mDoookJ_oonf[ooeP01_l0
oi000ooonf[oo`40oookJP04oookJP03o`3oP_m8o`3obOl000CobOl01OoonfX00ol0<_oooo]Zoook
JP0CoookJP?o00[o1_oonfX3o`0000?obOl03_oonfX00ol0Kooo0?n2o`3oT002o`3oT004oookJ_l0
oeCooo]Zo`0bo`Gooo]Z00?oB?l0oookJ_l02_l01?oonfX2ool900Gooo]Z0oo`o`001?oio`3ooo]Z
oookJ_oo0@04oookJP03oonm0?oonf[ooo]Z00;ooo]Z0_oo8P0CoookJP03oomB0?oonf[ooo]Z00Wo
oo]Z0_oo1@06oookJP03ool00?oonf[ooo]Z00;ooo]Z00?ooad0oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP0PoookJP03ool00?oonf[ooa<004_ooo]Z00?o0000oookJ_oonfX08OoonfX0017ooo]Z
00?o0000oookJ_oonfX07ooonfX00ooo003ooo]ZoookJP0foookJP03ool30?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX04ooonfX00ooo003ooo]ZoookJP0AoookJP;ooaP08ooonfX00ooo003ooo]Z
oookJP0CoookJP03oome0?oonf[ooo]Z00Oooo]Z00?oojH0oookJ_oonfX01ooonfX00ooo1@3ooo]Z
oooC0003oookJP03o`3oP_l0oi3o0?mD00;o0?n@00?o0?mDoomH0?oonfX01?oonfX4o`3oT0Gooo]Z
00GoB?l0olWo0?o9o`3o06oooookJP03olWo00?o0?n20_oo2`0AoookJP04ool20?l02_oo00[oo`0:
o`Kooo]Z0ol000001?oonf[o0?n@o`3oT?l0oi02oookJPGobOl02OoonfX00ol0Kooo0?n2o`3oT002
oookJP;obOl00_oonfX00ol0<_oooo]ZoookJP05oookJP06o`0:oooonf[ooo]Zool00?oonf[oolT0
1_oonfX2ooWo0003oooC0?oio`3onOl000?ooo]Z0ooo_@05oookJP03oolR0?oonf[ooo]Z013ooo]Z
0oooDP09oookJP03oom50?oonf[ooo]Z00_ooo]Z0_oo7@06oookJP03o`000?oonf[ooo]Z01cooo]Z
00Coo`40oookJ_oonf[oo`000_oo4`0YoookJP03ool20?oonf[ooo]Z023ooo]Z00?o0000oookJ_oo
nfX08?oonfX0013ooo]Z00?o0000oookJ_oonfX0>OoonfX00ooo003ooo]ZoookJP0MoookJP03ool3
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP0HoookJP03oolH
0?oonf[ooo]Z00Kooo]Z0_oo0`0BoookJP03ool90?oonf[ooo]Z02Gooo]Z00?oo`40oookJ_oonfX0
2?oonfX03?ood`3ooo]Zo`3oE?l0oeCoc_l0o`3oT?o>o`3o0?mDo`3oT?ooF03o0?mDolko00Oooo]Z
0_l0oi04oookJP08olWo0?oonf[ooo]Zo`1_oooonf[obOl0oookJ_o9o`03oookJP03ool;0?l0oh;o
0?n200?o0?n20_oonfX00ooo003ooo]ZoookJP06oookJP?o00[o1_oonfX3o`000004oookJ_l0oi3o
0?n@o`3oT0[ooo]Z1Oo9o`04oookJP03o`3oP_l0Kooooo]Z00;ooo]Z00?obOl0ool80?oo20000_oo
nfX00ol0<_oooo]ZoookJP05oookJP03o`0:oooonf[ooo]Z00;ooo]Z00?oolT0oookJ_oonfX00_oo
nfX01Ooio`3ooo]ZooWo0?ood`3ooo]Z00;onOl000?ooo]Zoonm0?oo_@000_oo_@0EoookJP05ool3
0?oonf[ooo]ZoookJ_ooDP000ooonfX2ool400Gooo]Z00?oodD0oookJ_oonfX04ooonfX00ol0003o
oo]ZoookJP0>oookJP03ool80?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX08?oonfX0013ooo]Z
00?o0000oookJ_oonfX0EOoonfX00ooo1`3ooo]ZoookJP0>oookJP;o0000:_oonfX00ooo003ooo]Z
oookJP0?oookJP;ooad01OoonfX2ool902Sooo]Z00?oojH0oookJ_oonfX01_oonfX00ol0oeCoom<0
o`3oE003o`3oE007o`3oT?l0oeCoc_l0o`3oT?oonf[o0?n@olko0008oookJP04o`3oT?oonf[ooo]Z
oookJP;oo`P000?obOl0oookJ_oonfX00_o9o`001?oonf[obOl0olWo0?oonfX3oolb00Cooo]Z1Ol0
oh83oookJP?o00[o1ooonfX2o`000004oookJ_l0oi3o0?n@o`3oT1;ooo]Z1?o9o`000ol0oh;ooo]Z
o`1_o`02oookJP;obOl00ooo8P000ol0<_oooo]ZoookJP05oookJP;oc_l01?oonfX02?oob@3ooo]Z
ooo90?oob@3onOl0oookJ_oio`3oom<00_oio`001Ooonf[ookd0oookJ_oo_@3ooo]Z00;ookd03_oo
nfX00ooo=`3ooo]ZoookJP0AoookJP03oom50?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ooo1@3ooo]ZoookJP02oookJP03ool00?oonf[ooo]Z00;oo`P0:OoonfX00ooo203oo`00oook
JP0coookJP03o`000?oonf[ooo]Z01oooo]Z000@oookJP03o`000?oonf[ooo]Z03Gooo]Z00?oo`00
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP04oookJP03ool20?oonf[ooo]Z01oooo]Z00?oo`00
oookJ_oonfX02?oonfX2oolX00Kooo]Z00?ooad0oookJ_oonfX09?oonfX00ooo003ooo]ZoookJP08
oookJP03oonV0?oonf[ooo]Z00Cooo]Z0ol0oe@4oo3o0007o`3oT?o>o`3o0?n@olko0?l0oi3o0?mD
o`3oT007oookJP03o`3oT?oonf[o0=3o00;ooo]Z00Goo`P0oookJ_oonf[obOl0oookJP03olWo0003
oookJ_oo<P3ooc8000;ooo]Z00?ooc80oookJ_oonfX01ooonfX3o`3oPPOooo]Z0ol00003o`3oT1;o
oo]Z0_oo1@04oookJP03o`3oP_o9o`3obOl000GobOl00_oonfX2oolR0003o`0boooonf[ooo]Z00?o
oo]Z00Coc_l0oookJ_oonf[o00[o1?oonfX2ooo90006o`0:oooob@3onOl0ooWo0?ood`3onOl00_oo
nfX4oonm00Sooo]Z00?oo`00oookJ_oonfX01OoonfX00ooo=`3ooo]ZoookJP0@oookJP;oodD05?oo
nfX01Ooo003ooo]ZoookJ_oonf[o0000073ooo]Z00?o0000oookJ_oonfX07_oonfX0013ooo]Z00?o
0000oookJ_oonfX0<_oonfX00ooo003ooo]ZoookJP0KoookJP03ool00?oonf[ooo]Z01Kooo]Z0_oo
1`0PoookJP03ool00?oonf[ooo]Z00oooo]Z00?oobP0oookJ_oonfX01?oonfX00ooo7@3ooo]Zoook
JP0;oookJP03ool60?oonf[ooo]Z00Gooo]Z0_oo9006oookJP;oo`H04ooonfX00oooYP3ooo]Zoook
JP04oookJP03oonG0?l0oeCol?l000;o0?mD00Kol?l0o`3oT?l0oi3o0?mDolko0?l0oi02olko0003
o`3oT?o>o`3oo`D000?ooo]Z00Oo0?n@oookJ_oonf[ooo]Zo`3@oooonf[oB?l000?ooo]Z0oo9o`00
0ol0Kooooo]ZoookJP0:oookJP?o00[o1ooonfX3o`0000?o0?n@2OoonfX00ooo003ooo]ZoookJP0;
oookJP05o`3@oooonf[ooo]ZoookJ_l0oh801?oonfX7olWo0003oookJ_l0<_oooo]Z00;ooo]Z00?o
c_l0oookJ_oonfX00_oonfX01Ol02_oooo]ZoookJ_oob@3ooo]Z00?oolT000?o00[oooWo0?ood`00
0ooonfX2ool90003oonm0?oonf[ooo]Z00;ooo]Z00?ooi/0oookJ_oonfX02_oonfX2oolg017ooo]Z
00?oodD0oookJ_oonfX03?oonfX2ool300Sooo]Z0_oo7P000ol0003ooo]ZoookJP0ToookJP03ool0
0?oo0P3oo`8002Wooo]Z0_oo0`0KoookJP03o`000?oonf[ooo]Z01kooo]Z000@oookJP03o`000?oo
nf[ooo]Z04_ooo]Z00?oo`00oookJ_oonfX07?oonfX00ooo1`3ooo]ZoookJP0aoookJP03oolX0?oo
nf[ooo]Z00Wooo]Z00?oo`80oookJ_oonfX01?oonfX2oolh00Oooo]Z0_oo9006oookJP03ool60?oo
nf[ooo]Z00;ooo]Z00?ooeH0oookJ_oonfX04ooonfX3oonG00?ol?l00_l0oi001?oonf[ol?l0o`3o
E?l0oi02o`3oE003oookJ_l0oi3oc_l000;oc_l000?o0?n@oookJ_oonfX00ooonfX00om8o`3ooo]Z
oookJP02oookJP;obOl00_oonfX00ol0Kooooo]ZoookJP06oookJP?o00[o1ooonfX3o`0000?o0?n@
3_oonfX00ol0<_ooK?l0ofco0002ofco00Oooo]Z00Co0=3ooookJ_oonf[o0?n21?oonfX00ol0oeCo
bOl0olWo0002oookJPCobOl000Cooo]Zo`0boooonf[oc_l01OoonfX00ooo1`3ooo]Zooo90005ooo9
00;ooo]Z00?oom<0ool10?oo0@002?oonfX00oooV`3ooo]ZoookJP0:oookJP;oocL05ooonfX00ooo
2`3ooo]ZoookJP0AoookJP03oolN0?l0003ooo]Z01Kooo]Z00?oo``0oookJ_oonfX03?oonfX00ooo
003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z01gooo]Z000@oookJP03o`000?oonf[ooo]Z06Co
oo]Z0_oo3005oookJP03o`000?oonf[ooo]Z01Oooo]Z00?oo`40oookJ_oonfX08_oonfX00ooo0P3o
oo]ZoookJP04oookJP;oocP01ooonfX00ooo903ooo]ZoookJP09oookJP?ooeH02OoonfX00ooo:@3o
oo]ZoookJP07oookJPGooiL00_o`o`002?oo003o0?n@oookJ_o`o`3ooo]Zo`3oE?l0oi3ooo]Z0_l0
oe@00ol0oi3o0?mDo`3oT002olko00Cooo]Z00?o0=3ooookJ_oonfX00_oonfX00oo9o`3ooo]Zoook
JP02oookJP03o`1_oooonf[ooo]Z00;ooo]Z0ol02_l7oookJP?o000000?o0?n@ool;0?l0oi000ooo
nfX2ool500Wooo]Z0ol0<_l8ofco00Gooo]Z00?o0=3ooookJ_l0oh801?oonfX00ol0oeCobOl0olWo
0004olWo00?ooo]Z00?oc_l0o`0boooonfX00ooonfX01?ooN`3oo`L0ool70?l02_l2oookJP04o`0:
oooob@3oolT0ooo900;ooo]Z00Coom<0oookJ_l02_oo00[o1_oonfX00oooV`3ooo]ZoookJP0<oook
JP03oolg0?oonf[ooo]Z00kooo]Z0_oo0@05oookJP;oo`/05?oonfX00ol0003ooo]ZoookJP0Boook
JP03ool00?oonf[oo``002Wooo]Z00?oo`T0ool00?oonfX0;OoonfX00ol0003ooo]ZoookJP0Loook
JP003ooonfX00ol0003ooo]ZoookJP0=oookJP03ool00?oonf[ooo]Z03Sooo]Z00?oo`00oookJ_oo
nfX07OoonfX00ooo0@3ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z013ooo]Z00?oo`H0oookJ_oo
nfX08?oonfX00ooo003ooo]ZoookJP0=oookJP03oolh0?oonf[ooo]Z00Sooo]Z0_ooD@08oookJP;o
oeH00_oonfX2ool900?ooo]Z00?oohH0oolY0?oo:@001ooonfX01_oo0@3ooo]ZoookJ_oonf[ooiL0
oookJPCol?l000Kooo]Zo`3oT?l0oi3o00[oo`3oE?l0oi04oookJP03o`3oT?oonf[o0?mD00Co0?mD
0_oonfX01?l0d?oooo]ZoookJ_o9o`06oookJP04o`1_ool02_oo00[oo`0:o`;ooo]Z00?oo`P0oook
J_oonfX00_oonfX3o`0000?o0?n@3_oonfX3o`0bo`?ooo]Z00CoK?l0oookJ_oonf[oK?l00_oonfX4
ofco00Cooo]Z00?o0=3ooookJ_oonfX00_oonfX00ol0oeCooo]ZoookJP02olWo0003ool30?oonf[o
oo]Z00;ooo]Z00Coc_l0oookJ_oonf[o03;o0ooonfX01?ooN`3ooo]ZoookJ_oonfX2o`0:o`Cooo]Z
00Co00[ooookJ_ood`3oom<00_oonfX2o`0:o`Cooo]Z00?ooi/0oookJ_oonfX03ooonfX00ooo003o
oo]ZoookJP02oookJP;oo`T000?oocX0oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP04oookJP03
oolM0?oonf[ooo]Z00Kooo]Z00?oo`@0oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0LoookJP00
3ooonfX00ol0003ooo]ZoookJP14oookJP03ool20?oonf[ooo]Z01cooo]Z00?oo`00oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP09oookJP03ool>0?oonf[ooo]Z01oooo]Z00?oo`00oookJ_oonfX0
5OoonfX00ooo>03ooo]ZoookJP07oookJP?ooe400ooonfX00ooo1@3ooo]ZoookJP02oookJP03oomF
0?oonf[ooo]Z00Gooo]Z00CoohH0oolY0?oonf[oohH02_oonfX02OooU`3ooo]ZoookJ_oonf[ol?l0
o`3oE?o`o`3o0?mDo`0:o`02o`3oT007oookJ_l0oi3ooo]ZoookJ_l0oi3ooo]Zo`3oT005oookJP?o
0?mD00Go0=3oo`3oE?o9o`3ooo]Zool30002oookJP?o00[o00?o06oooookJ_oonfX01?oonfX3o`00
00;ooo]Z00?o0?n@oookJ_oonfX03?oonfX3o`0bo`Kooo]Z00GoK?l0oookJ_oonf[oK?l0oookJP03
ofco00;oo`d000Ko0?n2oookJ_oonf[ooo]Zo`3oP_l0d?l3oookJP03o`3oE?oonf[ooo]Z00;ooo]Z
00Go0?lCoookJ_oonf[ooo]Zolko0003oookJP03o`0boooonf[ooo]Z00;ooo]Z00?oog/0oookJ_oo
nfX00_l02_l4oookJP05o`0:ooood`3oom<0oookJ_ood`000ooonfX2o`0:o`03oookJ_ooV`3ooo]Z
00Oooo]Z00Goo`P0oookJ_oonf[ooo]ZoomZ000<oookJP03oolj0?oonf[ooo]Z02?ooo]Z00?o0000
oookJ_oo0@000_oonfX2oolM02Sooo]Z00?oo`<0oookJ_oonfX09ooonfX00ooo103ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01_ooo]Z000?oookJP03o`000?oonf[ooo]Z02;ooo]Z00?oo`00oook
J_oonfX07ooonfX00ooo0P3ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00Sooo]Z00?oo`h0oook
J_oonfX06OoonfX00ooo1@3ooo]ZoookJP0UoookJP?ooe400ooonfX00ooo1@3ooo]ZoookJP02oook
JP03oomF0?oonf[ooo]Z00Gooo]Z00CoohH0oolY0?ooQP3oohH02ooonfX02_ooU`3ooo]ZoookJ_l0
2_ool?l0o`3oE?o`o`3ooo]Zo`3oE?oonfX2o`3oT005oookJ_l0oi3ooo]ZoookJ_l0oi001ooonfX2
olko0004olWo0?l0oeCo0?mDool300;o0?mD1?oonfX00ol0Kooooo]ZoookJP03o`00017ooo]Z0ol0
<_l:oookJPCoK?l00_oonfX2ofco00;oo`d000?o0?n2ool00?n:o`000_oonfX00ol0d?oooo]Zo`3o
E003oookJP;oc_l000Co0?lCo`1_oooonf[oc_l01OoonfX00ol0<_oooo]ZoookJP02oookJP05oomk
0?l02_oooo]ZoookJ_l02_l00ooonfX00oood`3o00[ooooC0002oookJP07oooC0?oonf[ooo]Zoook
J_ooV`3o00[ooonK0003oookJP;oo``00_oonfX2ool800;ooo]Z00?oofX0oookJ_oonfX02_oonfX2
oolj01Sooo]Z00?ooa40oookJ_oonfX01ooonfX2ool20003oookJ_l0003ooo]Z01gooo]Z00?oo`d0
oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01_ooo]Z000?oook
JP03o`000?oonf[ooo]Z05kooo]Z00?oo`00oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0=oook
JP03ool20?oonf[ooo]Z00cooo]Z00?oo`l0oookJ_oonfX00ooonfX2ool502Cooo]Z0_oo0@04oook
JP03oomA0?oonf[ooo]Z00Kooo]Z00?ooeH0oookJ_oonfX01_oonfX2oon600_ooo]Z00OooiL0oook
J_oonf[o00[ooookJ_l02_oo0?mD00?oo``00_oo8P000ol0oi3ooo]ZoookJP02oookJP03o`3oT?oo
nf[oo`0000Kooo]Z00?obOl0o`3@ool02_l00ooonfX4o`3oE0?o00004OoonfX3o`0bo`Oooo]Z0ooo
30002?oonf[oK?l0oonK0?m/o`3ooi/0oookJ_m/o`3ooo]Z0_m/o`001?oonf[oR_l0oh[o0?n:o`02
o`3oPP?ooo]Z00Oo0=3oo`3oE?oonf[ooo]Zolko0?oonf[o0?lC00;ooo]Z00?o06oooookJ_oonfX0
1OoonfX02ol0<_oooo]ZoookJ_oonf[o00[ooomk0?oonf[oog/0oookJ_l02_oooo]Z00;oom<000Go
00[ooonG0?oonf[oom<0ool50002oookJP?ooi/01OoonfX00ooo303ooo]ZoookJP03oookJP03oomZ
0?oonf[ooo]Z00_ooo]Z0_oo>P0:oookJP03oolc0?oonf[ooo]Z00Gooo]Z00?oo`00oookJ_oonfX0
0ooonfX00ooo4@3ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Wooo]Z00?oo`00ool=0?oo3@00
:OoonfX00ooo0@3ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01[ooo]Z000?oookJP03o`000?oo
nf[ooo]Z023ooo]Z00?oo`00oookJ_oonfX0=_oonfX00ooo0@3ooo]ZoookJP0EoookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX03?oonfX00ooo5`3ooo]ZoookJP03oookJP03ool?0?oo
nf[ooo]Z02;ooo]Z00?oo`00oookJ_oonfX02ooonfX00oooD@3ooo]ZoookJP0@oookJP03oon60?oo
nf[ooo]Z00Sooo]Z00GooiL0oookJ_l02_oooo]Zo`0:o`03oookJP04oo3o0?oio`3oob80oolR00;o
0?lC1?oonfX00ol0oi3ooo]ZoookJP02oookJP;o00[o00CobOl0oookJ_oonf[o0=3o1?oonfX3o`00
0003oookJ_l0oeCo0?mD00?o0?mD2ooonfX2o`0bo`03ool80?oonf[ooo]Z00Wooo]Z0om/o`02oook
JP03ofco0?oonf[ooi/000?oK?l000Cooi/0oh[o0?l0oh;ooo]Z0_ooV`002ol0oh;ooo]ZoookJ_oo
nf[o0?mDo`3@oooonf[oc_l0oookJ_o>o`3o0?lC00;oc_l000?o06oooookJ_oonfX01_oonfX01Ol0
<_oooo]Zool00?l02_oooo]Z00?oog/000Oo00[ooookJ_oonf[ooo]ZoooC0?ooU`3oom<000Cooo]Z
1?ooV`08oookJP;oofX06_oonfX00ooo<`3ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z01Sooo]Z
00?oo`00oookJ_oonfX0:OoonfX00ooo0@3ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01Wooo]Z
000?oookJP03o`000?oonf[ooo]Z03Sooo]Z00?oo`00oookJ_oonfX06_oonfX00ooo103ooo]Zoook
JP0JoookJP03o`000?oonf[oo`0001?ooo]Z0_oo5`0RoookJP03ool30?oonf[ooo]Z02Oooo]Z00?o
ohH0oookJ_oonfX00_oonfX2oonC00;oo`X000Cooo]ZoonG0?l02_oooo]Z0_l02_l2oookJP;onOl0
00?oob80o`3o4ooio`000ol0oa<4oookJP04o`3oT?l02_oo00[oo`0:o`;ooo]Z00GobOl0oookJ_oo
nf[ooo]Zo`3@o`03o`0000Wooo]Z1Ol0oe@3oookJP?o03;o00?ooo]Zool80?oo20002?oonfX3ofco
00Gooo]Z00?oK?l0oookJ_l0oh800_m/o`02oookJPKooi/000ko0?n2oookJ_oonf[o0?mDoookJ_l0
d?ooc_l0oookJ_l0oa?oc_l0oookJ_o>o`3ooo]Zo`1_o`Oooo]Z0_oio`000ooo003ooo]Zoomk0003
oomk0003oookJ_l0<_oo03;o00;ooo]Z00?ooiL0oookJ_oonfX00ooonfX00ol02_oooi/0oonK0008
oookJP?oofX04ooonfX00ooo003ooo]ZoookJP02oookJP;ooc<00_oo200LoookJP03o`000?oonf[o
oo]Z00Kooo]Z0_oo100<oookJP03ool20?oonf[ooo]Z01_ooo]Z00?oo`D0oookJ_oonfX09OoonfX2
ool5013ooo]Z00?o0000oookJ_oonfX06OoonfX000oooo]Z00?o0000oookJ_oonfX0LooonfX00ol0
003ooo]ZoookJP0CoookJP03oolG0?oonf[ooo]Z00cooo]Z0_oo1@0:oookJP;ooa401_oonfX00ooo
0`3ooo]ZoookJP0UoookJP04ool50?oonf[ooo]Zoon600?ooo]Z00_ooi<0oookJ_ooT`3ooi<0oook
J_ooU`3ooo]Zo`0:oooonf[o00[ooookJP07o`3o4`04ooWo0?l0oa?ooo]ZoookJP?o00[o00?o0?n@
oookJ_oonfX00_oonfX00oo9o`3ooo]Zo`000002o`000003o`3@oooonf[ooo]Z00_ooo]Z00?oo`40
oookJ_oonfX00ol0oe@:oookJP04oh[o0?m/o`3oK?l0ofco00Oooo]Z0_n:o`02ofco00Gooo]Z00?o
0?n2oonK0?ooV`000oooV`001Ol0oh;o0?mDoookJ_oonf[o0=3o00;oc_l000Co0?lCool=0?oo3@3o
o`D00_oonfX00ol0Kooooo]ZoookJP03oookJP03ooWo0?oonf[o03;o00Cooo]Z0_ooN`000ooonf[o
03;oo`0:o`02o`0bo`03oonG0?l02_oooo]Z00;ooo]Z00?o00[ooookJ_l02_l02OoonfX2oomZ00Ko
oo]Z00?ooa`0oookJ_oonfX00_oonfX2ool600cooo]Z0_oo<`0HoookJP03oolD0?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP0LoookJP03ool>0?oonf[ooo]Z00go
oo]Z00?oo`00oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0HoookJP003_oonfX00ol0003ooo]Z
oookJP0foookJP03ool00?oonf[ooo]Z03Oooo]Z00?oo`00oookJ_oonfX00_oonfX00ol0003ooo]Z
oookJP0JoookJP;oo`802_oonfX2oolM00Kooo]Z00?ooa40oookJ_oonfX08ooonfX00ooo003ooo]Z
oookJP0:oookJP06oon60?oonf[ooo]ZoookJ_ooT`3ooo]Z0_ooT`02o`0:o`;ooo]Z1?l0oa<3ooWo
0004oo3o0?l0oa?onOl0o`3o4`;o00[o1?oonfX00ol0oi3ooo]ZoookJP03o`0000Cooo]Z00Co0=3o
oookJ_oo203oo`P01?oonfX2olko00?ooo]Z0ol0<_l;oookJP?oK?l000?oR_l0oookJ_oonfX01?oo
nfX3oh[o00;ooo]Z00?oK?l0o`3oP_oonfX01?oonfX01?l0oh;oo`/0oonK0?ooV`03oookJP06o`3o
E?oonf[ooo]ZoookJ_l0d?oo0?lC1Oo>o`02oookJP09o`1_oooonf[ooo]ZoookJ_oio`3ooo]Zo`0:
oooonf[o03;o00Gooo]Z00Oo03;ooookJ_l0<_oo00[ooookJ_ooU`3o03;o00;ooo]Z00Co00[ooook
J_oonf[o00[o0ooonfX00oooM03ooo]ZoookJP02oookJP03ool20?oonf[ooo]Z00Kooo]Z00?ooa`0
oookJ_oonfX07?oonfX00ooo:`3ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z00;ooa@01_oonfX0
0ol0003ooo]ZoookJP0PoookJP03ool00?oonf[ooo]Z02Sooo]Z00?oo`80oookJ_oonfX07OoonfX3
o`0001Wooo]Z000>oookJP03o`000?oonf[ooo]Z03?ooo]Z00?oo`00oookJ_oonfX06_oonfX00ooo
003ooo]ZoookJP0GoookJP;oo`<02_oonfX00ol0003ooo]ZoookJP0CoookJP03ool00?oonf[ooo]Z
013ooo]Z00?ooad0oookJ_oonfX06_oonfX00ooo4@3ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z
01Oooo]Z00?ooi<0oookJ_l02_l00_ooT`000ooonf[o0?lCo`3o4`02o`3o4`;ooo]Z0_oio`000ol0
2_ool?l0o`3o4`03ooWo00Cooo]Z0ol00002ool>00Kooo]Z00?o0=3ooookJ_oonfX00_oonfX4olko
00?o03;o2ooonfX3ofco00;oR_l00_oonfX00on:o`3ooo]ZoookJP03oh[o00?ooo]Z0_l0Kol00ooo
nf[o0?n2o`3oPP03oookJP05o`3oP_oonf[oo`/0ool;0?l0oi000_oonfX00ol0oeCooo]Zo`3oPP02
oookJP03olko0?l0d?ooc_l000;oc_l01OoonfX01Ol0Kooooo]ZooWo0?oonf[o00[o00?ooo]Z00Go
03;ooookJ_oonf[ooo]Zo`0bo`02oookJP08o`0booooT`3ooi<0oonG0?l02_oo03;ooookJ_l02_l2
oookJP05o`0:oooonf[ooo]ZoookJ_ooM0001?oonfX00ooo0P3ooo]ZoookJP06oookJP03oolL0?oo
nf[ooo]Z01_ooo]Z00?oob/0oookJ_oonfX04_oonfX2ool80003o`000?oonf[ooo]Z01kooo]Z00?o
o`00oookJ_oonfX0:OoonfX00ooo0P3ooo]ZoookJP0JoookJP?o00000_oonfX00ol0003ooo]Zoook
JP0GoookJP003_oonfX00ol0003ooo]ZoookJP1@oookJP03ool00?oonf[ooo]Z01?ooo]Z00?oo`P0
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0BoookJP03ool00?oonf[ooo]Z02?ooo]Z0_oo2@00
0ooo9P3ooo]ZoookJP05oookJP03oolA0?oonf[ooo]Z023ooo]Z0_l02_l2oookJP;ooi<000?ooo]Z
o`3o4ooonfX01_l0oa<2ool;00;ooo]Z00ConOl0o`000?l0003o00000_oonfX00oo9o`3ooo]Zoook
JP07oookJP03o`3@oooonf[ooo]Z00;oc_l00ol0<_l;oookJP?oK?l00_oonfX3oh[o00;ooo]Z0on:
o`03oookJP03o`1_oooo1P3o06oo00Cooo]Z0_l0oh82oookJP03o`3oP_oonf[o0?n200;ooo]Z00Co
0?n@oookJ_l0oeCooo]Z0_l0oh801?oonf[o0?lCoookJ_l0d?l7oookJP03ooWo0?l0Kooooo]Z00?o
00[o0ooonfX00ol0<_oooo]Zo`0bo`03oookJP03o`0boooonf[ooiL000;ooiL000Goo`00o`0:oooo
3P3ooo]Zo`0:o`03oookJP03oomd0?oonf[ooo]Z02Gooo]Z00Coo`<0oookJ_oonf[ooo]Z0_oo:`03
oookJP;oo`L04_oonfX00ol0003ooo]ZoookJP0=oookJP03ool60?oonf[ooo]Z00cooo]Z00?oo`40
oookJ_oonfX06?oonfX00ooo1P3ooo]ZoookJP0YoookJP?o00001OoonfX00ol0003ooo]ZoookJP0G
oookJP003_oonfX00ol0003ooo]ZoookJP1<oookJP03ool00?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX02ooonfX00ooo003ooo]ZoookJP0RoookJP03ool50?oo:`3ooo]Z00Gooo]Z00?oo`T0oolV
0?oonfX01_oonfX00ooo4@3ooo]ZoookJP0:oookJP03oolg0?oonf[ooo]Z01;ooo]Z0_l02_l4oook
JP;oo`@00ooob@03o`0bo`04o`3o4ol0<_oo0?lCoo3o00?o000000Cooo]ZooWo0?oio`3onOl00_oo
nfX00ol0oi3ooo]ZoookJP07oookJP04o`3@ool0<_oo03;oo`0bo`_oc_l00om/o`06olko0005ool0
0?n:o`3oc_l0olko0?n:o`000_oonfX3o`1_o`Oooo]Z00Co0?n2oookJ_l0oh;ooo]Z0_l0oh82o`3o
E0;ooo]Z00?o0?n@o`3oP_l0oh800ooonfX01?l0oa?ooo]ZoookJ_l0d?l5oookJP03ooWo0?oonf[o
06oo00?ooo]Z0_l02_l01?oo3@3o00[ooookJ_l0<_l2oookJP;ooi<000Oooo]ZoonG0?oonf[ooiL0
oookJ_ooU`3ooo]Z00;oo`h000Go03;ooookJ_oonf[ooo]Zoomd000IoookJP03oolT0?oonf[ooo]Z
00Cooo]Z00?oo`@0oookJ_oonfX08OoonfX00ol0003ooa@0oookJP0;oookJP03ool00?oonf[ooo]Z
02_ooo]Z00?oo`00oookJ_oonfX09?oonfX3o`0000Sooo]Z00?o0000oookJ_oonfX05ooonfX000ko
oo]Z00?o0000oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP0ioookJP03ool00?oonf[ooo]Z02ko
oo]Z00?o0000ool80?oonfX01?oonfX00ooo0`3ooo]ZoookJP0QoookJP03ool10?oonf[ooo]Z00Co
oo]Z00?oo`D0ool[0?oonfX01_oonfX00ooo9P3ooo]ZoookJP0BoookJP;oocL04OoonfX01Ooo003o
oo]Zo`0:oooonf[ooeP000;ooo]Z0_l02_l00ooob@3ooi<0ooo90002ooo90003o`3o4ooonf[o0?lC
00?o00000ooonfX6o`3o4`04oookJ_ooV`3ooi/0oonK00Cooo]Z0ol0<_l00ol0d?oooo]Zolko0003
olko00Kooo]Z0_m/o`02oookJP;ooa000ooonfX3oh[o0003oookJ_n:o`3ooo]Z00?o06oo2ooonfX0
0ol0oh;ooo]Zo`3oPP02o`3oE006oookJ_l0oeCo0?mDo`3oP_l0oeCo0?n@0ooonfX00ol0oa?ooo]Z
oookJP02oookJP05odSo0?oio`3ooo]ZoookJ_oio`000ooonfX00ol0Kooooo]ZoookJP02oookJP;o
o`d000Co03;oo`0:ool0<_oooi<00ooonfX01_l0<_oooiL0oonG0?ooU`3ooo]Zo`0:o`;ooo]Z00Co
00[oo`0booooM03oog@03?oonfX00oooDP3ooo]ZoookJP0:oookJP;oob@01_oonfX00ooo103ooo]Z
oookJP0NoookJP05ool00?oonf[ooo]ZoolD0?l00000:?oonfX00ooo0@3ooo]ZoookJP0WoookJP03
ool20?oonf[ooo]Z00Sooo]Z1?l0000;oookJP03o`000?oonf[ooo]Z01Oooo]Z000>oookJP03o`00
0?oonf[ooo]Z04Cooo]Z00?oo`00oookJ_oonfX08?oonfX2ool200cooo]Z00?oo`h0oookJ_oonfX0
0_oonfX00ooo203ooo]ZoookJP0PoookJP03ool00?oonf[ooo]Z00?ooo]Z00?oo`40oookJ_oonfX0
1ooonfX00ooo:`3ooo]ZoookJP0@oookJP;oocd01ooonfX01?oo=`3ooo]ZoookJ_oonfX2ool>00Co
oo]Z00?oo`h0oomS0?ooH`001ooonfX00ol02_oooo]ZoomH0002oomH0003o`0:oooonf[ooo]Z00;o
olT000?o00[ooookJ_oob@000ol000000ooonf[o0?lCo`0:o`09oookJP;ooi/000Co0?n@oonK0?l0
oa?o0?lC0_l0<_l4oookJP03o`3@oooonf[ooo]Z00;oo`l03_oonfX4oh[o00?o06oo0_n:o`0<oook
JP09o`3oP_oonf[o0?mDo`3oP_oonf[o0?n2o`3oE?ngo`3o0?mD00;ooo]Z00Co0?n@oookJ_oonf[o
0?lC0ooonfX00ooio`3oo`T0ool90002ooWo00Gooo]Z00?o06oooookJ_oonfX00_oonfX2oolb0003
oonC0?l0<_oo00[o00?o00[o00?ooo]Zo`0booooU`000ol02_l2oookJP03o`0:ooooM03oog@000;o
og@02ooonfX00oooDP3ooo]ZoookJP03oookJP03ool00?oonf[ooo]Z00Cooo]Z0_oo900WoookJP03
ool00?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01?oonfX2ool701oooo]Z00?oo`40oookJ_oo
nfX05_oonfX00ooo1`3ooo]ZoookJP0>oookJP03ool20?oonf[ooo]Z00Gooo]Z0ol0000@oookJP03
o`000?oonf[ooo]Z01Kooo]Z000=oookJP03o`000?oonf[ooo]Z06?ooo]Z0_oo000AoookJP03ool>
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX06?oonfX00ooo0@3ooo]ZoookJP0WoookJP03oolm
0?oonf[oocd000Oooo]Z00CoocL0oookJ_oo3P3oo`h01?oonfX00ooo3P3ooo]ZoomS0002oomS00Go
oo]Z1?l02_l00oooF03ooo]ZoookJP02oookJP;oolT00ol000002?oonf[o0?lCo`3o4ol0oa?o03;o
oookJ_l02_oooo]Z1_m/o`02oookJP?ooi/00_oo2`06o`3o4`?ooo]Z00?oo`l0olko0?oonfX03_oo
nfX3o`1_o`?oR_l03_oonfX2o`3oE0;o0?n20_ngo`02ool200;o0?mD0_oonfX00ol0oi3o0?lCoook
JP02oookJP05ooWo0?m8o`3onOl0ooWo0?l0d?l01ooonfX01?l0Kooooo]ZoookJ_oonfX2oolb00;o
00[o0_l0Kol2oookJP03o`0:ool0<_oo00[o00;ooo]Z0_l02_l00ooonf[o03;ooookJP02oomd00Co
oo]Z00?oo`40oookJ_oonfX00_oonfX00oooDP3ooo]ZoomB000VoookJP;oo`P05?oonfX00ol0003o
oo]ZoookJP04oookJP03ool70?oonf[ooo]Z00cooo]Z0_oo200>oookJP03ool00?oonf[ooo]Z01Oo
oo]Z00?oo`L0oookJ_oonfX04ooonfX3o`0001?ooo]Z00?o0000oookJ_oonfX05_oonfX000gooo]Z
00?o0000oookJ_oonfX08_oonfX2ool003_ooo]Z00?oo`00oookJ_oonfX06ooonfX00ol0003ooo]Z
oookJP0@oookJP03ool80?oonf[ooo]Z00Cooo]Z00?oo`40oookJ_oonfX0:_oonfX2ool:00Gooo]Z
00?oocL0oookJ_oonfX01_oonfX3oomS00Gooo]Z1_l02_l00oooF03ooo]ZoookJP03o`0000;oolT0
0ooonfX2o`3o4`05oookJ_l0<_oo00[ooookJ_m/o`000_oo0@05ofco0004o`0booooV`3o0?n@ool;
00Oooo]Z1Ol0oa<<oookJP?o06oo3ooonfX3oolM0003oookJ_l0oeCooo]Z00?o]ol000Co0?n2o`3o
E?oonf[o0?mD0_oonfX01?l0oeCooo]ZoookJ_l0oi03oookJP05ooWo0?m8o`3onOl0oookJ_l0d?l0
2?oonfX00ol0Kooooo]Zo`0bo`04oonC0007o`1_ool0<_oo06ooo`1_oooonf[o00[ooomH0004o`0:
o`;o03;o2_oonfX3ool=0003oomB0?oonf[ooo]Z01Oooo]Z00?oob<0oookJ_oonfX05_oonfX00ooo
103ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00?ooo]Z0_oo4`0=oookJP03ool00?oonf[ooo]Z
00kooo]Z00?oo`00oookJ_oonfX06OoonfX00ooo003ooo]ZoookJP0>oookJP?o00005_oonfX00ol0
003ooo]ZoookJP0FoookJP003OoonfX00ol0003ooo]ZoookJP0PoookJP03ool00?oonf[ooo]Z03Oo
oo]Z00?oo`00oookJ_oonfX08OoonfX01?l0003ooo]Zool50?oo1@08oookJP03ool@0?oonf[ooo]Z
00?ooo]Z00?oo`P0oookJ_oonfX08_oonfX00ooo003ooo]ZoookJP04oookJP;oo`D03ooonfX2oom;
00Sooo]Z00?oof<0oookJ_oonfX01OoonfX3o`0:o`?o000000Oo03;oo`0:ool0<_oo03;oo`0:oooo
b@3oo`D000;o00[o00Go0?lCoookJ_l0<_oo00[ooookJP02ofco0004oookJ_m/o`3o03;oo`0bo`?o
K?l00_oo_@001?l0oi3ookd0oonm0?oo_@09oookJPKo0?lC0ooonfX3o`1_o`gooo]Z0ooo4P04oook
JP04oolM0?ngo`3o0?mDokOo00Cooo]Z00?o0?mDoookJ_l0oe@00ooonfX01?l0oeCo0?lCoookJ_l0
oi02oookJP03odSo0?oio`3ooo]Z00;onOl000?o0=3ooookJ_oonfX01OoonfX2oooC00Cooo]Z00Go
06oooookJ_l0Kooo03;ooookJP02o`1_o`03oomH0?l02_oo00[o00;oo`/000?o00[oo`0boooonfX0
2ooonfX00oooDP3ooo]ZoookJP0:oookJP;ooc/02ooonfX2oolS00Sooo]Z00?oo`40oookJ_oonfX0
6OoonfX01?l0003ooo]ZoookJ_oo0@0[oookJP03ool30?oonf[ooo]Z01cooo]Z1?l00006oookJP03
ool30?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX05_oonfX000gooo]Z00?o0000oookJ_oonfX0
E_oonfX00ooo0P3ooo]ZoookJP0RoookJP05ool10?oonf[ooo]ZoookJ_l000002ooonfX00ooo403o
oo]ZoookJP0OoookJP03ool00?oonf[ooo]Z00Gooo]Z00?oo`00oookJ_oonfX05OoonfX00oooB`3o
oo]Zoom;0008oookJP03oomS0?oonf[ooo]Z00Cooo]Z0ol000002_ooF03o00[oo`0boooonf[o03;o
oookJ_l0<_oooo]Zo`0:oooob@02oookJP03o`0:ooood`3oom<000;o00[o0om/o`05oookJP05oonK
0?m/o`3ookd0oookJ_l0oi000_oonfX5oonm00[ooo]Z0ol0oa<4oookJP03oolA0?oonf[ooo]Z00Ko
oo]Z00Co]ol0oookJ_oonf[ooa801?oonfX3okOo00;ooo]Z00?o0?mDoookJ_oonfX00_oonfX2o`3o
E0Gooo]Z00?o0?lCoookJ_l0oi000_oonfX01om8o`3onOl0ooWo0?oonf[onOl0oookJ_l0d?l01Ooo
nfX00oood`3o03;oo`1_o`02ool60006oookJ_l0Kooooo]ZoookJ_l0Kooooo]Z0ol02_l01_ooF03o
oo]ZoookJ_l0<_oooo]Zo`0boaSooo]Z0_oo>`08oookJP03ool00?oonf[ooo]Z00;ooo]Z00?oob<0
oookJ_oonfX05ooonfX00ooo2`3ooo]ZoookJP0:oookJP03o`000?oonf[oo`4001[ooo]Z0_oo2@0[
oookJP?o00007OoonfX00ol0003ooo]ZoookJP0FoookJP003OoonfX00ol0003ooo]ZoookJP0ioook
JP03ool00?oonf[ooo]Z03Wooo]Z00?oo`00oookJ_oonfX02?oonfX2o`0001gooo]Z00?ooa<0oook
J_oonfX01?oonfX00ooo203ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z023ooo]Z00?ood/0oook
J_oonfX01_oonfX00oooH`3ooo]ZoookJP03o`0000;ooa0000?oogD0oookJ_oonfX00_l0<_l2o`0:
o`05oookJ_l0<_oo00[ooookJ_oob@001Oood`000om8o`3oK?l0oookJP02ofco00?ooo]Z00?ooi/0
oookJ_m/o`000ooonfX00ol0oi3ooo]ZoookJP04oookJP?ookd00_oonfX00ooio`3oo`T0ool90002
o`1_o`Kooo]Z0ooo4@06oookJP;o]ol01?oonfX3okOo00Gooo]Z0_l0oe@2oookJP03o`3oE?oonf[o
0?mD00;ooo]Z00?oojH0oookJ_l0oa<00_l0oe@01?oonf[o0?n@odSo0?ooYP02oookJP05ool00?oo
nf[ooo]ZoookJ_l0d?l00ooonfX01oood`3o03;ooookJ_oonf[o06oooookJ_l0Kol00ooonfX01Ol0
Kooooo]ZoookJ_l0<_oooo]Z00;ooeP000Co03;ooookJ_oonf[o03;o4ooonfX2ool900?ooo]Z0_oo
>`0?oookJP;oo`d01ooonfX00ooo7P3ooo]ZoookJP0;oookJP;oo`/03OoonfX00ol0003ooo]Zoook
JP0<oookJP03ool50?oonf[ooo]Z00[ooo]Z00?oo`T0oookJ_oonfX03_oonfX00ooo003ooo]Zoook
JP0FoookJP?o00008?oonfX00ol0003ooo]ZoookJP0FoookJP003OoonfX00ol0003ooo]ZoookJP0e
oookJP03ool00?oonf[ooo]Z03?ooo]Z00?oo`40oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?ooaP0ool90?oo2@001?oonfX00ooo4`3ooo]ZoookJP04
oookJP03ool80?oonf[ooo]Z02Sooo]Z00Cood/0oookJ_oonf[ooo]Z0_oo2`02oookJP?o00000ooo
nfX2oome0004oookJ_ooM@3oogD0o`0bo`?ooo]Z00Ko00[oo`0bool02_oooo]Zo`0:oooob@02oooC
00;oB?l000Kooo]Zofco0?m/o`3oK?l0odSo0?m/o`02oookJP03oonK0?m/o`3ooo]Z00Cooo]Z00?o
0?n@oookJ_oo00001_oonfX01?oio`3o06ooo`1_oooo2@0AoookJP;o]ol000?ooo]ZokOo0?ngo`00
0_ngo`09oookJP;o0?mD00Wooo]Zo`3oE?l0oeCooo]Zofco0?l0oa?oojH0o`3oE?l0oa<00oooYP00
1?oonf[o0?n@oookJ_oo4`06oookJP03o`3@oooonf[oom<000?o03;o0_oonfX00ol0Kooooo]Zoook
JP03oookJP03o`1_oooonf[oogD000CooeP00_l0Kol00ol0<_oooo]ZoookJP04oookJP03oom=0?oo
nf[ooo]Z013ooo]Z0_oo300FoookJP;ooah06OoonfX2ool20003oookJ_l0003ooo]Z01Wooo]Z0_oo
000VoookJP?o000000?ooo]Zool00?oonfX08?oonfX00ol0003ooo]ZoookJP0FoookJP003?oonfX0
0ol0003ooo]ZoookJP0coookJP03ool00?oonf[ooo]Z037ooo]Z00Goo`D0oookJ_oonf[ooo]Zool1
000HoookJP03o`000?oonf[ooo]Z00cooo]Z0_oo1005oookJP03ool90?oonf[ooo]Z02Sooo]Z00?o
o`00oookJ_oonfX01OoonfX2ool300Sooo]Z0ol00009oookJP;o03;o0_ooM@03oookJP;o03;o00Co
00[oo`0boooonf[oolT01?m8o`03ofco0005odSo0?oonf[oK?l0oonK0?m/o`001ooonfX00ol0oi3o
oo]ZoookJP03oookJP?o06oo00?onOl0oookJ_oio`002OoonfX3oomU00Cooo]Z00?o]ol0oookJ_ng
o`000_ngo`05oookJP?o0=3o1?oonfX01?l0oeCooo]Zo`3oE?oo5002o`3o4`05ofco0?l0oa?o0?lC
o`3o4oooYP000ooonfX00om8o`3ooo]Zo`3oT003oolC00Cooo]Z00?oom<0o`3@oooonfX00_oonfX2
o`0bo`03o`1_ool0<_oo06oo00Cooo]Z00Co06oooome0?oonf[o03;o0_ooF002oookJP03o`0bool0
Kooooo]Z00Gooo]Z00Goodd0oookJ_oonf[ooo]Zool8000RoookJP04ool00?oonf[ooo]ZoookJP;o
oah02OoonfX00ooo003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00Oooo]Z00?oo`<0oookJ_oo
nfX03OoonfX00ooo003ooo]ZoookJP0GoookJP;oo`@02?oonfX4o`0001[ooo]Z0_oo100;oookJP03
o`000?oonf[ooo]Z01Gooo]Z000<oookJP03o`000?oonf[ooo]Z057ooo]Z00?oo`80oookJ_oonfX0
4ooonfX00ooo1@3ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Gooo]Z00?oo`40oookJ_oonfX0
7OoonfX2oolN00Kooo]Z0_oo5`06oookJP;oo`H05OoonfX3o`0000cooo]Z00Go03;ooookJ_oonf[o
oo]Zoome0004o`0bo`0:oookJ_l0KoooB?l0odSo0?oob@3oB?l0oookJ_l0Kooooo]ZodSo00;oK?l0
0_oonfX3oolD00Oooo]Z00?o0?n@oookJ_l0Kol00_l0Kol=ooWo00GoofD01_oio`000ooonf[o]ol0
okOo0002oookJP03o`3@oooo4@3o0=3o00Sooo]Z00?o0?mDoookJ_oo50000_oo50001?l0oeCoK?l0
oonV0?l0oa<4oookJP04odSo0?oonf[ooo]Zo`3oT0;ooo]Z0_ood`001Ooonf[oom<0oookJ_oonf[o
0=3o00Cooo]Z00Co06ooo`0bool0d?oo0=3o0_l0<_l2oome0009o`1_oooonf[ooo]Zo`0boooonf[o
o`40oookJ_l0<_oo06oo00Cooo]Z0_ooC@0HoookJP03oolA0?oonf[ooo]Z02Wooo]Z0_oo3@05oook
JP03o`000?oonf[ooo]Z023ooo]Z00?oo`T0oookJ_oonfX05?oonfX3o`0002_ooo]Z00?o0000oook
J_oonfX05OoonfX000cooo]Z00?o0000oookJ_oonfX0C?oonfX2ool000?ooo]Z00?oo`80oookJ_oo
nfX0;OoonfX00ooo0@3ooo]ZoookJP02oookJP03o`000?oo003ooo]Z02Cooo]Z0_oo7P07oookJP03
oolG0?oonf[ooo]Z01Sooo]Z0ol0000>oookJP03o`0boooonf[ooo]Z00?o03;o00GoogD0oookJ_oo
nf[o03;oo`1_o`02oomZ00?ooa<01Om8o`001Om/o`3oB?l0oolD0?oo503oK?l000Oooo]Z0_l0Kol0
0ol0oi3ooo]ZoookJP03oookJPConOl01?oonfX3oomU00;ooo]Z0_ooI@02oookJP03ool50?ngo`3o
]ol000Co]ol00ol0d?l3oolA00Sooo]Z0_l0oa<2o`3oE006oookJ_l0oa?ooo]Zofco0?oonf[o0?lC
0_oonfX00om8o`3ooo]ZoookJP02oookJP03o`3oT?ood`3ooo]Z00;oom<00ooonfX02Ol0d?oooo]Z
oookJ_oonf[o06ooool80?oonf[o0=3oo`1_o`02o`3@o`;o03;o00Co06ooo`0bool0<_oooo]Z0_l0
<_l00ooonf[o06oooookJP03oookJP?oodd02ooonfX00ooo>P3ooo]ZoookJP0:oookJP03oolA0?oo
nf[ooo]Z01Cooo]Z0_oo2`04oookJP;ooaX03OoonfX00ooo3@3ooo]ZoookJP05oookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?oo`<0oookJ_oonfX06_oonfX00ooo003ooo]Zo`000002o`0002kooo]Z00?o
0000oookJ_oonfX05OoonfX000cooo]Z00?o0000oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP0j
oookJP03ool00?oonf[ooo]Z02oooo]Z00?oo`@0oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0U
oookJP04oolN0?oonf[ooo]ZoookJP?oo`h05OoonfX00ooo703ooo]ZoookJP03o`00013ooo]Z1?l0
<_l2ool<00Gooo]Z00Go06oooomZ0?l0Kooooa<0oookJP02odSo0006o`1_ool0<_ooB?l0odSo0?oo
nf[oK?l00om8o`001?m/o`3oB?l0odSo0?oonfX3o`1_o`?ooo]Z00?o0?n@oookJ_oonfX01?oonfX2
ooWo00;ooo]Z0_ooI@0=oookJP?o0=3o3OoonfX00ol0oa?ooo]Zo`3oE003o`3oE008o`3o4oo`o`3o
0?lCofco0?oonf[o0?lCoookJ_m8o`05oookJP04olWo0?ood`3oom<0oooC00Cooo]Z00?o0=3ooook
J_l0Kol00_oonfX02?l0d?oooo]Zo`3@ool0KoooogD0o`3@oooonf[o06oo1Ol0<_l2o`1_o`Cooo]Z
00?ood/0oom=0?oonfX02_oonfX00ooo>P3ooo]ZoookJP0BoookJP03ool80?oonf[ooo]Z00kooo]Z
00?oo`/0oookJ_oonfX00_oonfX00ooo6P3ooo]ZoookJP09oookJP03ool00?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX00_oonfX2ool001_ooo]Z00?oo`00oookJ_oonfX03_oonfX3o`0000Gooo]Z
00?oo`@0oookJ_oonfX03_oonfX00ooo0@3ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z01Gooo]Z
000<oookJP03o`000?oonf[ooo]Z04Gooo]Z00?oo`00oookJ_oonfX0;_oonfX00ooo2@3ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z01Wooo]Z0_oo1006oookJP03ool:0?oonf[ooo]Z01?ooo]Z0_oo
:P07oookJP?o00001_oonfX00ooo0P3ooo]ZoookJP06oookJP03ool10?oonf[ooo]Z00Ko03;o1Ooo
nfX00ol0Kooo03;oo`1_o`05oomZ00;oB?l000?ooo]ZodSo0?oonfX01?oonfX00oood`3oK?l0o`1_
o`06odSo00;ooo]Z00?o0?n@oookJ_oonfX01?oonfX00ooio`3ooo]ZoookJP0<oookJP?o0=3o00?o
oo]ZoonC0?ooT`000ooonfX7oonC00?ooo]Z0_l0oa<01?oonf[ol?l0oo3o0?o`o`02o`3o4`;ooo]Z
00?oK?l0oookJ_m8o`001?oonfX01?oo503ooo]ZolWo0?l0oi03oooC00Cooo]Z00?o0=3ooookJ_oo
nfX00ooo50001?l0d?ooogD0o`1_ool0<_l2o`3@o`08o`1_oooonf[o03;oo`0bool0Kooo03;oo`1_
oooonfX3oom;00_ooo]Z0_oo>P06oookJP03ool30?oonf[ooo]Z00gooo]Z00?oo`P0oookJ_oonfX0
3_oonfX2ool201[ooo]Z00?o0000oookJ_oonfX03OoonfX00ooo103ooo]ZoookJP0KoookJPCo0000
2?oonfX00ooo103ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Gooo]Z000<oookJP03o`000?oo
nf[ooo]Z06?ooo]Z00?oo`40oookJ_oonfX00_oonfX00ooo103ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?oo`00oookJ_oonfX01?oonfX00ooo003ooo]ZoookJP0IoookJP?oobP01_oo
nfX00ooo:P3ooo]ZoookJP02oookJP?o000000?ooo]ZoolL0?oonfX02OoonfX00ooo@03ooo]Zoook
JP08oookJP?o03;o00?ooo]Zo`0bool0<_l00_l0<_l01?l0Koooog/0oomk0?l0Kol3o`0bo`;ooo]Z
00?oofX0odSo0?m8o`001?oonfX3o`1_o`04oookJ_m/o`3ooi/0oonK00Cooo]Z1?m8o`000ooo603o
B?l0odSo000>oookJP?o0=3o0ooonfX6oonC00[ooo]Z00Col?l0o`3o4ol0oa?ooo]Z0_oo3P000ooo
nf[o0?lCoookJP02oookJP03ofco0?l0oa?o0?lC00?ooo]Z0ooo50000ol0oi3ooo]ZoooC0004oook
JP04o`1_oooonf[o0=3oo`3@o`Cooo]Z00?o0=3ooookJ_l0Kol00_l0<_l2o`3@o`04oookJ_l0Kooo
oo]Zo`1_o`;ooo]Z0_ooB`06oookJP03ool00?oonf[ooo]Z00?ooo]Z0_oo>P0IoookJP03oolD0?oo
nf[ooo]Z00_ooo]Z00?oo`80oookJ_oonfX06OoonfX00ooo3@3o0000oookJP0XoookJP?o0000>?oo
nfX00ol0003ooo]ZoookJP0EoookJP003?oonfX00ol0003ooo]ZoookJP1OoookJP05ool00?oonf[o
oo]ZoookJ_oo0@009_oonfX2ool:00Cooo]Z0_oo100[oookJP03oolX0?oonf[ooo]Z00Cooo]Z00Co
obX0o`000?l0003o00003ooonfX2oom000Wooo]Z0_oo8P001_oonf[o03;oo`0bool0<_oooo]Zo`1_
o`Coog/00ooonfX4o`0bo`03odSo0?oonf[o06oo00;o06oo0ooonfX01?ooV`3ooaL0oolG0?oo5`08
oookJP?ooaP01_m8o`05oookJP?o0=3o1ooonfX3oonC0003oookJ_o`o`3ol?l000?ooo]Z00?oo`00
oookJ_oonfX00oo`o`001Ooonf[o0?lCoookJ_l0oa?ooo]Z00;oo`h000Kooo]ZodSo0?m8o`3o0?lC
odSo0?m/o`05oookJP04olWo0?oonf[ooo]Zo`3oT0Cooo]Z0_l0Kol00ooonf[ooiL0oonG0004oook
JP0<o`3@oooonf[ooo]Zo`1_oooonf[o06oooookJ_l0d?ooob80oookJ_l0Kooooo]Z0_ooB`0Joook
JP03ool/0?oonf[ooo]Z00[ooo]Z0_oo500HoookJP03ool80?oonf[ooo]Z00kooo]Z0_oo2`000ol0
003ooo]ZoookJP0KoookJP;oo`401_oonfX3o`00017ooo]Z00?oo`00oookJ_oonfX05?oonfX00ooo
0P3ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z01Gooo]Z000;oookJP03o`000?oonf[ooo]Z023o
oo]Z00Coo`00oookJ_oonf[oo`00<_oonfX2ool100?ooo]Z00?oo`00oookJ_oonfX0:?oonfX00ooo
3P3ooo]ZoookJP03oookJP03ool:0?oonf[ooo]Z03Cooo]Z0ol00002ool@00Oooo]Z0_oo>007oook
JP;ood002OoonfX00ooo8P3ooo]ZoookJP03oookJP07o`0bool0Koooog/0oomk0?oo003oog/0o`1_
o`02oookJP?o03;o0_oo30000ol0Kooooo]ZoookJP05oookJP03oolG0?m/o`3ooi/000Oooi/02_oo
nfX3odSo00;o0=3o2ooonfX00oooT`3ooo]Zoo3o0002oo3o00?ooo]Z0oo`o`05oookJP03o`3o4ooo
nf[o0?lC00;o0?lC00CoB?l0o`3o4om8o`3oB?l00_oonfX01Om/o`3ooo]ZoookJ_oonf[obOl000;o
ohH00_oonfX00ol0oi3ooo]ZoookJP03oookJP;o0?n@00?o06ooo`3@oooonfX00_oonfX01?l0d?oo
oo]ZoookJ_l0Kol2oookJP05o`1_oooo8P3oob80oookJ_l0Kol03OoonfX2oolC00cooo]Z0_oo;00F
oookJP03ool50?oonf[ooo]Z00kooo]Z00?oo`P0oookJ_oonfX03?oonfX01Ooo003ooo]ZoookJ_oo
nf[o000000cooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo1@3ooo]ZoookJP08oookJP?o00000_oo
nfX00ooo0@3ooo]ZoookJP0EoookJP03ool50?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX05Ooo
nfX000_ooo]Z00?o0000oookJ_oonfX0POoonfX2ool800[ooo]Z00?o0000oookJ_oonfX07ooonfX0
0ooo003ooo]ZoookJP04oookJP03ool20?oonf[ooo]Z00Cooo]Z0_oo2`001?oonf[o0000o`000?l0
0003oookJP03ool@0?oonf[ooo]Z00Kooo]Z1?oo>007oookJP03oom00?oonf[ooo]Z00Kooo]Z00?o
ob80oookJ_oonfX00ooonfX2o`1_o`05oookJ_l0<_ooog/0oomk0?l0Kol00_l0<_l3o`1_o`03oook
J_l0Kooooo]Z00;o0=3o1ooonfX00om/o`3ooo]ZoookJP05oookJP?ooi/01_oonfX3o`3@oa3ooo]Z
00?ol?l0oookJ_oonfX00oo`o`09oookJP08o`3o4ooonf[oB?l0odSo0?l0oa?oB?l0o`3o4om8o`02
oookJP04oon60?m/o`3oohH0olWo00Kooo]Z00Oo0?n@oookJ_oonf[ooo]ZoonG0?l0oi3ooo]Z00;o
oa4000Go0=3oo`1_oooonf[ooo]Zo`3@o`02oookJP?o06oo00?ooo]ZoolR0?oo50000_oo500>oook
JP03oolC0?oonf[ooo]Z00Cooo]Z00?oo`40oookJ_oonfX00_oonfX00ooo;03ooo]ZoookJP06oook
JP03ool00?oonf[ooo]Z00gooo]Z00?oo`D0oolD0?oonfX03?oonfX2ool501?ooo]Z00?o0000oook
J_oonfX01?oonfX00ooo3@3ooo]ZoookJP0<oookJP03ool50?oonf[ooo]Z00Gooo]Z1?l00012oook
JP03o`000?oonf[ooo]Z01Cooo]Z000;oookJP03o`000?oonf[ooo]Z07Kooo]Z00?oo`00oookJ_oo
nfX00_oonfX2ool300Cooo]Z00?oo`P0oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP09oookJP03
ool@0?oonf[ooo]Z00?ooo]Z0_oo2`05oookJP;oo`805?oonfX3o`0001?ooo]Z00?oocP0oookJ_oo
nfX01OoonfX00ooo@03ooo]ZoookJP05oookJP;ooeH00ooonfX2o`1_o`Gooo]Z00?oog/0o`1_ool0
Kol01?oonfX4o`3@o`03oookJ_oo7@3ooo]Z00Gooo]Z00?oK?l0oookJ_oonfX02_oonfX3o`3@o`;o
om<01OoonfX00ooo7@3ooo]ZoookJP08oookJP03oo3o0?oo6P3ooaX000;ooaX02ooonfX01Ol0oa?o
B?l0o`3o4ol0oa?ooo]Z00;oB?l000?oohH0odSo0?ooQP000_oonfX00om/o`3obOl0oookJP02ool5
00Cooo]Z00Oo0?n@oookJ_ooU`3o0?n@oookJ_l0oi3ooo]Z00;ooa4000Co0=3oo`1_ool0Kooo0=3o
0_oonfX2o`1_o`04oookJ_l0d?oo0=3oo`1_o`Wooo]Z00?oobT0oookJ_oonfX02ooonfX00ooo0@3o
oo]ZoookJP0=oookJP;oob803?oonfX2oolD02?ooo]Z00?o0000oookJ_oonfX05ooonfX3o`0003[o
oo]Z00?oo`80oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0DoookJP002ooonfX00ol0003ooo]Z
oookJP0foookJP04ool00?oonf[ooo]Zool102gooo]Z00Coo`80oookJ_oonf[ooo]Z0_oo0004oook
JP03ool00?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX02?oonfX2ool@00Gooo]Z00?oo`/0oook
J_oonfX05ooonfX2o`0001oooo]Z0_oo>`001Ooonf[ooaL0oolG0?oo5`3ooo]Z00CooeH000?ooo]Z
o`1_oooonfX00_oonfX3o`1_o`04oookJ_ooN`3ooo]ZoookJPCooiL000Co0=3ooookJ_oonf[o0=3o
0_oo7@06oookJP03ofco0?oonf[ooo]Z00Kooo]Z00Co0=3ooolL0?oo703ooa`01?ood`04oookJPCo
oad01ooonfX4oo3o0003oookJ_o`o`3ooo]Z00?o0?n@1ooonfX2odSo00;o0?lC00?oofD0odSo0?m8
o`000_ooQP001?m8o`3ooo]ZoookJ_m/o`07oookJP;ooiL00_l0oi001?l0d?oooo]Zo`3oT?ooD@02
oookJP;o0?n@0_oonfX01?l0d?oo06ooo`1_oooonfX2o`3@o`03oookJ_l0Kooooo]Z00Oooo]Z0_oo
:@0LoookJP;oob80<ooonfX00ol0003ooo]ZoookJP04oookJP03ool80?oonf[ooo]Z00[ooo]Z00?o
o`00oookJ_l000000_l0000<oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oo`80oookJ_oonfX03_oo
nfX00ooo003ooo]ZoookJP0DoookJP03ool20?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX05?oo
nfX000_ooo]Z00?o0000oookJ_oonfX0<ooonfX00ooo003ooo]ZoookJP0aoookJP03ool20?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX09OoonfX3o`0001?ooo]Z00?oo`/0oookJ_oonfX01OoonfX2
oolD00Cooo]Z0ooo>`000ooo5`3ooo]ZoookJP05oookJP03oomF0?oonf[o06oo00;o06oo1?oonfX0
1Ol0Koooog/0oookJ_ooU`3ooo]Z00;ooiL000Gooo]Zo`1_oooonf[o0=3ooolM0002oookJP;obOl0
1?oonfX2ool800?ooo]Z0ol0d?l00ooonf[ooa`0oomZ000CoooC00?ooo]Z0_o`o`03o`3oT0[ooo]Z
00SoB?l0oookJ_m8o`3ooo]ZoomU0?m8o`3ooo]Zoon600;ooo]Z00CoB?l0oookJ_o9o`3oK?l00ooo
nfX2ofco0005oonG0?oonf[ooiL0oomA0?l0oi000_ooD@000ooonf[o0?n@oookJP02oookJP0:o`3@
ool0oi3ooo]Zo`1_oooonf[ooeH0o`3@ool0Kooo0=3oo`1_o`Wooo]Z0_oo:@03oookJP03oolA0?oo
nf[ooo]Z00cooo]Z00?ooa80oookJ_oonfX04_oonfX00ooo003ooo]ZoookJP0<oookJP03ool10?oo
nf[ooo]Z00_ooo]Z00?oo`L0oookJ_oo1@002_oonfX01?l0003ooo]ZoookJ_oo0@0?oookJP?o0000
1ooonfX00ooo1P3ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z01Cooo]Z000;oookJP03o`000?oo
nf[ooo]Z097ooo]Z00Co0000oookJ_oo203oo`P01OoonfX2ool>00_ooo]Z0_oo5`05oookJP;ooa@0
1OoonfX3o`0000Kooo]Z00?oo`00oookJ_oonfX01OoonfX00ooo003ooo]ZoookJP04oookJP;oo`/0
1_oonfX2oolD00Wooo]Z00?ooc/0oookJ_oonfX00ooonfX2o`1_o`03oomF0?oonf[ooo]Z00Kooo]Z
00?o06oooookJ_l0d?l00_ooU`001Ooonf[ooiL0oonG0?ooU`3o0=3o00KobOl01?oonfX01?m/o`3o
0=3oo`3@ool0d?l7oookJP04oomZ0?ood`3oom<0oooC013ooo]Z0ol0oi000oo`o`3ooo]ZoookJP0:
oookJP03oolN0?m8o`3ooo]Z00;oB?l000?oofD0oookJ_oonfX00_oonfX01Om8o`3obOl0oookJ_oo
nf[oK?l000;ooo]Z00?oK?l0oookJ_m/o`000_m/o`000ol0oi3ooo]Zo`3oT002oookJP03o`3oT?oo
nf[ooo]Z00;ooo]Z00?o0=3oo`3oT?l0Kol00_l0d?l2o`1_o`03o`3@ool0Koooo`T000cooo]Z0ooo
4@0>oookJP03oolB0?oonf[ooo]Z00;ooo]Z00?oo`H0oookJ_oonfX06_oonfX2oolB00gooo]Z00?o
o`L0oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0;oookJPCo0000CooonfX00ol0003ooo]Zoook
JP0DoookJP002_oonfX00ol0003ooo]ZoookJP1moookJP03ool20?oonf[ooo]Z00;ooo]Z00?oo`00
oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP03oookJP03ool30?oonf[ooo]Z00;ooo]Z00?o0000
ool80?oonfX04_oonfX3oolG00Gooo]Z00?ooa@0oookJ_oonfX00ol000000ooonf[oo`/0oookJP0]
oookJP_o06oo00Kooe80o`1_ool0d?oooo]Zo`3@ooooU`02oookJP03o`1_oooonf[obOl000?obOl0
00?ooo]ZolWo0?o9o`000_oonfX3o`3@o`03ofco0?oonf[ooo]Z00Wooo]Z0_ood`07oookJP03oolR
0?oonf[ooo]Z00?ooo]Z0ol0oi02oookJPCoob@02OoonfX4oolN0003oookJ_m8o`3ooo]Z00;oofD0
1?o9o`03oookJP;oK?l000Sooo]Zofco0?ooU`3ooiL0o`3oT?m/o`3o0=3oo`3oT0?ooo]Z00?oo`00
oookJ_oonfX00_oonfX00ol0oi3ooeH0o`3@o`02oookJP05o`3@oooonf[ooo]ZoookJ_oo2@001_oo
nfX2oolh00_ooo]Z00?oob@0oookJ_oonfX0:?oonfX00ooo4P3ooo]ZoookJP0KoookJP03o`000?oo
nf[ooo]Z00Oooo]Z0ol0000PoookJP03ool00?oonf[ooo]Z00Cooo]Z00?oo`<0oookJ_oonfX03_oo
nfX2ool001Wooo]Z00?o0000oookJ_oonfX05?oonfX000[ooo]Z00?o0000oookJ_oonfX0A_oonfX0
1?oo003ooo]ZoookJ_oo0003oookJP05ool10?oonf[ooo]ZoookJ_oo0`009OoonfX00ooo1@3ooo]Z
oookJP02oookJP03ool20?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX06OoonfX3o`0003Gooo]Z
0ol0Kol5oookJP?ooad000?o06ooo`3@ool0d?l01Ol0Kol01?oonf[o0=3oolWo0?ooU`05olWo00Co
oo]Z00?oK?l0oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP04oookJPCoob800ol0oi03oookJP;o
ogD000?oob@0oookJ_ooM@001OooM@08oookJPCoB?l00oooI@03olWo00?ooo]Z0_m/o`001_oonf[o
K?l0oookJ_l0oi3ooo]Zofco00;o0=3o00Co0?n@o`3@ool0d?oo0?n@0ooonfX2o`3oT0;o0=3o0_oo
nfX00ol0d?oooo]ZoookJP05oookJP?oocP03?oonfX00ooo903ooo]ZoookJP15oookJP04ool20?oo
nf[ooo]Zo`0000Gooo]Z0ol00002ool200Cooo]Z00?oo`D0oookJ_oonfX02?oonfX00ooo003ooo]Z
oookJP05oookJP;oo`L03ooonfX00ooo0`3ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z
000:oookJP03o`000?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX0Q_oonfX00ol0003ooo]Zoook
JP0EoookJP?o00003OoonfX00ooo7@3ooo]ZoookJP04oookJP;ooaT01ooonfX00ooo2@3ooo]Zoook
JP06oookJP03ool00?oonf[ooo]Z00Gooo]Z00?oo`T0oookJ_oonfX01OoonfX3oolI00;ooo]Z0ol0
Kol02ooonf[ooad0oolM0?oonf[o0=3oo`1_oooonf[o0=3ooomB0?oonf[o06oo00?ooo]Z00?o0=3o
oookJ_o9o`000_o9o`02oookJP03oomd0?o9o`3obOl000?obOl000?oK?l0oookJ_oonfX04?oonfX3
o`3oT0Gooo]Z1OooM@0;oookJP?oolT000Gooo]ZodSo0?m8o`3obOl0odSo0002oomU000<oookJ_o9
o`3ooo]ZolWo0?oonf[oK?l0oonK0?oonf[oK?l0oookJ_m/o`3o0?n@0_m/o`02oookJP04o`3@ool0
oi3ooo]Zo`3oT0;o0=3o0_l0oi001_oonf[o0=3oo`3@ool0d?oooo]Zo`3@o`Oooo]Z0_oo>00Coook
JP;oo`/03OoonfX2ool?00oooo]Z0_oo40000ooo003ooo]ZoookJP0:oookJP;ooa0000?ooo]Zool0
0?oonfX02ooonfX01?oo203ooo]ZoookJ_oo0P02oookJP03o`000?oonf[ooo]Z00?o0000F_oonfX0
0ol0003ooo]ZoookJP0CoookJP002_oonfX00ol0003ooo]ZoookJP2FoookJP03o`000?oonf[oo`00
00Kooo]Z00?oo`40oookJ_oonfX00ooonfX2ool800?ooo]Z0ol00002ool@00kooo]Z0_oo7@07oook
JP03oolI0?oonf[ooo]Z00Cooo]Z00?oo`T0oookJ_oonfX03_oonfX00ooo2@3ooo]ZoookJP05oook
JP03oolI0?oonf[ooo]Z00Gooo]Z0ol0Kol2o`3@o`05o`1_oooonf[ooo]Zo`3@ool0Kol00ooonfX3
o`3@o`04oookJ_o9o`3obOl0oookJPCoog@01?oonfX5olWo00[ooo]Z0ol0oi0:oookJP;oogD00ooo
nfX2ooo900Cooo]Z0ooob@03oolY00?ooo]Z0_o9o`000ooonf[obOl0olWo0002oookJP04olWo0?oo
8`3oob<0oolS00;ooo]Z0om/o`000ooonf[oK?l0oookJP03oookJP?ooad000?o0?n@oookJ_l0oi00
1Ol0d?l2oookJP03ool50?oonf[ooo]Z00_ooo]Z00?oo`40oookJ_oonfX00_oonfX2oolX00Kooo]Z
0_oo2`03oookJP;ooad02_oonfX00ooo3`3ooo]Zool9000KoookJP;ooa004ooonfX4o`0004[ooo]Z
00?oo`40oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0CoookJP002_oonfX00ol0003ooo]Zoook
JP1OoookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`<0oookJ_oonfX00_oonfX00ooo1`3ooo]Zoook
JP0JoookJP03ool90?oonf[ooo]Z00?ooo]Z00?oo`D0oookJ_oonfX00ooonfX00ooo0@3ooo]Zoook
JP02oookJP03o`000?oonf[ooo]Z00gooo]Z0ol0000`oookJP03oolR0?oonf[ooo]Z01?ooo]Z0_l0
d?l2o`1_o`04oookJ_l0Kooo0=3ooookJP?o0=3o0_oonfX01Ol0d?ooodD0oom50?o9o`3ooo]Z00;o
0?n@1oooM004oookJPGobOl00_oonfX3o`3oT13ooo]Z1?oo7@001?oonf[oolT0ooo90?oob@04oook
JP04oolY0?oonf[oobT0oolY00;ood/00oo9o`002_oonf[obOl0olWo0?oonf[oob<0oonK0?m/o`3o
ob<0ofco0?l0oi03ofco00Gooo]Z00OooeP0oolM0?l0oi3ooad0oookJ_l0oi3ooo]Z00Co0=3o0_oo
nfX00ooo1@3ooo]ZoookJP0>oookJP;oobP03?oonfX2oolM03_ooo]Z0ol00003oookJP03o`000?oo
nf[ooo]Z01kooo]Z00?oo`00oookJ_oonfX03ooonfX00ooo003ooo]ZoookJP03oookJP03ool30?oo
nf[ooo]Z00kooo]Z0_oo0@0BoookJP03o`000?oonf[ooo]Z01?ooo]Z000:oookJP03o`000?oonf[o
oo]Z02;ooo]Z00?oo`40oookJ_oonfX0<_oonfX01Ooo003ooo]ZoookJ_oonf[oo`0000Sooo]Z00?o
o`<0oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP09oookJP?o00008_oonfX3oolR00Gooo]Z0_oo
9P07oookJP;oob802?oonfX00ooo1@3ooo]ZoookJP08oookJP;o0=3o0ooonfX01?l0Kooo0=3ooolR
0?oo8P05oookJP03o`3@oooo9P3oobH000?oobH000?o0?n@oomd0?oonfX00ooonfX5oolR00Gooo]Z
00Co0?n@olWo0?o9o`3obOl04ooonfX4ooo900Kooo]Z0oooB`04oookJPGobOl000?oof<0oonK0?oo
V`000_oonfX00om/o`3ooo]Zofco0003ofco00Co0?n@00?ooeP0oookJ_oonfX00_l0oi000ol0d?oo
0?n@o`3@o`0HoookJP03oolX0?oonf[ooo]Z03;ooo]Z00?oo`h0ool10?oonfX03OoonfX00ooo003o
oo]Zo`000002o`0000Oooo]Z00?o0000oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP07oookJP;o
o`<01OoonfX2ool304Gooo]Z00?o0000oookJ_oonfX04ooonfX000Wooo]Z00?o0000oookJ_oonfX0
8OoonfX00ooo003ooo]Zool1001foookJP03o`000?oonf[ooo]Z00Gooo]Z0ol0000RoookJP;ooaP0
0_oonfX00ooo8P3ooo]ZoolR0006oookJP03oolV0?oonf[ooo]Z00Gooo]Z00?oob80oookJ_oonfX0
1_oonfX00ooo1@3ooo]ZoookJP06oookJP03ool50?oonf[o0=3o00;ooo]Z0_l0d?l2oolR0003oook
J_l0d?oooo]Z00Gooo]Z0_oo9P001Ooonf[o0?n@oookJ_oonf[o0?n@00Gooo]Z00?oob80oookJ_oo
nfX00ooonfX3o`3oT1Kooo]Z1_oob@06oookJP03oom;0?oonf[ooo]Z00Cooo]Z0oo9o`001OooH`3o
oi/0oonK0?ooV`3oob8000;ooo]Z1Om/o`02o`3oT0;ooeP000?o0?n@oolT0?l0oi000ol0oi09oook
JP03oolN0?oonf[ooo]Z01Gooo]Z00?oo`00oookJ_oonfX03?oonfX01?oo103ooo]ZoolH0?oo600;
oookJP?oo`/03OoonfX2ool>00gooo]Z0ol0000:oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000
oookJ_oonfX04ooonfX000Wooo]Z00?o0000oookJ_oonfX0UOoonfX2ool>00Cooo]Z0_oo2P02oook
JP?o000000?oo`D0oookJ_oonfX01?oonfX00ooo003ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z
00Cooo]Z00?oo`P0oookJ_oonfX01?oonfX2oolC00Kooo]Z0_oo600NoookJP;oocL01ooonfX01?l0
d?oooc80oolb0?oo<P03oookJP03oolR0?oonf[o0=3o00Kooo]Z00?o0=3oo`3oT?l0oi000ooonfX2
oomU00Oooo]Z0ol0oi02oookJP;ooe800ooonfX2oonG01?ooo]Z00?oolT0oookJ_oonfX04?oonfX0
0oooV`3ooo]ZoonK0003oolR00Oooo]Z00?ooeP0o`3oT?l0oi000ooo9003o`3oT0Kooo]Z0_oo=`00
1?oonf[ooah0oolN0?oo7P07oookJP;oo`h07OoonfX00ooo603ooo]ZoookJP0UoookJPCo00003_oo
nfX00ol0003ooo]ZoookJP0UoookJP03ool10?oonf[ooo]Z00oooo]Z00?oo`00oookJ_oonfX04ooo
nfX00ooo0@3ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01?ooo]Z0009oookJP03o`000?oonf[o
oo]Z06Sooo]Z00Coo`40oookJ_oonf[ooo]Z0_oo0004oookJP03ool00?oonf[ooo]Z00;ooo]Z00?o
o`80oookJ_oonfX00_oonfX00ooo1`3ooo]ZoookJP03oookJP;oo``06?oonfX3o`0003oooo]Z0ooo
;006oookJP?oocL01?oonfX3o`3@o`;ooc801_l0d?l6oookJP?o0?n@0ooonfX3oomU00?ooo]Z0ol0
oi04oookJPCooe800oooU`000ooo;03ooiL0oonG0008o`3oT0Sooo]Z0om/o`0;oookJP03ool00?oo
nf[ooo]Z00?ooo]Z1?ooV`02oookJP03oolR0?oonf[ooo]Z00Cooo]Z0_ooF0001Ooo?@3o0?n@o`3o
T?l0oi3oob@000Kooo]Z0_oo=`0=oookJP03ool>0?oonf[ooo]Z047ooo]Z0ol0000CoookJP03o`00
0?oonf[ooo]Z00?ooo]Z0_oo2005oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oo`@0oookJ_oonfX0
1_oonfX00ooo0@3ooo]ZoookJP05oookJP03ool10?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
4ooonfX000Wooo]Z00?o0000oookJ_oonfX0<ooonfX00ooo003ooo]ZoookJP02ool000;ooo]Z00?o
o`80oookJ_oonfX0G?oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0?_oonfX01?oo;03ooo]Zool/
0?oo;007oookJP03oolg0?oonf[ooo]Z00Cooo]Z0_l0d?l00ooo<P3ooo]ZoookJP02oookJP?o0=3o
00?ooeP0o`3@oooo00000_l0oi001?l0d?oo0?n@oookJ_oonfX3oolb0005oomU0?l0oi3o0?n@o`3o
T?oonfX01_oo=`02oookJP04oomB0?oonf[ooo]ZoookJPKoob`00ol0oi001?oonf[o0?n@oookJ_l0
oi04oookJP?oK?l05OoonfX2oonK00Wooo]Z0ooo?@0;oookJP;oocL0=_oonfX2oolD00cooo]Z0_oo
3008oookJP?o00000_oonfX00ooo0`3ooo]Zool:000=oookJP06ool00?oonf[ooo]ZoookJ_oo303o
00007?oonfX00ooo0@3ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z01?ooo]Z0009oookJP03o`00
0?oonf[ooo]Z09Kooo]Z0ol00006oookJP03o`000?oonf[ooo]Z00Oooo]Z0_oo4005oookJP;oo`/0
1OoonfX2ool300Kooo]Z00?oo`00oookJ_oonfX01OoonfX00ooo1P3ooo]ZoookJP05oookJP;ooaL0
1_oonfX3oolN01Wooo]Z00CoocX0o`3@ool0d?oo0=3o0_oonfX01?l0d?oooeP0oomH0?ooF002o`3o
T0;ooo]Z00Co0?n@oolb0?oo<P3ooo]Z0ol0oi000oooI@3ooo]ZoookJP02oookJP03oolg0?oonf[o
oo]Z00Wooo]Z00?ooiL0oookJ_oonfX00_l0oi03oookJP?o0?n@00?ooo]Zo`3oT?l0oi001_m/o`0/
oookJP05ool[0?oonf[oob/0ool[0?oonfX00_oo7007oookJP;oobH00ooonfX2oolM00Kooo]Z0_oo
4@05oookJP?ooaX01OoonfX00ooo003ooo]ZoookJP0;oookJP03ool00?oo503ooo]Z00cooo]Z0_oo
1@05oookJP?o00001ooonfX00ooo2P3ooo]ZoookJP0?oookJP03ool<0?l0003ooo]Z05Wooo]Z00?o
0000oookJ_oonfX04_oonfX000Wooo]Z00?o0000oookJ_oonfX0MooonfX2ool300Cooo]Z00?oo`00
oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP03oookJP03ool10?oonf[ooo]Z00?ooo]Z00?oo`H0
oookJ_oonfX00_oonfX3o`0000[ooo]Z00?o0000oookJ_oonfX0:ooonfX2oolG00Kooo]Z0_oo7P0C
oookJP?oob/01?oonfX4oolj0004oookJ_l0d?oo0=3oo`3@o`;ooeP000Co0=3ooomH0?ooF03ooeP0
0_oonfX01Ol0oi3ooc80o`3oT?oonf[o0?n@00;ooo]Z00?oofD0oookJ_oonfX03?oonfX6o`3@o`03
o`3oT?oonf[o0?n@00;ooc/000?oK?l0o`3oT?l0oi000_oo>P000ol0oi3ooeH0oookJP05ofco00Wo
oo]Z0_ooN`0;oookJP03oolM0?oonf[ooo]Z00Wooo]Z0_oo2005oookJP;oob/00ooonfX00ooo703o
oo]ZoolL0004oookJP;oobH01OoonfX00ooo7@3ooo]ZoolM0005oookJP03oolA0?oonf[ooo]Z00Go
oo]Z00?ooaX0oookJ_oo6P009?oonfX4o`0001kooo]Z00?o0000oookJ_oonfX06_oonfX00ooo103o
oo]ZoookJP0=oookJP03ool10?oonf[ooo]Z00oooo]Z00?oo`00oookJ_oonfX06?oonfX00ol0003o
oo]ZoookJP0BoookJP002?oonfX00ol0003ooo]ZoookJP16oookJP05ool00?oonf[ooo]ZoookJ_oo
0000A?oonfX00ooo1P3ooo]Zo`000002o`000003oookJ_oo3P3ooo]Z00_ooo]Z00?o0000oookJ_oo
nfX04ooonfX00ooo503ooo]ZoookJP0boookJP03ool[0?oonf[oob/000Cooo]Z00?oocX0oookJ_oo
nfX00_oo>P02oookJP03o`3@oooonf[o0?n@00;ooo]Z00Co0?n@oomH0?l0oi3o0?n@1?oonfX01?l0
oi3ooo]ZoookJ_ooI@03oonK00Gooo]Z00?oofD0o`3@ool0d?l00_l0d?l01_ooF03ooo]ZoookJ_oo
F03o0=3oo`3oT0;o0=3o0oooV`02oookJPOoocX00ooonfX2ofco00;ooo]Z00?oog/0ool[0?oo:`00
0ooo:`0<oookJP;ooad0FOoonfX3o`0000Kooo]Z0_oo2`0>oookJP03ool40?oonf[ooo]Z00[ooo]Z
00Co0000oookJ_oo003oo`003ooonfX00ooo003ooo]ZoookJP0?oookJP03ool00?oonf[ooo]Z037o
oo]Z00?o0000oookJ_oonfX04_oonfX000Sooo]Z00?o0000oookJ_oonfX0C_oonfX01Ooo0P3ooo]Z
oookJ_oonf[oo`D003_ooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z01;ooo]Z0_oo5005oookJP;o
oa<01OoonfX2ool<00Oooo]Z00?oo`40oookJ_oonfX01OoonfX00ooo0P3ooo]ZoookJP0RoookJPCo
0?n@0ooonfX00ol0oi3ooo]ZoookJP02oookJP03o`3oT?oonf[ooi/000?ooi/000?oofD0oookJ_oo
nfX00oooI@001?m/o`3o0=3ooookJ_oonfX3o`3@o`07oomH0?l0d?ooK?l0ofco0?l0oi3ooi/0o`3@
o`02oonK00Cooo]Z00CoocX0oookJ_m/o`3o0?n@1OoonfX00om/o`3ooo]Zoomk0002oomk0003ool[
0?oonf[ooo]Z00gooo]Z00?ooad0oookJ_oonfX0:OoonfX2oolM00cooo]Z00?ooa40oookJ_oonfX0
2ooonfX00ooo0`3ooo]ZoookJP0<oookJP04ool00?l0003o0000o`0000_ooo]Z0_oo0@0?oookJP03
ool50?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01?oonfX00ooo2@3ooo]ZoookJP1>oookJP03
o`000?oonf[ooo]Z01;ooo]Z0008oookJP03o`000?oonf[ooo]Z00cooo]Z0_oo001ioookJP;oo`H0
0_oonfX3o`0000Gooo]Z00?oo`00oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z033ooo]Z00?oo`80oookJ_oonfX01?oonfX3oolL00Gooo]Z1Ooo:P05oookJPGoobP0
1_oonfX8o`3oT006oolc0?l0oi3ooo]ZoookJ_ooC@3o0?n@0_ooC@03oonK00?oofD00_ooV`001?m/
o`3ooi/0o`3@ool0d?l2oookJP03oomH0?m/o`3o0=3o00?o0=3o00?o0?n@oookJ_ooV`000_l0d?l4
oonK00?oK?l000?o0?n@ofco0?oonfX00_oonfX01_m/o`3ooo]Zoomk0?ooN`3oodd0oookJP?oofD0
00Cooo]Zoolh0?oo>03oocP02OoonfX2oom000_ooo]Z00?oob80oookJ_oonfX02_oonfX00ooo003o
oo]ZoookJP0:oookJP04ool<0?oonf[ooo]ZoookJP;ooad01ooonfX2oolG00?ooo]Z0_oo4@08oook
JP;ooaP04?oonfX3o`0002[ooo]Z00?o0000oookJ_oonfX0<?oonfX2ool2013ooo]Z00?oo`00oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP0BoookJP002?oonfX00ol0003ooo]ZoookJP28oookJP?o
00000_oonfX00ooo0P3ooo]ZoookJP09oookJP03ool00?oonf[ooo]Z00Cooo]Z00?oo`D0oookJ_oo
nfX00_oonfX00ol0003oo`l0ool?0006oookJP;ooaL07?oonfX00ooo603ooo]ZoookJP05oookJP03
oolG0?oonf[ooo]Z00Oooo]Z0_oo7006oookJP;oobX02?oonfX2oolX00_ooo]Z0ol0oi000ooonf[o
oc<0oookJP07o`3oT0;ooo]Z00Cooi/0oomU0?ooI@3oofD00_oonfX2ofco000;oookJ_l0d?oo0=3o
o`3@ooooV`3oK?l0o`3@oooonf[o0?n@oookJ_l0oi001?l0d?l01Ol0oi3o0=3oo`3@oooonf[oK?l0
00;ooi/000Ko0?n@ofco0?ooV`3oK?l0oookJ_m/o`03oookJPGoodd000?oofD0oolh0?oonfX01ooo
nfX4oolc00_ooo]Z0_oo8P0YoookJP03oolG0?oonf[ooo]Z00cooo]Z00?ooaP0oookJ_oonfX02Ooo
nfX4o`0001Wooo]Z00?oo`/0oookJ_oonfX03?oonfX00ooo1@3ooo]ZoookJP03oookJP03o`000?oo
nf[ooo]Z00Kooo]Z0_oo0@0?oookJP03ool00?oonf[ooo]Z00oooo]Z00?oo`00oookJ_oonfX0:?oo
nfX00ol0003ooo]ZoookJP0BoookJP002?oonfX00ol0003ooo]ZoookJP1GoookJP04ool00?oonf[o
oo]ZoookJP;oo`000ooonfX00ooo0@3ooo]ZoookJP02oookJP03ool50?oonf[ooo]Z00;ooo]Z00?o
o`/0oookJ_oonfX06?oonfX3o`0001kooo]Z0_oo3`05oookJP;ooaL07OoonfX2oolH00Gooo]Z0ooo
5`06oookJP;oo``02?oonfX00ooo003ooo]ZoookJP0GoookJP;o0?n@0_oonfX01?l0oi3ooo]Zoook
J_l0oi06oookJP04oomU0?oonf[ooo]Zofco00;ooo]Z00?o0=3oofco0?m/o`000_l0d?l01Ooonf[o
0=3oo`3oT?oonf[o0?n@00;ooo]Z00?o0?n@oookJ_oonfX01?l0d?l2ofco0006o`3oT?oonf[oK?l0
oookJ_ooV`3oK?l01OoonfX01?ooC@3ooo]ZoookJ_ooI@03oom=00Gooo]Z0oooF0000ooo<`3ooo]Z
oookJP02oolc00Wooo]Z0_oo8P0YoookJP?ooaL02ooonfX2ool?00Sooo]Z0ol000000ooonf[oo`D0
oookJP0=oookJP03ool00?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX03_oonfX00ooo0P3ooo]Z
o`00001EoookJP03o`000?oonf[ooo]Z01;ooo]Z0008oookJP03o`000?oonf[ooo]Z023ooo]Z00Co
o`00oookJ_oonf[oo`80@?oonfX2ool500?ooo]Z0_oo2`0GoookJP?o00004OoonfX00ooo2@3ooo]Z
oookJP03oookJP03ool50?oonf[ooo]Z00?ooo]Z00?oo`40oookJ_oonfX00_oonfX00ol0003ooo]Z
oookJP0coookJP03ool<0?oonf[ooo]Z00oooo]Z00?oob80oookJ_oonfX01_oonfX2oom000Gooo]Z
00?oocP0oookJ_oo>0000_oo>003o`3oT0Oooo]Z00?oob/0oookJ_m/o`000om/o`001?l0d?oo06oo
o`1_ool0d?l3o`1_o`;o0?n@0ooonfX00ol0oi3ooo]ZoookJP02oookJP04o`3oT?l0d?oo0=3oo`3o
T0?oK?l00_oonfX2ofco00Wooo]Z00?oofD0oookJ_oonfX01OoonfX4oomH0003oookJ_oo:03oobP0
00Sooo]Z00?oocX0oolZ0?oo:P002ooonfX00ooo703ooo]ZoookJP0:oookJP03ool20?oonf[ooo]Z
00_ooo]Z00Coo`40oookJ_oonf[ooaL02_oonfX01?oo303ooo]ZoookJ_oo3`06oookJP?o00000_oo
nfX00ooo4`3ooo]ZoookJP0_oookJP04ool20?oonf[ooo]Zo`0000gooo]Z0_oo1P0joookJP03ool0
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX04OoonfX000Sooo]Z00?o0000oookJ_oonfX08_oo
nfX00ooo0P3ooo]ZoookJP1JoookJP?o00008?oonfX00ooo0@3ooo]ZoookJP03oookJP03o`000?oo
003ooo]Z00Gooo]Z00?oo`<0oookJ_oonfX01OoonfX00ooo4@3ooo]ZoookJP0MoookJP;ooaX01_oo
nfX2oolM00Oooo]Z00Cooa`0oookJ_oonf[ooo]Z0_oo8P05oookJPCood001_oonfX3oolh00Cooo]Z
00?o0?n@oookJ_oonfX01OoonfX2ool[0003ofco0?l0Kooo06oo00?o06oo0_oo>P02o`3@o`06o`1_
ool0d?oo06ooo`1_oooonf[ooeP00_oonfX01ol0oi3ooeP0oomH0?ooF03o0?n@oookJ_l0d?l00ooo
nfX3ofco00;ooo]Z00?oK?l0oookJ_oonfX01ooonfX00oooI@3ooo]ZoookJP05oookJP03oomH0?oo
nf[oobP000;ooeP02?oonfX4oolj00[ooo]Z00Cooa`0oookJ_oonf[oob/02_oonfX00ooo0P3ooo]Z
oookJP0;oookJP03ool10?oonf[ooo]Z00_ooo]Z00?oo``0oookJ_oonfX01?oonfX3o`0000Gooo]Z
0_oo4`0>oookJP?ooa@08_oonfX00ol0003oo`D0oookJP0=oookJP;oo`803ooonfX00ooo003ooo]Z
oookJP0?oookJP03ool00?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04OoonfX000Oooo]Z00?o
0000oookJ_oonfX0JOoonfX00ooo003ooo]ZoookJP02oookJP04ool00?oonf[ooo]ZoookJP;oo`00
2OoonfX3o`0002[ooo]Z00?o0000oookJ_oonfX02ooonfX00ooo4@3ooo]ZoookJP04oookJP?ooad0
6?oonfX2oolJ00Gooo]Z0ooo7@06oookJP;ooa`00_oonfX00ooo8P3ooo]ZoookJP03oookJP?ood00
2OoonfX00ooo>03ooo]ZoookJP0>oookJP03o`1_oooonf[oK?l000?o06oo00?oK?l0o`3@ool0d?l0
0_oonfX00ol0d?oooo]Zo`1_o`03oomH0003o`3oT?oonf[ooo]Z00;ooo]Z00?o0=3oo`3oT?oonfX0
0ooonfX01_m/o`3oofD0oomU0?ooI@3ooo]Zofco00Wooo]Z00?oofD0oookJ_oonfX02OoonfX00ooo
F03ooo]ZoookJP06oookJP03oolj0?oonf[ooo]Z00?oocX02OoonfX3ool[02Sooo]Z1?l00006oook
JP03ool>0?oonf[ooo]Z00_ooo]Z00?oo`H0oookJ_oonfX03?oonfX00ooo0@3ooo]ZoookJP0=oook
JP03ool00?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0Aoook
JP001ooonfX00ol0003ooo]ZoookJP0doookJP03ool00?oonf[ooo]Z043ooo]Z0_oo10001Ooonf[o
0000o`000?l0003oo`/002Kooo]Z0_oo3005oookJP03ool:0?oonf[ooo]Z00Cooo]Z00?oo`D0oook
J_oonfX02_oonfX00ooo7@3ooo]ZoookJP0ZoookJP03oolL0?oonf[ooo]Z00Gooo]Z0_oo2008oook
JP03oolM0?oonf[ooo]Z00Kooo]Z0_ooN`03oookJP03oomF0?oonf[ooo]Z00;ooo]Z0_l0Kol2oook
JP03o`3@oom/o`3o06oo00?o06oo0_oonfX01?l0d?oooo]Zo`1_ool0Kol2oookJP04o`3oT?oonf[o
oo]Zo`3@o`;o0?n@1OooI@05oookJP03ofco0?oonf[ooo]Z01gooo]Z0_oo<P07oookJP?ooah000Co
ocL0oookJ_oonf[ooo]Z0_oo:`05oookJP03oolG0?oonf[ooo]Z01_ooo]Z0ol00013oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX03ooonfX00ooo0`3ooo]ZoookJP0joookJP03o`00
0?oonf[ooo]Z017ooo]Z0007oookJP03o`000?oonf[ooo]Z03Oooo]Z00Coo`40oookJ_oonf[oo`@0
??oonfX3o`0000?ooo]Z00?oo`/0oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP03oookJP03ool5
0?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX01?oonfX2ool002cooo]Z0_oo7P07oookJP03oolT
0?oonf[ooo]Z00?ooo]Z0_oo7@05oookJP?oog/01OoonfX00oooEP3ooo]ZoookJP05oomF0005olWo
0?l0d?oobOl0o`1_ooo9o`001ooo>`002ooonf[o06ooo`1_ool0oi3oob`0o`3@ool0oi3oob`0oomU
0?l0oi3oofD000?ooo]Z1?oo=`000ooonf[oK?l0oookJP0MoookJP?ooc801ooonfX2oolN00?oocL0
2?oonfX00ooo5`3ooo]ZoookJP02oookJP03ool/0?oonf[ooo]Z00Kooo]Z00?oo`H0oookJ_oonfX0
2ooonfX00ooo003o0000o`00000<oookJP03ool30?oonf[ooo]Z00cooo]Z00?oo`/0oookJ_oonfX0
3OoonfX2ool@01[ooo]Z00?o0000oookJ_oonfX04ooonfX00ooo0P3ooo]ZoookJP0=oookJP;oo`00
4?oonfX00ooo003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z017ooo]Z0007oookJP03o`000?oo
nf[ooo]Z03[ooo]Z00?oo`@0oookJ_oonfX0=ooonfX3o`000003oookJ_oo0@3ooo]Z00Cooo]Z00?o
o`00oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o
oa40oookJ_oonfX01OoonfX2oolV00Oooo]Z0_oo:`0CoookJP03oolN0?oonf[ooah000Gooo]Z1?oo
9003oookJP05oolM0?oonf[oog/0oomk0?oo8P000_ooN`07oookJPCooeH000cooo]Zo`1_oooonf[o
bOl0o`1_ool0d?oobOl0o`3@ool0Kooooo]ZolWo0?oo>`03oookJPCo06oo00Cooo]Zo`1_oooo;03o
0=3o1?oonfX00ol0oi3ooo]ZoookJP02oolg00Gooo]Z00?oK?l0oookJ_oonfX00_oonfX00ooo<P3o
oo]Zoolb0002oolb00_ooo]Z00?oo`00oookJ_oonfX02OoonfX00ooo<P3ooo]ZoookJP07oookJP?o
ocL02ooonfX3ool/01;ooo]Z0ol0000IoookJP;oo``00ooonfX00ooo2`3ooo]ZoookJP06oookJP;o
o`L01_oonfX00ooo403ooo]ZoookJP04oookJP;oo`803ooonfX01?oo003ooo]ZoookJ_l0001Boook
JP03o`000?oonf[ooo]Z017ooo]Z0007oookJP03o`000?oonf[ooo]Z04Kooo]Z00?oo`00oookJ_oo
nfX0:?oonfX3o`0000oooo]Z00?oo`00oookJ_oonfX00ooonfX00ooo0`3ooo]ZoookJP03oookJP03
ool<0?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX01ooonfX2ool>00Kooo]Z00?oo`/0oookJ_oo
nfX01OoonfX00ooo4@3ooo]ZoookJP03oookJP;oobH01ooonfX2ool[02Kooo]Z0oooN`000ooo8P3o
oo]ZoookJP07oookJP05oomF0?oonf[ooo]ZoookJ_l0Kol00_oonfX01?l0Kooo0=3ooonG0?l0Kol4
olWo0003o`3@oooonf[ooo]Z00;ooo]Z00?o0=3ooookJ_l0Kol00ol0Kol2oomB00?ooo]Z00?o0?n@
oookJ_oonfX01ooonfX00om/o`3ooo]ZoookJP03oolb02Oooo]Z00?oocL0oookJ_oonfX00_oonfX3
oolH00Cooo]Z00Coob`0oookJ_oo;03oob`00_oonfX2oolC00Sooo]Z1?l000000ooo203ooo]Zoook
JP1;oookJP03o`000?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX03ooonfX00ooo0@3ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z017ooo]Z0007oookJP03o`000?oonf[ooo]Z04Wooo]Z0_oo0@0S
oookJP?o00005ooonfX00ooo0`3ooo]ZoookJP04oookJP03ool<0?oonf[ooo]Z00?ooo]Z0_oo500H
oookJP03o`000?oonf[ooo]Z00kooo]Z00?oo`/0oookJ_oonfX01?oonfX2ool400Gooo]Z0_oo9P00
0ooo003ooo]ZoookJP03oookJP?oob/08OoonfX3oolM0003oookJ_ooN`3oog/000;oog/000?ooo]Z
oolS0?oonfX02ooonfX01_l0Kooooo]ZoonG0?l0Kooo0=3oo`1_o`GooiL000?o0=3ooonG0?ooU`00
1?ooU`000ooonf[o0=3ooookJP05oomB00;ooo]Z00Co0?n@oookJ_oonf[ooo]Z1?oo8P02oookJP04
ofco0?oonf[ooo]ZoookJPCoobH0;ooonfX2oolR00Gooo]Z00?ooa<0oookJ_oonfX01?oonfX3o`00
00?ooo]Z0_oo200=oookJP03ool00?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX03?oonfX00ooo
1@3ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01[ooo]Z00?oo`40oookJ_oonfX03OoonfX00ooo
0@3ooo]ZoookJP0>oookJP03ool00?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX04OoonfX000Ko
oo]Z00?o0000oookJ_oonfX0C_oonfX01?oo103ooo]ZoookJ_oonfX2ool801Sooo]Z0ol0000Joook
JP03ool30?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX00ooonfX00ooo003ooa@0oolD000Joook
JP03o`000?oonf[ooo]Z01?ooo]Z00?ooa00oookJ_oonfX03_oonfX2ool>00Oooo]Z0_oo=`0Ioook
JP03oolM0?oonf[ooad000;ooo]Z00?oog/0oookJ_oonfX00ooo8`05oookJP?oobT00_oonfX01_l0
KoooK?l0ofco0?m/o`3o06oooonG00;o0=3o00GobOl0oookJ_oonf[ooo]Zo`3@o`05oookJP04o`3@
ooo9o`3obOl0olWo00;ooe800_oonfX4oomB00?ooo]Z0oooM003oookJP03ofco0?oonf[ooo]Z00;o
obH00_oonfX2oonG00Kooo]Z0ooo8P0;oookJP03ool50?oonf[ooo]Z00[ooo]Z00?oo`D0oookJ_oo
nfX02OoonfX2oolR00Wooo]Z0ol00002oolV037ooo]Z00?oo`D0oookJ_oonfX01OoonfX00ooo1`3o
oo]ZoookJP06oookJP03ool:0?oonf[ooo]Z00?ooo]Z00?oo`<0oookJ_oonfX02OoonfX01Ooo3P3o
0000oookJ_oonf[oo`0004gooo]Z00?o0000oookJ_oonfX04?oonfX000Kooo]Z00?o0000oookJ_oo
nfX03OoonfX00ooo0@3ooo]ZoookJP12oookJP03ool80?oonf[ooo]Z00?ooo]Z00?oo`00oookJ_oo
nfX03_oonfX3o`0002kooo]Z0_oo0@0FoookJP03o`000?oonf[ooo]Z01;ooo]Z0_oo4005oookJP;o
o`l01_oonfX00ooo2`3ooo]Zool>0007oookJP03oolg0?oonf[ooo]Z00Cooo]Z00?oocd0oookJ_oo
nfX00_oo?@0QoookJP05oolY0?m/o`3oK?l0ofco0?l0Kol00_oonfX00ol0<_oo06ooo`0bo`04o`0b
o`;ooo]Z00?o0=3ooookJ_oonfX00_oonfX01_l0d?oooo]Zo`3@oooonf[o06oooookJPKobOl000?o
0?n@oookJ_oonfX01?ooM004oookJP04ofco0?oonf[ooo]ZoookJPGooiL01OoonfX00ooo8P3ooo]Z
oookJP0VoookJP03oolR0?oonf[ooo]Z00?ooo]Z0ol00003oookJP03oolV0?oonf[oobH000;ooa00
2_oonfX3oolR04Cooo]Z00?oo`h0o`000?oonfX04_oonfX00ooo003ooo]ZoookJP0?oookJP03ool0
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX04?oonfX000Kooo]Z00?o0000oookJ_oonfX0G?oo
nfX00ooo003ooo]ZoookJP07oookJP?o0000;_oonfX00ooo1@3ooo]ZoookJP03oookJP05ool20?oo
nf[ooo]ZoookJ_oo2`001_oonfX00ooo603ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z023ooo]Z
00?oo`/0oookJ_oonfX01OoonfX2oolg00Kooo]Z1?oo?@0QoookJP?oK?l000?ooo]Zo`0bool0<_l0
0ol0<_l00ol0Kooooo]Zo`1_o`02oookJP05o`0bool0d?oo03;ooookJ_l0d?l01?oonfX01?l0d?oo
oo]Zo`3@ool0Kol8oookJP?obOl000Cooo]Zoomd0?ooM03ooo]Z1OooM0000om/o`3ooo]ZoookJP05
oonG0003oookJ_ooA@3oodD000;oodD00ooo7@08oookJP04oomk0?oonf[ooaT0oolI01gooo]Z0ol0
000GoookJP03ool80?oo8P3ooo]Z00_ooo]Z00?oo`40oookJ_oonfX03?oonfX00ooo003ooo]Zoook
JP0=oookJP03ool10?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0@OoonfX00ooo003ooo]Zoook
JP09oookJP03o`000?oonf[ooo]Z013ooo]Z0006oookJP03o`000?oonf[ooo]Z067ooo]Z00?oo`<0
oookJ_l000000_l0000goookJP03ool20?oonf[ooo]Z00Cooo]Z00Coo`00oookJ_oonf[ooaP03?oo
nfX2o`0002Gooo]Z00?ooa80oookJ_oonfX00_oo=`06oookJP;oocd02?oonfX2oomH00Wooo]Z0_m/
o`0;oookJP?oK?l00ooonfX01?m8o`3o03;ooolN0?l0Kol3o`0bo`04oookJ_l0Kooooo]Zo`0bo`;o
ob@000Co06ooo`0bool0<_oo0=3o0_oonfX01Ol0d?oooo]ZoookJ_l0Kooo0=3o00[ooo]Z00Co0?n@
oookJ_oonf[oog@01_oonfX3oomd0005oookJ_ooU`3ooiL0oonG0?oonfX00_ooU`000oooA@3ooo]Z
oookJP03oom500Oooo]Z0oooN`0<oookJP;oo`T03?oonfX00ooo003o0000o`000002o`0000Sooo]Z
00?oo`T0oookJ_oonfX02ooonfX00ooo6@3oo`h0oookJP0^oookJP03ool10?oonf[ooo]Z00gooo]Z
0_oo1@02oookJP;oo`<01OoonfX00ol0003ooo]ZoookJP05oookJP03ool90?oo0@3oo`4004Cooo]Z
00?o0000oookJ_oonfX04?oonfX000Kooo]Z00?o0000oookJ_oonfX08?oonfX2ool103kooo]Z0ol0
0002oookJP05ool80?oonf[ooo]ZoookJ_oo0000@?oonfX00ooo003ooo]ZoookJP09oookJP03o`00
0?oonf[ooo]Z02;ooo]Z0_oo4P06oookJP;ooa402_oonfX00oooF03ooo]ZoookJP07oookJP04ofco
0?ooH`3oof<0ofco00Oooo]Z1?m/o`04oookJP;oB?l000?ooo]Zo`0bool0<_l00_oonfX00ol0Kooo
oo]Zo`0bo`02o`0bo`;ooo]Z00Ooob@0oookJ_l0Kooooo]Zo`0boooonf[o0=3o00;ooo]Z00Co06oo
oolR0?oo8P3o0=3o2_oonfX00ol0oi3oo`00oookJP08oookJP05ofco0?oonf[ooo]ZoookJ_ooU`00
0ooonfX2oonG00Wooo]Z1?ooDP000oooN`3ooaL0oookJP0FoookJP?o00003?oonfX00ooo2@3ooo]Z
oookJP0;oookJP03oolI0?oonf[ooo]Z00[ooo]Z0_oo2002oolM00_ooo]Z00?oo`<0oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP03oookJP;oo`T04OoonfX00ooo003ooo]ZoookJP0?oookJP03ool0
0?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX04?oonfX000Kooo]Z00?o0000oookJ_oonfX08ooo
nfX00ooo0`3ooo]ZoookJP0goookJP?o00003OoonfX00ooo003ooo]ZoookJP0eoookJP;oo`P01?oo
nfX2ool500Cooo]Z00?oo`T0oookJ_oonfX00ooonfX00ol0003ooo]ZoolM000boookJP03ool90?oo
nf[ooeP000Gooo]Z00?oof<0oookJ_oo00000oooH`03oookJP05ofco0?oonf[ood/0oookJ_m/o`00
1?ooB`03oookJP?oB?l00_oonfX01Ol0<_ooB?l0o`0bool0<_oo06oo00?ooo]Z00?o03;oo`1_ool0
<_l00_l0<_l01?oonf[ooaX0o`1_oooo6P02o`0bo`;ooo]Z00Go06oooookJ_oonf[ooo]Zo`3@o`0:
oookJP03o`3oT?oonf[ooo]Z00Sooo]Z00?oK?l0oookJ_oonfX01_oonfX3oonG00Oooo]Z1?ooDP0:
oookJP?ooa@02?oonfX3o`0001kooo]Z00?ooaT0oookJ_oonfX02ooonfX00ooo7@3ooo]ZoolM000:
oookJP03ool30?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX03OoonfX00ooo003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX04?oonfX000Gooo]Z00?o0000oook
J_oonfX0G?oonfX2o`0001Gooo]Z00?oo`80oookJ_oonfX0=ooonfX00ooo1@3ooo]ZoookJP03oook
JP;oo`400ooonfX2oolM00Oooo]Z0_oo:00UoookJP?ooa<00_oonfX2oomH00Gooo]Z1?ooH`001?oo
nf[oK?l0oookJ_m/o`02oookJP03ofco0?ooB`3ood/000;ood/01OoonfX7odSo0003o`0boooonf[o
06oo00;o03;o0_oonfX00ol0<_oooo]Zo`1_o`03oookJP?o03;o0ooonfX00ol0<_oo06oooookJP02
oookJP;ooad000?o0=3ooookJ_oonfX02?oonfX00ol0oi3ooo]ZoookJP0CoookJP03oonG0?oo7@3o
oo]Z00Gooo]Z00?ooe80oookJ_ooN`000oooDP07oookJP?ooeH01OoonfX3o`0000;ooo]Z0_oo2`0<
oookJP03ool00?oonf[ooo]Z05Wooo]Z00?oo`80oookJ_l000003ooonfX00ooo0@3ooo]ZoookJP0>
oookJP03ool00?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX04?oonfX000Gooo]Z00?o0000oook
J_oonfX0=OoonfX00ooo003ooo]ZoookJP0QoookJP?o00007?oonfX2ool80005ool00?oonf[ooo]Z
oookJ_oo4000=OoonfX01?oo2`3ooo]ZoookJ_oonfX2oolM0003o`000?oo003ooo]Z00;ooo]Z0_oo
:00/oookJP?ooeP00ooo5003oomS00;ooo]Z00?oK?l0oolA0?oo4@000om/o`000ooonf[oK?l0oom;
0006oookJP?oB?l000?oolT0oome0?ooM@000_oonfX01Ol0<_oooo]Zo`1_ool0<_oooo]Z00;o03;o
0ooonfX00ol0Kooooo]ZoookJP03oookJP?o03;o00?o06ooo`0bool0<_l01OoonfX00ol0d?oooo]Z
oookJP04oookJPCooa`000?o0?n@oookJ_oonfX01_oonfX2ool800_ooo]Z0_oo7@08oookJP04oomk
0?oonf[ooo]ZoomB00Kooo]Z00CooeH0oookJ_ooEP3ooo]Z1?l0000QoookJP03ool00?oonf[ooo]Z
00_ooo]Z00?oo`/0oookJ_oonfX02?oonfX2ool800;ooo]Z0_oo5008oookJP;oo`<0:?oonfX00ol0
003ooo]ZoookJP0<oookJP03ool50?oonf[ooo]Z023ooo]Z00?oo`00oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP0@oookJP001OoonfX00ol0003ooo]ZoookJP0goookJP03ool30?oonf[ooo]Z01co
oo]Z0ol0000ToookJP;ooa0000?oo`00oookJ_oonfX0>?oonfX2ool800?ooo]Z0_oo:0000ooonf[o
o`H0oookJP06oookJP03oolT0?oonf[ooo]Z027ooo]Z00?ooeP0oookJ_oonfX01_oonfX5ofco00?o
oo]Z00CoK?l0oookJ_oonf[ooo]Z0_oo1@001Ooonf[oolT0ooo90?oob@3oB?l000?oogD00_m8o`04
oome0003o`0booooM@3oogD000?ooo]Z00?o06oooookJ_oonfX01?oonfX2o`1_o`Co03;o1OoonfX0
0ol0d?oooo]ZoookJP05oookJP04oolH0?oonf[ooo]Zo`3oT0Oooo]Z00?oo`P0oookJ_oonfX02Ooo
nfX00ooo7@3ooo]ZoookJP09oookJP03oomk0?oonf[ooo]Z00Oooo]Z00CooeH0o`000?ooEP3ooeH0
1_oonfX2ool@00;ooo]Z0ooo>`06oookJP03ool;0?oonf[ooo]Z01cooo]Z00?oo`/0oookJ_oonfX0
3?oonfX2oolD00oooo]Z0_oo5`06oookJP;oo`003ooonfX00ooo003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX03ooonfX000Gooo]Z00?o0000oookJ_oonfX0>_oo
nfX2ool701Oooo]Z0ol0000^oookJP03ool10?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX00_oo
nfX2ool500Kooo]Z00?oob@0oookJ_oonfX01_oonfX2oolh02;ooo]Z1_m/o`001?oob@3ooa@0oook
J_m/o`03oookJP?oolT00ooonfX6oome0005o`0boooonf[oom<0oooC0?l0<_l00_l0Kol01Om8o`3o
oo]ZoookJ_oonf[o06oo00Gooo]Z0_l0Kol3oookJP;o03;o1OoonfX00ol0d?oooo]ZoookJP04oook
JP?ooaP000?ooo]Zo`3oT?oonfX01OoonfX2oolG01Oooo]Z00?oog/0oookJ_oonfX00ooonfX3o`00
00Cooo]Z00?ooeH0oookJ_oonfX01ooonfX4oolk00Gooo]Z00?oo`/0oookJ_oonfX02_oonfX2ool2
00gooo]Z00?oo`00oookJ_oonfX08?oonfX2oolG02;ooo]Z00?o0000oookJ_oonfX00ooonfX00ooo
003ooo]ZoookJP0NoookJP03ool00?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX03ooonfX000Go
oo]Z00?o0000oookJ_oonfX0AooonfX00ooo003ooo]ZoookJP06oookJP?o0000=_oonfX00ooo0@3o
o`L0oookJP03oookJP03ool00?oo4P3ooo]Z02_ooo]Z00?o0000oookJ_oonfX01ooonfX00ooo2`3o
ob@0oolT0005oookJP?oocP09_oonfX3ofco00;oolT00om/o`03ooo900?ooo]Z0_oo5004oookJP03
oome0?m8o`3o03;o00;oom<000?ooo]ZoooC0?l0<_l00_oonfX2o`1_o`;oB?l000?o06ooodSo0?m8
o`000ooonfX00ol0Kooooo]Zo`1_o`03oookJP;oofX01OoonfX00ol0d?oooo]ZoookJP07oookJP03
o`3oT?oonf[ooo]Z00;ooo]Z0oood`0;oookJP04ool<0?oonf[ooo]ZoookJPCoolT02?oonfX3o`00
00Kooo]Z0_oo8P000oooEP3ooo]ZoookJP06oookJP06oom00?oo>`3ood00oookJ_oo>`3ooo]Z0_oo
3P0[oookJP03ool20?oonf[ooo]Z01Gooo]Z00?oo`@0oookJ_oonfX03?oonfX00ooo0@3ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z01?ooo]Z0_oo0P0PoookJP03ool00?oonf[ooo]Z013ooo]Z00?o
0000oookJ_oonfX03ooonfX000Gooo]Z00?o0000oookJ_oonfX0B_oonfX00ooo0P3ooo]ZoookJP03
o`0003kooo]Z00?oo`00oolB0?oo4P000ooonfX00ooo003ooo]ZoookJP0WoookJP03o`000?oonf[o
oo]Z00Oooo]Z00?oo`/0oookJ_oonfX00ooonfX3oolh00Sooo]Z00?oobT0oookJ_oonfX07ooonfX0
0ooob@3oK?l0ooo90002ooo900gooo]Z00?oB?l0o`0booood`000_ood`000ol0<_oo00[oo`0bo`05
o`0:o`03oooC0?l0Koooom<000;oom<000?o06oooooC0?ood`000_ood`07oomZ00?ooo]Z00?o0=3o
oookJ_ooV`000_ooV`05oookJP03o`3oT?oonf[oom<000Goom<000?ooa@0oookJ_oonfX02_oonfX0
0oooV`3oolT0oonK0003ooo900?ooo]Z00Co0000ool00?l0003o00002OoonfX00ooo8P3ooo]Zoook
JP09oookJP05oom00?oonf[ooo]ZoookJ_oo>`002?oonfX2oolh00?ooo]Z0_oo2P0^oookJP03ool;
0?oonf[ooo]Z00kooo]Z00?ooa00oookJ_oonfX00ooonfX00ooo0@3ooo]ZoookJP0=oookJP05ool0
0?oonf[ooo]ZoookJ_l00000BOoonfX00ol0003ooo]ZoookJP0?oookJP001OoonfX00ol0003ooo]Z
oookJP1:oookJP?o000000?ooo]Zool60?oonfX02?oonfX00ooo003ooo]ZoookJP0loookJP;oo`<0
0_oonfX00ooo1@3ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00gooo]Z00?oocP0oookJ_oonfX0
1OoonfX00ooo0`3ooo]ZoolY0007oookJP;ooeH05ooonfX4ooo90003oonK0?oonf[ooo]Z00Oooo]Z
0_l0oa<01?oo4`3ooo]ZoookJ_oonfX5o`0:o`03oooC0?l0<_oooo]Z00;ooo]Z00Co00[oo`1_ool0
2_oo06oo0_oonfX00ol0Kooooo]ZoookJP02oookJP03odSo0?l0<_ooB?l000;oofX000?oB?l0oook
J_oonfX01_ooJP02oonK00Kooo]Z00?o0?n@oooC0?oonfX01?ood`09oookJP;ooa<000?ooo]ZoonK
0?ooV`000_oob@03oookJP03ooo90?l0003o000000gooo]Z00?oob80oookJ_oonfX02_oonfX00ooo
@03ooo]ZoookJP09oookJP?oocP03ooonfX2ool400gooo]Z00?oo`00oookJ_oonfX08OoonfX2ool@
01[ooo]Z00?o0000oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z
00oooo]Z0004oookJP03o`000?oonf[ooo]Z00gooo]Z00?oo`80oookJ_oonfX0>?oonfX3o`0001;o
oo]Z00?oo`40oookJ_oonfX0>ooonfX2ool50003oookJ_oo003oo`0000;ooo]Z00?ooa@0oookJ_oo
nfX07?oonfX00ol0003ooo]ZoookJP0AoookJP;oo`d00_oonfX2oolY00Gooo]Z00?oo`00oomF0?oo
nfX02?oonfX3oomA00cooo]Z1_oob@000oooV`3ooo]ZoookJP04oookJP;o0?lC00?ooo]Zo`3o4ooo
nfX00_oonfX01?l0oi3o00[oo`3oT?l0<_l3o`0:o`04oolD0?l0<_oooo]Zo`0:o`;ooo]Z00Co03;o
o`0:ool02_oo06oo1OoonfX01_l0<_oooo]Zo`1_oooonf[oofX0oookJPKoB?l02?ooV`02oookJP03
oomU0?l0oi3oom<000;ooo]Z0oood`0<oookJP06oonK0?oob@3oolT0ooo90?l0003oolT00_oonfX2
ool<00_ooo]Z00?oo`40oookJ_oonfX03?oonfX00ooo@03ooo]ZoookJP0;oookJP03oolh0?oonf[o
oo]Z00Wooo]Z00?oo`T0oookJ_oonfX07_oonfX00ooo003ooo]ZoookJP0QoookJP;oo`802ooonfX0
0ol0003ooo]ZoookJP0KoookJP03ool10?oonf[ooo]Z01gooo]Z00?oo`00oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP0?oookJP001?oonfX00ol0003ooo]ZoookJP15oookJP?o00005OoonfX00ooo
0@3ooo]ZoookJP11oookJP;ooa@00_oonfX01Ooo003ooo]ZoookJ_oonf[oob8001Sooo]Z00?o0000
oookJ_oonfX06?oonfX2ool<00;ooeH01?oonfX00ooo203ooe40oomA0003oomA017ooo]Z00Cooi/0
ooo90?ooV`3ooi/01?oonfX3o`3o4`;ooo]Z0ol0oa<2o`3oT007oookJ_l02_oo00[ooookJ_ooI@3o
om<0oookJP03o`0:o`Cooo]Z00Co03;oo`1_ool02_oo00[o0ooonfX01_l0<_oooo]ZoookJ_oonf[o
06ooool500Oooo]Z00?oB?l0oonK0?ooV`001OoonfX5oonK0003oooC0?oonf[oom<000;ooo]Z0ooo
d`09oookJP05ofco0?ooV`3oolT0oookJ_oob@000oo9o`000ooo403ooo]ZoookJP0:oookJP03ool1
0?oonf[ooo]Z00[ooo]Z00?oo`80oookJ_oonfX02_oonfX2oolL00;ooo]Z00?oocP0oookJ_oonfX0
1ooonfX00ooo:P3oo`T0oookJP0;oookJP;oo`@08_oonfX00ooo103ooo]ZoookJP0OoookJP04o`00
0?oonf[ooo]Zool004Cooo]Z00?o0000oookJ_oonfX03ooonfX000Cooo]Z00?o0000oookJ_oonfX0
@_oonfX3o`0001cooo]Z0_oo1@07oookJP03ool00?oonf[ooo]Z03[ooo]Z0_oo8P02oookJP?oo`80
5OoonfX00ol0003ooo]ZoookJP0HoookJP;ooeH01OoonfX01Ooo203ooe40oomA0?oonf[oob8000Co
oo]Z00?oo`40oookJ_oonfX00_ooU`0:oookJP;ooi/00ooonfX2o`3o4`03oookJ_l0oa?o0?lC00?o
0?lC00Kooo]Zo`3o4ooonf[ooo]Zo`0:ool0<_l2o`0:o`Cooo]Z00?o00[oo`0bool02_l00ol02_l0
1Ooonf[o03;ooookJ_oo4P3o00[o00;ooo]Z00?o03;ooookJ_oonfX00_oonfX00ol0Kooooo]Zoook
JP07oookJP03oonK0?oonf[ooo]Z00?oofD00_oonfX00oooI@3ooo]ZoookJP02oonK00Kooo]Z0_oo
d`03oookJP?o000000OoK?l0oonK0?oonf[ooo]ZoomZ0?o9o`3oolT000;obOl02ooonfX2ool;01_o
oo]Z00?ooa`0oookJ_oonfX02_oonfX2oolZ01_ooo]Z00?oo`40oookJ_oonfX08_oonfX2ool:017o
oo]Z00?o0000oookJ_oonfX04?oonfX00ooo003ooo]ZoookJP0?oookJP03ool00?oonf[ooo]Z023o
oo]Z00?o0000oookJ_oonfX03_oonfX000Cooo]Z00?o0000oookJ_oonfX08OoonfX00ooo0P3ooo]Z
oookJP0KoookJP?o00009?oonfX00ooo3@3ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z03Kooo]Z
0_oo8P04oookJP03ool20?oonf[ooo]Z00?ooo]Z00?ooa@0oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP0GoookJP?ooeH01_oonfX2oomA00;oob800ooonfX00ooo0@3ooo]ZoonG000:oookJP;oohH0
0ooonfX5o`3o4`;o0?n@0_oonfX00ol0oa?ooo]Zo`3o4`02oookJP03o`0:ool0<_oooo]Z00;o00[o
0_oonfX00ol02_oooo]Zo`0bo`04oookJP?o00[o0_oonfX00ol02_oo03;ooookJP05oookJP03o`1_
oooo4@3ooo]Z00Oooo]Z00?o0=3ooomU0?oonfX02?oonfX00ol0oi3ooo]ZoookJP06oookJP;oom<0
00?o0000oookJ_oonfX01?m/o`03oomZ0004ofco0?oob@3obOl0olWo00Sooo]Z0_ooM@0=oookJP03
ool30?oonf[ooo]Z01cooo]Z00?oobX0oookJ_oonfX02_oonfX2oolX00Oooo]Z00?oo`D0oookJ_oo
nfX04OoonfX00ooo003ooo]ZoookJP0UoookJP;oo`h000?o0000oookJ_oonfX01_oonfX00ooo003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z00kooo]Z0004oookJP03o`000?oonf[ooo]Z02?ooo]Z
00?oo`D0oookJ_oonfX05_oonfX3o`0003Cooo]Z00?oo`@0oookJ_oonfX0??oonfX2oolD0003ool0
0?oo1`3ooo]Z00?ooo]Z00?oob`0oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0ToookJP;o0?n@
00Kooo]ZoonG0?oonf[ooo]Zool;0?ooQP03oookJP04ool80?ooQP3oohH0oon600Cooo]Z1?l0oa<0
0ol0oi3ooo]ZoookJP03oookJP03o`3o4ooonf[o0?lC00;ooo]Z00So00[ooookJ_l0<_oo00[ooook
J_l02_oooo]Zo`0:o`;ooo]Z00?o03;ooookJ_oonfX01?oonfX3o`0:o`03oookJ_l02_oo00[o00Go
oo]Z00?o06ooool@0?oonfX01ooonfX00ol0d?ooo`T0oookJP08oookJP03o`3oT?oonf[ooo]Z00;o
oo]Z0ol00002oookJP?oom<000GoK?l0oonK0?oonf[obOl0ofco0005oomZ0003olWo0?oonf[ooo]Z
00Gooo]Z1?ooM@0IoookJP03ool00?oonf[ooo]Z01gooo]Z0_oo:006oookJP03ool50?oonf[ooo]Z
00_ooo]Z00?oo`40oookJ_oonfX04ooonfX00ooo0@3ooo]ZoookJP0>oookJP03ool40?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX05ooonfX00ooo003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
00kooo]Z0004oookJP03o`000?oonf[ooo]Z03Cooo]Z00?oo`40oookJ_oonfX00_oonfX3o`0003Oo
oo]Z00?oo`@0oookJ_oonfX01?oonfX00ooo003ooo]ZoookJP0koookJP;oob`000?ooo]Zool00?oo
nfX02OoonfX00ol0003ooo]ZoookJP0PoookJP?o0?n@00?ooo]Zo`3oT?ooU`000ooonfX2oon60004
oookJ_ooQP3oohH0oon600?ooo]Z00?oo`H0oookJ_l0oi000ol0oi000ol0oa?ooo]Zo`3o4`05o`3o
4`03oookJ_l0oa?ooo]Z00;ooo]Z00Oo00[ooookJ_oonf[o00[oo`0boooonf[o00[o00?ooo]Z00?o
03;ooookJ_oonfX01OoonfX00ol0<_oooo]Zo`0:o`03o`0:o`Cooo]Z00?o06ooool@0?oo40002?oo
nfX00ol0d?oooo]ZoookJP08oookJP04ool00?l0003o0000o`0000Sooo]Z00?oom<0ofco0?o`o`00
0_o`o`001Ooonf[oofX0olWo0?o9o`3ooo]Z00?oofX01OoonfX01?ooM@3ooo]Zoome0?oonfX2o`3o
T0;ooeP01_oonfX00ooo2P3ooo]ZoookJP0:oookJP03ool50?oonf[ooo]Z00gooo]Z00?oo`H0oook
J_oonfX02ooonfX2oolG00Cooo]Z00?oobP0oookJ_oonfX04OoonfX00ooo0@3ooo]ZoookJP0<oook
JP;oo`005_oonfX00ooo103ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00Gooo]Z00?oo`T0oook
J_oonfX08?oonfX00ooo003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00kooo]Z0003oookJP03
o`000?oonf[ooo]Z03Gooo]Z00?oo`40oookJ_l000000_l0000ooookJP03ool=0?oonf[ooo]Z00Co
oo]Z00?oo`00oookJ_oonfX0=_oonfX2ool/00Oooo]Z00?oo`P0oolA0?oonfX00ooonfX00ol0003o
oo]ZoookJP0NoookJP03o`3oT?oonf[o0?n@00?ooiL000?o0?n@oookJ_oonfX01?ooQP000ooonf[o
o`h0ool>0002oookJP?o0?n@00Kooo]Zool=0?oo3@3ooo]ZolWo0?l0oa<2oookJP03ool00?oonf[o
oo]Z00Ko0?lC00Co00[ooookJ_oonf[ooo]Z0_l02_l00ol0<_oo00[ooookJP02oookJP03o`0boooo
nf[ooo]Z00?ooo]Z00?o03;ooookJ_l0<_l00ooonfX2o`0:o`Cooo]Z00?o06oooookJ_oonfX01_oo
nfX2ool?0003o`3@oooonf[ooo]Z00Cooo]Z1?l00009oookJP;oK?l000?ooi/0oo3o0?o`o`000oo`
o`002?oonf[obOl0olWo0?m8o`3ooo]Zooo90?m8o`3oofX00ooonfX01?l0oi3oogD0oome0?oonfX2
oome00CooeP000?o0?n@oookJ_oonfX01?oonfX2oomS00Sooo]Z0_oo1@0<oookJP03ool00?oonf[o
oo]Z00oooo]Z00?ooaL0oookJ_oonfX03?oonfX00ooo7P3ooo]ZoookJP0WoookJP03ool00?oonf[o
oo]Z00oooo]Z00?o0000oookJ_oonfX01?oonfX00ooo2@3ooo]ZoookJP0koookJP03o`000?oonf[o
oo]Z00kooo]Z0003oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol000000ooonf[oo`@0oookJP1;oook
JP03ool30?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX0=_oonfX00ooo4@3ooo]ZoookJP03oook
JP03ool70?oonf[oocX001gooo]Z0_l0oi001_ooU`3ooo]ZoonG0?ooU`3o0?n@oookJPGoohH00_oo
nfX3o`3oT0Cooo]Z0_oo3@000oo9o`3ooo]ZoookJP02o`3o4`04oookJ_o`o`3ol?l0o`3o4`;ooi<0
0_oonfX00ol02_oonOl0ooWo0002o`3o4`03o`0:ooooT`3ooi<000;ooi<00_oonfX00ol0<_oooo]Z
oookJP03oookJP03o`0boooonf[o03;o00Cooo]Z00?o00[ooookJ_oonfX00ooonfX00ol0Kooooo]Z
oookJP08oookJP03o`3@oooonf[onOl000?onOl00_oonfX2ool;00Kooo]Z0om/o`02oookJP05ool1
0?o`o`3ol?l0oookJ_m/o`000_o`o`000oo9o`3oB?l0oookJP02odSo0004ooo90?m8o`3ooo]Zoook
JPOo0?n@0_ooM@000oooF03ooo]ZoookJP03o`3oT0?ooo]Z0oooH`05oookJP;oo`T03_oonfX00ooo
003ooo]ZoookJP0;oookJP03ool00?oonf[ooo]Z017ooo]Z00?ooah0oookJ_oonfX03ooonfX2ool2
02Kooo]Z00?oo`40o`000?oonfX07_oonfX00ooo003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
00kooo]Z0003oookJP03o`000?oonf[ooo]Z037ooo]Z0ol0000CoookJP03ool00?oonf[ooo]Z047o
oo]Z00?oo`d0oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP0foookJP;oo`L000?oocX0oookJ_oo
nfX00ooonfX01?oo103ooo]Zoom;0?ooB`0CoookJP?o0?n@1OooU`001Ol0oi3ooo]ZoookJ_oonf[o
ohH000?o0?n@2OoonfX01?o9o`3ooo]Zoo3o0?o`o`02o`3o4`04oookJ_oo2@3ooi<0oookJPSooi<0
00Coo`80o`0:ool0oa?o0?lC0_l0<_l00ol0oa?o03;ooookJP03oookJP05o`0boooonf[ooo]Zoook
J_l0<_l00_oonfX00ol02_oooo]ZoookJP05oookJP03o`1_oooonf[ooo]Z00Kooo]Z2?oio`02oook
JP;oo`h00_oonfX3ofco00Gooo]Z0oo`o`02oookJP03ofco0?o`o`3oB?l000;oB?l00_oonfX3odSo
0003oookJ_l0oi3ooo]Z00?ooo]Z00Go0?n@oookJ_oonf[ooo]Zoome0006o`3oT0;ooo]Z0_ooH`0C
oookJP03ool50?oonf[ooo]Z00kooo]Z00?oo`00oookJ_oonfX03?oonfX00ooo203ooo]ZoookJP0T
oookJP03ool00?oonf[ooo]Z01Cooo]Z00Coo`40oookJ_oonf[o00003ooonfX00ooo1@3ooo]Zoook
JP0NoookJP03ool00?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX03_oonfX000?ooo]Z00?o0000
oookJ_oonfX0;_oonfX3o`0001[ooo]Z00?oo`@0oookJ_oonfX0?OoonfX00ooo3@3ooo]ZoookJP08
oookJP04ool10?oonf[ooo]Zool102oooo]Z0_oo>P000ol0003ooo]ZoookJP03oookJP;ood/000?o
o`T0oookJ_oonfX04OoonfX2o`3oT003oookJ_l0oi3ooiL000;ooiL00_oonfX00ol0oi3ooo]Zo`3o
T002o`3oT0?ooo]Z0_o`o`06oookJP?ol?l01?oonfX00ol0oa?ooi<0oonC0002oonC00;onOl000Co
00[ooookJ_oio`3o00[o0_oo0P001Ol02_oooo]ZoookJ_oonf[o0=3o00?o03;o0_l0oa<00ol0<_oo
0?lCoookJP03oookJP03o`0bool02_oooo]Z00Sooo]Z00?o06oooonm0?oo_@000ooonfX3o`0000Co
nOl00_oonfX01?oio`3ooo]ZoookJ_oonfX3ofco00Oooo]Z00?oo`/0oo3o0?o`o`000_o`o`001?m/
o`3ol?l0odSo0?m8o`04oookJP03odSo0?oonf[oB?l000;ooo]Z00?o0?n@oookJ_oonfX00_oonfX0
1Ol0oi3ooo]ZoookJ_ooF03oogD000;o0?n@00?ooo]Zo`3oT?l0oi001?oonfX00oooH`3ooo]Zoook
JP09oookJP;ood/04_oonfX00ooo0@3ooo]ZoookJP0@oookJP03ool80?oonf[ooo]Z00cooo]Z0_oo
4`0VoookJP03ool00?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03?oonfX00ooo1@3ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z00kooo]Z0003oookJP03o`000?oonf[ooo]Z02_ooo]Z0ol0000M
oookJP03ool40?oonf[ooo]Z04;ooo]Z0_oo6P03oookJP05ool10?oonf[ooo]ZoookJ_oo0@00;ooo
nfX2oolj0004oookJ_l0003ooo]ZoookJP;ood/01OoonfX2ool80004oookJ_oo003ooo]Zoom=00[o
oo]Z0_l0oi02oookJP04o`3oT?oonf[ooo]ZoookJPCo0?n@1OoonfX00oo`o`3ooo]Zoo3o0003oook
JP?ol?l000CobOl0oookJ_oonf[ooo]Z0_l0oe@2oookJP04o`3o4ooonf[o0?lCoonC00;onOl000Co
00[oooWo0?oio`3o00[o0ooio`000ol02_oonOl0ooWo0003ooWo0003o`0boooio`3o03;o00KonOl0
00?o00[oooWo0?oonfX01ooonfX4oonm00?o00001?oonfX00ooio`3ooo]ZooWo0002ooWo0004oook
J_m/o`3oK?l0ofco00[ooo]Z0_oo30001Ooonf[ol?l0ofco0?o`o`3oB?l000Gooo]Z0_m8o`001Ooo
nf[oB?l0odSo0?oonf[o0?n@00Cooo]Z0ol0oi001OooF03ooo]ZoookJ_oonf[o0?n@00Co0=3o0ooo
nfX00oooH`3ooo]ZoookJP08oookJP?ood/03_oonfX00ooo1@3ooo]ZoookJP0?oookJP03ool00?oo
nf[ooo]Z017ooo]Z00?ooa<0oookJ_oonfX03OoonfX2oolH00gooo]Z0_oo000BoookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX0;ooonfX00ooo003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z00gooo]Z0003oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000SoookJP;oo`T02OoonfX0
0ooo003ooo]ZoookJP0doookJP;ooaX02OoonfX2ool;00;ooo]Z00?oo`00oookJ_oonfX0:ooonfX0
1?l0003ooo]Zoom;0?ooB`0:oookJP04oom=0?oonf[ooo]Zool600;ooo]Z00Koo`40oookJ_ooM@3o
ogD0oookJ_l0oi04oookJP?o0?n@0ooonfX00ol0oi3ooo]ZoookJP02oookJP;ol?l000?ooo]Zoo3o
0?o`o`000_o`o`02oookJP03olWo0?oonf[ooo]Z00;o0?mD00?ooo]Zo`3oE?l0oe@00_oonfX2o`3o
4`;ooo]Z00GonOl0o`0:oooio`3o00[ooookJP03o`3@o`04o`0:oooonf[oo`d0ool=00;ooo]Z00Go
00[oo`0boooonf[ooo]ZoolM0003oookJP03o`0:oooonf[ooo]Z00Ko0?lC00?ooo]Zoonm0?oo_@00
0ooo_@08oookJP03ooWo0?oonf[o0=3o00ConOl03ooonfX01?o`o`3obOl0oo3o0?m8o`03oookJP03
odSo0?oo2P3oB?l000;ooo]Z00?oB?l0oookJ_l0oi000_oonfX3o`3oT003oookJ_oo003ooo]Z00;o
oo]Z00Co0?n@o`3@oooonf[o0=3o0_oonfX3o`3@o`03oookJ_ooH`3ooo]Z00Wooo]Z00?ood/0oolg
0?ooB`006_oonfX00ooo0P3ooo]ZoookJP0@oookJP;oo`405?oonfX2oolH01kooo]Z00Coo`00oook
J_oonf[o00005_oonfX00ooo0P3ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z00gooo]Z0002oook
JP03o`000?oonf[ooo]Z00gooo]Z00?oo`@0oookJ_oonfX05_oonfX3o`0003Gooo]Z00?oo`<0oook
J_oonfX0??oonfX00ooo2`3ooo]ZoookJP03oookJP06oolN0?oonf[ooo]Zool00?oonf[oo`809_oo
nfX2o`000003oom;0?oonf[ooo]Z00Kooo]Z0_ooC@07oookJP06oome0?oo2@3ooo]Zo`3oT?oo0P3o
oo]Z1?l0oi05oookJP04o`3oT?oonf[ooo]ZoookJPCol?l000?ooo]Zoo3o0?oonfX00ooonfX3o`3o
E0?ooo]Z0ol0oe@2oookJP08o`3o4ooonf[ooo]Zo`0:oooonf[o00[oooWo0?l0d?l2oookJP03ofco
0?l02_oooo]Z00Gooo]Z00Co00[ooookJ_oonf[ooo]Z0_oo30000ooonf[o00[ooookJP02oookJP05
o`0boooonf[ooo]Zool00?l000000ol0oa<9oonm0006oookJ_m/o`3oK?l0ooWo0?oonf[onOl00ooo
nfX2ooWo00gooo]Z00GobOl0oookJ_oonf[ol?l0odSo0002oookJP03odSo0?oonf[o0?lC00Go0?lC
0_l0oi02oookJP03ool50?l0oi3ooo]Z00;ooo]Z00?o0?n@o`3@oooonfX00_oonfX00ol0d?oooo]Z
oookJP02oookJP?o0=3o2OoonfX2oolg0003oookJ_ooB`3ooo]Z00Wooo]Z00?oocd0oookJ_oonfX0
6ooonfX00ooo003ooo]ZoookJP0AoookJP;oo`P0:?oonfX00ol0003ooo]ZoookJP0:oookJP03ool0
0?oonf[ooo]Z00Kooo]Z00?oo`80oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0=oookJP000_oo
nfX00ol0003ooo]ZoookJP0SoookJP?o0000AOoonfX00ooo003ooo]ZoookJP0doookJP;ooah02Ooo
nfX00ooo203oo`00ool0000QoookJP03o`000?oonf[ooo]Z00Gooo]Z0oooC@05oookJP;oogD00_oo
nfX4o`3oT0;ooo]Z00?ooeP0ool80?l0oi000_oonfX01Ooo003ooo]ZoookJ_l0oi3ooo]Z00Gol?l0
00Cooo]Zoo3o0?oonf[ooo]Z0_l0oe@00ooonf[o0?mDo`3oE004o`3oE003oookJ_l0oeCooo]Z00;o
oo]Z0_l0d?l2o`0:o`03oookJ_oio`3ooo]Z00?ooo]Z00?oK?l0o`0:oooonfX01OoonfX00ol02_oo
oo]ZoookJP02oookJP03o`0:oooonf[ooo]Z00?ooo]Z00Co03;oo`000?oo203oo`P01?oonfX2oonm
00;o0?lC0_oonfX2ofco00Kookd000?o0=3ooookJ_oonfX00_oonfX2ooWo00_ooo]Z00GobOl0oook
J_oonf[ooo]Zoo3o0002odSo0004oookJ_l0oa?oB?l0o`3oT0;o0?lC00Cooo]Zo`3o4ol0oi3ooo]Z
0_oo2@001_oonf[o0?n@oookJ_ooU`3o0?n@o`3@o`Cooo]Z00Go0=3ooookJ_oonf[oo`00ool>0003
oookJP?o0=3o1ooonfX01?oo=`3ooo]ZoookJ_ooB`08oookJP?oocd05ooonfX00ooo0P3ooo]Zoook
JP0GoookJP03ool80?oonf[ooo]Z00gooo]Z0_oo400HoookJP03o`000?oonf[ooo]Z03kooo]Z00?o
0000oookJ_oonfX03OoonfX000;ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0003oooo]Z00?oo`T0
oookJ_oonfX02_oonfX00ooo0@3ooo]ZoookJP0`oookJP;ooah02OoonfX00ooo203ooo]ZoookJP05
oookJP03ool00?oo103ooo]Z01[ooo]Z00?o0000oookJ_oonfX01OoonfX00oooC@3ooo]ZoookJP04
oome00?ooo]Z2_l0oi05oookJP;oom<00_oonfX5oo3o00Go0?mD1?oonfX01?l0oeCooo]ZoookJ_l0
oe@3o`3@o`;ooo]Z0_l02_l7oookJP03o`0:oooonf[ooo]Z00Gooo]Z00Co00[ooookJ_oonf[o00[o
0_oonfX4o`000004oookJ_l0<_oooo]ZoookJP;oo`/00ooonfX01_oo_@3ooo]ZoookJ_l0KoooK?l0
ool100Oooo]Z0ooo_@04oookJP?onOl01OoonfX3okOo00Gooo]Z00?ol?l0o`3o4ol0oa<00ol0oa<0
0ooonf[o0?lCo`3o4`03oonC00;oo`T000?ooo]Zo`3oT?ooU`000_ooU`0:o`3@o`Kooo]Z0ol0d?l4
oookJP03oolg0?oonf[ooo]Z00[ooo]Z0_oo?@0GoookJP03ool20?oonf[ooo]Z017ooo]Z00?oo`00
oookJ_oonfX05?oonfX00ooo403ooo]ZoookJP0GoookJP03o`000?oonf[oo`0001[ooo]Z00?oo`00
oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0=oookJP000_oonfX00ol0003ooo]ZoookJP0Moook
JP?o000000?ooo]Zool30?oonfX0C?oonfX00ooo0@3ooo]ZoookJP09oookJP03ool00?oonf[ooo]Z
03Kooo]Z00?oob<0oookJ_oonfX01OoonfX2ool201Gooo]Z00?o0000oookJ_oonfX01ooonfX3oome
00Kooo]Z0ol0oi02oookJP03oomH0?oonf[o0?n@00Co0?n@00?oom<0o`3oT?l0oi000ooonfX00ooo
2@3ooc80oo3o0002o`3oE0;oojH01_oonfX01?l0oeCo0=3oo`3@ool0oe@7oookJP03o`0:oooonf[o
oo]Z00Gooo]Z00?o00[ooookJ_oonfX01OoonfX2o`0:o`?o00001_oonfX00ol0<_oooo]ZoookJP08
oookJP03o`1_oooo0@3ooo]Z00Sooo]Z00?o0=3ooookJ_oonfX01OoonfX2ooWo0003oookJ_ngo`3o
]ol000;o]ol000?obOl0okOo0?oonfX00_oonfX01?l0oi3o0?lCo`3o4ol0oa<2odSo00?ooo]Z1Ooo
T`02oookJP05oonG0?l0oi3ooiL0o`3@ooooU`001?oonfX00ooo1@3o0=3ooookJP02oookJP[o0=3o
00?ooo]Zool00?oonfX03?oonfX01?oo4@3ooo]ZoookJ_oo?@0ToookJP03ool00?oonf[ooo]Z01?o
oo]Z00?oo`<0oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0@oookJP03ool00?oonf[ooo]Z02[o
oo]Z00?o0000oookJ_oonfX03OoonfX000;ooo]Z00?o0000oookJ_oonfX06_oonfX3o`0005Oooo]Z
00?oo`P0oookJ_oonfX0??oonfX2oolS00Kooo]Z0_oo>`06oookJP03ool50?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX01_oonfX4oome00;ooo]Z0_l0d?l4oookJP?o0?n@00?ooeP0oookJ_l0oi00
0_oonfX00oood`3o0?n@oookJP05oookJP06olWo0?ooYP3oojH0oonV0?l0oeCobOl01ol0oe@00ooo
nf[o0?mDoookJP08oookJP;o00[o1OoonfX00ol02_ooK?l0oookJP04oookJP03o`000?l02_oo00[o
00[ooo]Z00?o03;ooookJ_oonfX01ooonfX01?l0Koooo`P0ool80?oo2`08oookJP;oo`P01ooonfX0
0ooio`3o]ol0ooWo0005okOo00;o0?n@0_l0oa<00ooonf[ol?l0odSo0003oookJP03o`3o4oooT`3o
oi<000?ooi<00_oonfX01Ol0oi3ooiL0oonG0?ooU`3o0=3o00Gooo]Z0oooQP05oookJP?o0=3o00?o
oo]Zo`3@oooonfX03ooonfX00ooo4@3ooo]ZoookJP0;oookJP;oobH09ooonfX00ooo003ooo]Zoook
JP0EoookJP03ool80?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX08OoonfX00ooo003ooo]Zoook
JP0HoookJP03o`000?oonf[ooo]Z00gooo]Z0002oookJP03o`000?oonf[ooo]Z01Oooo]Z0ol0000J
oookJP;oo`80?_oonfX00ooo203ooo]ZoookJP09oookJP03ool00?oonf[ooo]Z033ooo]Z0_oo8`05
oookJP03oolk0?oonf[ooo]Z00Oooo]Z00?oob@0oookJ_oonfX00ooonfX00ooo0`3ooo]ZoookJP08
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0=3ooookJ_l0d?l01_oonfX02?ooF03o0?n@o`3oT?l0
oi3ooo]ZoooC0?oonf[oojH01?oonfX3oonV00;ooc800_o9o`02o`3oE0?o0=3o00?ooo]Zool90?l0
oe@01_l0oe@7oookJP;o00[o1?oonfX00ol02_ooK?l0oookJP03o`000004o`0:oooonf[ooo]Zo`0:
o`[ooo]Z00?o03;ooookJ_oonfX01ooonfX00ol0Koooo`/0olko0002olko00Kooo]Z0_oo0`08oook
JP;o]ol000ConOl0olWo0?l0oi3ooo]Z0_ngo`000ol0oa?oB?l0oookJP02oookJP03oo3o0?oonf[o
oo]Z00;o0?lC0_ooT`001Ol0oa?ooi<0oonC0?ooT`3o0?n@00;ooo]Z00?ooiL0oookJ_l0d?l01Ooo
nfX2oon60003oookJ_ooQP3ooo]Z00?o0=3o0_oonfX00ooo1P3o0=3ooookJP0=oookJP03ool00?oo
nf[ooo]Z00kooo]Z00?oobH0oookJ_oonfX03?oonfX00ooo:`3ooo]ZoookJP0AoookJP;oo`405Ooo
nfX00ooo003ooo]ZoookJP04oookJP03ool80?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX05_oo
nfX00ooo003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00cooo]Z0002oookJP03o`000?oonf[o
oo]Z01Cooo]Z0ol0001RoookJP03oolC0?oonf[ooo]Z00kooo]Z00?oo`00oookJ_oonfX0:ooonfX2
oolk00[ooo]Z00?oob@0oookJ_oonfX00ooonfX00ooo0`3oo`00oookJP03oookJP03ool70?oonf[o
oo]Z00?ooo]Z00?o0000oookJ_oonfX01ooonfX2o`3@o`04oookJ_l0d?oooo]Zo`3@o`Sooo]Z0_oo
d`001?oonf[oojH0oonV0?oonfX3oonV0005oookJ_o9o`3obOl0oookJ_o9o`000ol0d?l2o`3oE007
odSo0?oonf[ooo]ZoookJ_l0oeCooo]Zo`3oE002oookJP03ool30?ngo`3o0?mD00Go0?mD0ooonfX0
1ol02_oooo]ZoookJ_l0003o00[oo`000?m/o`000ooonfX01Ol02_ooK?l0oookJ_oonf[o00[o00[o
oo]Z00?o03;ooookJ_oonfX01OoonfX3olko0004oookJ_o>o`3ooo]Zolko00Gooo]Z0_oo2007oook
JPCo]ol01?oonfX00ongo`3oB?l0o`3o4`04oookJP04oo3o0?oonf[o0?lCo`3o4`;ooo]Z00Gooi<0
o`3o4ol0oi3o0?n@oonC0002oookJP03oonG0?oonf[o0=3o00Gooo]Z0oooQP02o`3@o`Gooo]Z00?o
0=3ooookJ_oonfX02OoonfX2ool2013ooo]Z00Goo`<0oookJ_oonf[ooo]ZoolV000=oookJP;oob/0
8_oonfX00ooo003ooo]ZoookJP03oookJP03ool00?oonf[ooo]Z01Oooo]Z00?oo`h0o`000?oonfX0
??oonfX00ol0003ooo]ZoookJP0<oookJP0000?ooo]Zo`000?oonfX04ooonfX3o`0002?ooo]Z00?o
o`L0oookJ_oonfX0?ooonfX00ooo4`3ooo]ZoookJP09oookJP03ool60?oonf[ooo]Z00Sooo]Z00?o
o`00oookJ_oonfX09OoonfX3oolk00Sooo]Z0_oo9007oookJP03oomB0?oonf[ooo]Z00;ooo]Z0_oo
0@04oookJP03ool50?oonf[ooo]Z00Gooo]Z00Co0=3ooookJ_oonf[o0=3o0_oonfX00ol0d?oooo]Z
oookJP02oookJP;oom<000Cooo]ZoooC0?oonf[ooo]Z1?ooYP05oookJP?o0=3o0oo9o`001_oonf[o
0?mDo`3oE?l0oeCooo]Zo`3oE0;ooo]Z00Ko0?mDokOo0?ngo`3o]ol0oookJ_oo2002olko0003oook
J_l0oi3ooo]Z00Co0?mD0_l02_l02Ol0oeCo00[ooookJ_oonf[oK?l0oookJ_l02_ooK?l0oookJP02
ofco0003oookJ_l02_oooo]Z00Wooo]Z00?o03;ooookJ_oonfX00ooonfX9olko00[ooo]Z0ol0oi02
okOo0003ool50?ngo`3o]ol000;ooo]Z00Go]ol0oookJ_m8o`3ooo]Zo`3o4`04oookJP03oo3o0?oo
8P3o0?lC00?ooo]Z0_l0oa<2oookJP;ooi<000CooiL0oookJ_oonf[o0=3o0_oonfX3o`3@o`;oohH0
00?ooo]Zo`1_ool0Kol00_l0Kol00ooonf[o0=3ooookJP0IoookJP05ool00?oonf[ooo]ZoookJ_oo
0`003_oonfX01Ooo4@3ooo]ZoookJ_oonf[oob/003[ooo]Z00?oo`<0oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP0WoookJP03ool00?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03?oonfX00003
oookJ_l0003ooo]Z013ooo]Z0ol0000foookJP03ool20?oonf[ooo]Z047ooo]Z00?ooa@0oookJ_oo
nfX02ooonfX00ooo003ooo]ZoookJP0_oookJP03oomB0?oonf[ooo]Z00Gooo]Z00Oooa`0oookJ_oo
nf[ooo]Zool50?l0003oo`0000Cooo]Z00Co0=3ooookJ_oonf[o0=3o0ooonfX01_l0d?oooo]Zoook
J_oonf[oom<0oookJP;oom<00_oonfX5oonV00;ooo]Z0ol0d?l00ooonf[obOl0olWo0002olWo00;o
oo]Z00GoB?l0oookJ_l0oh;o0?n2o`3oE002okOo0004o`3oE?oonf[ooo]ZoookJPCoc_l00_oonfX0
1ol0oi3o0000o`000?l0003ooo]Zool50?oonfX00ol02_l2o`3oE004o`0:ool0oeCooo]Zofco00;o
oo]Z00?oK?l0oookJ_l02_l02_oonfX00ol0<_oooo]ZoookJP02oookJPGoc_l000Co06oooookJ_oo
nf[oc_l01ooonfX3o`3oT0Gooo]Z0_ngo`001Ooonf[o]ol0okOo0?oonf[oB?l000?ooo]Z00Go0?lC
oookJ_oonf[oob80o`3o4`04o`3oE003o`3o4ooonf[ooo]Z00Cooo]Z0_ooT`001?oonf[o0=3oo`3@
ool0d?l3oookJP05o`3@oooonf[oohH0oookJ_l0Kol00_oonfX00ol0d?oo06ooo`1_o`0EoookJP;o
o`<00_oonfX00ooo003ooo]ZoookJP0@oookJP03oolA0?oonf[ooo]Z00;ooo]Z00?oob/0oookJ_oo
nfX01ooonfX00ooo7@3ooo]ZoookJP0NoookJP03ool00?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP05oookJP03ool80?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oo
nfX03?oonfX00003oookJ_l0003ooo]Z00gooo]Z0ol0000loookJP03ool60?oonf[ooo]Z03gooo]Z
0_oo500:oookJP03ool40?oonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX09ooonfX2oomB00Sooo]Z
0_oo7004oookJP03o`000?oonf[oog@000;ooo]Z00?o0=3oool30?l0d?l00ooonfX01_oo1P3ooo]Z
o`3@oooonf[oom<0oookJP?oom<01OoonfX01OooYP3o0=3oo`3@ool0d?oo]ol000Cooo]Z0_o9o`03
oookJP;o0?n200?o]ol0o`3oP_l0oe@00_oonfX00ol0oeCooo]ZoookJP02olko0003oookJ_o>o`3o
c_l000?o000000Co0?n@oookJ_oonf[ooo]Z0ol0Kol01_oo203o00[ooookJ_l02_ooK?l0oonK00Ko
0?mD00Cooo]Zo`0:oooonf[ooo]Z0_ooV`06oookJP03o`0boooonf[ooo]Z00;ooo]Z0oo>o`001?oo
nf[oc_l0olko0?o>o`04oookJPCo0?n@2OoonfX01_ngo`3ooo]ZokOo0?ngo`3ooo]ZodSo00Cooo]Z
00Ko0?lCool00?l0oa?o0?mDo`3o4ol0oe@2o`3o4`;o0?mD1?oonfX01_l0d?ooom<0o`3@ooooT`3o
oo]Zo`3@o`Gooo]Z00Ko06oooookJ_ooQP3ooo]Zo`1_ool0d?l3oookJPCo06oo0_oonfX00oooEP3o
oo]ZoookJP0JoookJP05ool00?oonf[ooo]ZoookJ_oo00004ooonfX2oolM03Oooo]Z00?oo`40oook
J_l000001_oonfX00ooo203ooo]ZoookJP0VoookJP03ool00?oonf[ooo]Z00Wooo]Z00?o0000oook
J_oonfX03?oonfX00003oookJ_l0003ooo]Z00[ooo]Z0ol0000ooookJP03ool60?oonf[ooo]Z00_o
oo]Z0_oo0@1=oookJP;oo`407ooonfX2oomB013ooo]Z00Oo0000oomd0?oonf[o0=3ooookJ_l0d?oo
oo]Z00;oo``000Gooo]Zool60?oonf[o0=3oool00006oooC0003oookJ_l0d?oo0=3o00;o0=3o0_oo
nfX2okOo00Oooo]Z0_l0oh82okOo0006oookJ_l0oh;o0?n2oookJ_l0oeCooo]Z0_o>o`000ooonf[o
0000o`000002olko00Cooo]Z0ol0Kol00ooonf[oc_l0olko0002olko0003o`0:ooo>o`3oc_l000Wo
c_l01Ol0oe@6oookJP07o`0boooonf[ooo]ZoookJ_o>o`3ooo]Zolko0002oookJPCoc_l00_l0oi0>
oookJP04okOo0?oonf[ooo]ZokOo00Kooo]Z00Co0?lCo`3oE?oonf[o0?lC0ol0oe@00ooonf[o0?mD
oookJP03o`3@o`03ool10?ood`3oom<000;ooo]Z00?o0=3ooookJ_oonfX00_oonfX01_l0Kooo0=3o
oookJ_oo:@3oohH0o`3@o`Sooo]Z00Co06oooomF0?ooEP3ooeH0;_oonfX2ool500Cooo]Z00?ooad0
oookJ_oonfX0;OoonfX00ooo003ooo]ZoookJP05oookJP04ool10?oonf[ooo]Zo`0003[ooo]Z00?o
0000oookJ_oonfX03?oonfX00003oookJ_l0003ooo]Z00Oooo]Z0ol0002CoookJP;ooa@02?oonfX2
ool100Oooo]Z00?oo`00oookJ_oonfX05ooonfX3oomB013ooo]Z00?oog@0o`3@oooonfX00_l0d?l2
oookJP03ool<0?ooT`3ooi<000;ooo]Z00Ko0=3ooookJ_ood`3oom<0ool40?ood`02o`3@o`03oook
J_oo1`3ooo]Z00;ooo]Z00Co]ol0oookJ_oonf[o]ol00ooonfX3o`3oPP04oookJ_m8o`3ooo]Zoook
JPCo0?n200?o0?mDolko0?o>o`003_o>o`04oookJP03ofco0?oonf[ooo]Z00;ooo]Z0_m/o`000ooo
nf[oK?l0ofco0003oookJP04o`0:ooooV`3ooi/0oonK00Ko0?mD00?o03;ooookJ_oonfX00_oonfX3
olko0005oookJ_o>o`3o0?n@o`1_oooonfX00_o>o`0AoookJP03odSo0?ngo`3ooo]Z00?ooo]Z0_l0
oe@00ol0oa?o0?mDo`3oE002oookJPCo0?mD00Goo`D0ool10?oo0@3oom<0oookJP02oooC0003oook
J_l0d?oooo]Z00;ooo]Z1_l0Kol00oooQP3o06ooo`1_o`03o`1_o`Gooo]Z00CooeH0o`1_ool0Kooo
06oo2?oonfX2oomA01Wooo]Z00Goo`40oookJ_oonf[ooo]Zool00004oookJP03ool50?oonf[ooo]Z
00kooo]Z00?oo`l0oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP03oookJP03ool00?oonf[ooo]Z
00Kooo]Z00?oo`@0oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0<oookJP0000?ooo]Zo`000?oo
nfX01?oonfX3o`0005Oooo]Z0_oo1@0<oookJP03ool00?oonf[ooo]Z02oooo]Z00?ooa@0oookJ_oo
nfX01?oonfX00ooo:`3ooo]ZoookJP0?oookJP;oo`808ooonfX01_ooM03ooo]Zo`3@ool0d?oooo]Z
o`3@o`;ooo]Z00?ooi<0oookJ_oonfX00_oonfX01Ol0d?oooo]Zo`3@ool0d?ooom<000?ooo]Z0_oo
0@02oookJP;o]ol00_oonfX2okOo00;o0?n20ooonfX5o`3oPP;ooo]Z00Co0?n2o`3oE?l0003ooo]Z
1_o>o`000ol0Kooooo]ZoookJP03oookJP03o`3oT?oonf[ooo]Z00;ooo]Z0om/o`04oookJP?oK?l0
1?oonfX01OooV`3o00[ooonK0?oonf[oo`8000;oo`L00ooonfX3o`3oE0?ooo]Z0_l0oi001Oo>o`3o
oo]ZoookJ_oonf[o06oo00;ooo]Z0oo>o`06oookJPKoR_l000Gooo]ZodSo0?oonf[ooo]ZokOo0002
oookJP05o`3oE?l0oa?o0?mDo`3oE?l0oa<01?l0d?l00ol0oeCooo]Zo`3oE002oookJP;oom<000Ko
oo]ZoooC0?oonf[oom<0oookJ_l0d?l2oookJP03o`1_oooonf[oo`0000;o0=3o0_oonfX00ol0Kooo
oo]ZoookJP02oookJP_o06oo1_oonfX3oomA01Oooo]Z0_oo0@0HoookJP;oo`l0;?oonfX01Ooo003o
oo]ZoookJ_oonf[o000000Cooo]Z00?oo`00oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0<oook
JP0000Co0000oookJ_oonf[ooo]Z0ol0002QoookJP03ool[0?oonf[ooo]Z00Kooo]Z00?ooa40oook
J_oonfX01_oonfX00ooo003ooo]ZoookJP0PoookJP?oog@00_l0d?l00ol0003ooo]ZoookJP02oonC
00Cooo]Z0ol0d?l00ooonf[ooiL0oookJP06oookJP03okOo0?oonf[oo`4000;o]ol01ol0oh801Om8
o`3ooo]ZoookJ_oonf[o0?n200;o000000Co0?n2oookJ_oonf[ooo]Z0_l0Kol4olko00Oooo]Z00?o
0?n@oookJ_oonfX00ooonfX8ofco00Gooo]Z00?ooi/0o`0:oooonfX02?oonfX01?l0<_oooo]Zo`3o
T?l0oi07oookJP03o`1_oooonf[ooo]Z00;ooo]Z0_o>o`04oookJP03oh[o0?oonf[ooo]Z00GoR_l0
0ooonfX01?ngo`3o0?mDo`3oE?l0oe@3o`3@o`?ooo]Z0ol0oe@00ooonf[o0?mDoookJP02oookJP?o
om<00_oonfX01ol0d?oooo]ZoookJ_oo0P3o06oooookJ_l0d?l00ooonfX00ol0Kooooo]ZoookJP07
oookJP05o`1_ooooEP3o06oooookJ_l0Kol01ooonfX3oomA02Kooo]Z00?oo`00oookJ_oonfX00_oo
nfX2ool101Gooo]Z0_oo5`0PoookJP03o`000?oonf[ooo]Z01?ooo]Z00?oo`80oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP0;oookJP001?l0001QoookJP;oo`h03?oonfX00ooo0`3ooo]ZoookJP09
oookJP03ool00?oonf[ooo]Z02Cooo]Z0_oo:`09oookJP03oolA0?oonf[ooo]Z00gooo]Z00?oo`00
oookJ_oonfX01?oonfX00ooo0`3ooo]ZoookJP0AoookJP05oomd0?oonf[oog@0oomd0?l0d?l00_oo
T`001?l0003ooi<0o`3@oooonfX4o`3@o`;ooo]Z00?o0=3ooookJ_ooU`001_oonfX5okOo00Co0?n2
0ooonfX02Om8o`3o0000o`000?l0003oo`<0o`3oP_oonf[o0?n2oookJP03o`1_o`Cooo]Z00?oc_l0
oookJ_oonfX01ooonfX00ol0oi3ooo]ZoookJP04oookJP03ofco0?oonf[oK?l000?oK?l01_oonfX0
0ol02_oooo]ZoookJP08oookJP05o`0boooonf[ooo]Zool40?oo1`001_oonfX01?l0Kooooo]Zoook
J_oonfX2oolb00?oc_l000Gooo]Zoh[o0?n:o`3ooo]Zoh[o0002oookJP?oR_l00_oonfX01?l0oeCo
]ol0o`3o4ol0d?l5oookJP04o`3oE?oonf[o0?mDoookJP;o0?mD1?oonfX00oood`3ooo]ZoookJP02
oookJP05o`3@oooonf[ooo]Zo`1_ool0d?l01?oonfX00ol0Kooooo]ZoookJP03oookJP08ool00?l0
Kooo06ooo`1_oooonf[ooeH0oookJ_l0Kol8oookJP;oob@000?ooo]ZoomA0?oonfX0>_oonfX00ooo
1P3ooo]ZoookJP03oookJP;ooaL08OoonfX00ol0003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z
00Oooo]Z00?oo`80oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0;oookJP000_l0000RoookJP;o
o`D0P?oonfX00ooo:`3ooo]ZoookJP0?oookJP03oolc0?oonf[ooo]Z00Gooo]Z0_oo2`06oookJP03
ool00?oonf[ooo]Z00Cooo]Z00?oo`40oookJ_oonfX02ooonfX3oomd0004oonC0?oonf[ooi<0oonC
00?o0=3o1_oonfX00ol0d?oooo]ZoonG0005oookJPSo]ol000?o0?n2oomk0?l0oh801Ol0oh801_oo
0`3o0?n2oookJ_l0Kooo0?n2o`1_oa;ooo]Z00?o0?n@oookJ_oonfX01?oonfX2ofco00[ooo]Z00?o
00[ooookJ_oonfX02?oonfX00ol0<_oooo]ZoookJP08oookJP05o`1_oooo<P3ooc80oookJ_oo<P00
0ooonfX2olko00;oR_l00_oonfX01Om8o`3ooo]ZoookJ_l0d?ooR_l000;o0=3o00?o0?mDokOo0?oo
nfX01OoonfX2o`3oE0?ooo]Z0_l0oe@3oookJP03oooC0?oonf[ooo]Z00;ooo]Z00?o0=3ooonV0?oo
YP000_ooYP05oookJP03o`1_oooonf[o06oo00?o06oo1OoonfX00ol0Kooooo]ZoookJP08oookJP04
oolT0?oonf[ooo]ZoomA00Wooo]Z0_oo>00RoookJP03ool00?oonf[ooo]Z00?ooo]Z00?oo`00oook
J_oonfX01?oonfX00ooo1P3ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01_ooo]Z00?oo`00oook
J_oonfX06?oonfX00ol0003ooo]ZoookJP0;oookJP000_oonfX00ol0003ooo]ZoookJP1coookJP03
ool=0?oonf[ooo]Z00Wooo]Z00?oo`80oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP0VoookJP;o
oc<02?oonfX00ooo2`3ooo]ZoookJP0;oookJP03ool10?oonf[ooo]Z00;ooo]Z0_oo1008oookJP09
oomd0?oonf[ooi<0oonC0?l0d?oooi<0oookJ_l0003o0=3o00Oooo]Z00?o0=3ooonG0?oonfX01Ooo
nfX00ooio`3ooo]ZokOo0004okOo0005o`000?l0oh;o0?n2oookJ_m8o`000ooonfX7o`3oPP;oob80
00Gooo]Zool00?oonf[ooo]Zool4000;oookJP03o`3oT?oonf[ooo]Z013ooo]Z00?o00[ooookJ_oo
nfX02?oonfX00ol0<_oooo]ZoookJP09oookJP03ool40?oonf[ooo]Z00?ooo]Z00OoR_l0oookJ_o>
o`3oR_l0olko0?oonf[oB?l000;o0=3o00Oooo]Zoh[o0?oonf[ooo]Zo`3o4ol0oeCo]ol000Cooo]Z
00?o0?mDoookJ_l0oe@01?oonfX01?l0oeCooo]ZoookJ_ood`05oookJP04o`3@ooooYP3o0=3ooook
JP;oojH00ooonfX2o`1_o`?o03;o1_oonfX00ol0Kooooo]ZoookJP02oookJP04ool00?oonf[ooo]Z
ool000;ooo]Z00?oob@0oookJ_oonfX02ooonfX2oolh03Wooo]Z00?oo`80oookJ_oonfX01?oonfX0
0ooo3P3ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z013ooo]Z00?oo`00oookJ_oonfX01ooonfX0
0ooo003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00_ooo]Z0003oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?oo`@0oookJ_oonfX0?OoonfX00ooo3@3ooo]ZoookJP0loookJP;ooc<03ooonfX00ooo
>P3ooo]ZoookJP04oookJP;oo`@01OoonfX00ooo003ooo]ZoookJP03oookJP04ool30?l0d?oo0=3o
o`3@o`Cooi<00_oonfX00ol0d?oooo]ZoookJP05oookJP04o`3@ooooU`3ooiL0oonG00?ooo]Z00?o
nOl0oookJ_oonfX00_oonfX01Ol0003o]ol0o`000?oonf[oB?l000;o0?n200WoB?l0o`1_ool0Kooo
06oooookJ_l0oh;o0?lCoookJ_l0oh800_oonfX6o`3oPP04ool40?oonf[oo`L0ool700Wooo]Z00?o
0?n@oookJ_oonfX04?oonfX00ol02_oooo]ZoookJP08oookJP03o`0boooonf[ooo]Z00kooo]Z0_n:
o`001?oonf[oR_l0o`3@ooo>o`03oookJP04oh[o0?oonf[ooo]Zo`3o4`;ooo]Z00So0?mDokOo0?oo
nf[ooo]ZoomH0?l0oeCooeP0o`3oE0Cooo]Z0_l0oe@00ooonf[oom<0oookJP04oookJP?oojH000?o
oo]Zo`1_ooooYP000ol0Kol01Ooonf[o03;oo`1_ool0<_oooo]Z00?o03;o0_oonfX00ol0Kooooo]Z
oookJP0EoookJP04ool90?oonf[ooo]Zoolh03;ooo]Z00?oo`00oookJ_oonfX00ooonfX00ooo0P3o
oo]ZoookJP05oookJP03ool>0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0;oookJP001?oonfX2o`0008?ooo]Z00?oo``0oookJ_oonfX02?oonfX00ooo003ooo]Z
oookJP07oookJP03ool00?oonf[ooo]Z01Kooo]Z00?ooc<0oookJ_oonfX03_oonfX00ooo>P3ooo]Z
oookJP0AoookJPCo0=3o00Co06oooonC0?l0d?oo06oo1?l0d?l6oookJP05oonG0?oonf[ooiL0oook
J_ooU`000_oio`000ooonf[o0000o`000002o`0000?ooo]Z00?oB?l0o`1_ool0Kol00_l0oh801ooo
N`3ooo]Zoomk0?oonf[o0?n2oookJ_l0oh801ooonfX2oh[o00Ko0?n20_oo0P001ooonf[oo`40oook
J_oonf[oo`D0oookJ_l0oi004_oonfX00ol02_oooo]ZoookJP08oookJP03o`0boooonf[ooo]Z00co
oo]Z00[o0=3ooh[o0?n:o`3o0=3ooh[o0?oonf[oo`D0oh[o0?oonf[oR_l00ooonfX02?l0oa?ooo]Z
oookJ_oonf[o0?mDokOo0?ooF03o0?mD1ol0oh83oookJP?onOl01OoonfX3oonV0009o`1_oooonf[o
oo]ZoookJ_l0<_oooo]Zo`1_oooonf[o03;o00?ooo]Z00?o03;oo`1_oooonfX03ooonfX01Ooo0@3o
oo]ZoookJ_oonf[oo`0000;ooo]Z0_oo2@02oookJP03oolh0?oonf[ooo]Z00Wooo]Z00?ooad0oook
J_oonfX0??oonfX00ooo1`3ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z023ooo]Z00?oo`00oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP0;oookJP001_oonfX00ol0003ooo]ZoookJP11oookJP;o
o`<0?OoonfX00ooo303ooo]ZoookJP0loookJP03oolj0?oonf[ooo]Z00Gooo]Z00?oofX0oookJ_oo
nfX01?oonfX00ooo=`3ooo]ZoookJP04oookJP03o`3@ool0Kooo06oo00;ooo]Z00Coo`40o`1_oooo
nf[ooo]Z2?l0d?l3oonG0004ooWo0?l0003o0000o`0000Gooo]Z0ol0Kol00ooonf[oB?l0odSo0003
o`3oPP05oomk0?oonf[o0?n2oookJ_l0oh801?oonfX3oh[o00Kooo]Z00?o0=3ooookJ_l0oh801Ol0
oh801?oo1@3ooo]ZoookJ_l0oi0BoookJP03o`0:oooonf[ooo]Z00Sooo]Z00?o03;ooookJ_oonfX0
2?oonfX3o`3@o`?ooo]Z0on:o`02oookJP05oh[o0?oonf[ooo]ZoookJ_l0oa<01?oonfX01_oo0P3o
0?mDokOo0?l0oh;ooo]Zo`3oE0?o0?n200[o0?mDo`3oP_oonf[ooo]ZooWo0?ood`3onOl0oookJ_oi
o`3ooo]Z1?l0Kol2oonV0009o`1_oooonf[ooo]Zo`0booooC@3ooo]Zo`1_oooonf[o03;o00?ooo]Z
00Go06oooookJ_ooM@3oogD0o`0bo`0SoookJP;ooad0;ooonfX00ooo003ooo]ZoookJP04oookJP03
ool00?oonf[ooo]Z00Gooo]Z00?oo`L0oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0coookJP03
o`000?oonf[ooo]Z00_ooo]Z0007oookJP03o`000?oonf[ooo]Z043ooo]Z00?oo`<0oookJ_oonfX0
@_oonfX00ooo7@3ooo]ZoookJP08oookJP03ool80?oonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX0
1_oonfX00ooo003ooo]ZoookJP0HoookJP?oocX01_oonfX00oooJP3ooo]ZoookJP04oookJP03oolg
0?oonf[ooo]Z00?ooo]Z0ol0Kol01Ooonf[o0=3oo`3@ool0d?oo06oo00?ooo]Z00Co0=3oool40?oo
nf[ooo]Z0_oio`02oookJP03oonG0?oio`3o000000Gooo]Z0ol0Kol3oookJP05odSo0?oonf[oB?l0
odSo0?ooN`000ol0oh82oookJP03o`3oP_oonf[oR_l000;oR_l02_oonfX00ol0d?oooo]ZoookJP04
oookJPKo0?n20oo9o`000ooo0`3ooo]Zool5000;oookJP05o`0:oooonf[ooo]ZoookJ_o9o`001_oo
nfX00ol0<_oooo]ZoookJP04oookJP?o0=3o2?oonfX01On:o`3ooo]Zoh[o0?oonf[oR_l000;ooo]Z
00?o0?lCoookJ_oonfX01?oonfX00ol0oh;ooo]ZoookJP03o`3oPP08oookJ_l0oh;o0?n2o`3oP_oi
o`3ooo]ZoooC0?oio`02o`1_o`03ooWo0?oonf[ooo]Z00Cooo]Z00GoojH0oookJ_l0<_oooo]Zoom=
0002oookJP06o`1_ool0<_oooo]ZoookJ_l0Kooooo]Z0_ooM@000ooonf[oogD0o`0bo`02o`0boaSo
oo]Z00Goo`00oookJ_oonf[ooo]Zool10003oookJP03oolM0?oonf[ooo]Z00gooo]Z0_oo:010oook
JP03o`000?oonf[ooo]Z02Oooo]Z00?oo`00oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0:oook
JP002?oonfX00ol0003ooo]ZoookJP13oookJP03ool90?oonf[ooo]Z00_ooo]Z00?oo`80oookJ_oo
nfX0;ooonfX2oolM00[ooo]Z00?oo`P0oookJ_oonfX0<_oonfX00oooJP3ooo]ZoookJP06oookJP;o
ocL00_oonfX01Ol0Kooooo]Zo`1_oooonf[ooi/000?ooo]Z00[o06ooo`3@oooo8P3ooo]Zo`3@oooo
nf[o0000ooWo0?l0d?oonOl00_l000000ooio`3oo`80oookJP02oookJP;o06oo0_n:o`000om8o`3o
oo]ZoookJP02oookJP;oB?l00_oonfX01?m8o`3ooo]Zo`3oP_l0oh82oh[o0003o`3oP_n:o`3ooo]Z
00gooo]Z00?o0=3ooookJ_oonfX00ol0<_l5oookJP03o`3oT?l0oh;o0?n200Go0?n200?obOl0oook
J_oonfX02?oonfX00ol02_oooo]ZoookJP02olWo00Kooo]Z00?o03;ooookJ_l0d?l00ol0d?l<oook
JP06oh[o0?oonf[ooo]ZoookJ_n:o`3o0?lC1OoonfX5o`3oPP03o`3oE?oonf[ooo]Z00;o0?n200Ko
o`<0o`3oP_oio`3o06oooooC0?oio`02oookJP;onOl01OoonfX00ol0KoooojH0o`0bo`05o`0bo`03
oookJ_l0<_oo06oo00;ooo]Z0oooM@04oookJP;o03;o:OoonfX00ooo2`3ooo]ZoookJP02oookJP03
oolX0?oonf[ooo]Z02kooo]Z00?oo`00oookJ_oonfX01OoonfX00ooo0`3ooo]ZoookJP06oookJP03
ool<0?l0003ooo]Z03?ooo]Z00?o0000oookJ_oonfX02_oonfX000Wooo]Z0_l00013oookJP03ool9
0?oonf[ooo]Z00_ooo]Z00?oo`80oookJ_oonfX0;ooonfX2oolM013ooo]Z00?ooah0oookJ_oonfX0
1_oonfX00ooo1@3ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z00Gooo]Z00?oo`40oookJ_oonfX0
3ooonfX3oomZ00Wooo]Z00CoocL0oookJ_oonf[ooo]Z0_l0Kol2oookJP03oonK0?oonf[ooo]Z00;o
oo]Z00Wo06ooo`3@ool0d?oo0=3ooookJ_oio`3o0000ooWo0?oonfX00_oio`000ooonf[o06ooo`1_
o`02o`1_o`05oookJ_n:o`3oR_l0oh[o0?m8o`001?oonfX2odSo00?ooo]Z0_n:o`001?l0oh;ooo]Z
oookJ_l0oh8?oookJP?o03;o2OoonfX00ol0oi3ooo]ZoookJP04oookJPKo0?n200?obOl0oolR0?oo
8P000ooonfX00ol02_oooo]ZolWo0002olWo00Cooo]Z0_l0d?l00ol0<_oooo]ZoookJP0:oookJP;o
og/01_oonfX00ol0oa?oR_l0oookJP03oookJP?o0?n20_oonfX01?l0oeCooo]ZoookJ_oonfX2o`3o
PP;o06oo00Ko0?n2ooWo0?oonf[onOl0oookJ_oio`08oookJP03o`0booooYP3ooo]Z00?ooo]Z00?o
06ooo`0bool0<_l01?l0<_l00oooM@3o03;oo`0bo`03o`0bo`;ooo]Z0ol0<_lLoookJP03ool00?oo
nf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo2`3ooo]ZoookJP03oookJP03oolX0?oo
nf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0:oookJP002ooonfX0
0ol0003ooo]ZoookJP1OoookJP03ool10?oonf[ooo]Z033ooo]Z00?ooah0oookJ_oonfX01ooonfX0
0ooo1@3ooo]ZoookJP0NoookJP03oomZ0?oonf[oofX000gooo]Z0ol0Kol00ooonf[ooi/0oookJP04
oookJP07o`1_oooonf[oob80oolR0?l0d?oonOl0o`000002ooWo0003o`1_oooio`3o06oo00?ooo]Z
00Ooo`T0oh[o0?n:o`3ooo]Zoh[o0?oo003oB?l000;ooo]Z0_m8o`001?oonf[oR_l0oh[o0?n:o`02
odSo0003oookJ_l0oh;o0?n200gooo]Z0ol0<_l2oookJP03o`3@oooonf[ooo]Z00Sooo]Z00?o0?n@
oookJ_oonfX02OoonfX6o`3oPP06oookJ_l02_oobOl0olWo0?oonf[obOl00ol0d?l3oookJP03o`0b
oooonf[ooo]Z00Wooo]Z0oooN`05oookJP03o`3o4on:o`3ooo]Z00;ooo]Z0_l0oh800ol0oeCooo]Z
oookJP03oookJP03o`1_ool0oh;o06oo00;o0?n200?ooo]Zo`3oP_oonfX00ooio`06oookJP06ool0
0?oonf[oo`00o`1_ool0<_ooojH01?oonfX00ol0Kooo03;ooookJP04oookJP03oome0?oonf[ooo]Z
00;ooo]Z1_l0<_leoookJP;ooaP0;?oonfX00ooo003ooo]ZoookJP06oookJP03ool10?oonf[o0000
00Kooo]Z0_oo1`0[oookJP03o`000?oonf[ooo]Z00[ooo]Z000<oookJP03o`000?oonf[ooo]Z057o
oo]Z00?oo`P0oookJ_oonfX02_oonfX00ooo0@3ooo]ZoookJP0_oookJP;ooah06?oonfX00ooo0@3o
oo]ZoookJP04oookJP;oo`001OoonfX00ooo0P3ooo]ZoookJP02oookJP?oofX02ooonfX2o`1_o`04
oookJ_l0Kooooo]ZoonK00Gooo]Z00?o06oooookJ_oonfX00_oonfX3ooWo0004o`1_oooonf[onOl0
ooWo00?ooo]Z00?oo`T0oh[o0?oonfX00_oonfX01?n:o`3oB?l0odSo0?oonfX3oh[o0004oookJ_m8
o`3oB?l0o`3o4`?ooo]Z00?o0?n2oookJ_oonfX01ooonfX4o`0bo`Kooo]Z00?o0=3ooookJ_oonfX0
2?oonfX00ol0oi3ooo]ZoookJP04oookJP;o0?n@2?oonfX3o`3oPP05olWo0?l0d?oo0=3oolWo0?oo
10001OoonfX00ol0<_oooo]ZoookJP05oookJPKoog/01?oonfX01_l0oa?ooo]ZoookJ_n:o`3ooo]Z
o`3oPP;ooo]Z00?o0?mDoookJ_oonfX00ol0Kol01Ooonf[o0?n2oonG0?l0oh;ooiL000;o0?n20_oo
nfX00ooio`3ooo]ZoookJP08oookJP03o`1_ool0<_oooo]Z00?ooo]Z00Co06oooookJ_oonf[o03;o
0_oonfX2oolA0003oome0?oonf[ooo]Z00;ooo]Z1?l0<_l4oookJP03oolj0?oonf[ooo]Z02Gooo]Z
00?oo`00oookJ_oonfX00_oonfX2ool300Cooo]Z00?ooaP0oookJ_oonfX0=ooonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z00[ooo]Z000=oookJP;o0000KooonfX00ooo003ooo]Zoook
JP0_oookJP03oolM0?oonf[ooo]Z01[ooo]Z00?oofX0oookJ_oonfX02OoonfX2o`1_o`;ooo]Z00?o
06oooonK0?oonfX01_oonfX01?l0Kooooo]Zo`1_ool0Kol5ooWo0003oooC0?oonf[ooo]Z00;ooo]Z
0_n:o`03oookJPCoR_l000?oB?l0oookJ_m8o`000_m8o`000ooo003o0?lCoookJP02ool100;ooo]Z
00?oo`@0oookJ_oonfX00_oonfX3o`0bo`_ooo]Z00?o0=3ooookJ_oonfX02?oonfX00ol0oi3ooo]Z
oookJP03oookJP03o`3oT?oonf[o0?n@00Sooo]Z0_o9o`000ol02_oobOl0olWo0002olWo00Kooo]Z
00Co03;ooookJ_oonf[ooo]Z0oooN`03oookJP;oog/01OoonfX02?l0oa?ooo]ZoookJ_oonf[oR_l0
oookJ_l0oh;o0?mD0ol0Kol3oookJP03o`3oP_ooU`3o0?n200;ooiL000Gooo]Zo`3oP_l0oh;ooo]Z
ooWo000;oookJP09o`0boooonf[ooo]ZoookJ_l0Kooooo]Zool10?oonf[o03;o00;ooo]Z0_oo4@00
0oooM@3o03;oo`0bo`02o`0bo`;ooo]Z00?o03;ooookJ_oonfX00_oonfX2oolj03gooo]Z00?oo``0
oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP02oookJP03ool00?oonf[ooo]Z00Kooo]Z0_oo0`0R
oookJP03o`000?oonf[ooo]Z00[ooo]Z000?oookJP03o`000?oonf[ooo]Z063ooo]Z00?oo`L0oook
J_oonfX0>ooonfX2oolM01Kooo]Z00?oo`00oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP03oook
JP04ool20?oonf[ooo]ZoookJP;o06oo0_oonfX3oonK00Kooo]Z0ol0Kol2oookJPConOl000?ooo]Z
oooC0?oonfX00_oonfX00on:o`3ooo]ZoookJP04oh[o0003oookJ_m8o`3oB?l000?oB?l00_oonfX0
0ol0oa?ooo]ZoookJP06oookJP?o03;o1ooonfX00ooo103ooo]ZoookJP05oookJP03o`3@oooonf[o
oo]Z00Sooo]Z00So0?n@oookJ_oonf[ooo]Zo`3oT?oonf[o0?n@oookJP;o0?n@1_oonfX3olWo0003
o`0:ooo9o`3ooo]Z00Sooo]Z00?o03;ooomk0?ooN`003?oonfX00ol0oa?ooo]ZoookJP02oookJP04
o`1_oon:o`3o0?mDo`3oPPKooo]Z00?o0?n2oonG0?l0oh800_ooU`02oookJP03o`3oP_oonf[onOl0
00_ooo]Z00Co06ooo`0boooonf[o06oo1?oonfX00ol0<_oooo]ZoookJP03o`0bo`Gooo]Z00?o03;o
oookJ_oonfX00ooonfX2oolj00cooo]Z0_ooB`0RoookJP03ool00?oonf[ooo]Z00?ooo]Z00?oo`00
oookJ_oonfX01?oonfX00ooo303ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX02_oonfX0013ooo]Z00?o0000oookJ_oonfX0NooonfX00ooo003ooo]ZoookJP0Voook
JP03oom50?oonf[ooo]Z00Kooo]Z0_oo5`0EoookJP;o06oo0_oonfX01?ooV`3ooo]ZoonK0?ooV`02
oookJPCo06oo0_oonfX01Ol0Kooooo]ZoookJ_oonf[o000000?ooo]Z00?oom<0oookJ_oonfX01On:
o`03oookJP03oh[o0?oonf[oB?l000;oB?l000CoolT0oookJ_oonf[o0?lC1?oonfX4o`0bo`;ooeP0
0_oonfX01Ooo003ooo]ZoookJ_oo0P3ooo]Z00;oo`@02?oonfX00ol0d?oooo]ZoookJP08oookJP03
o`3oT?oonf[o0?n@00;ooo]Z00Co0?n@oookJ_oonf[ooo]Z0_l0oi05oookJP04olWo0?oonf[ooo]Z
o`0:o`[ooo]Z00?o03;ooookJ_oonfX02OoonfX01?oo0P3o0?lCoookJ_oonfX3o`1_o`;ooo]Z00?o
R_l0oookJ_l0oh801?oonfX01Ol0oh;ooiL0oookJ_l0oh;ooiL000?ooo]Z0_l0oh800ooio`3ooo]Z
oookJP09oookJP03o`1_ool0<_oo06oo00Cooo]Z00Co03;oo`0:ool02_oo03;o1ooonfX01Ol0<_oo
o`00oookJ_oonf[oo`8000;ooo]Z00?oocX0oookJ_oonfX02_oonfX2oom;047ooo]Z00?ooa@0oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP09oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oo`40oook
J_oonfX06?oonfX00ol0003ooo]ZoookJP0:oookJP004OoonfX00ol0003ooo]ZoookJP1SoookJP03
oolC0?oonf[ooo]Z00Wooo]Z00?oo`@0oookJ_oonfX0<OoonfX00oooA@3ooo]ZoookJP06oookJP;o
oaL03OoonfX00ooo303ooo]ZoookJP04oookJP03ool00?l0Kooooo]Z00;ooo]Z1OooV`000ol0Kooo
o`<0oookJP04oookJP05o`1_oooonf[ooo]ZoookJ_l000000ooonfX00oood`3ooo]Zoh[o0009oh[o
00Gooo]Z00CoolT0o`3o4ooonf[ooo]Z0ol0<_l00ol0oeCooo]ZoookJP03oookJPCooeP03OoonfX0
0ooo0`3o0=3ooookJP09oookJP03o`3oT?oonf[ooo]Z00;ooo]Z00?o0?n@oookJ_oonfX00_oonfX0
0ol0oi3ooo]ZoookJP06oookJP03o`0:oooonf[ooo]Z01?ooo]Z00Coo``0o`3o4ol0Kooo06oo1?oo
nfX01Ol0oeCooo]Zoh[o0?oonf[o0?n200;ooo]Z00Co0?n2oookJ_oonf[o0?n21?oonfX00ol0oh;o
oo]ZoookJP02olko00_ooo]Z00?o06ooo`0boooonfX00ol0<_l2o`0:o`04o`0bool02_oo00[oo`0:
o`Cooo]Z00?o03;ooookJ_oonfX02OoonfX00ooo003ooo]ZoookJP04oookJP;ooa@000?ooo]Zoom;
0?oonfX0<_oonfX00ooo003ooo]ZoookJP03oookJP03ool40?oonf[ooo]Z00Gooo]Z00?ooa@0oook
J_oonfX07_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00Wooo]Z000BoookJP;o
00008_oonfX00ooo1`3ooo]ZoookJP0moookJP;ooa<06ooonfX00ooo0P3ooo]ZoookJP07oookJP03
ool00?oonf[ooo]Z01Kooo]Z00?oodD0oookJ_oonfX03_oonfX00oooDP3ooo]ZoookJP05oookJP03
ool<0?oonf[ooo]Z00Cooo]Z00?o06oooookJ_oonfX00_oonfX01Ol0Kooooi/0oonK0?ooV`3o06oo
00Oooo]Z00Wo06ooool20?oonf[ooo]Zo`000?oonf[oo`@0oookJ_ood`001?oonfX5oh[o00Sooo]Z
0ol0<_l3oookJP03o`3oE?oonf[ooo]Z00Kooo]Z0_ooF006oookJP?oo`h000Koo`00oookJ_oonf[o
o`<0oookJ_l0d?l8oookJP03o`3oT?oonf[o0?n@00?ooo]Z00?o0?n@oookJ_oonfX00ooonfX00ol0
oi3ooo]ZoookJP06oookJP03o`0:oooonf[ooo]Z00oooo]Z0ol0Kol00ol0oa?ooo]ZoookJP05oook
JP08o`3oE?oonf[ooo]Zoh[o0?oo003o0?n2oonG0?l0oh82oookJP05o`3oP_oonf[ooo]ZoookJ_l0
oh800_oonfX2olko0003oookJ_o>o`3oc_l000Sooo]Z0ol0<_l01?ooM03ooo]ZoookJ_l02_l2oook
JP03o`0:oooonf[ooo]Z00;ooi<00_l02_l00ol0<_oooo]ZoookJP0:oookJP04ool00?oonf[ooo]Z
ool000?ooo]Z0_oo5002oookJP03oom;0?oonf[ooo]Z00Sooo]Z00?oob`0oookJ_oonfX0;_oonfX0
0ooo003ooo]ZoookJP02oookJP03oolD0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX06OoonfX0
0ooo003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00Wooo]Z000DoookJP03o`000?oonf[ooo]Z
01oooo]Z00?oo`L0oookJ_oonfX0CooonfX00ooo4P3ooo]ZoookJP08oookJP03ool20?oonf[ooo]Z
01oooo]Z0oooA@0?oookJP03oomB0?oonf[ooo]Z00_ooo]Z00?o06oooookJ_oonfX00ol0Kol01Ooo
nf[o03;ooonK0?l0<_oo06oo00?ooo]Z00?oo`00oookJ_oonfX00_oonfX01?l0Kooooo]ZoookJ_l0
0003oookJP?oom<00_o>o`03oookJP03oh[o0?oonf[ooo]Z00Cooo]Z0ol0<_l00ooonf[oolT0oook
JP02oookJP03o`3oE?oonf[ooo]Z00Oooo]Z0oooF002oookJP05o`1_oooonf[ooo]ZoookJ_oo3P00
1ooonfX00ol0d?oooo]ZoookJP03oookJP03ool10?l0oi3oo`<000;ooo]Z00Go0?n@oookJ_oonf[o
oo]Zo`3oT004oookJP03o`3oT?oonf[ooo]Z00Oooo]Z00?o00[ooookJ_oonfX02ooonfX3o`1_o`[o
oo]Z00So0?mDoookJ_oonf[ooo]Zool00?n:o`3ooiL0o`3oPP?ooo]Z00Co0?n2oookJ_l0oh;o0?n2
0_oonfX00oo>o`3ooo]Zolko0003oookJP04olko0?oonf[ooo]ZoookJPCo03;o00?ooo]Zoomd0?l0
<_l00_ooM0001_l02_oooo]ZoookJ_oonf[o00[oo`0bo`;ooi<000?ooo]ZoonC0?l0<_l00ol02_lE
oookJP03oom;0?oonf[oo`0000Sooo]Z0_oo;00foookJP03ool10?oonf[ooo]Z00Gooo]Z00?oo`/0
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00Wooo]Z000Eoook
JP03o`000?oonf[ooo]Z037ooo]Z00?oo`D0oookJ_oonfX0??oonfX00ooo4P3ooo]ZoookJP0Goook
JP;oo`001ooonfX00ooo003ooo]ZoookJP08oookJP03oom50?oonf[ooo]Z00kooo]Z00?ooe80oook
J_oonfX02_oonfX4o`1_o`;ooo]Z0ol0<_l2oookJP03o`1_oooonf[ooo]Z00Kooo]Z00Co06oooook
J_oonf[o00000_oonfX01_ood`3ooo]ZoooC0?o>o`3oom<0oookJP;oo`<01?oonfX4o`0bo`;ooo]Z
00Oo0?lCoookJ_oonf[oolT0oookJ_oob@3o0?mD00oooo]Z00?o06oooookJ_oonfX02OoonfX01_l0
d?oooo]ZoookJ_oo003ooo]Zo`3oT0Gooo]Z00Co0?n@oookJ_oonf[o0?n@0ooonfX2o`3oT0[ooo]Z
00?o00[ooookJ_oonfX01ooonfX3o`1_o`Sooo]Z0_oob@03oookJP03o`3oE?oonf[ooo]Z00?ooo]Z
00?oR_l0o`3oP_l0oh800_oonfX2o`3oPP;ooo]Z00Goo`40olko0?oonf[ooa`0olko0003oookJP;o
c_l00_l0<_l6oookJP03oomd0?l0<_oo00[o00Cooo]Z00Oo00[ooonC0?ooT`3ooi<0oookJ_l0<_oo
oi<000?ooo]Z0_l02_lIoookJP;oo`D00ooonfX00ooo;03ooo]ZoookJP0moookJP03ool;0?oonf[o
oo]Z01Kooo]Z00?o0000oookJ_oonfX08?oonfX00ooo003ooo]ZoookJP09oookJP03o`000?oonf[o
oo]Z00Wooo]Z000FoookJP;o0000POoonfX00ooo3`3ooo]ZoookJP0MoookJP03ool00?oonf[ooo]Z
00[ooo]Z0oooDP0:oookJPKo06oo00?o03;oo`1_ool0<_l00ol0Kol00ol0<_oo06oooookJP06oook
JP06o`1_oooonf[ooo]Zool00?oonf[oom<00_oonfX01?o>o`3ooo]ZoookJ_ood`03oookJP?o03;o
0_oonfX2o`3o4`;ooo]Z00So0?lCoookJ_oonf[ooo]Zooo90?l0oeCooo]Zooo900oooo]Z00?o06oo
oookJ_oonfX01?oonfX3o`0:o`;ooo]Z1?m8o`07oookJP03o`3oT?oonf[o0?n@00;ooo]Z0_l0oi00
0ooonf[ooeP0oomH0009oookJP03o`0:oom8o`3oB?l000?ooo]Z0ol0Kol:oookJPCoolT000?ooo]Z
o`3oE?oonfX01OoonfX00ol0oh;ooo]ZoookJP03o`3oPP?ooo]Z0_o>o`000oood`3ooo]Zolko0002
o`0bo`03olko0?l0<_oooo]Z00Sooo]Z00?oog@0o`0:ool02_l01_l02_l01?oonf[ooi<0oonC0?oo
T`06oookJP?o00[o6ooonfX00ooo;03oo`00oookJP0noookJP03ool00?oonf[ooo]Z00Gooo]Z0_oo
1@0?oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX02OoonfX001Sooo]Z00?o0000
oookJ_oonfX0@?oonfX00ooo103ooo]ZoookJP0koookJP03ool?0?oonf[ooo]Z01Gooo]Z0_oo0006
oookJP03ool00?oonf[ooo]Z00_ooo]Z00?ooe80oookJ_oonfX02ooonfX3o`1_o`03o`0boooonf[o
03;o00Cooo]Z00?ookd0o`1_ool0Kol02?l0Kol2olko00;ooo]Z00Koom<0olko0?ood`3ooo]ZoooC
0?oonfX3o`0bo`Cooo]Z00Go0?lCoookJ_l0oa?ooo]Zo`3o4`02ool30004oookJ_oob@3ooo]Zo`3o
E0;oolT04?oonfX00ol0Kooooo]ZoookJP03o`0:o`Kooo]Z00?o0=3oo`3oT?l0oi001om8o`001Ooo
nf[ooeP0oomH0?ooF03o0?n@00KooeP02OoonfX00ol02_oo06ooo`1_o`02o`1_o`gooo]Z1?oob@00
0ol0oeCooo]ZoookJP04oookJP03o`3oP_oonf[ooo]Z00;ooo]Z00co0?n2oookJ_oonf[ooo]ZoooC
0?oonf[oom<0olko0?l0<_ooc_l0oookJ_o>o`05oookJP03ool00?oonf[ooo]Z00;ooo]Z00?oog@0
oookJ_l02_l01_oonfX3o`0:o`03oonC0?l02_oo00[o00Ko00[o0_oonfX3o`0:oakooo]Z00?oo`40
oookJ_oonfX00_oonfX2oolD03gooo]Z00?oo`00oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z00Wooo]Z000IoookJP03o`000?oonf[ooo]Z08?ooo]Z00?oob/0oook
J_oonfX01ooonfX00ooo2`3ooo]ZoookJP0KoookJP03ool00?oonf[ooo]Z00gooo]Z00?o03;oo`1_
ool0<_l01OoonfX00ooo_@3o06oooookJP05oookJP05o`1_ooo>o`3oc_l0oookJ_o>o`000_oonfX0
0oo>o`3oom<0o`0bo`03o`0bo`;ooa`00ooonfX2o`3o4`;ooo]Z0ol0oa<2oookJP;oolT000Co0?mD
ooo90?oob@3oolT04?oonfX3o`0:o`[ooo]Z00?o0=3ooookJ_l0oi000ol0oi03oookJPKoB?l000?o
0?n@oookJ_ooF0001_oonfX00ooo003oo`80oookJP03o`1_o`03o`0:oom8o`3oB?l000gooo]Z1Ooo
b@000ol0oeCooo]ZoookJP04oookJP03o`3oP_oonf[ooo]Z00Gooo]Z1?l0<_l01?ood`3oc_l0olko
0?o>o`08oookJP07ool30?oonf[ooo]Zoomd0?oonf[o00[oo`0bo`05oookJP04o`0:ool0<_oooo]Z
oonC00Sooo]Z1_l02_lRoookJP03oolD0?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX02?oonfX2
oolR03Gooo]Z00?oo`80oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[o
oo]Z00Wooo]Z000JoookJP03o`000?oonf[ooo]Z04oooo]Z00?oo`80oookJ_oonfX0<?oonfX00ooo
:`3ooo]ZoookJP0NoookJP03ool00?oonf[ooo]Z017ooo]Z00?oo`40oookJ_oonfX00_l0<_l02Ooo
EP3o06ooo`1_ool0Kooooo]Zoonm0?oonf[o03;oo`1_o`03oookJP;o06oo00Goc_l0oom00?oo@03o
c_l0o`000002olko00;o03;o00?oom<0oookJ_oonfX00_oonfX2oolL00;o0?lC0ooonfX01?l0oa?o
oo]Zo`3o4ol0oa<4oookJP06o`3oE?oob@3oolT0ooo90?oonf[oo`802_oonfX4o`0:o`;ooo]Z00?o
06oooookJ_oonfX02OoonfX01Ol0d?oooo]Zo`3oT?l0oi3ooo]Z00Co0?n@00Gooo]Zo`3oT?l0oi3o
0?n@oookJP07odSo0003oookJ_oo2@3o06oo00;o06oo00Kooo]ZodSo0?oonf[ooo]Zo`0:oooonfX2
odSo00Oooo]Z1?oob@02oookJP;oolT000?o0?mDoookJ_oonfX01?oonfX00ol0oh;ooo]ZoookJP03
oookJP?o03;o00Cooo]ZoooC0?ood`3ooo]Z0_ood`000oo>o`3ooo]ZoookJP09oookJP05oomd0?oo
nf[ooo]ZoookJ_l02_l00_oonfX01ooo003ooo]Zool00?l0<_oo00[ooolT0?ooT`002?oonfX5o`0:
o`03oomB0?oonf[ooo]Z02[ooo]Z00?oo`L0oookJ_oonfX00ooonfX2oolR03oooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP08oookJP006ooonfX2o`0004;ooo]Z00?oo`d0oookJ_oo
nfX06ooonfX00ooo0@3ooo]ZoookJP0NoookJP;oob/03ooonfX00ooo;03ooo]ZoookJP06oookJP03
ool50?oonf[ooo]Z01?ooo]Z00?oo`00oookJ_oonfX00ooonfX00ooo0@3ooo]Zo`0bo`02o`0bo`Co
oo]Z00Go06oooonm0?oonf[ooo]Zo`1_o`02oookJP04o`1_oooonf[ooo]Zolko00;ood000_o>o`00
0ol0<_ooc_l0ooWo0006oookJP03oolL0?l0oa?ooo]Z00Cooo]Z00Go0?lCoookJ_l0oa?ooo]Zo`3o
4`02ool60003o`3oE?oonf[ooo]Z00_ooo]Z0ol02_l2ool200Gooo]Z00?o06oooookJ_oonfX02Ooo
nfX00ol0d?oooo]ZoookJP02o`3oT0?ooo]Z1Ol0oi07oookJP;o06oo1Om8o`02oookJP03odSo0?l0
2_oooo]Z00;oB?l000?oo`00oookJ_oonfX00ooob@06oookJP03ooo90?oonf[o0?mD00Kooo]Z00?o
0?n2oookJ_l0<_l00ol0<_l3oookJP?oom<000Cooo]ZoooC0?ood`3oc_l03ooonfX00ol02_oo03;o
oookJP02oookJP06o`0boooonf[o00[ooookJ_oo903ooi<00ooonfX4o`0:o`;ooo]Z0_l02_l3oomB
02oooo]Z00?oo`00oookJ_oo8P00?ooonfX00ooo003ooo]Zo`00000[oookJP03o`000?oonf[ooo]Z
00Sooo]Z000MoookJP03o`000?oonf[ooo]Z057ooo]Z00?oo`/0oookJ_oonfX02OoonfX00ooo0@3o
oo]ZoookJP0OoookJP03ool[0?oonf[ooo]Z00gooo]Z00?oob`0oookJ_oonfX05OoonfX00ooo0@3o
oo]ZoookJP0;oookJP;o03;o00?ooo]Zo`0boooonfX01?oonfX01_oo_@3o06ooo`1_ool0Kooooo]Z
o`1_o`?ooo]Z1?o>o`03oookJP03olko0?oonf[ooo]Z00Cooo]Z00?o0?lCoookJ_oonfX01?oonfX2
o`3o4`06oo3o0?oonf[ooo]Zo`3o4ooonf[o0?mD2_oonfX3o`0:o`03oookJ_oo003ooo]Z00Sooo]Z
00?o06oooookJ_oonfX02OoonfX02?l0d?oooo]ZoookJ_oonf[o0?n@oookJ_l0oi3ooo]Z1?l0oi0=
oookJPGoB?l000?o00[oodSo0?oo00000ooob@08oookJP03ool10?oonf[o0?mD00Kooo]Z00?o0?n2
o`0bool0<_l01_oonfX01Oood`3ooo]ZoookJ_oonf[oom<000;ooo]Z00?oc_l0oookJ_oonfX03Ooo
nfX01Ol02_oo03;ooookJ_oonf[o03;o00?ooo]Z00?o00[ooookJ_ooT`000ol02_l00ooonf[oo`00
oookJP02oookJP;o00[o0_oonfX00oooDP3ooo]ZoookJP0doookJP03ool20?oonf[ooo]Z00Cooo]Z
00?ooa80oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP02oookJP03ool00?oonf[oo`D002?ooo]Z
00?o0000oookJ_oonfX02?oonfX001kooo]Z00?o0000oookJ_oonfX0D?oonfX00ooo2`3ooo]Zoook
JP0HoookJP;oo`008OoonfX2ool/00kooo]Z00?oobH0oookJ_oonfX04_oonfX2o`0bo`;ooo]Z00Ko
03;ooookJ_oonf[oo`00oookJ_oo_@03oookJP03o`0bool0Kooo03;o00?o03;o00Gooo]Zolko0?o>
o`3o0000oookJP04olko00Gooo]Z0_l0oa<4oookJP05o`3o4ooonf[o0?lCoookJ_o`o`000_oonfX0
0ol0oa?ooo]ZoookJP05oookJPCo00[o0_oo000=oookJP03o`1_oooo0@3ooo]Z00Wooo]Z00Co0=3o
oookJ_oonf[ooo]Z0ol0oi0AoookJP03odSo0?oonf[oB?l000?ooo]Z00Co00[oooo90?m8o`3oB?l0
2?oonfX01?oo0@3oo`00o`3oE?oo8P02oookJPCo03;o00?o0?n2oookJ_oonfX01OoonfX00oood`3o
oo]ZoookJP05oookJP03olko0?oonf[ooo]Z00gooo]Z00Cooi/0o`0:oooonf[o03;o0ooonfX4o`0:
o`Oooo]Z0_l02_l2oookJP03oomB0?oonf[ooo]Z03cooo]Z00?ooa80oookJ_oonfX0=_oonfX00ol0
003ooo]ZoookJP0;oookJP;oo`806_oonfX00ol0003ooo]ZoookJP08oookJP007ooonfX2o`00067o
oo]Z00?oo`P0oookJ_oonfX0:ooonfX00ooo;03ooo]ZoookJP0<oookJP;oobH04_oonfX2o`0bo`06
ool00?oonf[ooo]ZoookJ_l0<_oooo]Z0ooo_@02oookJP?o03;o1OoonfX6olko0003oookJ_oio`3o
oo]Z00Gooo]Z0_l0oa<3oookJP;o0?lC0ooonfX01?o`o`3ooo]Zo`3o4ol0oa<3oookJP?o00[o00?o
oo]ZoonG0?ooU`003_oonfX01?oo003ooo]ZoookJ_l0Kol;oookJP03o`3@oooonf[ooo]Z00Kooo]Z
0_l0d?l;oookJP03odSo0?oonf[ooo]Z00KoB?l02ooonfX00ooo8P3o0?mDo`0bo`02o`0bo`?ooo]Z
00?o0?n2oookJ_oonfX01?oonfX2oooC00Sooo]Z00?oc_l0oookJ_oonfX03?oonfX2oonK0003o`0:
ool0<_oo00[o00?o00[o00?ooo]Zo`0:oooonfX01ooonfX2o`0:o`?ooo]Z00Cooe80oookJ_oonf[o
o`001ooonfX2oolS03Gooo]Z00?oo`00oookJ_oonfX00ooonfX2ool802kooo]Z00?o0000oookJ_oo
nfX02ooonfX00ooo0P3ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Sooo]Z000QoookJP03o`00
0?oonf[ooo]Z05kooo]Z00?oo`P0oookJ_oonfX05ooonfX00ooo003ooo]ZoookJP0QoookJP;oobH0
3?oonfX2oolI00;ooo]Z0_l0<_l5oookJP04o`0boooo_@3ooo]Zoonm00?o03;o0_oonfX00ol0<_oo
o`00oookJP03oookJP04ool10?oonf[o0000olko00?ooo]Z00?onOl0oookJ_oonfX01OoonfX2o`3o
4`;ooo]Z0_l0oa<3oookJP;o0?lC0_oonfX3o`0:o`03o`3oP_oonf[ooo]Z00?ooo]Z0oooU`08oook
JPCoobT00ooonfX00ol0Kooooo]ZoookJP07oookJP03ool20?oonf[o0=3o00Oooo]Z00?o0=3ooook
J_l0d?l02_oonfX4odSo0003oookJ_m8o`3oB?l000_ooo]Z0_l0<_l00ol0oeCo03;ooookJP04oook
JP05o`3oP_oonf[ooo]ZoookJ_oo00000_oonfX00oood`3ooo]ZoookJP08oookJP03olko0?oonf[o
oo]Z00_ooo]Z0_ooV`02o`0:o`03oonK0?oonf[ooo]Z00Cooo]Z00?o00[ooookJ_oonfX01?oonfX2
o`0:o`_ooo]Z00?oo`40oookJ_oonfX00_oonfX00ooo8`3ooo]ZoookJP0;oookJP03oolk0?oonf[o
oo]Z02_ooo]Z00Coo`P0oookJ_oo003oo`00;OoonfX00ol0003ooo]ZoookJP0BoookJP;oo`404_oo
nfX00ol0003ooo]ZoookJP08oookJP008_oonfX00ol0003ooo]ZoookJP1]oookJP03ool50?oonf[o
oo]Z01Kooo]Z00?oo`00oookJ_oonfX06OoonfX00oooJP3ooo]ZoookJP05oookJP;ooaT000?ooo]Z
o`0boooonfX01OoonfX2oonm0003o`0:oooo_@3ookd000Cooo]Z00?o03;ooookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP02oookJP03ooWo0?oonf[ooo]Z00;ooo]Z0_oo0@02oookJP;o0?lC00?ooo]Z
o`3o4ooonfX01?l0oa<3o`0:o`?ooo]Z00?o0?n2oookJ_oonfX01_oonfX3oonG0003oookJ_ooU`3o
oiL000Gooo]Z0_oo:@03oookJP03o`1_oooonf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX00_oonfX0
0ol0d?oooo]ZoookJP03oookJP04o`3@oooonf[o0=3ooookJP;o0=3o2OoonfX4odSo00Wooo]Z1?l0
<_l7oookJP;ol?l000Co0?n2oo3o0?oonf[ooo]Z0_oo10000oood`3ooo]ZoookJP06oookJP06ool0
0?oonf[ooo]Zolko0?oonf[oocL02OoonfX3o`0:o`?ooi/000?o00[ooookJ_oonfX01?oonfX00ol0
2_oooo]ZoookJP03oookJP;o00[o4?oonfX00ooo8`3ooo]ZoookJP03oookJP03ool00?oonf[ooo]Z
00Gooo]Z0ooo>`0foookJP03ool30?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP08oookJP008ooonfX00ol0003ooo]ZoookJP1QoookJP03oolJ0?oonf[ooo]Z01So
oo]Z00?oo`80oookJ_oonfX08_oonfX00oooJP3ooo]ZoookJP07oookJP03o`0boooonf[ooo]Z00;o
oo]Z0ol0<_l00ol02_oookd0oonm0003oonm00Cooo]Z00?o03;ooookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP02oookJP03ooWo0?oo003ooo]Z00Oooo]Z1?l0oa<4o`0:o`03ool20?oonf[ol?l000;o
oo]Z00?o0?n2oookJ_oonfX02_oonfX3oonG0003o`0boooonf[ooo]Z00Sooo]Z00Go06oooookJ_oo
nf[ooo]Zool60007oookJP08o`3@oooonf[ooo]ZoookJ_l0d?oooo]Zool00?l0d?l3oookJP03o`3@
oooonf[ooo]Z00Oooo]Z00?oB?l0oookJ_oonfX01_oonfX3o`0bo`[ooo]Z0_o`o`000ol0oh;ol?l0
oo3o0002oo3o0003oookJ_ood`3ooo]Z00Wooo]Z0_oio`000oo>o`3onOl0ooWo0006oookJP?o00[o
0ooonfX2oonK0003oookJ_l02_oooo]Z00Gooo]Z00?o00[ooookJ_oonfX00_oonfX2o`0:oa_ooo]Z
0_oo2`03oookJP03oolk0?oonf[ooo]Z03gooo]Z00?ooa00oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0IoookJP03ool00?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX02?oonfX002Cooo]Z0_l0
000QoookJP;oo`P0?_oonfX2oolJ01Wooo]Z00?oo`80oookJ_oonfX05?oonfX00ooo003ooo]Zoook
JP0;oookJP03oomZ0?oonf[ooo]Z00Kooo]Z00?o03;ooookJ_oonfX00ol0<_l01OooM@3o00[oo`0:
ool02_oo03;o00;ookd01_oonfX00ol0<_oooo]ZoookJP04oookJP03o`000?oo0P3ooo]Z00;ooo]Z
0_oio`09oookJP?o00[o00Co0?lCoookJ_oonf[o0?mD0ooonfX00oo`o`3ooo]Zo`3oPP0<oookJPCo
oiL000?o03;ooookJ_oonfX02?oonfX4o`3o4`Sooo]Z00Go0=3ooookJ_l0d?oooo]Zool00002oook
JP04o`3@oooonf[ooo]ZoookJP;o0=3o0oooU`09oookJPCo03;o3OoonfX2oo3o0003o`3oP_o`o`3o
oo]Z00;ol?l02_oonfX4ooWo0003olko0?oonf[onOl000;ooo]Z1?l02_l5oookJP05oonK0?oonf[o
oo]ZoookJ_l02_l01ooonfX00ol02_oooo]ZoookJP02o`0:ob7ooo]Z00?ooc/0ool00?oonfX0?_oo
nfX00ooo0@3ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX01ooo
nfX002Kooo]Z00?o0000oookJ_oonfX07ooonfX00ooo203ooo]ZoookJP1=oookJP03oolH0?oonf[o
oo]Z01Kooo]Z00?oo`00oookJ_oonfX04_oonfX2oomZ00Oooo]Z1?l0<_l2oookJP;o00[o00KoogD0
o`0:oooonf[o03;ooookJ_l02_l7oookJP03o`0booooH`3ooo]Z00?ooo]Z00Co0000oookJ_oonf[o
oo]Z1?oio`05oookJP?o00[o0_oonfX01?l0oa?ooo]ZoookJ_l0oe@5oookJP04o`3oP_oonf[ol?l0
oo3o00_ooo]Z00GooiL0oookJ_oonf[ooo]Zo`0bo`0:oookJP03o`1_oooonf[ooo]Z00Ko0?lC0ooo
nfX00ol0d?oooo]ZoookJP03oookJP03o`3@oooonf[ooiL000OooiL01OoonfX3o`0bo`;ooo]Z00?o
0?lCoookJ_l0oa<02_oonfX3oo3o0003o`3oP_oonf[ol?l000;ol?l02ooonfX01_oio`3ooo]Zoook
J_oio`3oc_l0ooWo00?o00[o1?oonfX00ooo003ooo]ZoookJP02oookJP03oonK0?oonf[ooo]Z00;o
oo]Z00?o00[ooookJ_oonfX01?oonfX01?l02_oooo]Zo`0:ool02_lRoookJP03oolk0?oonf[ooo]Z
00;ooo]Z0_oo0`04oookJP;ooah0??oonfX2ool801Oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP07oookJP009ooonfX00ol0003ooo]ZoookJP0`oookJP03ool70?oonf[ooo]Z03_o
oo]Z0_oo600>oookJP03oolC0?oonf[ooo]Z01Cooo]Z00?oo`00oookJ_oonfX00ooonfX4oomZ00Go
oo]Z1_l0<_l01?l02_oooo]ZoookJ_l02_l3oookJP03o`0bool02_oooo]Z00Kooo]Z00?o03;ooook
J_ooH`000ooonfX01Ol0003ooo]ZoookJ_oio`3ooo]Z00;onOl000?ooo]ZooWo0?l02_l00ol02_l3
oookJP;o0?mD0ooonfX00ol0oeCooo]ZoookJP03oookJP05o`3oP_o`o`3ol?l0oookJ_o`o`003ooo
nfX00ol0<_oooo]ZoookJP08oookJP03o`1_oooonf[ooo]Z00Gooo]Z1_l0oa<5oonG00Cooo]Z0_oo
U`000ooo003ooo]ZoookJP04o`0bo`Gooo]Z0_l0oa<00ooonf[o0?lCoookJP05oookJP?ol?l00_oo
nfX00ol0oh;ol?l0oookJP02oo3o00gooo]Z00KonOl0o`0:ool02_ooc_l0o`0:oooio`07oookJP;o
o`/000?ooo]ZoonK0?oonfX01?oonfX00ol02_oooo]ZoookJP04oookJP?o00[o2_oonfX2oomZ02;o
oo]Z00?ooah0oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP0foookJP;oo`006?oonfX00ol0003o
oo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00Oooo]Z000XoookJP;o0000@OoonfX00ooo1@3ooo]Z
oookJP0joookJP;ooa<06ooonfX3oomZ00Sooo]Z0_l0<_l01Ooonf[o00[ooookJ_l0<_oo00[o00Ko
03;o00?o00[oo`0bool0<_l01?oonfX01?l0<_oooo]ZoookJ_ooH`02oookJP04o`000?oonf[onOl0
ooWo00;ooo]Z0ol02_l00ooio`3oocL0oookJP03oookJP06o`3oE?oonf[o0?mDo`3oE?oonf[o0?mD
1OoonfX00ol0oh;oo`00oo3o0002oo3o0003oookJ_o`o`3ooo]Z00Sooo]Z0_oo0@04oookJP03o`0b
oooonf[ooo]Z00Sooo]Z00?o06oooookJ_oonfX01_oonfX01?l0d?oooo]ZoookJ_l0d?l6o`3o4`?o
oo]Z00?ooiL0o`3@ool0<_l00_l0<_l8oookJP03o`3o4ooo003ooo]Z00?o0?lC0_oonfX3oo3o00Go
oo]Z00Co0?n2oo3o0?oonf[ol?l02ooonfX4o`0:o`03ooWo0?oonf[onOl000;onOl02OoonfX00ooo
V`3ooo]ZoookJP04oookJP03o`0:oooonf[oo`4000?ooo]Z00?oocX0o`0:ool02_l02_oonfX00ooo
JP3ooo]ZoomZ000VoookJP03ool00?oonf[ooo]Z00?ooo]Z00?oo`d0oookJ_oonfX0>_oonfX2ool4
013ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP07oookJP00:_oonfX00ol0003o
oo]ZoookJP0noookJP03ool50?oonf[ooo]Z04Wooo]Z0_oo2`0=oookJP03oomZ0?oonf[ooo]Z00Co
oo]Z00?oo`00oookJ_oonfX00_oonfX01Ol0<_oo00[ooookJ_l02_oooo]Z00;oogD000Gooo]Zoome
0?l0<_oooo]Zo`0:o`02oookJPKo03;o0_oonfX3oomS00;ooo]Z0ol02_l00ooio`3ooo]ZooWo0002
oookJP?oocL000Go0?mDoookJ_oonf[o0?mDoookJP02o`3oE0;ooo]Z0_oo4@000ooonf[o0?n2oo3o
0002oookJP?ol?l01ooonfX00ooo003ooo]ZoookJP06oookJP03o`0boooonf[ooo]Z00Sooo]Z00?o
06oooookJ_oonfX01?oonfX00ol0d?oooo]ZoookJP02oookJP06o`3@oooonf[ooo]ZoookJ_l0d?oo
oo]Z0ol0oa<2o`0bo`;o0?lC2OoonfX01Ol0oa?oo`<0oookJ_l0oa?ooo]Z00?ol?l01?oonfX01?oo
003ooo]ZoookJ_l0oh82oookJP03oo3o0?oonf[ooo]Z00Oooo]Z0ol02_l01ooonf[onOl0oookJ_oo
nf[onOl0oookJ_oio`004ooonfX00ol02_ooo`40oookJP02oookJP03o`0:oooonf[ooo]Z00[ooo]Z
1?ooJP0[oookJP05ool=0?oonf[ooo]ZoookJ_oo0000@OoonfX00ooo0@3ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX01ooonfX002_ooo]Z00?o0000oookJ_oonfX0
C_oonfX00ooo0`3ooo]ZoookJP0`oookJP03oolk0?oonf[ooo]Z01Cooo]Z0_oo1@0:oookJP03o`0:
oooonf[o00[o00;o03;o1?ooM@000ooo003o03;oo`0:o`05oookJP03o`0boooonf[ooo]Z00;ooo]Z
00?oof<0o`0:ool02_l00_l02_l00ooo0@3oc_l0ooWo0002ooWo00Cooo]Z0_l0oe@2oookJP03o`3o
E?oonf[ooo]Z00;o0?mD0ooonfX00ooo4@3o0?n2oo3o0003oo3o0003oookJ_o`o`3ol?l000Cooo]Z
00?oo`<0oookJ_oonfX02_oonfX00ol0<_oooo]Zool00008oookJP03o`1_oooonf[ooo]Z00;ooo]Z
00?o0=3ooookJ_oonfX01?oonfX01Ol0d?oooo]ZoookJ_oonf[o0=3o00;ooo]Z0_l0d?l3oookJPKo
0?lC0ooonfX01_l0oa?ooo]Zoo3o0?l0oa?ol?l0oookJP?o0?lC1_oonfX00ol0oh;ooo]ZoookJP06
oookJPCo00[o0ooonfX00ooio`3ooo]ZoookJP02oookJP03ooWo0?oonf[ooo]Z00oooo]Z0_oo_@00
0ooonf[o00[ooookJP02oookJP03o`0:oooonf[ooo]Z00Gooo]Z00?oo`00oookJ_oonfX01?oonfX0
0oooJP3ooo]ZoookJP0eoookJP03ool40?oonf[ooo]Z00Cooo]Z00?ooaX0oookJ_oonfX0>ooonfX0
0ooo003o0000oookJP0RoookJP03o`000?oonf[ooo]Z00Oooo]Z000/oookJP03o`000?oonf[ooo]Z
043ooo]Z00?ooa00oookJ_oonfX06_oonfX00ooo0@3ooo]ZoookJP0PoookJP03oolk0?oonf[ooo]Z
01oooo]Z00Ko00[ooookJ_l02_oo00[oool10?oonfX2o`0bo`06oome0?oonf[ooo]Zo`0boooonf[o
00[o0_oonfX2o`0bo`?ooo]Z0ol02_l2oomS00?ooo]Z00?oc_l0oookJ_oio`001?oonfX00ol0oeCo
oo]ZoookJP02oookJP06o`3oE?oonf[ooo]Zo`3oE?ngo`3o0?mD0ooonfX01Ol0oh;ooo]ZoookJ_o`
o`3ooo]Z00?ol?l00ooonfX2ool300gooo]Z00?o03;oool00?oonfX02?oonfX01?l0Kooooo]Zoook
J_l0d?l8oookJP08o`3@oooonf[ooo]Zo`3@oooonf[o0=3ooookJ_l0d?l9oookJP?o0?lC0_o`o`00
0ol0oa?ooo]ZoookJP03oookJP;o0?lC0_oonfX00ooo003ooo]Zo`3oPP03oom000?ooo]Z0ol02_l6
oookJP03ooWo0?oonf[ooo]Z01Cooo]Z1?oo_@001?l02_oooo]ZoookJ_l02_l;oookJP;ooa400_oo
nfX01?ooJP3ooo]ZoookJ_oo000koookJP04oolJ0?oonf[ooo]Zool103Wooo]Z00Coo`00oookJ_oo
203o00008_oonfX00ol0003ooo]ZoookJP07oookJP00;OoonfX2o`00043ooo]Z0_oo400ZoookJP03
ool00?oonf[ooo]Z017ooo]Z00?ooc/0oookJ_oonfX03OoonfX00ooo>03ooo]ZoookJP0>oookJP06
o`0:oooonf[o00[ooookJ_l02_ooo`400ooonfX2o`0bo`04oookJ_l0<_oooo]Zo`0:o`;o03;o0_oo
nfX3o`0:o`Cooo]Z00Go0000oookJ_oonf[ooo]Zolko0005oookJP03o`3oE?oonf[ooo]Z00?ooo]Z
00?o0?mDoookJ_l0oe@00_oonfX01?ngo`3o0?mDoookJ_l0oh84oookJP;ol?l00_oonfX2oooC00ko
oo]Z00Coo`00oookJ_oonf[o03;o2_oonfX00ol0Kooo0=3ooookJP09oookJP03o`3@oooonf[ooo]Z
00;o0=3o00?ooo]Zo`3@oooonfX02ooonfX00ol0oa?ooo]Zo`3o4`06o`3o4`08oookJ_l0oa?ooo]Z
oom00?l0oh;ood00oookJ_oo@004o`0:o`03oookJ_ngo`3o]ol000Cooo]Z0_oio`0FoookJP;ookd0
0_oonfX01?oo_@3ooo]Zo`0:ool02_l?oookJP03oomZ0?oonf[ooo]Z00Gooo]Z00Coo`@0oookJ_oo
nf[ooo]Z0_oo<`0boookJP04oolJ0?oonf[oo`40ool103gooo]Z00?o0000oookJ_oonfX01?oonfX0
0ooo103ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Kooo]Z000_oookJP03o`000?oonf[ooo]Z
04oooo]Z00?oo`h0oookJ_oonfX0:_oonfX3oolk00kooo]Z0_oo>00=oookJP04oolZ0?oonf[o00[o
o`0:o`?ooo]Z00?o00[ooookJ_oonfX00ooonfX4o`0bo`Co00[o00?oo`00oookJ_oonfX01?oonfX0
1Ol0003ooo]ZoookJ_oonf[oc_l000Cooo]Z00?o0?mDool00?oonfX01?oonfX00ol0oeCooo]Zo`3o
E003oookJP03okOo0?l0oeCo0?n200[ooo]Z0oood`0?oookJP03o`0boooonf[ooo]Z00Gooo]Z00?o
o`00oookJ_l0d?l00_l0d?l:oookJP03o`3@oooonf[o0=3o00;ooo]Z00?o0=3ooookJ_oonfX02Ooo
nfX01?l0oa?ooo]ZoookJ_l0oa<5oookJPCo0?lC00?ooo]Zo`3oP_l02_l00_l02_l4oookJP;o]ol0
00Gooo]ZokOo0?ngo`3ooo]ZooWo0006oookJP04ool00?oonf[ooo]ZoookJPCoc_l02ooonfX00ooo
_@3ooo]Zoonm0002oonm0003o`0:oooonf[ooo]Z00kooo]Z00?oofX0oookJ_oonfX01?oonfX2ool4
00?ooo]Z0_oo<`0koookJP;oo`d000?ooo]Zool00?oonfX0<ooonfX00ol0003ooo]ZoookJP0<oook
JP03ool20?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX01_oonfX0033ooo]Z00?o0000oookJ_oo
nfX0C_oonfX00ooo3P3ooo]ZoookJP0=oookJP03ool:0?oonf[ooo]Z01Kooo]Z00?oo`00oookJ_oo
nfX04_oonfX3oolh00gooo]Z0_l02_l4oookJP03o`0:oooonf[ooo]Z00Cooo]Z00Co00[oo`0bool0
2_oo00[o2_oonfX00ol0003ooo]ZoookJP02oookJP04olko0?oo003ooo]ZoookJP;o0?mD1?oonfX0
0ol0oeCooo]Zo`3oE004oookJP03ool10?l0oh;o0?mD00gooo]Z0oood`05oookJPOoodd000?ooo]Z
o`0boooonfX02OoonfX5o`3@o`?ooo]Z00Coo`00oookJ_oonf[o06oo0_l0d?l2oookJP03o`3@oooo
nf[ooo]Z00Wooo]Z00?o0?lCoookJ_oonfX02?l0oa<2o`0:o`03o`3oP_l02_oooo]Z00Gooo]Z1Ong
o`000ooo303onOl0okOo0009oookJP03olko0?oonf[oc_l000?oc_l02ooonfX3oonm01gooo]Z00?o
oc<0oookJ_oonfX01?oonfX00ooo003ooo]ZoookJP0noookJP03ool50?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX02ooonfX00ooo0P3ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00Kooo]Z000a
oookJP;o0000G_oonfX00ooo2P3ooo]ZoookJP0ToookJP03ool00?oonf[ooo]Z00Gooo]Z00?oocP0
oookJ_oonfX02ooonfX2o`0:o`03oolZ0?oonf[ooo]Z00;ooo]Z00Co00[ooookJ_oonf[ooo]Z0ol0
2_l3oolG0003o`0:oooonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00_oonfX00oo>o`3ooo]Zoook
JP02oookJP;o0?mD0ooonfX01Ol0oeCooo]Zo`3oE?oonf[oo`0000?ooo]Z00?o0?n2o`3oE?l0oe@0
3ooonfX2oooC00;o00[o00?ooo]ZoooC0?oonfX00ooonfX3oom=0003oookJ_l0<_oooo]Z00;ooo]Z
0ooo4@04oookJP04o`1_ool0d?oooo]ZoookJPGo0=3o00Cooo]Zo`3@oooonf[o06oo0_l0d?l4oook
JP;oom<01_oonfX4o`3o4`;ooo]Z0_l0oa<3o`0:o`[ooo]Z00Go]ol0oookJ_oonf[o]ol0oookJP04
okOo00Kooo]Z00?oo`40olko0?o>o`000oo>o`000oooEP3oc_l0oookJP0:oookJP;ookd0:OoonfX2
oolD00Cooo]Z00?oo`00oookJ_oonfX0=?oonfX00ooo1@3ooo]ZoookJP0]oookJP03o`000?oonf[o
oo]Z01;ooo]Z00?oo`00oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP06oookJP00<ooonfX00ol0
003ooo]ZoookJP1[oookJP03ool50?oonf[ooo]Z02;ooo]Z00?oo`00oookJ_oonfX01?oonfX2o`0:
o`Oooo]Z0ol02_l5oookJP03oolG0?oonf[o00[o00Wooo]Z0_oo2003oookJP03olko0?oonf[ooo]Z
00?ooo]Z0_l0oe@2oookJP;o0?mD1OoonfX01?l0oh;o0?mDoookJ_ngo`0AoookJPGoom<02?oonfX0
0ol0<_oooo]ZoookJP08oookJP04o`1_ool0d?oo0=3ooookJP;oo`800_oonfX01_l0Kooo0=3oo`1_
ool0d?oo06ooo`3@o`?ooo]Z00Coo`00oooC0?ood`3oom<01_oonfX3o`3o4`Co00[o3_oonfX01?ng
o`3ooo]ZokOo0?oio`02okOo00Sooo]Z0_o>o`02oomF0004olko0?oonf[oc_l0olko00?ooo]Z00?o
o`00oookJ_oonfX01?oonfX00ooo_@3ooo]ZoookJP0YoookJP03oolD0?oonf[ooo]Z04?ooo]Z00?o
o`80oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00Kooo]Z000d
oookJP03o`000?oonf[ooo]Z063ooo]Z00?oob80oookJ_oonfX05_oonfX00ooo0P3ooo]ZoookJP0J
oookJP03o`0:oooonf[ooo]Z00;ooo]Z1Ol02_l9oookJP03o`0:oooonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX00_oonfX00oo>o`3ooo]ZoookJP04oookJP;o0?mD00?oo`40o`3oE?l0oe@00_oonfX4
o`3oE0?ooo]Z00?o]ol0oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP0;oookJPCoom<01ooonfX4
o`3oE0Sooo]Z00Co06oooookJ_l0d?oo0=3o0_oonfX01?l0Kooo0=3ooookJ_l0Kol2o`3@o`;o06oo
0_oonfX00ooo003oom<0oookJP02oooC00Cooo]Z1?l02_l3oookJP;o0?mD2ooonfX4okOo0003oook
J_ngo`3o]ol000Wooo]Z00Coc_l0oomF0?o>o`3oc_l00_oonfX2olko00?ooo]Z00Coo`00oookJ_oo
nf[ooaL00_oonfX00ooo_@3ooo]ZoookJP0doookJP;oo`H01?oonfX2ool[03gooo]Z00?oo`d0oook
J_oonfX07?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00Kooo]Z000eoookJP03
o`000?oonf[ooo]Z05oooo]Z00?oob80oookJ_oonfX09OoonfX00ooo003ooo]ZoookJP0:oookJP03
o`0:oooonf[ooo]Z00?o00[o00?ooo]Zool00?oonfX00_oonfX00ol02_oooo]ZoookJP06oookJP03
o`0:oooonf[ooo]Z00;ooo]Z00?oohH0oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP;o
c_l01OoonfX01Ol0oeCooo]Zo`3oE?l0oeCooo]Z00;o0?mD00?ooo]Zo`3oE?l0oe@01OoonfX00ong
o`3ooo]ZoookJP0<oookJP;oo`001_ood`08oookJP03o`0boooonf[o0?mD00Ko0?mD0_oonfX00ol0
Koooom<0oooC000BoooC00?o00[o1ooonfX3o`3oE0Oooo]Z0ongo`02oookJP04okOo0?oonf[ooo]Z
okOo00_ooo]Z00Ooc_l0oookJ_oonf[ooo]Zolko0?oonf[oc_l000Gooo]Z0_oo5`02oookJP05oonm
0?oonf[ooo]ZoookJ_oo00001_oonfX3oomB02oooo]Z0_oo:`02oookJP03ool10?oonf[ooo]Z03So
oo]Z00?oo`d0oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Ko
oo]Z000foookJP;o00008?oonfX2ool;03gooo]Z0_oo8P0>oookJP03oolM0?oonf[ooo]Z027ooo]Z
1?l02_l8oookJP03o`0:oooonf[ooo]Z00Kooo]Z00?oo`00o`0:oooonfX00ooonfX01OooQP3ooo]Z
oookJ_oonf[o000000?ooo]Z1?o>o`000ooonf[ooeH0oomF0002oookJPCo0?mD0_oonfX00ol0oeCo
oo]Zo`3oPP06oookJP03okOo0?oonf[ooo]Z00;o]ol03OoonfX2oooC0003o`0:oooonf[ooo]Z00So
oo]Z00?o03;ooookJ_oonfX01OoonfX7o`3oE005o`3@oooonf[ooo]ZoookJ_l0Kol00ooonfX01?oo
=`3o06ooo`1_ooood`04o`0:o`Gooo]Z00?oo`00oookJ_oonfX00_oonfX01?l0oeCooo]Zo`3oE?l0
oe@2oookJPCo]ol01_oonfX2okOo00_ooo]Z00?oc_l0oookJ_o>o`000_oonfX2olko00Wooo]Z00?o
okd0oookJ_oonfX01OoonfX00ooo1@3ooo]ZoookJP02oookJP;ooe80;ooonfX01Ooo:`3ooo]Zoook
J_oonf[oo`4000Gooo]Z0_oo500loookJP03ool60?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
6ooonfX00ol0003ooo]ZoookJP06oookJP00>?oonfX00ol0003ooo]ZoookJP0_oookJP03ool80?oo
nf[ooo]Z03_ooo]Z00?ooad0oookJ_oonfX03?oonfX00ooo503ooo]ZoookJP0@oookJPOo00[o1_oo
nfX01?l02_oooo]ZoookJ_oo0006oookJP03o`0:oooonf[ooo]Z00?ooo]Z00SoohH0oookJ_oonf[o
0000oookJ_oo003oc_l0oookJP;oc_l000Cooo]Zolko0?oonf[ooo]Z0_ooEP002?oonf[o0?mDo`3o
P_l0oeCooo]Zo`3oE?oonf[o0?n20_oonfX3oolT00?ooo]Z00Co]ol0oookJ_ngo`3ooo]Z0_ngo`05
oookJP03ool00?oonf[ooo]Z00Kooo]Z00?o00[ooookJ_oonfX02?oonfX00ol0<_oooo]ZoookJP08
oookJP;o06oo00?ooo]Zo`3oE?l0oe@01Ol0oe@2oookJP?o00[o00?oocL0oookJ_oonfX01_oonfX0
1Ooo2`3ooo]ZoookJ_oonf[o0?mD00;ooo]Z00Go0?mDokOo0?ngo`3o]ol0ool00009oookJP03okOo
0?oonf[ooo]Z00Sooo]Z0_o>o`03oookJP03olko0?oonf[oc_l000Wooo]Z00?ookd0oookJ_oonfX0
1_oonfX01Ooo1@3ooo]ZoookJ_oonf[ooe8003_ooo]Z0_oo5002oookJP03ool00?oonf[ooo]Z043o
oo]Z00?oo`<0oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Go
oo]Z000ioookJP03o`000?oonf[ooo]Z03kooo]Z0_oo1@0koookJP;ooa@03OoonfX00ooo2`3ooo]Z
oookJP03oookJP;o00[o0ooonfX<o`0:o`Cooo]Z00?o00[ooookJ_oonfX01?oonfX01OooQP3ooo]Z
oon60?oonf[oc_l000;ooo]Z0_o>o`02oookJP09olko0?oonf[ooo]ZoookJ_ooEP3o0?n2oomF0?l0
oh;o0?mD00;ooo]Z00?o0?n2oookJ_oonfX00_oonfX2oolT00?ooo]Z00?o]ol0oookJ_ngo`000_oo
nfX00ongo`3ooo]ZoookJP0<oookJP03o`0:oooo003oo`0000Sooo]Z00?o03;ooookJ_oonfX01ooo
nfX2o`1_o`Kooo]Z00Co06oooookJ_l02_oo00[o1Ol0oe@6oookJP;oo`/00ooonfX3okOo0003o`3o
E?oonf[ooo]Z00;o0?mD1OoonfX3oomS00_ooo]Z00?oc_l0oookJ_oonfX01?oonfX00oo>o`3ooo]Z
oookJP0DoookJP03oomB0?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo7@3ooo]Z
oookJP0hoookJP03ool80?oonf[ooo]Z03Wooo]Z00?oo`<0oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z00Gooo]Z000joookJP;o0000CooonfX00ooo0`3ooo]Zoook
JP0hoookJP03ool;0?oonf[ooo]Z00Gooo]Z0ol02_l6oookJP04oonC0?l02_oooo]ZoonC00;ooo]Z
1_l02_l4oookJP04ool00?oonf[oohH0oon600;oc_l00ooonfX00oo>o`3ooo]ZoookJP02olko0003
oookJ_l0oh;o0?n200;ooeH00_l0oh800on:o`3o0?n2oookJP08oookJP04okOo0?oonf[o]ol0okOo
00;ooo]Z00?o]ol0ool90?oo2@003OoonfX00ol02_oooo]ZoookJP08oookJP03o`0boooo003ooo]Z
00Kooo]Z00?o06oooookJ_l0Kol01OoonfX00ol0Kooooo]ZoookJP05oookJP03o`1_ool0oeCo0?mD
00Go0?mD00Gooo]ZokOo0?ngo`3o]ol0o`3oE002oookJP05o`3oE?oonf[ooo]ZoookJ_oo0@000_l0
oe@00ooonf[oof<0oomS0003oomS00[ooo]Z00?oc_l0oookJ_oonfX06ooonfX00oooDP3ooo]Zoook
JP09oookJP;ooad01OoonfX00ooo003ooo]ZoookJP0boookJP03ool80?oonf[ooo]Z04;ooo]Z00?o
o`40oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00Gooo]Z000l
oookJP03o`000?oonf[ooo]Z04cooo]Z00?oo`<0oookJ_oonfX03?oonfX00ooo0@3ooo]ZoookJP0Q
oookJP03oom;0?oonf[ooo]Z013ooo]Z0_l02_l00ooonf[oo`@0oookJP02oonC0003o`0:ooooT`3o
oi<000Gooo]Z00?o00[ooookJ_oonfX01OoonfX4oon6000:oookJ_o>o`3oc_l0oookJ_o>o`3ooo]Z
olko0?oonf[oo`00o`3oPP?ooo]Z00?o0?n2oookJ_oonfX00_l0oh800on:o`3ooo]ZoookJP05oook
JP04okOo0?oonf[ooo]ZoookJPCo]ol03OoonfX01?oo0@3ooo]ZoookJ_l02_l:oookJP03o`0boooo
nf[ooo]Z00Cooo]Z00Go06oooookJ_oonf[ooo]Zo`1_o`05oookJP03o`1_oooonf[ooo]Z00Cooo]Z
00?o06oooookJ_oonfX01?oonfX2okOo00Ko0?mD1OoonfX00oooH`3o0?mDo`3oE003oookJP06oomS
0?oonf[ooo]ZoookJ_oo003ooo]Z0on:o`02oookJP03olko0?oonf[ooo]Z02Oooo]Z00?ooad0oook
J_oonfX03OoonfX2oom503Cooo]Z0_oo0`14oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oook
J_oonfX01OoonfX003gooo]Z00?o0000oookJ_oonfX0F_oonfX00ooo0@3ooo]ZoookJP0QoookJP03
oom;0?oonf[ooo]Z01;ooo]Z0_l02_l3oookJP03oonC0?l02_oooo]Z00?ooo]Z0_l02_l2oookJP03
ool10?oonf[ooo]Z00Gooo]Z0_ooQP03oookJP?oc_l000?ooo]Zo`3oP_l0oh801?oonfX00ol0oh;o
oo]ZoookJP02o`3oPP03oookJ_n:o`3oo`0000Cooo]Z1Ongo`000ooio`3o]ol0okOo000BoookJP03
o`0:oooonf[ooo]Z00Gooo]Z00Coo`00oookJ_oonf[o03;o1?oonfX00ol0Kooooo]ZoookJP03oook
JP03o`1_oooonf[ooo]Z00;ooo]Z00?o06oooookJ_oonfX00ooonfX2o`1_o`[ooo]Z00?o0?mDoook
J_oonfX02?l0oe@00ooonf[o0?mDoookJP06oookJP;oR_l000GooaT0oookJ_o>o`3oc_l0oh[o0003
oookJP03ool00?oonf[ooo]Z00Gooo]Z0oooM@0VoookJP;oo`P01?oonfX2oom503_ooo]Z00?ooa<0
ool00?oo0000>ooonfX00ooo1`3o0000oookJP0IoookJP03o`000?oonf[ooo]Z00Gooo]Z000noook
JP03o`000?oonf[ooo]Z03oooo]Z00?ooa@0oookJ_oonfX09_oonfX00ooo003ooo]ZoookJP0Coook
JP03oom;0?oonf[ooo]Z00_ooo]Z0_oo?@06oookJP?o00[o00Cooo]Zo`0:oooonf[ooo]Z0_l02_l<
oookJP03o`000?oonf[ooo]Z00;ooo]Z00Coo`00olko0?oonf[o0?n21_oonfX02?l0oh;ooo]Zoook
J_l0oh;ooo]Zo`3oP_oonf[oR_l01_oonfX2okOo0004oookJ_ngo`3o]ol0okOo00?onOl02?oonfX4
oomd00Cooo]Z00?o00[ooomd0?oonfX02?oonfX01?l0<_oooo]ZoookJ_l0Kol4oookJP04ool00?oo
nf[ooo]Zo`1_o`?ooo]Z00?o06oooookJ_oonfX00_oonfX2o`1_o`_ooo]Z00Co0?mDoookJ_oonf[o
0?mD1ooonfX3o`3oE0Gooo]Z2_n:o`08oookJPCoogD0:ooonfX00oooA@3ooo]ZoookJP02oookJP;o
o`80=_oonfX2oolC03kooo]Z00?o0000oookJ_oonfX01?oonfX2ool301;ooo]Z00?o0000oookJ_oo
nfX01OoonfX003oooo]Z0_l0000ooookJP03oolD0?oonf[ooo]Z00gooo]Z0_oo400VoookJP03ool0
0?oonf[ooo]Z00Cooo]Z0oooB`0=oookJP;oocd01ooonfX2o`0:o`04oookJ_l02_ooobH0oolV00co
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0oh;ooo]ZoookJP05oookJP04o`3oP_oonf[o0?n2ool0
00;ooo]Z00?o0?n2oookJ_n:o`001ooonfX2okOo00Gooo]Z0ooio`09oookJPKoog@00ooonfX4oolT
00?ooo]Z00?o03;ooookJ_l0Kol02?oonfX01Ol0Kooooo]ZoookJ_oonf[o06oo00;ooo]Z00?o06oo
ool00?l0Kol00_oonfX2ooWo00Oooo]Z00Co0?mDoookJ_oonf[o0?mD0_oonfX6o`3oE0Oooo]Z00Co
R_l0oookJ_oonf[oc_l01On:o`03oookJP;oo`D00ooonfX00oooM@3ooo]ZoookJP02oome02[ooo]Z
00?oodD0oookJ_oonfX02?oonfX2oolN00?ooo]Z00?oo`00oookJ_oonfX0=OoonfX00ooo2@3ooo]Z
oookJP0doookJP03o`000?oonf[ooo]Z00_ooo]Z0_oo0@0:oookJP03o`000?oonf[ooo]Z00Gooo]Z
0011oookJP03o`000?oonf[ooo]Z04gooo]Z00?ooa00oookJ_oonfX03?oonfX2ool:01gooo]Z0_oo
B`04oookJP03ool00?oonf[ooo]Z00Oooo]Z0_oo?@09oookJP05o`0:oooonf[ooo]ZoookJ_oo9P00
2ooonfX2oolA00Gooo]Z00?o0?n2oookJ_oonfX01OoonfX00ol0oh;ooo]Zo`3oPP04oookJP03o`3o
P_oonf[oR_l000Kooo]Z00?oo`00oookJ_oonfX01ooonfX3ooWo00Gooo]Z0_oio`03oookJP;oog@0
00?o00[ooookJ_oonfX00_oonfX00ooo903ooo]ZoookJP03oookJP04o`1_oooonf[ooo]ZoookJP;o
o`P01OoonfX2o`0bo`04oookJ_l0Kooooo]Zo`1_o`;ooo]Z00?o06oooookJ_oonfX01?oio`04oook
JP03o`3oE?oonf[o0?mD00Co0?mD00Cooo]Zo`3oE?l0oeCo0?mD2OoonfX2oh[o0004olko0?n:o`3o
R_l0oookJP;oR_l01ooonfX2oome00Kooo]Z00?oo`00oookJ_oonfX0<OoonfX2oolN04Cooo]Z00?o
o`@0oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00Gooo]Z0012
oookJP03o`000?oonf[ooo]Z06[ooo]Z0_oo1@0OoookJP04oolm0?oonf[ooo]Zool001Gooo]Z00?o
0000oookJ_oo4@001_oonfX00ol0oh;ooo]ZoookJP03oookJP03o`3oP_oonf[o0?n200Kooo]Z00?o
0?n2oookJ_n:o`004OoonfX01?oo003onOl0ooWo0?oio`02oookJP?onOl00_oonfX00oooM03ooo]Z
o`3oPP03o`3oPPKooo]Z0_l0Kol00ol0<_oooo]ZoookJP07oookJP05o`0bool0Kooo03;ooookJ_l0
Kol00_oo0@001_l0Kooooo]ZoookJ_oonf[onOl0oookJP?onOl00ooonfX2o`3oE004oookJ_l0oeCo
oo]ZoookJP;o0?n22OoonfX3oh[o0004oookJ_n:o`3ooo]ZoookJP?oR_l01ooonfX00oooM@3ooo]Z
oookJP0:oookJP;oobH01OoonfX00ooo003ooo]ZoookJP06oookJP;oofX0:?oonfX2ool<03[ooo]Z
00?oo`@0oookJ_oonfX01_oonfX00ooo0@3ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01Kooo]Z
00?o0000oookJ_oonfX01?oonfX004?ooo]Z0_l0001ioookJP03ool20?oonf[ooo]Z01oooo]Z00Go
o`00oookJ_oonf[ooo]ZoonV0004oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0?n2oookJ_oonfX0
0_oonfX00ol0oh;ooo]Zo`3oPP06oookJP;o0?n200?ooo]Zoh[o0?oo0@004ooonfX3ooWo0003oook
J_oio`3ooo]Z00Gooo]Z00?o00[ooookJ_l0oh801Ol0oh82oookJP04o`1_ool0<_oo06ooo`1_o`Go
oo]Z00?o03;ooookJ_l0<_l00_l0Kol=ooWo0004ool00?oonf[ooo]ZoookJPCo0?mD0ol0oh84oook
JPCoR_l01?oonfX00on:o`3ooo]ZoookJP02oh[o01Cooo]Z0ooo9P0=oookJP?oofX0:?oonfX00ooo
303ooo]ZoookJP07oookJP03ool30?oonf[ooo]Z03Sooo]Z00?oo`40oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00Cooo]Z0015oookJP03o`000?oonf[ooo]Z08Co
oo]Z00?oo`00oookJ_oonfX05_oonfX01OooYP3ooo]ZoookJ_oonf[o000000;ooo]Z00?oo`00oook
J_oonfX01OoonfX01?l0oh;ooo]ZoookJ_oonfX2o`3oPPGooo]Z0_l0oh84oookJP03oh[o0?oonf[o
oo]Z00[ooo]Z00?oo`00oookJ_oonfX01OoonfX00ooio`3ooo]ZooWo0002ooWo00Kooo]Z00?o00[o
oookJ_oonfX01?oonfX6o`3oPP[onOl000Cooo]Zo`0boooonf[o06oo0oooEP04ooWo00Oooo]Z00Ko
0?mDoookJ_oonf[o0?n2oookJ_l0oh84oh[o00Wooo]Z0_n:o`0EoookJP03oolV0?oonf[ooo]Z00Wo
oo]Z00?oo`/0oookJ_oonfX00_oonfX3oomZ03;ooo]Z00?oo`<0oookJ_oonfX01ooonfX00ooo0@3o
oo]ZoookJP1FoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX01?oonfX004Kooo]Z
00?o0000oookJ_oonfX0GOoonfX00ooo:03ooo]ZoookJP0aoookJP03ool00?oonf[ooo]Z00Wooo]Z
00CoojH0oookJ_oonf[o00002OoonfX00oooM@3o0?n2o`3oPP02oookJP;o0?n20_oonfX4o`3oPPKo
oo]Z00?oR_l0oookJ_oonfX00_oonfX2oh[o00cooo]Z1ooio`06oookJP03o`0:oooonf[ooo]Z00So
oo]Z00?o06ooo`3oP_l0oh801?l0oh83o`1_o`03oookJ_ooEP3ooeH000;o03;o0_oonfX00oooEP3o
nOl0ooWo0004oookJP;ooaL01_oonfX3oh[o00;o0?n21ooonfX2oon600;ooo]Z00?oR_l0oookJ_oo
nfX07ooonfX2ool;00?ooo]Z00?oofX0oookJ_ooJP000ooonfX00ooo0P3ooo]ZoookJP0coookJP;o
oad000?ooo]Zool10?oonfX0>OoonfX00ooo2@3ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX01?oonfX004Oooo]Z00?o0000oookJ_oonfX07ooonfX00ooo303ooo]Z
oookJP0koookJP;oobP03OoonfX2oolN02oooo]Z00?oojH0oookJ_l000002ooonfX2o`3oPP03oook
J_l0oh;oogD000;o0?n200?ooo]Zo`3oP_oonfX00_oonfX5oolj0003oookJ_n:o`3ooo]Z00;ooo]Z
00?oR_l0oookJ_n:o`003?oonfX01?oio`3ooo]ZooWo0?oio`09oookJP03o`0:oooonf[oo`0000So
oo]Z00?o06oooookJ_l0<_l00ooonfX6o`3oPP03o`1_oooonf[o03;o00;ooo]Z00?onOl0oookJ_oo
nfX00_oonfX00ooo5`3ooo]ZoolG0002oookJPCoR_l00ooonfX00ol0oh;oo`D0o`3oPP05oookJPCo
ohH09ooonfX00oooJP3ooo]ZoookJP04oookJP03ool20?oonf[ooo]Z00;ooo]Z00?oob`0oookJ_oo
nfX00_oonfX00ooo003ooo]ZoookJP0YoookJP03oolM0?oonf[ooo]Z04Cooo]Z00?oo`@0oookJ_oo
nfX05OoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Cooo]Z0018oookJP;o0000
;ooonfX2ool902cooo]Z0_oo:00>oookJP;ooah03?oonfX2oolC027ooo]Z00CoojH0o`000?oonf[o
ojH02?oonfX00ooo003ooo]Zo`3oPP03o`3oPP03oome0?l0oh;o0?n200Oooo]Z0_oo>P02oookJP07
oh[o0?oonf[oR_l0oookJ_n:o`3ooo]Zoh[o0002oolD00[ooo]Z00?onOl0oookJ_oonfX02_oonfX0
0ol02_oooo]ZoookJP08oookJP03o`1_ool0<_oooo]Z00;ooo]Z00Co06oooookJ_l0<_oooo]Z0_l0
Kol5o`3oPPOooo]Z0on:o`03oookJP07o`3oP_oonf[ooo]ZoookJ_l0oh;oo`D0oookJP02o`3oPPCo
ohH000Cooo]Zoon60?ooQP3oo`009OoonfX00oooJP3ooo]ZoookJP09oookJP;oob`01?oonfX00ooo
003ooo]ZoookJP0coookJP03ool=0?oonf[ooo]Z04;ooo]Z00?oo`80oookJ_oonfX03OoonfX00ol0
003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Cooo]Z001:oookJP03o`000?oonf[ooo]Z03go
oo]Z00?oo`H0oookJ_oonfX0A_oonfX2ool800gooo]Z00?oo`<0oookJ_oonfX01?oonfX01?ooYP3o
oo]ZoonV0?ooYP0:oookJP;o0?n200?oogD0o`3oP_oonfX01?oonfX00ooo003ooo]ZoookJP06oook
JP04oh[o0?oonf[ooo]Zoh[o00;ooo]Z00?oR_l0oookJ_oonfX02OoonfX00ooo1@3ooo]ZoookJP09
oookJP03ool10?oonf[o00[o00Wooo]Z0_l0<_l00ol0Kooooo]Zo`1_o`03o`1_o`03o`0boooonf[o
oo]Z00Gooo]Z1Ol0oh82oh[o00Kooo]Z00Co0?n2oookJ_oonf[o0?n20_oonfX2oon600;o0?n20ooo
nfX2oon600;oo`002_oonfX00ooo003ooo]ZoookJP06oookJP?ooi<06_oonfX00ooo;03ooo]Zoook
JP13oookJP03ool50?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Zoook
JP04oookJP00BooonfX00ol0003ooo]ZoookJP1;oookJP;oo`<03_oonfX00ooo0@3ooo]ZoookJP0e
oookJP;oo`<01_oonfX01ol0003oojH0oonV0?oonf[oojH0oookJ_oo00002OoonfX00ol0oh;oogD0
oome000<oookJP05oh[o0?oonf[oR_l0olko0?n:o`000_oonfX00on:o`3ooo]ZoookJP0EoookJP04
ool10?oonf[ooo]Zo`0:o`Oooo]Z00Co03;oool00?oonf[o03;o0_l0Kol3oookJP03o`0boooonf[o
oo]Z00Kooo]Z00?o03;ooookJ_oonfX00_oonfX6o`3oPP05oookJ_l0oh;ooo]ZoookJ_l0oh800_oo
QP04oookJP03o`3oP_oonf[ooo]Z00Gooo]Z0ooo:P0>oookJPGooi<09?oonfX2ool?04;ooo]Z0_oo
0P13oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX00ooonfX004cooo]Z0_l0001J
oookJP03ool10?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX04ooonfX00oooD@3ooo]ZoookJP0I
oookJPGoojH000?ooo]Zool00?oonfX02ooonfX00ooo003ooo]ZoookJP08oookJP06oh[o0?oonf[o
oo]ZoookJ_n:o`3oc_l00on:o`08oookJP?ooi/02?oonfX00oooV`3ooo]ZoookJP05oookJP03o`0:
oooonf[ooo]Z00?ooo]Z00?o03;ooookJ_oonfX00_oonfX00ol0<_oooo]ZoookJP03oookJP04o`0b
oooonf[ooo]Zool000Cooo]Z00?o03;ooookJ_oonfX02?oonfX6o`3oPPKooo]Z00?o0?n2oookJ_oo
nfX00_oonfX2oolZ0003oookJ_oo:P3ooo]Z00kooo]Z1OooT`0^oookJP03ool40?oonf[ooo]Z07go
oo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP03oookJP00C_oonfX00ol0003ooo]Z
oookJP1doookJP03ool00?oonf[ooo]Z00Kooo]Z00?ooe40oookJ_oonfX02_oonfX2oolh00cooo]Z
00Co0000oookJ_ooYP3oojH06OoonfX3oh[o00?ooo]Z0on:o`03olko00Wooo]Z1OooV`03oookJP;o
oi/01Ooo>P02oookJP03o`0:oooonf[ooo]Z00;ooo]Z00?o03;ooookJ_oonfX00ooonfX00ol0<_oo
oo]ZoookJP02oookJP03o`0boooonf[ooo]Z00Cooo]Z0_l0<_l2oookJP;oc_l01ooonfX01Ol0oh;o
oo]ZoookJ_l0oh;ooo]Z00Ko0?n200?ooo]Zo`3oP_oonfX03_oonfX00ooo2`3ooo]ZoookJP03oook
JP?ooi<000?ooo]ZoonC0?oonfX0<ooonfX2ool[00?ooo]Z00?oo`40oookJ_oonfX0=OoonfX2ool>
03cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP03oookJP00CooonfX00ol0003o
oo]ZoookJP0moookJP;ooaL03_oonfX00ooo403ooo]ZoookJP0]oookJP;ooe4000?ooo]Zool00?oo
nfX02OoonfX2oolh00[ooo]Z00?o0000oolM0?oo7@007?oonfX7oh[o00?ooo]Z0_o>o`000ooo003o
oo]ZoookJP09oookJPKooi/00ooonfX2oolj00;ooo]Z00Co00[ooookJ_oonf[o03;o0ooo4@04oook
JP03o`0boooonf[ooo]Z00;ooo]Z00?o03;ooookJ_oonfX00_oonfX2o`0bo`?ooo]Z00?oc_l0oook
J_o>o`001OoonfX01?l0oh;ooo]ZoookJ_l0oh87oookJPCo0?n24_oonfX2oonC00?ooo]Z00?ooi<0
oookJ_oo0P00<ooonfX3ool[03[ooo]Z0_oo3P0moookJP03o`000?oonf[ooo]Z00Cooo]Z00?oo`80
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP03oookJP00D?oonfX00ol0003ooo]ZoookJP0moook
JP03oolG0?oonf[ooo]Z00gooo]Z00?ooa00oookJ_oonfX03?oonfX00ooo2P3ooo]ZoookJP0Noook
JP;ooe403?oonfX2oolh00Wooo]Z00Co0000oookJ_oo7@3ooad02_oonfX2ool;013ooo]Z00?oR_l0
oookJ_n:o`000on:o`05oookJP?oc_l01_oonfX2olko00?ooo]Z1OooV`07oookJP03o`0:ool0<_oo
oo]Z00Sooo]Z00Ko03;ooookJ_oonf[ooo]Zo`0boooo1002oookJP03o`0boooonf[o03;o00?ooo]Z
0_o>o`000ooonf[oc_l0oookJP03oookJP03o`3oP_oonf[ooo]Z00[o0?n24_oonfX2oonC00_ooo]Z
0_oo>004oookJP03ool00?oonf[ooo]Z02Kooo]Z00?oob/0oookJ_oonfX02?oonfX2oolB03[ooo]Z
0_oo1P07oookJP03ool20?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP03oookJP00DOoonfX2o`0005cooo]Z00?oo`X0oookJ_oonfX02ooonfX2ool4013ooo]Z0ooo
D@0<oookJP03oolh0?oonf[ooo]Z00Sooo]Z00Co0000oookJ_oo003oo`002ooonfX00ooo2`3ooo]Z
oookJP09oookJP;oo`<01?oonfX2oh[o00_ooo]Z0oo>o`03oookJP?oc_l00ooonfX2oonK00Wooo]Z
00?o03;oo`0:oooonfX02OoonfX2o`0:o`;ooo]Z00?o03;ooookJ_l0<_l00_oonfX01_l0<_oooo]Z
oome0?ooM@3oc_l0oookJP?oc_l00ooonfX4o`3oPPCooo]Z0_l0oh8DoookJP03oonC0?oonf[ooo]Z
00Wooo]Z0_oo>0000ooonf[oocP0oookJP0goookJP;ooa80@ooonfX00ooo0P3ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX00ooonfX005?ooo]Z00?o0000oookJ_oo
nfX0M_oonfX00ooo0@3ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02Gooo]Z00?oo`00oookJ_oo
nfX01_oonfX3olko0004oookJ_oo003oc_l0olko00cooo]Z0ol0<_lMolko00;ooo]Z00Co0?n2oook
J_oonf[o0?n20_oonfX2o`3oPR7ooo]Z00?oocP0oookJ_oonfX02_oonfX00ooo4`3ooo]ZoookJP0g
oookJP03ool70?oonf[ooo]Z00Oooo]Z00?oo`80oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0>
oookJP03o`000?oonf[ooo]Z00?ooo]Z001DoookJP03o`000?oonf[ooo]Z08;ooo]Z0_oo000<oook
JP03ool00?oonf[o000000Sooo]Z0_ooT`0XoookJP?oc_l000?ooo]Zolko0?oonfX01ooonfX00ooo
003ooo]ZoookJP03oookJP;o03;o00?o00[oo`0boooonfX01OoonfX01_l02_oooo]Zo`0:ooooM@3o
00[oo`0bo`?oogD000?o03;ooookJ_oonfX00_ooM@04olko00;oobH00ooonfX5o`3oPP_ooo]Z0_oo
YP0RoookJP;ooa<02OoonfX00ooo1@3ooo]ZoookJP0foookJP03ool20?oonf[ooo]Z05oooo]Z00?o
0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP03oookJP00EOoonfX2o`0005kooo]Z00?oob/0
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP07oookJP03ool00?ooT`3ooi<000[ooo]Z0oooDP0I
oookJP03olko0?oonf[ooo]Z00?oc_l03_oonfX00ol0<_oooo]Zo`0:o`03o`0bo`;ooo]Z00Go00[o
oookJ_oonf[o00[ooookJP02o`0bo`04o`0:oooonf[ooo]Zo`0bo`;ooo]Z00CoogD0oookJ_o>o`3o
c_l00ooo9P05oookJP05o`3oP_oonf[ooo]ZoookJ_oo2`002OoonfX4oonV02_ooo]Z0_oo1@04oook
JP03oolk0?oonf[ooo]Z00;ooo]Z00?oo`40oookJ_oonfX0L?oonfX00ooo1`3ooo]ZoookJP0Loook
JP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX00_oonfX005Oooo]Z00?o0000oookJ_oo
nfX07_oonfX00ooo3P3ooo]ZoookJP0koookJP;oob/03?oonfX2oolM02?ooo]Z00?o0000oookJ_oo
nfX02_oonfX3oonC00Oooo]Z00?oo`00oookJ_oonfX01?ooDP07oookJPCoob<02OoonfX8olko00ko
oo]Z0_l0<_l01Ol02_oooo]ZoookJ_l0<_oo00[o00;o03;o0_oonfX01?l02_oo03;oo`0bool0<_l2
o`0:o`03o`0boooonf[ooo]Z00;ooo]Z00?oc_l0oookJ_oonfX02_oonfX2ool;00Oooo]Z0oooYP00
0ooo0P3oojH0oonV000aoookJP;ooc/00ooonfX00ooo0@3ooo]ZoookJP0coookJP;ooa<0>ooonfX0
0ooo1`3ooo]ZoookJP05oookJP;oo`<05_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o
oo]Z00;ooo]Z001HoookJP03o`000?oonf[ooo]Z01kooo]Z00?oo`h0oookJ_oonfX03OoonfX00ooo
2@3ooo]ZoookJP0[oookJP03ool[0?oonf[ooo]Z00cooo]Z00?ooad0oookJ_oonfX02_oonfX2ool?
01Cooo]Z00?o0000oookJ_oonfX03OoonfX4oonC00Sooo]Z0oooDP08oookJP03oolS0?oonf[ooo]Z
00Sooo]Z00?oo`/0olko0?oonfX00oo>o`06oookJP03ool30?oonf[ooo]Z00Wooo]Z00Co03;oo`0:
oooonf[o00[o0ooonfX3o`0bo`;ooo]Z0_l0<_l00ooonf[o00[ooookJP0EoookJPCoojH00ooonfX2
oonV00Wooo]Z00?oo`00oookJ_oonfX09?oonfX3oolk03[ooo]Z00?ooa<0oookJ_oonfX01_oonfX2
ool803[ooo]Z00?oo`<0oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o
oo]Z00;ooo]Z001IoookJP03o`000?oonf[ooo]Z02gooo]Z00?oo`T0oookJ_oonfX03?oonfX2ool5
00kooo]Z00?oo`80oookJ_oonfX0=_oonfX2ool600Kooo]Z00?o0000oookJ_oonfX00_oonfX2ool2
00[ooo]Z0oooT`09oookJP03oomB0?oonf[ooo]Z01Cooo]Z00?oc_l0oookJ_oonfX04ooonfX01?oo
003o03;oo`0bool02_l4oookJP03o`0bool02_oo03;o00Co03;o00?ooo]Zo`0:ool02_l04OoonfX3
oonV00Oooo]Z00CoojH0oookJ_oonf[ooo]Z0_oo?@0[oookJP03oolk0?oonf[ooo]Z00Wooo]Z0_oo
600ioookJP03ool80?oonf[ooo]Z00Kooo]Z0_oo0`1:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o
0000oookJ_oonfX00_oonfX005[ooo]Z0_l0001;oookJP;oo`803OoonfX00ooo0@3ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z00gooo]Z1OooT`0goookJP03o`0:ool0<_oooo]Z00;ooo]Z00Go03;o
oookJ_oonf[o00[ooookJP03o`0bo`?ooo]Z00?o00[ooookJ_oonfX03?oonfX2oonV00_ooo]Z1Ooo
?@0foookJP03oolH0?oonf[ooo]Z00Sooo]Z00?oo`P0oookJ_oonfX0Q?oonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z00;ooo]Z001LoookJP03o`000?oonf[ooo]Z06Gooo]Z00?oo`00
oookJ_oonfX02ooonfX00ooo003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00oooo]Z00?ooi<0
oookJ_oonfX02_oonfX00ooo003ooo]ZoookJP09oookJP04ool00?oonf[ooo]ZoookJPCookd02Ooo
nfX2oonm00Cooo]Z00?ooe80oookJ_oonfX01_oonfX01Ol02_oooo]ZoookJ_l0<_oooo]Z00Co03;o
00?o00[oo`0boooonfX01_oonfX00ol02_oooo]ZoookJP0GoookJP03oolm0?oonf[ooo]Z00Wooo]Z
0ooo5012oookJP03ool20?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Z
oookJP02oookJP00GOoonfX00ol0003ooo]ZoookJP1koookJP;ood/00_oonfX00ooo003ooo]Zoook
JP07oookJP03o`000?oonf[ooo]Z033ooo]Z1_oo_@03oookJP?ookd01OooDP04oookJP;ooad000?o
00[ooolM0?oonfX00_oonfX2o`0bo`Cooo]Z00?o00[ooookJ_oonfX01OoonfX00ol02_oooo]Zoook
JP0^oookJP03ool50?oonf[ooo]Z0;Gooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP02oookJP00G_oonfX2o`0003kooo]Z0_oo600moookJP?ood/02OoonfX4ool/00[ooo]Z0_oo500Y
oookJPGookd000Gooo]Zoonm0?oonf[ooo]ZoomB0006oookJP03o`0:oooonf[ooad000Cooo]Z00?o
00[ooookJ_oonfX00_oonfX00ol02_oooo]ZoookJP04oookJP;o00[o0ooonfX00ooo0P3ooo]Zoook
JP0`oookJP;ood/00ooonfX00ooo0@3ooo]ZoookJP0boookJP03oolJ0?oonf[ooo]Z03Wooo]Z00?o
o`T0oookJ_oonfX0>OoonfX00ooo103o0000oookJP0:oookJP03o`000?oonf[ooo]Z007ooo]Z001P
oookJP03o`000?oonf[ooo]Z03cooo]Z0_oo600=oookJP;ooa003OoonfX00ooo203ooo]ZoookJP0O
oookJP;ood/02?oonfX00ol0003ooo]ZoookJP02ool/00[ooo]Z0_oo500:oookJP;oo`L02ooonfX0
0ooo0P3ooo]ZoookJP0AoookJPGookd02?oonfX00ol02_oooo]ZoookJP05oookJP03o`0:oooonf[o
oo]Z00;ooo]Z00?o00[ooookJ_oonfX00_oonfX2o`0:o`04oookJ_ooT`3ooi<0oonC00[ooo]Z0_oo
000UoookJPCood/0=ooonfX2oolJ03[ooo]Z00?oo`T0oookJ_oonfX01_oonfX00ooo103ooo]Zoook
JP0coookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00OoonfX0067ooo]Z00?o0000
oookJ_oonfX0FOoonfX00ooo203ooo]ZoookJP0;oookJP;oo`<03?oonfX00ooo0@3ooo]ZoookJP02
oookJP?ood/02?oonfX00ol0003ooo]ZoookJP0UoookJP03ool20?oonf[ooo]Z00Wooo]Z0_oo0006
oookJP;ookd02_oonfX00ol02_oooo]ZoookJP07oookJP05o`0:oooonf[ooo]ZoookJ_l02_l00ooo
nfX01?l02_oooo]Zo`0:oooonfX4oonC02oooo]Z00Cood/0oookJ_oonf[ood/01ooonfX2oolM02oo
oo]Z00?ooaX0oookJ_oonfX01ooonfX00ooo2`3ooo]ZoookJP07oookJP03ool40?oonf[ooo]Z06Go
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP01oookJP00H_oonfX00ol0003ooo]Z
oookJP1doookJP03ool10?oonf[ooo]Z00[ooo]Z00Coo`00oookJ_oonf[o0000?ooonfX00ooo003o
oo]ZoookJP04oookJP03o`0:oooonf[ooo]Z00Wooo]Z00Co00[ooookJ_oonf[ooo]Z0_ooT`000ol0
2_oooi<0oonC0005oonC00?ooo]Z00?oocP0oookJ_oonfX0:OoonfX00oooB`3ooo]ZoookJP08oook
JP03oolM0?oonf[ooad004;ooo]Z00?oo`@0oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z007ooo]Z001SoookJP;o0000Q?oonfX00ol0003ooo]ZoookJP07oookJP03
ool00?oonf[ooo]Z00[ooo]Z00?oo`00oookJ_oonfX0;?oonfX00ol02_oooo]ZoookJP0:oookJPCo
oi<000?o00[ooookJ_l02_l00_oonfX01?l02_oooo]ZoonC0?ooT`06oolh00Oooo]Z00?ooa<0oook
J_oonfX0=_oonfX2ool:00Sooo]Z0_oo0`2HoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX00OoonfX006Gooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP0DoookJP?o
ofX01?oonfX00oooJP3ooo]ZoookJP04oookJPCooc<07?oonfX3o`0:o`gooo]Z00Co00[ooookJ_oo
nf[o00[o0_oonfX00ol02_oooo]ZoookJP0>oookJP;ooa<02OoonfX2ool50=;ooo]Z00?o0000oook
J_oonfX01OoonfX00ol0003ooo]ZoookJP01oookJP00I_oonfX00ol0003ooo]ZoookJP1KoookJP?o
obP02ooonfX2oolH01Cooo]Z00?o0000oookJ_oonfX06?oonfX6oomZ00Sooo]Z0_oo<`08oookJP;o
oa@02_oonfX2ool600Oooo]Z1Ol02_l:oookJP?o00[o0_oonfX00ol02_oooo]ZoookJP0ToookJP03
ool10?oonf[ooo]Z0:Sooo]Z00?oo`D0oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z007ooo]Z001WoookJP;o00007ooonfX00ooo3P3ooo]ZoookJP0=oookJP03ool9
0?oonf[ooo]Z02[ooo]Z0_oo:00=oookJP03oolH0?oonf[ooo]Z00[ooo]Z0_oo3005oookJP03o`00
0?oonf[ooo]Z00?ooo]Z0_oo100GoookJP?oofX09ooonfX2o`0:o`03ool10?oonf[o00[o00Co00[o
1OoonfX3o`0:o`;ooo]Z00?o00[ooookJ_oonfX07ooonfX2oomA03Kooo]Z0_oo8P0ioookJP;oo`d0
2?oonfX00ooo1@3ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
0OoonfX006Wooo]Z00?o0000oookJ_oonfX0;?oonfX00ooo2@3ooo]ZoookJP0<oookJP03ool50?oo
nf[ooo]Z00_ooo]Z0_oo0P0aoookJP03o`000?oonf[ooo]Z013ooo]Z0_oo0@0:oookJP03oomZ0?oo
003ooo]Z02Wooo]Z00?o00[ooookJ_oonfX01?oonfX5o`0:o`;ooo]Z0_l02_l00ooonf[o00[ooook
JP0MoookJPGooe40=OoonfX00ooo8P3ooo]ZoolR0008oookJP03ool>0?oonf[ooo]Z03Oooo]Z0_oo
1@1BoookJP03o`000?oonf[ooo]Z00Cooo]Z0Ol00001oookJP7ooo]Z001ZoookJP03o`000?oonf[o
oo]Z05Kooo]Z0_oo000<oookJP03ool00?oonf[ooo]Z00[ooo]Z00?oo`00oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP0YoookJP03ool00?oonf[ooo]Z01Kooo]Z00?oofX0oookJ_oonfX01?oonfX2
o`0:o`Sooo]Z1_l02_lMoookJP;ooe400ooonfX00oooD@3ooo]ZoookJP05oookJP;ooah0=ooonfX2
ool>00Sooo]Z0_oo1@24oookJP03o`000?oonf[ooo]Z00?ooo]Z0Ol00001oookJP7ooo]Z001[oook
JP03o`000?oonf[ooo]Z07[ooo]Z00Co0000oookJ_oonf[oo`00>OoonfX6oomZ00;ooo]Z0_ooJP06
oookJP03ool/0?l02_oooo]Z00Gooo]Z00?o00[ooookJ_oonfX00_oonfX2o`0:obSooo]Z0ooo7P08
oookJP;oo`X02_oonfX00ooo0`3ooo]ZoookJP2boookJP03o`000?oonf[ooo]Z00;ooo]Z0Ol00001
oookJP7ooo]Z001/oookJP;o0000N_oonfX00ol0003ooc/0oolk0010oookJPGoofX000?ooo]Zool/
0?oo;0000ooo;0000ooonf[o00[oo`0:o`03oookJP03o`0:oooonf[oo`l000?o00[o2?oonfX00ooo
103ooo]ZoookJP0eoookJP03ool30?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oonfX00_oonfX1o`00
007ooo]Z0OoonfX006kooo]Z00?o0000oookJ_oonfX0??oonfX2oolG03Wooo]Z00?o0000oookJ_oo
nfX00ooo>`09oookJP?ooah02_oonfX2ool=00_ooo]Z00?oo`@0oookJ_oonfX06OoonfX00oooJP3o
oo]ZoookJP09oookJP03o`0:oooonf[o00[o00?o00[o2_oonfX2ool400[ooo]Z00?oo`40oookJ_oo
nfX0YOoonfX00ooo1`3ooo]ZoookJP0ioookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX006oo
oo]Z00?o0000oookJ_oonfX0??oonfX2oolG00cooo]Z0_oo3P0<oookJP;oo`L03OoonfX00ooo0`3o
oo]ZoookJP0<oookJP04o`000?oonf[ooo]ZoookJP;ooc/02ooonfX00ooo7P3ooo]ZoookJP0Eoook
JP03ool40?oonf[ooo]Z00Wooo]Z00?oo`40oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP0>oook
JP;o00[oBooonfX00ooo:03ooo]ZoookJP0goookJP03ool@0?oonf[ooo]Z03Sooo]Z0_oo1`0loook
JP04o`000?oonf[ooo]Zo`0000;ooo]Z001`oookJP;o0000I_oonfX2ool300cooo]Z00?oo`40oook
J_l000002_oonfX00ooo003ooo]ZoookJP09oookJP03ool00?oonf[ooo]Z04cooo]Z0_ooB`0goook
JP;oobP0=ooonfX00ooo403ooo]ZoookJP07oookJP03ool70?oonf[ooo]Z06kooo]Z00?o0000oook
J_l000000_oonfX007;ooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP1RoookJPCo
od/01_oonfX00ooo7@3ooo]ZoookJP0[oookJP;oobP02?oonfX3ool@00Sooo]Z00?oo`D0oookJ_oo
nfX0W_oonfX01?l0003ooo]ZoookJ_l00001oookJP00LooonfX00ol0003ooo]ZoookJP1boookJP03
o`000?oonf[ooo]Z05kooo]Z1?ooB`000ooonf[ood/0oookJP05oookJP?ooad02?oonfX2ool:03So
oo]Z00?oo`D0oookJ_oonfX0WooonfX00ol0003ooo]Zo`000001oookJP00M?oonfX00ol0003ooo]Z
oookJP1aoookJP03o`000?oonf[ooo]Z02;ooo]Z1?ooA@000ooonf[oodD0oookJP06oookJPCooah0
2OoonfX2ool<00_ooo]Z00?oo`<0oookJ_oonfX0=?oonfX2ool30=3ooo]Z0_l00001oookJP00MOoo
nfX2o`0005_ooo]Z0ooo8P0;oookJP;ooa801_oonfX00ol0003ooo]ZoookJP03oookJP03ool80?oo
nf[ooo]Z00[ooo]Z00?oo`<0oookJ_oonfX04ooonfX3oom500Wooo]Z00?ooah0oookJ_oonfX02?oo
nfX00ooo303ooo]ZoookJP08oookJP;oo`<02_oonfX00ooo0@3ooo]ZoookJP3joookJP?o00000Ooo
nfX007Oooo]Z00?o0000oookJ_oonfX07OoonfX2ool>00gooo]Z0_oo200=oookJP03ool40?oonf[o
oo]Z00_ooo]Z00?oo`80oookJ_oonfX03_oonfX00ooo8P3ooo]ZoookJP0:oookJP;ooa801OoonfX0
0ol0003ooo]ZoookJP03oookJP03ool80?oonf[ooo]Z00[ooo]Z00?oo`<0oookJ_oonfX02_oonfX0
0ooo0@3ooo]ZoookJP09oookJP03ool00?oonf[ooo]Z09;ooo]Z00?ooa@0oookJ_oonfX0=ooonfX2
ool805?ooo]Z1?l00004oookJP00N?oonfX00ol0003ooo]ZoookJP18oookJP03ool20?oonf[ooo]Z
00_ooo]Z00?oo`00oookJ_oonfX02_oonfX00ooo003ooo]ZoookJP07oookJP04o`000?oonf[ooo]Z
ool008?ooo]Z0_oo:`0goookJP;ooa@02?oonfX2ool8083ooo]Z1?l00008oookJP00NOoonfX2o`00
06gooo]Z00?o0000oookJ_oonfX0BooonfX00ooo>`3ooo]ZoookJP0doookJPCoob/01ooonfX2ool@
0;Kooo]Z1?l0000<oookJP00NooonfX00ol0003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z04Ko
oo]Z1ooo>`06oookJP?ooaP02OoonfX00ooo203ooo]ZoookJP0foookJP03ool60?oonf[ooo]Z0:Ko
oo]Z1?l0000@oookJP00O?oonfX00ol0003ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z00_ooo]Z
1?oo:`0:oookJP;ooa@02ooonfX00ooo203ooo]ZoookJP0RoookJP03oolk0?oonf[ooo]Z00Kooo]Z
00?ooaP0oookJ_oonfX02?oonfX00ooo203ooo]ZoookJP08oookJP03ool20?oonf[ooo]Z0=3ooo]Z
1?l0000DoookJP00OOoonfX00ol0003ooo]ZoookJP0koookJP?ooa@03?oonfX2ool;00cooo]Z00?o
o`D0oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0>oookJP;oob/02_oonfX2oolD00[ooo]Z00?o
o`P0oookJ_oonfX02OoonfX2ool300[ooo]Z00?oo`00oookJ_oonfX0n?oonfX4o`0001Sooo]Z001n
oookJP;o0000??oonfX2oolD00gooo]Z00?oo`/0oookJ_oonfX02_oonfX00ooo1@3ooo]ZoookJP0:
oookJP;oo`8000?ooo]Zo`000?oonfX02?oonfX2ool000_ooo]Z00?oo`00oookJ_oonfX0bOoonfX2
ool;05?ooo]Z1?l0000LoookJP00P?oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z
0:Kooo]Z0_oo5`08oookJP03ool90?oonf[ooo]Z02gooo]Z00?oo`/0oookJ_oonfX0C_oonfX4o`00
023ooo]Z0021oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0K?oonfX3oolX00So
oo]Z00?ooa00oookJ_oonfX0:ooonfX00ooo5`3ooo]ZoookJP07oookJP;oo`T0O?oonfX4o`0002Co
oo]Z0022oookJP;o0000I?oonfX00ol0003ooo]ZoookJP0_oookJPCoob/02_oonfX00ooo4P3ooo]Z
oookJP09oookJP03ool70?oonf[ooo]Z01kooo]Z0_oo:0000ooonf[oobP0oookJP07oookJP;ooa00
2OoonfX00ooo1@3ooo]ZoookJP2UoookJPCo0000:?oonfX008Cooo]Z00?o0000oookJ_oonfX0FOoo
nfX2oolJ00Kooo]Z00?o0000oookJ_oonfX0<_oonfX2ool[00Sooo]Z0ooo4P09oookJP;oo`L02_oo
nfX00ooo0P3ooo]ZoookJP3>oookJPCo0000;?oonfX008Gooo]Z00?o0000oookJ_oonfX07OoonfX0
0ooo303ooo]ZoookJP0KoookJP03ool30?oonf[ooo]Z00[ooo]Z00?oo`40oookJ_oonfX03_oonfX2
oolJ00Gooo]Z00?o0000oookJ_oonfX00_oonfX3ool=00_ooo]Z00?oo`D0oookJ_oonfX02OoonfX2
ool200_ooo]Z00?oo`00oookJ_oonfX0mOoonfX4o`00033ooo]Z0026oookJP03o`000?oonf[ooo]Z
01gooo]Z00?oo``0oookJ_oonfX02ooonfX2ool700cooo]Z0_oo0`0<oookJP03ool10?oonf[ooo]Z
00[ooo]Z0_oo0009oookJP03o`000?oonf[oo`000<Sooo]Z0_oo301CoookJPCo0000=?oonfX008Oo
oo]Z0_l0001OoookJP03o`000?oonf[ooo]Z08kooo]Z0_oo600hoookJP;oo``0CooonfX4o`0003So
oo]Z0029oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0EOoonfX00ooo8P3ooo]Z
oookJP0CoookJP03ool50?oonf[ooo]Z01oooo]Z00?ooaP0oookJ_oo60002?oonfX2ool907cooo]Z
0ol0000loookJP00R_oonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z03kooo]Z00?o
o`80oookJ_oonfX04_oonfX4oolR00Sooo]Z0_oo3P09oookJP;oo`D0Y_oonfX4o`0003oooo]Z002;
oookJP;o0000F?oonfX00ooo103ooo]Zo`00000:oookJP03ool10?oonf[ooo]Z00[ooo]Z00?oo`00
oookJ_oonfX00_oonfX3oolM00Wooo]Z0ooo3@0:oookJP;oo`D02_oonfX00ooo0P3ooo]ZoookJP3=
oookJPCo0000@ooonfX008gooo]Z00?o0000oookJ_oonfX0>OoonfX3ool@00_ooo]Z0_oo200<oook
JP03ool40?oonf[o000000[ooo]Z00?oo`40oookJ_oonfX02_oonfX00ooo003ooo]ZoookJP3coook
JPCo0000AooonfX008kooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP3ooookJPSo
oo]Z1?l0001;oookJP00SooonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z07Sooo]Z
00?ooaL0oookJ_oonfX0=_oonfX2ool>053ooo]Z1?l0001?oookJP00T?oonfX2o`0005Gooo]Z00?o
0000oookJ_oonfX0MooonfX3oolG00Sooo]Z0_oo2@1koookJPCo0000DooonfX009;ooo]Z00?o0000
oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0NoookJP03ool40?oonf[ooo]Z00Wooo]Z00?oo`40
oookJ_oonfX04?oonfX3oolJ00Wooo]Z0_oo2`0:oookJP03ool40?oonf[ooo]Z0:?ooo]Z1?l0001G
oookJP00TooonfX00ol0003ooo]ZoookJP0joookJP03ool20?oonf[ooo]Z00[ooo]Z00?oo`40oook
J_oonfX01ooonfX01?l0003ooo]ZoookJ_oo0002oookJP?ooa<02_oonfX2ool900_ooo]Z0_oo100;
oookJP03ool10?oonf[ooo]Z0<[ooo]Z1?l0001KoookJP00U?oonfX2o`0001gooo]Z0_oo2`0=oook
JP03ool50?oonf[ooo]Z00_ooo]Z00?oo`80oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP3coook
JPCo0000GooonfX009Kooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP3_oookJPCo
0000HooonfX009Oooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP1/oookJP03ool8
0?oonf[ooo]Z02[ooo]Z0ooo3P1?oookJPCo0000IooonfX009Sooo]Z00?o0000oookJ_oonfX0C?oo
nfX00ol0003ooo]ZoookJP0doookJP03ool80?oonf[ooo]Z00Sooo]Z00?oo`<0oookJ_oonfX07_oo
nfX3oolD00Sooo]Z0_oo201joookJPCo0000JooonfX009Wooo]Z0_l0001:oookJP03ool60?oonf[o
000000[ooo]Z00?oo`<0oookJ_oonfX02OoonfX2ool1013ooo]Z0ooo4`0:oookJP;oo`P02_oonfX0
0ooo0`3ooo]ZoookJP2QoookJPCo0000KooonfX009_ooo]Z00?o0000oookJ_oonfX0>OoonfX2ool=
00cooo]Z00?oo`H0oookJ_l000002_oonfX00ooo0`3ooo]ZoookJP3DoookJPCo0000LooonfX009co
oo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP3KoookJPCo0000MooonfX009gooo]Z
0_l00018oookJP03o`000?oonf[ooo]Z0=Oooo]Z1?l0001koookJP00WooonfX00ol0003ooo]Zoook
JP15oookJP03o`000?oonf[ooo]Z08;ooo]Z0ooo3P1>oookJPCo0000OooonfX00:3ooo]Z00?o0000
oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0YoookJP;oo`807_oonfX3ool@00Wooo]Z0_oo1`1h
oookJPCo0000PooonfX00:7ooo]Z00?o0000oookJ_oonfX0;?oonfX00ooo103ooo]ZoookJP09oook
JP;oo`802OoonfX01?l0003ooo]Zool00?oo000?oookJP;oo`h02ooonfX2ool60:cooo]Z1?l00027
oookJP00X_oonfX2o`0001gooo]Z0_oo200<oookJP03ool40?oonf[ooo]Z01Gooo]Z00?o0000oook
J_oonfX0aooonfX4o`0008_ooo]Z002ToookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oo
nfX0`ooonfX4o`0008oooo]Z002UoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0
_ooonfX4o`0009?ooo]Z002VoookJP;o0000?ooonfX00ol0003ooo]ZoookJP0ooookJP;oo`D0:ooo
nfX2ool<04gooo]Z1?l0002GoookJP00Z?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[o
oo]Z00Oooo]Z0_oo100;oookJP03ool20?oonf[ooo]Z01cooo]Z0_oo3@0:oookJP03ool50?oonf[o
oo]Z07Gooo]Z1?l0002KoookJP00ZOoonfX00ol0003ooo]ZoookJP0hoookJP;oo`T000?ooo]Zo`00
0?oonfX02OoonfX00ooo103ooo]ZoookJP2XoookJPCo0000WooonfX00:[ooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ol0003ooo]ZoookJP2_oookJPCo0000XooonfX00:_ooo]Z0_l0000joookJP03o`00
0?oonf[ooo]Z0:_ooo]Z1?l0002WoookJP00[OoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oo
nf[ooo]Z0:Oooo]Z1?l0002[oookJP00[_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[o
o`4002Wooo]Z0_oo100ZoookJP;oo`/0COoonfX3o`000:oooo]Z002_oookJP;o0000:ooonfX00ooo
0`3ooo]ZoookJP07oookJP04o`000?oonf[ooo]Zool101gooo]Z0_oo2@21oookJPCo0000/_oonfX0
0;7ooo]Z00?o0000oookJ_oonfX06ooonfX00ooo1`3ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
09gooo]Z1?l0002foookJP00/_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z09Wo
oo]Z1?l0002joookJP00/ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z09Gooo]Z
1?l0002noookJP00]?oonfX2o`00033ooo]Z00?o0000oookJ_oonfX0@OoonfX00ooo203ooo]Zoook
JP1=oookJPCo0000`_oonfX00;Kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP08
oookJP;oo`L02ooonfX00ooo0`3ooo]ZoookJP0XoookJP;oo`P0BooonfX4o`000<Kooo]Z002goook
JP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX02OoonfX00ooo1`3ooo]ZoookJP1moook
JPCo0000b_oonfX00;Sooo]Z0_l0000/oookJP03o`000?oonf[ooo]Z08Gooo]Z1?l0003>oookJP00
^_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0003BoookJP00^ooo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z07gooo]Z1?l0003FoookJP00_?oonfX0
0ol0003ooo]ZoookJP0WoookJP04o`000?oonf[ooo]Zool202Wooo]Z0_oo1`1=oookJPCo0000f_oo
nfX00;gooo]Z0_l0000MoookJP03ool50?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0MOoonfX4
o`000=kooo]Z002ooookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0LOoonfX4o`00
0>;ooo]Z0030oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0KOoonfX4o`000>Ko
oo]Z0031oookJP;o00008ooonfX00ol0003ooo]ZoookJP1YoookJPCo0000j_oonfX00<?ooo]Z00?o
0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1UoookJPCo0000k_oonfX00<Cooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0EoookJP03ool50?oonf[ooo]Z04Wooo]Z1?l0003b
oookJP00aOoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z05gooo]Z1?l0003foook
JP00a_oonfX2o`0001kooo]Z00?o0000oookJ_oonfX0FOoonfX4o`000?[ooo]Z0038oookJP03o`00
0?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0EOoonfX4o`000?kooo]Z0039oookJP03o`000?oo
nf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000?oooo]Z0ooonfX00<[ooo]Z0_l0000J
oookJP04o`000?oonf[oo`@0ool404cooo]Z1?l0003ooookJPOooo]Z003<oookJP03o`000?oonf[o
oo]Z01Oooo]Z00?o0000oookJ_oonfX0BOoonfX4o`000?oooo]Z2ooonfX00<gooo]Z00?o0000oook
J_oonfX05_oonfX00ol0003ooo]ZoookJP15oookJPCo0000oooonfX?oookJP00c_oonfX00ol0003o
oo]ZoookJP0EoookJP03o`000?oonf[ooo]Z047ooo]Z1?l0003ooookJQ?ooo]Z003?oookJP;o0000
5OoonfX00ol0003ooo]ZoookJP0moookJPCo0000oooonfXGoookJP00dOoonfX00ol0003ooo]Zoook
JP0BoookJP03o`000?oonf[ooo]Z03Wooo]Z1?l0003ooookJQ_ooo]Z003BoookJP03o`000?oonf[o
oo]Z017ooo]Z00?o0000oookJ_oonfX0=OoonfX4o`000?oooo]Z7ooonfX00=?ooo]Z0_l0000Aoook
JP03o`000?oonf[ooo]Z03;ooo]Z0ol0003ooookJR?ooo]Z003EoookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX0;ooonfX4o`000?oooo]Z9_oonfX00=Kooo]Z00?o0000oookJ_oonfX0
3?oonfX00ol0003ooo]ZoookJP0[oookJPCo0000oooonfXZoookJP00eooonfX00ol0003ooo]Zoook
JP0;oookJP03o`000?oonf[ooo]Z02Oooo]Z1?l0003ooookJRkooo]Z003HoookJP;o00002ooonfX0
0ol0003ooo]ZoookJP0SoookJPCo0000oooonfXboookJP00f_oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z01oooo]Z1?l0003ooookJSKooo]Z003KoookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX06ooonfX4o`000?oooo]Z>_oonfX00=cooo]Z0_l00007oookJP03o`00
0?oonf[ooo]Z01Oooo]Z1?l0003ooookJSkooo]Z003NoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX04ooonfX4o`000?oooo]Z@_oonfX00=oooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0?oookJPCo0000oooonfY6oookJP00h?oonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z00_ooo]Z1?l0003ooookJT[ooo]Z003QoookJP;o00000_oonfX00ol0003o
oo]ZoookJP07oookJPCo0000oooonfY>oookJP00hooonfX00ol0003ooo]Zo`000005oookJPCo0000
oooonfYBoookJP00i?oonfX2o`000003oookJ_l0003o000000;o0000oooonfYFoookJP00iOoonfX2
o`000?oooo]ZF_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {513.25, 0}} -> {-0.000133425, 0.0275501, \
0.00165591, 0.00165591}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
We could make the function better behaved along the z-axis by brute \
force:\
\>", "Text"],

Cell[BoxData[
    \(LeavingKansasNicely[x_, \ y_, \ z_\ , \ n_]\  := \ 
      Module[{CindRadsq\  = \ 
            x^2\  + \ y^2}, \[IndentingNewLine]CindRadsq\  = \ 
          If[CindRadsq\  \[LessEqual] \ 10\^\(-4\), 10\^\(-4\), \ 
            CindRadsq, \ CindRadsq]; \[IndentingNewLine]\ 
        z\^n\/\(CindRadsq \((CindRadsq\  + \ z^2)\)\^\(n\/2\)\)\ {y, \(-x\), \
\ 0}]\)], "Input",
  CellTags->"mmtag:13:plots__dealing_with_singularities"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlotVectorField3D[
      LeavingKansasNicely[x, y, z, 3], {x, \(-1\), 1}, {y, \(-1\), 
        1}, {z, \(- .5\),  .5}, \ VectorHeads \[Rule] True, 
      ColorFunction \[Rule] \((\((Hue[#* .66])\) &)\), PlotPoints \[Rule] 15, 
      ScaleFactor \[Rule] 0.5]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89285 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
7.36261e-17 1.05055 -0.0289472 1.05055 [
[ 0 0 0 0 ]
[ 1 .89285 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05221 .25273 m
0 .58221 L
s
0 .58221 m
.39855 .89285 L
s
.39855 .89285 m
.40897 .59485 L
s
.40897 .59485 m
.05221 .25273 L
s
.68389 0 m
.95694 .42575 L
s
.95694 .42575 m
1 .74078 L
s
1 .74078 m
.70392 .345 L
s
.70392 .345 m
.68389 0 L
s
.05221 .25273 m
0 .58221 L
s
0 .58221 m
.70392 .345 L
s
.70392 .345 m
.68389 0 L
s
.68389 0 m
.05221 .25273 L
s
.40897 .59485 m
.95694 .42575 L
s
.95694 .42575 m
1 .74078 L
s
1 .74078 m
.39855 .89285 L
s
.39855 .89285 m
.40897 .59485 L
s
0 0 m
1 0 L
1 .89285 L
0 .89285 L
closepath
clip
newpath
1 .017 0 r
.5 Mabswid
.41326 .60692 m
.41269 .60683 L
s
.41281 .60692 m
.41279 .60689 L
s
.41279 .60689 m
.41281 .60678 L
s
.41279 .60689 m
.41269 .60683 L
s
.41281 .60678 m
.41283 .60681 L
s
.41281 .60678 m
.41269 .60683 L
s
.41269 .60683 m
.41281 .60692 L
s
.41269 .60683 m
.41283 .60681 L
s
.41283 .60681 m
.41281 .60692 L
s
1 .011 0 r
.4127 .62357 m
.41233 .62351 L
s
.4124 .62357 m
.41239 .62355 L
s
.41239 .62355 m
.4124 .62347 L
s
.41239 .62355 m
.41233 .62351 L
s
.4124 .62347 m
.41242 .62349 L
s
.4124 .62347 m
.41233 .62351 L
s
.41233 .62351 m
.4124 .62357 L
s
.41233 .62351 m
.41242 .62349 L
s
.41242 .62349 m
.4124 .62357 L
s
1 .022 0 r
.44767 .59639 m
.44692 .5963 L
s
.44707 .59641 m
.44705 .59638 L
s
.44705 .59638 m
.44708 .59623 L
s
.44705 .59638 m
.44692 .5963 L
s
.44708 .59623 m
.44709 .59626 L
s
.44708 .59623 m
.44692 .5963 L
s
.44692 .5963 m
.44707 .59641 L
s
.44692 .5963 m
.44709 .59626 L
s
.44709 .59626 m
.44707 .59641 L
s
1 .007 0 r
.41214 .64038 m
.41191 .64034 L
s
.41196 .64038 m
.41195 .64037 L
s
.41195 .64037 m
.41196 .64032 L
s
.41195 .64037 m
.41191 .64034 L
s
.41196 .64032 m
.41197 .64033 L
s
.41196 .64032 m
.41191 .64034 L
s
.41191 .64034 m
.41196 .64038 L
s
.41191 .64034 m
.41197 .64033 L
s
.41197 .64033 m
.41196 .64038 L
s
1 .014 0 r
.44729 .61309 m
.44679 .61303 L
s
.44688 .61311 m
.44687 .61308 L
s
.44687 .61308 m
.44689 .61298 L
s
.44687 .61308 m
.44679 .61303 L
s
.44689 .61298 m
.4469 .61301 L
s
.44689 .61298 m
.44679 .61303 L
s
.44679 .61303 m
.44688 .61311 L
s
.44679 .61303 m
.4469 .61301 L
s
.4469 .61301 m
.44688 .61311 L
s
1 .022 0 r
.39277 .58737 m
.39204 .58722 L
s
.39219 .58734 m
.39216 .58731 L
s
.39216 .58731 m
.39219 .58716 L
s
.39216 .58731 m
.39204 .58722 L
s
.39219 .58716 m
.39222 .58719 L
s
.39219 .58716 m
.39204 .58722 L
s
.39204 .58722 m
.39219 .58734 L
s
.39204 .58722 m
.39222 .58719 L
s
.39222 .58719 m
.39219 .58734 L
s
1 .028 0 r
.48175 .58578 m
.48174 .58574 L
s
.48174 .58574 m
.48176 .58555 L
s
.48174 .58574 m
.48156 .58565 L
s
.48176 .58555 m
.48177 .58559 L
s
.48176 .58555 m
.48156 .58565 L
s
.48254 .58572 m
.48156 .58565 L
s
.48156 .58565 m
.48175 .58578 L
s
.48156 .58565 m
.48177 .58559 L
s
.48177 .58559 m
.48175 .58578 L
s
1 .003 0 r
.41157 .65736 m
.41145 .65734 L
s
.41147 .65736 m
.41147 .65736 L
s
.41147 .65736 m
.41147 .65733 L
s
.41147 .65736 m
.41145 .65734 L
s
.41147 .65733 m
.41148 .65734 L
s
.41147 .65733 m
.41145 .65734 L
s
.41145 .65734 m
.41147 .65736 L
s
.41145 .65734 m
.41148 .65734 L
s
.41148 .65734 m
.41147 .65736 L
s
1 .009 0 r
.44689 .62996 m
.44659 .62993 L
s
.44665 .62997 m
.44664 .62996 L
s
.44664 .62996 m
.44665 .6299 L
s
.44664 .62996 m
.44659 .62993 L
s
.44665 .6299 m
.44666 .62991 L
s
.44665 .6299 m
.44659 .62993 L
s
.44659 .62993 m
.44665 .62997 L
s
.44659 .62993 m
.44666 .62991 L
s
.44666 .62991 m
.44665 .62997 L
s
1 .014 0 r
.3921 .60412 m
.39162 .60402 L
s
.39171 .6041 m
.39169 .60408 L
s
.39169 .60408 m
.39172 .60398 L
s
.39169 .60408 m
.39162 .60402 L
s
.39172 .60398 m
.39174 .604 L
s
.39172 .60398 m
.39162 .60402 L
s
.39162 .60402 m
.39171 .6041 L
s
.39162 .60402 m
.39174 .604 L
s
.39174 .604 m
.39171 .6041 L
s
1 .018 0 r
.4818 .60252 m
.48179 .60249 L
s
.48179 .60249 m
.4818 .60236 L
s
.48179 .60249 m
.48166 .60243 L
s
.4818 .60236 m
.48181 .60239 L
s
.4818 .60236 m
.48166 .60243 L
s
.48232 .60248 m
.48166 .60243 L
s
.48166 .60243 m
.4818 .60252 L
s
.48166 .60243 m
.48181 .60239 L
s
.48181 .60239 m
.4818 .60252 L
s
1 .029 0 r
.42747 .57658 m
.42646 .57642 L
s
.42666 .57657 m
.42663 .57653 L
s
.42663 .57653 m
.42667 .57633 L
s
.42663 .57653 m
.42646 .57642 L
s
.42667 .57633 m
.4267 .57637 L
s
.42667 .57633 m
.42646 .57642 L
s
.42646 .57642 m
.42666 .57657 L
s
.42646 .57642 m
.4267 .57637 L
s
.4267 .57637 m
.42666 .57657 L
s
1 .035 0 r
.51686 .57504 m
.51686 .575 L
s
.51686 .575 m
.51686 .57475 L
s
.51686 .575 m
.51661 .57489 L
s
.51686 .57475 m
.51686 .5748 L
s
.51686 .57475 m
.51661 .57489 L
s
.51786 .57491 m
.51661 .57489 L
s
.51661 .57489 m
.51686 .57504 L
s
.51661 .57489 m
.51686 .5748 L
s
.51686 .5748 m
.51686 .57504 L
s
1 .002 0 r
.41099 .67452 m
.41094 .67451 L
s
.41095 .67452 m
.41095 .67451 L
s
.41095 .67451 m
.41095 .6745 L
s
.41095 .67451 m
.41094 .67451 L
s
.41095 .6745 m
.41095 .6745 L
s
.41095 .6745 m
.41094 .67451 L
s
.41094 .67451 m
.41095 .67452 L
s
.41094 .67451 m
.41095 .6745 L
s
.41095 .6745 m
.41095 .67452 L
s
1 .005 0 r
.4465 .647 m
.44633 .64698 L
s
.44636 .64701 m
.44636 .647 L
s
.44636 .647 m
.44637 .64697 L
s
.44636 .647 m
.44633 .64698 L
s
.44637 .64697 m
.44637 .64697 L
s
.44637 .64697 m
.44633 .64698 L
s
.44633 .64698 m
.44636 .64701 L
s
.44633 .64698 m
.44637 .64697 L
s
.44637 .64697 m
.44636 .64701 L
s
1 .009 0 r
.39143 .62104 m
.39113 .62098 L
s
.39119 .62103 m
.39118 .62101 L
s
.39118 .62101 m
.39119 .62095 L
s
.39118 .62101 m
.39113 .62098 L
s
.39119 .62095 m
.39121 .62097 L
s
.39119 .62095 m
.39113 .62098 L
s
.39113 .62098 m
.39119 .62103 L
s
.39113 .62098 m
.39121 .62097 L
s
.39121 .62097 m
.39119 .62103 L
s
1 .011 0 r
.48178 .61943 m
.48178 .61941 L
s
.48178 .61941 m
.48178 .61933 L
s
.48178 .61941 m
.4817 .61938 L
s
.48178 .61933 m
.48179 .61935 L
s
.48178 .61933 m
.4817 .61938 L
s
.4821 .6194 m
.4817 .61938 L
s
.4817 .61938 m
.48178 .61943 L
s
.4817 .61938 m
.48179 .61935 L
s
.48179 .61935 m
.48178 .61943 L
s
1 .019 0 r
.42697 .59339 m
.4263 .59328 L
s
.42643 .59338 m
.42641 .59335 L
s
.42641 .59335 m
.42643 .59321 L
s
.42641 .59335 m
.4263 .59328 L
s
.42643 .59321 m
.42646 .59324 L
s
.42643 .59321 m
.4263 .59328 L
s
.4263 .59328 m
.42643 .59338 L
s
.4263 .59328 m
.42646 .59324 L
s
.42646 .59324 m
.42643 .59338 L
s
1 .028 0 r
.37178 .56734 m
.37087 .56709 L
s
.37104 .56726 m
.37099 .56722 L
s
.37099 .56722 m
.37106 .56703 L
s
.37099 .56722 m
.37087 .56709 L
s
.37106 .56703 m
.37111 .56707 L
s
.37106 .56703 m
.37087 .56709 L
s
.37087 .56709 m
.37104 .56726 L
s
.37087 .56709 m
.37111 .56707 L
s
.37111 .56707 m
.37104 .56726 L
s
1 .023 0 r
.51715 .59181 m
.51714 .59178 L
s
.51714 .59178 m
.51715 .59161 L
s
.51714 .59178 m
.51698 .59171 L
s
.51715 .59161 m
.51715 .59165 L
s
.51715 .59161 m
.51698 .59171 L
s
.51782 .59172 m
.51698 .59171 L
s
.51698 .59171 m
.51715 .59181 L
s
.51698 .59171 m
.51715 .59165 L
s
.51715 .59165 m
.51715 .59181 L
s
1 .039 0 r
.46262 .56565 m
.46124 .56549 L
s
1 0 0 r
.41041 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
.4104 .69184 m
.4104 .69184 L
s
1 .039 0 r
.46151 .56569 m
.46148 .56564 L
s
.46148 .56564 m
.46152 .56536 L
s
.46148 .56564 m
.46124 .56549 L
s
.46152 .56536 m
.46155 .56541 L
s
.46152 .56536 m
.46124 .56549 L
s
.46124 .56549 m
.46151 .56569 L
s
.46124 .56549 m
.46155 .56541 L
s
.46155 .56541 m
.46151 .56569 L
s
1 .043 0 r
.55243 .5642 m
.55244 .56414 L
s
.55244 .56414 m
.55242 .56384 L
s
.55244 .56414 m
.55212 .56404 L
s
.55242 .56384 m
.55241 .5639 L
s
.55242 .56384 m
.55212 .56404 L
s
.55212 .56404 m
.55243 .5642 L
s
.55212 .56404 m
.55241 .5639 L
s
.55365 .56396 m
.55212 .56404 L
s
.55241 .5639 m
.55243 .5642 L
s
1 .002 0 r
.44609 .66422 m
.44602 .66421 L
s
.44604 .66422 m
.44604 .66421 L
s
.44604 .66421 m
.44604 .6642 L
s
.44604 .66421 m
.44602 .66421 L
s
.44604 .6642 m
.44604 .6642 L
s
.44604 .6642 m
.44602 .66421 L
s
.44602 .66421 m
.44604 .66422 L
s
.44602 .66421 m
.44604 .6642 L
s
.44604 .6642 m
.44604 .66422 L
s
1 .005 0 r
.39075 .63813 m
.39059 .6381 L
s
.39062 .63812 m
.39061 .63811 L
s
.39061 .63811 m
.39062 .63808 L
s
.39061 .63811 m
.39059 .6381 L
s
.39062 .63808 m
.39063 .63809 L
s
.39062 .63808 m
.39059 .6381 L
s
.39059 .6381 m
.39062 .63812 L
s
.39059 .6381 m
.39063 .63809 L
s
.39063 .63809 m
.39062 .63812 L
s
1 .006 0 r
.48171 .63652 m
.48171 .63651 L
s
.48171 .63651 m
.48171 .63647 L
s
.48171 .63651 m
.48167 .63649 L
s
.48171 .63647 m
.48171 .63648 L
s
.48171 .63647 m
.48167 .63649 L
s
.48188 .6365 m
.48167 .63649 L
s
.48167 .63649 m
.48171 .63652 L
s
.48167 .63649 m
.48171 .63648 L
s
.48171 .63648 m
.48171 .63652 L
s
1 .012 0 r
.42647 .61036 m
.42606 .61029 L
s
.42614 .61036 m
.42612 .61034 L
s
.42612 .61034 m
.42614 .61026 L
s
.42612 .61034 m
.42606 .61029 L
s
.42614 .61026 m
.42615 .61028 L
s
.42614 .61026 m
.42606 .61029 L
s
.42606 .61029 m
.42614 .61036 L
s
.42606 .61029 m
.42615 .61028 L
s
.42615 .61028 m
.42614 .61036 L
s
1 .018 0 r
.371 .58419 m
.37038 .58403 L
s
.3705 .58414 m
.37047 .58411 L
s
.37047 .58411 m
.37051 .58398 L
s
.37047 .58411 m
.37038 .58403 L
s
.37051 .58398 m
.37055 .58401 L
s
.37051 .58398 m
.37038 .58403 L
s
.37038 .58403 m
.3705 .58414 L
s
.37038 .58403 m
.37055 .58401 L
s
.37055 .58401 m
.3705 .58414 L
s
1 .014 0 r
.51737 .60876 m
.51737 .60874 L
s
.51737 .60874 m
.51737 .60864 L
s
.51737 .60874 m
.51726 .6087 L
s
.51737 .60864 m
.51737 .60866 L
s
.51737 .60864 m
.51726 .6087 L
s
.51778 .60871 m
.51726 .6087 L
s
.51726 .6087 m
.51737 .60876 L
s
.51726 .6087 m
.51737 .60866 L
s
.51737 .60866 m
.51737 .60876 L
s
1 0 0 r
.40983 .70935 m
.40982 .70935 L
s
1 .026 0 r
.4623 .58251 m
.46137 .58241 L
s
1 0 0 r
.40982 .70935 m
.40982 .70935 L
s
.40982 .70935 m
.40982 .70935 L
s
.40982 .70935 m
.40982 .70935 L
s
.40982 .70935 m
.40982 .70935 L
s
.40982 .70935 m
.40982 .70935 L
s
.40982 .70935 m
.40982 .70935 L
s
.40982 .70935 m
.40982 .70935 L
s
.40982 .70935 m
.40982 .70935 L
s
1 .026 0 r
.46155 .58254 m
.46153 .5825 L
s
.46153 .5825 m
.46156 .58231 L
s
.46153 .5825 m
.46137 .58241 L
s
.46156 .58231 m
.46158 .58235 L
s
.46156 .58231 m
.46137 .58241 L
s
.46137 .58241 m
.46155 .58254 L
s
.46137 .58241 m
.46158 .58235 L
s
.46158 .58235 m
.46155 .58254 L
s
1 .039 0 r
.40677 .55629 m
.40543 .55599 L
s
.40569 .55622 m
.40563 .55616 L
s
.40563 .55616 m
.40571 .55588 L
s
.40563 .55616 m
.40543 .55599 L
s
.40571 .55588 m
.40577 .55594 L
s
.40571 .55588 m
.40543 .55599 L
s
.40543 .55599 m
.40569 .55622 L
s
.40543 .55599 m
.40577 .55594 L
s
.40577 .55594 m
.40569 .55622 L
s
1 .029 0 r
.55296 .58099 m
.55297 .58095 L
s
.55297 .58095 m
.55296 .58074 L
s
.55297 .58095 m
.55275 .58088 L
s
.55296 .58074 m
.55295 .58078 L
s
.55296 .58074 m
.55275 .58088 L
s
.55275 .58088 m
.55296 .58099 L
s
.55275 .58088 m
.55295 .58078 L
s
.55379 .58083 m
.55275 .58088 L
s
.55295 .58078 m
.55296 .58099 L
s
1 .051 0 r
.49676 .55472 m
.49674 .55465 L
s
.49674 .55465 m
.49676 .55428 L
s
.49674 .55465 m
.49639 .55448 L
s
.49676 .55428 m
.49678 .55435 L
s
.49676 .55428 m
.49639 .55448 L
s
.49825 .55457 m
.49639 .55448 L
s
1 .001 0 r
.44569 .68161 m
.44567 .6816 L
s
.44567 .68161 m
.44567 .68161 L
s
.44567 .68161 m
.44567 .6816 L
s
.44567 .68161 m
.44567 .6816 L
s
.44567 .6816 m
.44567 .6816 L
s
.44567 .6816 m
.44567 .6816 L
s
.44567 .6816 m
.44567 .68161 L
s
.44567 .6816 m
.44567 .6816 L
s
.44567 .6816 m
.44567 .68161 L
s
1 .051 0 r
.49639 .55448 m
.49676 .55472 L
s
.49639 .55448 m
.49678 .55435 L
s
.49678 .55435 m
.49676 .55472 L
s
1 .002 0 r
.39006 .65539 m
.38999 .65538 L
s
.39 .65539 m
.39 .65539 L
s
.39 .65539 m
.39 .65537 L
s
.39 .65539 m
.38999 .65538 L
s
.39 .65537 m
.39001 .65538 L
s
.39 .65537 m
.38999 .65538 L
s
.38999 .65538 m
.39 .65539 L
s
.38999 .65538 m
.39001 .65538 L
s
.39001 .65538 m
.39 .65539 L
s
1 .05 0 r
.5885 .55325 m
.58855 .55318 L
s
.58855 .55318 m
.58849 .55282 L
s
.58855 .55318 m
.58814 .55308 L
s
.58849 .55282 m
.58845 .55289 L
s
.58849 .55282 m
.58814 .55308 L
s
.58814 .55308 m
.5885 .55325 L
s
.58814 .55308 m
.58845 .55289 L
s
.58991 .55286 m
.58814 .55308 L
s
.58845 .55289 m
.5885 .55325 L
s
1 .003 0 r
.48159 .65379 m
.48158 .65378 L
s
.48158 .65378 m
.48159 .65376 L
s
.48158 .65378 m
.48157 .65377 L
s
.48159 .65376 m
.48159 .65377 L
s
.48159 .65376 m
.48157 .65377 L
s
.48166 .65378 m
.48157 .65377 L
s
.48157 .65377 m
.48159 .65379 L
s
.48157 .65377 m
.48159 .65377 L
s
.48159 .65377 m
.48159 .65379 L
s
1 .006 0 r
.42596 .62751 m
.42574 .62748 L
s
.42578 .62751 m
.42578 .6275 L
s
.42578 .6275 m
.42579 .62746 L
s
.42578 .6275 m
.42574 .62748 L
s
.42579 .62746 m
.42579 .62747 L
s
.42579 .62746 m
.42574 .62748 L
s
.42574 .62748 m
.42578 .62751 L
s
.42574 .62748 m
.42579 .62747 L
s
.42579 .62747 m
.42578 .62751 L
s
1 .011 0 r
.37021 .60122 m
.36983 .60112 L
s
.36991 .60119 m
.36988 .60117 L
s
.36988 .60117 m
.36991 .60109 L
s
.36988 .60117 m
.36983 .60112 L
s
.36991 .60109 m
.36993 .60111 L
s
.36991 .60109 m
.36983 .60112 L
s
.36983 .60112 m
.36991 .60119 L
s
.36983 .60112 m
.36993 .60111 L
s
.36993 .60111 m
.36991 .60119 L
s
1 .008 0 r
.51752 .6259 m
.51752 .62589 L
s
.51752 .62589 m
.51752 .62583 L
s
.51752 .62589 m
.51746 .62586 L
s
.51752 .62583 m
.51752 .62584 L
s
.51752 .62583 m
.51746 .62586 L
s
.51774 .62587 m
.51746 .62586 L
s
.51746 .62586 m
.51752 .6259 L
s
.51746 .62586 m
.51752 .62584 L
s
.51752 .62584 m
.51752 .6259 L
s
1 .016 0 r
.46198 .59954 m
.4614 .59948 L
s
1 0 0 r
.40923 .72703 m
.40923 .72703 L
s
1 .016 0 r
.46152 .59956 m
.4615 .59954 L
s
.4615 .59954 m
.46152 .59942 L
s
.4615 .59954 m
.4614 .59948 L
s
.46152 .59942 m
.46153 .59945 L
s
.46152 .59942 m
.4614 .59948 L
s
.4614 .59948 m
.46152 .59956 L
s
.4614 .59948 m
.46153 .59945 L
s
.46153 .59945 m
.46152 .59956 L
s
1 .026 0 r
.40616 .5732 m
.40525 .573 L
s
.40543 .57315 m
.40539 .57311 L
s
.40539 .57311 m
.40544 .57292 L
s
.40539 .57311 m
.40525 .573 L
s
.40544 .57292 m
.40548 .57296 L
s
.40544 .57292 m
.40525 .573 L
s
.40525 .573 m
.40543 .57315 L
s
.40525 .573 m
.40548 .57296 L
s
.40548 .57296 m
.40543 .57315 L
s
1 .018 0 r
.55342 .59797 m
.55343 .59794 L
s
.55343 .59794 m
.55342 .59782 L
s
.55343 .59794 m
.5533 .5979 L
s
.55342 .59782 m
.55342 .59784 L
s
.55342 .59782 m
.5533 .5979 L
s
.5533 .5979 m
.55342 .59797 L
s
.5533 .5979 m
.55342 .59784 L
s
.55394 .59787 m
.5533 .5979 L
s
1 .035 0 r
.35028 .54682 m
.34916 .54644 L
s
1 .018 0 r
.55342 .59784 m
.55342 .59797 L
s
1 .035 0 r
.34937 .54666 m
.3493 .5466 L
s
.3493 .5466 m
.34939 .54636 L
s
.3493 .5466 m
.34916 .54644 L
s
.34939 .54636 m
.34947 .54642 L
s
.34939 .54636 m
.34916 .54644 L
s
.34947 .54642 m
.34937 .54666 L
s
.34916 .54644 m
.34937 .54666 L
s
.34916 .54644 m
.34947 .54642 L
s
.49709 .57159 m
.49708 .57154 L
s
.49708 .57154 m
.49709 .57129 L
s
.49708 .57154 m
.49684 .57142 L
s
.49709 .57129 m
.49711 .57133 L
s
.49709 .57129 m
.49684 .57142 L
s
1 0 0 r
.44528 .69918 m
.44528 .69918 L
s
1 .035 0 r
.49811 .57149 m
.49684 .57142 L
s
1 0 0 r
.44528 .69918 m
.44528 .69918 L
s
.44528 .69918 m
.44528 .69917 L
s
.44528 .69918 m
.44528 .69918 L
s
.44528 .69917 m
.44528 .69917 L
s
.44528 .69917 m
.44528 .69918 L
s
.44528 .69918 m
.44528 .69918 L
s
.44528 .69918 m
.44528 .69917 L
s
.44528 .69917 m
.44528 .69918 L
s
1 .035 0 r
.49684 .57142 m
.49709 .57159 L
s
.49684 .57142 m
.49711 .57133 L
s
.49711 .57133 m
.49709 .57159 L
s
1 .055 0 r
.44222 .54509 m
.44028 .54476 L
s
1 .001 0 r
.38936 .67284 m
.38934 .67283 L
s
.38935 .67284 m
.38934 .67284 L
s
.38934 .67284 m
.38935 .67283 L
s
.38934 .67284 m
.38934 .67283 L
s
.38935 .67283 m
.38935 .67283 L
s
.38935 .67283 m
.38934 .67283 L
s
.38934 .67283 m
.38935 .67284 L
s
.38934 .67283 m
.38935 .67283 L
s
.38935 .67283 m
.38935 .67284 L
s
1 .055 0 r
.44066 .54506 m
.44059 .54498 L
s
.44059 .54498 m
.44067 .54459 L
s
.44059 .54498 m
.44028 .54476 L
s
.44067 .54459 m
.44074 .54467 L
s
.44067 .54459 m
.44028 .54476 L
s
.44028 .54476 m
.44066 .54506 L
s
.44028 .54476 m
.44074 .54467 L
s
.44074 .54467 m
.44066 .54506 L
s
1 .034 0 r
.58928 .57005 m
.58931 .57 L
s
.58931 .57 m
.58928 .56976 L
s
.58931 .57 m
.58904 .56993 L
s
.58928 .56976 m
.58924 .5698 L
s
.58928 .56976 m
.58904 .56993 L
s
.58904 .56993 m
.58928 .57005 L
s
.58904 .56993 m
.58924 .5698 L
s
.59025 .56978 m
.58904 .56993 L
s
.58924 .5698 m
.58928 .57005 L
s
1 .066 0 r
.53243 .54367 m
.53244 .54358 L
s
.53244 .54358 m
.53243 .54311 L
s
.53244 .54358 m
.53195 .54339 L
s
.53243 .54311 m
.53242 .54319 L
s
.53243 .54311 m
.53195 .54339 L
s
.53195 .54339 m
.53243 .54367 L
s
.53195 .54339 m
.53242 .54319 L
s
.53435 .54335 m
.53195 .54339 L
s
1 .001 0 r
.48141 .67123 m
.48141 .67123 L
s
.48141 .67123 m
.48141 .67123 L
s
.48141 .67123 m
.48141 .67123 L
s
.48141 .67123 m
.48141 .67123 L
s
.48141 .67123 m
.48141 .67123 L
s
.48144 .67123 m
.48141 .67123 L
s
.48141 .67123 m
.48141 .67123 L
s
.48141 .67123 m
.48141 .67123 L
s
.48141 .67123 m
.48141 .67123 L
s
1 .066 0 r
.53242 .54319 m
.53243 .54367 L
s
1 .003 0 r
.42545 .64484 m
.42535 .64482 L
s
.42537 .64484 m
.42537 .64483 L
s
.42537 .64483 m
.42537 .64481 L
s
.42537 .64483 m
.42535 .64482 L
s
.42537 .64481 m
.42538 .64482 L
s
.42537 .64481 m
.42535 .64482 L
s
.42535 .64482 m
.42537 .64484 L
s
.42535 .64482 m
.42538 .64482 L
s
.42538 .64482 m
.42537 .64484 L
s
1 .055 0 r
.62515 .54216 m
.62523 .54208 L
s
.62523 .54208 m
.62513 .5417 L
s
.62523 .54208 m
.62476 .54201 L
s
.62513 .5417 m
.62505 .54178 L
s
.62513 .5417 m
.62476 .54201 L
s
.62476 .54201 m
.62515 .54216 L
s
.62476 .54201 m
.62505 .54178 L
s
.62667 .54161 m
.62476 .54201 L
s
.62505 .54178 m
.62515 .54216 L
s
1 .006 0 r
.36941 .61842 m
.36921 .61836 L
s
.36925 .6184 m
.36923 .61839 L
s
.36923 .61839 m
.36925 .61835 L
s
.36923 .61839 m
.36921 .61836 L
s
.36925 .61835 m
.36926 .61836 L
s
.36925 .61835 m
.36921 .61836 L
s
.36921 .61836 m
.36925 .6184 L
s
.36921 .61836 m
.36926 .61836 L
s
.36926 .61836 m
.36925 .6184 L
s
1 .003 0 r
.51761 .64322 m
.51761 .64321 L
s
.51761 .64321 m
.51761 .64319 L
s
.51761 .64321 m
.51758 .6432 L
s
.51761 .64319 m
.51761 .64319 L
s
.51761 .64319 m
.51758 .6432 L
s
.51771 .6432 m
.51758 .6432 L
s
.51758 .6432 m
.51761 .64322 L
s
.51758 .6432 m
.51761 .64319 L
s
.51761 .64319 m
.51761 .64322 L
s
1 0 0 r
.40864 .7449 m
.40864 .7449 L
s
.40864 .7449 m
.40864 .7449 L
s
.40864 .7449 m
.40864 .7449 L
s
.40864 .7449 m
.40864 .7449 L
s
.40864 .7449 m
.40864 .7449 L
s
.40864 .7449 m
.40864 .7449 L
s
.40864 .7449 m
.40864 .7449 L
s
.40863 .7449 m
.40864 .7449 L
s
.40864 .7449 m
.40864 .7449 L
s
1 .009 0 r
.46165 .61675 m
.46134 .61672 L
s
.4614 .61676 m
.46139 .61675 L
s
.46139 .61675 m
.4614 .61669 L
s
.46139 .61675 m
.46134 .61672 L
s
.4614 .61669 m
.46141 .6167 L
s
.4614 .61669 m
.46134 .61672 L
s
.46134 .61672 m
.4614 .61676 L
s
.46134 .61672 m
.46141 .6167 L
s
.46141 .6167 m
.4614 .61676 L
s
1 .016 0 r
.40554 .59028 m
.40498 .59015 L
s
.40509 .59025 m
.40507 .59022 L
s
.40507 .59022 m
.4051 .59011 L
s
.40507 .59022 m
.40498 .59015 L
s
.4051 .59011 m
.40512 .59014 L
s
.4051 .59011 m
.40498 .59015 L
s
.40498 .59015 m
.40509 .59025 L
s
.40498 .59015 m
.40512 .59014 L
s
.40512 .59014 m
.40509 .59025 L
s
1 .01 0 r
.55381 .61514 m
.55381 .61513 L
s
.55381 .61513 m
.55381 .61506 L
s
.55381 .61513 m
.55374 .6151 L
s
.55381 .61506 m
.5538 .61507 L
s
.55381 .61506 m
.55374 .6151 L
s
.55374 .6151 m
.55381 .61514 L
s
.55374 .6151 m
.5538 .61507 L
s
.55409 .61509 m
.55374 .6151 L
s
1 .023 0 r
.34937 .56377 m
.34862 .56352 L
s
1 .01 0 r
.5538 .61507 m
.55381 .61514 L
s
1 .023 0 r
.34876 .56367 m
.34871 .56363 L
s
.34871 .56363 m
.34877 .56347 L
s
.34871 .56363 m
.34862 .56352 L
s
.34877 .56347 m
.34883 .56351 L
s
.34877 .56347 m
.34862 .56352 L
s
.34883 .56351 m
.34876 .56367 L
s
.34862 .56352 m
.34876 .56367 L
s
.34862 .56352 m
.34883 .56351 L
s
1 .022 0 r
.49733 .58864 m
.49732 .58861 L
s
.49732 .58861 m
.49733 .58845 L
s
.49732 .58861 m
.49717 .58854 L
s
.49733 .58845 m
.49734 .58848 L
s
.49733 .58845 m
.49717 .58854 L
s
.49797 .58858 m
.49717 .58854 L
s
1 0 0 r
.44487 .71693 m
.44487 .71693 L
s
1 .022 0 r
.49717 .58854 m
.49733 .58864 L
s
.49717 .58854 m
.49734 .58848 L
s
.49734 .58848 m
.49733 .58864 L
s
1 0 0 r
.38866 .69046 m
.38866 .69046 L
s
1 .038 0 r
.44179 .56205 m
.44046 .56183 L
s
1 0 0 r
.38866 .69046 m
.38866 .69046 L
s
.38866 .69046 m
.38866 .69046 L
s
.38866 .69046 m
.38866 .69046 L
s
.38866 .69046 m
.38866 .69046 L
s
.38866 .69046 m
.38866 .69046 L
s
.38866 .69046 m
.38866 .69046 L
s
.38866 .69046 m
.38866 .69046 L
s
.38866 .69046 m
.38866 .69046 L
s
1 .038 0 r
.44072 .56203 m
.44067 .56198 L
s
.44067 .56198 m
.44073 .56171 L
s
.44067 .56198 m
.44046 .56183 L
s
.44073 .56171 m
.44078 .56176 L
s
.44073 .56171 m
.44046 .56183 L
s
.44046 .56183 m
.44072 .56203 L
s
.44046 .56183 m
.44078 .56176 L
s
.44078 .56176 m
.44072 .56203 L
s
1 .021 0 r
.58998 .58705 m
.59 .58702 L
s
.59 .58702 m
.58998 .58686 L
s
.59 .58702 m
.58983 .58697 L
s
.58998 .58686 m
.58996 .5869 L
s
.58998 .58686 m
.58983 .58697 L
s
.58983 .58697 m
.58998 .58705 L
s
.58983 .58697 m
.58996 .5869 L
s
.59058 .58688 m
.58983 .58697 L
s
.58996 .5869 m
.58998 .58705 L
s
1 .051 0 r
.38555 .53549 m
.38384 .53498 L
s
.38417 .5353 m
.38407 .53522 L
s
.38407 .53522 m
.38419 .53486 L
s
.38407 .53522 m
.38384 .53498 L
s
.38419 .53486 m
.3843 .53494 L
s
.38419 .53486 m
.38384 .53498 L
s
.38384 .53498 m
.38417 .5353 L
s
.38384 .53498 m
.3843 .53494 L
s
.3843 .53494 m
.38417 .5353 L
s
1 .045 0 r
.53307 .56054 m
.53308 .56048 L
s
.53308 .56048 m
.53307 .56015 L
s
.53308 .56048 m
.53274 .56035 L
s
.53307 .56015 m
.53306 .56021 L
s
.53307 .56015 m
.53274 .56035 L
s
.53274 .56035 m
.53307 .56054 L
s
.53274 .56035 m
.53306 .56021 L
s
.53439 .56032 m
.53274 .56035 L
s
1 0 0 r
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
.48121 .68887 m
.48121 .68887 L
s
1 .045 0 r
.53306 .56021 m
.53307 .56054 L
s
1 .077 0 r
.47815 .53373 m
.47537 .53344 L
s
1 .001 0 r
.42493 .66234 m
.4249 .66234 L
s
.42491 .66234 m
.42491 .66234 L
s
.42491 .66234 m
.42491 .66234 L
s
.42491 .66234 m
.4249 .66234 L
s
1 .077 0 r
.47592 .53383 m
.47586 .53373 L
s
.47586 .53373 m
.47593 .53317 L
s
.47586 .53373 m
.47537 .53344 L
s
1 .001 0 r
.42491 .66234 m
.42491 .66234 L
s
.42491 .66234 m
.4249 .66234 L
s
.4249 .66234 m
.42491 .66234 L
s
.4249 .66234 m
.42491 .66234 L
s
.42491 .66234 m
.42491 .66234 L
s
1 .077 0 r
.47593 .53317 m
.47599 .53327 L
s
.47593 .53317 m
.47537 .53344 L
s
.47537 .53344 m
.47592 .53383 L
s
.47537 .53344 m
.47599 .53327 L
s
.47599 .53327 m
.47592 .53383 L
s
1 .038 0 r
.62615 .55897 m
.62621 .55891 L
s
.62621 .55891 m
.62614 .55865 L
s
.62621 .55891 m
.62588 .55886 L
s
.62614 .55865 m
.62608 .5587 L
s
.62614 .55865 m
.62588 .55886 L
s
.62588 .55886 m
.62615 .55897 L
s
.62588 .55886 m
.62608 .5587 L
s
.62719 .55859 m
.62588 .55886 L
s
.62608 .5587 m
.62615 .55897 L
s
1 .003 0 r
.3686 .6358 m
.36851 .63577 L
s
.36853 .63579 m
.36852 .63578 L
s
.36852 .63578 m
.36853 .63577 L
s
.36852 .63578 m
.36851 .63577 L
s
.36853 .63577 m
.36853 .63577 L
s
.36853 .63577 m
.36851 .63577 L
s
.36851 .63577 m
.36853 .63579 L
s
.36851 .63577 m
.36853 .63577 L
s
.36853 .63577 m
.36853 .63579 L
s
1 .08 0 r
.56862 .53255 m
.56868 .53245 L
s
.56868 .53245 m
.56861 .53187 L
s
.56868 .53245 m
.56803 .53227 L
s
.56861 .53187 m
.56855 .53197 L
s
.56861 .53187 m
.56803 .53227 L
s
.56803 .53227 m
.56862 .53255 L
s
.56803 .53227 m
.56855 .53197 L
s
.57093 .53197 m
.56803 .53227 L
s
.56855 .53197 m
.56862 .53255 L
s
1 .001 0 r
.51764 .66072 m
.51764 .66072 L
s
.51764 .66072 m
.51764 .66071 L
s
.51764 .66072 m
.51763 .66072 L
s
.51764 .66071 m
.51764 .66071 L
s
.51764 .66071 m
.51763 .66072 L
s
.51767 .66072 m
.51763 .66072 L
s
.51763 .66072 m
.51764 .66072 L
s
.51763 .66072 m
.51764 .66071 L
s
.51764 .66071 m
.51764 .66072 L
s
1 0 0 r
.40804 .76296 m
.40804 .76296 L
s
.40804 .76295 m
.40804 .76296 L
s
.40804 .76296 m
.40804 .76296 L
s
.40804 .76295 m
.40804 .76295 L
s
.40804 .76295 m
.40804 .76296 L
s
.40804 .76296 m
.40804 .76296 L
s
.40804 .76295 m
.40804 .76296 L
s
.40803 .76295 m
.40804 .76296 L
s
.40804 .76296 m
.40804 .76295 L
s
1 .004 0 r
.46132 .63414 m
.46118 .63413 L
s
.46121 .63415 m
.46121 .63414 L
s
.46121 .63414 m
.46121 .63411 L
s
.46121 .63414 m
.46118 .63413 L
s
.46121 .63411 m
.46122 .63412 L
s
.46121 .63411 m
.46118 .63413 L
s
.46118 .63413 m
.46121 .63415 L
s
.46118 .63413 m
.46122 .63412 L
s
.46122 .63412 m
.46121 .63415 L
s
1 .057 0 r
.66241 .53091 m
.66253 .53082 L
s
.66253 .53082 m
.66239 .53043 L
s
.66253 .53082 m
.66203 .53079 L
s
.66239 .53043 m
.66227 .53052 L
s
.66239 .53043 m
.66203 .53079 L
s
.66203 .53079 m
.66241 .53091 L
s
.66203 .53079 m
.66227 .53052 L
s
.66391 .53021 m
.66203 .53079 L
s
.66227 .53052 m
.66241 .53091 L
s
1 .009 0 r
.40492 .60754 m
.40462 .60747 L
s
.40468 .60752 m
.40466 .60751 L
s
.40466 .60751 m
.40468 .60745 L
s
.40466 .60751 m
.40462 .60747 L
s
.40468 .60745 m
.40469 .60746 L
s
.40468 .60745 m
.40462 .60747 L
s
.40462 .60747 m
.40468 .60752 L
s
.40462 .60747 m
.40469 .60746 L
s
.40469 .60746 m
.40468 .60752 L
s
1 .004 0 r
.55411 .63251 m
.55412 .6325 L
s
.55412 .6325 m
.55411 .63247 L
s
.55412 .6325 m
.55408 .63249 L
s
.55411 .63247 m
.55411 .63248 L
s
.55411 .63247 m
.55408 .63249 L
s
.55408 .63249 m
.55411 .63251 L
s
.55408 .63249 m
.55411 .63248 L
s
.55424 .63248 m
.55408 .63249 L
s
1 .014 0 r
.34846 .5809 m
.34799 .58075 L
s
1 .004 0 r
.55411 .63248 m
.55411 .63251 L
s
1 .014 0 r
.34808 .58084 m
.34805 .58081 L
s
.34805 .58081 m
.34809 .58072 L
s
.34805 .58081 m
.34799 .58075 L
s
.34809 .58072 m
.34812 .58074 L
s
.34809 .58072 m
.34799 .58075 L
s
.34812 .58074 m
.34808 .58084 L
s
.34799 .58075 m
.34808 .58084 L
s
.34799 .58075 m
.34812 .58074 L
s
1 .012 0 r
.49748 .60588 m
.49747 .60587 L
s
.49747 .60587 m
.49748 .60578 L
s
.49747 .60587 m
.49739 .60583 L
s
.49748 .60578 m
.49748 .6058 L
s
.49748 .60578 m
.49739 .60583 L
s
1 0 0 r
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
.44445 .73486 m
.44445 .73486 L
s
1 .012 0 r
.49782 .60585 m
.49739 .60583 L
s
.49739 .60583 m
.49748 .60588 L
s
.49739 .60583 m
.49748 .6058 L
s
.49748 .6058 m
.49748 .60588 L
s
1 .023 0 r
.44135 .57919 m
.44052 .57905 L
s
1 0 0 r
.38795 .70827 m
.38795 .70827 L
s
1 .023 0 r
.44069 .57918 m
.44066 .57914 L
s
.44066 .57914 m
.44069 .57898 L
s
.44066 .57914 m
.44052 .57905 L
s
.44069 .57898 m
.44072 .57901 L
s
.44069 .57898 m
.44052 .57905 L
s
.44052 .57905 m
.44069 .57918 L
s
.44052 .57905 m
.44072 .57901 L
s
.44072 .57901 m
.44069 .57918 L
s
1 .011 0 r
.59059 .60425 m
.59061 .60423 L
s
.59061 .60423 m
.59059 .60415 L
s
.59061 .60423 m
.59051 .60421 L
s
.59059 .60415 m
.59058 .60417 L
s
.59059 .60415 m
.59051 .60421 L
s
.59051 .60421 m
.59059 .60425 L
s
.59051 .60421 m
.59058 .60417 L
s
.59092 .60416 m
.59051 .60421 L
s
.59058 .60417 m
.59059 .60425 L
s
1 .035 0 r
.38482 .5525 m
.38365 .55215 L
s
.38388 .55237 m
.38381 .55232 L
s
.38381 .55232 m
.38389 .55207 L
s
.38381 .55232 m
.38365 .55215 L
s
.38389 .55207 m
.38397 .55213 L
s
.38389 .55207 m
.38365 .55215 L
s
.38365 .55215 m
.38388 .55237 L
s
.38365 .55215 m
.38397 .55213 L
s
.38397 .55213 m
.38388 .55237 L
s
1 .028 0 r
.53361 .57761 m
.53361 .57757 L
s
.53361 .57757 m
.53361 .57736 L
s
.53361 .57757 m
.5334 .57749 L
s
.53361 .57736 m
.5336 .5774 L
s
.53361 .57736 m
.5334 .57749 L
s
.5334 .57749 m
.53361 .57761 L
s
.5334 .57749 m
.5336 .5774 L
s
.53444 .57747 m
.5334 .57749 L
s
1 0 0 r
.48098 .70668 m
.48098 .70668 L
s
1 .043 0 r
.32823 .52578 m
.32694 .52522 L
s
1 .028 0 r
.5336 .5774 m
.53361 .57761 L
s
1 .043 0 r
.32719 .52551 m
.32707 .52543 L
s
.32707 .52543 m
.32721 .52515 L
s
.32707 .52543 m
.32694 .52522 L
s
.32721 .52515 m
.32732 .52523 L
s
.32721 .52515 m
.32694 .52522 L
s
.32732 .52523 m
.32719 .52551 L
s
.32694 .52522 m
.32719 .52551 L
s
.32694 .52522 m
.32732 .52523 L
s
1 .053 0 r
.4779 .55075 m
.47597 .55055 L
s
1 0 0 r
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
.42441 .68003 m
.42441 .68003 L
s
1 .053 0 r
.47635 .55082 m
.47631 .55075 L
s
.47631 .55075 m
.47636 .55036 L
s
.47631 .55075 m
.47597 .55055 L
s
.47636 .55036 m
.4764 .55043 L
s
.47636 .55036 m
.47597 .55055 L
s
.47597 .55055 m
.47635 .55082 L
s
.47597 .55055 m
.4764 .55043 L
s
.4764 .55043 m
.47635 .55082 L
s
1 .023 0 r
.62707 .57598 m
.62711 .57595 L
s
.62711 .57595 m
.62707 .57578 L
s
.62711 .57595 m
.6269 .57591 L
s
.62707 .57578 m
.62703 .57582 L
s
.62707 .57578 m
.6269 .57591 L
s
.6269 .57591 m
.62707 .57598 L
s
.6269 .57591 m
.62703 .57582 L
s
.62772 .57575 m
.6269 .57591 L
s
.62703 .57582 m
.62707 .57598 L
s
1 .077 0 r
.4213 .52401 m
.41865 .52337 L
s
1 .001 0 r
.36778 .65336 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
.36776 .65335 m
.36776 .65335 L
s
1 .077 0 r
.41917 .52382 m
.41904 .52371 L
s
.41904 .52371 m
.41919 .52316 L
s
.41904 .52371 m
.41865 .52337 L
s
.41919 .52316 m
.41933 .52328 L
s
.41919 .52316 m
.41865 .52337 L
s
1 .055 0 r
.56956 .5494 m
.5696 .54933 L
s
.5696 .54933 m
.56955 .54892 L
s
.5696 .54933 m
.56915 .5492 L
s
.56955 .54892 m
.56951 .549 L
s
.56955 .54892 m
.56915 .5492 L
s
1 .077 0 r
.41865 .52337 m
.41917 .52382 L
s
.41865 .52337 m
.41933 .52328 L
s
1 .055 0 r
.56915 .5492 m
.56956 .5494 L
s
.56915 .5492 m
.56951 .549 L
s
.57117 .549 m
.56915 .5492 L
s
1 .077 0 r
.41933 .52328 m
.41917 .52382 L
s
1 .055 0 r
.56951 .549 m
.56956 .5494 L
s
1 0 0 r
.51762 .67842 m
.51762 .67842 L
s
.51762 .67842 m
.51762 .67842 L
s
.51762 .67842 m
.51762 .67842 L
s
.51762 .67842 m
.51762 .67842 L
s
.51762 .67842 m
.51762 .67842 L
s
.51763 .67842 m
.51762 .67842 L
s
.51762 .67842 m
.51762 .67842 L
s
.51762 .67842 m
.51762 .67842 L
s
.51762 .67842 m
.51762 .67842 L
s
1 .104 0 r
.51149 .52259 m
.51147 .52247 L
s
.51147 .52247 m
.51149 .5217 L
s
.51147 .52247 m
.51072 .52213 L
s
.51149 .5217 m
.51151 .52183 L
s
.51149 .5217 m
.51072 .52213 L
s
1 .002 0 r
.40746 .7812 m
.40746 .78121 L
s
.40746 .78119 m
.40746 .7812 L
s
.40747 .7812 m
.40746 .7812 L
s
.40746 .7812 m
.40746 .78119 L
s
.40746 .78119 m
.40747 .7812 L
s
.40747 .7812 m
.40746 .78121 L
s
.40746 .7812 m
.40747 .7812 L
s
.40742 .78119 m
.40747 .7812 L
s
.40746 .78121 m
.40746 .7812 L
s
1 .104 0 r
.51456 .52223 m
.51072 .52213 L
s
1 .001 0 r
.46099 .65171 m
.46095 .65171 L
s
.46095 .65171 m
.46095 .65171 L
s
.46095 .65171 m
.46095 .6517 L
s
.46095 .65171 m
.46095 .65171 L
s
.46095 .6517 m
.46096 .6517 L
s
.46095 .6517 m
.46095 .65171 L
s
.46095 .65171 m
.46095 .65171 L
s
.46095 .65171 m
.46096 .6517 L
s
.46096 .6517 m
.46095 .65171 L
s
1 .104 0 r
.51072 .52213 m
.51149 .52259 L
s
.51072 .52213 m
.51151 .52183 L
s
.51151 .52183 m
.51149 .52259 L
s
1 .039 0 r
.66361 .54773 m
.66369 .54766 L
s
.66369 .54766 m
.66359 .54739 L
s
.66369 .54766 m
.66334 .54764 L
s
.66359 .54739 m
.66351 .54745 L
s
.66359 .54739 m
.66334 .54764 L
s
.66334 .54764 m
.66361 .54773 L
s
.66334 .54764 m
.66351 .54745 L
s
.66464 .54724 m
.66334 .54764 L
s
.66351 .54745 m
.66361 .54773 L
s
1 .004 0 r
.40429 .62498 m
.40416 .62495 L
s
.40418 .62497 m
.40418 .62496 L
s
.40418 .62496 m
.40419 .62494 L
s
.40418 .62496 m
.40416 .62495 L
s
.40419 .62494 m
.40419 .62494 L
s
.40419 .62494 m
.40416 .62495 L
s
.40416 .62495 m
.40418 .62497 L
s
.40416 .62495 m
.40419 .62494 L
s
.40419 .62494 m
.40418 .62497 L
s
1 .091 0 r
.60546 .52134 m
.6056 .52121 L
s
.6056 .52121 m
.60544 .52056 L
s
.6056 .52121 m
.60481 .52108 L
s
.60544 .52056 m
.60531 .52069 L
s
.60544 .52056 m
.60481 .52108 L
s
.60481 .52108 m
.60546 .52134 L
s
.60481 .52108 m
.60531 .52069 L
s
.60802 .52044 m
.60481 .52108 L
s
.60531 .52069 m
.60546 .52134 L
s
1 .001 0 r
.55435 .65007 m
.55435 .65007 L
s
.55435 .65007 m
.55435 .65006 L
s
.55435 .65007 m
.55434 .65006 L
s
.55435 .65006 m
.55435 .65006 L
s
.55435 .65006 m
.55434 .65006 L
s
.55434 .65006 m
.55435 .65007 L
s
.55434 .65006 m
.55435 .65006 L
s
.55439 .65006 m
.55434 .65006 L
s
1 .008 0 r
.34754 .59821 m
.34728 .59813 L
s
1 .001 0 r
.55435 .65006 m
.55435 .65007 L
s
1 .008 0 r
.34733 .59818 m
.34731 .59817 L
s
.34731 .59817 m
.34734 .59811 L
s
.34731 .59817 m
.34728 .59813 L
s
.34734 .59811 m
.34735 .59813 L
s
.34734 .59811 m
.34728 .59813 L
s
.34735 .59813 m
.34733 .59818 L
s
.34728 .59813 m
.34733 .59818 L
s
.34728 .59813 m
.34735 .59813 L
s
1 .005 0 r
.49753 .62331 m
.49752 .62331 L
s
.49752 .62331 m
.49753 .62327 L
s
.49752 .62331 m
.49749 .62329 L
s
1 .001 0 r
.44404 .75299 m
.44404 .75299 L
s
.44404 .75298 m
.44404 .75299 L
s
.44405 .75299 m
.44404 .75299 L
s
.44404 .75299 m
.44404 .75298 L
s
.44404 .75298 m
.44405 .75299 L
s
1 .005 0 r
.49753 .62327 m
.49753 .62327 L
s
.49753 .62327 m
.49749 .62329 L
s
1 .001 0 r
.44405 .75299 m
.44404 .75299 L
s
.44404 .75299 m
.44405 .75299 L
s
.44402 .75299 m
.44405 .75299 L
s
.44404 .75299 m
.44404 .75299 L
s
1 .005 0 r
.49768 .6233 m
.49749 .62329 L
s
.49749 .62329 m
.49753 .62331 L
s
.49749 .62329 m
.49753 .62327 L
s
.49753 .62327 m
.49753 .62331 L
s
1 .055 0 r
.69996 .51936 m
.70032 .51946 L
s
.70029 .51898 m
.69996 .51936 L
s
.69996 .51936 m
.70014 .51908 L
s
.70046 .51936 m
.69996 .51936 L
s
.70167 .51865 m
.69996 .51936 L
s
.70032 .51946 m
.70046 .51936 L
s
.70046 .51936 m
.70029 .51898 L
s
.70029 .51898 m
.70014 .51908 L
s
.70014 .51908 m
.70032 .51946 L
s
1 0 0 r
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
.38723 .72626 m
.38723 .72626 L
s
1 .013 0 r
.44091 .59651 m
.44046 .59643 L
s
.44055 .5965 m
.44053 .59648 L
s
.44053 .59648 m
.44055 .59639 L
s
.44053 .59648 m
.44046 .59643 L
s
.44055 .59639 m
.44057 .59641 L
s
.44055 .59639 m
.44046 .59643 L
s
.44046 .59643 m
.44055 .5965 L
s
.44046 .59643 m
.44057 .59641 L
s
.44057 .59641 m
.44055 .5965 L
s
1 .005 0 r
.59112 .62166 m
.59112 .62165 L
s
.59112 .62165 m
.59112 .62161 L
s
.59112 .62165 m
.59108 .62164 L
s
.59112 .62161 m
.59111 .62162 L
s
.59112 .62161 m
.59108 .62164 L
s
.59108 .62164 m
.59112 .62166 L
s
.59108 .62164 m
.59111 .62162 L
s
.59127 .62162 m
.59108 .62164 L
s
.59111 .62162 m
.59112 .62166 L
s
1 .022 0 r
.38409 .56969 m
.38336 .56947 L
s
.3835 .56961 m
.38346 .56957 L
s
.38346 .56957 m
.38351 .56942 L
s
.38346 .56957 m
.38336 .56947 L
s
.38351 .56942 m
.38355 .56946 L
s
.38351 .56942 m
.38336 .56947 L
s
.38336 .56947 m
.3835 .56961 L
s
.38336 .56947 m
.38355 .56946 L
s
.38355 .56946 m
.3835 .56961 L
s
1 .015 0 r
.53403 .59487 m
.53403 .59485 L
s
.53403 .59485 m
.53403 .59474 L
s
.53403 .59485 m
.53392 .59481 L
s
.53403 .59474 m
.53403 .59476 L
s
.53403 .59474 m
.53392 .59481 L
s
.53392 .59481 m
.53403 .59487 L
s
.53392 .59481 m
.53403 .59476 L
s
.53449 .5948 m
.53392 .59481 L
s
1 0 0 r
.48075 .72469 m
.48075 .72469 L
s
.48075 .72469 m
.48075 .72469 L
s
.48075 .72469 m
.48075 .72469 L
s
.48075 .72469 m
.48075 .72469 L
s
.48075 .72469 m
.48075 .72469 L
s
.48075 .72469 m
.48075 .72469 L
s
.48075 .72469 m
.48075 .72469 L
s
.48075 .72469 m
.48075 .72469 L
s
1 .029 0 r
.3272 .54284 m
.32632 .54246 L
s
1 0 0 r
.48075 .72469 m
.48075 .72469 L
s
1 .015 0 r
.53403 .59476 m
.53403 .59487 L
s
1 .029 0 r
.32649 .54266 m
.32641 .5426 L
s
.32641 .5426 m
.3265 .54241 L
s
.32641 .5426 m
.32632 .54246 L
s
.3265 .54241 m
.32658 .54247 L
s
.3265 .54241 m
.32632 .54246 L
s
.32658 .54247 m
.32649 .54266 L
s
.32632 .54246 m
.32649 .54266 L
s
.32632 .54246 m
.32658 .54247 L
s
1 .033 0 r
.47765 .56795 m
.47643 .56782 L
s
1 0 0 r
.42388 .69791 m
.42388 .69791 L
s
1 .033 0 r
.47667 .56799 m
.47664 .56795 L
s
.47664 .56795 m
.47667 .5677 L
s
.47664 .56795 m
.47643 .56782 L
s
.47667 .5677 m
.4767 .56775 L
s
.47667 .5677 m
.47643 .56782 L
s
.47643 .56782 m
.47667 .56799 L
s
.47643 .56782 m
.4767 .56775 L
s
.4767 .56775 m
.47667 .56799 L
s
1 .013 0 r
.6279 .59321 m
.62792 .59319 L
s
.62792 .59319 m
.6279 .5931 L
s
.62792 .59319 m
.62781 .59317 L
s
.6279 .5931 m
.62788 .59312 L
s
.6279 .5931 m
.62781 .59317 L
s
.62781 .59317 m
.6279 .59321 L
s
.62781 .59317 m
.62788 .59312 L
s
.62826 .59308 m
.62781 .59317 L
s
.62788 .59312 m
.6279 .59321 L
s
1 0 0 r
.36696 .6711 m
.36695 .6711 L
s
1 .053 0 r
.42076 .54107 m
.41891 .54063 L
s
1 0 0 r
.36696 .6711 m
.36696 .6711 L
s
.36696 .6711 m
.36696 .6711 L
s
.36696 .6711 m
.36695 .6711 L
s
.36696 .6711 m
.36696 .6711 L
s
.36696 .6711 m
.36695 .6711 L
s
.36695 .6711 m
.36696 .6711 L
s
.36695 .6711 m
.36696 .6711 L
s
.36696 .6711 m
.36696 .6711 L
s
1 .053 0 r
.41927 .54095 m
.41918 .54087 L
s
.41918 .54087 m
.41929 .54049 L
s
.41918 .54087 m
.41891 .54063 L
s
.41929 .54049 m
.41938 .54057 L
s
.41929 .54049 m
.41891 .54063 L
s
.41891 .54063 m
.41927 .54095 L
s
.41891 .54063 m
.41938 .54057 L
s
.41938 .54057 m
.41927 .54095 L
s
1 .035 0 r
.57039 .56646 m
.57042 .56641 L
s
.57042 .56641 m
.57038 .56615 L
s
.57042 .56641 m
.57013 .56633 L
s
.57038 .56615 m
.57036 .5662 L
s
.57038 .56615 m
.57013 .56633 L
s
.57013 .56633 m
.57039 .56646 L
s
.57013 .56633 m
.57036 .5662 L
s
.57141 .56621 m
.57013 .56633 L
s
.57036 .5662 m
.57039 .56646 L
s
1 0 0 r
.51759 .6963 m
.51759 .6963 L
s
1 .066 0 r
.3638 .51417 m
.36172 .51335 L
s
.36213 .5138 m
.36196 .51368 L
s
.36196 .51368 m
.36215 .51323 L
s
.36196 .51368 m
.36172 .51335 L
s
.36215 .51323 m
.36232 .51335 L
s
.36215 .51323 m
.36172 .51335 L
s
1 .073 0 r
.51233 .53956 m
.51232 .53947 L
s
.51232 .53947 m
.51234 .53893 L
s
.51232 .53947 m
.51179 .53923 L
s
.51234 .53893 m
.51235 .53902 L
s
.51234 .53893 m
.51179 .53923 L
s
1 .066 0 r
.36232 .51335 m
.36213 .5138 L
s
.36172 .51335 m
.36213 .5138 L
s
.36172 .51335 m
.36232 .51335 L
s
1 .003 0 r
.40689 .79965 m
.4069 .79966 L
s
.4069 .79963 m
.40689 .79965 L
s
.40692 .79965 m
.40689 .79965 L
s
.4069 .79963 m
.4069 .79963 L
s
.4069 .79963 m
.40692 .79965 L
s
.40692 .79965 m
.4069 .79966 L
s
.4069 .79963 m
.40692 .79965 L
s
.4068 .79963 m
.40692 .79965 L
s
.4069 .79966 m
.4069 .79963 L
s
1 .073 0 r
.51451 .5393 m
.51179 .53923 L
s
1 0 0 r
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
.46065 .66946 m
.46065 .66946 L
s
1 .073 0 r
.51179 .53923 m
.51233 .53956 L
s
.51179 .53923 m
.51235 .53902 L
s
.51235 .53902 m
.51233 .53956 L
s
1 .024 0 r
.66472 .56476 m
.66478 .56472 L
s
.66478 .56472 m
.66472 .56455 L
s
.66478 .56472 m
.66456 .5647 L
s
.66472 .56455 m
.66466 .56459 L
s
.66472 .56455 m
.66456 .5647 L
s
.66456 .5647 m
.66472 .56476 L
s
.66456 .5647 m
.66466 .56459 L
s
.66537 .56446 m
.66456 .5647 L
s
.66466 .56459 m
.66472 .56476 L
s
1 .115 0 r
.45754 .51237 m
.45343 .51165 L
s
1 .001 0 r
.40366 .6426 m
.40362 .64259 L
s
.40362 .6426 m
.40362 .64259 L
s
.40362 .64259 m
.40362 .64259 L
s
.40362 .64259 m
.40362 .64259 L
s
.40362 .64259 m
.40363 .64259 L
s
.40362 .64259 m
.40362 .64259 L
s
.40362 .64259 m
.40362 .6426 L
s
.40362 .64259 m
.40363 .64259 L
s
.40363 .64259 m
.40362 .6426 L
s
1 .115 0 r
.45424 .51229 m
.45409 .51214 L
s
.45409 .51214 m
.45426 .5113 L
s
.45409 .51214 m
.45343 .51165 L
s
.45426 .5113 m
.45441 .51146 L
s
.45426 .5113 m
.45343 .51165 L
s
1 .063 0 r
.60666 .53815 m
.60675 .53806 L
s
.60675 .53806 m
.60665 .5376 L
s
.60675 .53806 m
.6062 .53797 L
s
.60665 .5376 m
.60655 .53769 L
s
.60665 .5376 m
.6062 .53797 L
s
.6062 .53797 m
.60666 .53815 L
s
.6062 .53797 m
.60655 .53769 L
s
.60845 .53752 m
.6062 .53797 L
s
.60655 .53769 m
.60666 .53815 L
s
1 .115 0 r
.45343 .51165 m
.45424 .51229 L
s
.45343 .51165 m
.45441 .51146 L
s
.45441 .51146 m
.45424 .51229 L
s
1 0 0 r
.55454 .66783 m
.55454 .66783 L
s
.55454 .66783 m
.55454 .66782 L
s
.55454 .66783 m
.55454 .66782 L
s
.55454 .66782 m
.55454 .66782 L
s
.55454 .66782 m
.55454 .66782 L
s
.55454 .66782 m
.55454 .66783 L
s
.55454 .66782 m
.55454 .66782 L
s
.55454 .66782 m
.55454 .66782 L
s
1 .003 0 r
.3466 .6157 m
.34649 .61567 L
s
1 0 0 r
.55454 .66782 m
.55454 .66783 L
s
1 .003 0 r
.34651 .61569 m
.3465 .61568 L
s
.3465 .61568 m
.34651 .61566 L
s
.3465 .61568 m
.34649 .61567 L
s
.34651 .61566 m
.34652 .61567 L
s
.34651 .61566 m
.34649 .61567 L
s
.34652 .61567 m
.34651 .61569 L
s
.34649 .61567 m
.34651 .61569 L
s
.34649 .61567 m
.34652 .61567 L
s
1 .134 0 r
.54752 .51141 m
.54759 .51124 L
s
.54759 .51124 m
.54751 .51026 L
s
.54759 .51124 m
.54653 .5109 L
s
.54751 .51026 m
.54744 .51042 L
s
.54751 .51026 m
.54653 .5109 L
s
.54653 .5109 m
.54752 .51141 L
s
.54653 .5109 m
.54744 .51042 L
s
.55147 .51056 m
.54653 .5109 L
s
1 .002 0 r
.44365 .77131 m
.44366 .77131 L
s
.44366 .7713 m
.44365 .77131 L
s
.44367 .77131 m
.44365 .77131 L
s
.44366 .7713 m
.44366 .7713 L
s
.44366 .7713 m
.44367 .77131 L
s
.44367 .77131 m
.44366 .77131 L
s
.44366 .7713 m
.44367 .77131 L
s
.4436 .7713 m
.44367 .77131 L
s
.44366 .77131 m
.44366 .7713 L
s
.49749 .64093 m
.49749 .64093 L
s
.49749 .64093 m
.49749 .64092 L
s
.49749 .64093 m
.49748 .64093 L
s
.49749 .64092 m
.49749 .64092 L
s
.49749 .64092 m
.49748 .64093 L
s
.49754 .64093 m
.49748 .64093 L
s
.49748 .64093 m
.49749 .64093 L
s
.49748 .64093 m
.49749 .64092 L
s
.49749 .64092 m
.49749 .64093 L
s
1 .134 0 r
.54744 .51042 m
.54752 .51141 L
s
1 .038 0 r
.70142 .53623 m
.70167 .53629 L
s
.70165 .53597 m
.70142 .53623 L
s
.70142 .53623 m
.70155 .53604 L
s
.70177 .53622 m
.70142 .53623 L
s
.7026 .53574 m
.70142 .53623 L
s
.70167 .53629 m
.70177 .53622 L
s
.70177 .53622 m
.70165 .53597 L
s
.70165 .53597 m
.70155 .53604 L
s
.70155 .53604 m
.70167 .53629 L
s
1 .095 0 r
.64308 .50995 m
.64329 .5098 L
s
.64329 .5098 m
.64305 .50913 L
s
.64329 .5098 m
.64243 .50974 L
s
.64305 .50913 m
.64285 .50928 L
s
.64305 .50913 m
.64243 .50974 L
s
.64243 .50974 m
.64308 .50995 L
s
.64243 .50974 m
.64285 .50928 L
s
.64561 .50875 m
.64243 .50974 L
s
1 .001 0 r
.38652 .74445 m
.38652 .74445 L
s
.38652 .74444 m
.38652 .74445 L
s
.38653 .74445 m
.38652 .74445 L
s
.38652 .74445 m
.38652 .74444 L
s
.38652 .74444 m
.38653 .74445 L
s
.38653 .74445 m
.38652 .74445 L
s
.38652 .74445 m
.38653 .74445 L
s
.3865 .74444 m
.38653 .74445 L
s
.38652 .74445 m
.38652 .74445 L
s
1 .006 0 r
.44047 .61401 m
.44027 .61397 L
s
.44031 .61401 m
.4403 .614 L
s
.4403 .614 m
.44031 .61396 L
s
.4403 .614 m
.44027 .61397 L
s
.44031 .61396 m
.44032 .61397 L
s
.44031 .61396 m
.44027 .61397 L
s
.44027 .61397 m
.44031 .61401 L
s
.44027 .61397 m
.44032 .61397 L
s
.44032 .61397 m
.44031 .61401 L
s
1 .095 0 r
.64285 .50928 m
.64308 .50995 L
s
1 .002 0 r
.59157 .63927 m
.59157 .63927 L
s
.59157 .63927 m
.59157 .63926 L
s
.59157 .63927 m
.59156 .63927 L
s
.59157 .63926 m
.59157 .63926 L
s
.59157 .63926 m
.59156 .63927 L
s
.59156 .63927 m
.59157 .63927 L
s
.59156 .63927 m
.59157 .63926 L
s
.59161 .63926 m
.59156 .63927 L
s
.59157 .63926 m
.59157 .63927 L
s
1 .012 0 r
.38335 .58706 m
.38295 .58694 L
s
.38302 .58702 m
.383 .587 L
s
.383 .587 m
.38303 .58691 L
s
.383 .587 m
.38295 .58694 L
s
.38303 .58691 m
.38305 .58693 L
s
.38303 .58691 m
.38295 .58694 L
s
.38295 .58694 m
.38302 .58702 L
s
.38295 .58694 m
.38305 .58693 L
s
.38305 .58693 m
.38302 .58702 L
s
1 .007 0 r
.53433 .61234 m
.53433 .61233 L
s
.53433 .61233 m
.53433 .61228 L
s
.53433 .61233 m
.53428 .61231 L
s
.53433 .61228 m
.53433 .61229 L
s
.53433 .61228 m
.53428 .61231 L
s
.53428 .61231 m
.53433 .61234 L
s
.53428 .61231 m
.53433 .61229 L
s
.53454 .61231 m
.53428 .61231 L
s
1 .001 0 r
.48054 .74288 m
.48054 .74289 L
s
.48054 .74288 m
.48054 .74288 L
s
.48054 .74288 m
.48054 .74288 L
s
.48054 .74288 m
.48054 .74288 L
s
.48054 .74288 m
.48054 .74288 L
s
.48054 .74288 m
.48054 .74289 L
s
.48054 .74288 m
.48054 .74288 L
s
.48051 .74288 m
.48054 .74288 L
s
1 .018 0 r
.32616 .56008 m
.32561 .55984 L
s
1 .001 0 r
.48054 .74289 m
.48054 .74288 L
s
1 .007 0 r
.53433 .61229 m
.53433 .61234 L
s
1 .05 0 r
.73852 .5077 m
.73882 .50776 L
s
.73879 .50733 m
.73852 .5077 L
s
.73852 .5077 m
.73863 .50744 L
s
.73898 .50766 m
.73852 .5077 L
s
.73994 .50694 m
.73852 .5077 L
s
1 .018 0 r
.32572 .55997 m
.32567 .55993 L
s
.32567 .55993 m
.32573 .55981 L
s
.32567 .55993 m
.32561 .55984 L
s
.32573 .55981 m
.32578 .55985 L
s
.32573 .55981 m
.32561 .55984 L
s
1 .05 0 r
.73879 .50733 m
.73863 .50744 L
s
.73898 .50766 m
.73879 .50733 L
s
.73882 .50776 m
.73898 .50766 L
s
1 .018 0 r
.32578 .55985 m
.32572 .55997 L
s
.32561 .55984 m
.32572 .55997 L
s
.32561 .55984 m
.32578 .55985 L
s
1 .05 0 r
.73863 .50744 m
.73882 .50776 L
s
1 0 0 r
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
.42335 .71597 m
.42335 .71597 L
s
1 .018 0 r
.4774 .58533 m
.47672 .58526 L
s
.47686 .58535 m
.47684 .58533 L
s
.47684 .58533 m
.47686 .58519 L
s
.47684 .58533 m
.47672 .58526 L
s
.47686 .58519 m
.47687 .58522 L
s
.47686 .58519 m
.47672 .58526 L
s
.47672 .58526 m
.47686 .58535 L
s
.47672 .58526 m
.47687 .58522 L
s
.47687 .58522 m
.47686 .58535 L
s
1 .006 0 r
.62864 .61066 m
.62865 .61065 L
s
.62865 .61065 m
.62864 .61061 L
s
.62865 .61065 m
.6286 .61064 L
s
.62864 .61061 m
.62863 .61062 L
s
.62864 .61061 m
.6286 .61064 L
s
.6286 .61064 m
.62864 .61066 L
s
.6286 .61064 m
.62863 .61062 L
s
.6288 .6106 m
.6286 .61064 L
s
.62863 .61062 m
.62864 .61066 L
s
1 .033 0 r
.4202 .55832 m
.41904 .55804 L
s
1 0 0 r
.36612 .68903 m
.36612 .68903 L
s
1 .033 0 r
.41927 .55824 m
.41921 .55819 L
s
.41921 .55819 m
.41928 .55795 L
s
.41921 .55819 m
.41904 .55804 L
s
.41928 .55795 m
.41933 .558 L
s
.41928 .55795 m
.41904 .55804 L
s
.41904 .55804 m
.41927 .55824 L
s
.41904 .55804 m
.41933 .558 L
s
.41933 .558 m
.41927 .55824 L
s
1 .019 0 r
.57109 .58373 m
.5711 .58371 L
s
.5711 .58371 m
.57109 .58356 L
s
.5711 .58371 m
.57094 .58366 L
s
.57109 .58356 m
.57107 .58359 L
s
.57109 .58356 m
.57094 .58366 L
s
.57094 .58366 m
.57109 .58373 L
s
.57094 .58366 m
.57107 .58359 L
s
.57166 .58359 m
.57094 .58366 L
s
.57107 .58359 m
.57109 .58373 L
s
1 0 0 r
.51755 .71437 m
.51755 .71437 L
s
.51755 .71437 m
.51755 .71437 L
s
.51755 .71437 m
.51755 .71437 L
s
.51755 .71437 m
.51755 .71437 L
s
.51755 .71437 m
.51755 .71437 L
s
.51755 .71437 m
.51755 .71437 L
s
.51755 .71437 m
.51755 .71437 L
s
.51755 .71437 m
.51755 .71437 L
s
1 .045 0 r
.36295 .53128 m
.36151 .53072 L
s
1 0 0 r
.51755 .71437 m
.51755 .71437 L
s
1 .045 0 r
.36179 .53103 m
.36167 .53095 L
s
.36167 .53095 m
.36181 .53064 L
s
.36167 .53095 m
.36151 .53072 L
s
.36181 .53064 m
.36193 .53072 L
s
.36181 .53064 m
.36151 .53072 L
s
.36193 .53072 m
.36179 .53103 L
s
.36151 .53072 m
.36179 .53103 L
s
.36151 .53072 m
.36193 .53072 L
s
1 .047 0 r
.51305 .55672 m
.51304 .55666 L
s
.51304 .55666 m
.51305 .55631 L
s
.51304 .55666 m
.51271 .55651 L
s
.51305 .55631 m
.51306 .55638 L
s
.51305 .55631 m
.51271 .55651 L
s
1 .007 0 r
.40636 .8183 m
.40636 .81831 L
s
.40637 .81825 m
.40636 .8183 L
s
.40641 .81829 m
.40636 .8183 L
s
.40637 .81827 m
.40637 .81825 L
s
.40637 .81825 m
.40641 .81829 L
s
.40641 .81829 m
.40636 .81831 L
s
.40637 .81827 m
.40641 .81829 L
s
.40617 .81825 m
.40641 .81829 L
s
.40636 .81831 m
.40637 .81827 L
s
1 .047 0 r
.51445 .55655 m
.51271 .55651 L
s
1 0 0 r
.46031 .6874 m
.46031 .6874 L
s
1 .05 0 r
.30563 .50421 m
.30423 .50343 L
s
1 .047 0 r
.51271 .55651 m
.51305 .55672 L
s
.51271 .55651 m
.51306 .55638 L
s
.51306 .55638 m
.51305 .55672 L
s
1 .05 0 r
.30453 .50337 m
.30469 .50348 L
s
.30434 .5037 m
.30453 .50337 L
s
.30453 .50337 m
.30423 .50343 L
s
.3045 .5038 m
.30434 .5037 L
s
.30434 .5037 m
.30423 .50343 L
s
.30469 .50348 m
.3045 .5038 L
s
.30423 .50343 m
.30469 .50348 L
s
.30423 .50343 m
.3045 .5038 L
s
1 .013 0 r
.66576 .58202 m
.66578 .582 L
s
.66578 .582 m
.66575 .5819 L
s
.66578 .582 m
.66566 .58199 L
s
.66575 .5819 m
.66572 .58193 L
s
.66575 .5819 m
.66566 .58199 L
s
.66566 .58199 m
.66576 .58202 L
s
.66566 .58199 m
.66572 .58193 L
s
.66611 .58185 m
.66566 .58199 L
s
.66572 .58193 m
.66576 .58202 L
s
1 .081 0 r
.45718 .52949 m
.45426 .52899 L
s
1 0 0 r
.40301 .66041 m
.40301 .66041 L
s
.40301 .66041 m
.40301 .66041 L
s
.40301 .66041 m
.40301 .6604 L
s
.40301 .66041 m
.40301 .66041 L
s
.40301 .6604 m
.40301 .66041 L
s
.40301 .6604 m
.40301 .66041 L
s
.40301 .66041 m
.40301 .66041 L
s
.40301 .66041 m
.40301 .66041 L
s
.40301 .66041 m
.40301 .66041 L
s
1 .081 0 r
.45484 .52944 m
.45473 .52933 L
s
.45473 .52933 m
.45485 .52874 L
s
.45473 .52933 m
.45426 .52899 L
s
.45485 .52874 m
.45496 .52885 L
s
.45485 .52874 m
.45426 .52899 L
s
.45426 .52899 m
.45484 .52944 L
s
.45426 .52899 m
.45496 .52885 L
s
1 .04 0 r
.60775 .55519 m
.60781 .55513 L
s
.60781 .55513 m
.60774 .55483 L
s
.60781 .55513 m
.60746 .55507 L
s
.60774 .55483 m
.60768 .55489 L
s
.60774 .55483 m
.60746 .55507 L
s
1 .081 0 r
.45496 .52885 m
.45484 .52944 L
s
1 .04 0 r
.60746 .55507 m
.60775 .55519 L
s
.60746 .55507 m
.60768 .55489 L
s
.60889 .55479 m
.60746 .55507 L
s
.60768 .55489 m
.60775 .55519 L
s
1 0 0 r
.5547 .68578 m
.5547 .68578 L
s
1 .104 0 r
.39985 .50239 m
.39642 .50123 L
s
1 .001 0 r
.34566 .63338 m
.34562 .63337 L
s
.34563 .63338 m
.34563 .63337 L
s
.34563 .63337 m
.34563 .63337 L
s
.34563 .63337 m
.34562 .63337 L
s
.34563 .63337 m
.34563 .63337 L
s
.34563 .63337 m
.34562 .63337 L
s
.34563 .63337 m
.34563 .63338 L
s
.34562 .63337 m
.34563 .63338 L
s
.34562 .63337 m
.34563 .63337 L
s
1 .095 0 r
.54878 .5283 m
.54883 .52818 L
s
.54883 .52818 m
.54878 .52747 L
s
.54883 .52818 m
.54807 .52793 L
s
.54878 .52747 m
.54872 .52759 L
s
.54878 .52747 m
.54807 .52793 L
s
1 .104 0 r
.39709 .50191 m
.39684 .50174 L
s
.39684 .50174 m
.39712 .50101 L
s
.39684 .50174 m
.39642 .50123 L
s
1 .095 0 r
.54807 .52793 m
.54878 .5283 L
s
.54807 .52793 m
.54872 .52759 L
s
.55161 .52769 m
.54807 .52793 L
s
1 .104 0 r
.39712 .50101 m
.39737 .50118 L
s
.39712 .50101 m
.39642 .50123 L
s
1 .005 0 r
.4433 .78983 m
.4433 .78984 L
s
.4433 .7898 m
.4433 .78983 L
s
.44334 .78982 m
.4433 .78983 L
s
.44331 .78981 m
.4433 .7898 L
s
.4433 .7898 m
.44334 .78982 L
s
.44334 .78982 m
.4433 .78984 L
s
.44331 .78981 m
.44334 .78982 L
s
.44317 .78981 m
.44334 .78982 L
s
.4433 .78984 m
.44331 .78981 L
s
1 0 0 r
.49738 .65875 m
.49738 .65875 L
s
.49738 .65875 m
.49738 .65875 L
s
.49738 .65875 m
.49738 .65875 L
s
.49738 .65875 m
.49738 .65875 L
s
.49738 .65875 m
.49738 .65875 L
s
.49739 .65875 m
.49738 .65875 L
s
.49738 .65875 m
.49738 .65875 L
s
.49738 .65875 m
.49738 .65875 L
s
.49738 .65875 m
.49738 .65875 L
s
1 .095 0 r
.54872 .52759 m
.54878 .5283 L
s
1 .104 0 r
.39642 .50123 m
.39709 .50191 L
s
.39642 .50123 m
.39737 .50118 L
s
.39737 .50118 m
.39709 .50191 L
s
1 .023 0 r
.7028 .55331 m
.70295 .55336 L
s
.70294 .55315 m
.7028 .55331 L
s
.7028 .55331 m
.70288 .5532 L
s
.70302 .55331 m
.7028 .55331 L
s
.70353 .55302 m
.7028 .55331 L
s
.70295 .55336 m
.70302 .55331 L
s
.70302 .55331 m
.70294 .55315 L
s
.70294 .55315 m
.70288 .5532 L
s
.70288 .5532 m
.70295 .55336 L
s
1 .168 0 r
.48929 .50086 m
.48917 .50066 L
s
.48917 .50066 m
.4893 .49941 L
s
.48917 .50066 m
.48805 .50002 L
s
1 .002 0 r
.38582 .76284 m
.38583 .76284 L
s
.38583 .76282 m
.38582 .76284 L
s
.38584 .76283 m
.38582 .76284 L
s
.38583 .76283 m
.38583 .76282 L
s
.38583 .76282 m
.38584 .76283 L
s
.38584 .76283 m
.38583 .76284 L
s
.38583 .76283 m
.38584 .76283 L
s
.38577 .76282 m
.38584 .76283 L
s
.38583 .76284 m
.38583 .76283 L
s
1 .168 0 r
.49427 .50057 m
.48805 .50002 L
s
1 .002 0 r
.44002 .63169 m
.43996 .63168 L
s
.43997 .63169 m
.43997 .63169 L
s
.43997 .63169 m
.43997 .63168 L
s
.43997 .63169 m
.43996 .63168 L
s
.43997 .63168 m
.43997 .63168 L
s
.43997 .63168 m
.43996 .63168 L
s
.43996 .63168 m
.43997 .63169 L
s
.43996 .63168 m
.43997 .63168 L
s
.43997 .63168 m
.43997 .63169 L
s
1 .168 0 r
.4893 .49941 m
.48941 .49961 L
s
.4893 .49941 m
.48805 .50002 L
s
1 .066 0 r
.64447 .52673 m
.64461 .52662 L
s
.64461 .52662 m
.64445 .52615 L
s
.64461 .52662 m
.64401 .52658 L
s
.64445 .52615 m
.6443 .52626 L
s
.64445 .52615 m
.64401 .52658 L
s
.64401 .52658 m
.64447 .52673 L
s
.64401 .52658 m
.6443 .52626 L
s
.64624 .52589 m
.64401 .52658 L
s
.6443 .52626 m
.64447 .52673 L
s
1 .158 0 r
.58435 .50024 m
.58457 .50004 L
s
.58457 .50004 m
.58432 .49888 L
s
.58457 .50004 m
.5832 .49977 L
s
1 .168 0 r
.48805 .50002 m
.48929 .50086 L
s
.48805 .50002 m
.48941 .49961 L
s
1 .158 0 r
.58432 .49888 m
.5841 .49908 L
s
.58432 .49888 m
.5832 .49977 L
s
.5832 .49977 m
.58435 .50024 L
s
.5832 .49977 m
.5841 .49908 L
s
.5889 .49874 m
.5832 .49977 L
s
1 .168 0 r
.48941 .49961 m
.48929 .50086 L
s
1 0 0 r
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
.59196 .65709 m
.59196 .65709 L
s
1 .005 0 r
.38259 .60461 m
.38242 .60456 L
s
.38245 .60459 m
.38244 .60458 L
s
.38244 .60458 m
.38245 .60454 L
s
.38244 .60458 m
.38242 .60456 L
s
.38245 .60454 m
.38247 .60455 L
s
.38245 .60454 m
.38242 .60456 L
s
.38242 .60456 m
.38245 .60459 L
s
.38242 .60456 m
.38247 .60455 L
s
.38247 .60455 m
.38245 .60459 L
s
1 .158 0 r
.5841 .49908 m
.58435 .50024 L
s
1 .003 0 r
.48035 .76128 m
.48035 .76128 L
s
.48035 .76126 m
.48035 .76128 L
s
.48037 .76127 m
.48035 .76128 L
s
.48036 .76127 m
.48035 .76126 L
s
.48035 .76126 m
.48037 .76127 L
s
1 .002 0 r
.53452 .63001 m
.53452 .63001 L
s
.53452 .63001 m
.53452 .62999 L
s
.53452 .63001 m
.53451 .63 L
s
1 .003 0 r
.48037 .76127 m
.48035 .76128 L
s
.48036 .76127 m
.48037 .76127 L
s
.48028 .76127 m
.48037 .76127 L
s
1 .002 0 r
.53452 .62999 m
.53452 .63 L
s
.53452 .62999 m
.53451 .63 L
s
.53451 .63 m
.53452 .63001 L
s
.53451 .63 m
.53452 .63 L
s
.53459 .63 m
.53451 .63 L
s
1 .01 0 r
.32511 .5775 m
.32481 .57737 L
s
1 .003 0 r
.48035 .76128 m
.48036 .76127 L
s
1 .002 0 r
.53452 .63 m
.53452 .63001 L
s
1 .01 0 r
.32487 .57744 m
.32484 .57742 L
s
.32484 .57742 m
.32487 .57735 L
s
.32484 .57742 m
.32481 .57737 L
s
.32487 .57735 m
.3249 .57737 L
s
.32487 .57735 m
.32481 .57737 L
s
.3249 .57737 m
.32487 .57744 L
s
.32481 .57737 m
.32487 .57744 L
s
.32481 .57737 m
.3249 .57737 L
s
1 .034 0 r
.74011 .5246 m
.74031 .52465 L
s
.74029 .52435 m
.74011 .5246 L
s
.74011 .5246 m
.74018 .52442 L
s
.74042 .52457 m
.74011 .5246 L
s
.74108 .52409 m
.74011 .5246 L
s
.74029 .52435 m
.74018 .52442 L
s
.74042 .52457 m
.74029 .52435 L
s
.74031 .52465 m
.74042 .52457 L
s
.74018 .52442 m
.74031 .52465 L
s
1 .091 0 r
.68092 .49814 m
.6815 .49828 L
s
.68146 .4975 m
.68092 .49814 L
s
.68092 .49814 m
.6812 .49766 L
s
.68176 .49812 m
.68092 .49814 L
s
.68372 .4969 m
.68092 .49814 L
s
.6815 .49828 m
.68176 .49812 L
s
.68176 .49812 m
.68146 .4975 L
s
.68146 .4975 m
.6812 .49766 L
s
1 .001 0 r
.42283 .73423 m
.42283 .73423 L
s
.42283 .73422 m
.42283 .73423 L
s
.42284 .73423 m
.42283 .73423 L
s
.42284 .73422 m
.42283 .73422 L
s
.42283 .73422 m
.42284 .73423 L
s
.42284 .73423 m
.42283 .73423 L
s
.42284 .73422 m
.42284 .73423 L
s
.42281 .73422 m
.42284 .73423 L
s
.42283 .73423 m
.42284 .73422 L
s
1 .008 0 r
.47715 .60289 m
.47684 .60286 L
s
.4769 .6029 m
.4769 .60289 L
s
.4769 .60289 m
.4769 .60283 L
s
.4769 .60289 m
.47684 .60286 L
s
.4769 .60283 m
.47691 .60284 L
s
.4769 .60283 m
.47684 .60286 L
s
.47684 .60286 m
.4769 .6029 L
s
.47684 .60286 m
.47691 .60284 L
s
.47691 .60284 m
.4769 .6029 L
s
1 .091 0 r
.6812 .49766 m
.6815 .49828 L
s
1 .002 0 r
.6293 .62832 m
.6293 .62832 L
s
.6293 .62832 m
.6293 .62831 L
s
.6293 .62832 m
.62929 .62832 L
s
.6293 .62831 m
.6293 .62831 L
s
.6293 .62831 m
.62929 .62832 L
s
.62929 .62832 m
.6293 .62832 L
s
.62929 .62832 m
.6293 .62831 L
s
.62935 .62831 m
.62929 .62832 L
s
.6293 .62831 m
.6293 .62832 L
s
1 0 0 r
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
.36528 .70715 m
.36528 .70715 L
s
1 .018 0 r
.41965 .57575 m
.419 .57559 L
s
.41913 .57571 m
.4191 .57568 L
s
.4191 .57568 m
.41913 .57554 L
s
.4191 .57568 m
.419 .57559 L
s
.41913 .57554 m
.41917 .57557 L
s
.41913 .57554 m
.419 .57559 L
s
.419 .57559 m
.41913 .57571 L
s
.419 .57559 m
.41917 .57557 L
s
.41917 .57557 m
.41913 .57571 L
s
1 .009 0 r
.57165 .60123 m
.57165 .60121 L
s
.57165 .60121 m
.57164 .60115 L
s
.57165 .60121 m
.57158 .60119 L
s
.57164 .60115 m
.57164 .60116 L
s
.57164 .60115 m
.57158 .60119 L
s
.57158 .60119 m
.57165 .60123 L
s
.57158 .60119 m
.57164 .60116 L
s
.5719 .60116 m
.57158 .60119 L
s
.57164 .60116 m
.57165 .60123 L
s
1 .001 0 r
.51754 .73264 m
.51754 .73264 L
s
.51754 .73263 m
.51754 .73264 L
s
.51754 .73264 m
.51754 .73264 L
s
.51754 .73264 m
.51754 .73263 L
s
.51754 .73263 m
.51754 .73264 L
s
.51754 .73264 m
.51754 .73264 L
s
.51754 .73264 m
.51754 .73264 L
s
.51751 .73264 m
.51754 .73264 L
s
1 .028 0 r
.36209 .54857 m
.36119 .54823 L
s
1 .001 0 r
.51754 .73264 m
.51754 .73264 L
s
1 .043 0 r
.77764 .49581 m
.77787 .49584 L
s
.77785 .49547 m
.77764 .49581 L
s
.77764 .49581 m
.77769 .49557 L
s
.77803 .49574 m
.77764 .49581 L
s
.77874 .49506 m
.77764 .49581 L
s
1 .028 0 r
.36136 .54842 m
.36129 .54837 L
s
.36129 .54837 m
.36137 .54817 L
s
.36129 .54837 m
.36119 .54823 L
s
.36137 .54817 m
.36145 .54822 L
s
.36137 .54817 m
.36119 .54823 L
s
1 .043 0 r
.77785 .49547 m
.77769 .49557 L
s
.77803 .49574 m
.77785 .49547 L
s
.77787 .49584 m
.77803 .49574 L
s
1 .028 0 r
.36145 .54822 m
.36136 .54842 L
s
.36119 .54823 m
.36136 .54842 L
s
.36119 .54823 m
.36145 .54822 L
s
1 .043 0 r
.77769 .49557 m
.77787 .49584 L
s
1 .011 0 r
.40585 .83715 m
.40586 .83718 L
s
.40586 .83707 m
.40585 .83715 L
s
.40594 .83713 m
.40585 .83715 L
s
.40588 .8371 m
.40586 .83707 L
s
.40586 .83707 m
.40594 .83713 L
s
.40594 .83713 m
.40586 .83718 L
s
.40588 .8371 m
.40594 .83713 L
s
.40554 .83708 m
.40594 .83713 L
s
1 .026 0 r
.51361 .57409 m
.5136 .57405 L
s
.5136 .57405 m
.51361 .57386 L
s
.5136 .57405 m
.51341 .57397 L
s
.51361 .57386 m
.51361 .57389 L
s
.51361 .57386 m
.51341 .57397 L
s
1 .011 0 r
.40586 .83718 m
.40588 .8371 L
s
1 0 0 r
.45997 .70554 m
.45997 .70554 L
s
.45997 .70553 m
.45997 .70554 L
s
.45997 .70554 m
.45997 .70554 L
s
.45997 .70554 m
.45997 .70553 L
s
.45997 .70553 m
.45997 .70554 L
s
.45997 .70554 m
.45997 .70554 L
s
.45997 .70554 m
.45997 .70554 L
s
.45997 .70554 m
.45997 .70554 L
s
.45997 .70554 m
.45997 .70554 L
s
1 .026 0 r
.51439 .57399 m
.51341 .57397 L
s
1 .034 0 r
.30447 .52137 m
.30351 .52085 L
s
1 .026 0 r
.51341 .57397 m
.51361 .57409 L
s
.51341 .57397 m
.51361 .57389 L
s
.51361 .57389 m
.51361 .57409 L
s
1 .034 0 r
.30371 .5208 m
.30382 .52088 L
s
.30358 .52102 m
.30371 .5208 L
s
.30371 .5208 m
.30351 .52085 L
s
.30369 .5211 m
.30358 .52102 L
s
.30358 .52102 m
.30351 .52085 L
s
.30382 .52088 m
.30369 .5211 L
s
.30351 .52085 m
.30382 .52088 L
s
.30351 .52085 m
.30369 .5211 L
s
1 .006 0 r
.6667 .59951 m
.66671 .5995 L
s
.66671 .5995 m
.6667 .59946 L
s
.66671 .5995 m
.66666 .59949 L
s
.6667 .59946 m
.66668 .59947 L
s
.6667 .59946 m
.66666 .59949 L
s
.66666 .59949 m
.6667 .59951 L
s
.66666 .59949 m
.66668 .59947 L
s
.66686 .59944 m
.66666 .59949 L
s
.66668 .59947 m
.6667 .59951 L
s
1 .052 0 r
.45682 .54679 m
.45494 .54647 L
s
1 0 0 r
.40237 .6784 m
.40237 .6784 L
s
1 .052 0 r
.45531 .54676 m
.45524 .54669 L
s
.45524 .54669 m
.45532 .54631 L
s
.45524 .54669 m
.45494 .54647 L
s
.45532 .54631 m
.45539 .54638 L
s
.45532 .54631 m
.45494 .54647 L
s
.45494 .54647 m
.45531 .54676 L
s
.45494 .54647 m
.45539 .54638 L
s
.45539 .54638 m
.45531 .54676 L
s
1 .022 0 r
.6087 .57246 m
.60873 .57242 L
s
.60873 .57242 m
.60869 .57226 L
s
.60873 .57242 m
.60853 .57239 L
s
.60869 .57226 m
.60866 .57229 L
s
.60869 .57226 m
.60853 .57239 L
s
.60853 .57239 m
.6087 .57246 L
s
.60853 .57239 m
.60866 .57229 L
s
.60933 .57223 m
.60853 .57239 L
s
.60866 .57229 m
.6087 .57246 L
s
1 0 0 r
.55486 .70392 m
.55486 .70392 L
s
.55486 .70392 m
.55486 .70392 L
s
.55486 .70392 m
.55486 .70392 L
s
.55486 .70392 m
.55486 .70392 L
s
.55486 .70392 m
.55486 .70392 L
s
.55485 .70392 m
.55486 .70392 L
s
1 .073 0 r
.39919 .51956 m
.39676 .51874 L
s
1 0 0 r
.34471 .65124 m
.3447 .65124 L
s
.55486 .70392 m
.55486 .70392 L
s
.55486 .70392 m
.55486 .70392 L
s
.55486 .70392 m
.55486 .70392 L
s
.3447 .65124 m
.3447 .65124 L
s
.3447 .65124 m
.3447 .65124 L
s
.3447 .65124 m
.3447 .65124 L
s
.3447 .65124 m
.3447 .65124 L
s
.3447 .65124 m
.3447 .65124 L
s
.3447 .65124 m
.3447 .65124 L
s
.3447 .65124 m
.3447 .65124 L
s
.3447 .65124 m
.3447 .65124 L
s
1 .073 0 r
.39723 .51923 m
.39706 .5191 L
s
.39706 .5191 m
.39726 .51859 L
s
.39706 .5191 m
.39676 .51874 L
s
.39726 .51859 m
.39743 .51871 L
s
.39726 .51859 m
.39676 .51874 L
s
1 .062 0 r
.54991 .5454 m
.54994 .54532 L
s
.54994 .54532 m
.54991 .54485 L
s
.54994 .54532 m
.54945 .54516 L
s
.54991 .54485 m
.54987 .54494 L
s
.54991 .54485 m
.54945 .54516 L
s
.54945 .54516 m
.54991 .5454 L
s
.54945 .54516 m
.54987 .54494 L
s
.55175 .545 m
.54945 .54516 L
s
1 .073 0 r
.39676 .51874 m
.39723 .51923 L
s
.39676 .51874 m
.39743 .51871 L
s
.39743 .51871 m
.39723 .51923 L
s
1 .009 0 r
.44298 .80856 m
.44299 .80858 L
s
.44299 .80849 m
.44298 .80856 L
s
.44305 .80854 m
.44298 .80856 L
s
.44299 .80851 m
.44299 .80849 L
s
.44299 .80849 m
.44305 .80854 L
s
.44305 .80854 m
.44299 .80858 L
s
.44299 .80851 m
.44305 .80854 L
s
.44273 .80851 m
.44305 .80854 L
s
.44299 .80858 m
.44299 .80851 L
s
1 0 0 r
.49724 .67676 m
.49724 .67676 L
s
1 .08 0 r
.34149 .4923 m
.33917 .49108 L
s
1 .062 0 r
.54987 .54494 m
.54991 .5454 L
s
1 .013 0 r
.70408 .57063 m
.70416 .57066 L
s
.70416 .57054 m
.70408 .57063 L
s
.70408 .57063 m
.70412 .57057 L
s
.7042 .57063 m
.70408 .57063 L
s
.70448 .57047 m
.70408 .57063 L
s
.70416 .57066 m
.7042 .57063 L
s
.7042 .57063 m
.70416 .57054 L
s
.70416 .57054 m
.70412 .57057 L
s
1 .08 0 r
.33966 .49098 m
.33991 .49114 L
s
.33936 .49151 m
.33966 .49098 L
s
.33966 .49098 m
.33917 .49108 L
s
.33962 .49167 m
.33936 .49151 L
s
.33936 .49151 m
.33917 .49108 L
s
1 .013 0 r
.70412 .57057 m
.70416 .57066 L
s
1 .121 0 r
.49049 .51796 m
.49041 .51781 L
s
.49041 .51781 m
.4905 .5169 L
s
.49041 .51781 m
.48959 .51735 L
s
1 .005 0 r
.38515 .78143 m
.38516 .78144 L
s
.38516 .78139 m
.38515 .78143 L
s
.38519 .78142 m
.38515 .78143 L
s
.38517 .7814 m
.38516 .78139 L
s
.38516 .78139 m
.38519 .78142 L
s
.38519 .78142 m
.38516 .78144 L
s
.38517 .7814 m
.38519 .78142 L
s
.38503 .78139 m
.38519 .78142 L
s
.38516 .78144 m
.38517 .7814 L
s
1 0 0 r
.43957 .64957 m
.43956 .64956 L
s
1 .121 0 r
.49411 .51774 m
.48959 .51735 L
s
1 0 0 r
.43956 .64957 m
.43956 .64957 L
s
.43956 .64957 m
.43956 .64956 L
s
.43956 .64957 m
.43956 .64956 L
s
.43956 .64956 m
.43956 .64956 L
s
.43956 .64956 m
.43956 .64956 L
s
.43956 .64956 m
.43956 .64957 L
s
.43956 .64956 m
.43956 .64956 L
s
.43956 .64956 m
.43956 .64957 L
s
1 .121 0 r
.4905 .5169 m
.49058 .51705 L
s
.4905 .5169 m
.48959 .51735 L
s
1 .08 0 r
.33991 .49114 m
.33962 .49167 L
s
.33917 .49108 m
.33991 .49114 L
s
.33917 .49108 m
.33962 .49167 L
s
1 .121 0 r
.48959 .51735 m
.49049 .51796 L
s
.48959 .51735 m
.49058 .51705 L
s
1 .042 0 r
.64575 .54375 m
.64584 .54367 L
s
.64584 .54367 m
.64574 .54337 L
s
.64584 .54367 m
.64546 .54365 L
s
.64574 .54337 m
.64565 .54344 L
s
.64574 .54337 m
.64546 .54365 L
s
.64546 .54365 m
.64575 .54375 L
s
.64546 .54365 m
.64565 .54344 L
s
.64689 .54321 m
.64546 .54365 L
s
1 .121 0 r
.49058 .51705 m
.49049 .51796 L
s
1 .042 0 r
.64565 .54344 m
.64575 .54375 L
s
1 .114 0 r
.58594 .51701 m
.5861 .51685 L
s
.5861 .51685 m
.58593 .51601 L
s
.5861 .51685 m
.58511 .51666 L
s
1 0 0 r
.59232 .6751 m
.59232 .6751 L
s
1 .168 0 r
.43641 .49045 m
.43058 .48889 L
s
1 .002 0 r
.38184 .62235 m
.38178 .62233 L
s
.38179 .62234 m
.38179 .62234 L
s
.38179 .62234 m
.38179 .62233 L
s
.38179 .62234 m
.38178 .62233 L
s
.38179 .62233 m
.3818 .62233 L
s
.38179 .62233 m
.38178 .62233 L
s
.38178 .62233 m
.38179 .62234 L
s
.38178 .62233 m
.3818 .62233 L
s
.3818 .62233 m
.38179 .62234 L
s
1 .114 0 r
.58593 .51601 m
.58577 .51617 L
s
.58593 .51601 m
.58511 .51666 L
s
.58511 .51666 m
.58594 .51701 L
s
.58511 .51666 m
.58577 .51617 L
s
.58923 .51592 m
.58511 .51666 L
s
.58577 .51617 m
.58594 .51701 L
s
1 .168 0 r
.43172 .48993 m
.43139 .48969 L
s
.43139 .48969 m
.43177 .48847 L
s
.43139 .48969 m
.43058 .48889 L
s
.43177 .48847 m
.4321 .48871 L
s
.43177 .48847 m
.43058 .48889 L
s
1 .006 0 r
.48021 .77988 m
.48022 .77989 L
s
.48022 .77983 m
.48021 .77988 L
s
.48026 .77986 m
.48021 .77988 L
s
.48022 .77984 m
.48022 .77983 L
s
.48022 .77983 m
.48026 .77986 L
s
.48026 .77986 m
.48022 .77989 L
s
.48022 .77984 m
.48026 .77986 L
s
.48004 .77985 m
.48026 .77986 L
s
1 0 0 r
.53463 .64789 m
.53463 .64789 L
s
.53463 .64789 m
.53463 .64788 L
s
.53463 .64789 m
.53463 .64789 L
s
.53463 .64788 m
.53463 .64788 L
s
.53463 .64788 m
.53463 .64789 L
s
.53463 .64789 m
.53463 .64789 L
s
.53463 .64789 m
.53463 .64788 L
s
.53464 .64789 m
.53463 .64789 L
s
1 .004 0 r
.32404 .5951 m
.32391 .59504 L
s
1 0 0 r
.53463 .64788 m
.53463 .64789 L
s
1 .006 0 r
.48022 .77989 m
.48022 .77984 L
s
1 .004 0 r
.32394 .59507 m
.32392 .59507 L
s
.32392 .59507 m
.32394 .59504 L
s
.32392 .59507 m
.32391 .59504 L
s
.32394 .59504 m
.32395 .59505 L
s
.32394 .59504 m
.32391 .59504 L
s
1 .233 0 r
.5245 .48975 m
.52454 .48948 L
s
.52454 .48948 m
.5245 .48773 L
s
.52454 .48948 m
.52274 .48877 L
s
1 .004 0 r
.32395 .59505 m
.32394 .59507 L
s
.32391 .59504 m
.32394 .59507 L
s
.32391 .59504 m
.32395 .59505 L
s
1 .233 0 r
.5245 .48773 m
.52446 .48799 L
s
.5245 .48773 m
.52274 .48877 L
s
1 .021 0 r
.74162 .54173 m
.74175 .54176 L
s
.74173 .54158 m
.74162 .54173 L
s
.74162 .54173 m
.74167 .54162 L
s
.74181 .54172 m
.74162 .54173 L
s
.74222 .54142 m
.74162 .54173 L
s
.74173 .54158 m
.74167 .54162 L
s
.74181 .54172 m
.74173 .54158 L
s
.74175 .54176 m
.74181 .54172 L
s
1 .168 0 r
.43058 .48889 m
.43172 .48993 L
s
.43058 .48889 m
.4321 .48871 L
s
1 .021 0 r
.74167 .54162 m
.74175 .54176 L
s
1 .168 0 r
.4321 .48871 m
.43172 .48993 L
s
1 .233 0 r
.52274 .48877 m
.5245 .48975 L
s
.52274 .48877 m
.52446 .48799 L
s
.53152 .4886 m
.52274 .48877 L
s
1 .168 0 r
.62232 .48891 m
.6227 .48865 L
s
.6227 .48865 m
.62228 .48745 L
s
.6227 .48865 m
.62117 .48854 L
s
1 .003 0 r
.42234 .75269 m
.42234 .7527 L
s
.42235 .75267 m
.42234 .75269 L
s
.42237 .75269 m
.42234 .75269 L
s
.42235 .75268 m
.42235 .75267 L
s
.42235 .75267 m
.42237 .75269 L
s
.42237 .75269 m
.42234 .7527 L
s
.42235 .75268 m
.42237 .75269 L
s
.42226 .75267 m
.42237 .75269 L
s
.42234 .7527 m
.42235 .75268 L
s
.47689 .62064 m
.4768 .62063 L
s
.47682 .62064 m
.47681 .62064 L
s
.47681 .62064 m
.47682 .62062 L
s
.47681 .62064 m
.4768 .62063 L
s
.47682 .62062 m
.47682 .62062 L
s
.47682 .62062 m
.4768 .62063 L
s
.4768 .62063 m
.47682 .62064 L
s
.4768 .62063 m
.47682 .62062 L
s
.47682 .62062 m
.47682 .62064 L
s
1 .168 0 r
.62228 .48745 m
.6219 .48771 L
s
.62228 .48745 m
.62117 .48854 L
s
1 .063 0 r
.6826 .51495 m
.683 .51506 L
s
.68298 .51451 m
.6826 .51495 L
s
.6826 .51495 m
.6828 .51463 L
s
.68319 .51494 m
.6826 .51495 L
s
.68456 .5141 m
.6826 .51495 L
s
1 .168 0 r
.62117 .48854 m
.62232 .48891 L
s
.62117 .48854 m
.6219 .48771 L
s
.62683 .48675 m
.62117 .48854 L
s
1 .063 0 r
.683 .51506 m
.68319 .51494 L
s
.68319 .51494 m
.68298 .51451 L
s
.68298 .51451 m
.6828 .51463 L
s
.6828 .51463 m
.683 .51506 L
s
1 .233 0 r
.52446 .48799 m
.5245 .48975 L
s
1 .168 0 r
.6219 .48771 m
.62232 .48891 L
s
1 .001 0 r
.36445 .72547 m
.36445 .72547 L
s
.36445 .72546 m
.36445 .72547 L
s
.36446 .72547 m
.36445 .72547 L
s
.36445 .72547 m
.36445 .72546 L
s
.36445 .72546 m
.36446 .72547 L
s
.36446 .72547 m
.36445 .72547 L
s
.36445 .72547 m
.36446 .72547 L
s
.36443 .72546 m
.36446 .72547 L
s
.36445 .72547 m
.36445 .72547 L
s
1 0 0 r
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
.6299 .6462 m
.6299 .6462 L
s
1 .008 0 r
.41909 .59336 m
.4188 .59329 L
s
.41885 .59334 m
.41884 .59333 L
s
.41884 .59333 m
.41885 .59327 L
s
.41884 .59333 m
.4188 .59329 L
s
.41885 .59327 m
.41887 .59328 L
s
.41885 .59327 m
.4188 .59329 L
s
.4188 .59329 m
.41885 .59334 L
s
.4188 .59329 m
.41887 .59328 L
s
.41887 .59328 m
.41885 .59334 L
s
1 .003 0 r
.57207 .61894 m
.57207 .61894 L
s
.57207 .61894 m
.57207 .61892 L
s
.57207 .61894 m
.57205 .61893 L
s
.57207 .61892 m
.57207 .61892 L
s
.57207 .61892 m
.57205 .61893 L
s
.51757 .75111 m
.51757 .75111 L
s
.51757 .75108 m
.51757 .75111 L
s
.51759 .7511 m
.51757 .75111 L
s
.57205 .61893 m
.57207 .61894 L
s
.57205 .61893 m
.57207 .61892 L
s
.57215 .61892 m
.57205 .61893 L
s
.51757 .75109 m
.51757 .75108 L
s
.51757 .75108 m
.51759 .7511 L
s
.57207 .61892 m
.57207 .61894 L
s
.51759 .7511 m
.51757 .75111 L
s
.51757 .75109 m
.51759 .7511 L
s
.51746 .7511 m
.51759 .7511 L
s
1 .015 0 r
.36122 .56605 m
.36072 .56586 L
s
1 .003 0 r
.51757 .75111 m
.51757 .75109 L
s
1 .015 0 r
.36082 .56597 m
.36078 .56594 L
s
.36078 .56594 m
.36082 .56583 L
s
.36078 .56594 m
.36072 .56586 L
s
.36082 .56583 m
.36087 .56586 L
s
.36082 .56583 m
.36072 .56586 L
s
.36087 .56586 m
.36082 .56597 L
s
.36072 .56586 m
.36082 .56597 L
s
.36072 .56586 m
.36087 .56586 L
s
1 .029 0 r
.77934 .51277 m
.7795 .51279 L
s
.77948 .51254 m
.77934 .51277 L
s
.77934 .51277 m
.77938 .51261 L
s
.77961 .51272 m
.77934 .51277 L
s
.78009 .51227 m
.77934 .51277 L
s
.77948 .51254 m
.77938 .51261 L
s
.77961 .51272 m
.77948 .51254 L
s
.7795 .51279 m
.77961 .51272 L
s
1 .08 0 r
.72015 .4862 m
.72061 .48628 L
s
.72057 .48559 m
.72015 .4862 L
s
.72015 .4862 m
.72029 .48576 L
s
.72088 .48611 m
.72015 .4862 L
s
.72235 .48489 m
.72015 .4862 L
s
1 .029 0 r
.77938 .51261 m
.7795 .51279 L
s
1 .08 0 r
.72057 .48559 m
.72029 .48576 L
s
.72088 .48611 m
.72057 .48559 L
s
.72061 .48628 m
.72088 .48611 L
s
1 .017 0 r
.40537 .85621 m
.40539 .85625 L
s
.40539 .85609 m
.40537 .85621 L
s
.40551 .85619 m
.40537 .85621 L
s
.40541 .85613 m
.40539 .85609 L
s
.40539 .85609 m
.40551 .85619 L
s
.40551 .85619 m
.40539 .85625 L
s
.40541 .85613 m
.40551 .85619 L
s
.4049 .8561 m
.40551 .85619 L
s
.40539 .85625 m
.40541 .85613 L
s
1 .012 0 r
.51398 .59166 m
.51397 .59164 L
s
.51397 .59164 m
.51398 .59155 L
s
.51397 .59164 m
.51389 .5916 L
s
.51398 .59155 m
.51398 .59157 L
s
.51398 .59155 m
.51389 .5916 L
s
1 .001 0 r
.45965 .72387 m
.45965 .72387 L
s
.45965 .72386 m
.45965 .72387 L
s
.45966 .72386 m
.45965 .72387 L
s
.45965 .72386 m
.45965 .72386 L
s
.45965 .72386 m
.45966 .72386 L
s
.45966 .72386 m
.45965 .72387 L
s
.45965 .72386 m
.45966 .72386 L
s
.45962 .72386 m
.45966 .72386 L
s
.45965 .72387 m
.45965 .72386 L
s
1 .012 0 r
.51433 .59161 m
.51389 .5916 L
s
1 .021 0 r
.30329 .53872 m
.30269 .53839 L
s
1 .012 0 r
.51389 .5916 m
.51398 .59166 L
s
.51389 .5916 m
.51398 .59157 L
s
.51398 .59157 m
.51398 .59166 L
s
1 .08 0 r
.72029 .48576 m
.72061 .48628 L
s
1 .021 0 r
.30282 .53836 m
.30289 .53841 L
s
.30274 .5385 m
.30282 .53836 L
s
.30282 .53836 m
.30269 .53839 L
s
.30281 .53855 m
.30274 .5385 L
s
.30274 .5385 m
.30269 .53839 L
s
.30289 .53841 m
.30281 .53855 L
s
.30269 .53839 m
.30289 .53841 L
s
.30269 .53839 m
.30281 .53855 L
s
1 .002 0 r
.66756 .61723 m
.66757 .61722 L
s
.66757 .61722 m
.66756 .61721 L
s
.66757 .61722 m
.66755 .61722 L
s
.66756 .61721 m
.66756 .61721 L
s
.66756 .61721 m
.66755 .61722 L
s
.66755 .61722 m
.66756 .61723 L
s
.66755 .61722 m
.66756 .61721 L
s
.66761 .6172 m
.66755 .61722 L
s
.66756 .61721 m
.66756 .61723 L
s
1 0 0 r
.40171 .69659 m
.40172 .69659 L
s
.40172 .69659 m
.40171 .69659 L
s
.40172 .69659 m
.40171 .69659 L
s
.40172 .69659 m
.40172 .69659 L
s
.40172 .69659 m
.40172 .69659 L
s
.40172 .69659 m
.40172 .69659 L
s
.40172 .69659 m
.40172 .69659 L
s
.40171 .69659 m
.40172 .69659 L
s
.40172 .69659 m
.40172 .69659 L
s
1 .029 0 r
.45645 .56428 m
.45539 .5641 L
s
.4556 .56426 m
.45556 .56422 L
s
.45556 .56422 m
.45561 .56401 L
s
.45556 .56422 m
.45539 .5641 L
s
.45561 .56401 m
.45565 .56405 L
s
.45561 .56401 m
.45539 .5641 L
s
.45539 .5641 m
.4556 .56426 L
s
.45539 .5641 m
.45565 .56405 L
s
.45565 .56405 m
.4556 .56426 L
s
1 .01 0 r
.60949 .58997 m
.60951 .58995 L
s
.60951 .58995 m
.60949 .58988 L
s
.60951 .58995 m
.60942 .58994 L
s
.60949 .58988 m
.60948 .58989 L
s
.60949 .58988 m
.60942 .58994 L
s
.60942 .58994 m
.60949 .58997 L
s
.60942 .58994 m
.60948 .58989 L
s
.60978 .58987 m
.60942 .58994 L
s
.60948 .58989 m
.60949 .58997 L
s
1 .001 0 r
.55505 .72225 m
.55505 .72226 L
s
.55505 .72224 m
.55505 .72225 L
s
.55506 .72225 m
.55505 .72225 L
s
.55505 .72225 m
.55505 .72224 L
s
.55505 .72224 m
.55506 .72225 L
s
.55501 .72225 m
.55506 .72225 L
s
1 0 0 r
.34374 .6693 m
.34374 .6693 L
s
1 .047 0 r
.39852 .53691 m
.39696 .53639 L
s
1 .001 0 r
.55506 .72225 m
.55505 .72226 L
s
.55505 .72225 m
.55506 .72225 L
s
.55505 .72226 m
.55505 .72225 L
s
1 .035 0 r
.81727 .48369 m
.81745 .48371 L
s
.81742 .48341 m
.81727 .48369 L
s
.81727 .48369 m
.81728 .4835 L
s
.81758 .48362 m
.81727 .48369 L
s
.81808 .48303 m
.81727 .48369 L
s
1 .047 0 r
.39726 .5367 m
.39715 .53662 L
s
.39715 .53662 m
.39728 .53629 L
s
.39715 .53662 m
.39696 .53639 L
s
1 .035 0 r
.81742 .48341 m
.81728 .4835 L
s
.81758 .48362 m
.81742 .48341 L
s
1 .047 0 r
.39728 .53629 m
.39739 .53637 L
s
.39728 .53629 m
.39696 .53639 L
s
1 .035 0 r
.81745 .48371 m
.81758 .48362 L
s
.81728 .4835 m
.81745 .48371 L
s
1 .047 0 r
.39696 .53639 m
.39726 .5367 L
s
.39696 .53639 m
.39739 .53637 L
s
.39739 .53637 m
.39726 .5367 L
s
1 .035 0 r
.55085 .56272 m
.55087 .56267 L
s
.55087 .56267 m
.55084 .56241 L
s
.55087 .56267 m
.55058 .56259 L
s
.55084 .56241 m
.55083 .56246 L
s
.55084 .56241 m
.55058 .56259 L
s
1 .014 0 r
.4427 .82749 m
.44271 .82753 L
s
.44272 .82739 m
.4427 .82749 L
s
.44282 .82747 m
.4427 .82749 L
s
1 .035 0 r
.55058 .56259 m
.55085 .56272 L
s
.55058 .56259 m
.55083 .56246 L
s
.55189 .5625 m
.55058 .56259 L
s
1 .014 0 r
.44273 .82742 m
.44272 .82739 L
s
.44272 .82739 m
.44282 .82747 L
s
.44282 .82747 m
.44271 .82753 L
s
.44273 .82742 m
.44282 .82747 L
s
.44229 .82741 m
.44282 .82747 L
s
.44271 .82753 m
.44273 .82742 L
s
1 0 0 r
.4971 .69496 m
.4971 .69496 L
s
.4971 .69496 m
.4971 .69496 L
s
.4971 .69496 m
.4971 .69496 L
s
.4971 .69496 m
.4971 .69496 L
s
.4971 .69496 m
.4971 .69496 L
s
.4971 .69496 m
.4971 .69496 L
s
.4971 .69496 m
.4971 .69496 L
s
.49709 .69496 m
.4971 .69496 L
s
1 .055 0 r
.34051 .50952 m
.33889 .50868 L
s
1 0 0 r
.4971 .69496 m
.4971 .69496 L
s
1 .035 0 r
.55083 .56246 m
.55085 .56272 L
s
1 .055 0 r
.33923 .5086 m
.33941 .50872 L
s
.33903 .50897 m
.33923 .5086 L
s
.33923 .5086 m
.33889 .50868 L
s
.3392 .50909 m
.33903 .50897 L
s
.33903 .50897 m
.33889 .50868 L
s
.33941 .50872 m
.3392 .50909 L
s
.33889 .50868 m
.33941 .50872 L
s
.33889 .50868 m
.3392 .50909 L
s
1 .009 0 r
.38451 .80023 m
.38453 .80025 L
s
.38453 .80016 m
.38451 .80023 L
s
.38459 .80022 m
.38451 .80023 L
s
.38454 .80018 m
.38453 .80016 L
s
.38453 .80016 m
.38459 .80022 L
s
1 .006 0 r
.70526 .58819 m
.7053 .5882 L
s
.70529 .58815 m
.70526 .58819 L
s
.70526 .58819 m
.70528 .58816 L
s
.70531 .58818 m
.70526 .58819 L
s
.70544 .58811 m
.70526 .58819 L
s
.7053 .5882 m
.70531 .58818 L
s
.70531 .58818 m
.70529 .58815 L
s
.70529 .58815 m
.70528 .58816 L
s
1 .009 0 r
.38459 .80022 m
.38453 .80025 L
s
.38454 .80018 m
.38459 .80022 L
s
.38428 .80016 m
.38459 .80022 L
s
1 .006 0 r
.70528 .58816 m
.7053 .5882 L
s
1 .08 0 r
.49155 .53525 m
.4915 .53514 L
s
.4915 .53514 m
.49156 .53455 L
s
.4915 .53514 m
.49096 .53485 L
s
1 .009 0 r
.38453 .80025 m
.38454 .80018 L
s
1 0 0 r
.43911 .66763 m
.43911 .66763 L
s
1 .08 0 r
.49394 .5351 m
.49096 .53485 L
s
1 .055 0 r
.28245 .48209 m
.28107 .4811 L
s
1 .08 0 r
.49156 .53455 m
.49161 .53465 L
s
.49156 .53455 m
.49096 .53485 L
s
.49096 .53485 m
.49155 .53525 L
s
.49096 .53485 m
.49161 .53465 L
s
.49161 .53465 m
.49155 .53525 L
s
1 .023 0 r
.6469 .56101 m
.64695 .56097 L
s
.64695 .56097 m
.6469 .56081 L
s
.64695 .56097 m
.64674 .56096 L
s
1 .055 0 r
.28137 .48106 m
.28157 .48119 L
s
.28112 .4814 m
.28137 .48106 L
s
.28137 .48106 m
.28107 .4811 L
s
1 .023 0 r
.6469 .56081 m
.64684 .56085 L
s
.6469 .56081 m
.64674 .56096 L
s
.64674 .56096 m
.6469 .56101 L
s
.64674 .56096 m
.64684 .56085 L
s
.64754 .56072 m
.64674 .56096 L
s
1 .055 0 r
.28133 .48153 m
.28112 .4814 L
s
.28112 .4814 m
.28107 .4811 L
s
1 .023 0 r
.64684 .56085 m
.6469 .56101 L
s
1 .055 0 r
.28157 .48119 m
.28133 .48153 L
s
.28107 .4811 m
.28157 .48119 L
s
.28107 .4811 m
.28133 .48153 L
s
1 0 0 r
.59268 .69332 m
.59268 .69331 L
s
.38107 .64028 m
.38106 .64027 L
s
1 .121 0 r
.43593 .50768 m
.4317 .50655 L
s
1 0 0 r
.59268 .69332 m
.59268 .69332 L
s
.59268 .69331 m
.59268 .69332 L
s
.59268 .69331 m
.59268 .69332 L
s
.59268 .69331 m
.59268 .69331 L
s
.59268 .69331 m
.59268 .69331 L
s
.59268 .69331 m
.59268 .69332 L
s
.59268 .69331 m
.59268 .69331 L
s
.38106 .64028 m
.38106 .64028 L
s
.38106 .64028 m
.38106 .64027 L
s
.38106 .64028 m
.38106 .64027 L
s
.59268 .69332 m
.59268 .69331 L
s
.38106 .64027 m
.38106 .64027 L
s
.38106 .64027 m
.38106 .64027 L
s
.38106 .64027 m
.38106 .64028 L
s
.38106 .64027 m
.38106 .64027 L
s
.38106 .64027 m
.38106 .64028 L
s
1 .075 0 r
.58741 .534 m
.58752 .5339 L
s
.58752 .5339 m
.5874 .53335 L
s
.58752 .5339 m
.58686 .53377 L
s
.5874 .53335 m
.5873 .53345 L
s
.5874 .53335 m
.58686 .53377 L
s
.58686 .53377 m
.58741 .534 L
s
.58686 .53377 m
.5873 .53345 L
s
.58958 .53329 m
.58686 .53377 L
s
1 .121 0 r
.43253 .50731 m
.43229 .50713 L
s
.43229 .50713 m
.43256 .50625 L
s
.43229 .50713 m
.4317 .50655 L
s
.43256 .50625 m
.4328 .50643 L
s
.43256 .50625 m
.4317 .50655 L
s
1 .075 0 r
.5873 .53345 m
.58741 .534 L
s
1 .011 0 r
.48013 .79868 m
.48013 .7987 L
s
.48013 .7986 m
.48013 .79868 L
s
.48022 .79865 m
.48013 .79868 L
s
.48014 .79862 m
.48013 .7986 L
s
.48013 .7986 m
.48022 .79865 L
s
.48022 .79865 m
.48013 .7987 L
s
.48014 .79862 m
.48022 .79865 L
s
.4798 .79863 m
.48022 .79865 L
s
1 0 0 r
.53469 .66596 m
.53469 .66596 L
s
1 .134 0 r
.37786 .48022 m
.3738 .47829 L
s
1 .001 0 r
.32297 .61289 m
.32293 .61288 L
s
1 .011 0 r
.48013 .7987 m
.48014 .79862 L
s
1 .001 0 r
.32293 .61288 m
.32293 .61288 L
s
.32293 .61288 m
.32293 .61287 L
s
.32293 .61288 m
.32293 .61288 L
s
.32293 .61287 m
.32294 .61288 L
s
.32293 .61287 m
.32293 .61288 L
s
.32294 .61288 m
.32293 .61288 L
s
.32293 .61288 m
.32293 .61288 L
s
.32293 .61288 m
.32294 .61288 L
s
1 .121 0 r
.4317 .50655 m
.43253 .50731 L
s
.4317 .50655 m
.4328 .50643 L
s
.4328 .50643 m
.43253 .50731 L
s
1 .172 0 r
.52634 .50669 m
.52637 .50648 L
s
.52637 .50648 m
.52634 .50518 L
s
.52637 .50648 m
.52504 .50596 L
s
.52634 .50518 m
.52631 .50539 L
s
.52634 .50518 m
.52504 .50596 L
s
1 .011 0 r
.74306 .5591 m
.74312 .55912 L
s
.74312 .55902 m
.74306 .5591 L
s
.74306 .5591 m
.74308 .55904 L
s
.74316 .55909 m
.74306 .5591 L
s
.74339 .55893 m
.74306 .5591 L
s
.74312 .55902 m
.74308 .55904 L
s
.74316 .55909 m
.74312 .55902 L
s
.74312 .55912 m
.74316 .55909 L
s
1 .172 0 r
.52504 .50596 m
.52634 .50669 L
s
.52504 .50596 m
.52631 .50539 L
s
.53155 .50583 m
.52504 .50596 L
s
1 .011 0 r
.74308 .55904 m
.74312 .55912 L
s
1 .006 0 r
.42189 .77136 m
.4219 .77137 L
s
.4219 .77131 m
.42189 .77136 L
s
.42195 .77135 m
.42189 .77136 L
s
.42191 .77133 m
.4219 .77131 L
s
.4219 .77131 m
.42195 .77135 L
s
.42195 .77135 m
.4219 .77137 L
s
.42191 .77133 m
.42195 .77135 L
s
.42171 .77132 m
.42195 .77135 L
s
.4219 .77137 m
.42191 .77133 L
s
1 0 0 r
.47663 .63858 m
.47662 .63857 L
s
.47662 .63858 m
.47662 .63858 L
s
.47662 .63858 m
.47662 .63857 L
s
.47662 .63858 m
.47662 .63857 L
s
.47662 .63857 m
.47662 .63857 L
s
.47662 .63857 m
.47662 .63857 L
s
.47662 .63857 m
.47662 .63858 L
s
.47662 .63857 m
.47662 .63857 L
s
.47662 .63857 m
.47662 .63858 L
s
1 .134 0 r
.37458 .47926 m
.37417 .47901 L
s
.37417 .47901 m
.37464 .47809 L
s
.37417 .47901 m
.3738 .47829 L
s
.37464 .47809 m
.37504 .47834 L
s
.37464 .47809 m
.3738 .47829 L
s
1 .172 0 r
.52631 .50539 m
.52634 .50669 L
s
1 .04 0 r
.68416 .53202 m
.68442 .53209 L
s
.6844 .53173 m
.68416 .53202 L
s
.68416 .53202 m
.68429 .53181 L
s
.68454 .53201 m
.68416 .53202 L
s
.68541 .53147 m
.68416 .53202 L
s
.68442 .53209 m
.68454 .53201 L
s
.68454 .53201 m
.6844 .53173 L
s
.6844 .53173 m
.68429 .53181 L
s
1 .121 0 r
.6241 .50555 m
.62438 .50536 L
s
.62438 .50536 m
.62407 .50449 L
s
.62438 .50536 m
.62326 .50528 L
s
.62407 .50449 m
.62379 .50468 L
s
.62407 .50449 m
.62326 .50528 L
s
.62326 .50528 m
.6241 .50555 L
s
.62326 .50528 m
.62379 .50468 L
s
.62738 .50399 m
.62326 .50528 L
s
1 .293 0 r
.56067 .47906 m
.56103 .47871 L
s
.56103 .47871 m
.56064 .47652 L
s
.56103 .47871 m
.5585 .47812 L
s
1 .04 0 r
.68429 .53181 m
.68442 .53209 L
s
1 .293 0 r
.56064 .47652 m
.56028 .47688 L
s
.56064 .47652 m
.5585 .47812 L
s
1 .003 0 r
.36364 .744 m
.36364 .744 L
s
.36364 .74398 m
.36364 .744 L
s
.36366 .74399 m
.36364 .744 L
s
.36365 .74398 m
.36364 .74398 L
s
.36364 .74398 m
.36366 .74399 L
s
.36366 .74399 m
.36364 .744 L
s
.36365 .74398 m
.36366 .74399 L
s
.36357 .74397 m
.36366 .74399 L
s
.36364 .744 m
.36365 .74398 L
s
1 .134 0 r
.37504 .47834 m
.37458 .47926 L
s
.3738 .47829 m
.37458 .47926 L
s
1 0 0 r
.63046 .66429 m
.63046 .66429 L
s
1 .271 0 r
.47347 .47835 m
.46358 .4766 L
s
1 .003 0 r
.41852 .61116 m
.41843 .61114 L
s
1 .134 0 r
.3738 .47829 m
.37504 .47834 L
s
1 .003 0 r
.41844 .61116 m
.41844 .61115 L
s
.41844 .61115 m
.41845 .61113 L
s
.41844 .61115 m
.41843 .61114 L
s
.41845 .61113 m
.41845 .61114 L
s
.41845 .61113 m
.41843 .61114 L
s
.41843 .61114 m
.41844 .61116 L
s
.41843 .61114 m
.41845 .61114 L
s
.41845 .61114 m
.41844 .61116 L
s
1 .121 0 r
.62379 .50468 m
.6241 .50555 L
s
1 .293 0 r
.5585 .47812 m
.56067 .47906 L
s
.5585 .47812 m
.56028 .47688 L
s
.56928 .47647 m
.5585 .47812 L
s
1 .271 0 r
.46554 .47813 m
.46517 .47779 L
s
.46517 .47779 m
.46558 .47578 L
s
.46517 .47779 m
.46358 .4766 L
s
.46558 .47578 m
.46595 .47611 L
s
.46558 .47578 m
.46358 .4766 L
s
1 .008 0 r
.51765 .76978 m
.51766 .76979 L
s
.51766 .76972 m
.51765 .76978 L
s
.51771 .76976 m
.51765 .76978 L
s
.51766 .76973 m
.51766 .76972 L
s
.51766 .76972 m
.51771 .76976 L
s
.51771 .76976 m
.51766 .76979 L
s
.51766 .76973 m
.51771 .76976 L
s
.51742 .76975 m
.51771 .76976 L
s
1 0 0 r
.57239 .63687 m
.57239 .63687 L
s
.57239 .63687 m
.57239 .63687 L
s
.57239 .63687 m
.57239 .63687 L
s
.57239 .63687 m
.57239 .63687 L
s
.57239 .63687 m
.57239 .63687 L
s
.57239 .63687 m
.57239 .63687 L
s
.57239 .63687 m
.57239 .63687 L
s
.5724 .63687 m
.57239 .63687 L
s
.57239 .63687 m
.57239 .63687 L
s
1 .007 0 r
.36034 .58372 m
.36012 .58363 L
s
1 .008 0 r
.51766 .76979 m
.51766 .76973 L
s
1 .007 0 r
.36016 .58368 m
.36014 .58367 L
s
.36014 .58367 m
.36016 .58362 L
s
.36014 .58367 m
.36012 .58363 L
s
.36016 .58362 m
.36018 .58363 L
s
.36016 .58362 m
.36012 .58363 L
s
.36018 .58363 m
.36016 .58368 L
s
.36012 .58363 m
.36016 .58368 L
s
.36012 .58363 m
.36018 .58363 L
s
1 .293 0 r
.56028 .47688 m
.56067 .47906 L
s
1 .158 0 r
.66051 .47689 m
.66149 .47712 L
s
.66144 .47574 m
.66051 .47689 L
s
.66051 .47689 m
.66095 .47604 L
s
.66198 .47682 m
.66051 .47689 L
s
.6653 .47459 m
.66051 .47689 L
s
.66149 .47712 m
.66198 .47682 L
s
.66198 .47682 m
.66144 .47574 L
s
.66144 .47574 m
.66095 .47604 L
s
1 .018 0 r
.78099 .52996 m
.78109 .52998 L
s
.78108 .52982 m
.78099 .52996 L
s
.78099 .52996 m
.78101 .52986 L
s
.78116 .52993 m
.78099 .52996 L
s
.78146 .52965 m
.78099 .52996 L
s
.78108 .52982 m
.78101 .52986 L
s
.78116 .52993 m
.78108 .52982 L
s
.78109 .52998 m
.78116 .52993 L
s
.78101 .52986 m
.78109 .52998 L
s
1 .271 0 r
.46358 .4766 m
.46554 .47813 L
s
.46358 .4766 m
.46595 .47611 L
s
1 .004 0 r
.45938 .7424 m
.45938 .74241 L
s
.45938 .74237 m
.45938 .7424 L
s
.45941 .74239 m
.45938 .7424 L
s
.45938 .74238 m
.45938 .74237 L
s
.45938 .74237 m
.45941 .74239 L
s
.45941 .74239 m
.45938 .74241 L
s
.45938 .74238 m
.45941 .74239 L
s
.45927 .74238 m
.45941 .74239 L
s
.51416 .60944 m
.51416 .60943 L
s
.51416 .60943 m
.51416 .60941 L
s
.51416 .60943 m
.51413 .60942 L
s
.51416 .60941 m
.51416 .60941 L
s
.51416 .60941 m
.51413 .60942 L
s
.45938 .74241 m
.45938 .74238 L
s
.51427 .60943 m
.51413 .60942 L
s
1 .011 0 r
.3021 .55624 m
.30178 .55607 L
s
1 .004 0 r
.51413 .60942 m
.51416 .60944 L
s
.51413 .60942 m
.51416 .60941 L
s
.51416 .60941 m
.51416 .60944 L
s
1 .055 0 r
.72187 .50304 m
.72219 .5031 L
s
.72216 .50262 m
.72187 .50304 L
s
.72187 .50304 m
.72197 .50274 L
s
.72238 .50298 m
.72187 .50304 L
s
.72341 .50214 m
.72187 .50304 L
s
.72216 .50262 m
.72197 .50274 L
s
.72238 .50298 m
.72216 .50262 L
s
.72219 .5031 m
.72238 .50298 L
s
1 .011 0 r
.30184 .55605 m
.30188 .55608 L
s
.3018 .55613 m
.30184 .55605 L
s
.30184 .55605 m
.30178 .55607 L
s
.30184 .55615 m
.3018 .55613 L
s
.3018 .55613 m
.30178 .55607 L
s
1 .271 0 r
.46595 .47611 m
.46554 .47813 L
s
1 .011 0 r
.30188 .55608 m
.30184 .55615 L
s
.30178 .55607 m
.30188 .55608 L
s
.30178 .55607 m
.30184 .55615 L
s
1 .055 0 r
.72197 .50274 m
.72219 .5031 L
s
1 .158 0 r
.66095 .47604 m
.66149 .47712 L
s
1 .001 0 r
.40108 .71499 m
.40108 .71499 L
s
.40108 .71498 m
.40108 .71499 L
s
.40109 .71499 m
.40108 .71499 L
s
.40108 .71498 m
.40108 .71498 L
s
.40108 .71498 m
.40109 .71499 L
s
.40109 .71499 m
.40108 .71499 L
s
.40108 .71498 m
.40109 .71499 L
s
.40105 .71498 m
.40109 .71499 L
s
.40108 .71499 m
.40108 .71498 L
s
1 0 0 r
.66837 .63517 m
.66837 .63516 L
s
.66837 .63516 m
.66837 .63516 L
s
.66837 .63516 m
.66837 .63516 L
s
.66837 .63516 m
.66837 .63516 L
s
.66837 .63516 m
.66837 .63516 L
s
.66837 .63516 m
.66837 .63517 L
s
.66837 .63516 m
.66837 .63516 L
s
.66837 .63516 m
.66837 .63516 L
s
.66837 .63516 m
.66837 .63517 L
s
1 .013 0 r
.45609 .58195 m
.4556 .58187 L
s
.4557 .58195 m
.45568 .58193 L
s
.45568 .58193 m
.4557 .58183 L
s
.45568 .58193 m
.4556 .58187 L
s
.4557 .58183 m
.45572 .58185 L
s
.4557 .58183 m
.4556 .58187 L
s
.4556 .58187 m
.4557 .58195 L
s
.4556 .58187 m
.45572 .58185 L
s
.45572 .58185 m
.4557 .58195 L
s
1 .003 0 r
.61015 .60772 m
.61015 .60771 L
s
.61015 .60771 m
.61015 .60769 L
s
.61015 .60771 m
.61012 .60771 L
s
.61015 .60769 m
.61014 .6077 L
s
.61015 .60769 m
.61012 .60771 L
s
.61012 .60771 m
.61015 .60772 L
s
.61012 .60771 m
.61014 .6077 L
s
.61024 .60769 m
.61012 .60771 L
s
.61014 .6077 m
.61015 .60772 L
s
1 .004 0 r
.5553 .74079 m
.5553 .7408 L
s
.5553 .74076 m
.5553 .74079 L
s
.55533 .74078 m
.5553 .74079 L
s
.5553 .74077 m
.5553 .74076 L
s
.5553 .74076 m
.55533 .74078 L
s
1 0 0 r
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
.34277 .68755 m
.34277 .68755 L
s
1 .004 0 r
.55517 .74078 m
.55533 .74078 L
s
1 .026 0 r
.39784 .55445 m
.39696 .55416 L
s
1 .004 0 r
.55533 .74078 m
.5553 .7408 L
s
.5553 .74077 m
.55533 .74078 L
s
.5553 .7408 m
.5553 .74077 L
s
1 .026 0 r
.39713 .55434 m
.39707 .55429 L
s
.39707 .55429 m
.39714 .5541 L
s
.39707 .55429 m
.39696 .55416 L
s
.39714 .5541 m
.3972 .55415 L
s
.39714 .5541 m
.39696 .55416 L
s
.39696 .55416 m
.39713 .55434 L
s
.39696 .55416 m
.3972 .55415 L
s
.3972 .55415 m
.39713 .55434 L
s
1 .023 0 r
.8191 .50073 m
.81922 .50074 L
s
.8192 .50054 m
.8191 .50073 L
s
.8191 .50073 m
.81911 .5006 L
s
.81931 .50068 m
.8191 .50073 L
s
.81965 .50028 m
.8191 .50073 L
s
.8192 .50054 m
.81911 .5006 L
s
.81931 .50068 m
.8192 .50054 L
s
.81922 .50074 m
.81931 .50068 L
s
.81911 .5006 m
.81922 .50074 L
s
1 .066 0 r
.75993 .47393 m
.76027 .47397 L
s
.76023 .4734 m
.75993 .47393 L
s
.75993 .47393 m
.75998 .47356 L
s
.76053 .47381 m
.75993 .47393 L
s
.76153 .47271 m
.75993 .47393 L
s
.76023 .4734 m
.75998 .47356 L
s
.76053 .47381 m
.76023 .4734 L
s
.76027 .47397 m
.76053 .47381 L
s
1 .022 0 r
.44247 .84664 m
.44249 .84669 L
s
.44249 .84648 m
.44247 .84664 L
s
.44265 .8466 m
.44247 .84664 L
s
.44251 .84653 m
.44249 .84648 L
s
.44249 .84648 m
.44265 .8466 L
s
.44265 .8466 m
.44249 .84669 L
s
.44251 .84653 m
.44265 .8466 L
s
.44184 .84652 m
.44265 .8466 L
s
1 .016 0 r
.55155 .58029 m
.55156 .58026 L
s
.55156 .58026 m
.55155 .58014 L
s
.55156 .58026 m
.55143 .58022 L
s
.55155 .58014 m
.55155 .58017 L
s
.55155 .58014 m
.55143 .58022 L
s
.55143 .58022 m
.55155 .58029 L
s
.55143 .58022 m
.55155 .58017 L
s
.55204 .58018 m
.55143 .58022 L
s
1 .022 0 r
.44249 .84669 m
.44251 .84653 L
s
1 .002 0 r
.49699 .71336 m
.49699 .71336 L
s
.49699 .71335 m
.49699 .71336 L
s
.497 .71335 m
.49699 .71336 L
s
.49699 .71335 m
.49699 .71335 L
s
.49699 .71335 m
.497 .71335 L
s
.497 .71335 m
.49699 .71336 L
s
.49699 .71335 m
.497 .71335 L
s
.49694 .71335 m
.497 .71335 L
s
1 .035 0 r
.33952 .52692 m
.33849 .52639 L
s
1 .002 0 r
.49699 .71336 m
.49699 .71335 L
s
1 .016 0 r
.55155 .58017 m
.55155 .58029 L
s
1 .066 0 r
.75998 .47356 m
.76027 .47397 L
s
1 .035 0 r
.33871 .52634 m
.33882 .52641 L
s
.33858 .52658 m
.33871 .52634 L
s
.33871 .52634 m
.33849 .52639 L
s
.33869 .52665 m
.33858 .52658 L
s
.33858 .52658 m
.33849 .52639 L
s
.33882 .52641 m
.33869 .52665 L
s
.33849 .52639 m
.33882 .52641 L
s
.33849 .52639 m
.33869 .52665 L
s
1 .014 0 r
.38391 .81924 m
.38393 .81927 L
s
.38394 .81913 m
.38391 .81924 L
s
.38404 .81922 m
.38391 .81924 L
s
.38396 .81917 m
.38394 .81913 L
s
.38394 .81913 m
.38404 .81922 L
s
.38404 .81922 m
.38393 .81927 L
s
.38396 .81917 m
.38404 .81922 L
s
.38352 .81913 m
.38404 .81922 L
s
.38393 .81927 m
.38396 .81917 L
s
1 .046 0 r
.4924 .55274 m
.49237 .55267 L
s
.49237 .55267 m
.4924 .55233 L
s
.49237 .55267 m
.49206 .5525 L
s
1 .002 0 r
.70635 .60597 m
.70636 .60597 L
s
.70636 .60596 m
.70635 .60597 L
s
.70635 .60597 m
.70636 .60596 L
s
.70637 .60597 m
.70635 .60597 L
s
.7064 .60595 m
.70635 .60597 L
s
.70636 .60597 m
.70637 .60597 L
s
.70637 .60597 m
.70636 .60596 L
s
.70636 .60596 m
.70636 .60596 L
s
.70636 .60596 m
.70636 .60597 L
s
1 0 0 r
.43866 .68589 m
.43866 .68589 L
s
.43866 .68589 m
.43866 .68589 L
s
.43866 .68589 m
.43866 .68589 L
s
.43866 .68589 m
.43866 .68589 L
s
.43866 .68589 m
.43866 .68589 L
s
.43866 .68589 m
.43866 .68589 L
s
.43866 .68589 m
.43866 .68589 L
s
.43865 .68589 m
.43866 .68589 L
s
.43866 .68589 m
.43866 .68589 L
s
1 .046 0 r
.49378 .55265 m
.49206 .5525 L
s
1 .038 0 r
.28115 .49935 m
.2802 .49868 L
s
1 .046 0 r
.4924 .55233 m
.49243 .55239 L
s
.4924 .55233 m
.49206 .5525 L
s
.49206 .5525 m
.4924 .55274 L
s
.49206 .5525 m
.49243 .55239 L
s
.49243 .55239 m
.4924 .55274 L
s
1 .038 0 r
.2804 .49865 m
.28054 .49874 L
s
.28024 .49889 m
.2804 .49865 L
s
.2804 .49865 m
.2802 .49868 L
s
.28038 .49898 m
.28024 .49889 L
s
.28024 .49889 m
.2802 .49868 L
s
.28054 .49874 m
.28038 .49898 L
s
.2802 .49868 m
.28054 .49874 L
s
.2802 .49868 m
.28038 .49898 L
s
1 .011 0 r
.64791 .57854 m
.64793 .57853 L
s
.64793 .57853 m
.6479 .57845 L
s
.64793 .57853 m
.64783 .57852 L
s
.6479 .57845 m
.64788 .57847 L
s
.6479 .57845 m
.64783 .57852 L
s
.64783 .57852 m
.64791 .57854 L
s
.64783 .57852 m
.64788 .57847 L
s
.64819 .57841 m
.64783 .57852 L
s
.64788 .57847 m
.64791 .57854 L
s
1 .002 0 r
.59304 .71172 m
.5931 .71172 L
s
1 0 0 r
.3803 .6584 m
.3803 .6584 L
s
1 .08 0 r
.43545 .52509 m
.43266 .52435 L
s
1 .002 0 r
.59309 .71172 m
.59308 .71172 L
s
.59308 .71171 m
.59309 .71172 L
s
.5931 .71172 m
.59309 .71172 L
s
.59308 .71171 m
.59308 .71171 L
s
.59308 .71171 m
.5931 .71172 L
s
.5931 .71172 m
.59308 .71172 L
s
.59308 .71171 m
.5931 .71172 L
s
.59308 .71172 m
.59308 .71171 L
s
1 .08 0 r
.43321 .52485 m
.43305 .52473 L
s
.43305 .52473 m
.43323 .52415 L
s
.43305 .52473 m
.43266 .52435 L
s
1 .028 0 r
.8574 .47139 m
.85752 .47139 L
s
.8575 .47115 m
.8574 .47139 L
s
.8574 .47139 m
.85738 .47123 L
s
.85764 .47131 m
.8574 .47139 L
s
.85796 .47082 m
.8574 .47139 L
s
1 .08 0 r
.43323 .52415 m
.43339 .52427 L
s
.43323 .52415 m
.43266 .52435 L
s
1 .028 0 r
.8575 .47115 m
.85738 .47123 L
s
.85764 .47131 m
.8575 .47115 L
s
.85752 .47139 m
.85764 .47131 L
s
.85738 .47123 m
.85752 .47139 L
s
1 .043 0 r
.58868 .55125 m
.58874 .55119 L
s
.58874 .55119 m
.58867 .55088 L
s
.58874 .55119 m
.58837 .55112 L
s
.58867 .55088 m
.58861 .55094 L
s
.58867 .55088 m
.58837 .55112 L
s
.58837 .55112 m
.58868 .55125 L
s
.58837 .55112 m
.58861 .55094 L
s
.58992 .55085 m
.58837 .55112 L
s
1 .08 0 r
.43266 .52435 m
.43321 .52485 L
s
.43266 .52435 m
.43339 .52427 L
s
.43339 .52427 m
.43321 .52485 L
s
1 .043 0 r
.58861 .55094 m
.58868 .55125 L
s
1 .018 0 r
.4801 .81769 m
.48011 .81773 L
s
.48011 .81756 m
.4801 .81769 L
s
.48025 .81765 m
.4801 .81769 L
s
.48012 .8176 m
.48011 .81756 L
s
.48011 .81756 m
.48025 .81765 L
s
.48025 .81765 m
.48011 .81773 L
s
.48012 .8176 m
.48025 .81765 L
s
.47955 .81761 m
.48025 .81765 L
s
1 0 0 r
.53474 .68423 m
.53474 .68423 L
s
.53474 .68423 m
.53474 .68423 L
s
.53475 .68423 m
.53474 .68423 L
s
.53474 .68423 m
.53474 .68423 L
s
.53474 .68423 m
.53475 .68423 L
s
.53474 .68423 m
.53475 .68423 L
s
1 .095 0 r
.37706 .49749 m
.37416 .49612 L
s
1 0 0 r
.32188 .63088 m
.32187 .63087 L
s
.53475 .68423 m
.53474 .68423 L
s
.53474 .68423 m
.53475 .68423 L
s
.53474 .68423 m
.53474 .68423 L
s
.32187 .63088 m
.32187 .63087 L
s
.32187 .63087 m
.32187 .63087 L
s
.32187 .63087 m
.32187 .63087 L
s
.32187 .63087 m
.32187 .63087 L
s
.32187 .63087 m
.32187 .63087 L
s
.32187 .63087 m
.32187 .63088 L
s
.32187 .63087 m
.32187 .63088 L
s
.32187 .63087 m
.32187 .63087 L
s
1 .018 0 r
.48011 .81773 m
.48012 .8176 L
s
1 .116 0 r
.52807 .52383 m
.52808 .52369 L
s
.52808 .52369 m
.52806 .52281 L
s
.52808 .52369 m
.52718 .52334 L
s
.52806 .52281 m
.52804 .52295 L
s
.52806 .52281 m
.52718 .52334 L
s
1 .012 0 r
.42149 .79024 m
.4215 .79027 L
s
.42151 .79015 m
.42149 .79024 L
s
.42159 .79022 m
.42149 .79024 L
s
.42152 .79018 m
.42151 .79015 L
s
.42151 .79015 m
.42159 .79022 L
s
1 .116 0 r
.52718 .52334 m
.52807 .52383 L
s
.52718 .52334 m
.52804 .52295 L
s
.53159 .52325 m
.52718 .52334 L
s
1 .005 0 r
.74441 .57671 m
.74444 .57672 L
s
.74444 .57667 m
.74441 .57671 L
s
.74441 .57671 m
.74442 .57668 L
s
.74446 .57671 m
.74441 .57671 L
s
.74456 .57663 m
.74441 .57671 L
s
1 .012 0 r
.42159 .79022 m
.4215 .79027 L
s
.42152 .79018 m
.42159 .79022 L
s
.42116 .79016 m
.42159 .79022 L
s
1 .005 0 r
.74444 .57667 m
.74442 .57668 L
s
.74446 .57671 m
.74444 .57667 L
s
.74444 .57672 m
.74446 .57671 L
s
1 .095 0 r
.37472 .49682 m
.37443 .49663 L
s
.37443 .49663 m
.37476 .49598 L
s
.37443 .49663 m
.37416 .49612 L
s
.37476 .49598 m
.37505 .49616 L
s
.37476 .49598 m
.37416 .49612 L
s
1 .005 0 r
.74442 .57668 m
.74444 .57672 L
s
1 .012 0 r
.4215 .79027 m
.42152 .79018 L
s
1 0 0 r
.47637 .65671 m
.47637 .65671 L
s
1 .091 0 r
.31861 .46987 m
.3163 .46823 L
s
1 .116 0 r
.52804 .52295 m
.52807 .52383 L
s
1 .095 0 r
.37505 .49616 m
.37472 .49682 L
s
.37416 .49612 m
.37472 .49682 L
s
.37416 .49612 m
.37505 .49616 L
s
1 .022 0 r
.68558 .54934 m
.68572 .54938 L
s
.68571 .54918 m
.68558 .54934 L
s
.68558 .54934 m
.68565 .54922 L
s
.68579 .54933 m
.68558 .54934 L
s
.68627 .54904 m
.68558 .54934 L
s
.68572 .54938 m
.68579 .54933 L
s
.68579 .54933 m
.68571 .54918 L
s
.68571 .54918 m
.68565 .54922 L
s
.68565 .54922 m
.68572 .54938 L
s
1 .006 0 r
.36285 .76274 m
.36287 .76275 L
s
.36287 .76269 m
.36285 .76274 L
s
.36291 .76273 m
.36285 .76274 L
s
.36288 .76271 m
.36287 .76269 L
s
.36287 .76269 m
.36291 .76273 L
s
.36291 .76273 m
.36287 .76275 L
s
.36288 .76271 m
.36291 .76273 L
s
.3627 .76268 m
.36291 .76273 L
s
.36287 .76275 m
.36288 .76271 L
s
1 0 0 r
.63103 .68257 m
.63104 .68256 L
s
.41794 .62915 m
.41793 .62915 L
s
1 .202 0 r
.47319 .49563 m
.46577 .49433 L
s
1 0 0 r
.63104 .68256 m
.63104 .68257 L
s
.63104 .68256 m
.63104 .68256 L
s
.63104 .68256 m
.63104 .68256 L
s
.63104 .68256 m
.63104 .68256 L
s
.63104 .68256 m
.63104 .68256 L
s
.41793 .62915 m
.41793 .62915 L
s
.41793 .62915 m
.41793 .62915 L
s
.41793 .62915 m
.41793 .62915 L
s
.41793 .62915 m
.41793 .62915 L
s
.41793 .62915 m
.41793 .62915 L
s
.63104 .68256 m
.63104 .68257 L
s
.63104 .68256 m
.63104 .68256 L
s
.63104 .68257 m
.63104 .68256 L
s
.41793 .62915 m
.41793 .62915 L
s
.41793 .62915 m
.41793 .62915 L
s
.41793 .62915 m
.41793 .62915 L
s
1 .08 0 r
.62576 .52244 m
.62595 .52231 L
s
.62595 .52231 m
.62574 .52174 L
s
.62595 .52231 m
.62521 .52226 L
s
.62574 .52174 m
.62556 .52187 L
s
.62574 .52174 m
.62521 .52226 L
s
.62521 .52226 m
.62576 .52244 L
s
.62521 .52226 m
.62556 .52187 L
s
.62793 .52141 m
.62521 .52226 L
s
1 .091 0 r
.31679 .46817 m
.31713 .46838 L
s
.31639 .46874 m
.31679 .46817 L
s
.31679 .46817 m
.3163 .46823 L
s
.31673 .46896 m
.31639 .46874 L
s
.31639 .46874 m
.3163 .46823 L
s
1 .22 0 r
.56301 .49571 m
.56328 .49543 L
s
.56328 .49543 m
.56299 .49378 L
s
.56328 .49543 m
.56137 .49499 L
s
.56299 .49378 m
.56272 .49406 L
s
.56299 .49378 m
.56137 .49499 L
s
1 .202 0 r
.46724 .49548 m
.46696 .49521 L
s
.46696 .49521 m
.46727 .4937 L
s
.46696 .49521 m
.46577 .49433 L
s
1 .08 0 r
.62556 .52187 m
.62576 .52244 L
s
1 .091 0 r
.31713 .46838 m
.31673 .46896 L
s
.3163 .46823 m
.31713 .46838 L
s
1 .202 0 r
.46727 .4937 m
.46755 .49397 L
s
.46727 .4937 m
.46577 .49433 L
s
1 .091 0 r
.3163 .46823 m
.31673 .46896 L
s
1 .22 0 r
.56137 .49499 m
.56301 .49571 L
s
.56137 .49499 m
.56272 .49406 L
s
.56952 .49376 m
.56137 .49499 L
s
1 .014 0 r
.51782 .78865 m
.51782 .78868 L
s
.51782 .78855 m
.51782 .78865 L
s
.51793 .78862 m
.51782 .78865 L
s
.51782 .78858 m
.51782 .78855 L
s
.51782 .78855 m
.51793 .78862 L
s
.51793 .78862 m
.51782 .78868 L
s
.51782 .78858 m
.51793 .78862 L
s
.51738 .78861 m
.51793 .78862 L
s
1 0 0 r
.57265 .65501 m
.57265 .65501 L
s
1 .233 0 r
.41473 .46798 m
.40724 .46491 L
s
1 .002 0 r
.35945 .60157 m
.35938 .60155 L
s
.3594 .60156 m
.35939 .60156 L
s
.35939 .60156 m
.3594 .60154 L
s
.35939 .60156 m
.35938 .60155 L
s
.3594 .60154 m
.3594 .60155 L
s
.3594 .60154 m
.35938 .60155 L
s
.3594 .60155 m
.3594 .60156 L
s
.35938 .60155 m
.3594 .60156 L
s
.35938 .60155 m
.3594 .60155 L
s
1 .014 0 r
.51782 .78868 m
.51782 .78858 L
s
1 .318 0 r
.59895 .46834 m
.5997 .46787 L
s
.5997 .46787 m
.59889 .46557 L
s
.5997 .46787 m
.59676 .46765 L
s
.59889 .46557 m
.59813 .46604 L
s
.59889 .46557 m
.59676 .46765 L
s
.59676 .46765 m
.59895 .46834 L
s
.59676 .46765 m
.59813 .46604 L
s
.60758 .46417 m
.59676 .46765 L
s
1 .202 0 r
.46577 .49433 m
.46724 .49548 L
s
.46577 .49433 m
.46755 .49397 L
s
1 .22 0 r
.56272 .49406 m
.56301 .49571 L
s
1 .202 0 r
.46755 .49397 m
.46724 .49548 L
s
1 .01 0 r
.78258 .54739 m
.78264 .5474 L
s
.78263 .54732 m
.78258 .54739 L
s
.78258 .54739 m
.7826 .54734 L
s
.78267 .54738 m
.78258 .54739 L
s
.78284 .54723 m
.78258 .54739 L
s
.78263 .54732 m
.7826 .54734 L
s
.78267 .54738 m
.78263 .54732 L
s
.78264 .5474 m
.78267 .54738 L
s
.7826 .54734 m
.78264 .5474 L
s
1 .009 0 r
.45916 .76115 m
.45917 .76117 L
s
.45917 .76108 m
.45916 .76115 L
s
.45924 .76113 m
.45916 .76115 L
s
.45918 .7611 m
.45917 .76108 L
s
.45917 .76108 m
.45924 .76113 L
s
.45924 .76113 m
.45917 .76117 L
s
.45918 .7611 m
.45924 .76113 L
s
.45891 .7611 m
.45924 .76113 L
s
.45917 .76117 m
.45918 .7611 L
s
1 0 0 r
.5142 .62743 m
.5142 .62743 L
s
.5142 .62743 m
.5142 .62743 L
s
.5142 .62743 m
.5142 .62743 L
s
.5142 .62743 m
.5142 .62743 L
s
.5142 .62743 m
.5142 .62743 L
s
.51422 .62743 m
.5142 .62743 L
s
1 .005 0 r
.3009 .57396 m
.30075 .57388 L
s
1 0 0 r
.5142 .62743 m
.5142 .62743 L
s
.5142 .62743 m
.5142 .62743 L
s
.5142 .62743 m
.5142 .62743 L
s
1 .005 0 r
.30078 .57388 m
.3008 .57389 L
s
.30076 .57391 m
.30078 .57388 L
s
.30078 .57388 m
.30075 .57388 L
s
.30078 .57392 m
.30076 .57391 L
s
.30076 .57391 m
.30075 .57388 L
s
.3008 .57389 m
.30078 .57392 L
s
.30075 .57388 m
.3008 .57389 L
s
.30075 .57388 m
.30078 .57392 L
s
1 .114 0 r
.66259 .49353 m
.6633 .4937 L
s
.66326 .4927 m
.66259 .49353 L
s
.66259 .49353 m
.66291 .49292 L
s
.66365 .49349 m
.66259 .49353 L
s
.66606 .49189 m
.66259 .49353 L
s
.6633 .4937 m
.66365 .49349 L
s
.66365 .49349 m
.66326 .4927 L
s
1 .417 0 r
.49834 .46719 m
.49816 .46674 L
s
.49816 .46674 m
.49837 .46356 L
s
.49816 .46674 m
.49518 .4652 L
s
1 .114 0 r
.66326 .4927 m
.66291 .49292 L
s
1 .035 0 r
.7235 .52014 m
.72371 .52018 L
s
.72369 .51987 m
.7235 .52014 L
s
.7235 .52014 m
.72357 .51995 L
s
.72383 .5201 m
.7235 .52014 L
s
.72448 .51957 m
.7235 .52014 L
s
.72369 .51987 m
.72357 .51995 L
s
.72383 .5201 m
.72369 .51987 L
s
.72371 .52018 m
.72383 .5201 L
s
.72357 .51995 m
.72371 .52018 L
s
1 .417 0 r
.49837 .46356 m
.49854 .46401 L
s
.49837 .46356 m
.49518 .4652 L
s
1 .318 0 r
.59813 .46604 m
.59895 .46834 L
s
1 .114 0 r
.66291 .49292 m
.6633 .4937 L
s
1 .233 0 r
.40871 .46654 m
.40806 .46615 L
s
.40806 .46615 m
.40878 .46451 L
s
.40806 .46615 m
.40724 .46491 L
s
1 .004 0 r
.40048 .73359 m
.40049 .7336 L
s
.40049 .73356 m
.40048 .73359 L
s
.40052 .73359 m
.40048 .73359 L
s
.4005 .73357 m
.40049 .73356 L
s
.40049 .73356 m
.40052 .73359 L
s
.40052 .73359 m
.40049 .7336 L
s
.4005 .73357 m
.40052 .73359 L
s
.40038 .73356 m
.40052 .73359 L
s
.40049 .7336 m
.4005 .73357 L
s
1 .233 0 r
.40878 .46451 m
.40943 .4649 L
s
.40878 .46451 m
.40724 .46491 L
s
1 0 0 r
.66914 .65331 m
.66914 .65331 L
s
1 .004 0 r
.45571 .59982 m
.45556 .59979 L
s
1 .417 0 r
.51105 .46608 m
.49518 .4652 L
s
1 .004 0 r
.45559 .59982 m
.45558 .59981 L
s
.45558 .59981 m
.45559 .59978 L
s
.45558 .59981 m
.45556 .59979 L
s
.45559 .59978 m
.4556 .59979 L
s
.45559 .59978 m
.45556 .59979 L
s
.45556 .59979 m
.45559 .59982 L
s
.45556 .59979 m
.4556 .59979 L
s
.4556 .59979 m
.45559 .59982 L
s
1 .417 0 r
.49518 .4652 m
.49834 .46719 L
s
.49518 .4652 m
.49854 .46401 L
s
1 .01 0 r
.55563 .75953 m
.55562 .75955 L
s
.55562 .75946 m
.55563 .75953 L
s
.5557 .7595 m
.55563 .75953 L
s
1 .001 0 r
.34181 .706 m
.34181 .706 L
s
.34181 .70599 m
.34181 .706 L
s
.34182 .706 m
.34181 .706 L
s
.34182 .706 m
.34181 .706 L
s
.34181 .70599 m
.34182 .706 L
s
.34181 .706 m
.34182 .706 L
s
.34178 .70599 m
.34182 .706 L
s
.34181 .706 m
.34181 .70599 L
s
.34181 .706 m
.34181 .706 L
s
1 .01 0 r
.55562 .75948 m
.55562 .75946 L
s
.55562 .75946 m
.5557 .7595 L
s
1 0 0 r
.61068 .62571 m
.61068 .62571 L
s
.61068 .62571 m
.61068 .6257 L
s
.61068 .62571 m
.61068 .6257 L
s
.61068 .6257 m
.61068 .6257 L
s
.61068 .6257 m
.61068 .6257 L
s
.61068 .6257 m
.61068 .62571 L
s
.61068 .6257 m
.61068 .6257 L
s
.61069 .6257 m
.61068 .6257 L
s
.61068 .6257 m
.61068 .62571 L
s
1 .01 0 r
.55533 .75952 m
.5557 .7595 L
s
1 .012 0 r
.39715 .57218 m
.39675 .57205 L
s
1 .01 0 r
.5557 .7595 m
.55562 .75955 L
s
.55562 .75948 m
.5557 .7595 L
s
.55562 .75955 m
.55562 .75948 L
s
1 .012 0 r
.39683 .57213 m
.3968 .5721 L
s
.3968 .5721 m
.39683 .57202 L
s
.3968 .5721 m
.39675 .57205 L
s
.39683 .57202 m
.39686 .57204 L
s
.39683 .57202 m
.39675 .57205 L
s
.39675 .57205 m
.39683 .57213 L
s
.39675 .57205 m
.39686 .57204 L
s
.39686 .57204 m
.39683 .57213 L
s
1 .233 0 r
.40943 .4649 m
.40871 .46654 L
s
.40724 .46491 m
.40871 .46654 L
s
.40724 .46491 m
.40943 .4649 L
s
1 .134 0 r
.7008 .46463 m
.70154 .46474 L
s
.70147 .46358 m
.7008 .46463 L
s
.7008 .46463 m
.70097 .46388 L
s
.70204 .46444 m
.7008 .46463 L
s
.70431 .46226 m
.7008 .46463 L
s
.70147 .46358 m
.70097 .46388 L
s
.70204 .46444 m
.70147 .46358 L
s
1 .014 0 r
.8209 .518 m
.82097 .51801 L
s
.82096 .51788 m
.8209 .518 L
s
.8209 .518 m
.82091 .51792 L
s
.82103 .51797 m
.8209 .518 L
s
.82124 .51773 m
.8209 .518 L
s
1 .134 0 r
.70154 .46474 m
.70204 .46444 L
s
1 .014 0 r
.82096 .51788 m
.82091 .51792 L
s
.82103 .51797 m
.82096 .51788 L
s
.82097 .51801 m
.82103 .51797 L
s
.82091 .51792 m
.82097 .51801 L
s
1 .417 0 r
.49854 .46401 m
.49834 .46719 L
s
1 .005 0 r
.55203 .59809 m
.55203 .59808 L
s
.55203 .59808 m
.55203 .59805 L
s
.55203 .59808 m
.55199 .59807 L
s
.49694 .73197 m
.49695 .73198 L
s
.49695 .73193 m
.49694 .73197 L
s
.49699 .73195 m
.49694 .73197 L
s
.55203 .59805 m
.55203 .59805 L
s
.55203 .59805 m
.55199 .59807 L
s
.49695 .73194 m
.49695 .73193 L
s
.49695 .73193 m
.49699 .73195 L
s
.55199 .59807 m
.55203 .59809 L
s
.55199 .59807 m
.55203 .59805 L
s
.55218 .59806 m
.55199 .59807 L
s
.49699 .73195 m
.49695 .73198 L
s
.49695 .73194 m
.49699 .73195 L
s
.49679 .73195 m
.49699 .73195 L
s
1 .019 0 r
.33852 .5445 m
.33795 .54421 L
s
1 .005 0 r
.55203 .59805 m
.55203 .59809 L
s
.49695 .73198 m
.49695 .73194 L
s
1 .045 0 r
.7617 .49085 m
.76194 .49088 L
s
.76191 .49048 m
.7617 .49085 L
s
.7617 .49085 m
.76173 .4906 L
s
.76211 .49077 m
.7617 .49085 L
s
.76281 .49001 m
.7617 .49085 L
s
.76191 .49048 m
.76173 .4906 L
s
.76211 .49077 m
.76191 .49048 L
s
.76194 .49088 m
.76211 .49077 L
s
1 .019 0 r
.33807 .54419 m
.33813 .54423 L
s
.338 .54432 m
.33807 .54419 L
s
.33807 .54419 m
.33795 .54421 L
s
.33806 .54436 m
.338 .54432 L
s
.338 .54432 m
.33795 .54421 L
s
.33813 .54423 m
.33806 .54436 L
s
.33795 .54421 m
.33813 .54423 L
s
.33795 .54421 m
.33806 .54436 L
s
1 .134 0 r
.70097 .46388 m
.70154 .46474 L
s
1 .045 0 r
.76173 .4906 m
.76194 .49088 L
s
1 .022 0 r
.38335 .83847 m
.38338 .83852 L
s
.38339 .83831 m
.38335 .83847 L
s
.38354 .83844 m
.38335 .83847 L
s
.38342 .83836 m
.38339 .83831 L
s
.38339 .83831 m
.38354 .83844 L
s
.38354 .83844 m
.38338 .83852 L
s
.38342 .83836 m
.38354 .83844 L
s
.38276 .8383 m
.38354 .83844 L
s
.38338 .83852 m
.38342 .83836 L
s
1 .002 0 r
.43823 .70436 m
.43823 .70436 L
s
.43823 .70434 m
.43823 .70436 L
s
.43825 .70435 m
.43823 .70436 L
s
.43823 .70435 m
.43823 .70434 L
s
.43823 .70434 m
.43825 .70435 L
s
1 .021 0 r
.49296 .57043 m
.49295 .5704 L
s
.49295 .5704 m
.49297 .57024 L
s
.49295 .5704 m
.49281 .57032 L
s
1 .002 0 r
.43825 .70435 m
.43823 .70436 L
s
.43823 .70435 m
.43825 .70435 L
s
.43818 .70434 m
.43825 .70435 L
s
.43823 .70436 m
.43823 .70435 L
s
1 0 0 r
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
.70738 .62397 m
.70738 .62397 L
s
1 .021 0 r
.49361 .57039 m
.49281 .57032 L
s
1 .023 0 r
.27983 .5168 m
.27924 .51638 L
s
1 .021 0 r
.49297 .57024 m
.49298 .57027 L
s
.49297 .57024 m
.49281 .57032 L
s
.49281 .57032 m
.49296 .57043 L
s
.49281 .57032 m
.49298 .57027 L
s
.49298 .57027 m
.49296 .57043 L
s
1 .023 0 r
.27936 .51636 m
.27945 .51642 L
s
.27926 .51651 m
.27936 .51636 L
s
.27936 .51636 m
.27924 .51638 L
s
.27935 .51657 m
.27926 .51651 L
s
.27926 .51651 m
.27924 .51638 L
s
.27945 .51642 m
.27935 .51657 L
s
.27924 .51638 m
.27945 .51642 L
s
.27924 .51638 m
.27935 .51657 L
s
1 .003 0 r
.64877 .59634 m
.64878 .59633 L
s
.64878 .59633 m
.64877 .59631 L
s
.64878 .59633 m
.64874 .59633 L
s
.64877 .59631 m
.64876 .59631 L
s
.64877 .59631 m
.64874 .59633 L
s
.64874 .59633 m
.64877 .59634 L
s
.64874 .59633 m
.64876 .59631 L
s
.64886 .5963 m
.64874 .59633 L
s
.64876 .59631 m
.64877 .59634 L
s
1 0 0 r
.37952 .67672 m
.37952 .67672 L
s
.37952 .67671 m
.37952 .67672 L
s
.37952 .67672 m
.37952 .67672 L
s
.37952 .67672 m
.37952 .67671 L
s
.37952 .67671 m
.37952 .67672 L
s
.37952 .67672 m
.37952 .67672 L
s
.37952 .67672 m
.37952 .67672 L
s
.37951 .67671 m
.37952 .67672 L
s
.37952 .67672 m
.37952 .67672 L
s
1 .005 0 r
.5934 .73033 m
.59359 .73031 L
s
1 .046 0 r
.43497 .54268 m
.43336 .54226 L
s
1 .005 0 r
.59356 .73032 m
.59356 .73033 L
s
.59356 .73029 m
.59356 .73032 L
s
.59359 .73031 m
.59356 .73032 L
s
.59355 .7303 m
.59356 .73029 L
s
.59356 .73029 m
.59359 .73031 L
s
.59359 .73031 m
.59356 .73033 L
s
.59355 .7303 m
.59359 .73031 L
s
.59356 .73033 m
.59355 .7303 L
s
1 .046 0 r
.43367 .54255 m
.43358 .54248 L
s
.43358 .54248 m
.43369 .54214 L
s
.43358 .54248 m
.43336 .54226 L
s
.43369 .54214 m
.43378 .54222 L
s
.43369 .54214 m
.43336 .54226 L
s
.43336 .54226 m
.43367 .54255 L
s
.43336 .54226 m
.43378 .54222 L
s
.43378 .54222 m
.43367 .54255 L
s
1 .018 0 r
.85938 .48851 m
.85947 .48851 L
s
.85945 .48835 m
.85938 .48851 L
s
.85938 .48851 m
.85937 .48841 L
s
.85954 .48846 m
.85938 .48851 L
s
.85976 .48813 m
.85938 .48851 L
s
.85945 .48835 m
.85937 .48841 L
s
.85954 .48846 m
.85945 .48835 L
s
.85947 .48851 m
.85954 .48846 L
s
.85937 .48841 m
.85947 .48851 L
s
1 .02 0 r
.58969 .56878 m
.58972 .56875 L
s
.58972 .56875 m
.58969 .5686 L
s
.58972 .56875 m
.58955 .56872 L
s
.58969 .5686 m
.58966 .56863 L
s
.58969 .5686 m
.58955 .56872 L
s
1 .028 0 r
.48013 .83692 m
.48015 .83698 L
s
.48015 .83671 m
.48013 .83692 L
s
.48036 .83686 m
.48013 .83692 L
s
1 .02 0 r
.58955 .56872 m
.58969 .56878 L
s
.58955 .56872 m
.58966 .56863 L
s
.59027 .56859 m
.58955 .56872 L
s
1 .028 0 r
.48016 .83678 m
.48015 .83671 L
s
.48015 .83671 m
.48036 .83686 L
s
1 .051 0 r
.80018 .4614 m
.80041 .46142 L
s
.80037 .46097 m
.80018 .4614 L
s
.80018 .4614 m
.80016 .46111 L
s
.80063 .46127 m
.80018 .4614 L
s
.80126 .46035 m
.80018 .4614 L
s
1 .028 0 r
.48036 .83686 m
.48015 .83698 L
s
.48016 .83678 m
.48036 .83686 L
s
.4793 .8368 m
.48036 .83686 L
s
1 .02 0 r
.58966 .56863 m
.58969 .56878 L
s
1 .051 0 r
.80037 .46097 m
.80016 .46111 L
s
.80063 .46127 m
.80037 .46097 L
s
1 .002 0 r
.53485 .7027 m
.53485 .7027 L
s
.53485 .70268 m
.53485 .7027 L
s
.53487 .70269 m
.53485 .7027 L
s
.53485 .70269 m
.53485 .70268 L
s
.53485 .70268 m
.53487 .70269 L
s
.53479 .7027 m
.53487 .70269 L
s
1 .062 0 r
.37626 .51495 m
.37437 .51407 L
s
1 0 0 r
.32078 .64905 m
.32078 .64905 L
s
1 .002 0 r
.53487 .70269 m
.53485 .7027 L
s
.53485 .70269 m
.53487 .70269 L
s
1 .028 0 r
.48015 .83698 m
.48016 .83678 L
s
1 .002 0 r
.53485 .7027 m
.53485 .70269 L
s
1 .051 0 r
.80041 .46142 m
.80063 .46127 L
s
.80016 .46111 m
.80041 .46142 L
s
1 .062 0 r
.37474 .51452 m
.37455 .5144 L
s
.37455 .5144 m
.37476 .51397 L
s
.37455 .5144 m
.37437 .51407 L
s
.37476 .51397 m
.37495 .51409 L
s
.37476 .51397 m
.37437 .51407 L
s
1 .068 0 r
.52955 .5412 m
.52956 .54111 L
s
.52956 .54111 m
.52955 .54059 L
s
.52956 .54111 m
.52903 .54091 L
s
.52955 .54059 m
.52954 .54068 L
s
.52955 .54059 m
.52903 .54091 L
s
1 .019 0 r
.42114 .80934 m
.42117 .80939 L
s
.42117 .8092 m
.42114 .80934 L
s
.42131 .80931 m
.42114 .80934 L
s
.4212 .80924 m
.42117 .8092 L
s
.42117 .8092 m
.42131 .80931 L
s
.42131 .80931 m
.42117 .80939 L
s
.4212 .80924 m
.42131 .80931 L
s
.42059 .80921 m
.42131 .80931 L
s
1 .062 0 r
.37495 .51409 m
.37474 .51452 L
s
.37437 .51407 m
.37474 .51452 L
s
.37437 .51407 m
.37495 .51409 L
s
1 .019 0 r
.42117 .80939 m
.4212 .80924 L
s
1 .068 0 r
.52903 .54091 m
.52955 .5412 L
s
.52903 .54091 m
.52954 .54068 L
s
.53162 .54086 m
.52903 .54091 L
s
1 .002 0 r
.7457 .59455 m
.74571 .59455 L
s
.74571 .59454 m
.7457 .59455 L
s
.7457 .59455 m
.7457 .59454 L
s
.74571 .59455 m
.7457 .59455 L
s
.74574 .59453 m
.7457 .59455 L
s
.74571 .59454 m
.7457 .59454 L
s
.74571 .59455 m
.74571 .59454 L
s
.74571 .59455 m
.74571 .59455 L
s
.7457 .59454 m
.74571 .59455 L
s
1 0 0 r
.47612 .67504 m
.47612 .67504 L
s
.47612 .67503 m
.47612 .67504 L
s
.47612 .67504 m
.47612 .67504 L
s
.47612 .67503 m
.47612 .67503 L
s
.47612 .67503 m
.47612 .67504 L
s
.47612 .67504 m
.47612 .67504 L
s
.47612 .67503 m
.47612 .67504 L
s
.47611 .67503 m
.47612 .67504 L
s
.47612 .67504 m
.47612 .67503 L
s
1 .063 0 r
.3175 .48719 m
.31587 .48605 L
s
1 .068 0 r
.52954 .54068 m
.52955 .5412 L
s
1 .063 0 r
.31621 .486 m
.31645 .48615 L
s
.31594 .4864 m
.31621 .486 L
s
.31621 .486 m
.31587 .48605 L
s
.31618 .48656 m
.31594 .4864 L
s
.31594 .4864 m
.31587 .48605 L
s
1 .01 0 r
.68683 .56693 m
.68689 .56695 L
s
.68689 .56686 m
.68683 .56693 L
s
.68683 .56693 m
.68686 .56688 L
s
.68692 .56693 m
.68683 .56693 L
s
.68715 .56679 m
.68683 .56693 L
s
.68689 .56695 m
.68692 .56693 L
s
.68692 .56693 m
.68689 .56686 L
s
.68689 .56686 m
.68686 .56688 L
s
1 .011 0 r
.36211 .78169 m
.36213 .78172 L
s
.36214 .78161 m
.36211 .78169 L
s
.36222 .78169 m
.36211 .78169 L
s
.36216 .78164 m
.36214 .78161 L
s
.36214 .78161 m
.36222 .78169 L
s
.36222 .78169 m
.36213 .78172 L
s
.36216 .78164 m
.36222 .78169 L
s
.36182 .78159 m
.36222 .78169 L
s
1 .01 0 r
.68686 .56688 m
.68689 .56695 L
s
1 .011 0 r
.36213 .78172 m
.36216 .78164 L
s
1 .002 0 r
.6316 .70104 m
.63167 .70103 L
s
1 0 0 r
.41736 .64734 m
.41736 .64734 L
s
1 .137 0 r
.47291 .5131 m
.46784 .51222 L
s
1 .057 0 r
.25867 .4594 m
.25745 .45824 L
s
1 .002 0 r
.63166 .70104 m
.63165 .70104 L
s
.63165 .70103 m
.63166 .70104 L
s
.63167 .70103 m
.63166 .70104 L
s
.63165 .70103 m
.63165 .70103 L
s
.63165 .70103 m
.63167 .70103 L
s
.63167 .70103 m
.63165 .70104 L
s
.63165 .70103 m
.63167 .70103 L
s
.63165 .70104 m
.63165 .70103 L
s
1 .063 0 r
.31645 .48615 m
.31618 .48656 L
s
.31587 .48605 m
.31645 .48615 L
s
.31587 .48605 m
.31618 .48656 L
s
1 .137 0 r
.46884 .513 m
.46865 .51281 L
s
.46865 .51281 m
.46886 .51178 L
s
.46865 .51281 m
.46784 .51222 L
s
.46886 .51178 m
.46905 .51197 L
s
.46886 .51178 m
.46784 .51222 L
s
1 .046 0 r
.62724 .53962 m
.62734 .53954 L
s
.62734 .53954 m
.62723 .53921 L
s
.62734 .53954 m
.62692 .53951 L
s
.62723 .53921 m
.62712 .53929 L
s
.62723 .53921 m
.62692 .53951 L
s
.62692 .53951 m
.62724 .53962 L
s
.62692 .53951 m
.62712 .53929 L
s
.62848 .53903 m
.62692 .53951 L
s
1 .022 0 r
.89802 .4589 m
.89811 .4589 L
s
.89809 .45872 m
.89802 .4589 L
s
.89802 .4589 m
.89799 .45878 L
s
.8982 .45884 m
.89802 .4589 L
s
.89841 .45844 m
.89802 .4589 L
s
.89809 .45872 m
.89799 .45878 L
s
.8982 .45884 m
.89809 .45872 L
s
.89811 .4589 m
.8982 .45884 L
s
.89799 .45878 m
.89811 .4589 L
s
1 .046 0 r
.62712 .53929 m
.62724 .53962 L
s
1 .151 0 r
.56528 .51258 m
.56547 .51238 L
s
.56547 .51238 m
.56526 .51124 L
s
.56547 .51238 m
.56415 .51208 L
s
1 .057 0 r
.25772 .45822 m
.25796 .45838 L
s
.25744 .45856 m
.25772 .45822 L
s
.25772 .45822 m
.25745 .45824 L
s
.25768 .45872 m
.25744 .45856 L
s
.25744 .45856 m
.25745 .45824 L
s
1 .151 0 r
.56526 .51124 m
.56508 .51144 L
s
.56526 .51124 m
.56415 .51208 L
s
1 .023 0 r
.51805 .80774 m
.51805 .80779 L
s
.51806 .80757 m
.51805 .80774 L
s
.51823 .80768 m
.51805 .80774 L
s
.51806 .80762 m
.51806 .80757 L
s
.51806 .80757 m
.51823 .80768 L
s
1 .137 0 r
.46784 .51222 m
.46884 .513 L
s
.46784 .51222 m
.46905 .51197 L
s
1 .023 0 r
.51823 .80768 m
.51805 .80779 L
s
.51806 .80762 m
.51823 .80768 L
s
.51734 .80767 m
.51823 .80768 L
s
1 0 0 r
.57292 .67335 m
.57292 .67335 L
s
.57292 .67335 m
.57292 .67335 L
s
.57292 .67335 m
.57292 .67335 L
s
.57291 .67335 m
.57292 .67335 L
s
1 .172 0 r
.41413 .4853 m
.40857 .48305 L
s
1 0 0 r
.35855 .61962 m
.35855 .61962 L
s
.57292 .67335 m
.57292 .67335 L
s
.57292 .67335 m
.57292 .67335 L
s
.57292 .67335 m
.57292 .67335 L
s
.57292 .67335 m
.57292 .67335 L
s
.57292 .67335 m
.57292 .67335 L
s
.35855 .61962 m
.35855 .61962 L
s
.35855 .61962 m
.35855 .61962 L
s
.35855 .61962 m
.35855 .61962 L
s
.35855 .61962 m
.35855 .61962 L
s
.35855 .61962 m
.35855 .61962 L
s
.35855 .61962 m
.35855 .61962 L
s
.35855 .61962 m
.35855 .61962 L
s
.35855 .61962 m
.35855 .61962 L
s
1 .023 0 r
.51805 .80779 m
.51806 .80762 L
s
1 .057 0 r
.25796 .45838 m
.25768 .45872 L
s
.25745 .45824 m
.25796 .45838 L
s
1 .151 0 r
.56415 .51208 m
.56528 .51258 L
s
.56415 .51208 m
.56508 .51144 L
s
.56976 .51124 m
.56415 .51208 L
s
1 .137 0 r
.46905 .51197 m
.46884 .513 L
s
1 .057 0 r
.25745 .45824 m
.25768 .45872 L
s
1 .151 0 r
.56508 .51144 m
.56528 .51258 L
s
1 .016 0 r
.45902 .78011 m
.45904 .78015 L
s
.45904 .77999 m
.45902 .78011 L
s
.45916 .78008 m
.45902 .78011 L
s
.45905 .78003 m
.45904 .77999 L
s
.45904 .77999 m
.45916 .78008 L
s
1 .004 0 r
.78412 .56506 m
.78414 .56507 L
s
.78414 .56503 m
.78412 .56506 L
s
.78412 .56506 m
.78412 .56504 L
s
.78416 .56506 m
.78412 .56506 L
s
.78423 .56499 m
.78412 .56506 L
s
1 .016 0 r
.45916 .78008 m
.45904 .78015 L
s
.45905 .78003 m
.45916 .78008 L
s
.45855 .78002 m
.45916 .78008 L
s
1 .004 0 r
.78414 .56503 m
.78412 .56504 L
s
.78416 .56506 m
.78414 .56503 L
s
.78414 .56507 m
.78416 .56506 L
s
.78412 .56504 m
.78414 .56507 L
s
1 .016 0 r
.45904 .78015 m
.45905 .78003 L
s
1 0 0 r
.51416 .64563 m
.51416 .64563 L
s
1 .002 0 r
.29968 .59187 m
.29964 .59185 L
s
1 .158 0 r
.35529 .45748 m
.35113 .45465 L
s
1 .002 0 r
.29965 .59185 m
.29965 .59185 L
s
.29964 .59186 m
.29965 .59185 L
s
.29965 .59185 m
.29964 .59185 L
s
.29965 .59186 m
.29964 .59186 L
s
.29964 .59186 m
.29964 .59185 L
s
.29965 .59185 m
.29965 .59186 L
s
.29964 .59185 m
.29965 .59185 L
s
.29964 .59185 m
.29965 .59186 L
s
1 .241 0 r
.60146 .48467 m
.60203 .4843 L
s
.60203 .4843 m
.60141 .48255 L
s
.60203 .4843 m
.59979 .48413 L
s
1 .575 0 r
.53174 .458 m
.53228 .45737 L
s
.53228 .45737 m
.53173 .45298 L
s
.53228 .45737 m
.52739 .45595 L
s
1 .241 0 r
.60141 .48255 m
.60084 .48292 L
s
.60141 .48255 m
.59979 .48413 L
s
.59979 .48413 m
.60146 .48467 L
s
.59979 .48413 m
.60084 .48292 L
s
.60802 .48152 m
.59979 .48413 L
s
1 .172 0 r
.40966 .48426 m
.40918 .48396 L
s
.40918 .48396 m
.40971 .48274 L
s
.40918 .48396 m
.40857 .48305 L
s
1 .323 0 r
.50108 .48429 m
.50094 .48392 L
s
.50094 .48392 m
.5011 .48145 L
s
.50094 .48392 m
.49862 .48274 L
s
1 .172 0 r
.40971 .48274 m
.4102 .48304 L
s
.40971 .48274 m
.40857 .48305 L
s
1 .575 0 r
.53173 .45298 m
.5312 .45361 L
s
.53173 .45298 m
.52739 .45595 L
s
1 .019 0 r
.72502 .53751 m
.72513 .53753 L
s
.72512 .53736 m
.72502 .53751 L
s
.72502 .53751 m
.72505 .5374 L
s
.7252 .53749 m
.72502 .53751 L
s
.72556 .5372 m
.72502 .53751 L
s
.72512 .53736 m
.72505 .5374 L
s
.7252 .53749 m
.72512 .53736 L
s
.72513 .53753 m
.7252 .53749 L
s
1 .323 0 r
.5011 .48145 m
.50123 .48182 L
s
.5011 .48145 m
.49862 .48274 L
s
1 .019 0 r
.72505 .5374 m
.72513 .53753 L
s
1 .075 0 r
.66454 .51044 m
.66501 .51056 L
s
.66498 .5099 m
.66454 .51044 L
s
.66454 .51044 m
.66475 .51005 L
s
.66524 .51041 m
.66454 .51044 L
s
.66682 .50937 m
.66454 .51044 L
s
.66501 .51056 m
.66524 .51041 L
s
.66524 .51041 m
.66498 .5099 L
s
.66498 .5099 m
.66475 .51005 L
s
1 .009 0 r
.39994 .75242 m
.39995 .75244 L
s
.39996 .75235 m
.39994 .75242 L
s
.40002 .75241 m
.39994 .75242 L
s
.39997 .75237 m
.39996 .75235 L
s
.39996 .75235 m
.40002 .75241 L
s
.40002 .75241 m
.39995 .75244 L
s
.39997 .75237 m
.40002 .75241 L
s
.3997 .75234 m
.40002 .75241 L
s
.39995 .75244 m
.39997 .75237 L
s
1 0 0 r
.66992 .67166 m
.66993 .67166 L
s
1 .001 0 r
.45534 .61788 m
.45532 .61787 L
s
1 .323 0 r
.51097 .48341 m
.49862 .48274 L
s
1 .001 0 r
.45532 .61788 m
.45532 .61788 L
s
.45532 .61788 m
.45532 .61787 L
s
.45532 .61788 m
.45532 .61787 L
s
1 0 0 r
.66993 .67166 m
.66993 .67166 L
s
.66993 .67166 m
.66993 .67166 L
s
.66993 .67166 m
.66993 .67166 L
s
.66993 .67166 m
.66993 .67166 L
s
.66993 .67166 m
.66993 .67166 L
s
1 .001 0 r
.45532 .61787 m
.45532 .61787 L
s
.45532 .61787 m
.45532 .61787 L
s
1 0 0 r
.66993 .67166 m
.66993 .67166 L
s
.66993 .67166 m
.66993 .67166 L
s
.66993 .67166 m
.66993 .67166 L
s
1 .001 0 r
.45532 .61787 m
.45532 .61788 L
s
.45532 .61787 m
.45532 .61787 L
s
.45532 .61787 m
.45532 .61788 L
s
1 .293 0 r
.63781 .4563 m
.63958 .45666 L
s
.63948 .4541 m
.63781 .4563 L
s
.63781 .4563 m
.63849 .45466 L
s
.64057 .45609 m
.63781 .4563 L
s
.64641 .4517 m
.63781 .4563 L
s
1 .075 0 r
.66475 .51005 m
.66501 .51056 L
s
1 .172 0 r
.4102 .48304 m
.40966 .48426 L
s
.40857 .48305 m
.40966 .48426 L
s
.40857 .48305 m
.4102 .48304 L
s
1 .241 0 r
.60084 .48292 m
.60146 .48467 L
s
1 .293 0 r
.63958 .45666 m
.64057 .45609 L
s
.64057 .45609 m
.63948 .4541 L
s
.63948 .4541 m
.63849 .45466 L
s
1 .575 0 r
.52739 .45595 m
.53174 .458 L
s
.52739 .45595 m
.5312 .45361 L
s
.54916 .45363 m
.52739 .45595 L
s
1 .323 0 r
.49862 .48274 m
.50108 .48429 L
s
.49862 .48274 m
.50123 .48182 L
s
1 .158 0 r
.352 .45453 m
.3526 .45488 L
s
.35133 .45556 m
.352 .45453 L
s
.352 .45453 m
.35113 .45465 L
s
1 .003 0 r
.34087 .72467 m
.34088 .72468 L
s
.34088 .72465 m
.34087 .72467 L
s
.3409 .72467 m
.34087 .72467 L
s
.3409 .72467 m
.34088 .72468 L
s
.34088 .72465 m
.3409 .72467 L
s
.34089 .72465 m
.3409 .72467 L
s
.34079 .72463 m
.3409 .72467 L
s
.34089 .72465 m
.34088 .72465 L
s
1 .018 0 r
.55604 .77847 m
.55604 .77851 L
s
.55604 .77834 m
.55604 .77847 L
s
.55617 .77842 m
.55604 .77847 L
s
1 .003 0 r
.34088 .72468 m
.34089 .72465 L
s
1 .018 0 r
.55603 .77838 m
.55604 .77834 L
s
.55604 .77834 m
.55617 .77842 L
s
.55549 .77845 m
.55617 .77842 L
s
1 0 0 r
.61116 .64391 m
.61116 .64391 L
s
1 .004 0 r
.39645 .5901 m
.39633 .59005 L
s
1 .417 0 r
.45212 .45556 m
.43773 .45101 L
s
1 .158 0 r
.35192 .45591 m
.35133 .45556 L
s
.35133 .45556 m
.35113 .45465 L
s
1 .004 0 r
.39635 .59008 m
.39634 .59007 L
s
.39634 .59007 m
.39635 .59005 L
s
.39634 .59007 m
.39633 .59005 L
s
.39635 .59005 m
.39636 .59005 L
s
.39635 .59005 m
.39633 .59005 L
s
1 .018 0 r
.55617 .77842 m
.55604 .77851 L
s
.55603 .77838 m
.55617 .77842 L
s
1 .004 0 r
.39633 .59005 m
.39635 .59008 L
s
.39633 .59005 m
.39636 .59005 L
s
.39636 .59005 m
.39635 .59008 L
s
1 .018 0 r
.55604 .77851 m
.55603 .77838 L
s
1 .323 0 r
.50123 .48182 m
.50108 .48429 L
s
1 .158 0 r
.3526 .45488 m
.35192 .45591 L
s
.35113 .45465 m
.3526 .45488 L
s
.35113 .45465 m
.35192 .45591 L
s
1 .008 0 r
.82266 .53551 m
.8227 .53551 L
s
.82269 .53544 m
.82266 .53551 L
s
.82266 .53551 m
.82266 .53546 L
s
.82273 .53549 m
.82266 .53551 L
s
.82284 .53536 m
.82266 .53551 L
s
.82269 .53544 m
.82266 .53546 L
s
.82273 .53549 m
.82269 .53544 L
s
.8227 .53551 m
.82273 .53549 L
s
.82266 .53546 m
.8227 .53551 L
s
1 .293 0 r
.63849 .45466 m
.63958 .45666 L
s
1 .012 0 r
.49699 .75079 m
.49699 .75081 L
s
.49699 .7507 m
.49699 .75079 L
s
.49708 .75076 m
.49699 .75079 L
s
.497 .75072 m
.49699 .7507 L
s
.49699 .7507 m
.49708 .75076 L
s
.49708 .75076 m
.49699 .75081 L
s
.497 .75072 m
.49708 .75076 L
s
.49663 .75074 m
.49708 .75076 L
s
1 .001 0 r
.55231 .61613 m
.55231 .61613 L
s
.55231 .61613 m
.55231 .61613 L
s
.55231 .61613 m
.5523 .61613 L
s
.55231 .61613 m
.55231 .61613 L
s
.55231 .61613 m
.5523 .61613 L
s
.5523 .61613 m
.55231 .61613 L
s
.5523 .61613 m
.55231 .61613 L
s
.55233 .61613 m
.5523 .61613 L
s
1 .009 0 r
.33751 .56228 m
.33725 .56215 L
s
1 .001 0 r
.55231 .61613 m
.55231 .61613 L
s
1 .012 0 r
.49699 .75081 m
.497 .75072 L
s
1 .009 0 r
.3373 .56214 m
.33733 .56216 L
s
.33727 .5622 m
.3373 .56214 L
s
.3373 .56214 m
.33725 .56215 L
s
.3373 .56222 m
.33727 .5622 L
s
.33727 .5622 m
.33725 .56215 L
s
.33733 .56216 m
.3373 .56222 L
s
.33725 .56215 m
.33733 .56216 L
s
.33725 .56215 m
.3373 .56222 L
s
1 .095 0 r
.70277 .4813 m
.7033 .48138 L
s
.70325 .48054 m
.70277 .4813 L
s
.70277 .4813 m
.70289 .48076 L
s
.70365 .48116 m
.70277 .4813 L
s
.70528 .47962 m
.70277 .4813 L
s
.70325 .48054 m
.70289 .48076 L
s
.70365 .48116 m
.70325 .48054 L
s
.7033 .48138 m
.70365 .48116 L
s
1 .028 0 r
.7634 .50803 m
.76355 .50805 L
s
.76353 .5078 m
.7634 .50803 L
s
.7634 .50803 m
.76342 .50787 L
s
.76366 .50797 m
.7634 .50803 L
s
.7641 .5075 m
.7634 .50803 L
s
.76353 .5078 m
.76342 .50787 L
s
.76366 .50797 m
.76353 .5078 L
s
.76355 .50805 m
.76366 .50797 L
s
1 .575 0 r
.5312 .45361 m
.53174 .458 L
s
1 .028 0 r
.76342 .50787 m
.76355 .50805 L
s
1 .095 0 r
.70289 .48076 m
.7033 .48138 L
s
1 .006 0 r
.43787 .72304 m
.43788 .72305 L
s
.43788 .723 m
.43787 .72304 L
s
.43792 .72303 m
.43787 .72304 L
s
.43788 .72301 m
.43788 .723 L
s
.43788 .723 m
.43792 .72303 L
s
.43792 .72303 m
.43788 .72305 L
s
.43788 .72301 m
.43792 .72303 L
s
.43771 .723 m
.43792 .72303 L
s
.43788 .72305 m
.43788 .72301 L
s
1 .007 0 r
.49323 .58833 m
.49322 .58832 L
s
.49322 .58832 m
.49323 .58827 L
s
.49322 .58832 m
.49318 .58829 L
s
1 0 0 r
.70837 .64219 m
.70837 .64219 L
s
1 .007 0 r
.49343 .58831 m
.49318 .58829 L
s
1 .013 0 r
.2785 .53444 m
.27817 .53421 L
s
1 .007 0 r
.49323 .58827 m
.49323 .58828 L
s
.49323 .58827 m
.49318 .58829 L
s
.49318 .58829 m
.49323 .58833 L
s
.49318 .58829 m
.49323 .58828 L
s
.49323 .58828 m
.49323 .58833 L
s
1 .013 0 r
.27824 .5342 m
.27829 .53424 L
s
.27818 .53428 m
.27824 .5342 L
s
.27824 .5342 m
.27817 .53421 L
s
.27823 .53432 m
.27818 .53428 L
s
.27818 .53428 m
.27817 .53421 L
s
.27829 .53424 m
.27823 .53432 L
s
.27817 .53421 m
.27829 .53424 L
s
.27817 .53421 m
.27823 .53432 L
s
1 .417 0 r
.44057 .45375 m
.4396 .45315 L
s
.4396 .45315 m
.44066 .4501 L
s
.4396 .45315 m
.43773 .45101 L
s
.44066 .4501 m
.44163 .45069 L
s
.44066 .4501 m
.43773 .45101 L
s
1 .002 0 r
.37876 .69525 m
.37876 .69525 L
s
.37877 .69523 m
.37876 .69525 L
s
.37878 .69525 m
.37876 .69525 L
s
.37877 .69524 m
.37877 .69523 L
s
.37877 .69523 m
.37878 .69525 L
s
.37878 .69525 m
.37876 .69525 L
s
.37877 .69524 m
.37878 .69525 L
s
.37872 .69523 m
.37878 .69525 L
s
.37876 .69525 m
.37877 .69524 L
s
1 0 0 r
.64952 .61438 m
.64952 .61438 L
s
.64952 .61438 m
.64952 .61438 L
s
.64952 .61438 m
.64951 .61438 L
s
.64952 .61438 m
.64952 .61438 L
s
.64952 .61438 m
.64951 .61438 L
s
.64951 .61438 m
.64952 .61438 L
s
.64951 .61438 m
.64952 .61438 L
s
.64953 .61438 m
.64951 .61438 L
s
.64952 .61438 m
.64952 .61438 L
s
1 .011 0 r
.59377 .74913 m
.5942 .74909 L
s
1 .021 0 r
.43448 .56047 m
.43373 .56028 L
s
1 .011 0 r
.59413 .74913 m
.59412 .74915 L
s
.59412 .74904 m
.59413 .74913 L
s
.5942 .74909 m
.59413 .74913 L
s
.59411 .74906 m
.59412 .74904 L
s
.59412 .74904 m
.5942 .74909 L
s
.5942 .74909 m
.59412 .74915 L
s
.59411 .74906 m
.5942 .74909 L
s
.59412 .74915 m
.59411 .74906 L
s
1 .021 0 r
.43387 .56041 m
.43383 .56038 L
s
.43383 .56038 m
.43388 .56022 L
s
.43383 .56038 m
.43373 .56028 L
s
.43388 .56022 m
.43392 .56026 L
s
.43388 .56022 m
.43373 .56028 L
s
.43373 .56028 m
.43387 .56041 L
s
.43373 .56028 m
.43392 .56026 L
s
.43392 .56026 m
.43387 .56041 L
s
1 .011 0 r
.86135 .50586 m
.8614 .50586 L
s
.86139 .50576 m
.86135 .50586 L
s
.86135 .50586 m
.86134 .5058 L
s
.86145 .50583 m
.86135 .50586 L
s
.86158 .50563 m
.86135 .50586 L
s
.86139 .50576 m
.86134 .5058 L
s
.86145 .50583 m
.86139 .50576 L
s
.8614 .50586 m
.86145 .50583 L
s
.86134 .5058 m
.8614 .50586 L
s
1 .104 0 r
.74158 .45186 m
.74207 .45189 L
s
.74201 .45098 m
.74158 .45186 L
s
.74158 .45186 m
.74157 .45126 L
s
.74251 .45161 m
.74158 .45186 L
s
.74387 .44976 m
.74158 .45186 L
s
1 .006 0 r
.59044 .58659 m
.59045 .58658 L
s
.59045 .58658 m
.59044 .58653 L
s
.59045 .58658 m
.59039 .58657 L
s
.59044 .58653 m
.59043 .58654 L
s
.59044 .58653 m
.59039 .58657 L
s
.59039 .58657 m
.59044 .58659 L
s
.59039 .58657 m
.59043 .58654 L
s
.59062 .58653 m
.59039 .58657 L
s
.59043 .58654 m
.59044 .58659 L
s
1 .007 0 r
.53505 .72138 m
.53505 .72139 L
s
.53505 .72133 m
.53505 .72138 L
s
.5351 .72136 m
.53505 .72138 L
s
.53505 .72134 m
.53505 .72133 L
s
.53505 .72133 m
.5351 .72136 L
s
1 0 0 r
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
.31967 .66743 m
.31967 .66743 L
s
1 .007 0 r
.53484 .72136 m
.5351 .72136 L
s
1 .035 0 r
.37545 .5326 m
.37438 .5321 L
s
1 .007 0 r
.5351 .72136 m
.53505 .72139 L
s
.53505 .72134 m
.5351 .72136 L
s
1 .104 0 r
.74201 .45098 m
.74157 .45126 L
s
.74251 .45161 m
.74201 .45098 L
s
1 .007 0 r
.53505 .72139 m
.53505 .72134 L
s
1 .104 0 r
.74207 .45189 m
.74251 .45161 L
s
1 .035 0 r
.80202 .47842 m
.80218 .47844 L
s
.80215 .47813 m
.80202 .47842 L
s
.80202 .47842 m
.802 .47823 L
s
.80233 .47834 m
.80202 .47842 L
s
.80276 .47771 m
.80202 .47842 L
s
.80215 .47813 m
.802 .47823 L
s
.80233 .47834 m
.80215 .47813 L
s
.37458 .53236 m
.37448 .53229 L
s
.37448 .53229 m
.3746 .53204 L
s
.37448 .53229 m
.37438 .5321 L
s
.3746 .53204 m
.37471 .53212 L
s
.3746 .53204 m
.37438 .5321 L
s
.80218 .47844 m
.80233 .47834 L
s
1 .104 0 r
.74157 .45126 m
.74207 .45189 L
s
1 .035 0 r
.802 .47823 m
.80218 .47844 L
s
.37471 .53212 m
.37458 .53236 L
s
.37438 .5321 m
.37458 .53236 L
s
.37438 .5321 m
.37471 .53212 L
s
1 .417 0 r
.43773 .45101 m
.44057 .45375 L
s
.43773 .45101 m
.44163 .45069 L
s
1 .029 0 r
.42085 .82866 m
.42089 .82873 L
s
.4209 .82845 m
.42085 .82866 L
s
.42111 .82862 m
.42085 .82866 L
s
.42093 .82852 m
.4209 .82845 L
s
.4209 .82845 m
.42111 .82862 L
s
.42111 .82862 m
.42089 .82873 L
s
.42093 .82852 m
.42111 .82862 L
s
.42002 .82847 m
.42111 .82862 L
s
1 .417 0 r
.44163 .45069 m
.44057 .45375 L
s
1 .032 0 r
.53067 .55882 m
.53067 .55877 L
s
.53067 .55877 m
.53067 .55853 L
s
.53067 .55877 m
.53042 .55868 L
s
.53067 .55853 m
.53066 .55857 L
s
.53067 .55853 m
.53042 .55868 L
s
1 .029 0 r
.42089 .82873 m
.42093 .82852 L
s
1 .032 0 r
.53042 .55868 m
.53067 .55882 L
s
.53042 .55868 m
.53066 .55857 L
s
.53165 .55866 m
.53042 .55868 L
s
1 .003 0 r
.47591 .69358 m
.47592 .69358 L
s
.47592 .69356 m
.47591 .69358 L
s
.47594 .69357 m
.47591 .69358 L
s
.47592 .69356 m
.47592 .69356 L
s
.47592 .69356 m
.47594 .69357 L
s
.47594 .69357 m
.47592 .69358 L
s
.47592 .69356 m
.47594 .69357 L
s
.47584 .69356 m
.47594 .69357 L
s
1 0 0 r
.74694 .61262 m
.74694 .61262 L
s
.74694 .61262 m
.74694 .61262 L
s
.74694 .61262 m
.74694 .61262 L
s
.74694 .61262 m
.74694 .61262 L
s
.74694 .61262 m
.74694 .61262 L
s
.74694 .61262 m
.74694 .61262 L
s
.74694 .61262 m
.74694 .61262 L
s
.74694 .61262 m
.74694 .61262 L
s
1 .003 0 r
.47592 .69358 m
.47592 .69356 L
s
1 0 0 r
.74694 .61262 m
.74694 .61262 L
s
1 .04 0 r
.31637 .50469 m
.31533 .50398 L
s
1 .032 0 r
.53066 .55857 m
.53067 .55882 L
s
1 .04 0 r
.31555 .50394 m
.3157 .50404 L
s
.31537 .5042 m
.31555 .50394 L
s
.31555 .50394 m
.31533 .50398 L
s
.31552 .5043 m
.31537 .5042 L
s
.31537 .5042 m
.31533 .50398 L
s
.3157 .50404 m
.31552 .5043 L
s
.31533 .50398 m
.3157 .50404 L
s
.31533 .50398 m
.31552 .5043 L
s
1 .018 0 r
.36142 .80088 m
.36145 .80092 L
s
.36146 .80074 m
.36142 .80088 L
s
.36159 .80086 m
.36142 .80088 L
s
.36149 .80079 m
.36146 .80074 L
s
.36146 .80074 m
.36159 .80086 L
s
.36159 .80086 m
.36145 .80092 L
s
.36149 .80079 m
.36159 .80086 L
s
.36093 .80071 m
.36159 .80086 L
s
.36145 .80092 m
.36149 .80079 L
s
1 .003 0 r
.68793 .58478 m
.68795 .58479 L
s
.68795 .58476 m
.68793 .58478 L
s
.68793 .58478 m
.68794 .58477 L
s
.68796 .58478 m
.68793 .58478 L
s
.68803 .58474 m
.68793 .58478 L
s
.68795 .58479 m
.68796 .58478 L
s
.68796 .58478 m
.68795 .58476 L
s
.68795 .58476 m
.68794 .58477 L
s
.68794 .58477 m
.68795 .58479 L
s
1 0 0 r
.41678 .66573 m
.41678 .66573 L
s
.41678 .66573 m
.41678 .66573 L
s
.41679 .66573 m
.41678 .66573 L
s
.41679 .66573 m
.41678 .66573 L
s
.41678 .66573 m
.41679 .66573 L
s
.41679 .66573 m
.41678 .66573 L
s
.41679 .66573 m
.41679 .66573 L
s
.41678 .66573 m
.41679 .66573 L
s
.41678 .66573 m
.41679 .66573 L
s
1 .006 0 r
.63218 .71972 m
.63239 .71968 L
s
1 .081 0 r
.47262 .53075 m
.4696 .53023 L
s
1 .039 0 r
.25722 .47676 m
.25638 .47597 L
s
1 .006 0 r
.63236 .71971 m
.63235 .71972 L
s
.63234 .71966 m
.63236 .71971 L
s
.63239 .71968 m
.63236 .71971 L
s
.63234 .71968 m
.63234 .71966 L
s
.63234 .71966 m
.63239 .71968 L
s
.63239 .71968 m
.63235 .71972 L
s
.63234 .71968 m
.63239 .71968 L
s
.63235 .71972 m
.63234 .71968 L
s
1 .081 0 r
.4702 .5307 m
.47009 .53059 L
s
.47009 .53059 m
.47021 .52997 L
s
.47009 .53059 m
.4696 .53023 L
s
.47021 .52997 m
.47032 .53009 L
s
.47021 .52997 m
.4696 .53023 L
s
.4696 .53023 m
.4702 .5307 L
s
.4696 .53023 m
.47032 .53009 L
s
1 .039 0 r
.25656 .47596 m
.25673 .47607 L
s
.25637 .47619 m
.25656 .47596 L
s
.25656 .47596 m
.25638 .47597 L
s
.25653 .4763 m
.25637 .47619 L
s
.25637 .47619 m
.25638 .47597 L
s
1 .081 0 r
.47032 .53009 m
.4702 .5307 L
s
1 .014 0 r
.90018 .47611 m
.90024 .47611 L
s
.90023 .47599 m
.90018 .47611 L
s
.90018 .47611 m
.90016 .47603 L
s
.9003 .47607 m
.90018 .47611 L
s
.90044 .47581 m
.90018 .47611 L
s
.90023 .47599 m
.90016 .47603 L
s
.9003 .47607 m
.90023 .47599 L
s
1 .039 0 r
.25673 .47607 m
.25653 .4763 L
s
.25638 .47597 m
.25673 .47607 L
s
1 .014 0 r
.90024 .47611 m
.9003 .47607 L
s
1 .021 0 r
.62847 .55711 m
.62851 .55707 L
s
.62851 .55707 m
.62846 .55692 L
s
.62851 .55707 m
.62832 .55706 L
s
.62846 .55692 m
.62841 .55696 L
s
.62846 .55692 m
.62832 .55706 L
s
.62832 .55706 m
.62847 .55711 L
s
.62832 .55706 m
.62841 .55696 L
s
.62905 .55684 m
.62832 .55706 L
s
1 .039 0 r
.25638 .47597 m
.25653 .4763 L
s
1 .014 0 r
.90016 .47603 m
.90024 .47611 L
s
1 .021 0 r
.62841 .55696 m
.62847 .55711 L
s
1 .035 0 r
.51836 .82704 m
.51837 .82712 L
s
.51837 .82678 m
.51836 .82704 L
s
.51864 .82696 m
.51836 .82704 L
s
.51837 .82686 m
.51837 .82678 L
s
.51837 .82678 m
.51864 .82696 L
s
.51864 .82696 m
.51837 .82712 L
s
.51837 .82686 m
.51864 .82696 L
s
.51729 .82694 m
.51864 .82696 L
s
1 .003 0 r
.57325 .69189 m
.57325 .69189 L
s
.57325 .69187 m
.57325 .69189 L
s
.57327 .69188 m
.57325 .69189 L
s
.57317 .69189 m
.57327 .69188 L
s
1 .116 0 r
.41352 .50282 m
.40977 .50131 L
s
1 0 0 r
.35765 .63787 m
.35765 .63787 L
s
1 .003 0 r
.57325 .69187 m
.57325 .69187 L
s
.57325 .69187 m
.57327 .69188 L
s
.57327 .69188 m
.57325 .69189 L
s
.57325 .69187 m
.57327 .69188 L
s
.57325 .69189 m
.57325 .69187 L
s
1 .65 0 r
.57002 .44967 m
.57164 .44874 L
s
.57164 .44874 m
.56994 .44399 L
s
.57164 .44874 m
.56554 .44828 L
s
1 .035 0 r
.51837 .82712 m
.51837 .82686 L
s
1 .039 0 r
.84084 .44867 m
.841 .44867 L
s
.84097 .44833 m
.84084 .44867 L
s
.84084 .44867 m
.84079 .44846 L
s
.84117 .44855 m
.84084 .44867 L
s
.84155 .44782 m
.84084 .44867 L
s
.84097 .44833 m
.84079 .44846 L
s
.84117 .44855 m
.84097 .44833 L
s
.841 .44867 m
.84117 .44855 L
s
1 .09 0 r
.56731 .5297 m
.56743 .52958 L
s
.56743 .52958 m
.5673 .5289 L
s
.56743 .52958 m
.56664 .5294 L
s
.5673 .5289 m
.56719 .52902 L
s
.5673 .5289 m
.56664 .5294 L
s
1 .039 0 r
.84079 .44846 m
.841 .44867 L
s
1 .65 0 r
.56994 .44399 m
.56832 .44491 L
s
.56994 .44399 m
.56554 .44828 L
s
1 .09 0 r
.56664 .5294 m
.56731 .5297 L
s
.56664 .5294 m
.56719 .52902 L
s
.57 .5289 m
.56664 .5294 L
s
1 .65 0 r
.56554 .44828 m
.57002 .44967 L
s
.56554 .44828 m
.56832 .44491 L
s
.58781 .44101 m
.56554 .44828 L
s
1 .09 0 r
.56719 .52902 m
.56731 .5297 L
s
1 .026 0 r
.45896 .7993 m
.45898 .79936 L
s
.45899 .7991 m
.45896 .7993 L
s
.45919 .79925 m
.45896 .7993 L
s
.45901 .79916 m
.45899 .7991 L
s
.45899 .7991 m
.45919 .79925 L
s
.45919 .79925 m
.45898 .79936 L
s
.45901 .79916 m
.45919 .79925 L
s
.45819 .79915 m
.45919 .79925 L
s
1 .116 0 r
.4105 .50213 m
.41018 .50192 L
s
.41018 .50192 m
.41054 .5011 L
s
.41018 .50192 m
.40977 .50131 L
s
1 .026 0 r
.45898 .79936 m
.45901 .79916 L
s
1 .001 0 r
.78561 .58297 m
.78561 .58297 L
s
.78561 .58296 m
.78561 .58297 L
s
.78561 .58297 m
.78561 .58297 L
s
.78562 .58297 m
.78561 .58297 L
s
.78564 .58295 m
.78561 .58297 L
s
.78561 .58296 m
.78561 .58297 L
s
.78562 .58297 m
.78561 .58296 L
s
.78561 .58297 m
.78562 .58297 L
s
.78561 .58297 m
.78561 .58297 L
s
1 .116 0 r
.41054 .5011 m
.41087 .5013 L
s
.41054 .5011 m
.40977 .50131 L
s
1 0 0 r
.51411 .66403 m
.51411 .66403 L
s
.51411 .66402 m
.51411 .66403 L
s
.51411 .66403 m
.51411 .66403 L
s
.51411 .66403 m
.51411 .66402 L
s
.51411 .66402 m
.51411 .66403 L
s
.51411 .66403 m
.51411 .66403 L
s
.51411 .66403 m
.51411 .66403 L
s
.51409 .66403 m
.51411 .66403 L
s
.29845 .60998 m
.29845 .60997 L
s
1 .114 0 r
.35436 .47485 m
.35135 .47283 L
s
1 0 0 r
.51411 .66403 m
.51411 .66403 L
s
.29845 .60997 m
.29845 .60997 L
s
.29845 .60997 m
.29845 .60997 L
s
.29845 .60997 m
.29845 .60997 L
s
.29845 .60997 m
.29845 .60997 L
s
.29845 .60997 m
.29845 .60997 L
s
.29845 .60997 m
.29845 .60997 L
s
.29845 .60997 m
.29845 .60997 L
s
.29845 .60997 m
.29845 .60997 L
s
1 .116 0 r
.41087 .5013 m
.4105 .50213 L
s
.40977 .50131 m
.4105 .50213 L
s
.40977 .50131 m
.41087 .5013 L
s
1 .229 0 r
.50386 .50157 m
.50376 .50129 L
s
.50376 .50129 m
.50387 .49954 L
s
.50376 .50129 m
.50211 .50046 L
s
.50387 .49954 m
.50397 .49981 L
s
.50387 .49954 m
.50211 .50046 L
s
1 .016 0 r
.39946 .77147 m
.39949 .7715 L
s
.39949 .77135 m
.39946 .77147 L
s
.39961 .77145 m
.39946 .77147 L
s
.39952 .77138 m
.39949 .77135 L
s
.39949 .77135 m
.39961 .77145 L
s
1 .009 0 r
.7264 .55515 m
.72646 .55516 L
s
.72645 .55509 m
.7264 .55515 L
s
.7264 .55515 m
.72642 .55511 L
s
.72649 .55514 m
.7264 .55515 L
s
.72665 .55501 m
.7264 .55515 L
s
1 .016 0 r
.39961 .77145 m
.39949 .7715 L
s
.39952 .77138 m
.39961 .77145 L
s
.39902 .77133 m
.39961 .77145 L
s
1 .009 0 r
.72645 .55509 m
.72642 .55511 L
s
.72649 .55514 m
.72645 .55509 L
s
.72646 .55516 m
.72649 .55514 L
s
.72642 .55511 m
.72646 .55516 L
s
1 .459 0 r
.53531 .47452 m
.53574 .47399 L
s
.53574 .47399 m
.5353 .47047 L
s
.53574 .47399 m
.53182 .47286 L
s
1 .016 0 r
.39949 .7715 m
.39952 .77138 L
s
1 .166 0 r
.60392 .50122 m
.60432 .50096 L
s
.60432 .50096 m
.60389 .49975 L
s
.60432 .50096 m
.60277 .50084 L
s
1 .002 0 r
.67071 .69021 m
.67078 .6902 L
s
1 0 0 r
.45495 .63613 m
.45495 .63613 L
s
1 .229 0 r
.51089 .50093 m
.50211 .50046 L
s
1 .095 0 r
.29513 .44685 m
.29314 .44489 L
s
1 .002 0 r
.67077 .6902 m
.67076 .69021 L
s
.67076 .69019 m
.67077 .6902 L
s
.67078 .6902 m
.67077 .6902 L
s
.67076 .69019 m
.67076 .69019 L
s
.67076 .69019 m
.67078 .6902 L
s
.67078 .6902 m
.67076 .69021 L
s
.67076 .69019 m
.67078 .6902 L
s
.67076 .69021 m
.67076 .69019 L
s
1 .166 0 r
.60389 .49975 m
.60349 .50001 L
s
.60389 .49975 m
.60277 .50084 L
s
.60277 .50084 m
.60392 .50122 L
s
.60277 .50084 m
.60349 .50001 L
s
.60847 .49905 m
.60277 .50084 L
s
1 .459 0 r
.5353 .47047 m
.53488 .471 L
s
.5353 .47047 m
.53182 .47286 L
s
1 .043 0 r
.66628 .52765 m
.66655 .52772 L
s
.66654 .52734 m
.66628 .52765 L
s
.66628 .52765 m
.6664 .52743 L
s
.66669 .52764 m
.66628 .52765 L
s
.66759 .52705 m
.66628 .52765 L
s
.66655 .52772 m
.66669 .52764 L
s
.66669 .52764 m
.66654 .52734 L
s
.66654 .52734 m
.6664 .52743 L
s
1 .114 0 r
.35198 .47273 m
.35241 .47299 L
s
.3515 .47347 m
.35198 .47273 L
s
.35198 .47273 m
.35135 .47283 L
s
.35193 .47374 m
.3515 .47347 L
s
.3515 .47347 m
.35135 .47283 L
s
1 .229 0 r
.50211 .50046 m
.50386 .50157 L
s
.50211 .50046 m
.50397 .49981 L
s
1 .043 0 r
.6664 .52743 m
.66655 .52772 L
s
1 .017 0 r
.93917 .44626 m
.93923 .44625 L
s
.93921 .44611 m
.93917 .44626 L
s
.93917 .44626 m
.93914 .44617 L
s
.9393 .4462 m
.93917 .44626 L
s
.93944 .44588 m
.93917 .44626 L
s
.93921 .44611 m
.93914 .44617 L
s
.9393 .4462 m
.93921 .44611 L
s
.93923 .44625 m
.9393 .4462 L
s
.93914 .44617 m
.93923 .44625 L
s
1 .166 0 r
.60349 .50001 m
.60392 .50122 L
s
1 .008 0 r
.33997 .74356 m
.33999 .74358 L
s
.34 .74351 m
.33997 .74356 L
s
.34005 .74356 m
.33997 .74356 L
s
.34005 .74356 m
.33999 .74358 L
s
.34 .74351 m
.34005 .74356 L
s
.34001 .74353 m
.34005 .74356 L
s
.33978 .74348 m
.34005 .74356 L
s
.34001 .74353 m
.34 .74351 L
s
.33999 .74358 m
.34001 .74353 L
s
1 .114 0 r
.35241 .47299 m
.35193 .47374 L
s
.35135 .47283 m
.35241 .47299 L
s
1 .029 0 r
.55656 .79763 m
.55655 .79769 L
s
.55654 .79741 m
.55656 .79763 L
s
.55677 .79754 m
.55656 .79763 L
s
1 .114 0 r
.35135 .47283 m
.35193 .47374 L
s
1 .029 0 r
.55653 .79748 m
.55654 .79741 L
s
.55654 .79741 m
.55677 .79754 L
s
1 .229 0 r
.50397 .49981 m
.50386 .50157 L
s
1 .029 0 r
.55566 .79759 m
.55677 .79754 L
s
1 0 0 r
.61163 .66232 m
.61164 .66232 L
s
.39575 .60821 m
.39573 .6082 L
s
1 .323 0 r
.45172 .47294 m
.44053 .46944 L
s
1 0 0 r
.61164 .66232 m
.61164 .66232 L
s
.61164 .66231 m
.61164 .66232 L
s
.61164 .66232 m
.61164 .66232 L
s
.61164 .66232 m
.61164 .66231 L
s
.61164 .66231 m
.61164 .66232 L
s
.61164 .66232 m
.61164 .66232 L
s
.61164 .66232 m
.61164 .66232 L
s
.39574 .60821 m
.39574 .60821 L
s
.39574 .60821 m
.39574 .6082 L
s
.39574 .60821 m
.39573 .6082 L
s
.39574 .6082 m
.39574 .6082 L
s
.39574 .6082 m
.39573 .6082 L
s
.61164 .66232 m
.61164 .66232 L
s
.39573 .6082 m
.39574 .60821 L
s
.39573 .6082 m
.39574 .6082 L
s
.39574 .6082 m
.39574 .60821 L
s
1 .029 0 r
.55677 .79754 m
.55655 .79769 L
s
.55653 .79748 m
.55677 .79754 L
s
1 .459 0 r
.53182 .47286 m
.53531 .47452 L
s
.53182 .47286 m
.53488 .471 L
s
.54929 .47102 m
.53182 .47286 L
s
1 .029 0 r
.55655 .79769 m
.55653 .79748 L
s
1 .095 0 r
.29357 .44487 m
.29398 .44513 L
s
.2931 .44544 m
.29357 .44487 L
s
.29357 .44487 m
.29314 .44489 L
s
1 .22 0 r
.64057 .47254 m
.6419 .47282 L
s
.64183 .47088 m
.64057 .47254 L
s
.64057 .47254 m
.64109 .47131 L
s
.64265 .47239 m
.64057 .47254 L
s
.64707 .4691 m
.64057 .47254 L
s
1 .095 0 r
.29351 .4457 m
.2931 .44544 L
s
.2931 .44544 m
.29314 .44489 L
s
1 .22 0 r
.6419 .47282 m
.64265 .47239 L
s
.64265 .47239 m
.64183 .47088 L
s
.64183 .47088 m
.64109 .47131 L
s
1 .65 0 r
.56832 .44491 m
.57002 .44967 L
s
1 .095 0 r
.29398 .44513 m
.29351 .4457 L
s
.29314 .44489 m
.29398 .44513 L
s
.29314 .44489 m
.29351 .4457 L
s
1 .022 0 r
.49714 .76983 m
.49714 .76988 L
s
.49715 .76967 m
.49714 .76983 L
s
.49731 .76978 m
.49714 .76983 L
s
.49715 .76971 m
.49715 .76967 L
s
.49715 .76967 m
.49731 .76978 L
s
1 .003 0 r
.82439 .55325 m
.8244 .55325 L
s
.8244 .55322 m
.82439 .55325 L
s
.82439 .55325 m
.82439 .55323 L
s
.82442 .55324 m
.82439 .55325 L
s
.82447 .55319 m
.82439 .55325 L
s
.8244 .55322 m
.82439 .55323 L
s
.82442 .55324 m
.8244 .55322 L
s
.8244 .55325 m
.82442 .55324 L
s
.82439 .55323 m
.8244 .55325 L
s
1 .022 0 r
.49731 .76978 m
.49714 .76988 L
s
.49715 .76971 m
.49731 .76978 L
s
.49648 .76974 m
.49731 .76978 L
s
1 0 0 r
.55247 .63439 m
.55247 .63439 L
s
1 .003 0 r
.33648 .58026 m
.3364 .58022 L
s
1 .293 0 r
.39248 .44491 m
.38445 .43982 L
s
1 .022 0 r
.49714 .76988 m
.49715 .76971 L
s
1 .003 0 r
.33642 .58021 m
.33643 .58022 L
s
.33641 .58023 m
.33642 .58021 L
s
.33642 .58021 m
.3364 .58022 L
s
.33642 .58024 m
.33641 .58023 L
s
.33641 .58023 m
.3364 .58022 L
s
.33643 .58022 m
.33642 .58024 L
s
.3364 .58022 m
.33643 .58022 L
s
.3364 .58022 m
.33642 .58024 L
s
1 .459 0 r
.53488 .471 m
.53531 .47452 L
s
1 .22 0 r
.64109 .47131 m
.6419 .47282 L
s
1 .015 0 r
.76502 .52547 m
.7651 .52548 L
s
.76509 .52535 m
.76502 .52547 L
s
.76502 .52547 m
.76503 .52539 L
s
.76516 .52544 m
.76502 .52547 L
s
.7654 .52519 m
.76502 .52547 L
s
.76509 .52535 m
.76503 .52539 L
s
.76516 .52544 m
.76509 .52535 L
s
.7651 .52548 m
.76516 .52544 L
s
.76503 .52539 m
.7651 .52548 L
s
1 .062 0 r
.70463 .49824 m
.70497 .4983 L
s
.70494 .49775 m
.70463 .49824 L
s
.70463 .49824 m
.70471 .49789 L
s
.70521 .49815 m
.70463 .49824 L
s
.70627 .49716 m
.70463 .49824 L
s
1 .013 0 r
.43759 .74195 m
.43761 .74198 L
s
.43761 .74186 m
.43759 .74195 L
s
.43771 .74193 m
.43759 .74195 L
s
.43763 .74188 m
.43761 .74186 L
s
.43761 .74186 m
.43771 .74193 L
s
.43771 .74193 m
.43761 .74198 L
s
.43763 .74188 m
.43771 .74193 L
s
.43723 .74186 m
.43771 .74193 L
s
1 .062 0 r
.70494 .49775 m
.70471 .49789 L
s
.70521 .49815 m
.70494 .49775 L
s
1 .323 0 r
.44273 .47157 m
.44198 .47108 L
s
.44198 .47108 m
.4428 .46871 L
s
.44198 .47108 m
.44053 .46944 L
s
1 .062 0 r
.70497 .4983 m
.70521 .49815 L
s
1 .013 0 r
.43761 .74198 m
.43763 .74188 L
s
1 .001 0 r
.49323 .60644 m
.49323 .60644 L
s
.49323 .60644 m
.49323 .60643 L
s
.49323 .60644 m
.49323 .60644 L
s
1 0 0 r
.70937 .66061 m
.70938 .66061 L
s
1 .001 0 r
.49326 .60644 m
.49323 .60644 L
s
1 .006 0 r
.27715 .55227 m
.277 .55217 L
s
1 .001 0 r
.49323 .60643 m
.49323 .60643 L
s
.49323 .60643 m
.49323 .60644 L
s
1 0 0 r
.70938 .66061 m
.70938 .66061 L
s
.70938 .6606 m
.70938 .66061 L
s
.70938 .66061 m
.70938 .66061 L
s
.70938 .66061 m
.70938 .6606 L
s
.70938 .6606 m
.70938 .66061 L
s
.70938 .66061 m
.70938 .66061 L
s
.70938 .66061 m
.70938 .66061 L
s
1 .001 0 r
.49323 .60644 m
.49323 .60644 L
s
.49323 .60644 m
.49323 .60643 L
s
1 0 0 r
.70938 .66061 m
.70938 .66061 L
s
1 .001 0 r
.49323 .60643 m
.49323 .60644 L
s
1 .006 0 r
.27704 .55217 m
.27706 .55218 L
s
.27701 .5522 m
.27704 .55217 L
s
.27704 .55217 m
.277 .55217 L
s
.27703 .55222 m
.27701 .5522 L
s
.27701 .5522 m
.277 .55217 L
s
.27706 .55218 m
.27703 .55222 L
s
.277 .55217 m
.27706 .55218 L
s
1 .323 0 r
.4428 .46871 m
.44356 .46919 L
s
.4428 .46871 m
.44053 .46944 L
s
1 .006 0 r
.277 .55217 m
.27703 .55222 L
s
1 .062 0 r
.70471 .49789 m
.70497 .4983 L
s
1 .233 0 r
.68023 .44355 m
.68139 .44368 L
s
.68129 .44163 m
.68023 .44355 L
s
.68023 .44355 m
.68032 .4422 L
s
.68235 .4431 m
.68023 .44355 L
s
.6858 .43905 m
.68023 .44355 L
s
.68129 .44163 m
.68032 .4422 L
s
.68235 .4431 m
.68129 .44163 L
s
.68139 .44368 m
.68235 .4431 L
s
1 .005 0 r
.37805 .714 m
.37807 .71401 L
s
.37807 .71396 m
.37805 .714 L
s
.3781 .714 m
.37805 .714 L
s
.37808 .71397 m
.37807 .71396 L
s
.37807 .71396 m
.3781 .714 L
s
.3781 .714 m
.37807 .71401 L
s
.37808 .71397 m
.3781 .714 L
s
.37792 .71395 m
.3781 .714 L
s
.37807 .71401 m
.37808 .71397 L
s
1 .021 0 r
.59415 .76815 m
.59494 .76806 L
s
1 0 0 r
.65021 .63265 m
.65021 .63265 L
s
1 .007 0 r
.43398 .57845 m
.43374 .57839 L
s
1 .741 0 r
.49004 .44296 m
.46242 .43797 L
s
1 .021 0 r
.59481 .76813 m
.59479 .76818 L
s
.59478 .76798 m
.59481 .76813 L
s
.59494 .76806 m
.59481 .76813 L
s
1 .007 0 r
.43379 .57844 m
.43377 .57842 L
s
.43377 .57842 m
.43379 .57837 L
s
.43377 .57842 m
.43374 .57839 L
s
1 .021 0 r
.59476 .76802 m
.59478 .76798 L
s
.59478 .76798 m
.59494 .76806 L
s
1 .007 0 r
.43379 .57837 m
.4338 .57839 L
s
.43379 .57837 m
.43374 .57839 L
s
.43374 .57839 m
.43379 .57844 L
s
.43374 .57839 m
.4338 .57839 L
s
.4338 .57839 m
.43379 .57844 L
s
1 .021 0 r
.59494 .76806 m
.59479 .76818 L
s
.59476 .76802 m
.59494 .76806 L
s
.59479 .76818 m
.59476 .76802 L
s
1 .323 0 r
.44053 .46944 m
.44273 .47157 L
s
.44053 .46944 m
.44356 .46919 L
s
.44356 .46919 m
.44273 .47157 L
s
1 .233 0 r
.68032 .4422 m
.68139 .44368 L
s
1 .006 0 r
.86329 .52345 m
.86332 .52345 L
s
.86331 .52339 m
.86329 .52345 L
s
.86329 .52345 m
.86329 .52341 L
s
.86335 .52343 m
.86329 .52345 L
s
.86342 .52332 m
.86329 .52345 L
s
.86331 .52339 m
.86329 .52341 L
s
.86335 .52343 m
.86331 .52339 L
s
.86332 .52345 m
.86335 .52343 L
s
.86329 .52341 m
.86332 .52345 L
s
1 .015 0 r
.53537 .74027 m
.53537 .7403 L
s
.53537 .74015 m
.53537 .74027 L
s
.53549 .74022 m
.53537 .74027 L
s
.53537 .74018 m
.53537 .74015 L
s
.53537 .74015 m
.53549 .74022 L
s
1 .001 0 r
.31859 .68602 m
.31858 .68603 L
s
.31858 .68601 m
.31859 .68602 L
s
.31859 .68602 m
.31857 .68602 L
s
.31858 .68602 m
.31859 .68602 L
s
.31854 .68601 m
.31859 .68602 L
s
.31857 .68602 m
.31858 .68603 L
s
.31858 .68601 m
.31857 .68602 L
s
.31858 .68602 m
.31858 .68601 L
s
.31858 .68603 m
.31858 .68602 L
s
.59096 .60467 m
.59096 .60467 L
s
.59096 .60467 m
.59096 .60467 L
s
.59096 .60467 m
.59095 .60467 L
s
.59096 .60467 m
.59096 .60467 L
s
.59096 .60467 m
.59095 .60467 L
s
.59095 .60467 m
.59096 .60467 L
s
.59095 .60467 m
.59096 .60467 L
s
.59098 .60467 m
.59095 .60467 L
s
.59096 .60467 m
.59096 .60467 L
s
1 .015 0 r
.53489 .74023 m
.53549 .74022 L
s
1 .016 0 r
.37463 .55044 m
.37414 .55021 L
s
1 .015 0 r
.53549 .74022 m
.53537 .7403 L
s
.53537 .74018 m
.53549 .74022 L
s
.53537 .7403 m
.53537 .74018 L
s
1 .016 0 r
.37423 .55033 m
.37419 .5503 L
s
.37419 .5503 m
.37424 .55018 L
s
.37419 .5503 m
.37414 .55021 L
s
.37424 .55018 m
.37429 .55022 L
s
.37424 .55018 m
.37414 .55021 L
s
.37429 .55022 m
.37423 .55033 L
s
.37414 .55021 m
.37423 .55033 L
s
.37414 .55021 m
.37429 .55022 L
s
1 .293 0 r
.38611 .43956 m
.3872 .44017 L
s
.38492 .44151 m
.38611 .43956 L
s
.38611 .43956 m
.38445 .43982 L
s
1 .073 0 r
.74345 .46863 m
.74379 .46866 L
s
.74375 .46802 m
.74345 .46863 L
s
.74345 .46863 m
.74344 .46822 L
s
.7441 .46846 m
.74345 .46863 L
s
.74507 .46717 m
.74345 .46863 L
s
1 .293 0 r
.386 .44212 m
.38492 .44151 L
s
.38492 .44151 m
.38445 .43982 L
s
1 .022 0 r
.80381 .4957 m
.80391 .49571 L
s
.8039 .49552 m
.80381 .4957 L
s
.80381 .4957 m
.8038 .49558 L
s
.80401 .49565 m
.80381 .4957 L
s
.80428 .49526 m
.80381 .4957 L
s
.8039 .49552 m
.8038 .49558 L
s
.80401 .49565 m
.8039 .49552 L
s
.80391 .49571 m
.80401 .49565 L
s
1 .073 0 r
.74375 .46802 m
.74344 .46822 L
s
.7441 .46846 m
.74375 .46802 L
s
0 .04 1 r
.43733 .44708 m
.44881 .4414 L
s
.44881 .4414 m
.43829 .41229 L
s
.44881 .4414 m
.41128 .43856 L
s
1 .741 0 r
.4679 .44222 m
.46686 .44137 L
s
.46686 .44137 m
.46801 .43573 L
s
.46686 .44137 m
.46242 .43797 L
s
1 .073 0 r
.74379 .46866 m
.7441 .46846 L
s
1 .022 0 r
.8038 .49558 m
.80391 .49571 L
s
1 .073 0 r
.74344 .46822 m
.74379 .46866 L
s
1 .008 0 r
.47581 .71234 m
.47582 .71235 L
s
.47582 .71228 m
.47581 .71234 L
s
.47588 .71232 m
.47581 .71234 L
s
.47583 .71229 m
.47582 .71228 L
s
.47582 .71228 m
.47588 .71232 L
s
1 .01 0 r
.53137 .5767 m
.53137 .57669 L
s
.53137 .57669 m
.53137 .57661 L
s
.53137 .57669 m
.53129 .57666 L
s
1 .008 0 r
.47588 .71232 m
.47582 .71235 L
s
.47583 .71229 m
.47588 .71232 L
s
.47557 .71229 m
.47588 .71232 L
s
1 .01 0 r
.53137 .57661 m
.53137 .57662 L
s
.53137 .57661 m
.53129 .57666 L
s
.53129 .57666 m
.53137 .5767 L
s
.53129 .57666 m
.53137 .57662 L
s
.53169 .57665 m
.53129 .57666 L
s
1 .008 0 r
.47582 .71235 m
.47583 .71229 L
s
1 0 0 r
.74815 .63091 m
.74815 .63091 L
s
1 .022 0 r
.31522 .52239 m
.31465 .52199 L
s
1 .01 0 r
.53137 .57662 m
.53137 .5767 L
s
1 .741 0 r
.46801 .43573 m
.46905 .43657 L
s
.46801 .43573 m
.46242 .43797 L
s
1 .022 0 r
.31477 .52197 m
.31485 .52203 L
s
.31467 .52212 m
.31477 .52197 L
s
.31477 .52197 m
.31465 .52199 L
s
.31475 .52217 m
.31467 .52212 L
s
.31467 .52212 m
.31465 .52199 L
s
.31485 .52203 m
.31475 .52217 L
s
.31465 .52199 m
.31485 .52203 L
s
.31465 .52199 m
.31475 .52217 L
s
1 .028 0 r
.36076 .82028 m
.36082 .82035 L
s
.36083 .82008 m
.36076 .82028 L
s
.36102 .82026 m
.36076 .82028 L
s
.36088 .82015 m
.36083 .82008 L
s
.36083 .82008 m
.36102 .82026 L
s
.36102 .82026 m
.36082 .82035 L
s
.36088 .82015 m
.36102 .82026 L
s
.36003 .82003 m
.36102 .82026 L
s
.36082 .82035 m
.36088 .82015 L
s
1 .293 0 r
.3872 .44017 m
.386 .44212 L
s
.38445 .43982 m
.3872 .44017 L
s
.38445 .43982 m
.386 .44212 L
s
1 .003 0 r
.41625 .68434 m
.41626 .68435 L
s
.41626 .68432 m
.41625 .68434 L
s
.41627 .68434 m
.41625 .68434 L
s
.41626 .68433 m
.41626 .68432 L
s
.41626 .68432 m
.41627 .68434 L
s
.41627 .68434 m
.41626 .68435 L
s
.41626 .68433 m
.41627 .68434 L
s
.41618 .68432 m
.41627 .68434 L
s
.41626 .68435 m
.41626 .68433 L
s
1 0 0 r
.6889 .60289 m
.68891 .60289 L
s
.68891 .60289 m
.6889 .60289 L
s
.6889 .60289 m
.68891 .60289 L
s
.68891 .60289 m
.6889 .60289 L
s
.68892 .60289 m
.6889 .60289 L
s
.68891 .60289 m
.68891 .60289 L
s
.68891 .60289 m
.68891 .60289 L
s
.68891 .60289 m
.68891 .60289 L
s
.68891 .60289 m
.68891 .60289 L
s
1 .013 0 r
.63277 .7386 m
.63323 .73852 L
s
0 .04 1 r
.63678 .44003 m
.62362 .44095 L
s
.62254 .4061 m
.63678 .44003 L
s
.63678 .44003 m
.60337 .42989 L
s
.64293 .41692 m
.63678 .44003 L
s
.56563 .35383 m
.63678 .44003 L
s
1 .039 0 r
.47233 .5486 m
.47088 .54835 L
s
1 .024 0 r
.25575 .49431 m
.25523 .49383 L
s
1 .013 0 r
.63316 .73857 m
.63314 .7386 L
s
.63314 .73847 m
.63316 .73857 L
s
.63323 .73852 m
.63316 .73857 L
s
.63312 .7385 m
.63314 .73847 L
s
.63314 .73847 m
.63323 .73852 L
s
1 .039 0 r
.47117 .54858 m
.47112 .54852 L
s
.47112 .54852 m
.47118 .54823 L
s
.47112 .54852 m
.47088 .54835 L
s
1 .013 0 r
.63323 .73852 m
.63314 .7386 L
s
.63312 .7385 m
.63323 .73852 L
s
1 .039 0 r
.47118 .54823 m
.47123 .54829 L
s
.47118 .54823 m
.47088 .54835 L
s
1 .013 0 r
.63314 .7386 m
.63312 .7385 L
s
1 .039 0 r
.47088 .54835 m
.47117 .54858 L
s
.47088 .54835 m
.47123 .54829 L
s
.47123 .54829 m
.47117 .54858 L
s
1 .024 0 r
.25534 .49382 m
.25544 .49389 L
s
.25522 .49396 m
.25534 .49382 L
s
.25534 .49382 m
.25523 .49383 L
s
.25532 .49403 m
.25522 .49396 L
s
.25522 .49396 m
.25523 .49383 L
s
.25544 .49389 m
.25532 .49403 L
s
.25523 .49383 m
.25544 .49389 L
s
.25523 .49383 m
.25532 .49403 L
s
0 .04 1 r
.43829 .41229 m
.42667 .41762 L
s
.43829 .41229 m
.41128 .43856 L
s
1 .009 0 r
.90234 .49355 m
.90237 .49355 L
s
.90237 .49347 m
.90234 .49355 L
s
.90234 .49355 m
.90233 .4935 L
s
.90241 .49352 m
.90234 .49355 L
s
.9025 .49336 m
.90234 .49355 L
s
.90237 .49347 m
.90233 .4935 L
s
.90241 .49352 m
.90237 .49347 L
s
.90237 .49355 m
.90241 .49352 L
s
.90233 .4935 m
.90237 .49355 L
s
1 .007 0 r
.62943 .57493 m
.62944 .57491 L
s
.62944 .57491 m
.62943 .57486 L
s
.62944 .57491 m
.62938 .57491 L
s
.62943 .57486 m
.62941 .57488 L
s
.62943 .57486 m
.62938 .57491 L
s
.62938 .57491 m
.62943 .57493 L
s
.62938 .57491 m
.62941 .57488 L
s
.62961 .57484 m
.62938 .57491 L
s
.62941 .57488 m
.62943 .57493 L
s
1 0 0 r
.35674 .65632 m
.35674 .65632 L
s
.35674 .65631 m
.35674 .65632 L
s
.35674 .65632 m
.35674 .65632 L
s
.35674 .65632 m
.35674 .65632 L
s
.35674 .65631 m
.35674 .65632 L
s
.35674 .65632 m
.35674 .65632 L
s
.35673 .65631 m
.35674 .65632 L
s
.35674 .65632 m
.35674 .65631 L
s
.35674 .65632 m
.35674 .65632 L
s
1 .009 0 r
.5737 .71063 m
.5737 .71065 L
s
.5737 .71056 m
.5737 .71063 L
s
.57376 .7106 m
.5737 .71063 L
s
.57343 .71063 m
.57376 .7106 L
s
1 .068 0 r
.41291 .52052 m
.4107 .51964 L
s
1 .009 0 r
.57369 .71058 m
.5737 .71056 L
s
.5737 .71056 m
.57376 .7106 L
s
.57376 .7106 m
.5737 .71065 L
s
.57369 .71058 m
.57376 .7106 L
s
.5737 .71065 m
.57369 .71058 L
s
1 .077 0 r
.7826 .43876 m
.7829 .43876 L
s
.78285 .43809 m
.7826 .43876 L
s
.7826 .43876 m
.7825 .43832 L
s
.78325 .43853 m
.7826 .43876 L
s
.784 .43708 m
.7826 .43876 L
s
1 .026 0 r
.8428 .46581 m
.84291 .46581 L
s
.84288 .46558 m
.8428 .46581 L
s
.8428 .46581 m
.84277 .46566 L
s
.84303 .46573 m
.8428 .46581 L
s
.84328 .46524 m
.8428 .46581 L
s
1 .077 0 r
.78285 .43809 m
.7825 .43832 L
s
.78325 .43853 m
.78285 .43809 L
s
1 .026 0 r
.84288 .46558 m
.84277 .46566 L
s
.84303 .46573 m
.84288 .46558 L
s
.84291 .46581 m
.84303 .46573 L
s
0 .04 1 r
.41128 .43856 m
.43733 .44708 L
s
.41128 .43856 m
.42667 .41762 L
s
.54668 .3928 m
.41128 .43856 L
s
1 .077 0 r
.7829 .43876 m
.78325 .43853 L
s
1 .068 0 r
.41113 .52012 m
.41094 .52 L
s
.41094 .52 m
.41116 .51952 L
s
.41094 .52 m
.4107 .51964 L
s
1 .026 0 r
.84277 .46566 m
.84291 .46581 L
s
1 .068 0 r
.41116 .51952 m
.41135 .51964 L
s
.41116 .51952 m
.4107 .51964 L
s
1 .043 0 r
.56895 .54715 m
.569 .54708 L
s
.569 .54708 m
.56894 .54675 L
s
.569 .54708 m
.56862 .547 L
s
.56894 .54675 m
.56889 .54682 L
s
.56894 .54675 m
.56862 .547 L
s
1 .039 0 r
.45897 .81871 m
.45901 .8188 L
s
.45901 .81841 m
.45897 .81871 L
s
.45931 .81863 m
.45897 .81871 L
s
1 .077 0 r
.7825 .43832 m
.7829 .43876 L
s
1 .043 0 r
.56862 .547 m
.56895 .54715 L
s
.56862 .547 m
.56889 .54682 L
s
.57025 .54676 m
.56862 .547 L
s
1 .039 0 r
.45905 .8185 m
.45901 .81841 L
s
.45901 .81841 m
.45931 .81863 L
s
.45931 .81863 m
.45901 .8188 L
s
.45905 .8185 m
.45931 .81863 L
s
.45782 .81849 m
.45931 .81863 L
s
1 .575 0 r
.61121 .4382 m
.61443 .43873 L
s
.61429 .43368 m
.61121 .4382 L
s
.61121 .4382 m
.6121 .43487 L
s
.61662 .43754 m
.61121 .4382 L
s
.62702 .4282 m
.61121 .4382 L
s
1 .043 0 r
.56889 .54682 m
.56895 .54715 L
s
1 .068 0 r
.41135 .51964 m
.41113 .52012 L
s
.4107 .51964 m
.41113 .52012 L
s
.4107 .51964 m
.41135 .51964 L
s
0 1 .511 r
.55698 .43812 m
.56289 .43773 L
s
.56263 .41566 m
.55698 .43812 L
s
.55698 .43812 m
.54939 .4242 L
s
.5761 .4291 m
.55698 .43812 L
s
.58665 .37929 m
.55698 .43812 L
s
1 .039 0 r
.45901 .8188 m
.45905 .8185 L
s
1 .004 0 r
.51415 .68264 m
.51415 .68265 L
s
.51415 .68261 m
.51415 .68264 L
s
.51418 .68263 m
.51415 .68264 L
s
.51415 .68262 m
.51415 .68261 L
s
.51415 .68261 m
.51418 .68263 L
s
.51418 .68263 m
.51415 .68265 L
s
.51415 .68262 m
.51418 .68263 L
s
.51403 .68262 m
.51418 .68263 L
s
1 0 0 r
.78706 .60111 m
.78706 .60111 L
s
.78706 .60111 m
.78706 .60111 L
s
.78706 .60111 m
.78706 .60111 L
s
.78706 .60111 m
.78706 .60111 L
s
.78707 .60111 m
.78706 .60111 L
s
.78706 .60111 m
.78706 .60111 L
s
.78706 .60111 m
.78706 .60111 L
s
.78706 .60111 m
.78706 .60111 L
s
.78706 .60111 m
.78706 .60111 L
s
.29721 .62828 m
.29721 .62828 L
s
1 .075 0 r
.35343 .49241 m
.35145 .4911 L
s
1 .004 0 r
.51415 .68265 m
.51415 .68262 L
s
1 .741 0 r
.46242 .43797 m
.4679 .44222 L
s
.46242 .43797 m
.46905 .43657 L
s
1 .575 0 r
.61429 .43368 m
.6121 .43487 L
s
.61662 .43754 m
.61429 .43368 L
s
.61443 .43873 m
.61662 .43754 L
s
1 .525 0 r
.5737 .46546 m
.575 .46468 L
s
.575 .46468 m
.57363 .46082 L
s
.575 .46468 m
.57005 .4643 L
s
1 .026 0 r
.39905 .79074 m
.39909 .79081 L
s
.3991 .79055 m
.39905 .79074 L
s
.39929 .79071 m
.39905 .79074 L
s
.39914 .79061 m
.3991 .79055 L
s
.3991 .79055 m
.39929 .79071 L
s
.39929 .79071 m
.39909 .79081 L
s
.39914 .79061 m
.39929 .79071 L
s
.39833 .79053 m
.39929 .79071 L
s
1 .141 0 r
.50645 .51905 m
.50639 .51887 L
s
.50639 .51887 m
.50646 .51778 L
s
.50639 .51887 m
.50537 .51836 L
s
1 .525 0 r
.57363 .46082 m
.57232 .46159 L
s
.57363 .46082 m
.57005 .4643 L
s
1 .026 0 r
.39909 .79081 m
.39914 .79061 L
s
1 .141 0 r
.50646 .51778 m
.50652 .51796 L
s
.50646 .51778 m
.50537 .51836 L
s
1 .075 0 r
.35186 .49103 m
.35214 .4912 L
s
.35154 .49152 m
.35186 .49103 L
s
.35186 .49103 m
.35145 .4911 L
s
.35182 .49169 m
.35154 .49152 L
s
.35154 .49152 m
.35145 .4911 L
s
1 .741 0 r
.46905 .43657 m
.4679 .44222 L
s
1 .003 0 r
.72768 .57307 m
.72769 .57307 L
s
.72769 .57305 m
.72768 .57307 L
s
.72768 .57307 m
.72768 .57305 L
s
.7277 .57307 m
.72768 .57307 L
s
.72775 .57303 m
.72768 .57307 L
s
.72769 .57305 m
.72768 .57305 L
s
.7277 .57307 m
.72769 .57305 L
s
.72769 .57307 m
.7277 .57307 L
s
1 .525 0 r
.57005 .4643 m
.5737 .46546 L
s
.57005 .4643 m
.57232 .46159 L
s
.58815 .45845 m
.57005 .4643 L
s
1 .003 0 r
.72768 .57305 m
.72769 .57307 L
s
1 .001 0 r
.45458 .65459 m
.45459 .65459 L
s
.45459 .65459 m
.45458 .65459 L
s
.45459 .65459 m
.45458 .65459 L
s
.45459 .65459 m
.45459 .65459 L
s
.45459 .65459 m
.45459 .65459 L
s
.45459 .65459 m
.45459 .65459 L
s
.45459 .65459 m
.45459 .65459 L
s
.45457 .65459 m
.45459 .65459 L
s
.45459 .65459 m
.45459 .65459 L
s
1 .006 0 r
.67151 .70897 m
.67171 .70891 L
s
1 .141 0 r
.51081 .51865 m
.50537 .51836 L
s
1 .066 0 r
.29387 .46427 m
.29247 .46291 L
s
1 .006 0 r
.67169 .70894 m
.67167 .70895 L
s
.67167 .70889 m
.67169 .70894 L
s
.67171 .70891 m
.67169 .70894 L
s
.67166 .70891 m
.67167 .70889 L
s
.67167 .70889 m
.67171 .70891 L
s
.67171 .70891 m
.67167 .70895 L
s
.67166 .70891 m
.67171 .70891 L
s
.67167 .70895 m
.67166 .70891 L
s
1 .075 0 r
.35214 .4912 m
.35182 .49169 L
s
.35145 .4911 m
.35214 .4912 L
s
.35145 .4911 m
.35182 .49169 L
s
1 .141 0 r
.50537 .51836 m
.50645 .51905 L
s
.50537 .51836 m
.50652 .51796 L
s
.50652 .51796 m
.50645 .51905 L
s
1 .02 0 r
.66776 .54519 m
.66789 .54523 L
s
.66788 .54505 m
.66776 .54519 L
s
.66776 .54519 m
.66782 .54509 L
s
.66795 .54519 m
.66776 .54519 L
s
.66837 .54491 m
.66776 .54519 L
s
.66789 .54523 m
.66795 .54519 L
s
.66795 .54519 m
.66788 .54505 L
s
.66788 .54505 m
.66782 .54509 L
s
1 .336 0 r
.53914 .49118 m
.53945 .49076 L
s
.53945 .49076 m
.53913 .48818 L
s
.53945 .49076 m
.53656 .48994 L
s
1 .011 0 r
.94153 .46355 m
.94157 .46355 L
s
.94156 .46345 m
.94153 .46355 L
s
.94153 .46355 m
.94151 .46349 L
s
.94162 .46351 m
.94153 .46355 L
s
.94171 .4633 m
.94153 .46355 L
s
.94156 .46345 m
.94151 .46349 L
s
.94162 .46351 m
.94156 .46345 L
s
1 .1 0 r
.60618 .51808 m
.60642 .51791 L
s
.60642 .51791 m
.60616 .51718 L
s
.60642 .51791 m
.60548 .51785 L
s
1 .011 0 r
.94157 .46355 m
.94162 .46351 L
s
1 .02 0 r
.66782 .54509 m
.66789 .54523 L
s
1 .011 0 r
.94151 .46349 m
.94157 .46355 L
s
1 .014 0 r
.33912 .76269 m
.33916 .76272 L
s
.33916 .76259 m
.33912 .76269 L
s
.33926 .76268 m
.33912 .76269 L
s
.33926 .76268 m
.33916 .76272 L
s
.33916 .76259 m
.33926 .76268 L
s
.3392 .76262 m
.33926 .76268 L
s
.33877 .76254 m
.33926 .76268 L
s
.3392 .76262 m
.33916 .76259 L
s
1 .1 0 r
.60616 .51718 m
.60592 .51735 L
s
.60616 .51718 m
.60548 .51785 L
s
.60548 .51785 m
.60618 .51808 L
s
.60548 .51785 m
.60592 .51735 L
s
.60893 .51677 m
.60548 .51785 L
s
1 .014 0 r
.33916 .76272 m
.3392 .76262 L
s
1 .043 0 r
.55716 .817 m
.55714 .81709 L
s
.55714 .81668 m
.55716 .817 L
s
.55747 .81687 m
.55716 .817 L
s
1 .066 0 r
.29277 .46289 m
.29306 .46308 L
s
.29244 .46329 m
.29277 .46289 L
s
.29277 .46289 m
.29247 .46291 L
s
1 .043 0 r
.55712 .81677 m
.55714 .81668 L
s
.55714 .81668 m
.55747 .81687 L
s
.55582 .81694 m
.55747 .81687 L
s
1 .003 0 r
.6121 .68093 m
.61222 .68091 L
s
1 0 0 r
.39504 .62652 m
.39504 .62652 L
s
1 .229 0 r
.45132 .49051 m
.44336 .48805 L
s
1 .055 0 r
.23426 .4361 m
.23332 .43488 L
s
1 .003 0 r
.6122 .68092 m
.61219 .68093 L
s
.61219 .6809 m
.6122 .68092 L
s
.61222 .68091 m
.6122 .68092 L
s
.61219 .6809 m
.61219 .6809 L
s
.61219 .6809 m
.61222 .68091 L
s
1 .066 0 r
.29273 .46348 m
.29244 .46329 L
s
.29244 .46329 m
.29247 .46291 L
s
1 .336 0 r
.53913 .48818 m
.53882 .48859 L
s
.53913 .48818 m
.53656 .48994 L
s
1 .003 0 r
.61222 .68091 m
.61219 .68093 L
s
.61219 .6809 m
.61222 .68091 L
s
.61219 .68093 m
.61219 .6809 L
s
1 .043 0 r
.55747 .81687 m
.55714 .81709 L
s
.55712 .81677 m
.55747 .81687 L
s
.55714 .81709 m
.55712 .81677 L
s
1 .066 0 r
.29306 .46308 m
.29273 .46348 L
s
.29247 .46291 m
.29306 .46308 L
s
.29247 .46291 m
.29273 .46348 L
s
1 .029 0 r
.88196 .43578 m
.88206 .43578 L
s
.88204 .43552 m
.88196 .43578 L
s
.88196 .43578 m
.8819 .43562 L
s
.8822 .43568 m
.88196 .43578 L
s
.88241 .43512 m
.88196 .43578 L
s
1 .1 0 r
.60592 .51735 m
.60618 .51808 L
s
1 .029 0 r
.88204 .43552 m
.8819 .43562 L
s
.8822 .43568 m
.88204 .43552 L
s
.88206 .43578 m
.8822 .43568 L
s
.8819 .43562 m
.88206 .43578 L
s
1 .336 0 r
.53656 .48994 m
.53914 .49118 L
s
.53656 .48994 m
.53882 .48859 L
s
.54942 .4886 m
.53656 .48994 L
s
1 .035 0 r
.49739 .78909 m
.4974 .78917 L
s
.4974 .78883 m
.49739 .78909 L
s
.49767 .78901 m
.49739 .78909 L
s
.49742 .7889 m
.4974 .78883 L
s
.4974 .78883 m
.49767 .78901 L
s
1 .055 0 r
.23353 .43488 m
.23378 .43506 L
s
.23323 .43519 m
.23353 .43488 L
s
.23353 .43488 m
.23332 .43488 L
s
1 .035 0 r
.49767 .78901 m
.4974 .78917 L
s
.49742 .7889 m
.49767 .78901 L
s
.49632 .78895 m
.49767 .78901 L
s
1 .055 0 r
.23348 .43536 m
.23323 .43519 L
s
.23323 .43519 m
.23332 .43488 L
s
1 .001 0 r
.82608 .57123 m
.82609 .57123 L
s
.82609 .57122 m
.82608 .57123 L
s
.82608 .57123 m
.82608 .57122 L
s
.82609 .57122 m
.82608 .57123 L
s
.82611 .57121 m
.82608 .57123 L
s
.82609 .57122 m
.82608 .57122 L
s
.82609 .57122 m
.82609 .57122 L
s
.82609 .57123 m
.82609 .57122 L
s
.82608 .57122 m
.82609 .57123 L
s
.55264 .65286 m
.55264 .65286 L
s
.55264 .65286 m
.55264 .65286 L
s
.55265 .65286 m
.55264 .65286 L
s
.55264 .65286 m
.55264 .65286 L
s
.55264 .65286 m
.55265 .65286 L
s
.55262 .65286 m
.55265 .65286 L
s
1 0 0 r
.33545 .59843 m
.33544 .59842 L
s
1 .22 0 r
.39175 .46234 m
.38569 .45853 L
s
1 .001 0 r
.55265 .65286 m
.55264 .65286 L
s
.55264 .65286 m
.55265 .65286 L
s
.55264 .65286 m
.55264 .65286 L
s
1 0 0 r
.33544 .59842 m
.33544 .59842 L
s
.33544 .59842 m
.33544 .59842 L
s
.33544 .59842 m
.33544 .59842 L
s
.33544 .59842 m
.33544 .59842 L
s
.33544 .59842 m
.33544 .59842 L
s
.33544 .59842 m
.33544 .59842 L
s
.33544 .59842 m
.33544 .59842 L
s
.33544 .59842 m
.33544 .59842 L
s
1 .035 0 r
.4974 .78917 m
.49742 .7889 L
s
1 .055 0 r
.23378 .43506 m
.23348 .43536 L
s
.23332 .43488 m
.23378 .43506 L
s
.23332 .43488 m
.23348 .43536 L
s
.808 1 0 r
.49136 .43617 m
.49171 .43498 L
s
.49171 .43498 m
.49148 .4257 L
s
.49171 .43498 m
.48215 .43111 L
s
.542 1 0 r
.52731 .43699 m
.53115 .43494 L
s
.53115 .43494 m
.52731 .42419 L
s
.53115 .43494 m
.51735 .43389 L
s
1 .575 0 r
.6121 .43487 m
.61443 .43873 L
s
1 .229 0 r
.44493 .48956 m
.44439 .4892 L
s
.44439 .4892 m
.44498 .48752 L
s
.44439 .4892 m
.44336 .48805 L
s
.44498 .48752 m
.44552 .48787 L
s
.44498 .48752 m
.44336 .48805 L
s
1 .525 0 r
.57232 .46159 m
.5737 .46546 L
s
1 .151 0 r
.64326 .48903 m
.64418 .48924 L
s
.64413 .48789 m
.64326 .48903 L
s
.64326 .48903 m
.64362 .4882 L
s
.6447 .48893 m
.64326 .48903 L
s
.64774 .48669 m
.64326 .48903 L
s
.64418 .48924 m
.6447 .48893 L
s
.6447 .48893 m
.64413 .48789 L
s
.64413 .48789 m
.64362 .4882 L
s
1 .336 0 r
.53882 .48859 m
.53914 .49118 L
s
1 .023 0 r
.43742 .76109 m
.43745 .76114 L
s
.43745 .76092 m
.43742 .76109 L
s
.43762 .76106 m
.43742 .76109 L
s
.43748 .76097 m
.43745 .76092 L
s
.43745 .76092 m
.43762 .76106 L
s
.43762 .76106 m
.43745 .76114 L
s
.43748 .76097 m
.43762 .76106 L
s
.43675 .76093 m
.43762 .76106 L
s
1 .007 0 r
.76655 .54319 m
.76658 .5432 L
s
.76658 .54313 m
.76655 .54319 L
s
.76655 .54319 m
.76655 .54315 L
s
.76661 .54318 m
.76655 .54319 L
s
.76672 .54306 m
.76655 .54319 L
s
.76658 .54313 m
.76655 .54315 L
s
.76661 .54318 m
.76658 .54313 L
s
.76658 .5432 m
.76661 .54318 L
s
.76655 .54315 m
.76658 .5432 L
s
.542 1 0 r
.52731 .42419 m
.52345 .4262 L
s
.52731 .42419 m
.51735 .43389 L
s
1 .023 0 r
.43745 .76114 m
.43748 .76097 L
s
1 .002 0 r
.71038 .67923 m
.71044 .67921 L
s
1 0 0 r
.49308 .62476 m
.49308 .62476 L
s
1 .168 0 r
.33212 .43413 m
.32863 .43061 L
s
1 .002 0 r
.27579 .5703 m
.27574 .57027 L
s
.71043 .67922 m
.71043 .67922 L
s
.71043 .6792 m
.71043 .67922 L
s
.71044 .67921 m
.71043 .67922 L
s
.71042 .67921 m
.71043 .6792 L
s
.71043 .6792 m
.71044 .67921 L
s
.27575 .57026 m
.27576 .57027 L
s
.27574 .57028 m
.27575 .57026 L
s
.27575 .57026 m
.27574 .57027 L
s
.27575 .57028 m
.27574 .57028 L
s
.27574 .57028 m
.27574 .57027 L
s
.71043 .67922 m
.71042 .67921 L
s
.71044 .67921 m
.71043 .67922 L
s
.71042 .67921 m
.71044 .67921 L
s
.27576 .57027 m
.27575 .57028 L
s
.27574 .57027 m
.27576 .57027 L
s
.27574 .57027 m
.27575 .57028 L
s
.808 1 0 r
.49148 .4257 m
.49113 .42686 L
s
.49148 .4257 m
.48215 .43111 L
s
.542 1 0 r
.51735 .43389 m
.52731 .43699 L
s
.51735 .43389 m
.52345 .4262 L
s
.56752 .41722 m
.51735 .43389 L
s
1 .035 0 r
.70633 .5155 m
.70652 .51554 L
s
.70651 .51522 m
.70633 .5155 L
s
.70633 .5155 m
.70637 .51531 L
s
.70666 .51545 m
.70633 .5155 L
s
.70726 .51489 m
.70633 .5155 L
s
.70651 .51522 m
.70637 .51531 L
s
.70666 .51545 m
.70651 .51522 L
s
.70652 .51554 m
.70666 .51545 L
s
1 .151 0 r
.64362 .4882 m
.64418 .48924 L
s
1 .035 0 r
.70637 .51531 m
.70652 .51554 L
s
1 .229 0 r
.44336 .48805 m
.44493 .48956 L
s
.44336 .48805 m
.44552 .48787 L
s
.44552 .48787 m
.44493 .48956 L
s
0 .04 1 r
.62254 .4061 m
.60337 .42989 L
s
.64293 .41692 m
.62254 .4061 L
s
1 .012 0 r
.37742 .73299 m
.37744 .73302 L
s
.37745 .7329 m
.37742 .73299 L
s
.37753 .73298 m
.37742 .73299 L
s
.37747 .73293 m
.37745 .7329 L
s
.37745 .7329 m
.37753 .73298 L
s
.37753 .73298 m
.37744 .73302 L
s
.37747 .73293 m
.37753 .73298 L
s
.37711 .73287 m
.37753 .73298 L
s
.37744 .73302 m
.37747 .73293 L
s
1 .034 0 r
.59453 .78737 m
.59582 .78723 L
s
1 0 0 r
.65089 .65113 m
.65091 .65113 L
s
1 .001 0 r
.43348 .59663 m
.43345 .59663 L
s
1 .607 0 r
.48985 .46039 m
.46712 .45633 L
s
1 0 0 r
.65091 .65113 m
.65091 .65113 L
s
.65091 .65112 m
.65091 .65113 L
s
.65091 .65113 m
.65091 .65113 L
s
.6509 .65112 m
.65091 .65112 L
s
.65091 .65112 m
.65091 .65113 L
s
1 .001 0 r
.43345 .59663 m
.43345 .59663 L
s
.43345 .59663 m
.43345 .59662 L
s
.43345 .59663 m
.43345 .59663 L
s
.43345 .59662 m
.43345 .59662 L
s
.43345 .59662 m
.43345 .59663 L
s
1 0 0 r
.65091 .65113 m
.65091 .65113 L
s
.6509 .65112 m
.65091 .65113 L
s
.65091 .65113 m
.6509 .65112 L
s
1 .001 0 r
.43345 .59663 m
.43345 .59663 L
s
.43345 .59663 m
.43345 .59662 L
s
.43345 .59662 m
.43345 .59663 L
s
1 .034 0 r
.5956 .78735 m
.59556 .78742 L
s
.59556 .78709 m
.5956 .78735 L
s
.59582 .78723 m
.5956 .78735 L
s
.59552 .78717 m
.59556 .78709 L
s
.59556 .78709 m
.59582 .78723 L
s
.59582 .78723 m
.59556 .78742 L
s
.59552 .78717 m
.59582 .78723 L
s
0 1 .511 r
.56263 .41566 m
.54939 .4242 L
s
.5761 .4291 m
.56263 .41566 L
s
1 .034 0 r
.59556 .78742 m
.59552 .78717 L
s
1 .22 0 r
.38694 .45832 m
.38776 .4588 L
s
.38604 .45979 m
.38694 .45832 L
s
.38694 .45832 m
.38569 .45853 L
s
1 .172 0 r
.68254 .45982 m
.6834 .45992 L
s
.68333 .45839 m
.68254 .45982 L
s
.68254 .45982 m
.68261 .45882 L
s
.68412 .45948 m
.68254 .45982 L
s
.68668 .4565 m
.68254 .45982 L
s
1 .22 0 r
.38686 .46027 m
.38604 .45979 L
s
.38604 .45979 m
.38569 .45853 L
s
1 .172 0 r
.68333 .45839 m
.68261 .45882 L
s
.68412 .45948 m
.68333 .45839 L
s
1 .028 0 r
.53583 .75938 m
.53582 .75944 L
s
.53582 .75916 m
.53583 .75938 L
s
.53604 .75929 m
.53583 .75938 L
s
1 .004 0 r
.31754 .70484 m
.31752 .70485 L
s
.31752 .70481 m
.31754 .70484 L
s
.31754 .70484 m
.3175 .70484 L
s
.31753 .70482 m
.31754 .70484 L
s
.31741 .70479 m
.31754 .70484 L
s
1 .172 0 r
.6834 .45992 m
.68412 .45948 L
s
1 .004 0 r
.3175 .70484 m
.31752 .70485 L
s
.31752 .70481 m
.3175 .70484 L
s
.31753 .70482 m
.31752 .70481 L
s
1 .003 0 r
.86522 .54126 m
.86523 .54127 L
s
.86523 .54124 m
.86522 .54126 L
s
.86522 .54126 m
.86522 .54125 L
s
.86524 .54126 m
.86522 .54126 L
s
.86528 .54121 m
.86522 .54126 L
s
1 .028 0 r
.53582 .75922 m
.53582 .75916 L
s
.53582 .75916 m
.53604 .75929 L
s
1 .003 0 r
.86523 .54124 m
.86522 .54125 L
s
.86524 .54126 m
.86523 .54124 L
s
.86523 .54127 m
.86524 .54126 L
s
.86522 .54125 m
.86523 .54127 L
s
1 .004 0 r
.31752 .70485 m
.31753 .70482 L
s
1 0 0 r
.59134 .623 m
.59134 .623 L
s
1 .028 0 r
.53494 .75931 m
.53604 .75929 L
s
1 .005 0 r
.37381 .56847 m
.37365 .5684 L
s
1 .575 0 r
.4302 .43216 m
.41329 .42274 L
s
1 .028 0 r
.53604 .75929 m
.53582 .75944 L
s
.53582 .75922 m
.53604 .75929 L
s
1 .005 0 r
.37368 .56844 m
.37366 .56843 L
s
.37366 .56843 m
.37368 .56839 L
s
.37366 .56843 m
.37365 .5684 L
s
.37368 .56839 m
.3737 .5684 L
s
.37368 .56839 m
.37365 .5684 L
s
.3737 .5684 m
.37368 .56844 L
s
.37365 .5684 m
.37368 .56844 L
s
.37365 .5684 m
.3737 .5684 L
s
1 .028 0 r
.53582 .75944 m
.53582 .75922 L
s
1 .607 0 r
.47163 .45984 m
.47077 .4591 L
s
.47077 .4591 m
.47172 .45446 L
s
.47077 .4591 m
.46712 .45633 L
s
1 .168 0 r
.32938 .43058 m
.33012 .43105 L
s
.32854 .43159 m
.32938 .43058 L
s
.32938 .43058 m
.32863 .43061 L
s
.32928 .43206 m
.32854 .43159 L
s
.32854 .43159 m
.32863 .43061 L
s
1 .172 0 r
.68261 .45882 m
.6834 .45992 L
s
1 .22 0 r
.38776 .4588 m
.38686 .46027 L
s
.38569 .45853 m
.38776 .4588 L
s
.38569 .45853 m
.38686 .46027 L
s
1 .012 0 r
.80556 .51324 m
.80561 .51325 L
s
.8056 .51314 m
.80556 .51324 L
s
.80556 .51324 m
.80555 .51318 L
s
.80566 .51321 m
.80556 .51324 L
s
.80581 .513 m
.80556 .51324 L
s
.8056 .51314 m
.80555 .51318 L
s
.80566 .51321 m
.8056 .51314 L
s
.80561 .51325 m
.80566 .51321 L
s
1 .607 0 r
.47172 .45446 m
.47258 .45519 L
s
.47172 .45446 m
.46712 .45633 L
s
1 .012 0 r
.80555 .51318 m
.80561 .51325 L
s
1 .018 0 r
.47585 .73133 m
.47586 .73137 L
s
.47586 .73119 m
.47585 .73133 L
s
.476 .73129 m
.47585 .73133 L
s
.47588 .73123 m
.47586 .73119 L
s
.47586 .73119 m
.476 .73129 L
s
.476 .73129 m
.47586 .73137 L
s
.47588 .73123 m
.476 .73129 L
s
.4753 .73123 m
.476 .73129 L
s
.47586 .73137 m
.47588 .73123 L
s
1 .001 0 r
.53168 .59485 m
.53168 .59484 L
s
.53168 .59484 m
.53168 .59483 L
s
.53168 .59484 m
.53167 .59484 L
s
.53168 .59483 m
.53168 .59483 L
s
.53168 .59483 m
.53167 .59484 L
s
.53167 .59484 m
.53168 .59485 L
s
.53167 .59484 m
.53168 .59483 L
s
.53172 .59484 m
.53167 .59484 L
s
1 0 0 r
.74938 .64939 m
.74939 .64939 L
s
1 .01 0 r
.31407 .54028 m
.31381 .5401 L
s
1 0 0 r
.74938 .64939 m
.74939 .64939 L
s
.74938 .64939 m
.74938 .64939 L
s
.74938 .64939 m
.74939 .64939 L
s
.74939 .64939 m
.74938 .64939 L
s
.74939 .64939 m
.74939 .64939 L
s
1 .001 0 r
.53168 .59483 m
.53168 .59485 L
s
1 0 0 r
.74938 .64939 m
.74938 .64939 L
s
.74938 .64939 m
.74939 .64939 L
s
.74939 .64939 m
.74938 .64939 L
s
1 .047 0 r
.74523 .4857 m
.74546 .48572 L
s
.74543 .4853 m
.74523 .4857 L
s
.74523 .4857 m
.74523 .48543 L
s
.74566 .48559 m
.74523 .4857 L
s
.74628 .48477 m
.74523 .4857 L
s
.808 1 0 r
.48215 .43111 m
.49136 .43617 L
s
.48215 .43111 m
.49113 .42686 L
s
.5285 .43018 m
.48215 .43111 L
s
1 .047 0 r
.74543 .4853 m
.74523 .48543 L
s
.74566 .48559 m
.74543 .4853 L
s
1 .168 0 r
.33012 .43105 m
.32928 .43206 L
s
.32863 .43061 m
.33012 .43105 L
s
1 .01 0 r
.31386 .54009 m
.3139 .54012 L
s
.31382 .54016 m
.31386 .54009 L
s
.31386 .54009 m
.31381 .5401 L
s
.31386 .54019 m
.31382 .54016 L
s
.31382 .54016 m
.31381 .5401 L
s
1 .047 0 r
.74546 .48572 m
.74566 .48559 L
s
1 .01 0 r
.3139 .54012 m
.31386 .54019 L
s
.31381 .5401 m
.3139 .54012 L
s
.31381 .5401 m
.31386 .54019 L
s
1 .168 0 r
.32863 .43061 m
.32928 .43206 L
s
1 .047 0 r
.74523 .48543 m
.74546 .48572 L
s
1 .008 0 r
.41581 .70318 m
.41582 .7032 L
s
.41582 .70312 m
.41581 .70318 L
s
.41588 .70317 m
.41581 .70318 L
s
.41584 .70314 m
.41582 .70312 L
s
.41582 .70312 m
.41588 .70317 L
s
.41588 .70317 m
.41582 .7032 L
s
.41584 .70314 m
.41588 .70317 L
s
.41558 .70311 m
.41588 .70317 L
s
.41582 .7032 m
.41584 .70314 L
s
1 .023 0 r
.63336 .7577 m
.63422 .75754 L
s
1 0 0 r
.68982 .62123 m
.68982 .62123 L
s
1 .013 0 r
.47204 .56665 m
.47157 .56657 L
s
.25427 .51206 m
.25398 .5118 L
s
.47166 .56664 m
.47164 .56662 L
s
.47164 .56662 m
.47166 .56652 L
s
.47164 .56662 m
.47157 .56657 L
s
.47166 .56652 m
.47168 .56654 L
s
.47166 .56652 m
.47157 .56657 L
s
1 .023 0 r
.63409 .75763 m
.63405 .75768 L
s
.63404 .75746 m
.63409 .75763 L
s
.63422 .75754 m
.63409 .75763 L
s
1 .013 0 r
.47157 .56657 m
.47166 .56664 L
s
.47157 .56657 m
.47168 .56654 L
s
1 .023 0 r
.63401 .75751 m
.63404 .75746 L
s
.63404 .75746 m
.63422 .75754 L
s
1 .013 0 r
.47168 .56654 m
.47166 .56664 L
s
.25404 .51179 m
.2541 .51183 L
s
.25398 .51187 m
.25404 .51179 L
s
.25404 .51179 m
.25398 .5118 L
s
1 .023 0 r
.63422 .75754 m
.63405 .75768 L
s
.63401 .75751 m
.63422 .75754 L
s
1 .013 0 r
.25403 .51191 m
.25398 .51187 L
s
.25398 .51187 m
.25398 .5118 L
s
1 .023 0 r
.63405 .75768 m
.63401 .75751 L
s
1 .013 0 r
.2541 .51183 m
.25403 .51191 L
s
.25398 .5118 m
.2541 .51183 L
s
.25398 .5118 m
.25403 .51191 L
s
0 .04 1 r
.60337 .42989 m
.62362 .44095 L
s
1 .168 0 r
.72261 .42987 m
.72328 .42988 L
s
.72319 .4284 m
.72261 .42987 L
s
.72261 .42987 m
.72241 .4289 L
s
.72406 .42938 m
.72261 .42987 L
s
.72575 .42621 m
.72261 .42987 L
s
0 .197 1 r
.44113 .46265 m
.45218 .45697 L
s
.45218 .45697 m
.44202 .42885 L
s
.45218 .45697 m
.4159 .45425 L
s
1 .168 0 r
.72319 .4284 m
.72241 .4289 L
s
.72406 .42938 m
.72319 .4284 L
s
.72328 .42988 m
.72406 .42938 L
s
1 .005 0 r
.90449 .51121 m
.90451 .51121 L
s
.9045 .51117 m
.90449 .51121 L
s
.90449 .51121 m
.90448 .51119 L
s
.90453 .5112 m
.90449 .51121 L
s
.90457 .51112 m
.90449 .51121 L
s
.9045 .51117 m
.90448 .51119 L
s
.90453 .5112 m
.9045 .51117 L
s
.90451 .51121 m
.90453 .5112 L
s
.90448 .51119 m
.90451 .51121 L
s
1 .002 0 r
.35585 .67499 m
.35586 .67499 L
s
.35586 .67497 m
.35585 .67499 L
s
.35587 .67499 m
.35585 .67499 L
s
.35587 .67499 m
.35586 .67499 L
s
.35586 .67497 m
.35587 .67499 L
s
.35586 .67498 m
.35587 .67499 L
s
.3558 .67496 m
.35587 .67499 L
s
.35586 .67498 m
.35586 .67497 L
s
.35586 .67499 m
.35586 .67498 L
s
1 .001 0 r
.63016 .59305 m
.63017 .59305 L
s
.63017 .59305 m
.63016 .59304 L
s
.63017 .59305 m
.63016 .59305 L
s
.63016 .59304 m
.63016 .59304 L
s
.63016 .59304 m
.63016 .59305 L
s
.63016 .59305 m
.63016 .59305 L
s
.63016 .59305 m
.63016 .59304 L
s
.63019 .59304 m
.63016 .59305 L
s
.63016 .59304 m
.63016 .59305 L
s
1 .019 0 r
.57431 .72958 m
.57429 .72962 L
s
.57429 .72943 m
.57431 .72958 L
s
.57444 .72951 m
.57431 .72958 L
s
.5737 .72958 m
.57444 .72951 L
s
1 .032 0 r
.41229 .53842 m
.41124 .53801 L
s
1 .019 0 r
.57427 .72947 m
.57429 .72943 L
s
.57429 .72943 m
.57444 .72951 L
s
.57444 .72951 m
.57429 .72962 L
s
.57427 .72947 m
.57444 .72951 L
s
0 1 .511 r
.56289 .43773 m
.5761 .4291 L
s
1 .019 0 r
.57429 .72962 m
.57427 .72947 L
s
1 .607 0 r
.46712 .45633 m
.47163 .45984 L
s
.46712 .45633 m
.47258 .45519 L
s
1 .032 0 r
.41145 .53824 m
.41136 .53818 L
s
.41136 .53818 m
.41146 .53795 L
s
.41136 .53818 m
.41124 .53801 L
s
.41146 .53795 m
.41155 .53801 L
s
.41146 .53795 m
.41124 .53801 L
s
1 .168 0 r
.72241 .4289 m
.72328 .42988 L
s
1 .032 0 r
.41155 .53801 m
.41145 .53824 L
s
.41124 .53801 m
.41145 .53824 L
s
.41124 .53801 m
.41155 .53801 L
s
1 .016 0 r
.84473 .48319 m
.8448 .4832 L
s
.84479 .48305 m
.84473 .48319 L
s
.84473 .48319 m
.84471 .4831 L
s
.84487 .48314 m
.84473 .48319 L
s
.84503 .48285 m
.84473 .48319 L
s
.84479 .48305 m
.84471 .4831 L
s
.84487 .48314 m
.84479 .48305 L
s
.8448 .4832 m
.84487 .48314 L
s
.84471 .4831 m
.8448 .4832 L
s
1 .053 0 r
.78445 .4557 m
.78466 .4557 L
s
.78462 .45523 m
.78445 .4557 L
s
.78445 .4557 m
.78438 .4554 L
s
.7849 .45554 m
.78445 .4557 L
s
.78542 .45455 m
.78445 .4557 L
s
1 .607 0 r
.47258 .45519 m
.47163 .45984 L
s
1 .014 0 r
.57007 .56494 m
.57008 .56492 L
s
.57008 .56492 m
.57006 .56481 L
s
.57008 .56492 m
.56996 .56489 L
s
.57006 .56481 m
.57005 .56483 L
s
.57006 .56481 m
.56996 .56489 L
s
.56996 .56489 m
.57007 .56494 L
s
.56996 .56489 m
.57005 .56483 L
s
.57049 .56481 m
.56996 .56489 L
s
1 .053 0 r
.78462 .45523 m
.78438 .4554 L
s
.7849 .45554 m
.78462 .45523 L
s
1 .012 0 r
.51434 .70147 m
.51434 .70149 L
s
.51434 .70138 m
.51434 .70147 L
s
.51443 .70144 m
.51434 .70147 L
s
.51434 .7014 m
.51434 .70138 L
s
.51434 .70138 m
.51443 .70144 L
s
1 .014 0 r
.57005 .56483 m
.57007 .56494 L
s
1 .053 0 r
.78466 .4557 m
.7849 .45554 L
s
1 .012 0 r
.51443 .70144 m
.51434 .70149 L
s
.51434 .7014 m
.51443 .70144 L
s
.51397 .70143 m
.51443 .70144 L
s
1 0 0 r
.29596 .64679 m
.29596 .64679 L
s
.29596 .64678 m
.29596 .64679 L
s
.29596 .64679 m
.29596 .64679 L
s
.29596 .64678 m
.29596 .64679 L
s
.29596 .64678 m
.29596 .64679 L
s
.29596 .64678 m
.29596 .64679 L
s
.29596 .64678 m
.29596 .64678 L
s
.29596 .64679 m
.29596 .64679 L
s
.29596 .64679 m
.29596 .64678 L
s
.78851 .61946 m
.78851 .61946 L
s
1 .043 0 r
.35248 .51017 m
.35134 .50942 L
s
1 .012 0 r
.51434 .70149 m
.51434 .7014 L
s
1 .053 0 r
.78438 .4554 m
.78466 .4557 L
s
.808 1 0 r
.49113 .42686 m
.49136 .43617 L
s
0 .197 1 r
.44202 .42885 m
.43083 .4342 L
s
.44202 .42885 m
.4159 .45425 L
s
.808 1 0 r
.5794 .42777 m
.58498 .42833 L
s
.58478 .41784 m
.5794 .42777 L
s
.5794 .42777 m
.5795 .42072 L
s
.59025 .42542 m
.5794 .42777 L
s
.6071 .40407 m
.5794 .42777 L
s
1 .043 0 r
.35158 .50938 m
.35174 .50948 L
s
.3514 .50966 m
.35158 .50938 L
s
.35158 .50938 m
.35134 .50942 L
s
.35156 .50976 m
.3514 .50966 L
s
.3514 .50966 m
.35134 .50942 L
s
1 .039 0 r
.3987 .81025 m
.39877 .81035 L
s
.39878 .80996 m
.3987 .81025 L
s
.39906 .81021 m
.3987 .81025 L
s
.39885 .81006 m
.39878 .80996 L
s
.39878 .80996 m
.39906 .81021 L
s
.39906 .81021 m
.39877 .81035 L
s
.39885 .81006 m
.39906 .81021 L
s
.39763 .80994 m
.39906 .81021 L
s
1 .043 0 r
.35174 .50948 m
.35156 .50976 L
s
.35134 .50942 m
.35174 .50948 L
s
.35134 .50942 m
.35156 .50976 L
s
1 .039 0 r
.39877 .81035 m
.39885 .81006 L
s
1 .07 0 r
.50856 .53676 m
.50852 .53667 L
s
.50852 .53667 m
.50856 .53613 L
s
.50852 .53667 m
.50801 .53642 L
s
.50856 .53613 m
.50859 .53622 L
s
.50856 .53613 m
.50801 .53642 L
s
1 .004 0 r
.4543 .67328 m
.4543 .67329 L
s
.45431 .67325 m
.4543 .67328 L
s
.45434 .67327 m
.4543 .67328 L
s
.45431 .67326 m
.45431 .67325 L
s
.45431 .67325 m
.45434 .67327 L
s
.45434 .67327 m
.4543 .67329 L
s
.45431 .67326 m
.45434 .67327 L
s
.45418 .67325 m
.45434 .67327 L
s
.4543 .67329 m
.45431 .67326 L
s
1 0 0 r
.72886 .59124 m
.72886 .59124 L
s
.72886 .59124 m
.72886 .59124 L
s
.72886 .59124 m
.72886 .59124 L
s
.72886 .59124 m
.72886 .59124 L
s
.72887 .59124 m
.72886 .59124 L
s
.72886 .59124 m
.72886 .59124 L
s
.72886 .59124 m
.72886 .59124 L
s
.72886 .59124 m
.72886 .59124 L
s
.72886 .59124 m
.72886 .59124 L
s
1 .013 0 r
.67231 .72792 m
.67278 .7278 L
s
1 .07 0 r
.51073 .53656 m
.50801 .53642 L
s
1 .042 0 r
.2926 .48188 m
.2917 .48102 L
s
1 .013 0 r
.67272 .72786 m
.67269 .72789 L
s
.67268 .72776 m
.67272 .72786 L
s
.67278 .7278 m
.67272 .72786 L
s
.67265 .72779 m
.67268 .72776 L
s
.67268 .72776 m
.67278 .7278 L
s
.67278 .7278 m
.67269 .72789 L
s
.67265 .72779 m
.67278 .7278 L
s
1 .07 0 r
.50801 .53642 m
.50856 .53676 L
s
.50801 .53642 m
.50859 .53622 L
s
1 .013 0 r
.67269 .72789 m
.67265 .72779 L
s
.542 1 0 r
.52345 .4262 m
.52731 .43699 L
s
0 .197 1 r
.4159 .45425 m
.44113 .46265 L
s
.4159 .45425 m
.43083 .4342 L
s
.5468 .41044 m
.4159 .45425 L
s
1 .07 0 r
.50859 .53622 m
.50856 .53676 L
s
0 .197 1 r
.63469 .45423 m
.62193 .45533 L
s
.62091 .42146 m
.63469 .45423 L
s
.63469 .45423 m
.60236 .4445 L
s
.64061 .43206 m
.63469 .45423 L
s
.56587 .37162 m
.63469 .45423 L
s
1 .042 0 r
.29189 .481 m
.29208 .48113 L
s
.29168 .48126 m
.29189 .481 L
s
.29189 .481 m
.2917 .48102 L
s
.29187 .48138 m
.29168 .48126 L
s
.29168 .48126 m
.2917 .48102 L
s
1 .023 0 r
.33832 .78205 m
.33838 .78211 L
s
.33839 .78188 m
.33832 .78205 L
s
.33855 .78204 m
.33832 .78205 L
s
.33855 .78204 m
.33838 .78211 L
s
.33839 .78188 m
.33855 .78204 L
s
.33845 .78194 m
.33855 .78204 L
s
.33774 .7818 m
.33855 .78204 L
s
.33845 .78194 m
.33839 .78188 L
s
1 .042 0 r
.29208 .48113 m
.29187 .48138 L
s
.2917 .48102 m
.29208 .48113 L
s
1 .023 0 r
.33838 .78211 m
.33845 .78194 L
s
1 .042 0 r
.2917 .48102 m
.29187 .48138 L
s
1 .007 0 r
.94389 .48107 m
.94392 .48107 L
s
.94391 .48101 m
.94389 .48107 L
s
.94389 .48107 m
.94388 .48103 L
s
.94395 .48104 m
.94389 .48107 L
s
.944 .48092 m
.94389 .48107 L
s
.94391 .48101 m
.94388 .48103 L
s
.94395 .48104 m
.94391 .48101 L
s
.94392 .48107 m
.94395 .48104 L
s
.94388 .48103 m
.94392 .48107 L
s
1 .006 0 r
.66897 .56307 m
.66901 .56308 L
s
.66901 .56302 m
.66897 .56307 L
s
.66897 .56307 m
.66899 .56303 L
s
.66903 .56306 m
.66897 .56307 L
s
.66916 .56298 m
.66897 .56307 L
s
.66901 .56308 m
.66903 .56306 L
s
.66903 .56306 m
.66901 .56302 L
s
.66901 .56302 m
.66899 .56303 L
s
1 .459 0 r
.61488 .45365 m
.61747 .45411 L
s
.61735 .45003 m
.61488 .45365 L
s
.61488 .45365 m
.6156 .45101 L
s
.61922 .45313 m
.61488 .45365 L
s
.62758 .4457 m
.61488 .45365 L
s
1 .006 0 r
.66899 .56303 m
.66901 .56308 L
s
1 0 0 r
.39433 .64504 m
.39434 .64504 L
s
.39434 .64504 m
.39433 .64504 L
s
.39434 .64504 m
.39433 .64504 L
s
.39434 .64504 m
.39434 .64504 L
s
.39434 .64504 m
.39434 .64504 L
s
.39434 .64504 m
.39434 .64504 L
s
.39434 .64504 m
.39434 .64504 L
s
.39432 .64504 m
.39434 .64504 L
s
.39434 .64504 m
.39434 .64504 L
s
1 .01 0 r
.61258 .69974 m
.61295 .69968 L
s
1 .141 0 r
.45091 .50827 m
.44598 .50676 L
s
1 .038 0 r
.23265 .45357 m
.23201 .45274 L
s
1 .01 0 r
.61289 .69972 m
.61288 .69974 L
s
.61288 .69964 m
.61289 .69972 L
s
.61295 .69968 m
.61289 .69972 L
s
.61286 .69966 m
.61288 .69964 L
s
.61288 .69964 m
.61295 .69968 L
s
.61295 .69968 m
.61288 .69974 L
s
.61286 .69966 m
.61295 .69968 L
s
.61288 .69974 m
.61286 .69966 L
s
1 .575 0 r
.41678 .4221 m
.4188 .42319 L
s
.41458 .42607 m
.41678 .4221 L
s
.41678 .4221 m
.41329 .42274 L
s
.808 1 0 r
.58478 .41784 m
.5795 .42072 L
s
.59025 .42542 m
.58478 .41784 L
s
1 .575 0 r
.4166 .42716 m
.41458 .42607 L
s
.41458 .42607 m
.41329 .42274 L
s
1 .39 0 r
.57771 .4813 m
.57868 .48069 L
s
.57868 .48069 m
.57765 .47781 L
s
.57868 .48069 m
.57498 .48042 L
s
1 .459 0 r
.61735 .45003 m
.6156 .45101 L
s
.61922 .45313 m
.61735 .45003 L
s
1 .048 0 r
.60805 .53533 m
.60817 .53524 L
s
.60817 .53524 m
.60804 .53489 L
s
.60817 .53524 m
.60771 .53521 L
s
1 .39 0 r
.57765 .47781 m
.57668 .47841 L
s
.57765 .47781 m
.57498 .48042 L
s
1 .048 0 r
.60804 .53489 m
.60793 .53497 L
s
.60804 .53489 m
.60771 .53521 L
s
.60771 .53521 m
.60805 .53533 L
s
.60771 .53521 m
.60793 .53497 L
s
.60939 .53469 m
.60771 .53521 L
s
1 .459 0 r
.61747 .45411 m
.61922 .45313 L
s
1 .39 0 r
.57498 .48042 m
.57771 .4813 L
s
.57498 .48042 m
.57668 .47841 L
s
.5885 .47609 m
.57498 .48042 L
s
1 .215 0 r
.54293 .50803 m
.54313 .50775 L
s
.54313 .50775 m
.54292 .50609 L
s
.54313 .50775 m
.54127 .50723 L
s
1 .019 0 r
.88408 .45303 m
.88415 .45303 L
s
.88413 .45285 m
.88408 .45303 L
s
.88408 .45303 m
.88404 .45292 L
s
.88424 .45296 m
.88408 .45303 L
s
.88438 .45259 m
.88408 .45303 L
s
1 .038 0 r
.23215 .45274 m
.23233 .45286 L
s
.23195 .45295 m
.23215 .45274 L
s
.23215 .45274 m
.23201 .45274 L
s
1 .019 0 r
.88413 .45285 m
.88404 .45292 L
s
.88424 .45296 m
.88413 .45285 L
s
.88415 .45303 m
.88424 .45296 L
s
1 .038 0 r
.23212 .45307 m
.23195 .45295 L
s
.23195 .45295 m
.23201 .45274 L
s
1 .019 0 r
.88404 .45292 m
.88415 .45303 L
s
1 .048 0 r
.60793 .53497 m
.60805 .53533 L
s
1 .038 0 r
.23233 .45286 m
.23212 .45307 L
s
.23201 .45274 m
.23233 .45286 L
s
1 .055 0 r
.82387 .42549 m
.82406 .42548 L
s
.82402 .425 m
.82387 .42549 L
s
.82387 .42549 m
.82375 .42518 L
s
.82432 .42529 m
.82387 .42549 L
s
.8247 .42422 m
.82387 .42549 L
s
1 .051 0 r
.49774 .80858 m
.49776 .8087 L
s
.49776 .80819 m
.49774 .80858 L
s
.49816 .80846 m
.49774 .80858 L
s
1 .215 0 r
.54292 .50609 m
.54273 .50636 L
s
.54292 .50609 m
.54127 .50723 L
s
1 .038 0 r
.23201 .45274 m
.23212 .45307 L
s
1 .051 0 r
.49778 .8083 m
.49776 .80819 L
s
.49776 .80819 m
.49816 .80846 L
s
.808 1 0 r
.58498 .42833 m
.59025 .42542 L
s
1 .141 0 r
.44695 .5077 m
.44661 .50747 L
s
.44661 .50747 m
.44698 .50643 L
s
.44661 .50747 m
.44598 .50676 L
s
1 .055 0 r
.82402 .425 m
.82375 .42518 L
s
.82432 .42529 m
.82402 .425 L
s
1 .051 0 r
.49816 .80846 m
.49776 .8087 L
s
.49778 .8083 m
.49816 .80846 L
s
.49616 .80837 m
.49816 .80846 L
s
1 .141 0 r
.44698 .50643 m
.44731 .50666 L
s
.44698 .50643 m
.44598 .50676 L
s
1 .055 0 r
.82406 .42548 m
.82432 .42529 L
s
1 .005 0 r
.55293 .67154 m
.55293 .67155 L
s
.55293 .6715 m
.55293 .67154 L
s
.55297 .67152 m
.55293 .67154 L
s
1 0 0 r
.82776 .58943 m
.82776 .58943 L
s
.82776 .58943 m
.82776 .58943 L
s
.82776 .58943 m
.82776 .58943 L
s
.82776 .58943 m
.82776 .58943 L
s
.82777 .58943 m
.82776 .58943 L
s
.82776 .58943 m
.82776 .58943 L
s
.82776 .58943 m
.82776 .58943 L
s
.82776 .58943 m
.82776 .58943 L
s
.82776 .58943 m
.82776 .58943 L
s
1 .005 0 r
.55293 .67151 m
.55293 .6715 L
s
.55293 .6715 m
.55297 .67152 L
s
.55277 .67153 m
.55297 .67152 L
s
1 0 0 r
.3344 .6168 m
.3344 .6168 L
s
1 .151 0 r
.39102 .47996 m
.38684 .47737 L
s
1 .005 0 r
.55297 .67152 m
.55293 .67155 L
s
.55293 .67151 m
.55297 .67152 L
s
.55293 .67155 m
.55293 .67151 L
s
1 .055 0 r
.82375 .42518 m
.82406 .42548 L
s
1 .051 0 r
.49776 .8087 m
.49778 .8083 L
s
1 .215 0 r
.54127 .50723 m
.54293 .50803 L
s
.54127 .50723 m
.54273 .50636 L
s
.54955 .50637 m
.54127 .50723 L
s
1 .141 0 r
.44598 .50676 m
.44695 .5077 L
s
.44598 .50676 m
.44731 .50666 L
s
.44731 .50666 m
.44695 .5077 L
s
1 .038 0 r
.43734 .78047 m
.43739 .78055 L
s
.4374 .78019 m
.43734 .78047 L
s
.43768 .78041 m
.43734 .78047 L
s
.43745 .78027 m
.4374 .78019 L
s
.4374 .78019 m
.43768 .78041 L
s
.43768 .78041 m
.43739 .78055 L
s
.43745 .78027 m
.43768 .78041 L
s
.43626 .7802 m
.43768 .78041 L
s
.973 1 0 r
.49636 .45288 m
.49665 .45179 L
s
.49665 .45179 m
.49644 .44376 L
s
.49665 .45179 m
.48838 .44847 L
s
1 .215 0 r
.54273 .50636 m
.54293 .50803 L
s
1 .038 0 r
.43739 .78055 m
.43745 .78027 L
s
1 .002 0 r
.768 .56118 m
.76801 .56118 L
s
.76801 .56116 m
.768 .56118 L
s
.768 .56118 m
.768 .56117 L
s
.76802 .56117 m
.768 .56118 L
s
.76805 .56114 m
.768 .56118 L
s
.76801 .56116 m
.768 .56117 L
s
.76802 .56117 m
.76801 .56116 L
s
.76801 .56118 m
.76802 .56117 L
s
.768 .56117 m
.76801 .56118 L
s
1 .001 0 r
.49293 .64329 m
.49293 .64329 L
s
.49293 .64329 m
.49293 .64329 L
s
.49294 .64329 m
.49293 .64329 L
s
.49293 .64329 m
.49293 .64329 L
s
.49293 .64329 m
.49294 .64329 L
s
.49294 .64329 m
.49293 .64329 L
s
.49293 .64329 m
.49294 .64329 L
s
.49291 .64329 m
.49294 .64329 L
s
.49293 .64329 m
.49293 .64329 L
s
1 .006 0 r
.7114 .69805 m
.71159 .69799 L
s
1 0 0 r
.27441 .58852 m
.2744 .58852 L
s
1 .121 0 r
.33106 .45161 m
.32852 .44908 L
s
1 0 0 r
.27441 .58852 m
.27441 .58852 L
s
.2744 .58852 m
.27441 .58852 L
s
.27441 .58852 m
.2744 .58852 L
s
.27441 .58852 m
.2744 .58852 L
s
.2744 .58852 m
.2744 .58852 L
s
.27441 .58852 m
.27441 .58852 L
s
.2744 .58852 m
.27441 .58852 L
s
.2744 .58852 m
.27441 .58852 L
s
0 1 .511 r
.54939 .4242 m
.56289 .43773 L
s
1 .006 0 r
.71157 .69801 m
.71155 .69803 L
s
.71155 .69797 m
.71157 .69801 L
s
.71159 .69799 m
.71157 .69801 L
s
.71153 .69799 m
.71155 .69797 L
s
.71155 .69797 m
.71159 .69799 L
s
.71155 .69803 m
.71153 .69799 L
s
.71159 .69799 m
.71155 .69803 L
s
.71153 .69799 m
.71159 .69799 L
s
0 1 .331 r
.55922 .45151 m
.56477 .45128 L
s
.56452 .43053 m
.55922 .45151 L
s
.55922 .45151 m
.55214 .43859 L
s
.57712 .44314 m
.55922 .45151 L
s
.587 .39699 m
.55922 .45151 L
s
1 .417 0 r
.65847 .42413 m
.66021 .42419 L
s
.66005 .42052 m
.65847 .42413 L
s
.65847 .42413 m
.65812 .42168 L
s
.66214 .42302 m
.65847 .42413 L
s
.66679 .41521 m
.65847 .42413 L
s
1 .39 0 r
.57668 .47841 m
.57771 .4813 L
s
1 .09 0 r
.64573 .50586 m
.64628 .50599 L
s
.64625 .50518 m
.64573 .50586 L
s
.64573 .50586 m
.64594 .50537 L
s
.64659 .5058 m
.64573 .50586 L
s
.64842 .50447 m
.64573 .50586 L
s
.64628 .50599 m
.64659 .5058 L
s
.64659 .5058 m
.64625 .50518 L
s
.64625 .50518 m
.64594 .50537 L
s
1 .459 0 r
.6156 .45101 m
.61747 .45411 L
s
1 .016 0 r
.70784 .5331 m
.70793 .53311 L
s
.70792 .53297 m
.70784 .5331 L
s
.70784 .5331 m
.70786 .53301 L
s
.70799 .53307 m
.70784 .5331 L
s
.70827 .53282 m
.70784 .5331 L
s
.70792 .53297 m
.70786 .53301 L
s
.70799 .53307 m
.70792 .53297 L
s
.70793 .53311 m
.70799 .53307 L
s
1 .022 0 r
.37686 .75222 m
.3769 .75227 L
s
.37691 .75206 m
.37686 .75222 L
s
.37706 .75221 m
.37686 .75222 L
s
.37696 .75211 m
.37691 .75206 L
s
.37691 .75206 m
.37706 .75221 L
s
.37706 .75221 m
.3769 .75227 L
s
.37696 .75211 m
.37706 .75221 L
s
.37629 .75201 m
.37706 .75221 L
s
.973 1 0 r
.49644 .44376 m
.49616 .44482 L
s
.49644 .44376 m
.48838 .44847 L
s
1 .151 0 r
.38771 .47721 m
.38827 .47755 L
s
.38709 .47822 m
.38771 .47721 L
s
.38771 .47721 m
.38684 .47737 L
s
.38765 .47856 m
.38709 .47822 L
s
.38709 .47822 m
.38684 .47737 L
s
1 .016 0 r
.70786 .53301 m
.70793 .53311 L
s
1 .417 0 r
.66005 .42052 m
.65812 .42168 L
s
.66214 .42302 m
.66005 .42052 L
s
1 .022 0 r
.3769 .75227 m
.37696 .75211 L
s
1 .05 0 r
.59491 .8068 m
.59682 .8066 L
s
1 .003 0 r
.65159 .66981 m
.6517 .66978 L
s
1 .457 0 r
.48965 .47802 m
.47243 .47498 L
s
1 0 0 r
.43297 .61501 m
.43297 .61501 L
s
1 .091 0 r
.27103 .42323 m
.26959 .42116 L
s
1 .003 0 r
.65169 .66979 m
.65168 .6698 L
s
.65168 .66977 m
.65169 .66979 L
s
.6517 .66978 m
.65169 .66979 L
s
.65167 .66978 m
.65168 .66977 L
s
.65168 .66977 m
.6517 .66978 L
s
.6517 .66978 m
.65168 .6698 L
s
.65167 .66978 m
.6517 .66978 L
s
.65168 .6698 m
.65167 .66978 L
s
1 .575 0 r
.4188 .42319 m
.4166 .42716 L
s
.41329 .42274 m
.4188 .42319 L
s
1 .05 0 r
.59649 .80677 m
.59644 .80688 L
s
.59643 .80639 m
.59649 .80677 L
s
.59682 .8066 m
.59649 .80677 L
s
1 .575 0 r
.41329 .42274 m
.4166 .42716 L
s
1 .09 0 r
.64594 .50537 m
.64628 .50599 L
s
1 .05 0 r
.59638 .80651 m
.59643 .80639 L
s
.59643 .80639 m
.59682 .8066 L
s
1 .417 0 r
.66021 .42419 m
.66214 .42302 L
s
1 .05 0 r
.59682 .8066 m
.59644 .80688 L
s
.59638 .80651 m
.59682 .8066 L
s
.717 1 0 r
.53215 .45219 m
.53553 .45031 L
s
.53553 .45031 m
.53213 .44079 L
s
.53553 .45031 m
.52331 .44939 L
s
1 .05 0 r
.59644 .80688 m
.59638 .80651 L
s
1 .022 0 r
.92357 .42274 m
.92364 .42273 L
s
.92362 .42254 m
.92357 .42274 L
s
.92357 .42274 m
.92352 .42262 L
s
.92375 .42265 m
.92357 .42274 L
s
.92386 .42223 m
.92357 .42274 L
s
1 .151 0 r
.38827 .47755 m
.38765 .47856 L
s
.38684 .47737 m
.38827 .47755 L
s
.38684 .47737 m
.38765 .47856 L
s
1 .022 0 r
.92362 .42254 m
.92352 .42262 L
s
.92375 .42265 m
.92362 .42254 L
s
.92364 .42273 m
.92375 .42265 L
s
.92352 .42262 m
.92364 .42273 L
s
1 .121 0 r
.32906 .44905 m
.3296 .44939 L
s
.32846 .44978 m
.32906 .44905 L
s
.32906 .44905 m
.32852 .44908 L
s
1 .01 0 r
.31657 .72389 m
.31651 .72392 L
s
.31651 .72382 m
.31657 .72389 L
s
.31657 .72389 m
.31648 .72389 L
s
.31654 .72385 m
.31657 .72389 L
s
.31626 .72378 m
.31657 .72389 L
s
.31648 .72389 m
.31651 .72392 L
s
.31651 .72382 m
.31648 .72389 L
s
1 .121 0 r
.329 .45012 m
.32846 .44978 L
s
.32846 .44978 m
.32852 .44908 L
s
1 .01 0 r
.31654 .72385 m
.31651 .72382 L
s
1 .045 0 r
.53642 .7787 m
.53641 .7788 L
s
.53641 .77836 m
.53642 .7787 L
s
.53676 .77857 m
.53642 .7787 L
s
1 .01 0 r
.31651 .72392 m
.31654 .72385 L
s
1 .045 0 r
.5364 .77845 m
.53641 .77836 L
s
.53641 .77836 m
.53676 .77857 L
s
.717 1 0 r
.53213 .44079 m
.52873 .44264 L
s
.53213 .44079 m
.52331 .44939 L
s
1 .001 0 r
.86714 .55931 m
.86714 .55931 L
s
.86714 .5593 m
.86714 .55931 L
s
.86714 .55931 m
.86714 .55931 L
s
.86714 .55931 m
.86714 .55931 L
s
.86715 .5593 m
.86714 .55931 L
s
.86714 .5593 m
.86714 .55931 L
s
.86714 .55931 m
.86714 .5593 L
s
.86714 .55931 m
.86714 .55931 L
s
.86714 .55931 m
.86714 .55931 L
s
.59171 .64154 m
.59174 .64153 L
s
1 .045 0 r
.535 .7786 m
.53676 .77857 L
s
1 .001 0 r
.37297 .58671 m
.37295 .5867 L
s
1 .459 0 r
.42968 .44964 m
.41612 .44216 L
s
1 .001 0 r
.59173 .64153 m
.59173 .64154 L
s
.59173 .64153 m
.59173 .64153 L
s
.59174 .64153 m
.59173 .64153 L
s
.59173 .64153 m
.59173 .64153 L
s
.59173 .64153 m
.59174 .64153 L
s
1 .457 0 r
.47584 .47764 m
.47519 .47705 L
s
.47519 .47705 m
.47591 .47354 L
s
.47519 .47705 m
.47243 .47498 L
s
1 .001 0 r
.59174 .64153 m
.59173 .64154 L
s
.59173 .64153 m
.59174 .64153 L
s
.37295 .5867 m
.37295 .5867 L
s
.37295 .5867 m
.37295 .5867 L
s
.37295 .5867 m
.37295 .5867 L
s
.37295 .5867 m
.37296 .5867 L
s
.37295 .5867 m
.37295 .5867 L
s
.59173 .64154 m
.59173 .64153 L
s
.37296 .5867 m
.37295 .5867 L
s
.37295 .5867 m
.37295 .5867 L
s
.37295 .5867 m
.37296 .5867 L
s
1 .045 0 r
.53676 .77857 m
.53641 .7788 L
s
.5364 .77845 m
.53676 .77857 L
s
.53641 .7788 m
.5364 .77845 L
s
1 .121 0 r
.3296 .44939 m
.329 .45012 L
s
.32852 .44908 m
.3296 .44939 L
s
.717 1 0 r
.52331 .44939 m
.53215 .45219 L
s
.52331 .44939 m
.52873 .44264 L
s
.56776 .43477 m
.52331 .44939 L
s
1 .457 0 r
.47591 .47354 m
.47656 .47412 L
s
.47591 .47354 m
.47243 .47498 L
s
1 .121 0 r
.32852 .44908 m
.329 .45012 L
s
1 .091 0 r
.26991 .42117 m
.27034 .42147 L
s
.26941 .42167 m
.26991 .42117 L
s
.26991 .42117 m
.26959 .42116 L
s
1 .417 0 r
.65812 .42168 m
.66021 .42419 L
s
1 .091 0 r
.26984 .42197 m
.26941 .42167 L
s
.26941 .42167 m
.26959 .42116 L
s
1 .116 0 r
.68477 .47636 m
.68536 .47644 L
s
.68531 .4754 m
.68477 .47636 L
s
.68477 .47636 m
.68482 .4757 L
s
.68584 .47614 m
.68477 .47636 L
s
.68757 .47415 m
.68477 .47636 L
s
1 .091 0 r
.27034 .42147 m
.26984 .42197 L
s
.26959 .42116 m
.27034 .42147 L
s
1 .033 0 r
.47602 .75056 m
.47605 .75063 L
s
.47606 .7503 m
.47602 .75056 L
s
.47631 .75049 m
.47602 .75056 L
s
.47608 .75037 m
.47606 .7503 L
s
.47606 .7503 m
.47631 .75049 L
s
.47631 .75049 m
.47605 .75063 L
s
.47608 .75037 m
.47631 .75049 L
s
.47502 .75037 m
.47631 .75049 L
s
1 .116 0 r
.68531 .4754 m
.68482 .4757 L
s
.68584 .47614 m
.68531 .4754 L
s
1 .091 0 r
.26959 .42116 m
.26984 .42197 L
s
1 .005 0 r
.80725 .53105 m
.80727 .53105 L
s
.80727 .531 m
.80725 .53105 L
s
.80725 .53105 m
.80725 .53102 L
s
.80729 .53104 m
.80725 .53105 L
s
.80736 .53094 m
.80725 .53105 L
s
.80727 .531 m
.80725 .53102 L
s
.80729 .53104 m
.80727 .531 L
s
.80727 .53105 m
.80729 .53104 L
s
.80725 .53102 m
.80727 .53105 L
s
1 .116 0 r
.68536 .47644 m
.68584 .47614 L
s
1 .033 0 r
.47605 .75063 m
.47608 .75037 L
s
1 .002 0 r
.75062 .66809 m
.75067 .66806 L
s
1 0 0 r
.53176 .61323 m
.53176 .61323 L
s
1 .003 0 r
.3129 .55837 m
.31282 .55832 L
s
1 .318 0 r
.36964 .42123 m
.36312 .41446 L
s
1 .002 0 r
.75066 .66806 m
.75066 .66807 L
s
.75065 .66806 m
.75066 .66806 L
s
.75066 .66806 m
.75067 .66806 L
s
.75066 .66807 m
.75066 .66808 L
s
.75067 .66806 m
.75066 .66807 L
s
.75066 .66808 m
.75065 .66806 L
s
.75065 .66806 m
.75067 .66806 L
s
.75067 .66806 m
.75066 .66808 L
s
1 .003 0 r
.31284 .55831 m
.31285 .55832 L
s
.31282 .55833 m
.31284 .55831 L
s
.31284 .55831 m
.31282 .55832 L
s
.31284 .55834 m
.31282 .55833 L
s
.31282 .55833 m
.31282 .55832 L
s
.31285 .55832 m
.31284 .55834 L
s
.31282 .55832 m
.31285 .55832 L
s
.31282 .55832 m
.31284 .55834 L
s
.973 1 0 r
.48838 .44847 m
.49636 .45288 L
s
.48838 .44847 m
.49616 .44482 L
s
.52852 .44767 m
.48838 .44847 L
s
1 .116 0 r
.68482 .4757 m
.68536 .47644 L
s
1 .026 0 r
.74691 .50308 m
.74704 .50309 L
s
.74702 .50286 m
.74691 .50308 L
s
.74691 .50308 m
.74691 .50293 L
s
.74715 .50302 m
.74691 .50308 L
s
.7475 .50256 m
.74691 .50308 L
s
.74702 .50286 m
.74691 .50293 L
s
.74715 .50302 m
.74702 .50286 L
s
.808 1 0 r
.5795 .42072 m
.58498 .42833 L
s
1 .026 0 r
.74704 .50309 m
.74715 .50302 L
s
.74691 .50293 m
.74704 .50309 L
s
1 .018 0 r
.41548 .72227 m
.41551 .72231 L
s
.41552 .72214 m
.41548 .72227 L
s
.41565 .72225 m
.41548 .72227 L
s
.41555 .72218 m
.41552 .72214 L
s
.41552 .72214 m
.41565 .72225 L
s
.41565 .72225 m
.41551 .72231 L
s
.41555 .72218 m
.41565 .72225 L
s
.41498 .72211 m
.41565 .72225 L
s
0 .197 1 r
.62091 .42146 m
.60236 .4445 L
s
.64061 .43206 m
.62091 .42146 L
s
1 .018 0 r
.41551 .72231 m
.41555 .72218 L
s
1 .038 0 r
.63395 .777 m
.63535 .77674 L
s
1 0 0 r
.69073 .63978 m
.69074 .63977 L
s
1 .002 0 r
.47175 .58489 m
.47168 .58488 L
s
1 .006 0 r
.25277 .53 m
.25264 .52989 L
s
1 0 0 r
.69074 .63978 m
.69074 .63978 L
s
.69074 .63977 m
.69074 .63978 L
s
.69074 .63977 m
.69074 .63978 L
s
1 .002 0 r
.4717 .58489 m
.47169 .58489 L
s
.47169 .58489 m
.4717 .58488 L
s
.47169 .58489 m
.47168 .58488 L
s
1 0 0 r
.69074 .63977 m
.69074 .63977 L
s
.69074 .63977 m
.69074 .63977 L
s
1 .002 0 r
.4717 .58488 m
.4717 .58488 L
s
.4717 .58488 m
.47168 .58488 L
s
1 0 0 r
.69074 .63978 m
.69074 .63977 L
s
.69074 .63977 m
.69074 .63978 L
s
.69074 .63977 m
.69074 .63977 L
s
1 .002 0 r
.47168 .58488 m
.4717 .58489 L
s
.47168 .58488 m
.4717 .58488 L
s
.4717 .58488 m
.4717 .58489 L
s
1 .006 0 r
.25267 .52988 m
.25269 .5299 L
s
.25264 .52992 m
.25267 .52988 L
s
.25267 .52988 m
.25264 .52989 L
s
.25266 .52994 m
.25264 .52992 L
s
.25264 .52992 m
.25264 .52989 L
s
.25269 .5299 m
.25266 .52994 L
s
.25264 .52989 m
.25269 .5299 L
s
.25264 .52989 m
.25266 .52994 L
s
1 .038 0 r
.63514 .77689 m
.63508 .77698 L
s
.63507 .77661 m
.63514 .77689 L
s
.63535 .77674 m
.63514 .77689 L
s
1 .457 0 r
.47243 .47498 m
.47584 .47764 L
s
.47243 .47498 m
.47656 .47412 L
s
1 .038 0 r
.63501 .7767 m
.63507 .77661 L
s
.63507 .77661 m
.63535 .77674 L
s
.63535 .77674 m
.63508 .77698 L
s
.63501 .7767 m
.63535 .77674 L
s
.63508 .77698 m
.63501 .7767 L
s
0 .04 1 r
.42667 .41762 m
.43733 .44708 L
s
1 .457 0 r
.47656 .47412 m
.47584 .47764 L
s
1 .007 0 r
.35503 .6939 m
.35505 .69391 L
s
.35505 .69385 m
.35503 .6939 L
s
.35509 .6939 m
.35503 .6939 L
s
.35509 .6939 m
.35505 .69391 L
s
.35505 .69385 m
.35509 .6939 L
s
.35507 .69386 m
.35509 .6939 L
s
.35486 .69382 m
.35509 .6939 L
s
.35507 .69386 m
.35505 .69385 L
s
.35505 .69391 m
.35507 .69386 L
s
1 .002 0 r
.90664 .52911 m
.90664 .52911 L
s
.90664 .52909 m
.90664 .52911 L
s
.90664 .52911 m
.90663 .5291 L
s
.90665 .5291 m
.90664 .52911 L
s
.90667 .52906 m
.90664 .52911 L
s
.90664 .52909 m
.90663 .5291 L
s
.90665 .5291 m
.90664 .52909 L
s
.90664 .52911 m
.90665 .5291 L
s
.90663 .5291 m
.90664 .52911 L
s
0 1 .331 r
.56452 .43053 m
.55214 .43859 L
s
.57712 .44314 m
.56452 .43053 L
s
1 .035 0 r
.57508 .74874 m
.57505 .74881 L
s
.57504 .74847 m
.57508 .74874 L
s
.57532 .74861 m
.57508 .74874 L
s
1 0 0 r
.63077 .61144 m
.63077 .61144 L
s
1 .035 0 r
.57396 .74873 m
.57532 .74861 L
s
1 .01 0 r
.41167 .55652 m
.41133 .55639 L
s
.808 1 0 r
.46847 .41923 m
.42936 .40255 L
s
1 .035 0 r
.57502 .74854 m
.57504 .74847 L
s
.57504 .74847 m
.57532 .74861 L
s
1 .01 0 r
.41139 .55646 m
.41136 .55644 L
s
.41136 .55644 m
.4114 .55637 L
s
.41136 .55644 m
.41133 .55639 L
s
.4114 .55637 m
.41143 .55639 L
s
.4114 .55637 m
.41133 .55639 L
s
.41143 .55639 m
.41139 .55646 L
s
.41133 .55639 m
.41139 .55646 L
s
.41133 .55639 m
.41143 .55639 L
s
1 .035 0 r
.57532 .74861 m
.57505 .74881 L
s
.57502 .74854 m
.57532 .74861 L
s
.57505 .74881 m
.57502 .74854 L
s
1 .121 0 r
.72458 .44635 m
.72507 .44636 L
s
.725 .44529 m
.72458 .44635 L
s
.72458 .44635 m
.72444 .44565 L
s
.72563 .446 m
.72458 .44635 L
s
.72686 .44372 m
.72458 .44635 L
s
.725 .44529 m
.72444 .44565 L
s
.72563 .446 m
.725 .44529 L
s
.72507 .44636 m
.72563 .446 L
s
1 .009 0 r
.84664 .50083 m
.84668 .50084 L
s
.84667 .50076 m
.84664 .50083 L
s
.84664 .50083 m
.84663 .50079 L
s
.84672 .50081 m
.84664 .50083 L
s
.8468 .50065 m
.84664 .50083 L
s
.84667 .50076 m
.84663 .50079 L
s
.84672 .50081 m
.84667 .50076 L
s
.84668 .50084 m
.84672 .50081 L
s
.84663 .50079 m
.84668 .50084 L
s
1 .026 0 r
.51472 .72053 m
.51473 .72058 L
s
.51473 .72033 m
.51472 .72053 L
s
.51493 .72046 m
.51472 .72053 L
s
.51473 .72038 m
.51473 .72033 L
s
.51473 .72033 m
.51493 .72046 L
s
.973 1 0 r
.49616 .44482 m
.49636 .45288 L
s
1 .026 0 r
.51493 .72046 m
.51473 .72058 L
s
.51473 .72038 m
.51493 .72046 L
s
.51391 .72044 m
.51493 .72046 L
s
1 .002 0 r
.29473 .66552 m
.29472 .66552 L
s
.29472 .6655 m
.29473 .66552 L
s
.29473 .66552 m
.29472 .66551 L
s
.29473 .66551 m
.29473 .66552 L
s
.29469 .66549 m
.29473 .66552 L
s
.29472 .6655 m
.29472 .66551 L
s
.29473 .66551 m
.29472 .6655 L
s
.29472 .66551 m
.29472 .66552 L
s
.29472 .66552 m
.29473 .66551 L
s
.57069 .58309 m
.57069 .58308 L
s
.57069 .58308 m
.57069 .58307 L
s
.57069 .58308 m
.57067 .58308 L
s
.57069 .58307 m
.57068 .58307 L
s
.57069 .58307 m
.57067 .58308 L
s
.57067 .58308 m
.57069 .58309 L
s
.57067 .58308 m
.57068 .58307 L
s
.57074 .58307 m
.57067 .58308 L
s
.57068 .58307 m
.57069 .58309 L
s
1 0 0 r
.78997 .63802 m
.78997 .63802 L
s
1 .02 0 r
.35152 .52812 m
.351 .52778 L
s
1 0 0 r
.78997 .63801 m
.78997 .63802 L
s
.78997 .63802 m
.78997 .63801 L
s
.78997 .63801 m
.78997 .63802 L
s
.78997 .63802 m
.78997 .63802 L
s
.78997 .63802 m
.78997 .63802 L
s
.78997 .63802 m
.78997 .63802 L
s
.78997 .63802 m
.78997 .63802 L
s
.78997 .63802 m
.78997 .63802 L
s
1 .026 0 r
.51473 .72058 m
.51473 .72038 L
s
1 .121 0 r
.72444 .44565 m
.72507 .44636 L
s
1 .02 0 r
.35111 .52776 m
.35118 .52781 L
s
.35102 .52789 m
.35111 .52776 L
s
.35111 .52776 m
.351 .52778 L
s
.3511 .52794 m
.35102 .52789 L
s
.35102 .52789 m
.351 .52778 L
s
1 .033 0 r
.78624 .47292 m
.78638 .47293 L
s
.78636 .47263 m
.78624 .47292 L
s
.78624 .47292 m
.7862 .47274 L
s
.78653 .47282 m
.78624 .47292 L
s
.78686 .4722 m
.78624 .47292 L
s
.78636 .47263 m
.7862 .47274 L
s
.78653 .47282 m
.78636 .47263 L
s
1 .02 0 r
.35118 .52781 m
.3511 .52794 L
s
.351 .52778 m
.35118 .52781 L
s
.351 .52778 m
.3511 .52794 L
s
1 .033 0 r
.78638 .47293 m
.78653 .47282 L
s
.7862 .47274 m
.78638 .47293 L
s
1 .013 0 r
.45417 .69221 m
.45419 .69224 L
s
.45419 .69211 m
.45417 .69221 L
s
.45429 .69219 m
.45417 .69221 L
s
.45421 .69214 m
.45419 .69211 L
s
.45419 .69211 m
.45429 .69219 L
s
1 .459 0 r
.41891 .44162 m
.42053 .44252 L
s
.41715 .44481 m
.41891 .44162 L
s
.41891 .44162 m
.41612 .44216 L
s
.41877 .44571 m
.41715 .44481 L
s
.41715 .44481 m
.41612 .44216 L
s
1 .013 0 r
.45429 .69219 m
.45419 .69224 L
s
.45421 .69214 m
.45429 .69219 L
s
.45379 .69211 m
.45429 .69219 L
s
.45419 .69224 m
.45421 .69214 L
s
1 .024 0 r
.50992 .55474 m
.5099 .5547 L
s
.5099 .5547 m
.50992 .55452 L
s
.5099 .5547 m
.50973 .55462 L
s
.50992 .55452 m
.50993 .55455 L
s
.50992 .55452 m
.50973 .55462 L
s
.67313 .74709 m
.67399 .74686 L
s
1 0 0 r
.73 .60965 m
.73 .60965 L
s
1 .024 0 r
.51065 .55467 m
.50973 .55462 L
s
1 .023 0 r
.29131 .49969 m
.29081 .49921 L
s
1 .024 0 r
.50973 .55462 m
.50992 .55474 L
s
.50973 .55462 m
.50993 .55455 L
s
.50993 .55455 m
.50992 .55474 L
s
.67387 .74697 m
.67382 .74703 L
s
.67381 .74679 m
.67387 .74697 L
s
.67399 .74686 m
.67387 .74697 L
s
.67376 .74685 m
.67381 .74679 L
s
.67381 .74679 m
.67399 .74686 L
s
0 .197 1 r
.60236 .4445 m
.62193 .45533 L
s
1 .024 0 r
.67399 .74686 m
.67382 .74703 L
s
.67376 .74685 m
.67399 .74686 L
s
.67382 .74703 m
.67376 .74685 L
s
0 .04 1 r
.62362 .44095 m
.64293 .41692 L
s
1 .023 0 r
.29092 .4992 m
.29102 .49927 L
s
.2908 .49934 m
.29092 .4992 L
s
.29092 .4992 m
.29081 .49921 L
s
.2909 .49941 m
.2908 .49934 L
s
.2908 .49934 m
.29081 .49921 L
s
0 .434 1 r
.44721 .47731 m
.45758 .47179 L
s
.45758 .47179 m
.44799 .44525 L
s
.45758 .47179 m
.42334 .46924 L
s
1 .023 0 r
.29102 .49927 m
.2909 .49941 L
s
.29081 .49921 m
.29102 .49927 L
s
.29081 .49921 m
.2909 .49941 L
s
1 .035 0 r
.33757 .80164 m
.33766 .80173 L
s
.33768 .80139 m
.33757 .80164 L
s
.33791 .80163 m
.33757 .80164 L
s
.33791 .80163 m
.33766 .80173 L
s
.33768 .80139 m
.33791 .80163 L
s
.33776 .80148 m
.33791 .80163 L
s
.3367 .80128 m
.33791 .80163 L
s
.33776 .80148 m
.33768 .80139 L
s
1 .318 0 r
.3645 .41442 m
.36595 .41529 L
s
.3629 .41634 m
.3645 .41442 L
s
.3645 .41442 m
.36312 .41446 L
s
1 .035 0 r
.33766 .80173 m
.33776 .80148 L
s
1 .318 0 r
.36435 .41722 m
.3629 .41634 L
s
.3629 .41634 m
.36312 .41446 L
s
1 .003 0 r
.94627 .49881 m
.94628 .49881 L
s
.94627 .49878 m
.94627 .49881 L
s
.94627 .49881 m
.94626 .49879 L
s
.94629 .4988 m
.94627 .49881 L
s
.94632 .49873 m
.94627 .49881 L
s
.94627 .49878 m
.94626 .49879 L
s
.94629 .4988 m
.94627 .49878 L
s
.94628 .49881 m
.94629 .4988 L
s
.94626 .49879 m
.94628 .49881 L
s
1 .004 0 r
.39369 .6638 m
.3937 .66381 L
s
.3937 .66377 m
.39369 .6638 L
s
.39372 .6638 m
.39369 .6638 L
s
.39371 .66378 m
.3937 .66377 L
s
.3937 .66377 m
.39372 .6638 L
s
.39372 .6638 m
.3937 .66381 L
s
.39371 .66378 m
.39372 .6638 L
s
.3936 .66376 m
.39372 .6638 L
s
.3937 .66381 m
.39371 .66378 L
s
1 .001 0 r
.66993 .58126 m
.66994 .58126 L
s
.66994 .58125 m
.66993 .58126 L
s
.66993 .58126 m
.66994 .58125 L
s
.66994 .58126 m
.66993 .58126 L
s
.66996 .58124 m
.66993 .58126 L
s
.66994 .58126 m
.66994 .58126 L
s
.66994 .58126 m
.66994 .58125 L
s
.66994 .58125 m
.66994 .58125 L
s
.66994 .58125 m
.66994 .58126 L
s
1 .022 0 r
.61306 .71877 m
.6139 .71862 L
s
1 .07 0 r
.4505 .52624 m
.44803 .52549 L
s
1 .023 0 r
.23103 .47123 m
.23063 .47071 L
s
1 .022 0 r
.61377 .71871 m
.61373 .71876 L
s
.61373 .71854 m
.61377 .71871 L
s
.6139 .71862 m
.61377 .71871 L
s
.61369 .71859 m
.61373 .71854 L
s
.61373 .71854 m
.6139 .71862 L
s
.6139 .71862 m
.61373 .71876 L
s
.61369 .71859 m
.6139 .71862 L
s
.61373 .71876 m
.61369 .71859 L
s
1 .115 0 r
.76464 .41587 m
.765 .41584 L
s
.76493 .41483 m
.76464 .41587 L
s
.76464 .41587 m
.76436 .41522 L
s
.76557 .41545 m
.76464 .41587 L
s
.76627 .4132 m
.76464 .41587 L
s
1 .023 0 r
.23072 .47071 m
.23083 .47079 L
s
.23059 .47084 m
.23072 .47071 L
s
.23072 .47071 m
.23063 .47071 L
s
.2307 .47092 m
.23059 .47084 L
s
.23059 .47084 m
.23063 .47071 L
s
1 .07 0 r
.44852 .52596 m
.44835 .52584 L
s
.44835 .52584 m
.44853 .52532 L
s
.44835 .52584 m
.44803 .52549 L
s
.717 1 0 r
.52873 .44264 m
.53215 .45219 L
s
1 .023 0 r
.23083 .47079 m
.2307 .47092 L
s
.23063 .47071 m
.23083 .47079 L
s
1 .07 0 r
.44853 .52532 m
.4487 .52544 L
s
.44853 .52532 m
.44803 .52549 L
s
1 .023 0 r
.23063 .47071 m
.2307 .47092 L
s
0 1 .331 r
.56477 .45128 m
.57712 .44314 L
s
1 .115 0 r
.76493 .41483 m
.76436 .41522 L
s
.76557 .41545 m
.76493 .41483 L
s
1 .012 0 r
.88619 .47052 m
.88623 .47052 L
s
.88622 .47041 m
.88619 .47052 L
s
.88619 .47052 m
.88616 .47045 L
s
.88629 .47048 m
.88619 .47052 L
s
.88637 .47025 m
.88619 .47052 L
s
.88622 .47041 m
.88616 .47045 L
s
.88629 .47048 m
.88622 .47041 L
s
1 .115 0 r
.765 .41584 m
.76557 .41545 L
s
1 .012 0 r
.88623 .47052 m
.88629 .47048 L
s
1 .07 0 r
.44803 .52549 m
.44852 .52596 L
s
.44803 .52549 m
.4487 .52544 L
s
1 .012 0 r
.88616 .47045 m
.88623 .47052 L
s
1 .016 0 r
.60941 .55302 m
.60945 .55299 L
s
.60945 .55299 m
.60941 .55287 L
s
.60945 .55299 m
.6093 .55298 L
s
1 .07 0 r
.4487 .52544 m
.44852 .52596 L
s
1 .016 0 r
.60941 .55287 m
.60937 .5529 L
s
.60941 .55287 m
.6093 .55298 L
s
.6093 .55298 m
.60941 .55302 L
s
.6093 .55298 m
.60937 .5529 L
s
.60986 .55281 m
.6093 .55298 L
s
.60937 .5529 m
.60941 .55302 L
s
1 .318 0 r
.36595 .41529 m
.36435 .41722 L
s
.36312 .41446 m
.36595 .41529 L
s
1 .016 0 r
.55344 .69043 m
.55343 .69046 L
s
.55343 .6903 m
.55344 .69043 L
s
.55355 .69037 m
.55344 .69043 L
s
1 .115 0 r
.76436 .41522 m
.765 .41584 L
s
1 0 0 r
.33335 .63537 m
.33335 .63538 L
s
.33335 .63537 m
.33335 .63537 L
s
.33335 .63537 m
.33335 .63537 L
s
.33335 .63537 m
.33335 .63537 L
s
.33334 .63537 m
.33335 .63537 L
s
.33335 .63537 m
.33335 .63537 L
s
.33335 .63537 m
.33335 .63537 L
s
.33335 .63537 m
.33335 .63538 L
s
1 .016 0 r
.55342 .69033 m
.55343 .6903 L
s
.55343 .6903 m
.55355 .69037 L
s
1 0 0 r
.33335 .63538 m
.33335 .63537 L
s
.82944 .60785 m
.82944 .60785 L
s
1 .016 0 r
.55293 .69041 m
.55355 .69037 L
s
1 .09 0 r
.39027 .49777 m
.38777 .49623 L
s
1 .016 0 r
.55355 .69037 m
.55343 .69046 L
s
.55342 .69033 m
.55355 .69037 L
s
.55343 .69046 m
.55342 .69033 L
s
1 .038 0 r
.82579 .4426 m
.82592 .4426 L
s
.82589 .44226 m
.82579 .4426 L
s
.82579 .4426 m
.82571 .44239 L
s
.8261 .44246 m
.82579 .4426 L
s
.82636 .44174 m
.82579 .4426 L
s
1 .318 0 r
.36312 .41446 m
.36435 .41722 L
s
1 .038 0 r
.82589 .44226 m
.82571 .44239 L
s
.8261 .44246 m
.82589 .44226 L
s
1 .459 0 r
.42053 .44252 m
.41877 .44571 L
s
.41612 .44216 m
.42053 .44252 L
s
.41612 .44216 m
.41877 .44571 L
s
0 .434 1 r
.44799 .44525 m
.43751 .45048 L
s
.44799 .44525 m
.42334 .46924 L
s
1 .111 0 r
.54626 .5252 m
.54636 .52505 L
s
.54636 .52505 m
.54625 .52419 L
s
.54636 .52505 m
.5454 .52478 L
s
1 .038 0 r
.82592 .4426 m
.8261 .44246 L
s
.82571 .44239 m
.82592 .4426 L
s
1 .111 0 r
.54625 .52419 m
.54615 .52434 L
s
.54625 .52419 m
.5454 .52478 L
s
1 .055 0 r
.43736 .80008 m
.43743 .80021 L
s
.43744 .79966 m
.43736 .80008 L
s
.43785 .79999 m
.43736 .80008 L
s
1 .111 0 r
.5454 .52478 m
.54626 .5252 L
s
.5454 .52478 m
.54615 .52434 L
s
.54969 .52434 m
.5454 .52478 L
s
1 .055 0 r
.43751 .79979 m
.43744 .79966 L
s
.43744 .79966 m
.43785 .79999 L
s
.43785 .79999 m
.43743 .80021 L
s
.43751 .79979 m
.43785 .79999 L
s
.43577 .79969 m
.43785 .79999 L
s
.973 1 0 r
.58352 .44203 m
.58838 .44257 L
s
.58819 .43343 m
.58352 .44203 L
s
.58352 .44203 m
.58362 .43597 L
s
.59294 .44002 m
.58352 .44203 L
s
.60756 .42167 m
.58352 .44203 L
s
1 .055 0 r
.43743 .80021 m
.43751 .79979 L
s
1 .253 0 r
.58179 .49731 m
.58242 .4969 L
s
.58242 .4969 m
.58175 .49502 L
s
.58242 .4969 m
.58 .49672 L
s
1 .111 0 r
.54615 .52434 m
.54626 .5252 L
s
1 .007 0 r
.49293 .66206 m
.49294 .66207 L
s
.49294 .662 m
.49293 .66206 L
s
.49299 .66204 m
.49293 .66206 L
s
.49294 .66202 m
.49294 .662 L
s
.49294 .662 m
.49299 .66204 L
s
.49299 .66204 m
.49294 .66207 L
s
.49294 .66202 m
.49299 .66204 L
s
.49273 .66202 m
.49299 .66204 L
s
1 0 0 r
.76939 .57942 m
.76939 .57942 L
s
.76939 .57942 m
.76939 .57942 L
s
.76939 .57942 m
.76939 .57942 L
s
.76939 .57942 m
.76939 .57942 L
s
.7694 .57941 m
.76939 .57942 L
s
.76939 .57942 m
.76939 .57942 L
s
.76939 .57942 m
.76939 .57942 L
s
.76939 .57942 m
.76939 .57942 L
s
.76939 .57942 m
.76939 .57942 L
s
1 .007 0 r
.49294 .66207 m
.49294 .66202 L
s
1 .013 0 r
.71243 .71709 m
.71285 .71694 L
s
1 .08 0 r
.32998 .46927 m
.3283 .46762 L
s
1 0 0 r
.27302 .60695 m
.27302 .60695 L
s
1 .253 0 r
.58175 .49502 m
.58112 .49543 L
s
.58175 .49502 m
.58 .49672 L
s
0 .434 1 r
.42334 .46924 m
.44721 .47731 L
s
.42334 .46924 m
.43751 .45048 L
s
.54693 .42829 m
.42334 .46924 L
s
1 .09 0 r
.38829 .49614 m
.38863 .49634 L
s
.38791 .49674 m
.38829 .49614 L
s
.38829 .49614 m
.38777 .49623 L
s
.38825 .49695 m
.38791 .49674 L
s
.38791 .49674 m
.38777 .49623 L
s
1 .336 0 r
.61879 .46919 m
.6207 .46954 L
s
.62061 .46653 m
.61879 .46919 L
s
.61879 .46919 m
.61932 .46726 L
s
.62199 .46881 m
.61879 .46919 L
s
.62815 .46339 m
.61879 .46919 L
s
1 .253 0 r
.58 .49672 m
.58179 .49731 L
s
.58 .49672 m
.58112 .49543 L
s
.58885 .49392 m
.58 .49672 L
s
1 .013 0 r
.71281 .717 m
.71277 .71703 L
s
.71277 .71691 m
.71281 .717 L
s
.71285 .71694 m
.71281 .717 L
s
.71273 .71694 m
.71277 .71691 L
s
.71277 .71691 m
.71285 .71694 L
s
.71277 .71703 m
.71273 .71694 L
s
.71285 .71694 m
.71277 .71703 L
s
.71273 .71694 m
.71285 .71694 L
s
1 .336 0 r
.62061 .46653 m
.61932 .46726 L
s
.62199 .46881 m
.62061 .46653 L
s
.6207 .46954 m
.62199 .46881 L
s
1 .09 0 r
.38863 .49634 m
.38825 .49695 L
s
.38777 .49623 m
.38863 .49634 L
s
.38777 .49623 m
.38825 .49695 L
s
1 .035 0 r
.37638 .77169 m
.37646 .77178 L
s
.37647 .77143 m
.37638 .77169 L
s
.37671 .77167 m
.37638 .77169 L
s
.37655 .77152 m
.37647 .77143 L
s
.37647 .77143 m
.37671 .77167 L
s
.37671 .77167 m
.37646 .77178 L
s
.37655 .77152 m
.37671 .77167 L
s
.37547 .77135 m
.37671 .77167 L
s
1 .825 0 r
.50256 .46958 m
.50278 .46865 L
s
.50278 .46865 m
.50262 .46217 L
s
.50278 .46865 m
.49611 .466 L
s
1 .035 0 r
.37646 .77178 m
.37655 .77152 L
s
1 .005 0 r
.70915 .55104 m
.70917 .55104 L
s
.70917 .55099 m
.70915 .55104 L
s
.70915 .55104 m
.70915 .55101 L
s
.70919 .55103 m
.70915 .55104 L
s
.70928 .55095 m
.70915 .55104 L
s
.70917 .55099 m
.70915 .55101 L
s
.70919 .55103 m
.70917 .55099 L
s
.70917 .55104 m
.70919 .55103 L
s
.70915 .55101 m
.70917 .55104 L
s
1 .001 0 r
.43248 .63361 m
.43248 .63361 L
s
.43248 .6336 m
.43248 .63361 L
s
.43249 .63361 m
.43248 .63361 L
s
.43249 .6336 m
.43248 .6336 L
s
.43248 .6336 m
.43249 .63361 L
s
.43249 .63361 m
.43248 .63361 L
s
.43249 .6336 m
.43249 .63361 L
s
.43246 .6336 m
.43249 .63361 L
s
.43248 .63361 m
.43249 .6336 L
s
1 .011 0 r
.65229 .6887 m
.65266 .6886 L
s
1 .303 0 r
.48945 .49585 m
.47798 .49384 L
s
1 .063 0 r
.26962 .44075 m
.26861 .43931 L
s
1 .011 0 r
.65261 .68864 m
.65259 .68867 L
s
.65259 .68857 m
.65261 .68864 L
s
.65266 .6886 m
.65261 .68864 L
s
.65256 .68859 m
.65259 .68857 L
s
.65259 .68857 m
.65266 .6886 L
s
.65266 .6886 m
.65259 .68867 L
s
.65256 .68859 m
.65266 .6886 L
s
.65259 .68867 m
.65256 .68859 L
s
1 .08 0 r
.32866 .46759 m
.32902 .46782 L
s
.32826 .46808 m
.32866 .46759 L
s
.32866 .46759 m
.3283 .46762 L
s
.973 1 0 r
.58819 .43343 m
.58362 .43597 L
s
.59294 .44002 m
.58819 .43343 L
s
1 .08 0 r
.32862 .46831 m
.32826 .46808 L
s
.32826 .46808 m
.3283 .46762 L
s
1 .043 0 r
.6478 .52312 m
.64807 .52318 L
s
.64805 .52279 m
.6478 .52312 L
s
.6478 .52312 m
.64791 .52288 L
s
.64822 .52309 m
.6478 .52312 L
s
.6491 .52245 m
.6478 .52312 L
s
1 .253 0 r
.58112 .49543 m
.58179 .49731 L
s
1 .043 0 r
.64807 .52318 m
.64822 .52309 L
s
.64822 .52309 m
.64805 .52279 L
s
.64805 .52279 m
.64791 .52288 L
s
1 .825 0 r
.50262 .46217 m
.5024 .46308 L
s
.50262 .46217 m
.49611 .466 L
s
1 .08 0 r
.32902 .46782 m
.32862 .46831 L
s
.3283 .46762 m
.32902 .46782 L
s
1 .043 0 r
.64791 .52288 m
.64807 .52318 L
s
1 .08 0 r
.3283 .46762 m
.32862 .46831 L
s
1 .014 0 r
.92588 .44009 m
.92593 .44009 L
s
.92592 .43996 m
.92588 .44009 L
s
.92588 .44009 m
.92585 .44001 L
s
.926 .44003 m
.92588 .44009 L
s
.92608 .43975 m
.92588 .44009 L
s
1 .303 0 r
.48026 .49561 m
.47982 .49521 L
s
.47982 .49521 m
.4803 .49287 L
s
.47982 .49521 m
.47798 .49384 L
s
1 .014 0 r
.92592 .43996 m
.92585 .44001 L
s
.926 .44003 m
.92592 .43996 L
s
.92593 .44009 m
.926 .44003 L
s
1 .018 0 r
.31568 .74319 m
.31556 .74324 L
s
.31557 .74306 m
.31568 .74319 L
s
.31568 .74319 m
.31551 .74319 L
s
.31562 .74311 m
.31568 .74319 L
s
.3151 .74297 m
.31568 .74319 L
s
.973 1 0 r
.58838 .44257 m
.59294 .44002 L
s
1 .018 0 r
.31551 .74319 m
.31556 .74324 L
s
.31557 .74306 m
.31551 .74319 L
s
1 .014 0 r
.92585 .44001 m
.92593 .44009 L
s
1 .018 0 r
.31562 .74311 m
.31557 .74306 L
s
1 .066 0 r
.53713 .79825 m
.53712 .7984 L
s
.53712 .79775 m
.53713 .79825 L
s
.53763 .79806 m
.53713 .79825 L
s
1 .018 0 r
.31556 .74324 m
.31562 .74311 L
s
1 .066 0 r
.53711 .79789 m
.53712 .79775 L
s
.53712 .79775 m
.53763 .79806 L
s
1 .303 0 r
.4803 .49287 m
.48074 .49327 L
s
.4803 .49287 m
.47798 .49384 L
s
1 .063 0 r
.26883 .43932 m
.26914 .43953 L
s
.26848 .43967 m
.26883 .43932 L
s
.26883 .43932 m
.26861 .43931 L
s
1 0 0 r
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
.86905 .57758 m
.86905 .57758 L
s
1 .066 0 r
.53505 .79811 m
.53763 .79806 L
s
1 .006 0 r
.59208 .66028 m
.59231 .66024 L
s
1 0 0 r
.37212 .60515 m
.37212 .60515 L
s
1 .336 0 r
.42915 .46732 m
.41918 .46188 L
s
1 .05 0 r
.2092 .41219 m
.20857 .411 L
s
1 .006 0 r
.59227 .66026 m
.59227 .66028 L
s
.59226 .66022 m
.59227 .66026 L
s
.59231 .66024 m
.59227 .66026 L
s
.59226 .66023 m
.59226 .66022 L
s
.59226 .66022 m
.59231 .66024 L
s
.59231 .66024 m
.59227 .66028 L
s
.59226 .66023 m
.59231 .66024 L
s
.59227 .66028 m
.59226 .66023 L
s
1 .066 0 r
.53763 .79806 m
.53712 .7984 L
s
.53711 .79789 m
.53763 .79806 L
s
1 .336 0 r
.61932 .46726 m
.6207 .46954 L
s
1 .039 0 r
.86551 .41211 m
.86562 .41209 L
s
.86558 .41175 m
.86551 .41211 L
s
.86551 .41211 m
.86539 .4119 L
s
.86581 .41195 m
.86551 .41211 L
s
.86598 .41118 m
.86551 .41211 L
s
1 .063 0 r
.26879 .43988 m
.26848 .43967 L
s
.26848 .43967 m
.26861 .43931 L
s
1 .323 0 r
.66109 .43965 m
.66245 .43972 L
s
.66232 .43684 m
.66109 .43965 L
s
.66109 .43965 m
.66082 .43776 L
s
.66395 .43879 m
.66109 .43965 L
s
.66758 .43276 m
.66109 .43965 L
s
1 .039 0 r
.86558 .41175 m
.86539 .4119 L
s
.86581 .41195 m
.86558 .41175 L
s
1 .066 0 r
.53712 .7984 m
.53711 .79789 L
s
1 .063 0 r
.26914 .43953 m
.26879 .43988 L
s
.26861 .43931 m
.26914 .43953 L
s
1 .039 0 r
.86562 .41209 m
.86581 .41195 L
s
.86539 .4119 m
.86562 .41209 L
s
1 .063 0 r
.26861 .43931 m
.26879 .43988 L
s
0 .434 1 r
.63115 .46696 m
.61905 .46816 L
s
.61811 .43603 m
.63115 .46696 L
s
.63115 .46696 m
.60058 .45783 L
s
.6367 .44617 m
.63115 .46696 L
s
.5661 .38963 m
.63115 .46696 L
s
1 .053 0 r
.47634 .77002 m
.47639 .77014 L
s
.47639 .76962 m
.47634 .77002 L
s
.4768 .76991 m
.47634 .77002 L
s
1 .323 0 r
.66232 .43684 m
.66082 .43776 L
s
.66395 .43879 m
.66232 .43684 L
s
1 .053 0 r
.47644 .76973 m
.47639 .76962 L
s
.47639 .76962 m
.4768 .76991 L
s
.4768 .76991 m
.47639 .77014 L
s
.47644 .76973 m
.4768 .76991 L
s
.47474 .76973 m
.4768 .76991 L
s
1 .05 0 r
.20871 .41102 m
.20896 .4112 L
s
.20843 .41128 m
.20871 .41102 L
s
.20871 .41102 m
.20857 .411 L
s
.20867 .41146 m
.20843 .41128 L
s
.20843 .41128 m
.20857 .411 L
s
1 .053 0 r
.47639 .77014 m
.47644 .76973 L
s
1 .323 0 r
.66245 .43972 m
.66395 .43879 L
s
1 .002 0 r
.80889 .54911 m
.8089 .54911 L
s
.8089 .5491 m
.80889 .54911 L
s
.80889 .54911 m
.80889 .5491 L
s
.80891 .54911 m
.80889 .54911 L
s
.80893 .54908 m
.80889 .54911 L
s
.8089 .5491 m
.80889 .5491 L
s
.80891 .54911 m
.8089 .5491 L
s
.8089 .54911 m
.80891 .54911 L
s
1 .05 0 r
.20896 .4112 m
.20867 .41146 L
s
.20857 .411 m
.20896 .4112 L
s
1 .002 0 r
.80889 .5491 m
.8089 .54911 L
s
1 .001 0 r
.53184 .63183 m
.53184 .63183 L
s
.53184 .63182 m
.53184 .63183 L
s
.53185 .63182 m
.53184 .63183 L
s
.53184 .63182 m
.53184 .63182 L
s
.53184 .63182 m
.53185 .63182 L
s
1 .005 0 r
.75187 .68699 m
.75202 .68691 L
s
1 .001 0 r
.5318 .63182 m
.53185 .63182 L
s
1 0 0 r
.31172 .57666 m
.31171 .57666 L
s
1 .241 0 r
.36878 .43876 m
.36381 .43366 L
s
1 .001 0 r
.53185 .63182 m
.53184 .63183 L
s
.53184 .63182 m
.53185 .63182 L
s
.53184 .63183 m
.53184 .63182 L
s
1 0 0 r
.31171 .57666 m
.31172 .57666 L
s
.31171 .57666 m
.31171 .57666 L
s
.31171 .57666 m
.31171 .57666 L
s
.31171 .57666 m
.31171 .57666 L
s
.31171 .57666 m
.31171 .57666 L
s
.31172 .57666 m
.31171 .57666 L
s
.31171 .57666 m
.31172 .57666 L
s
.31171 .57666 m
.31171 .57666 L
s
1 .005 0 r
.75199 .6869 m
.75201 .68694 L
s
.75197 .68692 m
.75199 .6869 L
s
.75199 .6869 m
.75202 .68691 L
s
.75201 .68694 m
.75199 .68695 L
s
.75202 .68691 m
.75201 .68694 L
s
1 .05 0 r
.20857 .411 m
.20867 .41146 L
s
1 .005 0 r
.75199 .68695 m
.75197 .68692 L
s
.75197 .68692 m
.75202 .68691 L
s
.75202 .68691 m
.75199 .68695 L
s
1 .303 0 r
.47798 .49384 m
.48026 .49561 L
s
.47798 .49384 m
.48074 .49327 L
s
0 1 .331 r
.55214 .43859 m
.56477 .45128 L
s
1 .825 0 r
.49611 .466 m
.50256 .46958 L
s
.49611 .466 m
.5024 .46308 L
s
.52854 .46536 m
.49611 .466 L
s
1 .303 0 r
.48074 .49327 m
.48026 .49561 L
s
1 .033 0 r
.41528 .74162 m
.41534 .74169 L
s
.41535 .74137 m
.41528 .74162 L
s
.41559 .74158 m
.41528 .74162 L
s
1 .068 0 r
.68682 .49328 m
.68717 .49333 L
s
.68714 .49272 m
.68682 .49328 L
s
.68682 .49328 m
.68685 .49289 L
s
.68745 .49315 m
.68682 .49328 L
s
.68848 .49199 m
.68682 .49328 L
s
1 .033 0 r
.41541 .74144 m
.41535 .74137 L
s
.41535 .74137 m
.41559 .74158 L
s
.41559 .74158 m
.41534 .74169 L
s
.41541 .74144 m
.41559 .74158 L
s
.41436 .74132 m
.41559 .74158 L
s
1 .012 0 r
.74847 .52078 m
.74853 .52079 L
s
.74852 .52068 m
.74847 .52078 L
s
.74847 .52078 m
.74847 .52072 L
s
.74858 .52076 m
.74847 .52078 L
s
.74874 .52055 m
.74847 .52078 L
s
1 .068 0 r
.68714 .49272 m
.68685 .49289 L
s
.68745 .49315 m
.68714 .49272 L
s
1 .012 0 r
.74852 .52068 m
.74847 .52072 L
s
.74858 .52076 m
.74852 .52068 L
s
.74853 .52079 m
.74858 .52076 L
s
1 .068 0 r
.68717 .49333 m
.68745 .49315 L
s
1 .012 0 r
.74847 .52072 m
.74853 .52079 L
s
1 .033 0 r
.41534 .74169 m
.41541 .74144 L
s
1 .055 0 r
.63456 .79651 m
.63662 .79615 L
s
1 .003 0 r
.69165 .65853 m
.69175 .65849 L
s
1 0 0 r
.47145 .60334 m
.47145 .60334 L
s
1 .158 0 r
.30834 .41017 m
.30606 .40646 L
s
1 .002 0 r
.25125 .54815 m
.25121 .54811 L
s
1 .323 0 r
.66082 .43776 m
.66245 .43972 L
s
1 .002 0 r
.25122 .54811 m
.25123 .54812 L
s
.25121 .54812 m
.25122 .54811 L
s
.25122 .54811 m
.25121 .54811 L
s
.25122 .54813 m
.25121 .54812 L
s
.25121 .54812 m
.25121 .54811 L
s
1 .003 0 r
.69174 .65851 m
.69173 .65851 L
s
.69173 .65848 m
.69174 .65851 L
s
.69175 .65849 m
.69174 .65851 L
s
.69172 .65849 m
.69173 .65848 L
s
.69173 .65848 m
.69175 .65849 L
s
1 .002 0 r
.25123 .54812 m
.25122 .54813 L
s
.25121 .54811 m
.25123 .54812 L
s
.25121 .54811 m
.25122 .54813 L
s
.939 1 0 r
.53837 .46693 m
.54117 .46532 L
s
.54117 .46532 m
.53833 .4574 L
s
.54117 .46532 m
.53099 .46456 L
s
1 .003 0 r
.69173 .65851 m
.69172 .65849 L
s
.69175 .65849 m
.69173 .65851 L
s
.69172 .65849 m
.69175 .65849 L
s
1 .068 0 r
.68685 .49289 m
.68717 .49333 L
s
1 .055 0 r
.6363 .79636 m
.63621 .79649 L
s
.6362 .79595 m
.6363 .79636 L
s
.63662 .79615 m
.6363 .79636 L
s
.63611 .79608 m
.6362 .79595 L
s
.6362 .79595 m
.63662 .79615 L
s
.63662 .79615 m
.63621 .79649 L
s
.63611 .79608 m
.63662 .79615 L
s
.63621 .79649 m
.63611 .79608 L
s
.939 1 0 r
.53833 .4574 m
.53553 .45899 L
s
.53833 .4574 m
.53099 .46456 L
s
1 .015 0 r
.35429 .71306 m
.35433 .7131 L
s
.35434 .71295 m
.35429 .71306 L
s
.35444 .71306 m
.35429 .71306 L
s
.35444 .71306 m
.35433 .7131 L
s
.35434 .71295 m
.35444 .71306 L
s
.35438 .71299 m
.35444 .71306 L
s
.35392 .71288 m
.35444 .71306 L
s
.35438 .71299 m
.35434 .71295 L
s
.939 1 0 r
.53099 .46456 m
.53837 .46693 L
s
.53099 .46456 m
.53553 .45899 L
s
.56799 .45251 m
.53099 .46456 L
s
.808 1 0 r
.43709 .41119 m
.43356 .40933 L
s
.43356 .40933 m
.43738 .40065 L
s
.43356 .40933 m
.42936 .40255 L
s
1 .015 0 r
.35433 .7131 m
.35438 .71299 L
s
1 .001 0 r
.90878 .54722 m
.90879 .54722 L
s
.90879 .54722 m
.90878 .54722 L
s
.90878 .54722 m
.90878 .54722 L
s
.90879 .54722 m
.90878 .54722 L
s
.9088 .54721 m
.90878 .54722 L
s
.90879 .54722 m
.90878 .54722 L
s
.90879 .54722 m
.90879 .54722 L
s
.90879 .54722 m
.90879 .54722 L
s
.90878 .54722 m
.90879 .54722 L
s
1 .055 0 r
.57601 .76811 m
.57596 .76823 L
s
.57596 .76768 m
.57601 .76811 L
s
.57639 .76792 m
.57601 .76811 L
s
1 .001 0 r
.63136 .63005 m
.63139 .63004 L
s
1 .055 0 r
.57424 .7681 m
.57639 .76792 L
s
1 .001 0 r
.41104 .57482 m
.41099 .57481 L
s
.973 1 0 r
.46816 .43676 m
.43432 .42248 L
s
1 .001 0 r
.63138 .63004 m
.63138 .63004 L
s
.63138 .63003 m
.63138 .63004 L
s
.63139 .63004 m
.63138 .63004 L
s
.63138 .63004 m
.63138 .63003 L
s
.63138 .63003 m
.63139 .63004 L
s
.63139 .63004 m
.63138 .63004 L
s
.63138 .63004 m
.63139 .63004 L
s
.63138 .63004 m
.63138 .63004 L
s
.411 .57482 m
.411 .57481 L
s
.411 .57481 m
.411 .5748 L
s
.411 .57481 m
.41099 .57481 L
s
.411 .5748 m
.411 .57481 L
s
.411 .5748 m
.41099 .57481 L
s
.411 .57481 m
.411 .57482 L
s
.41099 .57481 m
.411 .57482 L
s
.41099 .57481 m
.411 .57481 L
s
1 .055 0 r
.57591 .7678 m
.57596 .76768 L
s
.57596 .76768 m
.57639 .76792 L
s
.808 1 0 r
.43738 .40065 m
.44093 .40248 L
s
.43738 .40065 m
.42936 .40255 L
s
1 .055 0 r
.57639 .76792 m
.57596 .76823 L
s
.57591 .7678 m
.57639 .76792 L
s
.57596 .76823 m
.57591 .7678 L
s
1 .825 0 r
.5024 .46308 m
.50256 .46958 L
s
1 .336 0 r
.42123 .46146 m
.42242 .46214 L
s
.41994 .4638 m
.42123 .46146 L
s
.42123 .46146 m
.41918 .46188 L
s
.42113 .46448 m
.41994 .4638 L
s
.41994 .4638 m
.41918 .46188 L
s
0 .197 1 r
.43083 .4342 m
.44113 .46265 L
s
1 .271 0 r
.70347 .4084 m
.70427 .40833 L
s
.70413 .40594 m
.70347 .4084 L
s
.70347 .4084 m
.70276 .40686 L
s
.70563 .4074 m
.70347 .4084 L
s
.70714 .40203 m
.70347 .4084 L
s
.973 1 0 r
.58362 .43597 m
.58838 .44257 L
s
1 .047 0 r
.51531 .73983 m
.51532 .73992 L
s
.51532 .73947 m
.51531 .73983 L
s
.51569 .7397 m
.51531 .73983 L
s
.51533 .73956 m
.51532 .73947 L
s
.51532 .73947 m
.51569 .7397 L
s
1 .741 0 r
.63778 .40828 m
.63979 .40807 L
s
.63955 .40152 m
.63778 .40828 L
s
.63778 .40828 m
.63571 .40405 L
s
.64362 .40554 m
.63778 .40828 L
s
.64727 .39073 m
.63778 .40828 L
s
1 .005 0 r
.29355 .68448 m
.29352 .68449 L
s
.29352 .68444 m
.29355 .68448 L
s
.29355 .68448 m
.2935 .68448 L
s
.29354 .68446 m
.29355 .68448 L
s
.2934 .68441 m
.29355 .68448 L
s
1 .004 0 r
.84852 .51873 m
.84854 .51873 L
s
.84853 .5187 m
.84852 .51873 L
s
.84852 .51873 m
.84851 .51871 L
s
.84855 .51872 m
.84852 .51873 L
s
.84859 .51865 m
.84852 .51873 L
s
1 .005 0 r
.29352 .68444 m
.2935 .68448 L
s
.29354 .68446 m
.29352 .68444 L
s
.2935 .68448 m
.29352 .68449 L
s
1 .004 0 r
.84853 .5187 m
.84851 .51871 L
s
.84855 .51872 m
.84853 .5187 L
s
.84854 .51873 m
.84855 .51872 L
s
.84851 .51871 m
.84854 .51873 L
s
1 .005 0 r
.29352 .68449 m
.29354 .68446 L
s
1 .047 0 r
.51569 .7397 m
.51532 .73992 L
s
.51533 .73956 m
.51569 .7397 L
s
.51385 .73966 m
.51569 .7397 L
s
0 1 .077 r
.56238 .46342 m
.56739 .46331 L
s
.56714 .4446 m
.56238 .46342 L
s
.56238 .46342 m
.55604 .45189 L
s
.57847 .45595 m
.56238 .46342 L
s
.58735 .41489 m
.56238 .46342 L
s
1 .001 0 r
.79144 .65678 m
.79147 .65676 L
s
1 0 0 r
.571 .60153 m
.571 .60153 L
s
1 .006 0 r
.35056 .54627 m
.35039 .54617 L
s
1 .65 0 r
.40771 .40814 m
.39451 .39405 L
s
1 .001 0 r
.79147 .65676 m
.79147 .65677 L
s
.79146 .65676 m
.79147 .65676 L
s
.79147 .65676 m
.79147 .65676 L
s
.79147 .65677 m
.79147 .65677 L
s
.79147 .65676 m
.79147 .65677 L
s
.79147 .65677 m
.79146 .65676 L
s
.79146 .65676 m
.79147 .65676 L
s
.79147 .65676 m
.79147 .65677 L
s
1 .006 0 r
.35042 .54616 m
.35045 .54617 L
s
.35039 .5462 m
.35042 .54616 L
s
.35042 .54616 m
.35039 .54617 L
s
1 .047 0 r
.51532 .73992 m
.51533 .73956 L
s
1 .006 0 r
.35042 .54622 m
.35039 .5462 L
s
.35039 .5462 m
.35039 .54617 L
s
.35045 .54617 m
.35042 .54622 L
s
.35039 .54617 m
.35045 .54617 L
s
.35039 .54617 m
.35042 .54622 L
s
1 .08 0 r
.72647 .46314 m
.7268 .46316 L
s
.72675 .46244 m
.72647 .46314 L
s
.72647 .46314 m
.72638 .46269 L
s
.72717 .46291 m
.72647 .46314 L
s
.72798 .46142 m
.72647 .46314 L
s
1 .271 0 r
.70413 .40594 m
.70276 .40686 L
s
.70563 .4074 m
.70413 .40594 L
s
1 .08 0 r
.72675 .46244 m
.72638 .46269 L
s
.72717 .46291 m
.72675 .46244 L
s
1 .241 0 r
.36486 .43361 m
.36597 .43429 L
s
.36365 .43508 m
.36486 .43361 L
s
.36486 .43361 m
.36381 .43366 L
s
1 .08 0 r
.7268 .46316 m
.72717 .46291 L
s
1 .158 0 r
.30657 .40651 m
.30735 .40704 L
s
.30569 .40737 m
.30657 .40651 L
s
.30657 .40651 m
.30606 .40646 L
s
1 .018 0 r
.78798 .49045 m
.78805 .49045 L
s
.78804 .49029 m
.78798 .49045 L
s
.78798 .49045 m
.78795 .49035 L
s
.78814 .49039 m
.78798 .49045 L
s
.78832 .49005 m
.78798 .49045 L
s
.78804 .49029 m
.78795 .49035 L
s
.78814 .49039 m
.78804 .49029 L
s
.78805 .49045 m
.78814 .49039 L
s
1 .241 0 r
.36476 .43576 m
.36365 .43508 L
s
.36365 .43508 m
.36381 .43366 L
s
1 .018 0 r
.78795 .49035 m
.78805 .49045 L
s
1 .08 0 r
.72638 .46269 m
.7268 .46316 L
s
1 .271 0 r
.70427 .40833 m
.70563 .4074 L
s
1 .029 0 r
.45423 .71141 m
.45427 .71147 L
s
.45428 .71119 m
.45423 .71141 L
s
.4545 .71136 m
.45423 .71141 L
s
1 .158 0 r
.30647 .40791 m
.30569 .40737 L
s
.30569 .40737 m
.30606 .40646 L
s
1 .029 0 r
.45432 .71125 m
.45428 .71119 L
s
.45428 .71119 m
.4545 .71136 L
s
.4545 .71136 m
.45427 .71147 L
s
.45432 .71125 m
.4545 .71136 L
s
.45339 .71119 m
.4545 .71136 L
s
.45427 .71147 m
.45432 .71125 L
s
1 .003 0 r
.51047 .57299 m
.51047 .57298 L
s
.51047 .57298 m
.51047 .57296 L
s
.51047 .57298 m
.51045 .57297 L
s
.51047 .57296 m
.51047 .57296 L
s
.51047 .57296 m
.51045 .57297 L
s
1 .039 0 r
.67395 .76648 m
.67534 .76611 L
s
1 0 0 r
.73114 .62826 m
.73115 .62826 L
s
1 .003 0 r
.51057 .57298 m
.51045 .57297 L
s
1 .011 0 r
.29001 .51769 m
.28978 .51748 L
s
1 0 0 r
.73114 .62826 m
.73115 .62826 L
s
.73114 .62826 m
.73114 .62826 L
s
.73114 .62826 m
.73115 .62826 L
s
.73115 .62826 m
.73114 .62826 L
s
.73115 .62826 m
.73115 .62826 L
s
.73114 .62826 m
.73114 .62826 L
s
.73114 .62826 m
.73115 .62826 L
s
.73115 .62826 m
.73114 .62826 L
s
1 .003 0 r
.51045 .57297 m
.51047 .57299 L
s
.51045 .57297 m
.51047 .57296 L
s
.51047 .57296 m
.51047 .57299 L
s
1 .158 0 r
.30735 .40704 m
.30647 .40791 L
s
.30606 .40646 m
.30735 .40704 L
s
1 .011 0 r
.28983 .51747 m
.28987 .51751 L
s
.28977 .51754 m
.28983 .51747 L
s
.28983 .51747 m
.28978 .51748 L
s
.28982 .51757 m
.28977 .51754 L
s
.28977 .51754 m
.28978 .51748 L
s
.28987 .51751 m
.28982 .51757 L
s
.28978 .51748 m
.28987 .51751 L
s
.28978 .51748 m
.28982 .51757 L
s
1 .039 0 r
.67516 .76628 m
.67507 .76638 L
s
.67505 .76599 m
.67516 .76628 L
s
.67534 .76611 m
.67516 .76628 L
s
.67497 .76609 m
.67505 .76599 L
s
.67505 .76599 m
.67534 .76611 L
s
1 .271 0 r
.70276 .40686 m
.70427 .40833 L
s
1 .336 0 r
.42242 .46214 m
.42113 .46448 L
s
.41918 .46188 m
.42242 .46214 L
s
.41918 .46188 m
.42113 .46448 L
s
1 .158 0 r
.30606 .40646 m
.30647 .40791 L
s
1 .741 0 r
.63955 .40152 m
.63571 .40405 L
s
.64362 .40554 m
.63955 .40152 L
s
1 .039 0 r
.67534 .76611 m
.67507 .76638 L
s
.67497 .76609 m
.67534 .76611 L
s
.67507 .76638 m
.67497 .76609 L
s
1 .241 0 r
.36597 .43429 m
.36476 .43576 L
s
.36381 .43366 m
.36597 .43429 L
s
.36381 .43366 m
.36476 .43576 L
s
1 .012 0 r
.39316 .68282 m
.39319 .68284 L
s
.39319 .68273 m
.39316 .68282 L
s
.39327 .68281 m
.39316 .68282 L
s
.39322 .68276 m
.39319 .68273 L
s
.39319 .68273 m
.39327 .68281 L
s
.39327 .68281 m
.39319 .68284 L
s
.39322 .68276 m
.39327 .68281 L
s
.39286 .68269 m
.39327 .68281 L
s
.39319 .68284 m
.39322 .68276 L
s
1 .002 0 r
.94864 .51677 m
.94865 .51677 L
s
.94865 .51676 m
.94864 .51677 L
s
.94864 .51677 m
.94864 .51677 L
s
.94866 .51677 m
.94864 .51677 L
s
.94867 .51674 m
.94864 .51677 L
s
.94865 .51676 m
.94864 .51677 L
s
.94866 .51677 m
.94865 .51676 L
s
.94865 .51677 m
.94866 .51677 L
s
.94864 .51677 m
.94865 .51677 L
s
1 .04 0 r
.61355 .738 m
.61507 .73774 L
s
1 0 0 r
.67077 .59971 m
.67077 .59971 L
s
1 .024 0 r
.45008 .5444 m
.44924 .54415 L
s
0 1 .511 r
.50729 .40611 m
.41129 .38839 L
s
1 .013 0 r
.22939 .48908 m
.22917 .4888 L
s
1 .04 0 r
.61483 .7379 m
.61477 .73799 L
s
.61476 .7376 m
.61483 .7379 L
s
.61507 .73774 m
.61483 .7379 L
s
1 .024 0 r
.44941 .54431 m
.44935 .54427 L
s
.44935 .54427 m
.44941 .54409 L
s
.44935 .54427 m
.44924 .54415 L
s
1 .04 0 r
.6147 .73768 m
.61476 .7376 L
s
.61476 .7376 m
.61507 .73774 L
s
1 .024 0 r
.44941 .54409 m
.44947 .54413 L
s
.44941 .54409 m
.44924 .54415 L
s
1 .013 0 r
.22922 .4888 m
.22928 .48884 L
s
.22915 .48887 m
.22922 .4888 L
s
.22922 .4888 m
.22917 .4888 L
s
.22921 .48892 m
.22915 .48887 L
s
.22915 .48887 m
.22917 .4888 L
s
.22928 .48884 m
.22921 .48892 L
s
.22917 .4888 m
.22928 .48884 L
s
.22917 .4888 m
.22921 .48892 L
s
1 .024 0 r
.44924 .54415 m
.44941 .54431 L
s
.44924 .54415 m
.44947 .54413 L
s
.44947 .54413 m
.44941 .54431 L
s
1 .04 0 r
.61507 .73774 m
.61477 .73799 L
s
.6147 .73768 m
.61507 .73774 L
s
.61477 .73799 m
.6147 .73768 L
s
0 .434 1 r
.61811 .43603 m
.60058 .45783 L
s
.6367 .44617 m
.61811 .43603 L
s
1 .741 0 r
.63979 .40807 m
.64362 .40554 L
s
1 .006 0 r
.88829 .48825 m
.88831 .48825 L
s
.8883 .4882 m
.88829 .48825 L
s
.88829 .48825 m
.88827 .48822 L
s
.88834 .48823 m
.88829 .48825 L
s
.88839 .48811 m
.88829 .48825 L
s
.8883 .4882 m
.88827 .48822 L
s
.88834 .48823 m
.8883 .4882 L
s
.88831 .48825 m
.88834 .48823 L
s
.88827 .48822 m
.88831 .48825 L
s
1 .003 0 r
.33235 .65419 m
.33234 .65419 L
s
.33234 .65417 m
.33235 .65419 L
s
.33235 .65419 m
.33233 .65419 L
s
.33235 .65418 m
.33235 .65419 L
s
.33227 .65415 m
.33235 .65419 L
s
.33234 .65417 m
.33233 .65419 L
s
.33235 .65418 m
.33234 .65417 L
s
.33233 .65419 m
.33234 .65419 L
s
1 .035 0 r
.5542 .70953 m
.55418 .7096 L
s
.55418 .70926 m
.5542 .70953 L
s
.55445 .70941 m
.5542 .70953 L
s
1 .003 0 r
.33234 .65419 m
.33235 .65418 L
s
1 .002 0 r
.61027 .57116 m
.61027 .57115 L
s
.61027 .57115 m
.61027 .57114 L
s
.61027 .57115 m
.61025 .57115 L
s
.61027 .57114 m
.61026 .57114 L
s
.61027 .57114 m
.61025 .57115 L
s
.61025 .57115 m
.61027 .57116 L
s
.61025 .57115 m
.61026 .57114 L
s
.61033 .57113 m
.61025 .57115 L
s
.61026 .57114 m
.61027 .57116 L
s
1 .035 0 r
.55416 .70933 m
.55418 .70926 L
s
.55418 .70926 m
.55445 .70941 L
s
1 0 0 r
.83114 .62648 m
.83114 .62647 L
s
1 .035 0 r
.55308 .7095 m
.55445 .70941 L
s
1 .043 0 r
.38952 .51578 m
.38831 .51505 L
s
1 0 0 r
.83114 .62647 m
.83114 .62648 L
s
.83114 .62648 m
.83114 .62647 L
s
.83114 .62647 m
.83114 .62647 L
s
.83114 .62648 m
.83114 .62648 L
s
.83114 .62647 m
.83114 .62648 L
s
.83114 .62648 m
.83114 .62648 L
s
.83114 .62648 m
.83114 .62647 L
s
.83114 .62647 m
.83114 .62648 L
s
1 .035 0 r
.55445 .70941 m
.55418 .7096 L
s
.55416 .70933 m
.55445 .70941 L
s
1 .081 0 r
.76646 .43264 m
.76672 .43262 L
s
.76666 .4319 m
.76646 .43264 L
s
.76646 .43264 m
.76626 .43218 L
s
.76712 .43234 m
.76646 .43264 L
s
.76762 .43076 m
.76646 .43264 L
s
1 .035 0 r
.55418 .7096 m
.55416 .70933 L
s
1 .081 0 r
.76666 .4319 m
.76626 .43218 L
s
.76712 .43234 m
.76666 .4319 L
s
.76672 .43262 m
.76712 .43234 L
s
1 .023 0 r
.82768 .45998 m
.82776 .45998 L
s
.82774 .45977 m
.82768 .45998 L
s
.82768 .45998 m
.82763 .45985 L
s
.82788 .4599 m
.82768 .45998 L
s
.82804 .45945 m
.82768 .45998 L
s
1 .043 0 r
.38856 .515 m
.38872 .5151 L
s
.38838 .51529 m
.38856 .515 L
s
.38856 .515 m
.38831 .51505 L
s
1 .023 0 r
.82774 .45977 m
.82763 .45985 L
s
.82788 .4599 m
.82774 .45977 L
s
1 .043 0 r
.38854 .51539 m
.38838 .51529 L
s
.38838 .51529 m
.38831 .51505 L
s
1 .023 0 r
.82776 .45998 m
.82788 .4599 L
s
1 .081 0 r
.76626 .43218 m
.76672 .43262 L
s
1 .023 0 r
.82763 .45985 m
.82776 .45998 L
s
0 .197 1 r
.62193 .45533 m
.64061 .43206 L
s
1 .043 0 r
.38872 .5151 m
.38854 .51539 L
s
.38831 .51505 m
.38872 .5151 L
s
.38831 .51505 m
.38854 .51539 L
s
1 .039 0 r
.54862 .54282 m
.54866 .54276 L
s
.54866 .54276 m
.54862 .54246 L
s
.54866 .54276 m
.54832 .54267 L
s
.54862 .54246 m
.54859 .54252 L
s
.54862 .54246 m
.54832 .54267 L
s
.54832 .54267 m
.54862 .54282 L
s
.54832 .54267 m
.54859 .54252 L
s
.54982 .54252 m
.54832 .54267 L
s
1 .021 0 r
.49319 .68107 m
.49321 .68111 L
s
.49321 .68091 m
.49319 .68107 L
s
.49337 .68102 m
.49319 .68107 L
s
.49322 .68095 m
.49321 .68091 L
s
.49321 .68091 m
.49337 .68102 L
s
.49337 .68102 m
.49321 .68111 L
s
.49322 .68095 m
.49337 .68102 L
s
.49254 .68096 m
.49337 .68102 L
s
.939 1 0 r
.53553 .45899 m
.53837 .46693 L
s
1 .039 0 r
.54859 .54252 m
.54862 .54282 L
s
1 .021 0 r
.49321 .68111 m
.49322 .68095 L
s
1 0 0 r
.27162 .62559 m
.27162 .62559 L
s
.27162 .62558 m
.27162 .62559 L
s
.27162 .62559 m
.27161 .62559 L
s
.27162 .62559 m
.27162 .62559 L
s
.27161 .62558 m
.27162 .62559 L
s
.27162 .62558 m
.27161 .62559 L
s
.27162 .62559 m
.27162 .62558 L
s
.27161 .62559 m
.27162 .62559 L
s
.27162 .62559 m
.27162 .62559 L
s
1 .023 0 r
.71348 .73634 m
.71425 .73606 L
s
1 0 0 r
.77076 .59789 m
.77076 .59789 L
s
1 .046 0 r
.32889 .48714 m
.32793 .4862 L
s
1 .741 0 r
.63571 .40405 m
.63979 .40807 L
s
1 .023 0 r
.71417 .73617 m
.71411 .73623 L
s
.71409 .736 m
.71417 .73617 L
s
.71425 .73606 m
.71417 .73617 L
s
.71403 .73606 m
.71409 .736 L
s
.71409 .736 m
.71425 .73606 L
s
.71411 .73623 m
.71403 .73606 L
s
.71425 .73606 m
.71411 .73623 L
s
0 1 .077 r
.56714 .4446 m
.55604 .45189 L
s
.57847 .45595 m
.56714 .4446 L
s
1 .023 0 r
.71403 .73606 m
.71425 .73606 L
s
1 .051 0 r
.37598 .79141 m
.37609 .79154 L
s
.37612 .79103 m
.37598 .79141 L
s
.37647 .79138 m
.37598 .79141 L
s
.37623 .79116 m
.37612 .79103 L
s
.37612 .79103 m
.37647 .79138 L
s
.37647 .79138 m
.37609 .79154 L
s
.37623 .79116 m
.37647 .79138 L
s
.37463 .79091 m
.37647 .79138 L
s
1 .046 0 r
.32813 .48618 m
.32834 .48631 L
s
.3279 .48646 m
.32813 .48618 L
s
.32813 .48618 m
.32793 .4862 L
s
1 .051 0 r
.37609 .79154 m
.37623 .79116 L
s
1 .046 0 r
.32811 .48659 m
.3279 .48646 L
s
.3279 .48646 m
.32793 .4862 L
s
.32834 .48631 m
.32811 .48659 L
s
.32793 .4862 m
.32834 .48631 L
s
.32793 .4862 m
.32811 .48659 L
s
1 .007 0 r
.43212 .65246 m
.43214 .65247 L
s
.43214 .65241 m
.43212 .65246 L
s
.43219 .65245 m
.43212 .65246 L
s
.43215 .65242 m
.43214 .65241 L
s
.43214 .65241 m
.43219 .65245 L
s
.43219 .65245 m
.43214 .65247 L
s
.43215 .65242 m
.43219 .65245 L
s
.43194 .65239 m
.43219 .65245 L
s
.43214 .65247 m
.43215 .65242 L
s
1 .001 0 r
.71029 .56929 m
.7103 .56929 L
s
.71029 .56928 m
.71029 .56929 L
s
.71029 .56929 m
.71029 .56929 L
s
.7103 .56929 m
.71029 .56929 L
s
.71031 .56928 m
.71029 .56929 L
s
.71029 .56928 m
.71029 .56929 L
s
.7103 .56929 m
.71029 .56928 L
s
.7103 .56929 m
.7103 .56929 L
s
.71029 .56929 m
.7103 .56929 L
s
1 .023 0 r
.653 .7078 m
.65383 .70757 L
s
1 .162 0 r
.48925 .51387 m
.48309 .5128 L
s
1 .04 0 r
.26819 .45846 m
.26755 .45755 L
s
1 .023 0 r
.65372 .70768 m
.65367 .70773 L
s
.65366 .7075 m
.65372 .70768 L
s
.65383 .70757 m
.65372 .70768 L
s
.65361 .70756 m
.65366 .7075 L
s
.65366 .7075 m
.65383 .70757 L
s
.808 1 0 r
.44093 .40248 m
.43709 .41119 L
s
.42936 .40255 m
.43709 .41119 L
s
1 .023 0 r
.65383 .70757 m
.65367 .70773 L
s
.65361 .70756 m
.65383 .70757 L
s
.65367 .70773 m
.65361 .70756 L
s
1 .162 0 r
.48432 .51376 m
.48408 .51353 L
s
.48408 .51353 m
.48433 .51228 L
s
.48408 .51353 m
.48309 .5128 L
s
1 .133 0 r
.58548 .51373 m
.58582 .51351 L
s
.58582 .51351 m
.58546 .51252 L
s
.58582 .51351 m
.58454 .51342 L
s
.58546 .51252 m
.58513 .51274 L
s
.58546 .51252 m
.58454 .51342 L
s
.58454 .51342 m
.58548 .51373 L
s
.58454 .51342 m
.58513 .51274 L
s
.58921 .51195 m
.58454 .51342 L
s
1 .162 0 r
.48433 .51228 m
.48457 .5125 L
s
.48433 .51228 m
.48309 .5128 L
s
.808 1 0 r
.42936 .40255 m
.44093 .40248 L
s
1 .029 0 r
.31487 .76274 m
.31467 .76281 L
s
.31469 .76253 m
.31487 .76274 L
s
.31487 .76274 m
.31459 .76273 L
s
.31477 .76261 m
.31487 .76274 L
s
.31393 .76239 m
.31487 .76274 L
s
.31459 .76273 m
.31467 .76281 L
s
.31469 .76253 m
.31459 .76273 L
s
.31477 .76261 m
.31469 .76253 L
s
1 .59 0 r
.50987 .48629 m
.51001 .48559 L
s
.51001 .48559 m
.5099 .48093 L
s
.51001 .48559 m
.50522 .4837 L
s
1 .04 0 r
.26769 .45755 m
.26788 .45769 L
s
.26747 .45778 m
.26769 .45755 L
s
.26769 .45755 m
.26755 .45755 L
s
0 .434 1 r
.60058 .45783 m
.61905 .46816 L
s
1 .04 0 r
.26766 .45792 m
.26747 .45778 L
s
.26747 .45778 m
.26755 .45755 L
s
1 .029 0 r
.31467 .76281 m
.31477 .76261 L
s
1 .014 0 r
.64936 .54085 m
.64945 .54087 L
s
.64945 .54074 m
.64936 .54085 L
s
.64936 .54085 m
.6494 .54077 L
s
.6495 .54084 m
.64936 .54085 L
s
.64979 .54063 m
.64936 .54085 L
s
1 .04 0 r
.26788 .45769 m
.26766 .45792 L
s
.26755 .45755 m
.26788 .45769 L
s
1 .014 0 r
.64945 .54087 m
.6495 .54084 L
s
.6495 .54084 m
.64945 .54074 L
s
.64945 .54074 m
.6494 .54077 L
s
1 .009 0 r
.9282 .45768 m
.92823 .45767 L
s
.92822 .4576 m
.9282 .45768 L
s
.9282 .45768 m
.92818 .45763 L
s
.92827 .45764 m
.9282 .45768 L
s
.92832 .45747 m
.9282 .45768 L
s
.92822 .4576 m
.92818 .45763 L
s
.92827 .45764 m
.92822 .4576 L
s
.92823 .45767 m
.92827 .45764 L
s
1 .04 0 r
.26755 .45755 m
.26766 .45792 L
s
1 .009 0 r
.92818 .45763 m
.92823 .45767 L
s
1 .014 0 r
.6494 .54077 m
.64945 .54087 L
s
1 .001 0 r
.37129 .6238 m
.37128 .6238 L
s
.37129 .62379 m
.37129 .6238 L
s
.37129 .6238 m
.37128 .6238 L
s
.37129 .6238 m
.37129 .6238 L
s
.37127 .62379 m
.37129 .6238 L
s
.37128 .6238 m
.37128 .6238 L
s
.37129 .62379 m
.37128 .6238 L
s
.37129 .6238 m
.37129 .62379 L
s
.37128 .6238 m
.37129 .6238 L
s
1 0 0 r
.87097 .59607 m
.87097 .59607 L
s
1 .02 0 r
.59245 .67923 m
.5932 .67911 L
s
1 .215 0 r
.42861 .48519 m
.4222 .48173 L
s
1 .034 0 r
.20743 .42975 m
.207 .42895 L
s
0 .813 1 r
.45728 .49026 m
.46652 .48515 L
s
.46652 .48515 m
.45789 .46125 L
s
.46652 .48515 m
.43568 .48287 L
s
1 .02 0 r
.59308 .67919 m
.59305 .67923 L
s
.59305 .67904 m
.59308 .67919 L
s
.5932 .67911 m
.59308 .67919 L
s
.59302 .67908 m
.59305 .67904 L
s
.59305 .67904 m
.5932 .67911 L
s
1 .162 0 r
.48309 .5128 m
.48432 .51376 L
s
.48309 .5128 m
.48457 .5125 L
s
1 .133 0 r
.58513 .51274 m
.58548 .51373 L
s
1 .59 0 r
.5099 .48093 m
.50976 .48162 L
s
.5099 .48093 m
.50522 .4837 L
s
1 .02 0 r
.5932 .67911 m
.59305 .67923 L
s
.59302 .67908 m
.5932 .67911 L
s
.59305 .67923 m
.59302 .67908 L
s
1 .077 0 r
.80657 .40185 m
.80676 .40182 L
s
.8067 .40114 m
.80657 .40185 L
s
.80657 .40185 m
.80631 .40143 L
s
.80715 .40153 m
.80657 .40185 L
s
.80739 .39999 m
.80657 .40185 L
s
1 .215 0 r
.62269 .48499 m
.62393 .48522 L
s
.62387 .48327 m
.62269 .48499 L
s
.62269 .48499 m
.62304 .48375 L
s
.62476 .48474 m
.62269 .48499 L
s
.62872 .48129 m
.62269 .48499 L
s
1 .162 0 r
.48457 .5125 m
.48432 .51376 L
s
1 .077 0 r
.8067 .40114 m
.80631 .40143 L
s
.80715 .40153 m
.8067 .40114 L
s
1 .026 0 r
.86756 .42937 m
.86764 .42937 L
s
.86762 .42913 m
.86756 .42937 L
s
.86756 .42937 m
.86749 .42923 L
s
.86777 .42927 m
.86756 .42937 L
s
.86789 .42875 m
.86756 .42937 L
s
1 .215 0 r
.62387 .48327 m
.62304 .48375 L
s
.62476 .48474 m
.62387 .48327 L
s
1 .026 0 r
.86762 .42913 m
.86749 .42923 L
s
.86777 .42927 m
.86762 .42913 L
s
1 .215 0 r
.62393 .48522 m
.62476 .48474 L
s
1 .077 0 r
.47679 .78972 m
.47685 .7899 L
s
.47686 .78913 m
.47679 .78972 L
s
.47745 .78957 m
.47679 .78972 L
s
1 .026 0 r
.86764 .42937 m
.86777 .42927 L
s
1 .077 0 r
.80676 .40182 m
.80715 .40153 L
s
1 .026 0 r
.86749 .42923 m
.86764 .42937 L
s
1 .077 0 r
.47692 .78931 m
.47686 .78913 L
s
.47686 .78913 m
.47745 .78957 L
s
1 .034 0 r
.2071 .42896 m
.20727 .42909 L
s
.2069 .42914 m
.2071 .42896 L
s
.2071 .42896 m
.207 .42895 L
s
1 .077 0 r
.80631 .40143 m
.80676 .40182 L
s
1 .034 0 r
.20707 .42926 m
.2069 .42914 L
s
.2069 .42914 m
.207 .42895 L
s
.20727 .42909 m
.20707 .42926 L
s
.207 .42895 m
.20727 .42909 L
s
1 .077 0 r
.47745 .78957 m
.47685 .7899 L
s
.47692 .78931 m
.47745 .78957 L
s
.47446 .7893 m
.47745 .78957 L
s
1 .034 0 r
.207 .42895 m
.20707 .42926 L
s
1 .077 0 r
.47685 .7899 m
.47692 .78931 L
s
1 .01 0 r
.53216 .65065 m
.53216 .65067 L
s
.53216 .65057 m
.53216 .65065 L
s
.53224 .65062 m
.53216 .65065 L
s
.53216 .65059 m
.53216 .65057 L
s
.53216 .65057 m
.53224 .65062 L
s
1 0 0 r
.81051 .56743 m
.81051 .56743 L
s
.81051 .56742 m
.81051 .56743 L
s
.81051 .56743 m
.81051 .56743 L
s
.81051 .56743 m
.81051 .56743 L
s
.81051 .56742 m
.81051 .56743 L
s
.81051 .56742 m
.81051 .56743 L
s
.81051 .56743 m
.81051 .56742 L
s
.81051 .56743 m
.81051 .56743 L
s
.81051 .56743 m
.81051 .56743 L
s
1 .011 0 r
.75314 .7061 m
.75348 .70593 L
s
1 .01 0 r
.53183 .65063 m
.53224 .65062 L
s
1 .166 0 r
.3679 .45648 m
.36446 .45299 L
s
1 0 0 r
.31053 .59516 m
.31053 .59516 L
s
1 .01 0 r
.53224 .65062 m
.53216 .65067 L
s
.53216 .65059 m
.53224 .65062 L
s
.53216 .65067 m
.53216 .65059 L
s
1 .011 0 r
.75341 .70591 m
.75346 .70599 L
s
.75337 .70594 m
.75341 .70591 L
s
.75341 .70591 m
.75348 .70593 L
s
.75346 .70599 m
.75342 .70602 L
s
.75348 .70593 m
.75346 .70599 L
s
.75342 .70602 m
.75337 .70594 L
s
.75337 .70594 m
.75348 .70593 L
s
.75348 .70593 m
.75342 .70602 L
s
1 .053 0 r
.41521 .76121 m
.41531 .76134 L
s
.41532 .76081 m
.41521 .76121 L
s
.41571 .76116 m
.41521 .76121 L
s
.973 1 0 r
.44101 .42995 m
.43794 .42828 L
s
.43794 .42828 m
.44125 .42078 L
s
.43794 .42828 m
.43432 .42248 L
s
1 .053 0 r
.41542 .76094 m
.41532 .76081 L
s
.41532 .76081 m
.41571 .76116 L
s
1 .215 0 r
.62304 .48375 m
.62393 .48522 L
s
1 .053 0 r
.41571 .76116 m
.41531 .76134 L
s
.41542 .76094 m
.41571 .76116 L
s
.41374 .76075 m
.41571 .76116 L
s
0 1 .511 r
.4303 .40313 m
.42704 .40049 L
s
.42704 .40049 m
.43098 .38088 L
s
.42704 .40049 m
.41129 .38839 L
s
1 .59 0 r
.50522 .4837 m
.50987 .48629 L
s
.50522 .4837 m
.50976 .48162 L
s
.52856 .48324 m
.50522 .4837 L
s
0 1 .077 r
.56739 .46331 m
.57847 .45595 L
s
0 .813 1 r
.45789 .46125 m
.44855 .46612 L
s
.45789 .46125 m
.43568 .48287 L
s
1 .825 0 r
.58856 .45579 m
.5925 .45627 L
s
.59234 .44884 m
.58856 .45579 L
s
.58856 .45579 m
.58865 .45093 L
s
.59618 .45417 m
.58856 .45579 L
s
.60803 .43947 m
.58856 .45579 L
s
1 .053 0 r
.41531 .76134 m
.41542 .76094 L
s
.973 1 0 r
.44125 .42078 m
.44433 .42242 L
s
.44125 .42078 m
.43432 .42248 L
s
1 .004 0 r
.7499 .53881 m
.74992 .53882 L
s
.74992 .53878 m
.7499 .53881 L
s
.7499 .53881 m
.7499 .53879 L
s
.74993 .53881 m
.7499 .53881 L
s
.74998 .53874 m
.7499 .53881 L
s
.74992 .53878 m
.7499 .53879 L
s
.74993 .53881 m
.74992 .53878 L
s
.74992 .53882 m
.74993 .53881 L
s
.7499 .53879 m
.74992 .53882 L
s
1 .002 0 r
.4712 .62201 m
.4712 .62201 L
s
.4712 .62199 m
.4712 .62201 L
s
.47121 .622 m
.4712 .62201 L
s
.4712 .622 m
.4712 .62199 L
s
.4712 .62199 m
.47121 .622 L
s
.47121 .622 m
.4712 .62201 L
s
.4712 .622 m
.47121 .622 L
s
.47115 .62199 m
.47121 .622 L
s
.4712 .62201 m
.4712 .622 L
s
1 .01 0 r
.69258 .6775 m
.69291 .67737 L
s
1 .114 0 r
.30713 .42774 m
.30548 .42509 L
s
1 0 0 r
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
.24972 .56649 m
.24972 .56649 L
s
1 .01 0 r
.69287 .67742 m
.69284 .67744 L
s
.69284 .67734 m
.69287 .67742 L
s
.69291 .67737 m
.69287 .67742 L
s
.69281 .67737 m
.69284 .67734 L
s
.69284 .67734 m
.69291 .67737 L
s
1 .229 0 r
.66376 .45537 m
.66472 .45543 L
s
.66463 .45337 m
.66376 .45537 L
s
.66376 .45537 m
.66356 .45403 L
s
.66579 .45476 m
.66376 .45537 L
s
.66837 .45052 m
.66376 .45537 L
s
1 .01 0 r
.69284 .67744 m
.69281 .67737 L
s
.69291 .67737 m
.69284 .67744 L
s
.69281 .67737 m
.69291 .67737 L
s
1 .215 0 r
.42352 .48145 m
.42429 .48189 L
s
.42268 .48295 m
.42352 .48145 L
s
.42352 .48145 m
.4222 .48173 L
s
.42345 .4834 m
.42268 .48295 L
s
.42268 .48295 m
.4222 .48173 L
s
1 .032 0 r
.6886 .51064 m
.68877 .51066 L
s
.68875 .51037 m
.6886 .51064 L
s
.6886 .51064 m
.68862 .51046 L
s
.6889 .51058 m
.6886 .51064 L
s
.68939 .51003 m
.6886 .51064 L
s
0 .813 1 r
.43568 .48287 m
.45728 .49026 L
s
.43568 .48287 m
.44855 .46612 L
s
.54705 .44634 m
.43568 .48287 L
s
1 .032 0 r
.68875 .51037 m
.68862 .51046 L
s
.6889 .51058 m
.68875 .51037 L
s
.68877 .51066 m
.6889 .51058 L
s
1 .229 0 r
.66463 .45337 m
.66356 .45403 L
s
.66579 .45476 m
.66463 .45337 L
s
1 .032 0 r
.68862 .51046 m
.68877 .51066 L
s
1 .028 0 r
.35364 .73249 m
.35371 .73256 L
s
.35373 .73228 m
.35364 .73249 L
s
.35391 .73249 m
.35364 .73249 L
s
.35391 .73249 m
.35371 .73256 L
s
.35373 .73228 m
.35391 .73249 L
s
.35381 .73235 m
.35391 .73249 L
s
.35296 .73216 m
.35391 .73249 L
s
.35381 .73235 m
.35373 .73228 L
s
1 .229 0 r
.66472 .45543 m
.66579 .45476 L
s
1 .028 0 r
.35371 .73256 m
.35381 .73235 L
s
1 .825 0 r
.59234 .44884 m
.58865 .45093 L
s
.59618 .45417 m
.59234 .44884 L
s
1 .08 0 r
.57708 .78769 m
.57702 .78787 L
s
.57701 .78708 m
.57708 .78769 L
s
.57764 .78742 m
.57708 .78769 L
s
1 0 0 r
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
.91094 .56556 m
.91094 .56556 L
s
1 .007 0 r
.63195 .64886 m
.63219 .64879 L
s
1 .08 0 r
.57451 .78769 m
.57764 .78742 L
s
1 0 0 r
.4104 .59333 m
.4104 .59333 L
s
1 .825 0 r
.46784 .4545 m
.44054 .44309 L
s
1 .08 0 r
.24628 .39897 m
.24544 .39702 L
s
1 .007 0 r
.63216 .64882 m
.63214 .64884 L
s
.63214 .64877 m
.63216 .64882 L
s
.63219 .64879 m
.63216 .64882 L
s
.63212 .64879 m
.63214 .64877 L
s
.63214 .64877 m
.63219 .64879 L
s
1 .08 0 r
.57694 .78726 m
.57701 .78708 L
s
.57701 .78708 m
.57764 .78742 L
s
1 .007 0 r
.63219 .64879 m
.63214 .64884 L
s
.63212 .64879 m
.63219 .64879 L
s
.63214 .64884 m
.63212 .64879 L
s
1 .59 0 r
.50976 .48162 m
.50987 .48629 L
s
1 .825 0 r
.5925 .45627 m
.59618 .45417 L
s
1 .08 0 r
.57764 .78742 m
.57702 .78787 L
s
.57694 .78726 m
.57764 .78742 L
s
1 .028 0 r
.9076 .39862 m
.90767 .39861 L
s
.90764 .39836 m
.9076 .39862 L
s
.9076 .39862 m
.9075 .39847 L
s
.9078 .3985 m
.9076 .39862 L
s
.90787 .39794 m
.9076 .39862 L
s
1 .215 0 r
.42429 .48189 m
.42345 .4834 L
s
.4222 .48173 m
.42429 .48189 L
s
.4222 .48173 m
.42345 .4834 L
s
1 .65 0 r
.39728 .39401 m
.40033 .39579 L
s
.39401 .39798 m
.39728 .39401 L
s
.39728 .39401 m
.39451 .39405 L
s
1 .166 0 r
.36519 .45294 m
.36595 .45342 L
s
.36435 .45396 m
.36519 .45294 L
s
.36519 .45294 m
.36446 .45299 L
s
1 .028 0 r
.90764 .39836 m
.9075 .39847 L
s
.9078 .3985 m
.90764 .39836 L
s
.90767 .39861 m
.9078 .3985 L
s
0 1 .511 r
.43098 .38088 m
.43428 .38336 L
s
.43098 .38088 m
.41129 .38839 L
s
1 .229 0 r
.66356 .45403 m
.66472 .45543 L
s
1 .08 0 r
.57702 .78787 m
.57694 .78726 L
s
1 .028 0 r
.9075 .39847 m
.90767 .39861 L
s
1 .166 0 r
.36512 .45444 m
.36435 .45396 L
s
.36435 .45396 m
.36446 .45299 L
s
1 .073 0 r
.51608 .75936 m
.5161 .75951 L
s
.5161 .75879 m
.51608 .75936 L
s
.51668 .75917 m
.51608 .75936 L
s
.51611 .75895 m
.5161 .75879 L
s
.5161 .75879 m
.51668 .75917 L
s
1 .011 0 r
.29245 .70371 m
.29237 .70373 L
s
.29238 .70362 m
.29245 .70371 L
s
.29245 .70371 m
.29234 .7037 L
s
.29242 .70365 m
.29245 .70371 L
s
.29211 .70354 m
.29245 .70371 L
s
1 .114 0 r
.30584 .42511 m
.30641 .4255 L
s
.30521 .42574 m
.30584 .42511 L
s
.30584 .42511 m
.30548 .42509 L
s
1 .011 0 r
.29238 .70362 m
.29234 .7037 L
s
.29242 .70365 m
.29238 .70362 L
s
.29234 .7037 m
.29237 .70373 L
s
.29237 .70373 m
.29242 .70365 L
s
1 .073 0 r
.51668 .75917 m
.5161 .75951 L
s
.51611 .75895 m
.51668 .75917 L
s
.51378 .7591 m
.51668 .75917 L
s
1 .65 0 r
.39705 .39976 m
.39401 .39798 L
s
.39401 .39798 m
.39451 .39405 L
s
1 .001 0 r
.85038 .53687 m
.85038 .53687 L
s
.85038 .53686 m
.85038 .53687 L
s
.85038 .53687 m
.85038 .53687 L
s
.85039 .53687 m
.85038 .53687 L
s
.8504 .53685 m
.85038 .53687 L
s
.85038 .53686 m
.85038 .53687 L
s
.85039 .53687 m
.85038 .53686 L
s
.85038 .53687 m
.85039 .53687 L
s
.85038 .53687 m
.85038 .53687 L
s
1 .114 0 r
.30577 .42613 m
.30521 .42574 L
s
.30521 .42574 m
.30548 .42509 L
s
1 .004 0 r
.79293 .67576 m
.79305 .67569 L
s
1 .002 0 r
.57125 .62019 m
.57133 .62018 L
s
1 .001 0 r
.34958 .56463 m
.34955 .56462 L
s
1 .525 0 r
.40705 .42572 m
.39634 .4144 L
s
1 .002 0 r
.57131 .62019 m
.57131 .62019 L
s
.57131 .62018 m
.57131 .62019 L
s
.57133 .62018 m
.57131 .62019 L
s
.57131 .62018 m
.57131 .62018 L
s
.57131 .62018 m
.57133 .62018 L
s
1 .001 0 r
.34956 .56462 m
.34956 .56462 L
s
.34956 .56462 m
.34956 .56462 L
s
.34956 .56462 m
.34955 .56462 L
s
.34956 .56462 m
.34956 .56462 L
s
.34956 .56462 m
.34955 .56462 L
s
1 .002 0 r
.57133 .62018 m
.57131 .62019 L
s
.57131 .62018 m
.57133 .62018 L
s
.57131 .62019 m
.57131 .62018 L
s
1 .001 0 r
.34956 .56462 m
.34956 .56462 L
s
.34955 .56462 m
.34956 .56462 L
s
.34955 .56462 m
.34956 .56462 L
s
1 .004 0 r
.79302 .67568 m
.79304 .67571 L
s
.793 .67569 m
.79302 .67568 L
s
.79302 .67568 m
.79305 .67569 L
s
.79304 .67571 m
.79302 .67572 L
s
.79305 .67569 m
.79304 .67571 L
s
.79302 .67572 m
.793 .67569 L
s
.793 .67569 m
.79305 .67569 L
s
.79305 .67569 m
.79302 .67572 L
s
1 .166 0 r
.36595 .45342 m
.36512 .45444 L
s
.36446 .45299 m
.36595 .45342 L
s
1 .073 0 r
.5161 .75951 m
.51611 .75895 L
s
1 .114 0 r
.30641 .4255 m
.30577 .42613 L
s
.30548 .42509 m
.30641 .4255 L
s
1 .166 0 r
.36446 .45299 m
.36512 .45444 L
s
1 .08 0 r
.24564 .39705 m
.24604 .39736 L
s
.24517 .39746 m
.24564 .39705 L
s
.24564 .39705 m
.24544 .39702 L
s
1 .114 0 r
.30548 .42509 m
.30577 .42613 L
s
1 .08 0 r
.24557 .39776 m
.24517 .39746 L
s
.24517 .39746 m
.24544 .39702 L
s
1 .052 0 r
.4545 .73087 m
.45457 .73098 L
s
.45458 .73047 m
.4545 .73087 L
s
.45498 .73078 m
.4545 .73087 L
s
1 .08 0 r
.24604 .39736 m
.24557 .39776 L
s
.24544 .39702 m
.24604 .39736 L
s
1 .052 0 r
.45465 .73058 m
.45458 .73047 L
s
.45458 .73047 m
.45498 .73078 L
s
.45498 .73078 m
.45457 .73098 L
s
.45465 .73058 m
.45498 .73078 L
s
.45299 .73048 m
.45498 .73078 L
s
1 .08 0 r
.24544 .39702 m
.24557 .39776 L
s
1 .008 0 r
.78964 .50828 m
.78967 .50828 L
s
.78967 .50821 m
.78964 .50828 L
s
.78964 .50828 m
.78963 .50823 L
s
.78971 .50826 m
.78964 .50828 L
s
.78979 .5081 m
.78964 .50828 L
s
.78967 .50821 m
.78963 .50823 L
s
.78971 .50826 m
.78967 .50821 L
s
.78967 .50828 m
.78971 .50826 L
s
1 .052 0 r
.45457 .73098 m
.45465 .73058 L
s
1 .008 0 r
.78963 .50823 m
.78967 .50828 L
s
1 .046 0 r
.72825 .48031 m
.72844 .48032 L
s
.72841 .4799 m
.72825 .48031 L
s
.72825 .48031 m
.72819 .48005 L
s
.72865 .48017 m
.72825 .48031 L
s
.72912 .47933 m
.72825 .48031 L
s
1 .057 0 r
.67479 .78608 m
.67683 .78555 L
s
1 .003 0 r
.73229 .64709 m
.73237 .64705 L
s
1 0 0 r
.51049 .59149 m
.51049 .59149 L
s
1 .293 0 r
.34619 .39691 m
.3426 .38986 L
s
1 .003 0 r
.28869 .5359 m
.28862 .53583 L
s
.73235 .64704 m
.73236 .64706 L
s
.73234 .64705 m
.73235 .64704 L
s
.73235 .64704 m
.73237 .64705 L
s
.73236 .64706 m
.73235 .64707 L
s
.73237 .64705 m
.73236 .64706 L
s
.73235 .64707 m
.73234 .64705 L
s
.73234 .64705 m
.73237 .64705 L
s
.73237 .64705 m
.73235 .64707 L
s
.28863 .53583 m
.28865 .53584 L
s
.28862 .53585 m
.28863 .53583 L
s
.28863 .53583 m
.28862 .53583 L
s
.28863 .53586 m
.28862 .53585 L
s
.28862 .53585 m
.28862 .53583 L
s
.28865 .53584 m
.28863 .53586 L
s
.28862 .53583 m
.28865 .53584 L
s
.28862 .53583 m
.28863 .53586 L
s
1 .046 0 r
.72841 .4799 m
.72819 .48005 L
s
.72865 .48017 m
.72841 .4799 L
s
.72844 .48032 m
.72865 .48017 L
s
0 .434 1 r
.43751 .45048 m
.44721 .47731 L
s
1 .046 0 r
.72819 .48005 m
.72844 .48032 L
s
1 .202 0 r
.7054 .42438 m
.706 .42434 L
s
.7059 .42253 m
.7054 .42438 L
s
.7054 .42438 m
.70487 .42323 L
s
.70702 .42364 m
.7054 .42438 L
s
.70816 .41964 m
.7054 .42438 L
s
1 .057 0 r
.67656 .78579 m
.67643 .78594 L
s
.6764 .78537 m
.67656 .78579 L
s
.67683 .78555 m
.67656 .78579 L
s
1 .787 0 r
.54609 .48118 m
.54817 .47994 L
s
.54817 .47994 m
.54605 .47402 L
s
.54817 .47994 m
.54056 .47937 L
s
1 .057 0 r
.67628 .78551 m
.6764 .78537 L
s
.6764 .78537 m
.67683 .78555 L
s
0 1 .077 r
.55604 .45189 m
.56739 .46331 L
s
1 .057 0 r
.67683 .78555 m
.67643 .78594 L
s
.67628 .78551 m
.67683 .78555 L
s
1 .026 0 r
.39278 .70211 m
.39285 .70217 L
s
.39286 .70192 m
.39278 .70211 L
s
.39304 .7021 m
.39278 .70211 L
s
1 .057 0 r
.67643 .78594 m
.67628 .78551 L
s
1 .026 0 r
.39292 .70198 m
.39286 .70192 L
s
.39286 .70192 m
.39304 .7021 L
s
.39304 .7021 m
.39285 .70217 L
s
.39292 .70198 m
.39304 .7021 L
s
.39212 .70183 m
.39304 .7021 L
s
1 .202 0 r
.7059 .42253 m
.70487 .42323 L
s
.70702 .42364 m
.7059 .42253 L
s
1 .787 0 r
.54605 .47402 m
.54397 .47525 L
s
.54605 .47402 m
.54056 .47937 L
s
1 .026 0 r
.39285 .70217 m
.39292 .70198 L
s
1 .787 0 r
.54056 .47937 m
.54609 .48118 L
s
.54056 .47937 m
.54397 .47525 L
s
.56823 .47045 m
.54056 .47937 L
s
1 0 0 r
.95104 .53496 m
.95104 .53496 L
s
.95104 .53496 m
.95104 .53496 L
s
.95104 .53496 m
.95103 .53496 L
s
.95104 .53496 m
.95104 .53496 L
s
.95104 .53495 m
.95104 .53496 L
s
.95104 .53496 m
.95103 .53496 L
s
.95104 .53496 m
.95104 .53496 L
s
.95104 .53496 m
.95104 .53496 L
s
.95103 .53496 m
.95104 .53496 L
s
1 .063 0 r
.61405 .75745 m
.61645 .75704 L
s
1 .001 0 r
.67158 .61839 m
.67161 .61838 L
s
1 .003 0 r
.44966 .56276 m
.44954 .56273 L
s
0 1 .331 r
.50719 .4237 m
.41761 .40733 L
s
1 .006 0 r
.22773 .50714 m
.22763 .50702 L
s
1 .001 0 r
.67161 .61838 m
.6716 .61838 L
s
.6716 .61838 m
.67161 .61838 L
s
.67161 .61838 m
.67161 .61838 L
s
.6716 .61838 m
.6716 .61838 L
s
.6716 .61838 m
.67161 .61838 L
s
.6716 .61838 m
.6716 .61838 L
s
.67161 .61838 m
.6716 .61838 L
s
.6716 .61838 m
.67161 .61838 L
s
1 .003 0 r
.44957 .56275 m
.44956 .56275 L
s
.44956 .56275 m
.44957 .56272 L
s
.44956 .56275 m
.44954 .56273 L
s
.44957 .56272 m
.44957 .56273 L
s
.44957 .56272 m
.44954 .56273 L
s
.44954 .56273 m
.44957 .56275 L
s
.44954 .56273 m
.44957 .56273 L
s
.44957 .56273 m
.44957 .56275 L
s
1 .202 0 r
.706 .42434 m
.70702 .42364 L
s
1 .006 0 r
.22766 .50701 m
.22768 .50703 L
s
.22762 .50705 m
.22766 .50701 L
s
.22766 .50701 m
.22763 .50702 L
s
.22765 .50707 m
.22762 .50705 L
s
.22762 .50705 m
.22763 .50702 L
s
1 .65 0 r
.40033 .39579 m
.39705 .39976 L
s
.39451 .39405 m
.40033 .39579 L
s
1 .006 0 r
.22768 .50703 m
.22765 .50707 L
s
.22763 .50702 m
.22768 .50703 L
s
.22763 .50702 m
.22765 .50707 L
s
1 .063 0 r
.61607 .7573 m
.61598 .75744 L
s
.61596 .75681 m
.61607 .7573 L
s
.61645 .75704 m
.61607 .7573 L
s
.61586 .75695 m
.61596 .75681 L
s
.61596 .75681 m
.61645 .75704 L
s
.808 1 0 r
.62712 .39562 m
.62731 .39499 L
s
.62696 .38442 m
.62712 .39562 L
s
.62712 .39562 m
.62035 .38983 L
s
.63392 .38956 m
.62712 .39562 L
s
.62721 .36558 m
.62712 .39562 L
s
1 .202 0 r
.70487 .42323 m
.706 .42434 L
s
1 .063 0 r
.61645 .75704 m
.61598 .75744 L
s
.61586 .75695 m
.61645 .75704 L
s
.61598 .75744 m
.61586 .75695 L
s
1 .825 0 r
.58865 .45093 m
.5925 .45627 L
s
1 .65 0 r
.39451 .39405 m
.39705 .39976 L
s
1 .009 0 r
.33145 .67327 m
.3314 .67328 L
s
.3314 .6732 m
.33145 .67327 L
s
.33145 .67327 m
.33137 .67326 L
s
.33143 .67322 m
.33145 .67327 L
s
.33119 .67314 m
.33145 .67327 L
s
.3314 .6732 m
.33137 .67326 L
s
.33143 .67322 m
.3314 .6732 L
s
.33137 .67326 m
.3314 .67328 L
s
.3314 .67328 m
.33143 .67322 L
s
1 .062 0 r
.55522 .72886 m
.55519 .72899 L
s
.55518 .72838 m
.55522 .72886 L
s
.55567 .72865 m
.55522 .72886 L
s
1 .003 0 r
.89038 .50623 m
.89039 .50623 L
s
.89039 .50621 m
.89038 .50623 L
s
.89038 .50623 m
.89037 .50622 L
s
.8904 .50622 m
.89038 .50623 L
s
.89042 .50617 m
.89038 .50623 L
s
.89039 .50621 m
.89037 .50622 L
s
.8904 .50622 m
.89039 .50621 L
s
.89039 .50623 m
.8904 .50622 L
s
.89037 .50622 m
.89039 .50623 L
s
.973 1 0 r
.44433 .42242 m
.44101 .42995 L
s
.43432 .42248 m
.44101 .42995 L
s
1 .607 0 r
.64013 .42272 m
.64179 .42258 L
s
.64158 .41716 m
.64013 .42272 L
s
.64013 .42272 m
.63842 .41926 L
s
.64495 .42047 m
.64013 .42272 L
s
.64795 .40839 m
.64013 .42272 L
s
1 .062 0 r
.55515 .72851 m
.55518 .72838 L
s
.55518 .72838 m
.55567 .72865 L
s
1 .001 0 r
.83286 .64531 m
.83288 .6453 L
s
1 .062 0 r
.55324 .7288 m
.55567 .72865 L
s
1 0 0 r
.61081 .58966 m
.61081 .58966 L
s
1 .014 0 r
.38876 .534 m
.38836 .53376 L
s
.542 1 0 r
.44633 .39486 m
.41689 .36247 L
s
1 .001 0 r
.83287 .64529 m
.83288 .6453 L
s
.83287 .6453 m
.83287 .64529 L
s
.83287 .64529 m
.83288 .6453 L
s
.83288 .6453 m
.83288 .6453 L
s
.83288 .6453 m
.83288 .6453 L
s
.83288 .6453 m
.83287 .6453 L
s
.83287 .6453 m
.83288 .6453 L
s
.83288 .6453 m
.83288 .6453 L
s
1 .014 0 r
.38844 .53374 m
.38849 .53378 L
s
.38838 .53384 m
.38844 .53374 L
s
.38844 .53374 m
.38836 .53376 L
s
.38844 .53387 m
.38838 .53384 L
s
.38838 .53384 m
.38836 .53376 L
s
1 .062 0 r
.55567 .72865 m
.55519 .72899 L
s
.55515 .72851 m
.55567 .72865 L
s
.973 1 0 r
.43432 .42248 m
.44433 .42242 L
s
1 .014 0 r
.38849 .53378 m
.38844 .53387 L
s
.38836 .53376 m
.38849 .53378 L
s
.38836 .53376 m
.38844 .53387 L
s
1 .062 0 r
.55519 .72899 m
.55515 .72851 L
s
1 .013 0 r
.82954 .47765 m
.82959 .47765 L
s
.82958 .47753 m
.82954 .47765 L
s
.82954 .47765 m
.82951 .47758 L
s
.82965 .4776 m
.82954 .47765 L
s
.82974 .47736 m
.82954 .47765 L
s
1 .046 0 r
.49376 .70036 m
.4938 .70045 L
s
.4938 .7 m
.49376 .70036 L
s
.49416 .70025 m
.49376 .70036 L
s
1 .013 0 r
.82958 .47753 m
.82951 .47758 L
s
.82965 .4776 m
.82958 .47753 L
s
.82959 .47765 m
.82965 .4776 L
s
1 .046 0 r
.49383 .70009 m
.4938 .7 L
s
.4938 .7 m
.49416 .70025 L
s
1 .013 0 r
.82951 .47758 m
.82959 .47765 L
s
1 .052 0 r
.76823 .44972 m
.7684 .44971 L
s
.76836 .44924 m
.76823 .44972 L
s
.76823 .44972 m
.7681 .44943 L
s
.76865 .44953 m
.76823 .44972 L
s
.76898 .44852 m
.76823 .44972 L
s
1 .046 0 r
.49416 .70025 m
.4938 .70045 L
s
.49383 .70009 m
.49416 .70025 L
s
.49236 .70011 m
.49416 .70025 L
s
1 .052 0 r
.76836 .44924 m
.7681 .44943 L
s
.76865 .44953 m
.76836 .44924 L
s
1 .005 0 r
.54979 .56093 m
.5498 .56093 L
s
.5498 .56093 m
.54979 .56088 L
s
.5498 .56093 m
.54975 .56091 L
s
1 .002 0 r
.27023 .64445 m
.27022 .64446 L
s
.27022 .64444 m
.27023 .64445 L
s
.27023 .64445 m
.27022 .64445 L
s
.27023 .64445 m
.27023 .64445 L
s
.27019 .64442 m
.27023 .64445 L
s
1 .005 0 r
.54979 .56088 m
.54979 .56089 L
s
.54979 .56088 m
.54975 .56091 L
s
1 .002 0 r
.27022 .64444 m
.27022 .64445 L
s
.27023 .64445 m
.27022 .64444 L
s
.27022 .64445 m
.27022 .64446 L
s
.27022 .64446 m
.27023 .64445 L
s
1 .005 0 r
.54975 .56091 m
.54979 .56093 L
s
.54975 .56091 m
.54979 .56089 L
s
.54996 .56089 m
.54975 .56091 L
s
1 .046 0 r
.4938 .70045 m
.49383 .70009 L
s
1 .052 0 r
.7684 .44971 m
.76865 .44953 L
s
1 .005 0 r
.54979 .56089 m
.54979 .56093 L
s
1 .038 0 r
.71454 .7558 m
.71579 .75535 L
s
1 0 0 r
.77214 .61658 m
.77214 .61658 L
s
1 .021 0 r
.32779 .5052 m
.32734 .50477 L
s
1 0 0 r
.77214 .61658 m
.77214 .61658 L
s
.77214 .61658 m
.77214 .61658 L
s
.77214 .61658 m
.77214 .61658 L
s
.77214 .61658 m
.77214 .61658 L
s
.77214 .61658 m
.77214 .61658 L
s
.77214 .61658 m
.77214 .61658 L
s
.77214 .61658 m
.77214 .61658 L
s
.77214 .61658 m
.77214 .61658 L
s
1 .052 0 r
.7681 .44943 m
.7684 .44971 L
s
1 .607 0 r
.64158 .41716 m
.63842 .41926 L
s
.64495 .42047 m
.64158 .41716 L
s
1 .021 0 r
.32743 .50476 m
.32753 .50482 L
s
.32733 .50489 m
.32743 .50476 L
s
.32743 .50476 m
.32734 .50477 L
s
.32742 .50495 m
.32733 .50489 L
s
.32733 .50489 m
.32734 .50477 L
s
1 .038 0 r
.71565 .75553 m
.71555 .75563 L
s
.71553 .75526 m
.71565 .75553 L
s
.71579 .75535 m
.71565 .75553 L
s
.71542 .75536 m
.71553 .75526 L
s
.71553 .75526 m
.71579 .75535 L
s
0 .813 1 r
.62507 .47698 m
.61409 .47819 L
s
.61328 .44909 m
.62507 .47698 L
s
.62507 .47698 m
.59745 .46879 L
s
.63001 .45833 m
.62507 .47698 L
s
.56634 .40784 m
.62507 .47698 L
s
1 .021 0 r
.32753 .50482 m
.32742 .50495 L
s
.32734 .50477 m
.32753 .50482 L
s
.32734 .50477 m
.32742 .50495 L
s
1 .038 0 r
.71555 .75563 m
.71542 .75536 L
s
.71579 .75535 m
.71555 .75563 L
s
.71542 .75536 m
.71579 .75535 L
s
1 .021 0 r
.43199 .6716 m
.43203 .67165 L
s
.43204 .67144 m
.43199 .6716 L
s
.43219 .67158 m
.43199 .6716 L
s
.43208 .67149 m
.43204 .67144 L
s
.43204 .67144 m
.43219 .67158 L
s
.43219 .67158 m
.43203 .67165 L
s
.43208 .67149 m
.43219 .67158 L
s
.43142 .67139 m
.43219 .67158 L
s
.43203 .67165 m
.43208 .67149 L
s
1 .168 0 r
.7466 .39281 m
.74694 .39272 L
s
.74684 .39124 m
.7466 .39281 L
s
.7466 .39281 m
.74596 .39189 L
s
.74782 .39207 m
.7466 .39281 L
s
.74807 .38866 m
.7466 .39281 L
s
.808 1 0 r
.62696 .38442 m
.62035 .38983 L
s
.63392 .38956 m
.62696 .38442 L
s
1 0 0 r
.71135 .58782 m
.71135 .58782 L
s
1 .042 0 r
.65372 .72711 m
.65523 .7267 L
s
1 .058 0 r
.48905 .5321 m
.48682 .53171 L
s
1 .022 0 r
.26675 .47638 m
.26639 .47588 L
s
1 .058 0 r
.48726 .53206 m
.48718 .53197 L
s
.48718 .53197 m
.48727 .53152 L
s
.48718 .53197 m
.48682 .53171 L
s
.48727 .53152 m
.48736 .53161 L
s
.48727 .53152 m
.48682 .53171 L
s
1 .607 0 r
.64179 .42258 m
.64495 .42047 L
s
1 .042 0 r
.65503 .72689 m
.65493 .72699 L
s
.65492 .72658 m
.65503 .72689 L
s
.65523 .7267 m
.65503 .72689 L
s
.65482 .72668 m
.65492 .72658 L
s
.65492 .72658 m
.65523 .7267 L
s
1 .022 0 r
.26647 .47587 m
.26658 .47595 L
s
.26634 .476 m
.26647 .47587 L
s
.26647 .47587 m
.26639 .47588 L
s
1 .043 0 r
.31414 .78254 m
.31385 .78265 L
s
.31387 .78222 m
.31414 .78254 L
s
.31414 .78254 m
.31372 .78253 L
s
.314 .78234 m
.31414 .78254 L
s
.31274 .78202 m
.31414 .78254 L
s
1 .168 0 r
.74684 .39124 m
.74596 .39189 L
s
.74782 .39207 m
.74684 .39124 L
s
1 .043 0 r
.31372 .78253 m
.31385 .78265 L
s
.31387 .78222 m
.31372 .78253 L
s
1 .022 0 r
.26645 .47608 m
.26634 .476 L
s
.26634 .476 m
.26639 .47588 L
s
1 .043 0 r
.314 .78234 m
.31387 .78222 L
s
1 .058 0 r
.48682 .53171 m
.48726 .53206 L
s
.48682 .53171 m
.48736 .53161 L
s
1 .022 0 r
.26658 .47595 m
.26645 .47608 L
s
.26639 .47588 m
.26658 .47595 L
s
.26639 .47588 m
.26645 .47608 L
s
1 .058 0 r
.48736 .53161 m
.48726 .53206 L
s
1 .042 0 r
.65523 .7267 m
.65493 .72699 L
s
.65482 .72668 m
.65523 .7267 L
s
.65493 .72699 m
.65482 .72668 L
s
1 .043 0 r
.31385 .78265 m
.314 .78234 L
s
1 .168 0 r
.74694 .39272 m
.74782 .39207 L
s
1 .293 0 r
.3434 .38998 m
.34491 .39102 L
s
.34174 .39154 m
.3434 .38998 L
s
.3434 .38998 m
.3426 .38986 L
s
1 .787 0 r
.54397 .47525 m
.54609 .48118 L
s
1 .825 0 r
.44593 .44911 m
.44344 .44772 L
s
.44344 .44772 m
.44612 .44166 L
s
.44344 .44772 m
.44054 .44309 L
s
1 .168 0 r
.74596 .39189 m
.74694 .39272 L
s
1 .005 0 r
.93052 .4755 m
.93053 .4755 L
s
.93053 .47546 m
.93052 .4755 L
s
.93052 .4755 m
.93051 .47547 L
s
.93056 .47548 m
.93052 .4755 L
s
.93058 .47539 m
.93052 .4755 L
s
.93053 .47546 m
.93051 .47547 L
s
.93056 .47548 m
.93053 .47546 L
s
.93053 .4755 m
.93056 .47548 L
s
.93051 .47547 m
.93053 .4755 L
s
.37056 .64271 m
.37053 .64272 L
s
.37053 .64267 m
.37056 .64271 L
s
.37056 .64271 m
.37051 .64271 L
s
.37055 .64269 m
.37056 .64271 L
s
.3704 .64264 m
.37056 .64271 L
s
.37051 .64271 m
.37053 .64272 L
s
.37053 .64267 m
.37051 .64271 L
s
.37055 .64269 m
.37053 .64267 L
s
.37053 .64272 m
.37055 .64269 L
s
1 .002 0 r
.65043 .55905 m
.65045 .55905 L
s
.65045 .55903 m
.65043 .55905 L
s
.65043 .55905 m
.65044 .55904 L
s
.65045 .55905 m
.65043 .55905 L
s
.65049 .55902 m
.65043 .55905 L
s
.65045 .55905 m
.65045 .55905 L
s
.65045 .55905 m
.65045 .55903 L
s
.65045 .55903 m
.65044 .55904 L
s
.65044 .55904 m
.65045 .55905 L
s
1 0 0 r
.87292 .61477 m
.87292 .61477 L
s
1 .043 0 r
.59283 .69839 m
.59445 .69813 L
s
1 .111 0 r
.42807 .50327 m
.42475 .50149 L
s
1 .021 0 r
.20565 .44752 m
.20538 .44702 L
s
1 0 0 r
.87292 .61477 m
.87292 .61477 L
s
.87292 .61477 m
.87292 .61477 L
s
.87292 .61477 m
.87292 .61477 L
s
.87292 .61477 m
.87292 .61477 L
s
.87292 .61477 m
.87292 .61477 L
s
.87292 .61477 m
.87292 .61477 L
s
.87292 .61477 m
.87292 .61477 L
s
.87292 .61477 m
.87292 .61477 L
s
1 .825 0 r
.44612 .44166 m
.44862 .44304 L
s
.44612 .44166 m
.44054 .44309 L
s
1 .043 0 r
.59419 .69831 m
.59413 .69839 L
s
.59412 .69798 m
.59419 .69831 L
s
.59445 .69813 m
.59419 .69831 L
s
.59406 .69807 m
.59412 .69798 L
s
.59412 .69798 m
.59445 .69813 L
s
1 .293 0 r
.34325 .39258 m
.34174 .39154 L
s
.34174 .39154 m
.3426 .38986 L
s
1 .043 0 r
.59445 .69813 m
.59413 .69839 L
s
.59406 .69807 m
.59445 .69813 L
s
1 .021 0 r
.20544 .44703 m
.20554 .44711 L
s
.20532 .44714 m
.20544 .44703 L
s
.20544 .44703 m
.20538 .44702 L
s
1 .043 0 r
.59413 .69839 m
.59406 .69807 L
s
1 .607 0 r
.63842 .41926 m
.64179 .42258 L
s
1 .021 0 r
.20542 .44722 m
.20532 .44714 L
s
.20532 .44714 m
.20538 .44702 L
s
.20554 .44711 m
.20542 .44722 L
s
.20538 .44702 m
.20554 .44711 L
s
1 .047 0 r
.58824 .53082 m
.58836 .53074 L
s
.58836 .53074 m
.58823 .53038 L
s
.58836 .53074 m
.58791 .5307 L
s
1 .021 0 r
.20538 .44702 m
.20542 .44722 L
s
1 .047 0 r
.58823 .53038 m
.58812 .53046 L
s
.58823 .53038 m
.58791 .5307 L
s
.58791 .5307 m
.58824 .53082 L
s
.58791 .5307 m
.58812 .53046 L
s
.58957 .53019 m
.58791 .5307 L
s
1 .344 0 r
.51761 .50312 m
.51769 .50269 L
s
.51769 .50269 m
.51762 .49996 L
s
.51769 .50269 m
.51488 .50159 L
s
1 .016 0 r
.86961 .4469 m
.86966 .44689 L
s
.86965 .44675 m
.86961 .4469 L
s
.86961 .4469 m
.86957 .44681 L
s
.86974 .44683 m
.86961 .4469 L
s
.86981 .44651 m
.86961 .4469 L
s
.86965 .44675 m
.86957 .44681 L
s
.86974 .44683 m
.86965 .44675 L
s
.86966 .44689 m
.86974 .44683 L
s
1 .047 0 r
.58812 .53046 m
.58824 .53082 L
s
1 .016 0 r
.86957 .44681 m
.86966 .44689 L
s
1 .293 0 r
.34491 .39102 m
.34325 .39258 L
s
.3426 .38986 m
.34491 .39102 L
s
1 .053 0 r
.8084 .41889 m
.80854 .41887 L
s
.8085 .4184 m
.8084 .41889 L
s
.8084 .41889 m
.80823 .4186 L
s
.80881 .41867 m
.8084 .41889 L
s
.80898 .41761 m
.8084 .41889 L
s
.8085 .4184 m
.80823 .4186 L
s
.80881 .41867 m
.8085 .4184 L
s
1 .032 0 r
.53289 .66972 m
.53289 .66978 L
s
.53289 .66947 m
.53289 .66972 L
s
.53314 .66962 m
.53289 .66972 L
s
1 .344 0 r
.51762 .49996 m
.51755 .50038 L
s
.51762 .49996 m
.51488 .50159 L
s
1 .032 0 r
.53288 .66953 m
.53289 .66947 L
s
.53289 .66947 m
.53314 .66962 L
s
1 .053 0 r
.80854 .41887 m
.80881 .41867 L
s
1 0 0 r
.30933 .61387 m
.30933 .61387 L
s
.30933 .61386 m
.30933 .61387 L
s
.30933 .61387 m
.30933 .61387 L
s
.30933 .61387 m
.30933 .61387 L
s
.30932 .61386 m
.30933 .61387 L
s
.30933 .61386 m
.30933 .61387 L
s
.30933 .61387 m
.30933 .61386 L
s
.30933 .61387 m
.30933 .61387 L
s
.30933 .61387 m
.30933 .61387 L
s
1 .021 0 r
.75442 .72542 m
.75506 .72513 L
s
1 0 0 r
.81212 .58597 m
.81212 .58597 L
s
1 .032 0 r
.53187 .66964 m
.53314 .66962 L
s
1 .1 0 r
.36702 .47441 m
.36494 .47232 L
s
1 .053 0 r
.80823 .4186 m
.80854 .41887 L
s
1 .032 0 r
.53314 .66962 m
.53289 .66978 L
s
.53288 .66953 m
.53314 .66962 L
s
.53289 .66978 m
.53288 .66953 L
s
0 1 .331 r
.43536 .42111 m
.43227 .4185 L
s
.43227 .4185 m
.43595 .40022 L
s
.43227 .4185 m
.41761 .40733 L
s
1 .077 0 r
.41525 .78106 m
.41539 .78124 L
s
.41541 .78048 m
.41525 .78106 L
s
.41597 .78098 m
.41525 .78106 L
s
1 .111 0 r
.42543 .50134 m
.42583 .50158 L
s
.425 .50212 m
.42543 .50134 L
s
.42543 .50134 m
.42475 .50149 L
s
.4254 .50236 m
.425 .50212 L
s
.425 .50212 m
.42475 .50149 L
s
1 .293 0 r
.3426 .38986 m
.34325 .39258 L
s
1 .077 0 r
.41556 .78066 m
.41541 .78048 L
s
.41541 .78048 m
.41597 .78098 L
s
1 .021 0 r
.75492 .72508 m
.75501 .72523 L
s
.75485 .72514 m
.75492 .72508 L
s
.75492 .72508 m
.75506 .72513 L
s
.75501 .72523 m
.75494 .72529 L
s
.75506 .72513 m
.75501 .72523 L
s
1 .077 0 r
.41597 .78098 m
.41539 .78124 L
s
.41556 .78066 m
.41597 .78098 L
s
.41311 .78039 m
.41597 .78098 L
s
1 .021 0 r
.75494 .72529 m
.75485 .72514 L
s
.75485 .72514 m
.75506 .72513 L
s
.75506 .72513 m
.75494 .72529 L
s
0 .434 1 r
.61905 .46816 m
.6367 .44617 L
s
1 .525 0 r
.39859 .41433 m
.40106 .4158 L
s
.39593 .41756 m
.39859 .41433 L
s
.39859 .41433 m
.39634 .4144 L
s
1 .077 0 r
.41539 .78124 m
.41556 .78066 L
s
1 .344 0 r
.51488 .50159 m
.51761 .50312 L
s
.51488 .50159 m
.51755 .50038 L
s
.52857 .50133 m
.51488 .50159 L
s
1 .111 0 r
.42583 .50158 m
.4254 .50236 L
s
.42475 .50149 m
.42583 .50158 L
s
.42475 .50149 m
.4254 .50236 L
s
.808 1 0 r
.62035 .38983 m
.62731 .39499 L
s
1 .013 0 r
.47121 .64096 m
.47123 .64098 L
s
.47123 .64086 m
.47121 .64096 L
s
.47133 .64094 m
.47121 .64096 L
s
.47125 .64088 m
.47123 .64086 L
s
.47123 .64086 m
.47133 .64094 L
s
.47133 .64094 m
.47123 .64098 L
s
.47125 .64088 m
.47133 .64094 L
s
.47084 .64086 m
.47133 .64094 L
s
.47123 .64098 m
.47125 .64088 L
s
1 0 0 r
.75124 .55715 m
.75124 .55715 L
s
.75124 .55714 m
.75124 .55715 L
s
.75124 .55715 m
.75124 .55715 L
s
.75124 .55715 m
.75124 .55715 L
s
.75125 .55714 m
.75124 .55715 L
s
.75124 .55714 m
.75124 .55715 L
s
.75124 .55715 m
.75124 .55714 L
s
.75124 .55715 m
.75124 .55715 L
s
.75124 .55715 m
.75124 .55715 L
s
1 .022 0 r
.69352 .69667 m
.69425 .69639 L
s
1 .075 0 r
.3059 .44551 m
.30481 .44379 L
s
1 0 0 r
.24817 .58505 m
.24817 .58505 L
s
1 .525 0 r
.3984 .41903 m
.39593 .41756 L
s
.39593 .41756 m
.39634 .4144 L
s
1 .111 0 r
.62618 .50128 m
.62682 .50141 L
s
.62679 .50039 m
.62618 .50128 L
s
.62618 .50128 m
.62636 .50065 L
s
.62725 .50115 m
.62618 .50128 L
s
.62931 .49938 m
.62618 .50128 L
s
.808 1 0 r
.62731 .39499 m
.63392 .38956 L
s
1 .111 0 r
.62679 .50039 m
.62636 .50065 L
s
.62725 .50115 m
.62679 .50039 L
s
.62682 .50141 m
.62725 .50115 L
s
1 .022 0 r
.69418 .6965 m
.69411 .69655 L
s
.6941 .69633 m
.69418 .6965 L
s
.69425 .69639 m
.69418 .6965 L
s
.69403 .69639 m
.6941 .69633 L
s
.6941 .69633 m
.69425 .69639 L
s
.69411 .69655 m
.69403 .69639 L
s
.69425 .69639 m
.69411 .69655 L
s
.69403 .69639 m
.69425 .69639 L
s
.285 1 0 r
.56687 .47307 m
.57108 .47304 L
s
.57085 .4574 m
.56687 .47307 L
s
.56687 .47307 m
.56161 .46352 L
s
.5803 .46688 m
.56687 .47307 L
s
.58771 .433 m
.56687 .47307 L
s
1 .045 0 r
.35308 .75218 m
.3532 .75229 L
s
.35323 .75185 m
.35308 .75218 L
s
.35352 .75217 m
.35308 .75218 L
s
.35352 .75217 m
.3532 .75229 L
s
.35323 .75185 m
.35352 .75217 L
s
.35335 .75196 m
.35352 .75217 L
s
.35199 .75165 m
.35352 .75217 L
s
.35335 .75196 m
.35323 .75185 L
s
1 .1 0 r
.36538 .47228 m
.36584 .47257 L
s
.36487 .4729 m
.36538 .47228 L
s
.36538 .47228 m
.36494 .47232 L
s
.36534 .47319 m
.36487 .4729 L
s
.36487 .4729 m
.36494 .47232 L
s
1 .045 0 r
.3532 .75229 m
.35335 .75196 L
s
1 .344 0 r
.51755 .50038 m
.51761 .50312 L
s
1 .111 0 r
.62636 .50065 m
.62682 .50141 L
s
1 .01 0 r
.69006 .52847 m
.69011 .52848 L
s
.69011 .52838 m
.69006 .52847 L
s
.69006 .52847 m
.69006 .52841 L
s
.69015 .52845 m
.69006 .52847 L
s
.69031 .52827 m
.69006 .52847 L
s
.69011 .52838 m
.69006 .52841 L
s
.69015 .52845 m
.69011 .52838 L
s
.69011 .52848 m
.69015 .52845 L
s
1 .1 0 r
.36584 .47257 m
.36534 .47319 L
s
.36494 .47232 m
.36584 .47257 L
s
1 .01 0 r
.69006 .52841 m
.69011 .52848 L
s
0 1 .331 r
.43595 .40022 m
.43907 .40268 L
s
.43595 .40022 m
.41761 .40733 L
s
1 .1 0 r
.36494 .47232 m
.36534 .47319 L
s
1 .001 0 r
.40978 .61206 m
.40979 .61206 L
s
.40979 .61205 m
.40978 .61206 L
s
.4098 .61206 m
.40978 .61206 L
s
.4098 .61206 m
.40979 .61206 L
s
.40979 .61205 m
.4098 .61206 L
s
.40979 .61205 m
.4098 .61206 L
s
.40975 .61204 m
.4098 .61206 L
s
.40979 .61205 m
.40979 .61205 L
s
.40979 .61206 m
.40979 .61205 L
s
1 0 0 r
.91311 .58412 m
.91311 .58412 L
s
1 .021 0 r
.63255 .66789 m
.6333 .66767 L
s
1 .59 0 r
.46751 .47243 m
.4479 .46432 L
s
1 .055 0 r
.24471 .41659 m
.24412 .41524 L
s
1 .021 0 r
.63321 .66777 m
.63316 .66782 L
s
.63315 .66761 m
.63321 .66777 L
s
.6333 .66767 m
.63321 .66777 L
s
.6331 .66766 m
.63315 .66761 L
s
.63315 .66761 m
.6333 .66767 L
s
1 .075 0 r
.30506 .44379 m
.30543 .44406 L
s
.30464 .44421 m
.30506 .44379 L
s
.30506 .44379 m
.30481 .44379 L
s
1 .021 0 r
.6333 .66767 m
.63316 .66782 L
s
.6331 .66766 m
.6333 .66767 L
s
.63316 .66782 m
.6331 .66766 L
s
0 1 .511 r
.41129 .38839 m
.4303 .40313 L
s
.41129 .38839 m
.43428 .38336 L
s
1 .075 0 r
.30501 .44447 m
.30464 .44421 L
s
.30464 .44421 m
.30481 .44379 L
s
.30543 .44406 m
.30501 .44447 L
s
.30481 .44379 m
.30543 .44406 L
s
1 .104 0 r
.51701 .77912 m
.51703 .77935 L
s
.51703 .77831 m
.51701 .77912 L
s
.51786 .77885 m
.51701 .77912 L
s
1 .018 0 r
.90984 .41602 m
.90989 .41601 L
s
.90987 .41584 m
.90984 .41602 L
s
.90984 .41602 m
.90977 .41592 L
s
.90998 .41593 m
.90984 .41602 L
s
.91003 .41556 m
.90984 .41602 L
s
1 .075 0 r
.30481 .44379 m
.30501 .44447 L
s
1 .018 0 r
.90987 .41584 m
.90977 .41592 L
s
.90998 .41593 m
.90987 .41584 L
s
.90989 .41601 m
.90998 .41593 L
s
1 .021 0 r
.29142 .72319 m
.29129 .72323 L
s
.2913 .72303 m
.29142 .72319 L
s
.29142 .72319 m
.29122 .72317 L
s
.29138 .72309 m
.29142 .72319 L
s
.29079 .72288 m
.29142 .72319 L
s
1 .104 0 r
.51706 .77854 m
.51703 .77831 L
s
.51703 .77831 m
.51786 .77885 L
s
1 .018 0 r
.90977 .41592 m
.90989 .41601 L
s
1 .021 0 r
.2913 .72303 m
.29122 .72317 L
s
.29138 .72309 m
.2913 .72303 L
s
.29122 .72317 m
.29129 .72323 L
s
.29129 .72323 m
.29138 .72309 L
s
1 .051 0 r
.8487 .38787 m
.8488 .38784 L
s
.84876 .38739 m
.8487 .38787 L
s
.8487 .38787 m
.84849 .3876 L
s
.84907 .38763 m
.8487 .38787 L
s
.84911 .38659 m
.8487 .38787 L
s
1 .525 0 r
.40106 .4158 m
.3984 .41903 L
s
.39634 .4144 m
.40106 .4158 L
s
0 .813 1 r
.61328 .44909 m
.59745 .46879 L
s
.63001 .45833 m
.61328 .44909 L
s
1 .051 0 r
.84876 .38739 m
.84849 .3876 L
s
.84907 .38763 m
.84876 .38739 L
s
1 .104 0 r
.51786 .77885 m
.51703 .77935 L
s
.51706 .77854 m
.51786 .77885 L
s
.51372 .77876 m
.51786 .77885 L
s
1 .055 0 r
.24426 .41526 m
.24455 .41548 L
s
.24394 .41554 m
.24426 .41526 L
s
.24426 .41526 m
.24412 .41524 L
s
1 .417 0 r
.68558 .38766 m
.68616 .38743 L
s
.68597 .38372 m
.68558 .38766 L
s
.68558 .38766 m
.68371 .38544 L
s
.68842 .38571 m
.68558 .38766 L
s
.68802 .3772 m
.68558 .38766 L
s
1 .141 0 r
.66631 .47145 m
.66691 .47149 L
s
.66686 .47021 m
.66631 .47145 L
s
.66631 .47145 m
.66619 .47063 L
s
.66758 .47108 m
.66631 .47145 L
s
.66918 .46847 m
.66631 .47145 L
s
1 .051 0 r
.8488 .38784 m
.84907 .38763 L
s
1 0 0 r
.85223 .55526 m
.85223 .55526 L
s
.85223 .55526 m
.85223 .55526 L
s
.85223 .55526 m
.85223 .55526 L
s
.85223 .55526 m
.85223 .55526 L
s
.85223 .55525 m
.85223 .55526 L
s
.85223 .55526 m
.85223 .55526 L
s
.85223 .55526 m
.85223 .55526 L
s
.85223 .55526 m
.85223 .55526 L
s
.85223 .55526 m
.85223 .55526 L
s
1 .01 0 r
.79444 .69495 m
.7947 .69479 L
s
1 .014 0 r
.57151 .63907 m
.57206 .63899 L
s
1 0 0 r
.34859 .58319 m
.34859 .58319 L
s
1 .39 0 r
.40638 .4435 m
.3984 .43515 L
s
1 .043 0 r
.18346 .38763 m
.18311 .38656 L
s
1 .055 0 r
.24422 .41576 m
.24394 .41554 L
s
.24394 .41554 m
.24412 .41524 L
s
1 .014 0 r
.57197 .63905 m
.57195 .63908 L
s
.57195 .63894 m
.57197 .63905 L
s
.57206 .63899 m
.57197 .63905 L
s
1 .051 0 r
.84849 .3876 m
.8488 .38784 L
s
1 .014 0 r
.57193 .63897 m
.57195 .63894 L
s
.57195 .63894 m
.57206 .63899 L
s
.57206 .63899 m
.57195 .63908 L
s
.57193 .63897 m
.57206 .63899 L
s
1 .055 0 r
.24455 .41548 m
.24422 .41576 L
s
.24412 .41524 m
.24455 .41548 L
s
1 .014 0 r
.57195 .63908 m
.57193 .63897 L
s
1 .01 0 r
.79464 .69477 m
.79469 .69484 L
s
.79461 .6948 m
.79464 .69477 L
s
.79464 .69477 m
.7947 .69479 L
s
.79469 .69484 m
.79465 .69487 L
s
.7947 .69479 m
.79469 .69484 L
s
.79465 .69487 m
.79461 .6948 L
s
.79461 .6948 m
.7947 .69479 L
s
.7947 .69479 m
.79465 .69487 L
s
1 .104 0 r
.51703 .77935 m
.51706 .77854 L
s
1 .055 0 r
.24412 .41524 m
.24422 .41576 L
s
1 .825 0 r
.44862 .44304 m
.44593 .44911 L
s
.44054 .44309 m
.44593 .44911 L
s
1 .525 0 r
.39634 .4144 m
.3984 .41903 L
s
1 .141 0 r
.66686 .47021 m
.66619 .47063 L
s
.66758 .47108 m
.66686 .47021 L
s
1 .081 0 r
.45495 .75058 m
.45506 .75076 L
s
.45508 .74996 m
.45495 .75058 L
s
.45569 .75045 m
.45495 .75058 L
s
.45519 .75014 m
.45508 .74996 L
s
.45508 .74996 m
.45569 .75045 L
s
1 .141 0 r
.66691 .47149 m
.66758 .47108 L
s
1 .825 0 r
.44054 .44309 m
.44862 .44304 L
s
1 .081 0 r
.45569 .75045 m
.45506 .75076 L
s
.45519 .75014 m
.45569 .75045 L
s
.45258 .74999 m
.45569 .75045 L
s
1 .043 0 r
.1832 .38659 m
.18342 .38676 L
s
.18294 .38679 m
.1832 .38659 L
s
.1832 .38659 m
.18311 .38656 L
s
1 .081 0 r
.45506 .75076 m
.45519 .75014 L
s
1 .043 0 r
.18316 .38697 m
.18294 .38679 L
s
.18294 .38679 m
.18311 .38656 L
s
1 .141 0 r
.66619 .47063 m
.66691 .47149 L
s
1 .043 0 r
.18342 .38676 m
.18316 .38697 L
s
.18311 .38656 m
.18342 .38676 L
s
1 .417 0 r
.68597 .38372 m
.68371 .38544 L
s
.68842 .38571 m
.68597 .38372 L
s
1 .043 0 r
.18311 .38656 m
.18316 .38697 L
s
1 .003 0 r
.79124 .52641 m
.79125 .52641 L
s
.79124 .52639 m
.79124 .52641 L
s
.79124 .52641 m
.79123 .5264 L
s
.79126 .5264 m
.79124 .52641 L
s
.79128 .52636 m
.79124 .52641 L
s
.79124 .52639 m
.79123 .5264 L
s
.79126 .5264 m
.79124 .52639 L
s
.79125 .52641 m
.79126 .5264 L
s
.79123 .5264 m
.79125 .52641 L
s
.51051 .61023 m
.51051 .61024 L
s
.51051 .61021 m
.51051 .61023 L
s
.51053 .61023 m
.51051 .61023 L
s
.51051 .61021 m
.51051 .61021 L
s
.51051 .61021 m
.51053 .61023 L
s
.51053 .61023 m
.51051 .61024 L
s
.51051 .61021 m
.51053 .61023 L
s
.51041 .61022 m
.51053 .61023 L
s
1 .009 0 r
.73346 .66613 m
.73371 .66599 L
s
1 .22 0 r
.34518 .41454 m
.34247 .40927 L
s
1 0 0 r
.28736 .55431 m
.28735 .5543 L
s
1 .003 0 r
.51051 .61024 m
.51051 .61021 L
s
1 0 0 r
.28735 .5543 m
.28735 .5543 L
s
.28735 .55431 m
.28735 .5543 L
s
.28735 .5543 m
.28735 .5543 L
s
.28735 .55431 m
.28735 .55431 L
s
.28735 .55431 m
.28735 .5543 L
s
.28735 .5543 m
.28735 .55431 L
s
.28735 .5543 m
.28735 .5543 L
s
.28735 .5543 m
.28735 .55431 L
s
1 .009 0 r
.73366 .66598 m
.73369 .66604 L
s
.73363 .666 m
.73366 .66598 L
s
.73366 .66598 m
.73371 .66599 L
s
.73369 .66604 m
.73366 .66606 L
s
.73371 .66599 m
.73369 .66604 L
s
.73366 .66606 m
.73363 .666 L
s
.73363 .666 m
.73371 .66599 L
s
.73371 .66599 m
.73366 .66606 L
s
1 .047 0 r
.39256 .72169 m
.39268 .7218 L
s
.3927 .72135 m
.39256 .72169 L
s
.39302 .72167 m
.39256 .72169 L
s
.39281 .72146 m
.3927 .72135 L
s
.3927 .72135 m
.39302 .72167 L
s
.39302 .72167 m
.39268 .7218 L
s
.39281 .72146 m
.39302 .72167 L
s
.39137 .72118 m
.39302 .72167 L
s
1 .021 0 r
.72986 .49788 m
.72995 .49789 L
s
.72994 .49769 m
.72986 .49788 L
s
.72986 .49788 m
.72984 .49776 L
s
.73005 .49782 m
.72986 .49788 L
s
.73027 .49743 m
.72986 .49788 L
s
.72994 .49769 m
.72984 .49776 L
s
.73005 .49782 m
.72994 .49769 L
s
.72995 .49789 m
.73005 .49782 L
s
1 .047 0 r
.39268 .7218 m
.39281 .72146 L
s
1 .021 0 r
.72984 .49776 m
.72995 .49789 L
s
1 .417 0 r
.68616 .38743 m
.68842 .38571 L
s
.285 1 0 r
.57085 .4574 m
.56161 .46352 L
s
.5803 .46688 m
.57085 .4574 L
s
1 0 0 r
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
.95344 .55337 m
.95344 .55337 L
s
1 .091 0 r
.61455 .77712 m
.61801 .77654 L
s
1 .006 0 r
.67241 .63728 m
.67261 .63719 L
s
1 0 0 r
.44923 .58134 m
.44923 .58134 L
s
0 1 .077 r
.50709 .44149 m
.4269 .42698 L
s
1 .002 0 r
.22606 .5254 m
.22602 .52536 L
s
1 .134 0 r
.28392 .38555 m
.28286 .38221 L
s
1 .002 0 r
.22603 .52536 m
.22604 .52537 L
s
.22602 .52537 m
.22603 .52536 L
s
.22603 .52536 m
.22602 .52536 L
s
.22603 .52538 m
.22602 .52537 L
s
.22602 .52537 m
.22602 .52536 L
s
.22604 .52537 m
.22603 .52538 L
s
.22602 .52536 m
.22604 .52537 L
s
.22602 .52536 m
.22603 .52538 L
s
1 .006 0 r
.67259 .63722 m
.67257 .63724 L
s
.67256 .63718 m
.67259 .63722 L
s
.67261 .63719 m
.67259 .63722 L
s
.67254 .63719 m
.67256 .63718 L
s
.67256 .63718 m
.67261 .63719 L
s
.67257 .63724 m
.67254 .63719 L
s
.67261 .63719 m
.67257 .63724 L
s
.67254 .63719 m
.67261 .63719 L
s
1 .417 0 r
.68371 .38544 m
.68616 .38743 L
s
0 1 .511 r
.43428 .38336 m
.4303 .40313 L
s
1 .091 0 r
.61747 .7769 m
.61733 .77711 L
s
.6173 .7762 m
.61747 .7769 L
s
.61801 .77654 m
.61747 .7769 L
s
1 .59 0 r
.59445 .46913 m
.5973 .4695 L
s
.59718 .46412 m
.59445 .46913 L
s
.59445 .46913 m
.59453 .46565 L
s
.59995 .46797 m
.59445 .46913 L
s
.6085 .45747 m
.59445 .46913 L
s
1 .091 0 r
.61716 .77641 m
.6173 .7762 L
s
.6173 .7762 m
.61801 .77654 L
s
0 .813 1 r
.59745 .46879 m
.61409 .47819 L
s
1 .019 0 r
.33069 .69262 m
.33057 .69266 L
s
.33058 .69247 m
.33069 .69262 L
s
.33069 .69262 m
.3305 .69261 L
s
.33064 .69253 m
.33069 .69262 L
s
.33009 .69235 m
.33069 .69262 L
s
.33058 .69247 m
.3305 .69261 L
s
.33064 .69253 m
.33058 .69247 L
s
.3305 .69261 m
.33057 .69266 L
s
1 .091 0 r
.61801 .77654 m
.61733 .77711 L
s
.61716 .77641 m
.61801 .77654 L
s
1 .019 0 r
.33057 .69266 m
.33064 .69253 L
s
1 .091 0 r
.61733 .77711 m
.61716 .77641 L
s
1 .137 0 r
.7073 .44066 m
.70771 .44064 L
s
.70764 .4394 m
.7073 .44066 L
s
.7073 .44066 m
.70694 .43988 L
s
.70841 .44015 m
.7073 .44066 L
s
.70919 .43745 m
.7073 .44066 L
s
1 .095 0 r
.55648 .74841 m
.55643 .74861 L
s
.55642 .74767 m
.55648 .74841 L
s
.55718 .7481 m
.55648 .74841 L
s
.55637 .74787 m
.55642 .74767 L
s
.55642 .74767 m
.55718 .7481 L
s
1 .001 0 r
.89247 .52445 m
.89247 .52446 L
s
.89247 .52445 m
.89247 .52445 L
s
.89247 .52445 m
.89247 .52445 L
s
.89248 .52445 m
.89247 .52445 L
s
.89248 .52444 m
.89247 .52445 L
s
.89247 .52445 m
.89247 .52445 L
s
.89248 .52445 m
.89247 .52445 L
s
.89247 .52446 m
.89248 .52445 L
s
.89247 .52445 m
.89247 .52446 L
s
1 .003 0 r
.83459 .66436 m
.83467 .6643 L
s
1 .095 0 r
.5534 .74832 m
.55718 .7481 L
s
1 .002 0 r
.61129 .60839 m
.61136 .60837 L
s
.38799 .55242 m
.38793 .55239 L
s
.717 1 0 r
.44588 .41249 m
.41988 .38417 L
s
1 .002 0 r
.61135 .60838 m
.61135 .60838 L
s
.61135 .60836 m
.61135 .60838 L
s
.61136 .60837 m
.61135 .60838 L
s
.61134 .60837 m
.61135 .60836 L
s
.61135 .60836 m
.61136 .60837 L
s
.38794 .55239 m
.38795 .55239 L
s
.38794 .5524 m
.38794 .55239 L
s
.38794 .55239 m
.38793 .55239 L
s
.38794 .55241 m
.38794 .5524 L
s
.38794 .5524 m
.38793 .55239 L
s
.61136 .60837 m
.61135 .60838 L
s
.61134 .60837 m
.61136 .60837 L
s
.61135 .60838 m
.61134 .60837 L
s
.38795 .55239 m
.38794 .55241 L
s
.38793 .55239 m
.38795 .55239 L
s
.38793 .55239 m
.38794 .55241 L
s
1 .003 0 r
.83465 .6643 m
.83467 .66432 L
s
.83464 .66431 m
.83465 .6643 L
s
.83465 .6643 m
.83467 .6643 L
s
.83467 .66432 m
.83466 .66433 L
s
.83467 .6643 m
.83467 .66432 L
s
.83466 .66433 m
.83464 .66431 L
s
.83464 .66431 m
.83467 .6643 L
s
.83467 .6643 m
.83466 .66433 L
s
1 .137 0 r
.70764 .4394 m
.70694 .43988 L
s
.70841 .44015 m
.70764 .4394 L
s
1 .59 0 r
.59718 .46412 m
.59453 .46565 L
s
.59995 .46797 m
.59718 .46412 L
s
1 .095 0 r
.55718 .7481 m
.55643 .74861 L
s
.55637 .74787 m
.55718 .7481 L
s
1 .137 0 r
.70771 .44064 m
.70841 .44015 L
s
1 .095 0 r
.55643 .74861 m
.55637 .74787 L
s
1 .59 0 r
.5973 .4695 m
.59995 .46797 L
s
1 .08 0 r
.49464 .71991 m
.49469 .72007 L
s
.4947 .71928 m
.49464 .71991 L
s
.49533 .71972 m
.49464 .71991 L
s
.49476 .71944 m
.4947 .71928 L
s
.4947 .71928 m
.49533 .71972 L
s
1 .137 0 r
.70694 .43988 m
.70771 .44064 L
s
0 1 .566 r
.47432 .50006 m
.4817 .49583 L
s
.4817 .49583 m
.4747 .4764 L
s
.4817 .49583 m
.45665 .49399 L
s
1 .08 0 r
.49533 .71972 m
.49469 .72007 L
s
.49476 .71944 m
.49533 .71972 L
s
.49218 .71948 m
.49533 .71972 L
s
0 .813 1 r
.44855 .46612 m
.45728 .49026 L
s
1 .59 0 r
.45178 .46864 m
.44998 .4676 L
s
.44998 .4676 m
.4519 .46326 L
s
.44998 .4676 m
.4479 .46432 L
s
1 .006 0 r
.83137 .4956 m
.83139 .4956 L
s
.83138 .49555 m
.83137 .4956 L
s
.83137 .4956 m
.83136 .49557 L
s
.83141 .49558 m
.83137 .4956 L
s
.83145 .49547 m
.83137 .4956 L
s
.83138 .49555 m
.83136 .49557 L
s
.83141 .49558 m
.83138 .49555 L
s
.83139 .4956 m
.83141 .49558 L
s
.2689 .66358 m
.26887 .66358 L
s
.26887 .66353 m
.2689 .66358 L
s
.2689 .66358 m
.26884 .66357 L
s
.26889 .66355 m
.2689 .66358 L
s
.26875 .66348 m
.2689 .66358 L
s
.26887 .66353 m
.26884 .66357 L
s
.26889 .66355 m
.26887 .66353 L
s
.26884 .66357 m
.26887 .66358 L
s
.83136 .49557 m
.83139 .4956 L
s
.26887 .66358 m
.26889 .66355 L
s
1 .08 0 r
.49469 .72007 m
.49476 .71944 L
s
1 .055 0 r
.7156 .77548 m
.71745 .77484 L
s
1 .002 0 r
.77353 .63548 m
.77358 .63544 L
s
1 0 0 r
.5501 .57948 m
.5501 .57948 L
s
1 .007 0 r
.32667 .52347 m
.32653 .52334 L
s
1 .575 0 r
.3846 .38347 m
.37948 .36911 L
s
1 .002 0 r
.77357 .63544 m
.77358 .63545 L
s
.77356 .63544 m
.77357 .63544 L
s
.77357 .63544 m
.77358 .63544 L
s
.77358 .63545 m
.77357 .63546 L
s
.77358 .63544 m
.77358 .63545 L
s
.77357 .63546 m
.77356 .63544 L
s
.77356 .63544 m
.77358 .63544 L
s
.77358 .63544 m
.77357 .63546 L
s
1 .59 0 r
.4519 .46326 m
.45371 .46428 L
s
.4519 .46326 m
.4479 .46432 L
s
1 .007 0 r
.32656 .52333 m
.32659 .52335 L
s
.32653 .52337 m
.32656 .52333 L
s
.32656 .52333 m
.32653 .52334 L
s
.32656 .5234 m
.32653 .52337 L
s
.32653 .52337 m
.32653 .52334 L
s
.32659 .52335 m
.32656 .5234 L
s
.32653 .52334 m
.32659 .52335 L
s
.32653 .52334 m
.32656 .5234 L
s
1 .134 0 r
.28312 .38228 m
.28382 .38282 L
s
.28232 .38293 m
.28312 .38228 L
s
.28312 .38228 m
.28286 .38221 L
s
1 .029 0 r
.76993 .46715 m
.77003 .46715 L
s
.77001 .46688 m
.76993 .46715 L
s
.76993 .46715 m
.76986 .46699 L
s
.77017 .46704 m
.76993 .46715 L
s
.77036 .46648 m
.76993 .46715 L
s
.77001 .46688 m
.76986 .46699 L
s
.77017 .46704 m
.77001 .46688 L
s
.77003 .46715 m
.77017 .46704 L
s
1 .055 0 r
.71725 .77509 m
.7171 .77524 L
s
.71707 .77469 m
.71725 .77509 L
s
.71745 .77484 m
.71725 .77509 L
s
1 .029 0 r
.76986 .46699 m
.77003 .46715 L
s
1 .046 0 r
.43213 .69106 m
.43223 .69115 L
s
.43224 .69071 m
.43213 .69106 L
s
.43257 .69101 m
.43213 .69106 L
s
1 .055 0 r
.71691 .77484 m
.71707 .77469 L
s
.71707 .77469 m
.71745 .77484 L
s
1 .134 0 r
.28302 .38347 m
.28232 .38293 L
s
.28232 .38293 m
.28286 .38221 L
s
1 .046 0 r
.43233 .69081 m
.43224 .69071 L
s
.43224 .69071 m
.43257 .69101 L
s
.43257 .69101 m
.43223 .69115 L
s
.43233 .69081 m
.43257 .69101 L
s
.43089 .69061 m
.43257 .69101 L
s
1 .22 0 r
.34307 .40934 m
.34421 .41013 L
s
.34182 .41052 m
.34307 .40934 L
s
.34307 .40934 m
.34247 .40927 L
s
.285 1 0 r
.57108 .47304 m
.5803 .46688 L
s
1 .134 0 r
.28382 .38282 m
.28302 .38347 L
s
.28286 .38221 m
.28382 .38282 L
s
1 .046 0 r
.43223 .69115 m
.43233 .69081 L
s
1 .055 0 r
.7171 .77524 m
.71691 .77484 L
s
.71745 .77484 m
.7171 .77524 L
s
.71691 .77484 m
.71745 .77484 L
s
1 .134 0 r
.28286 .38221 m
.28302 .38347 L
s
1 .22 0 r
.34296 .41131 m
.34182 .41052 L
s
.34182 .41052 m
.34247 .40927 L
s
0 1 .566 r
.4747 .4764 m
.46726 .48048 L
s
.4747 .4764 m
.45665 .49399 L
s
1 .066 0 r
.65444 .74665 m
.65683 .74601 L
s
1 .001 0 r
.7124 .60656 m
.71242 .60655 L
s
1 .008 0 r
.48884 .55053 m
.48853 .55047 L
s
1 .01 0 r
.26529 .49449 m
.26513 .49427 L
s
1 .001 0 r
.71241 .60655 m
.71242 .60655 L
s
.71241 .60655 m
.71241 .60655 L
s
.71241 .60655 m
.71242 .60655 L
s
.71242 .60655 m
.71241 .60656 L
s
.71242 .60655 m
.71242 .60655 L
s
.71241 .60656 m
.71241 .60655 L
s
.71241 .60655 m
.71242 .60655 L
s
.71242 .60655 m
.71241 .60656 L
s
1 .008 0 r
.48859 .55052 m
.48858 .55051 L
s
.48858 .55051 m
.48859 .55045 L
s
.48858 .55051 m
.48853 .55047 L
s
.48859 .55045 m
.4886 .55046 L
s
.48859 .55045 m
.48853 .55047 L
s
.48853 .55047 m
.48859 .55052 L
s
.48853 .55047 m
.4886 .55046 L
s
.4886 .55046 m
.48859 .55052 L
s
1 .481 0 r
.55486 .49516 m
.55612 .49438 L
s
.55612 .49438 m
.55482 .49073 L
s
.55612 .49438 m
.55144 .49403 L
s
1 .01 0 r
.26516 .49427 m
.26521 .4943 L
s
.26511 .49432 m
.26516 .49427 L
s
.26516 .49427 m
.26513 .49427 L
s
.26516 .49436 m
.26511 .49432 L
s
.26511 .49432 m
.26513 .49427 L
s
.26521 .4943 m
.26516 .49436 L
s
.26513 .49427 m
.26521 .4943 L
s
.26513 .49427 m
.26516 .49436 L
s
1 .22 0 r
.34421 .41013 m
.34296 .41131 L
s
.34247 .40927 m
.34421 .41013 L
s
1 .481 0 r
.55482 .49073 m
.55355 .49151 L
s
.55482 .49073 m
.55144 .49403 L
s
1 .066 0 r
.65652 .7463 m
.65636 .74646 L
s
.65634 .74581 m
.65652 .7463 L
s
.65683 .74601 m
.65652 .7463 L
s
.65619 .74597 m
.65634 .74581 L
s
.65634 .74581 m
.65683 .74601 L
s
1 .481 0 r
.55144 .49403 m
.55486 .49516 L
s
.55144 .49403 m
.55355 .49151 L
s
.56848 .48859 m
.55144 .49403 L
s
0 1 .566 r
.45665 .49399 m
.47432 .50006 L
s
.45665 .49399 m
.46726 .48048 L
s
.54717 .46459 m
.45665 .49399 L
s
1 .39 0 r
.40007 .43507 m
.40192 .43618 L
s
.39809 .43748 m
.40007 .43507 L
s
.40007 .43507 m
.3984 .43515 L
s
1 .22 0 r
.34247 .40927 m
.34296 .41131 L
s
1 .016 0 r
.37004 .66193 m
.36993 .66196 L
s
.36994 .66181 m
.37004 .66193 L
s
.37004 .66193 m
.36988 .66192 L
s
.36999 .66185 m
.37004 .66193 L
s
.36953 .66171 m
.37004 .66193 L
s
.36988 .66192 m
.36993 .66196 L
s
.36994 .66181 m
.36988 .66192 L
s
.36999 .66185 m
.36994 .66181 L
s
1 .066 0 r
.65683 .74601 m
.65636 .74646 L
s
.65619 .74597 m
.65683 .74601 L
s
.65636 .74646 m
.65619 .74597 L
s
1 .59 0 r
.59453 .46565 m
.5973 .4695 L
s
1 .016 0 r
.36993 .66196 m
.36999 .66185 L
s
1 .002 0 r
.93284 .49356 m
.93285 .49356 L
s
.93285 .49354 m
.93284 .49356 L
s
.93284 .49356 m
.93284 .49355 L
s
.93286 .49355 m
.93284 .49356 L
s
.93287 .49351 m
.93284 .49356 L
s
.93285 .49354 m
.93284 .49355 L
s
.93286 .49355 m
.93285 .49354 L
s
.93285 .49356 m
.93286 .49355 L
s
.93284 .49355 m
.93285 .49356 L
s
1 .39 0 r
.39993 .43859 m
.39809 .43748 L
s
.39809 .43748 m
.3984 .43515 L
s
1 .001 0 r
.87488 .63368 m
.8749 .63366 L
s
1 .075 0 r
.59321 .71778 m
.59608 .71732 L
s
1 0 0 r
.6512 .57761 m
.6512 .57761 L
s
1 .039 0 r
.42752 .52155 m
.42636 .52093 L
s
0 .04 1 r
.48551 .38138 m
.40439 .2893 L
s
1 .011 0 r
.20384 .46548 m
.20369 .46521 L
s
1 .001 0 r
.87489 .63366 m
.8749 .63367 L
s
.87489 .63366 m
.87489 .63366 L
s
.87489 .63366 m
.8749 .63366 L
s
.8749 .63367 m
.87489 .63367 L
s
.8749 .63366 m
.8749 .63367 L
s
.87489 .63367 m
.87489 .63366 L
s
.87489 .63366 m
.8749 .63366 L
s
.8749 .63366 m
.87489 .63367 L
s
1 .121 0 r
.74826 .40931 m
.74851 .40926 L
s
.74843 .40817 m
.74826 .40931 L
s
.74826 .40931 m
.7478 .40865 L
s
.74915 .40877 m
.74826 .40931 L
s
.74934 .40632 m
.74826 .40931 L
s
1 .075 0 r
.59562 .71762 m
.59551 .71778 L
s
.5955 .71705 m
.59562 .71762 L
s
.59608 .71732 m
.59562 .71762 L
s
1 .011 0 r
.20373 .46521 m
.20378 .46526 L
s
.20366 .46528 m
.20373 .46521 L
s
.20373 .46521 m
.20369 .46521 L
s
.20372 .46532 m
.20366 .46528 L
s
.20366 .46528 m
.20369 .46521 L
s
.20378 .46526 m
.20372 .46532 L
s
.20369 .46521 m
.20378 .46526 L
s
1 .075 0 r
.59539 .7172 m
.5955 .71705 L
s
.5955 .71705 m
.59608 .71732 L
s
.973 1 0 r
.62771 .40917 m
.62787 .40867 L
s
.62757 .39946 m
.62771 .40917 L
s
.62771 .40917 m
.62184 .40418 L
s
.63361 .40394 m
.62771 .40917 L
s
.62779 .38334 m
.62771 .40917 L
s
1 .011 0 r
.20369 .46521 m
.20372 .46532 L
s
1 .121 0 r
.74843 .40817 m
.7478 .40865 L
s
.74915 .40877 m
.74843 .40817 L
s
1 .039 0 r
.4266 .52087 m
.42674 .52096 L
s
.42644 .52115 m
.4266 .52087 L
s
.4266 .52087 m
.42636 .52093 L
s
.42658 .52123 m
.42644 .52115 L
s
.42644 .52115 m
.42636 .52093 L
s
1 .457 0 r
.6427 .43702 m
.64396 .43695 L
s
.64381 .43281 m
.6427 .43702 L
s
.6427 .43702 m
.64141 .43442 L
s
.64636 .43533 m
.6427 .43702 L
s
.64865 .42624 m
.6427 .43702 L
s
1 .075 0 r
.59608 .71732 m
.59551 .71778 L
s
.59539 .7172 m
.59608 .71732 L
s
0 1 .077 r
.4428 .43934 m
.43998 .43688 L
s
.43998 .43688 m
.44329 .42052 L
s
.43998 .43688 m
.4269 .42698 L
s
1 .039 0 r
.42674 .52096 m
.42658 .52123 L
s
.42636 .52093 m
.42674 .52096 L
s
.42636 .52093 m
.42658 .52123 L
s
1 .075 0 r
.59551 .71778 m
.59539 .7172 L
s
1 .121 0 r
.74851 .40926 m
.74915 .40877 L
s
.7478 .40865 m
.74851 .40926 L
s
1 .009 0 r
.87165 .46469 m
.87168 .46469 L
s
.87167 .46461 m
.87165 .46469 L
s
.87165 .46469 m
.87163 .46464 L
s
.87172 .46465 m
.87165 .46469 L
s
.87176 .46448 m
.87165 .46469 L
s
1 .068 0 r
.53409 .68904 m
.53408 .68917 L
s
.53407 .6885 m
.53409 .68904 L
s
.53462 .68883 m
.53409 .68904 L
s
1 .009 0 r
.87167 .46461 m
.87163 .46464 L
s
.87172 .46465 m
.87167 .46461 L
s
.87168 .46469 m
.87172 .46465 L
s
.87163 .46464 m
.87168 .46469 L
s
1 .068 0 r
.53406 .68863 m
.53407 .6885 L
s
.53407 .6885 m
.53462 .68883 L
s
1 .007 0 r
.58974 .54872 m
.58976 .54871 L
s
.58976 .54871 m
.58974 .54866 L
s
.58976 .54871 m
.5897 .5487 L
s
.58974 .54866 m
.58973 .54867 L
s
.58974 .54866 m
.5897 .5487 L
s
.5897 .5487 m
.58974 .54872 L
s
.5897 .5487 m
.58973 .54867 L
s
.58993 .54863 m
.5897 .5487 L
s
1 .003 0 r
.30818 .63283 m
.30817 .63283 L
s
.30817 .6328 m
.30818 .63283 L
s
.30818 .63283 m
.30815 .63282 L
s
.30818 .63281 m
.30818 .63283 L
s
.3081 .63277 m
.30818 .63283 L
s
.30817 .6328 m
.30815 .63282 L
s
.30818 .63281 m
.30817 .6328 L
s
.30815 .63282 m
.30817 .63283 L
s
1 .007 0 r
.58973 .54867 m
.58974 .54872 L
s
1 .003 0 r
.30817 .63283 m
.30818 .63281 L
s
1 .034 0 r
.75571 .74497 m
.75676 .74449 L
s
1 0 0 r
.81374 .60473 m
.81374 .60472 L
s
1 .068 0 r
.53191 .68887 m
.53462 .68883 L
s
1 .048 0 r
.36612 .49253 m
.36511 .49153 L
s
1 0 0 r
.81374 .60472 m
.81374 .60472 L
s
.81374 .60472 m
.81374 .60472 L
s
.81374 .60472 m
.81374 .60472 L
s
.81374 .60472 m
.81374 .60472 L
s
.81374 .60472 m
.81374 .60472 L
s
.81374 .60472 m
.81374 .60472 L
s
.81374 .60472 m
.81374 .60472 L
s
.81374 .60472 m
.81374 .60472 L
s
1 .59 0 r
.45371 .46428 m
.45178 .46864 L
s
.4479 .46432 m
.45178 .46864 L
s
1 .068 0 r
.53462 .68883 m
.53408 .68917 L
s
.53406 .68863 m
.53462 .68883 L
s
1 .59 0 r
.4479 .46432 m
.45371 .46428 L
s
1 .033 0 r
.81022 .43623 m
.8103 .43622 L
s
.81028 .43591 m
.81022 .43623 L
s
.81022 .43623 m
.81011 .43604 L
s
.81048 .43609 m
.81022 .43623 L
s
.81058 .43542 m
.81022 .43623 L
s
1 .068 0 r
.53408 .68917 m
.53406 .68863 L
s
1 .39 0 r
.40192 .43618 m
.39993 .43859 L
s
.3984 .43515 m
.40192 .43618 L
s
1 .033 0 r
.81028 .43591 m
.81011 .43604 L
s
.81048 .43609 m
.81028 .43591 L
s
.8103 .43622 m
.81048 .43609 L
s
1 .034 0 r
.75654 .74442 m
.75667 .74466 L
s
.75642 .74452 m
.75654 .74442 L
s
.75654 .74442 m
.75676 .74449 L
s
.75667 .74466 m
.75656 .74475 L
s
.75676 .74449 m
.75667 .74466 L
s
1 .457 0 r
.64381 .43281 m
.64141 .43442 L
s
.64636 .43533 m
.64381 .43281 L
s
1 .033 0 r
.81011 .43604 m
.8103 .43622 L
s
1 .136 0 r
.52426 .52033 m
.52428 .52015 L
s
.52428 .52015 m
.52426 .51907 L
s
.52428 .52015 m
.52317 .51972 L
s
1 .034 0 r
.75656 .74475 m
.75642 .74452 L
s
.75642 .74452 m
.75676 .74449 L
s
.75676 .74449 m
.75656 .74475 L
s
1 .136 0 r
.52426 .51907 m
.52423 .51924 L
s
.52426 .51907 m
.52317 .51972 L
s
1 .39 0 r
.3984 .43515 m
.39993 .43859 L
s
1 .039 0 r
.47168 .66024 m
.47173 .66031 L
s
.47174 .65994 m
.47168 .66024 L
s
.47204 .66017 m
.47168 .66024 L
s
.4718 .66001 m
.47174 .65994 L
s
.47174 .65994 m
.47204 .66017 L
s
1 .048 0 r
.36533 .49151 m
.36555 .49165 L
s
.36508 .49181 m
.36533 .49151 L
s
.36533 .49151 m
.36511 .49153 L
s
1 .039 0 r
.47204 .66017 m
.47173 .66031 L
s
.4718 .66001 m
.47204 .66017 L
s
.47054 .65994 m
.47204 .66017 L
s
1 .048 0 r
.36531 .49195 m
.36508 .49181 L
s
.36508 .49181 m
.36511 .49153 L
s
1 .481 0 r
.55355 .49151 m
.55486 .49516 L
s
1 .039 0 r
.47173 .66031 m
.4718 .66001 L
s
1 .136 0 r
.52317 .51972 m
.52426 .52033 L
s
.52317 .51972 m
.52423 .51924 L
s
.52859 .51961 m
.52317 .51972 L
s
1 .048 0 r
.36555 .49165 m
.36531 .49195 L
s
.36511 .49153 m
.36555 .49165 L
s
.36511 .49153 m
.36531 .49195 L
s
.285 1 0 r
.56161 .46352 m
.57108 .47304 L
s
1 0 0 r
.24661 .60381 m
.24661 .60381 L
s
.24661 .60381 m
.24661 .60381 L
s
.24661 .60381 m
.24661 .60381 L
s
.24661 .60381 m
.24661 .60381 L
s
.2466 .60381 m
.24661 .60381 L
s
.24661 .60381 m
.24661 .60381 L
s
.24661 .60381 m
.24661 .60381 L
s
.24661 .60381 m
.24661 .60381 L
s
.24661 .60381 m
.24661 .60381 L
s
.75253 .57574 m
.75253 .57574 L
s
1 .04 0 r
.69447 .71606 m
.6958 .71555 L
s
1 .043 0 r
.30466 .46348 m
.30404 .4625 L
s
0 1 .331 r
.41761 .40733 m
.43536 .42111 L
s
.41761 .40733 m
.43907 .40268 L
s
1 .066 0 r
.35261 .77212 m
.35279 .7723 L
s
.35282 .77164 m
.35261 .77212 L
s
.35325 .77212 m
.35261 .77212 L
s
1 .457 0 r
.64396 .43695 m
.64636 .43533 L
s
1 .066 0 r
.35325 .77212 m
.35279 .7723 L
s
.35282 .77164 m
.35325 .77212 L
s
.353 .77182 m
.35325 .77212 L
s
.35101 .77137 m
.35325 .77212 L
s
.353 .77182 m
.35282 .77164 L
s
0 1 .077 r
.44329 .42052 m
.44613 .42287 L
s
.44329 .42052 m
.4269 .42698 L
s
1 .136 0 r
.52423 .51924 m
.52426 .52033 L
s
1 .04 0 r
.69566 .71575 m
.69554 .71585 L
s
.69552 .71546 m
.69566 .71575 L
s
.6958 .71555 m
.69566 .71575 L
s
.6954 .71556 m
.69552 .71546 L
s
.69552 .71546 m
.6958 .71555 L
s
1 .066 0 r
.35279 .7723 m
.353 .77182 L
s
1 .04 0 r
.69554 .71585 m
.6954 .71556 L
s
.6958 .71555 m
.69554 .71585 L
s
.6954 .71556 m
.6958 .71555 L
s
.973 1 0 r
.62757 .39946 m
.62184 .40418 L
s
.63361 .40394 m
.62757 .39946 L
s
1 .043 0 r
.30417 .46251 m
.30439 .46266 L
s
.30393 .46274 m
.30417 .46251 L
s
.30417 .46251 m
.30404 .4625 L
s
.30415 .46289 m
.30393 .46274 L
s
.30393 .46274 m
.30404 .4625 L
s
.30439 .46266 m
.30415 .46289 L
s
.30404 .4625 m
.30439 .46266 L
s
1 .01 0 r
.40934 .6311 m
.40937 .63112 L
s
.40938 .63102 m
.40934 .6311 L
s
.40945 .6311 m
.40934 .6311 L
s
.40945 .6311 m
.40937 .63112 L
s
.40938 .63102 m
.40945 .6311 L
s
.40941 .63104 m
.40945 .6311 L
s
.4091 .63097 m
.40945 .6311 L
s
.40941 .63104 m
.40938 .63102 L
s
1 .043 0 r
.30404 .4625 m
.30415 .46289 L
s
1 .01 0 r
.40937 .63112 m
.40941 .63104 L
s
1 .001 0 r
.69121 .54675 m
.69122 .54675 L
s
.69122 .54674 m
.69121 .54675 L
s
.69121 .54675 m
.69121 .54674 L
s
.69123 .54675 m
.69121 .54675 L
s
.69125 .54673 m
.69121 .54675 L
s
.69122 .54674 m
.69121 .54674 L
s
.69123 .54675 m
.69122 .54674 L
s
.69122 .54675 m
.69123 .54675 L
s
.69121 .54674 m
.69122 .54675 L
s
1 .457 0 r
.64141 .43442 m
.64396 .43695 L
s
1 0 0 r
.91531 .60289 m
.91531 .60289 L
s
1 .046 0 r
.63316 .68713 m
.6348 .68667 L
s
1 .344 0 r
.46719 .49057 m
.4557 .48586 L
s
1 .035 0 r
.24313 .4344 m
.24275 .43356 L
s
1 0 0 r
.91531 .60289 m
.91531 .60289 L
s
.91531 .60289 m
.91531 .60289 L
s
.91531 .60289 m
.91531 .60289 L
s
.91531 .60289 m
.91531 .60289 L
s
.91531 .60289 m
.91531 .60289 L
s
.91531 .60289 m
.91531 .60289 L
s
.91531 .60289 m
.91531 .60289 L
s
.91531 .60289 m
.91531 .60289 L
s
1 .046 0 r
.63458 .68688 m
.63447 .68698 L
s
.63446 .68654 m
.63458 .68688 L
s
.6348 .68667 m
.63458 .68688 L
s
.63435 .68664 m
.63446 .68654 L
s
.63446 .68654 m
.6348 .68667 L
s
1 .039 0 r
.6288 .51834 m
.62902 .51838 L
s
.62901 .51802 m
.6288 .51834 L
s
.6288 .51834 m
.62886 .51812 L
s
.62917 .51829 m
.6288 .51834 L
s
.6299 .51768 m
.6288 .51834 L
s
.62901 .51802 m
.62886 .51812 L
s
.62917 .51829 m
.62901 .51802 L
s
.62902 .51838 m
.62917 .51829 L
s
1 .034 0 r
.29049 .74294 m
.29027 .74301 L
s
.2903 .74267 m
.29049 .74294 L
s
.29049 .74294 m
.29016 .74291 L
s
.29041 .74277 m
.29049 .74294 L
s
.28946 .74245 m
.29049 .74294 L
s
.2903 .74267 m
.29016 .74291 L
s
.29041 .74277 m
.2903 .74267 L
s
.29016 .74291 m
.29027 .74301 L
s
1 .104 0 r
.78906 .37773 m
.78921 .37767 L
s
.78913 .37674 m
.78906 .37773 L
s
.78906 .37773 m
.78858 .37719 L
s
.78976 .37722 m
.78906 .37773 L
s
.78962 .3751 m
.78906 .37773 L
s
1 .046 0 r
.6348 .68667 m
.63447 .68698 L
s
.63435 .68664 m
.6348 .68667 L
s
.63447 .68698 m
.63435 .68664 L
s
1 .039 0 r
.62886 .51812 m
.62902 .51838 L
s
1 .035 0 r
.24284 .43357 m
.24302 .43371 L
s
.24263 .43375 m
.24284 .43357 L
s
.24284 .43357 m
.24275 .43356 L
s
1 .034 0 r
.29027 .74301 m
.29041 .74277 L
s
1 .035 0 r
.24281 .43389 m
.24263 .43375 L
s
.24263 .43375 m
.24275 .43356 L
s
.24302 .43371 m
.24281 .43389 L
s
.24275 .43356 m
.24302 .43371 L
s
1 .104 0 r
.78913 .37674 m
.78858 .37719 L
s
.78976 .37722 m
.78913 .37674 L
s
1 .011 0 r
.91209 .43366 m
.91212 .43366 L
s
.91211 .43356 m
.91209 .43366 L
s
.91209 .43366 m
.91205 .4336 L
s
.91218 .43361 m
.91209 .43366 L
s
.91221 .43339 m
.91209 .43366 L
s
1 .035 0 r
.24275 .43356 m
.24281 .43389 L
s
1 .011 0 r
.91211 .43356 m
.91205 .4336 L
s
.91218 .43361 m
.91211 .43356 L
s
.91212 .43366 m
.91218 .43361 L
s
.91205 .4336 m
.91212 .43366 L
s
1 .104 0 r
.78921 .37767 m
.78976 .37722 L
s
1 .001 0 r
.34761 .60198 m
.3476 .60198 L
s
.34761 .60197 m
.34761 .60198 L
s
.34761 .60198 m
.3476 .60198 L
s
.34761 .60198 m
.34761 .60198 L
s
.34759 .60197 m
.34761 .60198 L
s
.34761 .60197 m
.3476 .60198 L
s
.34761 .60198 m
.34761 .60197 L
s
.3476 .60198 m
.3476 .60198 L
s
.3476 .60198 m
.34761 .60198 L
s
1 .115 0 r
.45554 .77055 m
.45571 .77081 L
s
.45573 .76966 m
.45554 .77055 L
s
.4566 .77037 m
.45554 .77055 L
s
1 .018 0 r
.79596 .71435 m
.79645 .71406 L
s
1 0 0 r
.85408 .57387 m
.85408 .57387 L
s
1 .043 0 r
.57177 .65816 m
.57346 .65793 L
s
1 .253 0 r
.40571 .46148 m
.40049 .45609 L
s
1 .029 0 r
.18152 .40529 m
.18128 .40458 L
s
1 .104 0 r
.78858 .37719 m
.78921 .37767 L
s
1 .043 0 r
.57318 .6581 m
.57312 .65818 L
s
.57312 .65776 m
.57318 .6581 L
s
.57346 .65793 m
.57318 .6581 L
s
1 .115 0 r
.45589 .76992 m
.45573 .76966 L
s
.45573 .76966 m
.4566 .77037 L
s
1 .043 0 r
.57306 .65785 m
.57312 .65776 L
s
.57312 .65776 m
.57346 .65793 L
s
1 .035 0 r
.85066 .40513 m
.85074 .40511 L
s
.8507 .4048 m
.85066 .40513 L
s
.85066 .40513 m
.85052 .40494 L
s
.85092 .40497 m
.85066 .40513 L
s
.85095 .40426 m
.85066 .40513 L
s
1 .115 0 r
.4566 .77037 m
.45571 .77081 L
s
.45589 .76992 m
.4566 .77037 L
s
.45217 .76972 m
.4566 .77037 L
s
1 .018 0 r
.79635 .71403 m
.79643 .71415 L
s
.79628 .71409 m
.79635 .71403 L
s
.79635 .71403 m
.79645 .71406 L
s
.79643 .71415 m
.79636 .71421 L
s
.79645 .71406 m
.79643 .71415 L
s
1 .035 0 r
.8507 .4048 m
.85052 .40494 L
s
.85092 .40497 m
.8507 .4048 L
s
1 .043 0 r
.57346 .65793 m
.57312 .65818 L
s
.57306 .65785 m
.57346 .65793 L
s
1 .018 0 r
.79636 .71421 m
.79628 .71409 L
s
.79628 .71409 m
.79645 .71406 L
s
.79645 .71406 m
.79636 .71421 L
s
1 .035 0 r
.85074 .40511 m
.85092 .40497 L
s
1 .043 0 r
.57312 .65818 m
.57306 .65785 L
s
1 .035 0 r
.85052 .40494 m
.85074 .40511 L
s
1 .029 0 r
.18135 .40459 m
.18149 .40471 L
s
.18117 .40473 m
.18135 .40459 L
s
.18135 .40459 m
.18128 .40458 L
s
.18132 .40485 m
.18117 .40473 L
s
.18117 .40473 m
.18128 .40458 L
s
.18149 .40471 m
.18132 .40485 L
s
.18128 .40458 m
.18149 .40471 L
s
.18128 .40458 m
.18132 .40485 L
s
1 .115 0 r
.45571 .77081 m
.45589 .76992 L
s
0 1 .331 r
.43907 .40268 m
.43536 .42111 L
s
1 .024 0 r
.51106 .62927 m
.51107 .62931 L
s
.51108 .62908 m
.51106 .62927 L
s
.51126 .6292 m
.51106 .62927 L
s
.51109 .62912 m
.51108 .62908 L
s
.51108 .62908 m
.51126 .6292 L
s
.51126 .6292 m
.51107 .62931 L
s
.51109 .62912 m
.51126 .6292 L
s
.51032 .62916 m
.51126 .6292 L
s
1 0 0 r
.79278 .54483 m
.79279 .54483 L
s
.79279 .54482 m
.79278 .54483 L
s
.79278 .54483 m
.79278 .54482 L
s
.79279 .54483 m
.79278 .54483 L
s
.79279 .54482 m
.79278 .54483 L
s
.79279 .54482 m
.79278 .54482 L
s
.79279 .54483 m
.79279 .54482 L
s
.79279 .54483 m
.79279 .54483 L
s
.79278 .54482 m
.79279 .54483 L
s
1 .019 0 r
.73464 .68538 m
.7352 .68508 L
s
1 0 0 r
.28601 .57293 m
.28601 .57293 L
s
1 .151 0 r
.34416 .43237 m
.3423 .42878 L
s
1 .024 0 r
.51107 .62931 m
.51109 .62912 L
s
1 .073 0 r
.39249 .74155 m
.39267 .74173 L
s
.3927 .741 m
.39249 .74155 L
s
.3932 .74152 m
.39249 .74155 L
s
.973 1 0 r
.62184 .40418 m
.62787 .40867 L
s
1 .073 0 r
.39288 .74118 m
.3927 .741 L
s
.3927 .741 m
.3932 .74152 L
s
.3932 .74152 m
.39267 .74173 L
s
.39288 .74118 m
.3932 .74152 L
s
.39061 .74076 m
.3932 .74152 L
s
1 .019 0 r
.73508 .68505 m
.73517 .68518 L
s
.73502 .6851 m
.73508 .68505 L
s
.73508 .68505 m
.7352 .68508 L
s
.73517 .68518 m
.7351 .68524 L
s
.7352 .68508 m
.73517 .68518 L
s
.973 1 0 r
.62787 .40867 m
.63361 .40394 L
s
1 .019 0 r
.7351 .68524 m
.73502 .6851 L
s
.73502 .6851 m
.7352 .68508 L
s
.7352 .68508 m
.7351 .68524 L
s
1 .073 0 r
.39267 .74173 m
.39288 .74118 L
s
1 .07 0 r
.66856 .48809 m
.66886 .48812 L
s
.66884 .48748 m
.66856 .48809 L
s
.66856 .48809 m
.6685 .48769 L
s
.66919 .48791 m
.66856 .48809 L
s
.67 .48662 m
.66856 .48809 L
s
.66884 .48748 m
.6685 .48769 L
s
.66919 .48791 m
.66884 .48748 L
s
.66886 .48812 m
.66919 .48791 L
s
1 .344 0 r
.45797 .48839 m
.45691 .48777 L
s
.45691 .48777 m
.45804 .48522 L
s
.45691 .48777 m
.4557 .48586 L
s
1 .007 0 r
.7313 .51588 m
.73133 .51588 L
s
.73132 .51582 m
.7313 .51588 L
s
.7313 .51588 m
.73129 .51584 L
s
.73136 .51586 m
.7313 .51588 L
s
.73143 .51574 m
.7313 .51588 L
s
.73132 .51582 m
.73129 .51584 L
s
.73136 .51586 m
.73132 .51582 L
s
.73133 .51588 m
.73136 .51586 L
s
.73129 .51584 m
.73133 .51588 L
s
1 .07 0 r
.6685 .48769 m
.66886 .48812 L
s
1 .344 0 r
.45804 .48522 m
.4591 .48584 L
s
.45804 .48522 m
.4557 .48586 L
s
1 .003 0 r
.44888 .60016 m
.44889 .60016 L
s
.44889 .60013 m
.44888 .60016 L
s
.44891 .60015 m
.44888 .60016 L
s
.4489 .60014 m
.44889 .60013 L
s
.44889 .60013 m
.44891 .60015 L
s
.44891 .60015 m
.44889 .60016 L
s
.4489 .60014 m
.44891 .60015 L
s
.4488 .60012 m
.44891 .60015 L
s
.44889 .60016 m
.4489 .60014 L
s
1 0 0 r
.95587 .57199 m
.95587 .57199 L
s
1 .02 0 r
.67324 .65638 m
.67387 .65611 L
s
.285 1 0 r
.50699 .45948 m
.44051 .44757 L
s
1 .095 0 r
.28255 .40322 m
.28179 .40085 L
s
1 0 0 r
.22436 .54386 m
.22436 .54386 L
s
.22436 .54386 m
.22436 .54386 L
s
.22435 .54386 m
.22436 .54386 L
s
.22436 .54386 m
.22436 .54386 L
s
.22436 .54386 m
.22435 .54386 L
s
.22435 .54386 m
.22436 .54386 L
s
.22436 .54386 m
.22436 .54386 L
s
.22436 .54386 m
.22436 .54386 L
s
.22436 .54386 m
.22436 .54386 L
s
1 .02 0 r
.67381 .65621 m
.67375 .65626 L
s
.67374 .65606 m
.67381 .65621 L
s
.67387 .65611 m
.67381 .65621 L
s
.67368 .65611 m
.67374 .65606 L
s
.67374 .65606 m
.67387 .65611 L
s
1 .323 0 r
.68704 .40298 m
.68749 .40282 L
s
.68734 .39992 m
.68704 .40298 L
s
.68704 .40298 m
.68558 .40127 L
s
.68926 .40148 m
.68704 .40298 L
s
.68895 .3949 m
.68704 .40298 L
s
1 .02 0 r
.67375 .65626 m
.67368 .65611 L
s
.67387 .65611 m
.67375 .65626 L
s
.67368 .65611 m
.67387 .65611 L
s
1 .035 0 r
.33008 .71227 m
.32985 .71234 L
s
.32987 .712 m
.33008 .71227 L
s
.33008 .71227 m
.32973 .71225 L
s
.32999 .71209 m
.33008 .71227 L
s
.32899 .71177 m
.33008 .71227 L
s
.32987 .712 m
.32973 .71225 L
s
.32999 .71209 m
.32987 .712 L
s
.32973 .71225 m
.32985 .71234 L
s
.32985 .71234 m
.32999 .71209 L
s
1 .134 0 r
.55791 .76819 m
.55784 .76848 L
s
.55782 .76714 m
.55791 .76819 L
s
.5589 .76775 m
.55791 .76819 L
s
.55775 .76743 m
.55782 .76714 L
s
.55782 .76714 m
.5589 .76775 L
s
1 .323 0 r
.68734 .39992 m
.68558 .40127 L
s
.68926 .40148 m
.68734 .39992 L
s
1 0 0 r
.89456 .54291 m
.89456 .54291 L
s
.89456 .54291 m
.89456 .54291 L
s
.89456 .54291 m
.89456 .54291 L
s
.89456 .54291 m
.89456 .54291 L
s
.89457 .54291 m
.89456 .54291 L
s
.89456 .54291 m
.89456 .54291 L
s
.89456 .54291 m
.89456 .54291 L
s
.89456 .54291 m
.89456 .54291 L
s
.89456 .54291 m
.89456 .54291 L
s
1 .008 0 r
.83634 .68363 m
.83654 .68349 L
s
1 .134 0 r
.55355 .76806 m
.5589 .76775 L
s
1 .016 0 r
.61178 .62734 m
.61235 .62717 L
s
1 0 0 r
.38721 .57105 m
.38721 .57105 L
s
.939 1 0 r
.44543 .43033 m
.42387 .40707 L
s
1 .066 0 r
.22086 .37404 m
.2205 .37237 L
s
1 .016 0 r
.61227 .62725 m
.61223 .62728 L
s
.61223 .62713 m
.61227 .62725 L
s
.61235 .62717 m
.61227 .62725 L
s
.61219 .62716 m
.61223 .62713 L
s
.61223 .62713 m
.61235 .62717 L
s
1 .008 0 r
.83649 .68348 m
.83653 .68353 L
s
.83646 .6835 m
.83649 .68348 L
s
.83649 .68348 m
.83654 .68349 L
s
.83653 .68353 m
.8365 .68355 L
s
.83654 .68349 m
.83653 .68353 L
s
.8365 .68355 m
.83646 .6835 L
s
.83646 .6835 m
.83654 .68349 L
s
0 .813 1 r
.61409 .47819 m
.63001 .45833 L
s
1 .008 0 r
.83654 .68349 m
.8365 .68355 L
s
1 .035 0 r
.89124 .37388 m
.8913 .37385 L
s
.89126 .37354 m
.89124 .37388 L
s
.89124 .37388 m
.89108 .3737 L
s
.89148 .3737 m
.89124 .37388 L
s
.89145 .37299 m
.89124 .37388 L
s
1 .016 0 r
.61235 .62717 m
.61223 .62728 L
s
.61219 .62716 m
.61235 .62717 L
s
.61223 .62728 m
.61219 .62716 L
s
1 .035 0 r
.89126 .37354 m
.89108 .3737 L
s
.89148 .3737 m
.89126 .37354 L
s
1 .121 0 r
.49575 .73971 m
.49584 .73996 L
s
.49585 .73876 m
.49575 .73971 L
s
.49681 .73943 m
.49575 .73971 L
s
1 .035 0 r
.8913 .37385 m
.89148 .3737 L
s
.89108 .3737 m
.8913 .37385 L
s
1 .121 0 r
.49594 .73901 m
.49585 .73876 L
s
.49585 .73876 m
.49681 .73943 L
s
1 .134 0 r
.5589 .76775 m
.55784 .76848 L
s
.55775 .76743 m
.5589 .76775 L
s
1 .151 0 r
.34271 .42882 m
.34349 .42937 L
s
.34185 .42963 m
.34271 .42882 L
s
.34271 .42882 m
.3423 .42878 L
s
1 .575 0 r
.38063 .36944 m
.38374 .37164 L
s
.37729 .37237 m
.38063 .36944 L
s
.38063 .36944 m
.37948 .36911 L
s
1 .121 0 r
.49681 .73943 m
.49584 .73996 L
s
.49594 .73901 m
.49681 .73943 L
s
.49199 .73907 m
.49681 .73943 L
s
1 .095 0 r
.28197 .4009 m
.28248 .40129 L
s
.2814 .40137 m
.28197 .4009 L
s
.28197 .4009 m
.28179 .40085 L
s
1 .134 0 r
.55784 .76848 m
.55775 .76743 L
s
1 .253 0 r
.40158 .45601 m
.40279 .45675 L
s
.40029 .45759 m
.40158 .45601 L
s
.40158 .45601 m
.40049 .45609 L
s
1 .344 0 r
.4591 .48584 m
.45797 .48839 L
s
.4557 .48586 m
.45797 .48839 L
s
1 .323 0 r
.68749 .40282 m
.68926 .40148 L
s
1 .151 0 r
.34263 .43018 m
.34185 .42963 L
s
.34185 .42963 m
.3423 .42878 L
s
1 .013 0 r
.26763 .68297 m
.26756 .68299 L
s
.26757 .68286 m
.26763 .68297 L
s
.26763 .68297 m
.26751 .68295 L
s
.26762 .6829 m
.26763 .68297 L
s
.26729 .68275 m
.26763 .68297 L
s
1 .344 0 r
.4557 .48586 m
.4591 .48584 L
s
1 .013 0 r
.26757 .68286 m
.26751 .68295 L
s
.26762 .6829 m
.26757 .68286 L
s
.26751 .68295 m
.26756 .68299 L
s
1 .095 0 r
.28191 .40176 m
.2814 .40137 L
s
.2814 .40137 m
.28179 .40085 L
s
1 .013 0 r
.26756 .68299 m
.26762 .6829 L
s
1 .095 0 r
.28248 .40129 m
.28191 .40176 L
s
.28179 .40085 m
.28248 .40129 L
s
1 .253 0 r
.40149 .45833 m
.40029 .45759 L
s
.40029 .45759 m
.40049 .45609 L
s
1 .323 0 r
.68558 .40127 m
.68749 .40282 L
s
1 .151 0 r
.34349 .42937 m
.34263 .43018 L
s
.3423 .42878 m
.34349 .42937 L
s
1 .002 0 r
.83317 .51383 m
.83317 .51383 L
s
.83317 .51381 m
.83317 .51383 L
s
.83317 .51383 m
.83316 .51382 L
s
.83318 .51382 m
.83317 .51383 L
s
.83319 .51379 m
.83317 .51383 L
s
1 .121 0 r
.49584 .73996 m
.49594 .73901 L
s
1 .002 0 r
.83317 .51381 m
.83316 .51382 L
s
.83318 .51382 m
.83317 .51381 L
s
.83317 .51383 m
.83318 .51382 L
s
.83316 .51382 m
.83317 .51383 L
s
1 .005 0 r
.55042 .59827 m
.55041 .59828 L
s
.55041 .59823 m
.55042 .59827 L
s
.55045 .59825 m
.55042 .59827 L
s
1 .007 0 r
.77494 .65459 m
.77512 .65447 L
s
1 .005 0 r
.55024 .59827 m
.55045 .59825 L
s
1 .001 0 r
.32555 .54195 m
.32553 .54193 L
s
1 .459 0 r
.3838 .40115 m
.3797 .38976 L
s
1 .005 0 r
.55041 .59824 m
.55041 .59823 L
s
.55041 .59823 m
.55045 .59825 L
s
1 .001 0 r
.32553 .54193 m
.32554 .54193 L
s
.32553 .54194 m
.32553 .54193 L
s
.32553 .54193 m
.32553 .54193 L
s
.32553 .54194 m
.32553 .54194 L
s
.32553 .54194 m
.32553 .54193 L
s
.32554 .54193 m
.32553 .54194 L
s
.32553 .54193 m
.32554 .54193 L
s
.32553 .54193 m
.32553 .54194 L
s
1 .005 0 r
.55045 .59825 m
.55041 .59828 L
s
.55041 .59824 m
.55045 .59825 L
s
.55041 .59828 m
.55041 .59824 L
s
.542 1 0 r
.42308 .36256 m
.4301 .36651 L
s
.41564 .37157 m
.42308 .36256 L
s
.42308 .36256 m
.41689 .36247 L
s
1 .095 0 r
.28179 .40085 m
.28191 .40176 L
s
.542 1 0 r
.63305 .37291 m
.62805 .37288 L
s
.62762 .35989 m
.63305 .37291 L
s
.63305 .37291 m
.62033 .36891 L
s
.63536 .36383 m
.63305 .37291 L
s
.6066 .33974 m
.63305 .37291 L
s
1 .007 0 r
.77508 .65446 m
.77511 .65451 L
s
.77505 .65448 m
.77508 .65446 L
s
.77508 .65446 m
.77512 .65447 L
s
.77511 .65451 m
.77508 .65453 L
s
.77512 .65447 m
.77511 .65451 L
s
1 .066 0 r
.2206 .37242 m
.22095 .3727 L
s
.2202 .37272 m
.2206 .37242 L
s
.2206 .37242 m
.2205 .37237 L
s
1 .08 0 r
.43253 .71082 m
.4327 .711 L
s
.43272 .71021 m
.43253 .71082 L
s
.4333 .71074 m
.43253 .71082 L
s
1 .081 0 r
.70911 .45735 m
.70935 .45735 L
s
.70931 .4566 m
.70911 .45735 L
s
.70911 .45735 m
.70889 .45689 L
s
.70977 .45705 m
.70911 .45735 L
s
.71024 .45546 m
.70911 .45735 L
s
1 .007 0 r
.77508 .65453 m
.77505 .65448 L
s
.77505 .65448 m
.77512 .65447 L
s
.77512 .65447 m
.77508 .65453 L
s
1 .08 0 r
.43289 .71039 m
.43272 .71021 L
s
.43272 .71021 m
.4333 .71074 L
s
1 .151 0 r
.3423 .42878 m
.34263 .43018 L
s
1 .08 0 r
.4333 .71074 m
.4327 .711 L
s
.43289 .71039 m
.4333 .71074 L
s
.43035 .71005 m
.4333 .71074 L
s
1 .066 0 r
.22054 .373 m
.2202 .37272 L
s
.2202 .37272 m
.2205 .37237 L
s
.22095 .3727 m
.22054 .373 L
s
.2205 .37237 m
.22095 .3727 L
s
1 .081 0 r
.70931 .4566 m
.70889 .45689 L
s
.70977 .45705 m
.70931 .4566 L
s
.70935 .45735 m
.70977 .45705 L
s
1 .066 0 r
.2205 .37237 m
.22054 .373 L
s
1 .08 0 r
.4327 .711 m
.43289 .71039 L
s
1 .081 0 r
.70889 .45689 m
.70935 .45735 L
s
1 .575 0 r
.38039 .37457 m
.37729 .37237 L
s
.37729 .37237 m
.37948 .36911 L
s
1 .013 0 r
.77155 .48494 m
.7716 .48494 L
s
.77159 .48482 m
.77155 .48494 L
s
.77155 .48494 m
.77152 .48487 L
s
.77166 .4849 m
.77155 .48494 L
s
.77175 .48464 m
.77155 .48494 L
s
1 .253 0 r
.40279 .45675 m
.40149 .45833 L
s
.40049 .45609 m
.40279 .45675 L
s
1 .013 0 r
.77159 .48482 m
.77152 .48487 L
s
.77166 .4849 m
.77159 .48482 L
s
.7716 .48494 m
.77166 .4849 L
s
.77152 .48487 m
.7716 .48494 L
s
1 .253 0 r
.40049 .45609 m
.40149 .45833 L
s
1 .005 0 r
.71346 .62552 m
.7136 .62544 L
s
1 .095 0 r
.65517 .7664 m
.65861 .76549 L
s
1 0 0 r
.48864 .56917 m
.48864 .56917 L
s
1 .003 0 r
.26382 .51282 m
.26376 .51275 L
s
1 .233 0 r
.3221 .37194 m
.32114 .36599 L
s
1 .003 0 r
.26378 .51275 m
.26379 .51276 L
s
.26376 .51276 m
.26378 .51275 L
s
.26378 .51275 m
.26376 .51275 L
s
.26377 .51277 m
.26376 .51276 L
s
.26376 .51276 m
.26376 .51275 L
s
.26379 .51276 m
.26377 .51277 L
s
.26376 .51275 m
.26379 .51276 L
s
1 .005 0 r
.71357 .62543 m
.71359 .62546 L
s
.71355 .62544 m
.71357 .62543 L
s
.71357 .62543 m
.7136 .62544 L
s
.71359 .62546 m
.71357 .62548 L
s
.7136 .62544 m
.71359 .62546 L
s
1 .003 0 r
.26376 .51275 m
.26377 .51277 L
s
1 .005 0 r
.71357 .62548 m
.71355 .62544 L
s
.71355 .62544 m
.7136 .62544 L
s
.7136 .62544 m
.71357 .62548 L
s
1 .575 0 r
.38374 .37164 m
.38039 .37457 L
s
.37948 .36911 m
.38374 .37164 L
s
.542 1 0 r
.42265 .37555 m
.41564 .37157 L
s
.41564 .37157 m
.41689 .36247 L
s
1 .035 0 r
.36977 .68147 m
.36954 .68154 L
s
.36955 .6812 m
.36977 .68147 L
s
.36977 .68147 m
.36942 .68145 L
s
.36966 .68129 m
.36977 .68147 L
s
.36864 .68099 m
.36977 .68147 L
s
.36942 .68145 m
.36954 .68154 L
s
.36955 .6812 m
.36942 .68145 L
s
.36966 .68129 m
.36955 .6812 L
s
1 .095 0 r
.65816 .76591 m
.65794 .76615 L
s
.65791 .7652 m
.65816 .76591 L
s
.65861 .76549 m
.65816 .76591 L
s
.65769 .76543 m
.65791 .7652 L
s
.65791 .7652 m
.65861 .76549 L
s
1 .035 0 r
.36954 .68154 m
.36966 .68129 L
s
.285 1 0 r
.4537 .45784 m
.4513 .45569 L
s
.4513 .45569 m
.45405 .44213 L
s
.4513 .45569 m
.44051 .44757 L
s
1 .001 0 r
.93518 .51185 m
.93518 .51185 L
s
.93518 .51185 m
.93518 .51185 L
s
.93518 .51185 m
.93518 .51185 L
s
.93518 .51185 m
.93518 .51185 L
s
.93519 .51184 m
.93518 .51185 L
s
.93518 .51185 m
.93518 .51185 L
s
.93518 .51185 m
.93518 .51185 L
s
.93518 .51185 m
.93518 .51185 L
s
.93518 .51185 m
.93518 .51185 L
s
1 .003 0 r
.87687 .6528 m
.87692 .65275 L
s
1 .114 0 r
.59359 .73738 m
.598 .73669 L
s
1 .002 0 r
.65191 .59642 m
.65197 .59639 L
s
1 .005 0 r
.42696 .54003 m
.4268 .53995 L
s
0 .197 1 r
.48528 .39907 m
.40705 .31112 L
s
1 .005 0 r
.20201 .48365 m
.20195 .48353 L
s
1 .002 0 r
.65197 .5964 m
.65196 .5964 L
s
.65196 .59638 m
.65197 .5964 L
s
.65197 .59639 m
.65197 .5964 L
s
.65195 .59639 m
.65196 .59638 L
s
.65196 .59638 m
.65197 .59639 L
s
.65196 .5964 m
.65195 .59639 L
s
.65197 .59639 m
.65196 .5964 L
s
.65195 .59639 m
.65197 .59639 L
s
1 .003 0 r
.87691 .65275 m
.87692 .65276 L
s
.8769 .65276 m
.87691 .65275 L
s
.87691 .65275 m
.87692 .65275 L
s
.87692 .65276 m
.87691 .65277 L
s
.87692 .65275 m
.87692 .65276 L
s
.87691 .65277 m
.8769 .65276 L
s
.8769 .65276 m
.87692 .65275 L
s
.87692 .65275 m
.87691 .65277 L
s
1 .005 0 r
.42683 .53994 m
.42685 .53995 L
s
.42681 .53998 m
.42683 .53994 L
s
.42683 .53994 m
.4268 .53995 L
s
.42683 .53999 m
.42681 .53998 L
s
.42681 .53998 m
.4268 .53995 L
s
.20196 .48353 m
.20199 .48355 L
s
.20193 .48356 m
.20196 .48353 L
s
.20196 .48353 m
.20195 .48353 L
s
.42685 .53995 m
.42683 .53999 L
s
.4268 .53995 m
.42685 .53995 L
s
.4268 .53995 m
.42683 .53999 L
s
.20196 .48358 m
.20193 .48356 L
s
.20193 .48356 m
.20195 .48353 L
s
1 .095 0 r
.65861 .76549 m
.65794 .76615 L
s
.65769 .76543 m
.65861 .76549 L
s
1 .005 0 r
.20199 .48355 m
.20196 .48358 L
s
.20195 .48353 m
.20199 .48355 L
s
.20195 .48353 m
.20196 .48358 L
s
1 .095 0 r
.65794 .76615 m
.65769 .76543 L
s
1 .114 0 r
.5973 .73715 m
.59713 .73739 L
s
.59711 .73626 m
.5973 .73715 L
s
.598 .73669 m
.5973 .73715 L
s
0 1 .077 r
.4269 .42698 m
.4428 .43934 L
s
.4269 .42698 m
.44613 .42287 L
s
1 .114 0 r
.59694 .73651 m
.59711 .73626 L
s
.59711 .73626 m
.598 .73669 L
s
1 .575 0 r
.37948 .36911 m
.38039 .37457 L
s
.542 1 0 r
.62762 .35989 m
.62033 .36891 L
s
.63536 .36383 m
.62762 .35989 L
s
1 .116 0 r
.53569 .7086 m
.53567 .70883 L
s
.53567 .70769 m
.53569 .7086 L
s
.5366 .70824 m
.53569 .7086 L
s
.53565 .70791 m
.53567 .70769 L
s
.53567 .70769 m
.5366 .70824 L
s
1 .01 0 r
.30714 .65208 m
.30708 .65209 L
s
.30709 .65199 m
.30714 .65208 L
s
.30714 .65208 m
.30704 .65206 L
s
.30713 .65202 m
.30714 .65208 L
s
.30687 .6519 m
.30714 .65208 L
s
1 .114 0 r
.598 .73669 m
.59713 .73739 L
s
.59694 .73651 m
.598 .73669 L
s
1 .01 0 r
.30709 .65199 m
.30704 .65206 L
s
.30713 .65202 m
.30709 .65199 L
s
.30704 .65206 m
.30708 .65209 L
s
.30708 .65209 m
.30713 .65202 L
s
1 .004 0 r
.87368 .48275 m
.87369 .48275 L
s
.87369 .48271 m
.87368 .48275 L
s
.87368 .48275 m
.87367 .48273 L
s
.87371 .48273 m
.87368 .48275 L
s
.87373 .48266 m
.87368 .48275 L
s
.87369 .48271 m
.87367 .48273 L
s
.87371 .48273 m
.87369 .48271 L
s
.87369 .48275 m
.87371 .48273 L
s
.87367 .48273 m
.87369 .48275 L
s
1 .114 0 r
.59713 .73739 m
.59694 .73651 L
s
1 .05 0 r
.75702 .76474 m
.75857 .76404 L
s
1 .002 0 r
.81538 .6237 m
.81541 .62366 L
s
1 .116 0 r
.53194 .70832 m
.5366 .70824 L
s
1 0 0 r
.5903 .56728 m
.5903 .56728 L
s
1 .016 0 r
.36522 .51086 m
.36488 .51053 L
s
.808 1 0 r
.42357 .36982 m
.42029 .33892 L
s
1 .002 0 r
.81541 .62366 m
.81541 .62367 L
s
.8154 .62367 m
.81541 .62366 L
s
.81541 .62366 m
.81541 .62366 L
s
.81541 .62367 m
.81541 .62368 L
s
.81541 .62366 m
.81541 .62367 L
s
.81541 .62368 m
.8154 .62367 L
s
.8154 .62367 m
.81541 .62366 L
s
.81541 .62366 m
.81541 .62368 L
s
1 .116 0 r
.5366 .70824 m
.53567 .70883 L
s
.53565 .70791 m
.5366 .70824 L
s
1 .08 0 r
.7499 .42614 m
.75007 .42611 L
s
.75001 .42539 m
.7499 .42614 L
s
.7499 .42614 m
.74959 .42571 L
s
.75049 .42579 m
.7499 .42614 L
s
.75061 .42419 m
.7499 .42614 L
s
.285 1 0 r
.45405 .44213 m
.45647 .4442 L
s
.45405 .44213 m
.44051 .44757 L
s
1 .344 0 r
.6007 .48246 m
.60239 .4827 L
s
.60231 .47952 m
.6007 .48246 L
s
.6007 .48246 m
.60076 .48043 L
s
.60394 .48179 m
.6007 .48246 L
s
.60897 .47568 m
.6007 .48246 L
s
1 .016 0 r
.36496 .51053 m
.36503 .51057 L
s
.36487 .51063 m
.36496 .51053 L
s
.36496 .51053 m
.36488 .51053 L
s
.36495 .51067 m
.36487 .51063 L
s
.36487 .51063 m
.36488 .51053 L
s
1 .08 0 r
.75001 .42539 m
.74959 .42571 L
s
.75049 .42579 m
.75001 .42539 L
s
1 .081 0 r
.47263 .67986 m
.47274 .68002 L
s
.47276 .67923 m
.47263 .67986 L
s
.47338 .67972 m
.47263 .67986 L
s
1 .016 0 r
.36503 .51057 m
.36495 .51067 L
s
.36488 .51053 m
.36503 .51057 L
s
.36488 .51053 m
.36495 .51067 L
s
1 .081 0 r
.47288 .67939 m
.47276 .67923 L
s
.47276 .67923 m
.47338 .67972 L
s
1 .116 0 r
.53567 .70883 m
.53565 .70791 L
s
1 .233 0 r
.72903 .36942 m
.72917 .36927 L
s
.72903 .3672 m
.72903 .36942 L
s
.72903 .36942 m
.72776 .36826 L
s
.73044 .36821 m
.72903 .36942 L
s
.72938 .36346 m
.72903 .36942 L
s
1 .08 0 r
.75007 .42611 m
.75049 .42579 L
s
1 .081 0 r
.47338 .67972 m
.47274 .68002 L
s
.47288 .67939 m
.47338 .67972 L
s
.47023 .67923 m
.47338 .67972 L
s
1 .08 0 r
.74959 .42571 m
.75007 .42611 L
s
1 .05 0 r
.75824 .76393 m
.75844 .76428 L
s
.75807 .76407 m
.75824 .76393 L
s
.75824 .76393 m
.75857 .76404 L
s
.75844 .76428 m
.75827 .76443 L
s
.75857 .76404 m
.75844 .76428 L
s
1 .018 0 r
.812 .45388 m
.81205 .45388 L
s
.81204 .45371 m
.812 .45388 L
s
.812 .45388 m
.81194 .45378 L
s
.81215 .4538 m
.812 .45388 L
s
.81221 .45344 m
.812 .45388 L
s
0 1 .566 r
.61448 .48209 m
.60543 .48313 L
s
.60484 .45937 m
.61448 .48209 L
s
.61448 .48209 m
.59193 .47543 L
s
.61841 .46696 m
.61448 .48209 L
s
.56658 .42627 m
.61448 .48209 L
s
1 .018 0 r
.81204 .45371 m
.81194 .45378 L
s
.81215 .4538 m
.81204 .45371 L
s
.81205 .45388 m
.81215 .4538 L
s
.81194 .45378 m
.81205 .45388 L
s
1 .344 0 r
.60231 .47952 m
.60076 .48043 L
s
.60394 .48179 m
.60231 .47952 L
s
1 .081 0 r
.47274 .68002 m
.47288 .67939 L
s
1 .05 0 r
.75827 .76443 m
.75807 .76407 L
s
.75807 .76407 m
.75857 .76404 L
s
.75857 .76404 m
.75827 .76443 L
s
.542 1 0 r
.62033 .36891 m
.62805 .37288 L
s
1 .344 0 r
.60239 .4827 m
.60394 .48179 L
s
0 1 .566 r
.46726 .48048 m
.47432 .50006 L
s
1 .233 0 r
.72903 .3672 m
.72776 .36826 L
s
.73044 .36821 m
.72903 .3672 L
s
1 .021 0 r
.52795 .53822 m
.52795 .53819 L
s
.52795 .53819 m
.52795 .53803 L
s
.52795 .53819 m
.52778 .53813 L
s
.52795 .53803 m
.52794 .53805 L
s
.52795 .53803 m
.52778 .53813 L
s
1 .002 0 r
.24506 .62282 m
.24505 .62282 L
s
.24505 .6228 m
.24506 .62282 L
s
.24506 .62282 m
.24504 .62281 L
s
.24506 .62281 m
.24506 .62282 L
s
.24502 .62278 m
.24506 .62282 L
s
.24505 .6228 m
.24504 .62281 L
s
.24506 .62281 m
.24505 .6228 L
s
.24504 .62281 m
.24505 .62282 L
s
.24505 .62282 m
.24506 .62281 L
s
1 .021 0 r
.52778 .53813 m
.52795 .53822 L
s
.52778 .53813 m
.52794 .53805 L
s
.52861 .53811 m
.52778 .53813 L
s
1 0 0 r
.75382 .59456 m
.75383 .59455 L
s
1 .063 0 r
.69543 .73568 m
.69754 .73488 L
s
1 .02 0 r
.30341 .48166 m
.30312 .48121 L
s
1 0 0 r
.75383 .59455 m
.75383 .59455 L
s
.75383 .59455 m
.75383 .59455 L
s
.75383 .59455 m
.75383 .59455 L
s
.75383 .59455 m
.75383 .59455 L
s
.75383 .59455 m
.75383 .59455 L
s
.75383 .59455 m
.75383 .59455 L
s
.75383 .59455 m
.75383 .59455 L
s
.75383 .59455 m
.75383 .59455 L
s
1 .021 0 r
.52794 .53805 m
.52795 .53822 L
s
1 .02 0 r
.30318 .48121 m
.30328 .48128 L
s
.30307 .48132 m
.30318 .48121 L
s
.30318 .48121 m
.30312 .48121 L
s
.30317 .48139 m
.30307 .48132 L
s
.30307 .48132 m
.30312 .48121 L
s
.30328 .48128 m
.30317 .48139 L
s
.30312 .48121 m
.30328 .48128 L
s
.30312 .48121 m
.30317 .48139 L
s
1 .233 0 r
.72776 .36826 m
.72917 .36927 L
s
.72917 .36927 m
.73044 .36821 L
s
1 .032 0 r
.4092 .65051 m
.4093 .65058 L
s
.40931 .65027 m
.4092 .65051 L
s
.40952 .65051 m
.4092 .65051 L
s
.40952 .65051 m
.4093 .65058 L
s
.40931 .65027 m
.40952 .65051 L
s
.4094 .65035 m
.40952 .65051 L
s
.40844 .65011 m
.40952 .65051 L
s
.4094 .65035 m
.40931 .65027 L
s
1 .199 0 r
.56305 .50967 m
.56357 .50933 L
s
.56357 .50933 m
.56302 .50781 L
s
.56357 .50933 m
.56161 .50919 L
s
1 .063 0 r
.69732 .73519 m
.69713 .73536 L
s
.6971 .73472 m
.69732 .73519 L
s
.69754 .73488 m
.69732 .73519 L
s
.69691 .73489 m
.6971 .73472 L
s
.6971 .73472 m
.69754 .73488 L
s
1 .199 0 r
.56302 .50781 m
.5625 .50815 L
s
.56302 .50781 m
.56161 .50919 L
s
0 1 .077 r
.44613 .42287 m
.4428 .43934 L
s
1 .199 0 r
.56161 .50919 m
.56305 .50967 L
s
.56161 .50919 m
.5625 .50815 L
s
.56872 .50695 m
.56161 .50919 L
s
1 .032 0 r
.4093 .65058 m
.4094 .65035 L
s
1 .233 0 r
.3214 .36614 m
.32267 .36715 L
s
.32 .36721 m
.3214 .36614 L
s
.3214 .36614 m
.32114 .36599 L
s
1 .063 0 r
.69713 .73536 m
.69691 .73489 L
s
.69754 .73488 m
.69713 .73536 L
s
.69691 .73489 m
.69754 .73488 L
s
1 .001 0 r
.91753 .62187 m
.91754 .62186 L
s
1 .08 0 r
.63377 .70659 m
.63665 .70579 L
s
1 0 0 r
.69219 .56539 m
.69219 .56539 L
s
1 .136 0 r
.46686 .50891 m
.46232 .50707 L
s
1 0 0 r
.01 w
.52528 .36771 Mdot
1 .019 0 r
.5 Mabswid
.24152 .45243 m
.24131 .45196 L
s
1 .001 0 r
.91753 .62186 m
.91754 .62186 L
s
.91753 .62186 m
.91753 .62186 L
s
.91753 .62186 m
.91754 .62186 L
s
.91754 .62186 m
.91754 .62186 L
s
.91754 .62186 m
.91754 .62186 L
s
.91754 .62186 m
.91753 .62186 L
s
.91753 .62186 m
.91754 .62186 L
s
.91754 .62186 m
.91754 .62186 L
s
1 .05 0 r
.28964 .76295 m
.28932 .76306 L
s
.28935 .76256 m
.28964 .76295 L
s
.28964 .76295 m
.28915 .76291 L
s
.28953 .76271 m
.28964 .76295 L
s
.28812 .76223 m
.28964 .76295 L
s
.28935 .76256 m
.28915 .76291 L
s
.28953 .76271 m
.28935 .76256 L
s
.28915 .76291 m
.28932 .76306 L
s
1 .344 0 r
.60076 .48043 m
.60239 .4827 L
s
1 .019 0 r
.24136 .45197 m
.24146 .45204 L
s
.24125 .45207 m
.24136 .45197 L
s
.24136 .45197 m
.24131 .45196 L
s
.24135 .45214 m
.24125 .45207 L
s
.24125 .45207 m
.24131 .45196 L
s
.24146 .45204 m
.24135 .45214 L
s
.24131 .45196 m
.24146 .45204 L
s
.24131 .45196 m
.24135 .45214 L
s
1 .05 0 r
.28932 .76306 m
.28953 .76271 L
s
1 .233 0 r
.32127 .36822 m
.32 .36721 L
s
.32 .36721 m
.32114 .36599 L
s
1 .08 0 r
.63628 .70616 m
.63609 .70635 L
s
.63606 .70556 m
.63628 .70616 L
s
.63665 .70579 m
.63628 .70616 L
s
1 .233 0 r
.32267 .36715 m
.32127 .36822 L
s
.32114 .36599 m
.32267 .36715 L
s
1 .08 0 r
.63587 .70574 m
.63606 .70556 L
s
.63606 .70556 m
.63665 .70579 L
s
1 .199 0 r
.5625 .50815 m
.56305 .50967 L
s
1 .006 0 r
.91435 .45156 m
.91436 .45156 L
s
.91436 .4515 m
.91435 .45156 L
s
.91435 .45156 m
.91433 .45153 L
s
.91439 .45153 m
.91435 .45156 L
s
.91441 .45141 m
.91435 .45156 L
s
.91436 .4515 m
.91433 .45153 L
s
.91439 .45153 m
.91436 .4515 L
s
.91436 .45156 m
.91439 .45153 L
s
.34675 .62106 m
.34671 .62107 L
s
.34671 .62101 m
.34675 .62106 L
s
.34675 .62106 m
.34669 .62105 L
s
.34674 .62102 m
.34675 .62106 L
s
.34658 .62095 m
.34675 .62106 L
s
.91433 .45153 m
.91436 .45156 L
s
.34671 .62101 m
.34669 .62105 L
s
.34674 .62102 m
.34671 .62101 L
s
.34669 .62105 m
.34671 .62107 L
s
1 .005 0 r
.63034 .53627 m
.63037 .53628 L
s
.63037 .53623 m
.63034 .53627 L
s
.63034 .53627 m
.63035 .53624 L
s
.63039 .53627 m
.63034 .53627 L
s
.63049 .53618 m
.63034 .53627 L
s
.63037 .53623 m
.63035 .53624 L
s
.63039 .53627 m
.63037 .53623 L
s
.63037 .53628 m
.63039 .53627 L
s
1 .08 0 r
.63665 .70579 m
.63609 .70635 L
s
.63587 .70574 m
.63665 .70579 L
s
1 .006 0 r
.34671 .62107 m
.34674 .62102 L
s
1 .08 0 r
.63609 .70635 m
.63587 .70574 L
s
1 .005 0 r
.63035 .53624 m
.63037 .53628 L
s
.787 1 0 r
.57314 .47973 m
.57617 .47974 L
s
.576 .46852 m
.57314 .47973 L
s
.57314 .47973 m
.5694 .47292 L
s
.58276 .47531 m
.57314 .47973 L
s
.58807 .45131 m
.57314 .47973 L
s
1 .303 0 r
.64538 .45142 m
.64623 .45139 L
s
.64612 .44862 m
.64538 .45142 L
s
.64538 .45142 m
.64452 .4497 L
s
.64783 .4503 m
.64538 .45142 L
s
.64936 .4443 m
.64538 .45142 L
s
1 .029 0 r
.7975 .73398 m
.79831 .73351 L
s
1 0 0 r
.85596 .5927 m
.85596 .59269 L
s
1 .09 0 r
.57204 .67746 m
.57556 .67699 L
s
1 .133 0 r
.40503 .47967 m
.40228 .47686 L
s
1 .018 0 r
.17957 .42316 m
.17942 .42272 L
s
1 0 0 r
.85596 .59269 m
.85596 .59269 L
s
.85596 .59269 m
.85596 .59269 L
s
.85596 .59269 m
.85596 .59269 L
s
.85596 .59269 m
.85596 .59269 L
s
.85596 .59269 m
.85596 .59269 L
s
.85596 .59269 m
.85596 .59269 L
s
.85596 .59269 m
.85596 .59269 L
s
.85596 .59269 m
.85596 .59269 L
s
1 .233 0 r
.32114 .36599 m
.32127 .36822 L
s
1 .136 0 r
.46321 .50807 m
.46279 .50781 L
s
.46279 .50781 m
.46324 .50681 L
s
.46279 .50781 m
.46232 .50707 L
s
1 .09 0 r
.57497 .67735 m
.57486 .67752 L
s
.57485 .67664 m
.57497 .67735 L
s
.57556 .67699 m
.57497 .67735 L
s
.542 1 0 r
.4301 .36651 m
.42265 .37555 L
s
.41689 .36247 m
.4301 .36651 L
s
1 .136 0 r
.46324 .50681 m
.46366 .50706 L
s
.46324 .50681 m
.46232 .50707 L
s
1 .09 0 r
.57473 .67682 m
.57485 .67664 L
s
.57485 .67664 m
.57556 .67699 L
s
1 .073 0 r
.79073 .39465 m
.79083 .39462 L
s
.79078 .39396 m
.79073 .39465 L
s
.79073 .39465 m
.79039 .39427 L
s
.79123 .3943 m
.79073 .39465 L
s
.79112 .39281 m
.79073 .39465 L
s
1 .018 0 r
.17946 .42273 m
.17955 .4228 L
s
.17935 .42281 m
.17946 .42273 L
s
.17946 .42273 m
.17942 .42272 L
s
1 .575 0 r
.67129 .3663 m
.67083 .36596 L
s
.67059 .36083 m
.67129 .3663 L
s
.67129 .3663 m
.66742 .36376 L
s
.67401 .36302 m
.67129 .3663 L
s
.66837 .35167 m
.67129 .3663 L
s
1 .018 0 r
.17944 .42289 m
.17935 .42281 L
s
.17935 .42281 m
.17942 .42272 L
s
.17955 .4228 m
.17944 .42289 L
s
.17942 .42272 m
.17955 .4228 L
s
1 .029 0 r
.79813 .73346 m
.79827 .73366 L
s
.79803 .73355 m
.79813 .73346 L
s
.79813 .73346 m
.79831 .73351 L
s
.79827 .73366 m
.79816 .73375 L
s
.79831 .73351 m
.79827 .73366 L
s
1 .018 0 r
.17942 .42272 m
.17944 .42289 L
s
1 .073 0 r
.79078 .39396 m
.79039 .39427 L
s
.79123 .3943 m
.79078 .39396 L
s
1 .022 0 r
.85262 .42267 m
.85267 .42266 L
s
.85265 .42246 m
.85262 .42267 L
s
.85262 .42267 m
.85254 .42255 L
s
.85278 .42257 m
.85262 .42267 L
s
.8528 .42213 m
.85262 .42267 L
s
1 .029 0 r
.79816 .73375 m
.79803 .73355 L
s
.79803 .73355 m
.79831 .73351 L
s
.79831 .73351 m
.79816 .73375 L
s
1 .022 0 r
.85265 .42246 m
.85254 .42255 L
s
.85278 .42257 m
.85265 .42246 L
s
1 .09 0 r
.57556 .67699 m
.57486 .67752 L
s
.57473 .67682 m
.57556 .67699 L
s
1 .022 0 r
.85267 .42266 m
.85278 .42257 L
s
1 .073 0 r
.79083 .39462 m
.79123 .3943 L
s
1 .022 0 r
.85254 .42255 m
.85267 .42266 L
s
1 .073 0 r
.79039 .39427 m
.79083 .39462 L
s
1 .303 0 r
.64612 .44862 m
.64452 .4497 L
s
.64783 .4503 m
.64612 .44862 L
s
1 .07 0 r
.51245 .64864 m
.51248 .64876 L
s
.51249 .64808 m
.51245 .64864 L
s
.51305 .64845 m
.51245 .64864 L
s
1 .09 0 r
.57486 .67752 m
.57473 .67682 L
s
1 .104 0 r
.39253 .76167 m
.39279 .76194 L
s
.39283 .76089 m
.39253 .76167 L
s
.39356 .76163 m
.39253 .76167 L
s
1 .07 0 r
.51252 .6482 m
.51249 .64808 L
s
.51249 .64808 m
.51305 .64845 L
s
1 .104 0 r
.3931 .76116 m
.39283 .76089 L
s
.39283 .76089 m
.39356 .76163 L
s
.39356 .76163 m
.39279 .76194 L
s
.3931 .76116 m
.39356 .76163 L
s
.38984 .76056 m
.39356 .76163 L
s
1 .136 0 r
.46366 .50706 m
.46321 .50807 L
s
.46232 .50707 m
.46321 .50807 L
s
1 .07 0 r
.51305 .64845 m
.51248 .64876 L
s
.51252 .6482 m
.51305 .64845 L
s
.51024 .64831 m
.51305 .64845 L
s
1 .136 0 r
.46232 .50707 m
.46366 .50706 L
s
1 0 0 r
.28465 .59177 m
.28465 .59177 L
s
.28465 .59177 m
.28465 .59177 L
s
.28465 .59177 m
.28465 .59177 L
s
.28465 .59177 m
.28465 .59177 L
s
.28464 .59176 m
.28465 .59177 L
s
.28465 .59177 m
.28465 .59177 L
s
.28465 .59177 m
.28465 .59177 L
s
.28465 .59177 m
.28465 .59177 L
s
.28465 .59177 m
.28465 .59177 L
s
1 .035 0 r
.73583 .70485 m
.73687 .70432 L
s
1 0 0 r
.79431 .56349 m
.79431 .56349 L
s
1 .09 0 r
.34313 .4504 m
.34201 .44827 L
s
1 .07 0 r
.51248 .64876 m
.51252 .6482 L
s
1 .303 0 r
.64623 .45139 m
.64783 .4503 L
s
1 .825 0 r
.62831 .42202 m
.62844 .42166 L
s
.6282 .41417 m
.62831 .42202 L
s
.62831 .42202 m
.62356 .41801 L
s
.63309 .41781 m
.62831 .42202 L
s
.62838 .40129 m
.62831 .42202 L
s
1 .104 0 r
.39279 .76194 m
.3931 .76116 L
s
1 .035 0 r
.73665 .70425 m
.7368 .7045 L
s
.73652 .70435 m
.73665 .70425 L
s
.73665 .70425 m
.73687 .70432 L
s
.7368 .7045 m
.73667 .7046 L
s
.73687 .70432 m
.7368 .7045 L
s
.542 1 0 r
.41689 .36247 m
.42265 .37555 L
s
.717 1 0 r
.42533 .38414 m
.43154 .38769 L
s
.41876 .39211 m
.42533 .38414 L
s
.42533 .38414 m
.41988 .38417 L
s
1 .459 0 r
.38062 .38998 m
.38311 .39176 L
s
.37794 .39234 m
.38062 .38998 L
s
.38062 .38998 m
.3797 .38976 L
s
1 .035 0 r
.73667 .7046 m
.73652 .70435 L
s
.73652 .70435 m
.73687 .70432 L
s
.73687 .70432 m
.73667 .7046 L
s
1 .575 0 r
.67059 .36083 m
.66742 .36376 L
s
.67401 .36302 m
.67059 .36083 L
s
1 .303 0 r
.64452 .4497 m
.64623 .45139 L
s
1 .024 0 r
.44899 .61938 m
.44904 .61943 L
s
.44905 .6192 m
.44899 .61938 L
s
.44922 .61936 m
.44899 .61938 L
s
.44911 .61925 m
.44905 .6192 L
s
.44905 .6192 m
.44922 .61936 L
s
.44922 .61936 m
.44904 .61943 L
s
.44911 .61925 m
.44922 .61936 L
s
.44836 .61912 m
.44922 .61936 L
s
.44904 .61943 m
.44911 .61925 L
s
1 .133 0 r
.40286 .47681 m
.40349 .4772 L
s
.40218 .47764 m
.40286 .47681 L
s
.40286 .47681 m
.40228 .47686 L
s
0 1 .566 r
.60484 .45937 m
.59193 .47543 L
s
.61841 .46696 m
.60484 .45937 L
s
1 .001 0 r
.73259 .53427 m
.73259 .53427 L
s
.73259 .53426 m
.73259 .53427 L
s
.73259 .53427 m
.73259 .53427 L
s
.73259 .53427 m
.73259 .53427 L
s
.7326 .53425 m
.73259 .53427 L
s
.73259 .53426 m
.73259 .53427 L
s
.73259 .53427 m
.73259 .53426 L
s
.73259 .53427 m
.73259 .53427 L
s
.73259 .53427 m
.73259 .53427 L
s
1 0 0 r
.95832 .59083 m
.95833 .59083 L
s
1 .043 0 r
.67408 .67569 m
.67546 .67511 L
s
.787 1 0 r
.50688 .47768 m
.45966 .4693 L
s
1 0 0 r
.22264 .56254 m
.22264 .56254 L
s
1 .062 0 r
.28116 .4211 m
.28067 .41957 L
s
1 0 0 r
.95832 .59083 m
.95833 .59083 L
s
.95832 .59083 m
.95832 .59083 L
s
.95832 .59083 m
.95833 .59083 L
s
.95833 .59083 m
.95833 .59083 L
s
.95833 .59083 m
.95833 .59083 L
s
.95833 .59083 m
.95832 .59083 L
s
.95832 .59083 m
.95833 .59083 L
s
.95833 .59083 m
.95833 .59083 L
s
1 .133 0 r
.40281 .47804 m
.40218 .47764 L
s
.40218 .47764 m
.40228 .47686 L
s
1 .055 0 r
.3296 .7322 m
.32924 .73232 L
s
.32927 .73177 m
.3296 .7322 L
s
.3296 .7322 m
.32905 .73216 L
s
.32946 .73192 m
.3296 .7322 L
s
.32787 .73142 m
.3296 .7322 L
s
.32927 .73177 m
.32905 .73216 L
s
.32946 .73192 m
.32927 .73177 L
s
.32905 .73216 m
.32924 .73232 L
s
.32924 .73232 m
.32946 .73192 L
s
1 .043 0 r
.67533 .67533 m
.67519 .67544 L
s
.67517 .67502 m
.67533 .67533 L
s
.67546 .67511 m
.67533 .67533 L
s
.67504 .67513 m
.67517 .67502 L
s
.67517 .67502 m
.67546 .67511 L
s
1 .09 0 r
.34226 .44829 m
.34273 .44862 L
s
.34174 .44878 m
.34226 .44829 L
s
.34226 .44829 m
.34201 .44827 L
s
1 .459 0 r
.38042 .39412 m
.37794 .39234 L
s
.37794 .39234 m
.3797 .38976 L
s
1 .133 0 r
.40349 .4772 m
.40281 .47804 L
s
.40228 .47686 m
.40349 .4772 L
s
.787 1 0 r
.576 .46852 m
.5694 .47292 L
s
.58276 .47531 m
.576 .46852 L
s
1 .024 0 r
.67034 .50548 m
.67044 .50549 L
s
.67043 .50527 m
.67034 .50548 L
s
.67034 .50548 m
.67032 .50534 L
s
.67055 .50541 m
.67034 .50548 L
s
.67082 .50498 m
.67034 .50548 L
s
.67043 .50527 m
.67032 .50534 L
s
.67055 .50541 m
.67043 .50527 L
s
.67044 .50549 m
.67055 .50541 L
s
1 .133 0 r
.40228 .47686 m
.40281 .47804 L
s
1 .09 0 r
.34221 .44911 m
.34174 .44878 L
s
.34174 .44878 m
.34201 .44827 L
s
1 .043 0 r
.67519 .67544 m
.67504 .67513 L
s
.67546 .67511 m
.67519 .67544 L
s
1 .024 0 r
.67032 .50534 m
.67044 .50549 L
s
1 .043 0 r
.67504 .67513 m
.67546 .67511 L
s
.542 1 0 r
.62805 .37288 m
.63536 .36383 L
s
.717 1 0 r
.42496 .39569 m
.41876 .39211 L
s
.41876 .39211 m
.41988 .38417 L
s
1 .575 0 r
.66742 .36376 m
.67083 .36596 L
s
1 .09 0 r
.34273 .44862 m
.34221 .44911 L
s
.34201 .44827 m
.34273 .44862 L
s
.34201 .44827 m
.34221 .44911 L
s
1 .168 0 r
.49704 .75976 m
.49717 .76013 L
s
.49718 .75844 m
.49704 .75976 L
s
.49852 .75938 m
.49704 .75976 L
s
1 .002 0 r
.38647 .58993 m
.38646 .58993 L
s
.38646 .58991 m
.38647 .58993 L
s
.38647 .58993 m
.38646 .58992 L
s
.38647 .58992 m
.38647 .58993 L
s
.38642 .58989 m
.38647 .58993 L
s
.38646 .58991 m
.38646 .58992 L
s
.38647 .58992 m
.38646 .58991 L
s
.38646 .58992 m
.38646 .58993 L
s
.38646 .58993 m
.38647 .58992 L
s
1 .014 0 r
.83812 .70311 m
.83848 .70286 L
s
1 0 0 r
.89667 .56159 m
.89667 .56159 L
s
1 .048 0 r
.61227 .6465 m
.61401 .646 L
s
1 .787 0 r
.44497 .44837 m
.42892 .43123 L
s
1 .045 0 r
.21913 .39176 m
.21887 .39062 L
s
1 .459 0 r
.38311 .39176 m
.38042 .39412 L
s
.3797 .38976 m
.38311 .39176 L
s
1 .825 0 r
.6282 .41417 m
.62356 .41801 L
s
.63309 .41781 m
.6282 .41417 L
s
1 .062 0 r
.28079 .4196 m
.28112 .41985 L
s
.28042 .4199 m
.28079 .4196 L
s
.28079 .4196 m
.28067 .41957 L
s
1 .168 0 r
.49731 .7588 m
.49718 .75844 L
s
.49718 .75844 m
.49852 .75938 L
s
1 .062 0 r
.28075 .42016 m
.28042 .4199 L
s
.28042 .4199 m
.28067 .41957 L
s
1 .014 0 r
.8384 .70284 m
.83847 .70293 L
s
.83834 .70289 m
.8384 .70284 L
s
.8384 .70284 m
.83848 .70286 L
s
1 .062 0 r
.28112 .41985 m
.28075 .42016 L
s
.28067 .41957 m
.28112 .41985 L
s
1 .014 0 r
.83847 .70293 m
.83841 .70298 L
s
.83848 .70286 m
.83847 .70293 L
s
.83841 .70298 m
.83834 .70289 L
s
.83834 .70289 m
.83848 .70286 L
s
.83848 .70286 m
.83841 .70298 L
s
1 .048 0 r
.61379 .64624 m
.61367 .64634 L
s
.61365 .64587 m
.61379 .64624 L
s
.61401 .646 m
.61379 .64624 L
s
.61354 .64597 m
.61365 .64587 L
s
.61365 .64587 m
.61401 .646 L
s
1 .062 0 r
.28067 .41957 m
.28075 .42016 L
s
1 .168 0 r
.49852 .75938 m
.49717 .76013 L
s
.49731 .7588 m
.49852 .75938 L
s
.4918 .75888 m
.49852 .75938 L
s
1 .575 0 r
.67083 .36596 m
.67401 .36302 L
s
1 .066 0 r
.83159 .36302 m
.83165 .36297 L
s
.8316 .36238 m
.83159 .36302 L
s
.83159 .36302 m
.83124 .36269 L
s
.832 .36267 m
.83159 .36302 L
s
.83178 .36133 m
.83159 .36302 L
s
1 .023 0 r
.8934 .39131 m
.89344 .39129 L
s
.89341 .39108 m
.8934 .39131 L
s
.8934 .39131 m
.89329 .39119 L
s
.89356 .39119 m
.8934 .39131 L
s
.89354 .39071 m
.8934 .39131 L
s
.89341 .39108 m
.89329 .39119 L
s
.89356 .39119 m
.89341 .39108 L
s
.89344 .39129 m
.89356 .39119 L
s
.26645 .70264 m
.26631 .70267 L
s
.26633 .70244 m
.26645 .70264 L
s
.26645 .70264 m
.26622 .7026 L
s
.26642 .70252 m
.26645 .70264 L
s
.26582 .70224 m
.26645 .70264 L
s
.89329 .39119 m
.89344 .39129 L
s
1 .048 0 r
.61401 .646 m
.61367 .64634 L
s
.61354 .64597 m
.61401 .646 L
s
.61367 .64634 m
.61354 .64597 L
s
1 .066 0 r
.8316 .36238 m
.83124 .36269 L
s
.832 .36267 m
.8316 .36238 L
s
1 .023 0 r
.26633 .70244 m
.26622 .7026 L
s
.26642 .70252 m
.26633 .70244 L
s
.26622 .7026 m
.26631 .70267 L
s
1 .121 0 r
.43315 .73087 m
.43341 .73115 L
s
.43344 .72994 m
.43315 .73087 L
s
.43433 .73075 m
.43315 .73087 L
s
1 .023 0 r
.26631 .70267 m
.26642 .70252 L
s
1 .121 0 r
.4337 .73022 m
.43344 .72994 L
s
.43344 .72994 m
.43433 .73075 L
s
1 .066 0 r
.83124 .36269 m
.83165 .36297 L
s
.83165 .36297 m
.832 .36267 L
s
1 .045 0 r
.21894 .39064 m
.21918 .39084 L
s
.21867 .39085 m
.21894 .39064 L
s
.21894 .39064 m
.21887 .39062 L
s
1 .121 0 r
.43433 .73075 m
.43341 .73115 L
s
.4337 .73022 m
.43433 .73075 L
s
.42981 .72971 m
.43433 .73075 L
s
.285 1 0 r
.44051 .44757 m
.4537 .45784 L
s
.44051 .44757 m
.45647 .4442 L
s
1 .045 0 r
.21891 .39105 m
.21867 .39085 L
s
.21867 .39085 m
.21887 .39062 L
s
.21918 .39084 m
.21891 .39105 L
s
.21887 .39062 m
.21918 .39084 L
s
1 .459 0 r
.3797 .38976 m
.38042 .39412 L
s
1 .168 0 r
.49717 .76013 m
.49731 .7588 L
s
1 .045 0 r
.21887 .39062 m
.21891 .39105 L
s
1 0 0 r
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
.83495 .53232 m
.83495 .53232 L
s
1 .039 0 r
.55165 .61728 m
.55162 .61735 L
s
.55161 .61697 m
.55165 .61728 L
s
.55192 .61713 m
.55165 .61728 L
s
1 .015 0 r
.77636 .67392 m
.77676 .67365 L
s
1 .039 0 r
.55038 .61728 m
.55192 .61713 L
s
1 0 0 r
.32441 .56064 m
.32441 .56064 L
s
1 .336 0 r
.38299 .41903 m
.37997 .41075 L
s
1 .035 0 r
.15702 .36239 m
.15687 .3615 L
s
1 .039 0 r
.55158 .61704 m
.55161 .61697 L
s
.55161 .61697 m
.55192 .61713 L
s
.55192 .61713 m
.55162 .61735 L
s
.55158 .61704 m
.55192 .61713 L
s
1 .015 0 r
.77668 .67363 m
.77675 .67373 L
s
.77662 .67368 m
.77668 .67363 L
s
.77668 .67363 m
.77676 .67365 L
s
.77675 .67373 m
.77669 .67378 L
s
.77676 .67365 m
.77675 .67373 L
s
1 .039 0 r
.55162 .61735 m
.55158 .61704 L
s
0 1 .566 r
.59193 .47543 m
.60543 .48313 L
s
1 .015 0 r
.77669 .67378 m
.77662 .67368 L
s
.77662 .67368 m
.77676 .67365 L
s
.77676 .67365 m
.77669 .67378 L
s
1 .121 0 r
.43341 .73115 m
.4337 .73022 L
s
.787 1 0 r
.57617 .47974 m
.58276 .47531 L
s
1 .229 0 r
.68852 .41851 m
.68885 .41841 L
s
.68874 .41633 m
.68852 .41851 L
s
.68852 .41851 m
.68749 .4173 L
s
.6901 .41745 m
.68852 .41851 L
s
.68988 .41281 m
.68852 .41851 L
s
1 .035 0 r
.15692 .36152 m
.1571 .36168 L
s
.1567 .36167 m
.15692 .36152 L
s
.15692 .36152 m
.15687 .3615 L
s
.787 1 0 r
.46904 .47661 m
.46727 .47501 L
s
.46727 .47501 m
.46924 .46538 L
s
.46727 .47501 m
.45966 .4693 L
s
1 .035 0 r
.1571 .36168 m
.15688 .36183 L
s
.15687 .3615 m
.1571 .36168 L
s
.15688 .36183 m
.1567 .36167 L
s
.1567 .36167 m
.15687 .3615 L
s
.15687 .3615 m
.15688 .36183 L
s
1 .004 0 r
.77309 .50311 m
.77311 .50311 L
s
.77311 .50307 m
.77309 .50311 L
s
.77309 .50311 m
.77308 .50308 L
s
.77313 .50309 m
.77309 .50311 L
s
.77316 .50301 m
.77309 .50311 L
s
.77311 .50307 m
.77308 .50308 L
s
.77313 .50309 m
.77311 .50307 L
s
.77311 .50311 m
.77313 .50309 L
s
1 .008 0 r
.48867 .58809 m
.48869 .5881 L
s
.48869 .58802 m
.48867 .58809 L
s
.48875 .58808 m
.48867 .58809 L
s
1 .004 0 r
.77308 .50308 m
.77311 .50311 L
s
1 .008 0 r
.4887 .58804 m
.48869 .58802 L
s
.48869 .58802 m
.48875 .58808 L
s
.48875 .58808 m
.48869 .5881 L
s
.4887 .58804 m
.48875 .58808 L
s
.48843 .58802 m
.48875 .58808 L
s
.48869 .5881 m
.4887 .58804 L
s
1 .825 0 r
.62356 .41801 m
.62844 .42166 L
s
1 .016 0 r
.71454 .6447 m
.71498 .64443 L
s
1 .172 0 r
.32094 .38966 m
.32023 .38529 L
s
1 0 0 r
.26232 .53135 m
.26232 .53134 L
s
.26232 .53134 m
.26232 .53134 L
s
.26231 .53134 m
.26232 .53134 L
s
.26232 .53134 m
.26232 .53134 L
s
.26232 .53134 m
.26231 .53134 L
s
.26231 .53134 m
.26232 .53134 L
s
.26232 .53134 m
.26232 .53134 L
s
.26232 .53134 m
.26232 .53134 L
s
.26232 .53134 m
.26232 .53134 L
s
1 .229 0 r
.68874 .41633 m
.68749 .4173 L
s
.6901 .41745 m
.68874 .41633 L
s
1 .062 0 r
.36975 .70133 m
.36934 .70147 L
s
.36937 .70086 m
.36975 .70133 L
s
.36975 .70133 m
.36914 .7013 L
s
.36957 .70102 m
.36975 .70133 L
s
.36775 .7005 m
.36975 .70133 L
s
.36914 .7013 m
.36934 .70147 L
s
.36937 .70086 m
.36914 .7013 L
s
.36957 .70102 m
.36937 .70086 L
s
1 .039 0 r
.71075 .47457 m
.71087 .47457 L
s
.71085 .47421 m
.71075 .47457 L
s
.71075 .47457 m
.71065 .47435 L
s
.71107 .47443 m
.71075 .47457 L
s
.71129 .47367 m
.71075 .47457 L
s
1 .825 0 r
.62844 .42166 m
.63309 .41781 L
s
1 .039 0 r
.71085 .47421 m
.71065 .47435 L
s
.71107 .47443 m
.71085 .47421 L
s
1 .016 0 r
.71489 .6444 m
.71496 .64451 L
s
.71482 .64445 m
.71489 .6444 L
s
.71489 .6444 m
.71498 .64443 L
s
.71496 .64451 m
.7149 .64456 L
s
.71498 .64443 m
.71496 .64451 L
s
1 .039 0 r
.71087 .47457 m
.71107 .47443 L
s
1 .016 0 r
.7149 .64456 m
.71482 .64445 L
s
.71482 .64445 m
.71498 .64443 L
s
.71498 .64443 m
.7149 .64456 L
s
1 .039 0 r
.71065 .47435 m
.71087 .47457 L
s
1 .062 0 r
.36934 .70147 m
.36957 .70102 L
s
1 .229 0 r
.68885 .41841 m
.6901 .41745 L
s
.787 1 0 r
.46924 .46538 m
.47102 .46694 L
s
.46924 .46538 m
.45966 .4693 L
s
1 .229 0 r
.68749 .4173 m
.68885 .41841 L
s
.425 1 0 r
.50216 .50492 m
.50661 .50227 L
s
.50661 .50227 m
.50227 .4902 L
s
.50661 .50227 m
.49106 .50113 L
s
.285 1 0 r
.45647 .4442 m
.4537 .45784 L
s
1 0 0 r
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
.93753 .53038 m
.93753 .53038 L
s
1 .006 0 r
.87887 .67214 m
.87901 .67203 L
s
1 .158 0 r
.59398 .7572 m
.60015 .75625 L
s
1 .014 0 r
.65264 .61544 m
.65308 .61522 L
s
1 0 0 r
.4264 .55873 m
.4264 .55873 L
s
0 .434 1 r
.48506 .41696 m
.41148 .33508 L
s
1 .002 0 r
.20017 .50202 m
.20015 .50199 L
s
1 .104 0 r
.25882 .36026 m
.25862 .35757 L
s
1 .002 0 r
.20015 .50199 m
.20016 .50199 L
s
.20014 .502 m
.20015 .50199 L
s
.20015 .50199 m
.20015 .50199 L
s
.20015 .502 m
.20014 .502 L
s
.20014 .502 m
.20015 .50199 L
s
.20016 .50199 m
.20015 .502 L
s
.20015 .50199 m
.20016 .50199 L
s
.20015 .50199 m
.20015 .502 L
s
1 .006 0 r
.87898 .67202 m
.87901 .67206 L
s
.87895 .67204 m
.87898 .67202 L
s
.87898 .67202 m
.87901 .67203 L
s
.87901 .67206 m
.87898 .67208 L
s
.87901 .67203 m
.87901 .67206 L
s
.87898 .67208 m
.87895 .67204 L
s
.87895 .67204 m
.87901 .67203 L
s
.87901 .67203 m
.87898 .67208 L
s
1 .014 0 r
.65304 .6153 m
.65299 .61533 L
s
.65299 .6152 m
.65304 .6153 L
s
.65308 .61522 m
.65304 .6153 L
s
.65294 .61523 m
.65299 .6152 L
s
.65299 .6152 m
.65308 .61522 L
s
.65299 .61533 m
.65294 .61523 L
s
.65308 .61522 m
.65299 .61533 L
s
.65294 .61523 m
.65308 .61522 L
s
1 .158 0 r
.59916 .75688 m
.59893 .75724 L
s
.5989 .75565 m
.59916 .75688 L
s
.60015 .75625 m
.59916 .75688 L
s
.59867 .756 m
.5989 .75565 L
s
.5989 .75565 m
.60015 .75625 L
s
1 .172 0 r
.53758 .72841 m
.53756 .72876 L
s
.53755 .72704 m
.53758 .72841 L
s
.53895 .72787 m
.53758 .72841 L
s
.425 1 0 r
.50227 .4902 m
.49779 .4928 L
s
.50227 .4902 m
.49106 .50113 L
s
1 .022 0 r
.30623 .67163 m
.3061 .67166 L
s
.30611 .67145 m
.30623 .67163 L
s
.30623 .67163 m
.30601 .6716 L
s
.3062 .67151 m
.30623 .67163 L
s
.30562 .67125 m
.30623 .67163 L
s
.30611 .67145 m
.30601 .6716 L
s
.3062 .67151 m
.30611 .67145 L
s
.30601 .6716 m
.3061 .67166 L
s
1 .172 0 r
.53753 .72739 m
.53755 .72704 L
s
.53755 .72704 m
.53895 .72787 L
s
1 .022 0 r
.3061 .67166 m
.3062 .67151 L
s
.787 1 0 r
.5694 .47292 m
.57617 .47974 L
s
1 .137 0 r
.47398 .6998 m
.47419 .70009 L
s
.47421 .69873 m
.47398 .6998 L
s
.47527 .69957 m
.47398 .6998 L
s
.717 1 0 r
.43154 .38769 m
.42496 .39569 L
s
.41988 .38417 m
.43154 .38769 L
s
1 .137 0 r
.47441 .69901 m
.47421 .69873 L
s
.47421 .69873 m
.47527 .69957 L
s
.425 1 0 r
.49106 .50113 m
.50216 .50492 L
s
.49106 .50113 m
.49779 .4928 L
s
.5473 .48306 m
.49106 .50113 L
s
1 .001 0 r
.87571 .50106 m
.87571 .50106 L
s
.87571 .50105 m
.87571 .50106 L
s
.87571 .50106 m
.8757 .50106 L
s
.87572 .50106 m
.87571 .50106 L
s
.87572 .50104 m
.87571 .50106 L
s
.87571 .50105 m
.8757 .50106 L
s
.87572 .50106 m
.87571 .50105 L
s
.87571 .50106 m
.87572 .50106 L
s
.8757 .50106 m
.87571 .50106 L
s
1 .005 0 r
.81704 .64288 m
.81715 .64278 L
s
1 .172 0 r
.53198 .72799 m
.53895 .72787 L
s
1 .007 0 r
.59067 .58614 m
.59091 .58607 L
s
1 .002 0 r
.3643 .52941 m
.36426 .52936 L
s
.973 1 0 r
.42299 .38756 m
.42014 .36111 L
s
1 .002 0 r
.36427 .52936 m
.36428 .52937 L
s
.36426 .52937 m
.36427 .52936 L
s
.36427 .52936 m
.36426 .52936 L
s
.36427 .52938 m
.36426 .52937 L
s
.36426 .52937 m
.36426 .52936 L
s
.36428 .52937 m
.36427 .52938 L
s
.36426 .52936 m
.36428 .52937 L
s
1 .007 0 r
.59088 .58611 m
.59086 .58612 L
s
.59086 .58606 m
.59088 .58611 L
s
.59091 .58607 m
.59088 .58611 L
s
1 .002 0 r
.36426 .52936 m
.36427 .52938 L
s
1 .007 0 r
.59084 .58607 m
.59086 .58606 L
s
.59086 .58606 m
.59091 .58607 L
s
1 .137 0 r
.47527 .69957 m
.47419 .70009 L
s
.47441 .69901 m
.47527 .69957 L
s
.46991 .69875 m
.47527 .69957 L
s
1 .007 0 r
.59091 .58607 m
.59086 .58612 L
s
.59084 .58607 m
.59091 .58607 L
s
1 .005 0 r
.81713 .64278 m
.81715 .64281 L
s
.8171 .64279 m
.81713 .64278 L
s
.81713 .64278 m
.81715 .64278 L
s
1 .007 0 r
.59086 .58612 m
.59084 .58607 L
s
1 .005 0 r
.81715 .64281 m
.81713 .64283 L
s
.81715 .64278 m
.81715 .64281 L
s
.81713 .64283 m
.8171 .64279 L
s
.8171 .64279 m
.81715 .64278 L
s
.81715 .64278 m
.81713 .64283 L
s
1 .158 0 r
.60015 .75625 m
.59893 .75724 L
s
.59867 .756 m
.60015 .75625 L
s
1 .172 0 r
.53895 .72787 m
.53756 .72876 L
s
.53753 .72739 m
.53895 .72787 L
s
1 .158 0 r
.59893 .75724 m
.59867 .756 L
s
1 .172 0 r
.53756 .72876 m
.53753 .72739 L
s
1 .137 0 r
.47419 .70009 m
.47441 .69901 L
s
1 .104 0 r
.2587 .35765 m
.25927 .35813 L
s
.25806 .35809 m
.2587 .35765 L
s
.2587 .35765 m
.25862 .35757 L
s
.717 1 0 r
.63053 .38673 m
.62608 .38677 L
s
.62571 .3752 m
.63053 .38673 L
s
.63053 .38673 m
.61924 .38321 L
s
.63257 .37874 m
.63053 .38673 L
s
.60707 .35759 m
.63053 .38673 L
s
1 .008 0 r
.81376 .47186 m
.81378 .47186 L
s
.81377 .47178 m
.81376 .47186 L
s
.81376 .47186 m
.81373 .47181 L
s
.81382 .47182 m
.81376 .47186 L
s
.81385 .47166 m
.81376 .47186 L
s
.81377 .47178 m
.81373 .47181 L
s
.81382 .47182 m
.81377 .47178 L
s
.81378 .47186 m
.81382 .47182 L
s
.81373 .47181 m
.81378 .47186 L
s
1 .006 0 r
.24355 .64209 m
.24352 .64209 L
s
.24352 .64204 m
.24355 .64209 L
s
.24355 .64209 m
.24349 .64207 L
s
.24355 .64206 m
.24355 .64209 L
s
.24342 .64198 m
.24355 .64209 L
s
.24352 .64204 m
.24349 .64207 L
s
.24355 .64206 m
.24352 .64204 L
s
1 .172 0 r
.32042 .38539 m
.32136 .38615 L
s
.31938 .38619 m
.32042 .38539 L
s
.32042 .38539 m
.32023 .38529 L
s
1 .006 0 r
.24349 .64207 m
.24352 .64209 L
s
.24352 .64209 m
.24355 .64206 L
s
1 .046 0 r
.75149 .44337 m
.75159 .44335 L
s
.75156 .44294 m
.75149 .44337 L
s
.75149 .44337 m
.75131 .44312 L
s
.75183 .44317 m
.75149 .44337 L
s
.7519 .44225 m
.75149 .44337 L
s
1 .104 0 r
.25927 .35813 m
.25862 .35858 L
s
.25862 .35757 m
.25927 .35813 L
s
1 .004 0 r
.75513 .61359 m
.75521 .61352 L
s
1 .091 0 r
.69641 .75552 m
.69944 .75438 L
s
1 0 0 r
.52863 .55682 m
.52863 .55682 L
s
1 .006 0 r
.30214 .50005 m
.30204 .49991 L
s
1 .417 0 r
.36086 .35812 m
.36146 .34732 L
s
.717 1 0 r
.41988 .38417 m
.42496 .39569 L
s
1 .046 0 r
.75156 .44294 m
.75131 .44312 L
s
.75183 .44317 m
.75156 .44294 L
s
1 .104 0 r
.25862 .35858 m
.25806 .35809 L
s
.25806 .35809 m
.25862 .35757 L
s
1 .004 0 r
.75519 .61352 m
.75521 .61354 L
s
.75518 .61353 m
.75519 .61352 L
s
.75519 .61352 m
.75521 .61352 L
s
.75521 .61354 m
.7552 .61355 L
s
.75521 .61352 m
.75521 .61354 L
s
1 .068 0 r
.4094 .67031 m
.4096 .67047 L
s
.40963 .6698 m
.4094 .67031 L
s
.41008 .6703 m
.4094 .67031 L
s
.41008 .6703 m
.4096 .67047 L
s
.40963 .6698 m
.41008 .6703 L
s
.40983 .66997 m
.41008 .6703 L
s
.40777 .66947 m
.41008 .6703 L
s
1 .004 0 r
.7552 .61355 m
.75518 .61353 L
s
.75518 .61353 m
.75521 .61352 L
s
.75521 .61352 m
.7552 .61355 L
s
1 .068 0 r
.40983 .66997 m
.40963 .6698 L
s
1 .006 0 r
.30206 .4999 m
.3021 .49993 L
s
.30203 .49994 m
.30206 .4999 L
s
.30206 .4999 m
.30204 .49991 L
s
1 .046 0 r
.75159 .44335 m
.75183 .44317 L
s
1 .006 0 r
.30206 .49996 m
.30203 .49994 L
s
.30203 .49994 m
.30204 .49991 L
s
.3021 .49993 m
.30206 .49996 L
s
.30204 .49991 m
.3021 .49993 L
s
.30204 .49991 m
.30206 .49996 L
s
1 .046 0 r
.75131 .44312 m
.75159 .44335 L
s
1 .104 0 r
.25862 .35757 m
.25862 .35858 L
s
1 .172 0 r
.32032 .38694 m
.31938 .38619 L
s
.31938 .38619 m
.32023 .38529 L
s
.939 1 0 r
.42837 .40696 m
.43353 .40996 L
s
.42292 .41359 m
.42837 .40696 L
s
.42837 .40696 m
.42387 .40707 L
s
1 .172 0 r
.32136 .38615 m
.32032 .38694 L
s
.32023 .38529 m
.32136 .38615 L
s
1 .068 0 r
.4096 .67047 m
.40983 .66997 L
s
1 .172 0 r
.32023 .38529 m
.32032 .38694 L
s
1 .091 0 r
.69913 .75482 m
.69886 .75507 L
s
.69881 .75415 m
.69913 .75482 L
s
.69944 .75438 m
.69913 .75482 L
s
.69853 .7544 m
.69881 .75415 L
s
.69881 .75415 m
.69944 .75438 L
s
1 .172 0 r
.73029 .38561 m
.73039 .38551 L
s
.73029 .38396 m
.73029 .38561 L
s
.73029 .38561 m
.72934 .38475 L
s
.73134 .38471 m
.73029 .38561 L
s
.73055 .38122 m
.73029 .38561 L
s
1 .002 0 r
.91977 .64107 m
.91981 .64103 L
s
1 .121 0 r
.63439 .72627 m
.6388 .72507 L
s
1 .001 0 r
.69315 .58426 m
.69318 .58424 L
s
1 .021 0 r
.46652 .52746 m
.46582 .52718 L
s
1 0 0 r
.01 w
.52528 .38545 Mdot
1 .009 0 r
.5 Mabswid
.2399 .47066 m
.2398 .47045 L
s
1 .001 0 r
.69317 .58424 m
.69318 .58424 L
s
.69317 .58424 m
.69317 .58424 L
s
.69317 .58424 m
.69318 .58424 L
s
.69318 .58424 m
.69317 .58425 L
s
.69318 .58424 m
.69318 .58424 L
s
.69317 .58425 m
.69317 .58424 L
s
.69317 .58424 m
.69318 .58424 L
s
.69318 .58424 m
.69317 .58425 L
s
1 .002 0 r
.9198 .64102 m
.91981 .64104 L
s
.91979 .64103 m
.9198 .64102 L
s
.9198 .64102 m
.91981 .64103 L
s
.91981 .64104 m
.9198 .64104 L
s
.91981 .64103 m
.91981 .64104 L
s
.9198 .64104 m
.91979 .64103 L
s
.91979 .64103 m
.91981 .64103 L
s
.91981 .64103 m
.9198 .64104 L
s
1 .009 0 r
.23982 .47045 m
.23987 .47048 L
s
.23977 .47049 m
.23982 .47045 L
s
.23982 .47045 m
.2398 .47045 L
s
.23982 .47053 m
.23977 .47049 L
s
.23977 .47049 m
.2398 .47045 L
s
.23987 .47048 m
.23982 .47053 L
s
.2398 .47045 m
.23987 .47048 L
s
1 .021 0 r
.46596 .52733 m
.4659 .52729 L
s
.4659 .52729 m
.46597 .52714 L
s
.4659 .52729 m
.46582 .52718 L
s
.46597 .52714 m
.46603 .52718 L
s
.46597 .52714 m
.46582 .52718 L
s
1 .009 0 r
.2398 .47045 m
.23982 .47053 L
s
1 .172 0 r
.73029 .38396 m
.72934 .38475 L
s
.73134 .38471 m
.73029 .38396 L
s
.939 1 0 r
.42807 .41661 m
.42292 .41359 L
s
.42292 .41359 m
.42387 .40707 L
s
1 .021 0 r
.46603 .52718 m
.46596 .52733 L
s
.46582 .52718 m
.46596 .52733 L
s
.46582 .52718 m
.46603 .52718 L
s
1 .091 0 r
.69886 .75507 m
.69853 .7544 L
s
.69944 .75438 m
.69886 .75507 L
s
.69853 .7544 m
.69944 .75438 L
s
1 .336 0 r
.38065 .41088 m
.38248 .4122 L
s
.37868 .41262 m
.38065 .41088 L
s
.38065 .41088 m
.37997 .41075 L
s
1 .02 0 r
.3461 .64049 m
.34598 .64052 L
s
.34599 .64033 m
.3461 .64049 L
s
.3461 .64049 m
.34591 .64046 L
s
.34607 .64038 m
.3461 .64049 L
s
.34555 .64016 m
.3461 .64049 L
s
1 .172 0 r
.72934 .38475 m
.73039 .38551 L
s
1 .02 0 r
.34599 .64033 m
.34591 .64046 L
s
.34607 .64038 m
.34599 .64033 L
s
.34591 .64046 m
.34598 .64052 L
s
1 .172 0 r
.73039 .38551 m
.73134 .38471 L
s
1 .121 0 r
.63823 .72563 m
.63794 .72592 L
s
.6379 .7247 m
.63823 .72563 L
s
.6388 .72507 m
.63823 .72563 L
s
1 .02 0 r
.34598 .64052 m
.34607 .64038 L
s
1 .121 0 r
.63761 .72499 m
.6379 .7247 L
s
.6379 .7247 m
.6388 .72507 L
s
1 .003 0 r
.91661 .46971 m
.91662 .46971 L
s
.91661 .46969 m
.91661 .46971 L
s
.91661 .46971 m
.9166 .4697 L
s
.91663 .4697 m
.91661 .46971 L
s
.91664 .46965 m
.91661 .46971 L
s
.91661 .46969 m
.9166 .4697 L
s
.91663 .4697 m
.91661 .46969 L
s
.91662 .46971 m
.91663 .4697 L
s
.9166 .4697 m
.91662 .46971 L
s
.717 1 0 r
.62571 .3752 m
.61924 .38321 L
s
.63257 .37874 m
.62571 .3752 L
s
1 .043 0 r
.79906 .75383 m
.80026 .75315 L
s
1 .001 0 r
.85785 .61174 m
.85787 .61171 L
s
1 .151 0 r
.57231 .69699 m
.57824 .6962 L
s
1 0 0 r
.63109 .5549 m
.63109 .5549 L
s
1 .047 0 r
.40434 .49807 m
.40336 .49708 L
s
0 1 .511 r
.46313 .35598 m
.49098 .29153 L
s
1 .01 0 r
.17759 .44123 m
.1775 .44099 L
s
1 .001 0 r
.85787 .61171 m
.85787 .61172 L
s
.85786 .61172 m
.85787 .61171 L
s
.85787 .61171 m
.85787 .61171 L
s
.85787 .61172 m
.85787 .61172 L
s
.85787 .61171 m
.85787 .61172 L
s
.85787 .61172 m
.85786 .61172 L
s
.85786 .61172 m
.85787 .61171 L
s
.85787 .61171 m
.85787 .61172 L
s
1 .01 0 r
.17753 .441 m
.17758 .44104 L
s
.17747 .44104 m
.17753 .441 L
s
.17753 .441 m
.1775 .44099 L
s
.17752 .44109 m
.17747 .44104 L
s
.17747 .44104 m
.1775 .44099 L
s
1 .336 0 r
.38051 .41394 m
.37868 .41262 L
s
.37868 .41262 m
.37997 .41075 L
s
1 .01 0 r
.17758 .44104 m
.17752 .44109 L
s
.1775 .44099 m
.17758 .44104 L
s
.1775 .44099 m
.17752 .44109 L
s
1 .151 0 r
.57726 .6968 m
.57707 .6971 L
s
.57704 .69561 m
.57726 .6968 L
s
.57824 .6962 m
.57726 .6968 L
s
1 .141 0 r
.51463 .66834 m
.5147 .6686 L
s
.51471 .66721 m
.51463 .66834 L
s
.51585 .66796 m
.51463 .66834 L
s
.787 1 0 r
.45966 .4693 m
.46904 .47661 L
s
.45966 .4693 m
.47102 .46694 L
s
1 .151 0 r
.57685 .69592 m
.57704 .69561 L
s
.57704 .69561 m
.57824 .6962 L
s
1 .121 0 r
.6388 .72507 m
.63794 .72592 L
s
.63761 .72499 m
.6388 .72507 L
s
1 .141 0 r
.51478 .66747 m
.51471 .66721 L
s
.51471 .66721 m
.51585 .66796 L
s
1 .121 0 r
.63794 .72592 m
.63761 .72499 L
s
1 .043 0 r
.8 .75307 m
.8002 .75336 L
s
.79984 .75321 m
.8 .75307 L
s
.8 .75307 m
.80026 .75315 L
s
.8002 .75336 m
.80004 .7535 L
s
.80026 .75315 m
.8002 .75336 L
s
1 .336 0 r
.38248 .4122 m
.38051 .41394 L
s
.37997 .41075 m
.38248 .4122 L
s
1 .032 0 r
.56806 .52594 m
.56814 .52589 L
s
.56814 .52589 m
.56806 .52564 L
s
.56814 .52589 m
.56783 .52586 L
s
.56806 .52564 m
.56797 .5257 L
s
.56806 .52564 m
.56783 .52586 L
s
.56783 .52586 m
.56806 .52594 L
s
.56783 .52586 m
.56797 .5257 L
s
.56897 .52551 m
.56783 .52586 L
s
1 .047 0 r
.40357 .49706 m
.40379 .4972 L
s
.40333 .49735 m
.40357 .49706 L
s
.40357 .49706 m
.40336 .49708 L
s
1 .141 0 r
.51585 .66796 m
.5147 .6686 L
s
.51478 .66747 m
.51585 .66796 L
s
.51015 .66768 m
.51585 .66796 L
s
1 .012 0 r
.85458 .4405 m
.85461 .44049 L
s
.85459 .44038 m
.85458 .4405 L
s
.85458 .4405 m
.85453 .44043 L
s
.85467 .44044 m
.85458 .4405 L
s
.85468 .4402 m
.85458 .4405 L
s
1 .047 0 r
.40355 .49749 m
.40333 .49735 L
s
.40333 .49735 m
.40336 .49708 L
s
1 .043 0 r
.80004 .7535 m
.79984 .75321 L
s
.79984 .75321 m
.80026 .75315 L
s
1 .012 0 r
.85459 .44038 m
.85453 .44043 L
s
.85467 .44044 m
.85459 .44038 L
s
1 .043 0 r
.80026 .75315 m
.80004 .7535 L
s
1 .012 0 r
.85461 .44049 m
.85467 .44044 L
s
.85453 .44043 m
.85461 .44049 L
s
1 .032 0 r
.56797 .5257 m
.56806 .52594 L
s
1 .047 0 r
.79239 .4119 m
.79246 .41188 L
s
.79243 .41146 m
.79239 .4119 L
s
.79239 .4119 m
.79217 .41166 L
s
.79271 .41168 m
.79239 .4119 L
s
.79265 .41073 m
.79239 .4119 L
s
.40379 .4972 m
.40355 .49749 L
s
.40336 .49708 m
.40379 .4972 L
s
1 .151 0 r
.57824 .6962 m
.57707 .6971 L
s
.57685 .69592 m
.57824 .6962 L
s
1 .047 0 r
.40336 .49708 m
.40355 .49749 L
s
1 .003 0 r
.28334 .61088 m
.28332 .61088 L
s
.28333 .61085 m
.28334 .61088 L
s
.28334 .61088 m
.28331 .61087 L
s
.28334 .61086 m
.28334 .61088 L
s
.28327 .61081 m
.28334 .61088 L
s
.28333 .61085 m
.28331 .61087 L
s
.28334 .61086 m
.28333 .61085 L
s
.28331 .61087 m
.28332 .61088 L
s
.28332 .61088 m
.28334 .61086 L
s
1 .047 0 r
.79243 .41146 m
.79217 .41166 L
s
.79271 .41168 m
.79243 .41146 L
s
1 .055 0 r
.73703 .72455 m
.73869 .72371 L
s
1 0 0 r
.79586 .58238 m
.79586 .58237 L
s
1 .043 0 r
.34209 .46864 m
.34155 .46762 L
s
1 0 0 r
.79586 .58237 m
.79586 .58237 L
s
.79586 .58237 m
.79586 .58237 L
s
.79586 .58237 m
.79586 .58237 L
s
.79586 .58237 m
.79586 .58237 L
s
.79586 .58237 m
.79586 .58237 L
s
.79586 .58237 m
.79586 .58237 L
s
.79586 .58237 m
.79586 .58237 L
s
.79586 .58237 m
.79586 .58237 L
s
1 .047 0 r
.79246 .41188 m
.79271 .41168 L
s
1 .151 0 r
.57707 .6971 m
.57685 .69592 L
s
1 .047 0 r
.79217 .41166 m
.79246 .41188 L
s
1 .141 0 r
.5147 .6686 m
.51478 .66747 L
s
.717 1 0 r
.61924 .38321 m
.62608 .38677 L
s
1 .07 0 r
.44978 .6391 m
.44995 .63925 L
s
.44997 .63857 m
.44978 .6391 L
s
.45047 .63905 m
.44978 .6391 L
s
.45014 .63872 m
.44997 .63857 L
s
.44997 .63857 m
.45047 .63905 L
s
.45047 .63905 m
.44995 .63925 L
s
.45014 .63872 m
.45047 .63905 L
s
.44792 .63833 m
.45047 .63905 L
s
1 .336 0 r
.37997 .41075 m
.38051 .41394 L
s
1 .136 0 r
.60617 .49675 m
.60684 .49686 L
s
.60681 .49559 m
.60617 .49675 L
s
.60617 .49675 m
.60619 .49596 L
s
.60746 .49649 m
.60617 .49675 L
s
.60945 .49409 m
.60617 .49675 L
s
.60681 .49559 m
.60619 .49596 L
s
.60746 .49649 m
.60681 .49559 L
s
1 .07 0 r
.44995 .63925 m
.45014 .63872 L
s
1 .136 0 r
.60684 .49686 m
.60746 .49649 L
s
1 .055 0 r
.73834 .7236 m
.73858 .72399 L
s
.73814 .72376 m
.73834 .7236 L
s
.73834 .7236 m
.73869 .72371 L
s
.73858 .72399 m
.73838 .72415 L
s
.73869 .72371 m
.73858 .72399 L
s
1 .08 0 r
.32925 .75241 m
.32873 .75259 L
s
.32877 .75178 m
.32925 .75241 L
s
.32925 .75241 m
.32845 .75235 L
s
.32904 .75201 m
.32925 .75241 L
s
.32673 .75129 m
.32925 .75241 L
s
1 .043 0 r
.34167 .46762 m
.34189 .46779 L
s
.34142 .46786 m
.34167 .46762 L
s
.34167 .46762 m
.34155 .46762 L
s
.787 1 0 r
.47102 .46694 m
.46904 .47661 L
s
1 .08 0 r
.32877 .75178 m
.32845 .75235 L
s
.32904 .75201 m
.32877 .75178 L
s
.32845 .75235 m
.32873 .75259 L
s
1 .043 0 r
.34164 .46802 m
.34142 .46786 L
s
.34142 .46786 m
.34155 .46762 L
s
.34189 .46779 m
.34164 .46802 L
s
.34155 .46762 m
.34189 .46779 L
s
1 .055 0 r
.73838 .72415 m
.73814 .72376 L
s
.73814 .72376 m
.73869 .72371 L
s
1 .043 0 r
.34155 .46762 m
.34164 .46802 L
s
1 .055 0 r
.73869 .72371 m
.73838 .72415 L
s
1 0 0 r
.22091 .58144 m
.22091 .58144 L
s
.22091 .58143 m
.22091 .58144 L
s
.22091 .58144 m
.22091 .58144 L
s
.22091 .58144 m
.22091 .58144 L
s
.22091 .58143 m
.22091 .58144 L
s
.22091 .58143 m
.22091 .58144 L
s
.22091 .58144 m
.22091 .58143 L
s
.22091 .58144 m
.22091 .58144 L
s
.22091 .58144 m
.22091 .58144 L
s
.96081 .60988 m
.96081 .60987 L
s
1 .075 0 r
.67494 .69523 m
.67736 .69422 L
s
1 0 0 r
.73379 .55298 m
.73379 .55298 L
s
1 .606 0 r
.50678 .49608 m
.48311 .49193 L
s
1 .035 0 r
.27976 .43918 m
.27948 .43832 L
s
1 0 0 r
.96081 .60987 m
.96082 .60988 L
s
.96081 .60987 m
.96081 .60987 L
s
.96081 .60987 m
.96081 .60987 L
s
.96082 .60988 m
.96081 .60988 L
s
.96081 .60987 m
.96082 .60988 L
s
.96081 .60988 m
.96081 .60987 L
s
.96081 .60987 m
.96081 .60987 L
s
.96081 .60987 m
.96081 .60988 L
s
1 .136 0 r
.60619 .49596 m
.60684 .49686 L
s
1 .08 0 r
.32873 .75259 m
.32904 .75201 L
s
1 .035 0 r
.27955 .43833 m
.27974 .43848 L
s
.27934 .43851 m
.27955 .43833 L
s
.27955 .43833 m
.27948 .43832 L
s
.27953 .43865 m
.27934 .43851 L
s
.27934 .43851 m
.27948 .43832 L
s
0 1 .566 r
.60543 .48313 m
.61841 .46696 L
s
1 .035 0 r
.27974 .43848 m
.27953 .43865 L
s
.27948 .43832 m
.27974 .43848 L
s
1 .075 0 r
.67714 .6946 m
.67689 .69479 L
s
.67686 .69406 m
.67714 .6946 L
s
.67736 .69422 m
.67714 .6946 L
s
.67662 .69425 m
.67686 .69406 L
s
.67686 .69406 m
.67736 .69422 L
s
.939 1 0 r
.43353 .40996 m
.42807 .41661 L
s
.42387 .40707 m
.43353 .40996 L
s
1 .014 0 r
.38603 .60919 m
.38595 .60921 L
s
.38595 .60907 m
.38603 .60919 L
s
.38603 .60919 m
.38589 .60917 L
s
.38601 .60911 m
.38603 .60919 L
s
.38562 .60895 m
.38603 .60919 L
s
1 .035 0 r
.27948 .43832 m
.27953 .43865 L
s
1 .014 0 r
.38595 .60907 m
.38589 .60917 L
s
.38601 .60911 m
.38595 .60907 L
s
.38589 .60917 m
.38595 .60921 L
s
1 .134 0 r
.77153 .35297 m
.77154 .35288 L
s
.77144 .35169 m
.77153 .35297 L
s
.77153 .35297 m
.77071 .35234 L
s
.77227 .35223 m
.77153 .35297 L
s
.77135 .34951 m
.77153 .35297 L
s
1 .014 0 r
.38595 .60921 m
.38601 .60911 L
s
1 .003 0 r
.67159 .52362 m
.67161 .52362 L
s
.6716 .52359 m
.67159 .52362 L
s
.67159 .52362 m
.67159 .5236 L
s
.67162 .52361 m
.67159 .52362 L
s
.67166 .52355 m
.67159 .52362 L
s
.6716 .52359 m
.67159 .5236 L
s
.67162 .52361 m
.6716 .52359 L
s
.67161 .52362 m
.67162 .52361 L
s
.67159 .5236 m
.67161 .52362 L
s
1 .023 0 r
.83991 .72282 m
.8405 .72241 L
s
1 0 0 r
.8988 .58049 m
.8988 .58048 L
s
1 .1 0 r
.61277 .66589 m
.61638 .66486 L
s
1 .481 0 r
.44451 .46662 m
.43468 .45623 L
s
1 .028 0 r
.21737 .40968 m
.21721 .40897 L
s
1 0 0 r
.8988 .58048 m
.8988 .58048 L
s
.8988 .58048 m
.8988 .58048 L
s
.8988 .58048 m
.8988 .58048 L
s
.8988 .58048 m
.8988 .58049 L
s
.8988 .58048 m
.8988 .58048 L
s
.8988 .58049 m
.8988 .58048 L
s
.8988 .58048 m
.8988 .58048 L
s
.8988 .58048 m
.8988 .58049 L
s
1 .459 0 r
.67154 .38112 m
.67117 .38088 L
s
.67098 .37673 m
.67154 .38112 L
s
.67154 .38112 m
.66843 .3791 L
s
.67372 .37851 m
.67154 .38112 L
s
.6692 .36948 m
.67154 .38112 L
s
1 .134 0 r
.77144 .35169 m
.77071 .35234 L
s
.77227 .35223 m
.77144 .35169 L
s
1 .075 0 r
.67689 .69479 m
.67662 .69425 L
s
.67736 .69422 m
.67689 .69479 L
s
.67662 .69425 m
.67736 .69422 L
s
1 .168 0 r
.43391 .75119 m
.43427 .75159 L
s
.43432 .74989 m
.43391 .75119 L
s
.43555 .75103 m
.43391 .75119 L
s
.43467 .75029 m
.43432 .74989 L
s
.43432 .74989 m
.43555 .75103 L
s
1 .162 0 r
.64793 .46636 m
.64839 .46635 L
s
.64833 .46485 m
.64793 .46636 L
s
.64793 .46636 m
.64747 .46544 L
s
.64925 .46576 m
.64793 .46636 L
s
.65007 .46256 m
.64793 .46636 L
s
1 .038 0 r
.26535 .72259 m
.26513 .72265 L
s
.26516 .72227 m
.26535 .72259 L
s
.26535 .72259 m
.26498 .72253 L
s
.26531 .72239 m
.26535 .72259 L
s
.26433 .72196 m
.26535 .72259 L
s
1 .168 0 r
.43555 .75103 m
.43427 .75159 L
s
.43467 .75029 m
.43555 .75103 L
s
.42926 .74959 m
.43555 .75103 L
s
1 .038 0 r
.26516 .72227 m
.26498 .72253 L
s
.26531 .72239 m
.26516 .72227 L
s
1 .023 0 r
.84037 .72237 m
.84049 .72253 L
s
.84028 .72245 m
.84037 .72237 L
s
.84037 .72237 m
.8405 .72241 L
s
1 .606 0 r
.48782 .4956 m
.48689 .49476 L
s
.48689 .49476 m
.48788 .48993 L
s
.48689 .49476 m
.48311 .49193 L
s
1 .038 0 r
.26498 .72253 m
.26513 .72265 L
s
1 .023 0 r
.84049 .72253 m
.84039 .72261 L
s
.8405 .72241 m
.84049 .72253 L
s
1 .134 0 r
.77071 .35234 m
.77154 .35288 L
s
1 .023 0 r
.84039 .72261 m
.84028 .72245 L
s
.84028 .72245 m
.8405 .72241 L
s
.8405 .72241 m
.84039 .72261 L
s
1 .028 0 r
.21725 .40899 m
.21741 .40911 L
s
.21708 .40912 m
.21725 .40899 L
s
.21725 .40899 m
.21721 .40897 L
s
1 .134 0 r
.77154 .35288 m
.77227 .35223 L
s
1 .038 0 r
.26513 .72265 m
.26531 .72239 L
s
1 .028 0 r
.21723 .40924 m
.21708 .40912 L
s
.21708 .40912 m
.21721 .40897 L
s
.21741 .40911 m
.21723 .40924 L
s
.21721 .40897 m
.21741 .40911 L
s
1 .162 0 r
.64833 .46485 m
.64747 .46544 L
s
.64925 .46576 m
.64833 .46485 L
s
1 .1 0 r
.61592 .66534 m
.61567 .66556 L
s
.61565 .66458 m
.61592 .66534 L
s
.61638 .66486 m
.61592 .66534 L
s
1 .028 0 r
.21721 .40897 m
.21723 .40924 L
s
1 .014 0 r
.89556 .409 m
.89559 .40899 L
s
.89557 .40886 m
.89556 .409 L
s
.89556 .409 m
.8955 .40893 L
s
.89566 .40893 m
.89556 .409 L
s
.89565 .40864 m
.89556 .409 L
s
1 .1 0 r
.6154 .66479 m
.61565 .66458 L
s
.61565 .66458 m
.61638 .66486 L
s
.939 1 0 r
.42387 .40707 m
.42807 .41661 L
s
1 .014 0 r
.89557 .40886 m
.8955 .40893 L
s
.89566 .40893 m
.89557 .40886 L
s
.89559 .40899 m
.89566 .40893 L
s
.8955 .40893 m
.89559 .40899 L
s
1 .606 0 r
.48788 .48993 m
.48881 .49076 L
s
.48788 .48993 m
.48311 .49193 L
s
1 .162 0 r
.64839 .46635 m
.64925 .46576 L
s
0 1 .511 r
.61783 .35178 m
.6228 .35408 L
s
.62209 .3316 m
.61783 .35178 L
s
.64185 .34655 m
.61783 .35178 L
s
1 .045 0 r
.8334 .38025 m
.83345 .38022 L
s
.83341 .37982 m
.8334 .38025 L
s
.8334 .38025 m
.83317 .38003 L
s
.83369 .38001 m
.8334 .38025 L
s
.83354 .37909 m
.8334 .38025 L
s
1 .001 0 r
.32327 .57956 m
.32327 .57956 L
s
.32327 .57955 m
.32327 .57956 L
s
.32327 .57956 m
.32326 .57956 L
s
.32327 .57955 m
.32327 .57956 L
s
.32325 .57954 m
.32327 .57956 L
s
.32327 .57955 m
.32326 .57956 L
s
.32327 .57955 m
.32327 .57955 L
s
.32326 .57956 m
.32327 .57956 L
s
.32327 .57956 m
.32327 .57955 L
s
1 .111 0 r
.55419 .63651 m
.55409 .63671 L
s
.55408 .63562 m
.55419 .63651 L
s
.55497 .63608 m
.55419 .63651 L
s
1 .028 0 r
.7778 .69347 m
.77854 .69298 L
s
1 0 0 r
.83673 .55106 m
.83673 .55106 L
s
1 .111 0 r
.55053 .63651 m
.55497 .63608 L
s
1 .215 0 r
.38218 .43712 m
.38023 .43185 L
s
1 .023 0 r
.1549 .38016 m
.1548 .37956 L
s
1 .045 0 r
.83341 .37982 m
.83317 .38003 L
s
.83369 .38001 m
.83341 .37982 L
s
1 .168 0 r
.43427 .75159 m
.43467 .75029 L
s
1 .111 0 r
.55398 .63582 m
.55408 .63562 L
s
.55408 .63562 m
.55497 .63608 L
s
1 .459 0 r
.67098 .37673 m
.66843 .3791 L
s
.67372 .37851 m
.67098 .37673 L
s
1 .045 0 r
.83317 .38003 m
.83345 .38022 L
s
.83345 .38022 m
.83369 .38001 L
s
1 .1 0 r
.61638 .66486 m
.61567 .66556 L
s
.6154 .66479 m
.61638 .66486 L
s
1 .162 0 r
.64747 .46544 m
.64839 .46635 L
s
1 .1 0 r
.61567 .66556 m
.6154 .66479 L
s
1 .787 0 r
.43226 .43107 m
.43611 .43335 L
s
.4282 .43602 m
.43226 .43107 L
s
.43226 .43107 m
.42892 .43123 L
s
1 .028 0 r
.77839 .69294 m
.77852 .69313 L
s
.77827 .69303 m
.77839 .69294 L
s
.77839 .69294 m
.77854 .69298 L
s
.77852 .69313 m
.77841 .69322 L
s
.77854 .69298 m
.77852 .69313 L
s
1 .023 0 r
.15484 .37957 m
.15496 .37968 L
s
.15469 .37967 m
.15484 .37957 L
s
.15484 .37957 m
.1548 .37956 L
s
.15496 .37968 m
.15481 .37978 L
s
.1548 .37956 m
.15496 .37968 L
s
.15481 .37978 m
.15469 .37967 L
s
.15469 .37967 m
.1548 .37956 L
s
1 .111 0 r
.55497 .63608 m
.55409 .63671 L
s
.55398 .63582 m
.55497 .63608 L
s
1 .058 0 r
.48995 .60757 m
.49004 .60767 L
s
.49004 .60711 m
.48995 .60757 L
s
.4905 .60747 m
.48995 .60757 L
s
.425 1 0 r
.49779 .4928 m
.50216 .50492 L
s
1 .028 0 r
.77841 .69322 m
.77827 .69303 L
s
.77827 .69303 m
.77854 .69298 L
s
1 .023 0 r
.1548 .37956 m
.15481 .37978 L
s
1 .028 0 r
.77854 .69298 m
.77841 .69322 L
s
1 .095 0 r
.36995 .7215 m
.36931 .72172 L
s
.36935 .72077 m
.36995 .7215 L
s
.36995 .7215 m
.369 .72146 L
s
.36966 .72102 m
.36995 .7215 L
s
.36684 .72022 m
.36995 .7215 L
s
1 .058 0 r
.49013 .60721 m
.49004 .60711 L
s
.49004 .60711 m
.4905 .60747 L
s
1 .095 0 r
.369 .72146 m
.36931 .72172 L
s
.36935 .72077 m
.369 .72146 L
s
.36966 .72102 m
.36935 .72077 L
s
1 .058 0 r
.4905 .60747 m
.49004 .60767 L
s
.49013 .60721 m
.4905 .60747 L
s
.48822 .60709 m
.4905 .60747 L
s
1 .111 0 r
.55409 .63671 m
.55398 .63582 L
s
1 .058 0 r
.49004 .60767 m
.49013 .60721 L
s
1 .417 0 r
.36144 .34762 m
.36377 .34963 L
s
.35891 .34935 m
.36144 .34762 L
s
.36144 .34762 m
.36146 .34732 L
s
1 .001 0 r
.77457 .5216 m
.77457 .5216 L
s
.77457 .5216 m
.77457 .5216 L
s
.77457 .5216 m
.77457 .5216 L
s
.77458 .5216 m
.77457 .5216 L
s
.77458 .52159 m
.77457 .5216 L
s
.77457 .5216 m
.77457 .5216 L
s
.77458 .5216 m
.77457 .5216 L
s
.77457 .5216 m
.77458 .5216 L
s
.77457 .5216 m
.77457 .5216 L
s
1 .459 0 r
.66843 .3791 m
.67117 .38088 L
s
1 .035 0 r
.71562 .66409 m
.7166 .66351 L
s
1 0 0 r
.26081 .55009 m
.26081 .55009 L
s
1 .116 0 r
.31977 .40759 m
.31928 .40467 L
s
1 .095 0 r
.36931 .72172 m
.36966 .72102 L
s
1 .787 0 r
.43205 .43831 m
.4282 .43602 L
s
.4282 .43602 m
.42892 .43123 L
s
.717 1 0 r
.62608 .38677 m
.63257 .37874 L
s
1 .035 0 r
.7164 .66345 m
.71655 .66369 L
s
.71626 .66356 m
.7164 .66345 L
s
.7164 .66345 m
.7166 .66351 L
s
.71655 .66369 m
.71641 .6638 L
s
.7166 .66351 m
.71655 .66369 L
s
1 .459 0 r
.67117 .38088 m
.67372 .37851 L
s
1 .035 0 r
.71641 .6638 m
.71626 .66356 L
s
.71626 .66356 m
.7166 .66351 L
s
.7166 .66351 m
.71641 .6638 L
s
1 .013 0 r
.71218 .49239 m
.71222 .49239 L
s
.71221 .49227 m
.71218 .49239 L
s
.71218 .49239 m
.71215 .49232 L
s
.71229 .49234 m
.71218 .49239 L
s
.71236 .49209 m
.71218 .49239 L
s
.71221 .49227 m
.71215 .49232 L
s
.71229 .49234 m
.71221 .49227 L
s
.71222 .49239 m
.71229 .49234 L
s
.71215 .49232 m
.71222 .49239 L
s
0 1 .511 r
.6271 .33373 m
.62209 .3316 L
s
.62209 .3316 m
.64185 .34655 L
s
1 .417 0 r
.36377 .34963 m
.36124 .35136 L
s
.36146 .34732 m
.36377 .34963 L
s
1 .005 0 r
.426 .57773 m
.42596 .57774 L
s
.42597 .57768 m
.426 .57773 L
s
.426 .57773 m
.42595 .57772 L
s
.42599 .5777 m
.426 .57773 L
s
.42583 .57764 m
.426 .57773 L
s
.42597 .57768 m
.42595 .57772 L
s
.42599 .5777 m
.42597 .57768 L
s
.42595 .57772 m
.42596 .57774 L
s
.42596 .57774 m
.42599 .5777 L
s
1 .011 0 r
.88091 .69171 m
.88116 .69149 L
s
1 0 0 r
.9399 .54913 m
.9399 .54913 L
s
1 .043 0 r
.65337 .63468 m
.65472 .63403 L
s
0 .813 1 r
.48483 .43506 m
.41897 .36251 L
s
1 .073 0 r
.25729 .37803 m
.25715 .37615 L
s
1 0 0 r
.1983 .52061 m
.1983 .52061 L
s
.1983 .52061 m
.1983 .52061 L
s
.19829 .52061 m
.1983 .52061 L
s
.1983 .52061 m
.1983 .52061 L
s
.1983 .52061 m
.19829 .52061 L
s
.19829 .52061 m
.1983 .52061 L
s
.1983 .52061 m
.1983 .52061 L
s
.1983 .52061 m
.1983 .52061 L
s
.1983 .52061 m
.1983 .52061 L
s
1 .417 0 r
.36124 .35136 m
.35891 .34935 L
s
.35891 .34935 m
.36146 .34732 L
s
1 .011 0 r
.8811 .69148 m
.88116 .69155 L
s
.88105 .69152 m
.8811 .69148 L
s
.8811 .69148 m
.88116 .69149 L
s
1 .606 0 r
.48311 .49193 m
.48782 .4956 L
s
.48311 .49193 m
.48881 .49076 L
s
1 .011 0 r
.88116 .69155 m
.88111 .69159 L
s
.88116 .69149 m
.88116 .69155 L
s
.88111 .69159 m
.88105 .69152 L
s
.88105 .69152 m
.88116 .69149 L
s
1 .202 0 r
.47562 .72003 m
.47592 .72046 L
s
.47595 .71844 m
.47562 .72003 L
s
.47751 .71969 m
.47562 .72003 L
s
1 .011 0 r
.88116 .69149 m
.88111 .69159 L
s
1 .04 0 r
.30546 .6915 m
.30522 .69156 L
s
.30525 .69116 m
.30546 .6915 L
s
.30546 .6915 m
.30506 .69144 L
s
.30541 .69129 m
.30546 .6915 L
s
.30435 .69082 m
.30546 .6915 L
s
.30525 .69116 m
.30506 .69144 L
s
.30541 .69129 m
.30525 .69116 L
s
.30506 .69144 m
.30522 .69156 L
s
1 .233 0 r
.53965 .74845 m
.53961 .74894 L
s
.5396 .74658 m
.53965 .74845 L
s
.54151 .74773 m
.53965 .74845 L
s
1 .202 0 r
.47625 .71887 m
.47595 .71844 L
s
.47595 .71844 m
.47751 .71969 L
s
1 .043 0 r
.65461 .63426 m
.65446 .63437 L
s
.65444 .63395 m
.65461 .63426 L
s
.65472 .63403 m
.65461 .63426 L
s
.65429 .63406 m
.65444 .63395 L
s
.65444 .63395 m
.65472 .63403 L
s
1 .04 0 r
.30522 .69156 m
.30541 .69129 L
s
1 .233 0 r
.53957 .74708 m
.5396 .74658 L
s
.5396 .74658 m
.54151 .74773 L
s
1 .202 0 r
.47751 .71969 m
.47592 .72046 L
s
.47625 .71887 m
.47751 .71969 L
s
.46959 .71849 m
.47751 .71969 L
s
1 .141 0 r
.68998 .43443 m
.69019 .43438 L
s
.69012 .43308 m
.68998 .43443 L
s
.68998 .43443 m
.68934 .43369 L
s
.69097 .43378 m
.68998 .43443 L
s
.69083 .43093 m
.68998 .43443 L
s
1 .043 0 r
.65446 .63437 m
.65429 .63406 L
s
.65472 .63403 m
.65446 .63437 L
s
.65429 .63406 m
.65472 .63403 L
s
1 .59 0 r
.62892 .43427 m
.62902 .43405 L
s
.62884 .42861 m
.62892 .43427 L
s
.62892 .43427 m
.6255 .4314 L
s
.63237 .43126 m
.62892 .43427 L
s
.62898 .41946 m
.62892 .43427 L
s
1 .606 0 r
.48881 .49076 m
.48782 .4956 L
s
1 .141 0 r
.69012 .43308 m
.68934 .43369 L
s
.69097 .43378 m
.69012 .43308 L
s
1 .116 0 r
.31942 .40473 m
.32005 .40524 L
s
.31871 .40527 m
.31942 .40473 L
s
.31942 .40473 m
.31928 .40467 L
s
1 .043 0 r
.87452 .34846 m
.87455 .34843 L
s
.87451 .34805 m
.87452 .34846 L
s
.87452 .34846 m
.87428 .34825 L
s
.87478 .34822 m
.87452 .34846 L
s
.87457 .34735 m
.87452 .34846 L
s
.808 1 0 r
.42113 .33986 m
.42788 .34504 L
s
.41402 .34533 m
.42113 .33986 L
s
.42113 .33986 m
.42029 .33892 L
s
1 0 0 r
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
.87774 .51963 m
.87774 .51963 L
s
1 .012 0 r
.81871 .66229 m
.81898 .66206 L
s
1 .233 0 r
.53202 .74789 m
.54151 .74773 L
s
1 .047 0 r
.59105 .60523 m
.59275 .60472 L
s
1 0 0 r
.36338 .54816 m
.36338 .54816 L
s
1 .825 0 r
.4224 .4055 m
.4201 .38439 L
s
1 .051 0 r
.19474 .34843 m
.19469 .3471 L
s
1 .043 0 r
.87451 .34805 m
.87428 .34825 L
s
.87478 .34822 m
.87451 .34805 L
s
1 .417 0 r
.36146 .34732 m
.36124 .35136 L
s
1 .043 0 r
.87428 .34825 m
.87455 .34843 L
s
1 .012 0 r
.81892 .66205 m
.81898 .66213 L
s
.81887 .66209 m
.81892 .66205 L
s
.81892 .66205 m
.81898 .66206 L
s
.81898 .66213 m
.81893 .66217 L
s
.81898 .66206 m
.81898 .66213 L
s
1 .233 0 r
.54151 .74773 m
.53961 .74894 L
s
.53957 .74708 m
.54151 .74773 L
s
1 .043 0 r
.87455 .34843 m
.87478 .34822 L
s
1 .116 0 r
.31935 .40578 m
.31871 .40527 L
s
.31871 .40527 m
.31928 .40467 L
s
1 .012 0 r
.81893 .66217 m
.81887 .66209 L
s
.81887 .66209 m
.81898 .66206 L
s
1 .073 0 r
.2572 .3762 m
.2576 .37654 L
s
.25675 .37652 m
.2572 .3762 L
s
.2572 .3762 m
.25715 .37615 L
s
1 .012 0 r
.81898 .66206 m
.81893 .66217 L
s
1 .116 0 r
.32005 .40524 m
.31935 .40578 L
s
.31928 .40467 m
.32005 .40524 L
s
1 .141 0 r
.69019 .43438 m
.69097 .43378 L
s
1 .047 0 r
.59253 .60496 m
.59241 .60505 L
s
.5924 .60459 m
.59253 .60496 L
s
.59275 .60472 m
.59253 .60496 L
s
.59228 .60469 m
.5924 .60459 L
s
.5924 .60459 m
.59275 .60472 L
s
1 .141 0 r
.68934 .43369 m
.69019 .43438 L
s
1 .116 0 r
.4099 .69048 m
.41025 .69076 L
s
.41028 .68961 m
.4099 .69048 L
s
.41106 .69047 m
.4099 .69048 L
s
1 .202 0 r
.47592 .72046 m
.47625 .71887 L
s
1 .116 0 r
.41106 .69047 m
.41025 .69076 L
s
.41028 .68961 m
.41106 .69047 L
s
.41063 .6899 m
.41106 .69047 L
s
.40709 .68905 m
.41106 .69047 L
s
1 .073 0 r
.2576 .37654 m
.25715 .37686 L
s
.25715 .37615 m
.2576 .37654 L
s
.25715 .37686 m
.25675 .37652 L
s
.25675 .37652 m
.25715 .37615 L
s
1 .116 0 r
.41063 .6899 m
.41028 .68961 L
s
.31928 .40467 m
.31935 .40578 L
s
1 .047 0 r
.59275 .60472 m
.59241 .60505 L
s
.59228 .60469 m
.59275 .60472 L
s
1 .215 0 r
.38067 .43192 m
.38184 .43277 L
s
.3794 .43304 m
.38067 .43192 L
s
.38067 .43192 m
.38023 .43185 L
s
1 .047 0 r
.59241 .60505 m
.59228 .60469 L
s
1 .073 0 r
.25715 .37615 m
.25715 .37686 L
s
1 .787 0 r
.43611 .43335 m
.43205 .43831 L
s
.42892 .43123 m
.43611 .43335 L
s
1 .013 0 r
.2421 .66164 m
.24203 .66166 L
s
.24204 .66153 m
.2421 .66164 L
s
.2421 .66164 m
.24197 .66161 L
s
.2421 .66157 m
.2421 .66164 L
s
.24179 .66139 m
.2421 .66164 L
s
1 .233 0 r
.53961 .74894 m
.53957 .74708 L
s
1 .013 0 r
.24204 .66153 m
.24197 .66161 L
s
.2421 .66157 m
.24204 .66153 L
s
.24197 .66161 m
.24203 .66166 L
s
.24203 .66166 m
.2421 .66157 L
s
1 .051 0 r
.19473 .34713 m
.195 .34738 L
s
.1944 .34735 m
.19473 .34713 L
s
.19473 .34713 m
.19469 .3471 L
s
1 .003 0 r
.81548 .49016 m
.81549 .49016 L
s
.81548 .49013 m
.81548 .49016 L
s
.81548 .49016 m
.81547 .49014 L
s
.8155 .49015 m
.81548 .49016 L
s
.81551 .4901 m
.81548 .49016 L
s
1 .021 0 r
.52933 .5758 m
.52932 .57583 L
s
.52932 .57563 m
.52933 .5758 L
s
.52949 .57573 m
.52933 .5758 L
s
1 .003 0 r
.81548 .49013 m
.81547 .49014 L
s
.8155 .49015 m
.81548 .49013 L
s
.81549 .49016 m
.8155 .49015 L
s
.81547 .49014 m
.81549 .49016 L
s
1 .215 0 r
.38058 .4339 m
.3794 .43304 L
s
.3794 .43304 m
.38023 .43185 L
s
1 .021 0 r
.52932 .57566 m
.52932 .57563 L
s
.52932 .57563 m
.52949 .57573 L
s
1 .051 0 r
.195 .34738 m
.19468 .34759 L
s
.19469 .3471 m
.195 .34738 L
s
1 .012 0 r
.75645 .63284 m
.75673 .63261 L
s
1 .021 0 r
.52865 .57574 m
.52949 .57573 L
s
1 .001 0 r
.30085 .51864 m
.30084 .51863 L
s
1 .323 0 r
.35991 .3759 m
.36038 .36758 L
s
1 .051 0 r
.19468 .34759 m
.1944 .34735 L
s
.1944 .34735 m
.19469 .3471 L
s
1 .116 0 r
.41025 .69076 m
.41063 .6899 L
s
1 .001 0 r
.30084 .51863 m
.30085 .51863 L
s
.30084 .51863 m
.30084 .51863 L
s
.30084 .51863 m
.30084 .51863 L
s
.30084 .51863 m
.30084 .51863 L
s
.30084 .51863 m
.30084 .51863 L
s
.30085 .51863 m
.30084 .51863 L
s
.30084 .51863 m
.30085 .51863 L
s
1 .021 0 r
.52949 .57573 m
.52932 .57583 L
s
.52932 .57566 m
.52949 .57573 L
s
1 .001 0 r
.30084 .51863 m
.30084 .51863 L
s
1 .021 0 r
.52932 .57583 m
.52932 .57566 L
s
1 .051 0 r
.19469 .3471 m
.19468 .34759 L
s
1 .59 0 r
.62884 .42861 m
.6255 .4314 L
s
.63237 .43126 m
.62884 .42861 L
s
1 .012 0 r
.75667 .6326 m
.75673 .63268 L
s
.75661 .63264 m
.75667 .6326 L
s
.75667 .6326 m
.75673 .63261 L
s
.75673 .63268 m
.75667 .63272 L
s
.75673 .63261 m
.75673 .63268 L
s
.75667 .63272 m
.75661 .63264 L
s
.75661 .63264 m
.75673 .63261 L
s
1 .215 0 r
.38184 .43277 m
.38058 .4339 L
s
.38023 .43185 m
.38184 .43277 L
s
1 .012 0 r
.75673 .63261 m
.75667 .63272 L
s
1 .787 0 r
.42892 .43123 m
.43205 .43831 L
s
1 .021 0 r
.75301 .46104 m
.75306 .46104 L
s
.75304 .46084 m
.75301 .46104 L
s
.75301 .46104 m
.75293 .46093 L
s
.75317 .46095 m
.75301 .46104 L
s
.7532 .46053 m
.75301 .46104 L
s
.75304 .46084 m
.75293 .46093 L
s
.75317 .46095 m
.75304 .46084 L
s
.75306 .46104 m
.75317 .46095 L
s
.75293 .46093 m
.75306 .46104 L
s
1 .215 0 r
.38023 .43185 m
.38058 .4339 L
s
0 1 .511 r
.64185 .34655 m
.6228 .35408 L
s
.6271 .33373 m
.64185 .34655 L
s
.54403 .32765 m
.64185 .34655 L
s
1 .005 0 r
.92204 .66049 m
.92213 .66039 L
s
1 .168 0 r
.63502 .74618 m
.64117 .74453 L
s
1 .01 0 r
.69411 .60335 m
.69437 .60316 L
s
1 0 0 r
.46618 .54622 m
.46618 .54622 L
s
.01 w
.52528 .4034 Mdot
1 .003 0 r
.5 Mabswid
.23825 .48909 m
.23822 .48903 L
s
1 .168 0 r
.29735 .34627 m
.29782 .34191 L
s
1 .003 0 r
.23823 .48903 m
.23825 .48904 L
s
.23822 .48904 m
.23823 .48903 L
s
.23823 .48903 m
.23822 .48903 L
s
.23823 .48906 m
.23822 .48904 L
s
.23822 .48904 m
.23822 .48903 L
s
.23825 .48904 m
.23823 .48906 L
s
.23822 .48903 m
.23825 .48904 L
s
.23822 .48903 m
.23823 .48906 L
s
1 .005 0 r
.92211 .66039 m
.92214 .66042 L
s
.92209 .66041 m
.92211 .66039 L
s
.92211 .66039 m
.92213 .66039 L
s
.92214 .66042 m
.92212 .66043 L
s
.92213 .66039 m
.92214 .66042 L
s
.92212 .66043 m
.92209 .66041 L
s
.92209 .66041 m
.92213 .66039 L
s
.92213 .66039 m
.92212 .66043 L
s
1 .01 0 r
.69432 .60315 m
.69437 .60322 L
s
.69427 .60318 m
.69432 .60315 L
s
.69432 .60315 m
.69437 .60316 L
s
.69437 .60322 m
.69432 .60325 L
s
.69437 .60316 m
.69437 .60322 L
s
.69432 .60325 m
.69427 .60318 L
s
.69427 .60318 m
.69437 .60316 L
s
.69437 .60316 m
.69432 .60325 L
s
1 .043 0 r
.34571 .66029 m
.34546 .66036 L
s
.34548 .65994 m
.34571 .66029 L
s
.34571 .66029 m
.34529 .66024 L
s
.34565 .66007 m
.34571 .66029 L
s
.34452 .65958 m
.34571 .66029 L
s
.34548 .65994 m
.34529 .66024 L
s
.34565 .66007 m
.34548 .65994 L
s
.34529 .66024 m
.34546 .66036 L
s
.34546 .66036 m
.34565 .66007 L
s
1 .59 0 r
.6255 .4314 m
.62902 .43405 L
s
.62902 .43405 m
.63237 .43126 L
s
1 .229 0 r
.51737 .68833 m
.51749 .68877 L
s
.51749 .6865 m
.51737 .68833 L
s
.51935 .68772 m
.51737 .68833 L
s
.808 1 0 r
.42077 .35053 m
.41402 .34533 L
s
.41402 .34533 m
.42029 .33892 L
s
1 .481 0 r
.43672 .45609 m
.43908 .45751 L
s
.43423 .45913 m
.43672 .45609 L
s
.43672 .45609 m
.43468 .45623 L
s
1 .001 0 r
.91888 .48811 m
.91888 .48811 L
s
.91888 .4881 m
.91888 .48811 L
s
.91888 .48811 m
.91888 .48811 L
s
.91889 .48811 m
.91888 .48811 L
s
.91889 .48809 m
.91888 .48811 L
s
.91888 .4881 m
.91888 .48811 L
s
.91889 .48811 m
.91888 .4881 L
s
.91888 .48811 m
.91889 .48811 L
s
.91888 .48811 m
.91888 .48811 L
s
1 .004 0 r
.85976 .631 m
.85984 .63092 L
s
1 .22 0 r
.57258 .71675 m
.58131 .71559 L
s
1 .005 0 r
.6317 .57384 m
.63186 .57375 L
s
1 .007 0 r
.40364 .51667 m
.40351 .51653 L
s
0 1 .331 r
.46277 .37376 m
.48871 .31429 L
s
1 .004 0 r
.17558 .45951 m
.17555 .45941 L
s
1 .229 0 r
.51761 .68694 m
.51749 .6865 L
s
.51749 .6865 m
.51935 .68772 L
s
1 .168 0 r
.64037 .7453 m
.63996 .74571 L
s
.63991 .74401 m
.64037 .7453 L
s
.64117 .74453 m
.64037 .7453 L
s
1 .004 0 r
.85982 .63092 m
.85984 .63094 L
s
.8598 .63093 m
.85982 .63092 L
s
.85982 .63092 m
.85984 .63092 L
s
1 .005 0 r
.63183 .57374 m
.63185 .57378 L
s
.63181 .57375 m
.63183 .57374 L
s
.63183 .57374 m
.63186 .57375 L
s
.63185 .57378 m
.63183 .57379 L
s
.63186 .57375 m
.63185 .57378 L
s
1 .004 0 r
.85984 .63094 m
.85983 .63096 L
s
.85984 .63092 m
.85984 .63094 L
s
.17556 .45941 m
.17558 .45943 L
s
.17553 .45943 m
.17556 .45941 L
s
.17556 .45941 m
.17555 .45941 L
s
.85983 .63096 m
.8598 .63093 L
s
.8598 .63093 m
.85984 .63092 L
s
.85984 .63092 m
.85983 .63096 L
s
.17555 .45945 m
.17553 .45943 L
s
.17553 .45943 m
.17555 .45941 L
s
.17558 .45943 m
.17555 .45945 L
s
.17555 .45941 m
.17558 .45943 L
s
1 .005 0 r
.63183 .57379 m
.63181 .57375 L
s
.63181 .57375 m
.63186 .57375 L
s
.63186 .57375 m
.63183 .57379 L
s
1 .004 0 r
.17555 .45941 m
.17555 .45945 L
s
1 .007 0 r
.40353 .51653 m
.40357 .51655 L
s
.4035 .51657 m
.40353 .51653 L
s
.40353 .51653 m
.40351 .51653 L
s
.40353 .51659 m
.4035 .51657 L
s
.4035 .51657 m
.40351 .51653 L
s
1 .168 0 r
.6395 .74443 m
.63991 .74401 L
s
.63991 .74401 m
.64117 .74453 L
s
1 .007 0 r
.40357 .51655 m
.40353 .51659 L
s
.40351 .51653 m
.40357 .51655 L
s
.40351 .51653 m
.40353 .51659 L
s
.808 1 0 r
.42788 .34504 m
.42077 .35053 L
s
.42029 .33892 m
.42788 .34504 L
s
1 .293 0 r
.7124 .34501 m
.71203 .34484 L
s
.71187 .34221 m
.7124 .34501 L
s
.7124 .34501 m
.71027 .3438 L
s
.71363 .34325 m
.7124 .34501 L
s
.71016 .33755 m
.7124 .34501 L
s
1 .116 0 r
.73155 .40213 m
.73162 .40207 L
s
.73155 .40101 m
.73155 .40213 L
s
.73155 .40213 m
.73091 .40155 L
s
.73226 .40152 m
.73155 .40213 L
s
.73173 .39918 m
.73155 .40213 L
s
1 .141 0 r
.45123 .65931 m
.45158 .65962 L
s
.45161 .65823 m
.45123 .65931 L
s
.45263 .65921 m
.45123 .65931 L
s
1 .22 0 r
.57985 .71646 m
.57958 .71693 L
s
.57954 .71472 m
.57985 .71646 L
s
.58131 .71559 m
.57985 .71646 L
s
1 .141 0 r
.45197 .65853 m
.45161 .65823 L
s
.45161 .65823 m
.45263 .65921 L
s
1 .481 0 r
.4366 .46056 m
.43423 .45913 L
s
.43423 .45913 m
.43468 .45623 L
s
1 .141 0 r
.45263 .65921 m
.45158 .65962 L
s
.45197 .65853 m
.45263 .65921 L
s
.44748 .65777 m
.45263 .65921 L
s
1 .116 0 r
.73155 .40101 m
.73091 .40155 L
s
.73226 .40152 m
.73155 .40101 L
s
1 .229 0 r
.51935 .68772 m
.51749 .68877 L
s
.51761 .68694 m
.51935 .68772 L
s
.51006 .68727 m
.51935 .68772 L
s
1 .22 0 r
.57926 .71518 m
.57954 .71472 L
s
.57954 .71472 m
.58131 .71559 L
s
1 .116 0 r
.73091 .40155 m
.73162 .40207 L
s
1 .011 0 r
.28211 .63029 m
.28206 .6303 L
s
.28206 .63019 m
.28211 .63029 L
s
.28211 .63029 m
.28201 .63026 L
s
.28211 .63023 m
.28211 .63029 L
s
.28187 .63008 m
.28211 .63029 L
s
1 .116 0 r
.73162 .40207 m
.73226 .40152 L
s
1 .293 0 r
.71187 .34221 m
.71027 .3438 L
s
.71363 .34325 m
.71187 .34221 L
s
1 .011 0 r
.28206 .63019 m
.28201 .63026 L
s
.28211 .63023 m
.28206 .63019 L
s
.28201 .63026 m
.28206 .6303 L
s
.28206 .6303 m
.28211 .63023 L
s
1 .005 0 r
.85653 .45862 m
.85654 .45862 L
s
.85654 .45857 m
.85653 .45862 L
s
.85653 .45862 m
.85651 .45859 L
s
.85657 .45859 m
.85653 .45862 L
s
.85658 .45849 m
.85653 .45862 L
s
.85654 .45857 m
.85651 .45859 L
s
.85657 .45859 m
.85654 .45857 L
s
.85654 .45862 m
.85657 .45859 L
s
.85651 .45859 m
.85654 .45862 L
s
1 .168 0 r
.64117 .74453 m
.63996 .74571 L
s
.6395 .74443 m
.64117 .74453 L
s
.63996 .74571 m
.6395 .74443 L
s
1 .08 0 r
.73825 .74447 m
.74066 .74327 L
s
1 .003 0 r
.79742 .60148 m
.79747 .60143 L
s
1 0 0 r
.56922 .54428 m
.56922 .54428 L
s
1 .014 0 r
.34103 .48709 m
.34085 .48676 L
s
1 .741 0 r
.40019 .3441 m
.40764 .32529 L
s
1 .003 0 r
.79745 .60143 m
.79747 .60144 L
s
.79744 .60143 m
.79745 .60143 L
s
.79745 .60143 m
.79747 .60143 L
s
.79747 .60144 m
.79746 .60145 L
s
.79747 .60143 m
.79747 .60144 L
s
.79746 .60145 m
.79744 .60143 L
s
.79744 .60143 m
.79747 .60143 L
s
.79747 .60143 m
.79746 .60145 L
s
1 .141 0 r
.45158 .65962 m
.45197 .65853 L
s
1 .229 0 r
.51749 .68877 m
.51761 .68694 L
s
1 .014 0 r
.34089 .48676 m
.34097 .48681 L
s
.34081 .48683 m
.34089 .48676 L
s
.34089 .48676 m
.34085 .48676 L
s
.34089 .48689 m
.34081 .48683 L
s
.34081 .48683 m
.34085 .48676 L
s
1 .293 0 r
.71027 .3438 m
.71203 .34484 L
s
1 .014 0 r
.34097 .48681 m
.34089 .48689 L
s
.34085 .48676 m
.34097 .48681 L
s
.34085 .48676 m
.34089 .48689 L
s
1 .22 0 r
.58131 .71559 m
.57958 .71693 L
s
.57926 .71518 m
.58131 .71559 L
s
1 .026 0 r
.79405 .42951 m
.79408 .4295 L
s
.79406 .42926 m
.79405 .42951 L
s
.79405 .42951 m
.79392 .42937 L
s
.79423 .42938 m
.79405 .42951 L
s
.79419 .42885 m
.79405 .42951 L
s
.79406 .42926 m
.79392 .42937 L
s
.79423 .42938 m
.79406 .42926 L
s
.79408 .4295 m
.79423 .42938 L
s
.79392 .42937 m
.79408 .4295 L
s
1 .22 0 r
.57958 .71693 m
.57926 .71518 L
s
1 .293 0 r
.71203 .34484 m
.71363 .34325 L
s
1 .168 0 r
.29778 .34203 m
.29871 .34288 L
s
.29675 .34269 m
.29778 .34203 L
s
.29778 .34203 m
.29782 .34191 L
s
1 .08 0 r
.74015 .7431 m
.74049 .74367 L
s
.73986 .74334 m
.74015 .7431 L
s
.74015 .7431 m
.74066 .74327 L
s
.74049 .74367 m
.7402 .74391 L
s
.74066 .74327 m
.74049 .74367 L
s
1 .481 0 r
.43908 .45751 m
.4366 .46056 L
s
.43468 .45623 m
.43908 .45751 L
s
1 .002 0 r
.21918 .60058 m
.21918 .60058 L
s
.21918 .60056 m
.21918 .60058 L
s
.21918 .60058 m
.21917 .60057 L
s
.21919 .60057 m
.21918 .60058 L
s
.21915 .60054 m
.21918 .60058 L
s
.21918 .60056 m
.21917 .60057 L
s
.21919 .60057 m
.21918 .60056 L
s
.21917 .60057 m
.21918 .60058 L
s
.21918 .60058 m
.21919 .60057 L
s
.96332 .62916 m
.96334 .62912 L
s
1 .114 0 r
.6758 .715 m
.67953 .71346 L
s
1 .001 0 r
.735 .57193 m
.73501 .57191 L
s
1 .117 0 r
.50667 .5147 m
.5021 .5139 L
s
1 .016 0 r
.27835 .45747 m
.27822 .45708 L
s
1 .001 0 r
.73501 .57191 m
.73501 .57191 L
s
.735 .57191 m
.73501 .57191 L
s
.73501 .57191 m
.73501 .57191 L
s
.73501 .57191 m
.73501 .57192 L
s
.73501 .57191 m
.73501 .57191 L
s
.73501 .57192 m
.735 .57191 L
s
.735 .57191 m
.73501 .57191 L
s
.73501 .57191 m
.73501 .57192 L
s
1 .002 0 r
.96334 .62912 m
.96335 .62913 L
s
.96333 .62913 m
.96334 .62912 L
s
.96334 .62912 m
.96334 .62912 L
s
.96335 .62913 m
.96334 .62914 L
s
.96334 .62912 m
.96335 .62913 L
s
.96334 .62914 m
.96333 .62913 L
s
.96333 .62913 m
.96334 .62912 L
s
.96334 .62912 m
.96334 .62914 L
s
1 .168 0 r
.29871 .34288 m
.29767 .34354 L
s
.29782 .34191 m
.29871 .34288 L
s
1 .043 0 r
.38607 .62894 m
.38581 .62901 L
s
.38583 .62859 m
.38607 .62894 L
s
.38607 .62894 m
.38564 .62889 L
s
.386 .62871 m
.38607 .62894 L
s
.38482 .62823 m
.38607 .62894 L
s
1 .117 0 r
.50301 .51461 m
.50282 .51444 L
s
.50282 .51444 m
.50302 .51351 L
s
.50282 .51444 m
.5021 .5139 L
s
1 .016 0 r
.27825 .45708 m
.27834 .45715 L
s
.27815 .45716 m
.27825 .45708 L
s
.27825 .45708 m
.27822 .45708 L
s
1 .043 0 r
.38583 .62859 m
.38564 .62889 L
s
.386 .62871 m
.38583 .62859 L
s
.38564 .62889 m
.38581 .62901 L
s
1 .168 0 r
.29767 .34354 m
.29675 .34269 L
s
.29675 .34269 m
.29782 .34191 L
s
1 .016 0 r
.27824 .45723 m
.27815 .45716 L
s
.27815 .45716 m
.27822 .45708 L
s
.27834 .45715 m
.27824 .45723 L
s
.27822 .45708 m
.27834 .45715 L
s
1 .08 0 r
.7402 .74391 m
.73986 .74334 L
s
.73986 .74334 m
.74066 .74327 L
s
.74066 .74327 m
.7402 .74391 L
s
1 .016 0 r
.27822 .45708 m
.27824 .45723 L
s
1 .117 0 r
.50302 .51351 m
.5032 .51368 L
s
.50302 .51351 m
.5021 .5139 L
s
1 .481 0 r
.43468 .45623 m
.4366 .46056 L
s
1 .043 0 r
.38581 .62901 m
.386 .62871 L
s
.939 1 0 r
.6271 .39971 m
.62338 .3998 L
s
.62308 .39011 m
.6271 .39971 L
s
.6271 .39971 m
.61768 .39679 L
s
.62878 .3931 m
.6271 .39971 L
s
.60755 .37565 m
.6271 .39971 L
s
1 .168 0 r
.29782 .34191 m
.29767 .34354 L
s
1 .117 0 r
.5021 .5139 m
.50301 .51461 L
s
.5021 .5139 m
.5032 .51368 L
s
1 .055 0 r
.26432 .74281 m
.264 .74291 L
s
.26404 .74235 m
.26432 .74281 L
s
.26432 .74281 m
.26378 .74273 L
s
.26426 .74253 m
.26432 .74281 L
s
.26282 .7419 m
.26432 .74281 L
s
1 .117 0 r
.5032 .51368 m
.50301 .51461 L
s
1 .035 0 r
.84173 .74276 m
.84261 .74214 L
s
1 .001 0 r
.90096 .5996 m
.90097 .59958 L
s
1 .166 0 r
.61327 .68549 m
.61933 .6838 L
s
1 0 0 r
.6725 .54234 m
.6725 .54234 L
s
1 .199 0 r
.44405 .48508 m
.43997 .48081 L
s
0 .04 1 r
.50328 .34192 m
.64867 .29102 L
s
1 .015 0 r
.21559 .42781 m
.2155 .42743 L
s
.808 1 0 r
.42029 .33892 m
.42077 .35053 L
s
1 .055 0 r
.26404 .74235 m
.26378 .74273 L
s
.26426 .74253 m
.26404 .74235 L
s
1 .001 0 r
.90097 .59958 m
.90097 .59959 L
s
.90096 .59959 m
.90097 .59958 L
s
.90097 .59958 m
.90097 .59958 L
s
.90097 .59959 m
.90097 .59959 L
s
.90097 .59958 m
.90097 .59959 L
s
.90097 .59959 m
.90096 .59959 L
s
.90096 .59959 m
.90097 .59958 L
s
.90097 .59958 m
.90097 .59959 L
s
1 .055 0 r
.26378 .74273 m
.264 .74291 L
s
1 .114 0 r
.67918 .71403 m
.67881 .71434 L
s
.67876 .7132 m
.67918 .71403 L
s
.67953 .71346 m
.67918 .71403 L
s
.67839 .71351 m
.67876 .7132 L
s
.67876 .7132 m
.67953 .71346 L
s
1 .015 0 r
.21553 .42743 m
.21561 .4275 L
s
.21543 .4275 m
.21553 .42743 L
s
.21553 .42743 m
.2155 .42743 L
s
1 .055 0 r
.264 .74291 m
.26426 .74253 L
s
1 .015 0 r
.21552 .42757 m
.21543 .4275 L
s
.21543 .4275 m
.2155 .42743 L
s
.21561 .4275 m
.21552 .42757 L
s
.2155 .42743 m
.21561 .4275 L
s
.2155 .42743 m
.21552 .42757 L
s
1 .323 0 r
.36036 .36779 m
.36217 .36936 L
s
.3584 .36914 m
.36036 .36779 L
s
.36036 .36779 m
.36038 .36758 L
s
1 .035 0 r
.84242 .74209 m
.8426 .74232 L
s
.84227 .74221 m
.84242 .74209 L
s
.84242 .74209 m
.84261 .74214 L
s
.8426 .74232 m
.84245 .74244 L
s
.84261 .74214 m
.8426 .74232 L
s
1 .162 0 r
.49284 .6277 m
.49309 .628 L
s
.4931 .62641 m
.49284 .6277 L
s
.49437 .62741 m
.49284 .6277 L
s
1 .021 0 r
.60943 .51312 m
.60954 .51314 L
s
.60953 .51294 m
.60943 .51312 L
s
.60943 .51312 m
.60944 .513 L
s
.60963 .51308 m
.60943 .51312 L
s
.60994 .51272 m
.60943 .51312 L
s
.60953 .51294 m
.60944 .513 L
s
.60963 .51308 m
.60953 .51294 L
s
.60954 .51314 m
.60963 .51308 L
s
1 .035 0 r
.84245 .74244 m
.84227 .74221 L
s
.84227 .74221 m
.84261 .74214 L
s
.84261 .74214 m
.84245 .74244 L
s
1 .114 0 r
.67881 .71434 m
.67839 .71351 L
s
.67953 .71346 m
.67881 .71434 L
s
1 .162 0 r
.49336 .62671 m
.4931 .62641 L
s
.4931 .62641 m
.49437 .62741 L
s
1 .114 0 r
.67839 .71351 m
.67953 .71346 L
s
1 .021 0 r
.60944 .513 m
.60954 .51314 L
s
1 .095 0 r
.7729 .36978 m
.77291 .36972 L
s
.77284 .36886 m
.7729 .36978 L
s
.7729 .36978 m
.77232 .36933 L
s
.77343 .36925 m
.7729 .36978 L
s
.77277 .36733 m
.7729 .36978 L
s
1 .008 0 r
.89774 .42697 m
.89775 .42696 L
s
.89775 .42689 m
.89774 .42697 L
s
.89774 .42697 m
.89771 .42693 L
s
.8978 .42693 m
.89774 .42697 L
s
.89779 .42677 m
.89774 .42697 L
s
.89775 .42689 m
.89771 .42693 L
s
.8978 .42693 m
.89775 .42689 L
s
.89775 .42696 m
.8978 .42693 L
s
.89771 .42693 m
.89775 .42696 L
s
1 .007 0 r
.32223 .59879 m
.3222 .5988 L
s
.32221 .59873 m
.32223 .59879 L
s
.32223 .59879 m
.32217 .59878 L
s
.32224 .59876 m
.32223 .59879 L
s
.32209 .59866 m
.32223 .59879 L
s
.32221 .59873 m
.32217 .59878 L
s
.32224 .59876 m
.32221 .59873 L
s
.32217 .59878 m
.3222 .5988 L
s
1 .162 0 r
.49437 .62741 m
.49309 .628 L
s
.49336 .62671 m
.49437 .62741 L
s
.488 .62638 m
.49437 .62741 L
s
1 .007 0 r
.3222 .5988 m
.32224 .59876 L
s
1 .095 0 r
.77284 .36886 m
.77232 .36933 L
s
.77343 .36925 m
.77284 .36886 L
s
1 .134 0 r
.37032 .74195 m
.36941 .74228 L
s
.36947 .74092 m
.37032 .74195 L
s
.37032 .74195 m
.36898 .7419 L
s
.36991 .74129 m
.37032 .74195 L
s
.36593 .74018 m
.37032 .74195 L
s
1 .606 0 r
.58087 .48409 m
.58242 .4841 L
s
.58232 .47841 m
.58087 .48409 L
s
.58087 .48409 m
.57899 .48065 L
s
.58575 .48186 m
.58087 .48409 L
s
.58844 .46984 m
.58087 .48409 L
s
1 .215 0 r
.55782 .65596 m
.55762 .65636 L
s
.5576 .65424 m
.55782 .65596 L
s
.55935 .65514 m
.55782 .65596 L
s
1 .134 0 r
.36898 .7419 m
.36941 .74228 L
s
.36947 .74092 m
.36898 .7419 L
s
1 .045 0 r
.77926 .71325 m
.78045 .71247 L
s
1 0 0 r
.83852 .57001 m
.83853 .57001 L
s
1 .215 0 r
.55067 .65596 m
.55935 .65514 L
s
1 .111 0 r
.38135 .45542 m
.38034 .45272 L
s
1 .014 0 r
.15276 .39813 m
.1527 .39776 L
s
1 0 0 r
.83853 .57001 m
.83853 .57001 L
s
.83853 .57001 m
.83853 .57001 L
s
.83853 .57001 m
.83853 .57001 L
s
.83853 .57001 m
.83853 .57001 L
s
.83853 .57001 m
.83853 .57001 L
s
.83853 .57001 m
.83853 .57001 L
s
.83853 .57001 m
.83853 .57001 L
s
.83853 .57001 m
.83853 .57001 L
s
1 .134 0 r
.36991 .74129 m
.36947 .74092 L
s
1 .166 0 r
.61855 .68458 m
.61814 .68496 L
s
.61809 .68331 m
.61855 .68458 L
s
.61933 .6838 m
.61855 .68458 L
s
.61768 .68369 m
.61809 .68331 L
s
.61809 .68331 m
.61933 .6838 L
s
1 .323 0 r
.36217 .36936 m
.36021 .37071 L
s
.36038 .36758 m
.36217 .36936 L
s
1 .095 0 r
.77232 .36933 m
.77291 .36972 L
s
1 .215 0 r
.55741 .65464 m
.5576 .65424 L
s
.5576 .65424 m
.55935 .65514 L
s
1 .095 0 r
.77291 .36972 m
.77343 .36925 L
s
.973 1 0 r
.42088 .36182 m
.42671 .36633 L
s
.41473 .36658 m
.42088 .36182 L
s
.42088 .36182 m
.42014 .36111 L
s
1 .65 0 r
.65985 .3406 m
.65766 .3405 L
s
.65741 .33467 m
.65985 .3406 L
s
.65985 .3406 m
.65411 .33875 L
s
.66096 .33642 m
.65985 .3406 L
s
.64818 .32544 m
.65985 .3406 L
s
1 .014 0 r
.15272 .39777 m
.1528 .39783 L
s
.15263 .39783 m
.15272 .39777 L
s
.15272 .39777 m
.1527 .39776 L
s
.1528 .39783 m
.15271 .3979 L
s
.1527 .39776 m
.1528 .39783 L
s
.15271 .3979 m
.15263 .39783 L
s
.15263 .39783 m
.1527 .39776 L
s
.1527 .39776 m
.15271 .3979 L
s
1 .323 0 r
.36021 .37071 m
.3584 .36914 L
s
.3584 .36914 m
.36038 .36758 L
s
1 .028 0 r
.83523 .39779 m
.83526 .39777 L
s
.83524 .39752 m
.83523 .39779 L
s
.83523 .39779 m
.83508 .39765 L
s
.83542 .39764 m
.83523 .39779 L
s
.83532 .39707 m
.83523 .39779 L
s
.939 1 0 r
.62308 .39011 m
.61768 .39679 L
s
.62878 .3931 m
.62308 .39011 L
s
1 .028 0 r
.83524 .39752 m
.83508 .39765 L
s
.83542 .39764 m
.83524 .39752 L
s
.83508 .39765 m
.83526 .39777 L
s
.83526 .39777 m
.83542 .39764 L
s
1 .162 0 r
.49309 .628 m
.49336 .62671 L
s
1 .045 0 r
.7802 .7124 m
.78042 .7127 L
s
.78001 .71255 m
.7802 .7124 L
s
.7802 .7124 m
.78045 .71247 L
s
.78042 .7127 m
.78023 .71285 L
s
.78045 .71247 m
.78042 .7127 L
s
1 .134 0 r
.36941 .74228 m
.36991 .74129 L
s
1 .045 0 r
.78023 .71285 m
.78001 .71255 L
s
.78001 .71255 m
.78045 .71247 L
s
.78045 .71247 m
.78023 .71285 L
s
1 .215 0 r
.55935 .65514 m
.55762 .65636 L
s
.55741 .65464 m
.55935 .65514 L
s
1 .166 0 r
.61933 .6838 m
.61814 .68496 L
s
.61768 .68369 m
.61933 .6838 L
s
.61814 .68496 m
.61768 .68369 L
s
1 0 0 r
.25929 .56906 m
.25929 .56906 L
s
.25929 .56906 m
.25929 .56906 L
s
.25929 .56906 m
.25929 .56906 L
s
.25929 .56906 m
.25929 .56906 L
s
.25928 .56905 m
.25929 .56906 L
s
.25929 .56906 m
.25929 .56906 L
s
.25929 .56906 m
.25929 .56906 L
s
.25929 .56906 m
.25929 .56906 L
s
.25929 .56906 m
.25929 .56906 L
s
1 .062 0 r
.71672 .68371 m
.71846 .68269 L
s
1 0 0 r
.77602 .54039 m
.77602 .54039 L
s
1 .068 0 r
.31858 .42573 m
.3183 .42403 L
s
1 .323 0 r
.36038 .36758 m
.36021 .37071 L
s
1 .606 0 r
.58232 .47841 m
.57899 .48065 L
s
.58575 .48186 m
.58232 .47841 L
s
.939 1 0 r
.61768 .39679 m
.62338 .3998 L
s
1 .215 0 r
.55762 .65636 m
.55741 .65464 L
s
1 .65 0 r
.65741 .33467 m
.65411 .33875 L
s
.66096 .33642 m
.65741 .33467 L
s
1 .039 0 r
.42645 .59738 m
.42621 .59744 L
s
.42622 .59707 m
.42645 .59738 L
s
.42645 .59738 m
.42606 .59735 L
s
.42636 .59716 m
.42645 .59738 L
s
.42526 .59677 m
.42645 .59738 L
s
.42622 .59707 m
.42606 .59735 L
s
.42636 .59716 m
.42622 .59707 L
s
.42606 .59735 m
.42621 .59744 L
s
0 1 .331 r
.61312 .36789 m
.61773 .37017 L
s
.6171 .34904 m
.61312 .36789 L
s
.63556 .36304 m
.61312 .36789 L
s
1 .039 0 r
.42621 .59744 m
.42636 .59716 L
s
1 .271 0 r
.47738 .74051 m
.47779 .74111 L
s
.47782 .73837 m
.47738 .74051 L
s
.47994 .74006 m
.47738 .74051 L
s
1 .058 0 r
.65002 .4824 m
.65018 .4824 L
s
.65016 .48186 m
.65002 .4824 L
s
.65002 .4824 m
.64985 .48207 L
s
.65049 .48219 m
.65002 .4824 L
s
.65079 .48104 m
.65002 .4824 L
s
1 .062 0 r
.7181 .68258 m
.71838 .68301 L
s
.71785 .68277 m
.7181 .68258 L
s
.7181 .68258 m
.71846 .68269 L
s
1 .058 0 r
.65016 .48186 m
.64985 .48207 L
s
.65049 .48219 m
.65016 .48186 L
s
1 .062 0 r
.71838 .68301 m
.71813 .6832 L
s
.71846 .68269 m
.71838 .68301 L
s
1 .063 0 r
.30482 .71168 m
.30445 .71179 L
s
.3045 .71115 m
.30482 .71168 L
s
.30482 .71168 m
.3042 .71158 L
s
.30475 .71135 m
.30482 .71168 L
s
.30308 .71062 m
.30482 .71168 L
s
1 .111 0 r
.38057 .45274 m
.38118 .45319 L
s
.37991 .45333 m
.38057 .45274 L
s
.38057 .45274 m
.38034 .45272 L
s
1 .271 0 r
.47823 .73897 m
.47782 .73837 L
s
.47782 .73837 m
.47994 .74006 L
s
1 .058 0 r
.65018 .4824 m
.65049 .48219 L
s
1 .063 0 r
.3045 .71115 m
.3042 .71158 L
s
.30475 .71135 m
.3045 .71115 L
s
1 .199 0 r
.44081 .48073 m
.44179 .48134 L
s
.43978 .482 m
.44081 .48073 L
s
.44081 .48073 m
.43997 .48081 L
s
1 .063 0 r
.3042 .71158 m
.30445 .71179 L
s
1 .65 0 r
.65411 .33875 m
.65766 .3405 L
s
1 .002 0 r
.71342 .51077 m
.71342 .51077 L
s
.71342 .51075 m
.71342 .51077 L
s
.71342 .51077 m
.71341 .51076 L
s
.71343 .51076 m
.71342 .51077 L
s
.71344 .51073 m
.71342 .51077 L
s
.71342 .51075 m
.71341 .51076 L
s
.71343 .51076 m
.71342 .51075 L
s
.71342 .51077 m
.71343 .51076 L
s
.71341 .51076 m
.71342 .51077 L
s
1 .058 0 r
.64985 .48207 m
.65018 .4824 L
s
1 .018 0 r
.88296 .7115 m
.88338 .71115 L
s
1 0 0 r
.94229 .56809 m
.94229 .56809 L
s
1 .09 0 r
.65411 .65414 m
.65693 .6528 L
s
0 1 .566 r
.48459 .45337 m
.43167 .39567 L
s
1 0 0 r
.19641 .53941 m
.19641 .53941 L
s
1 .047 0 r
.25574 .39601 m
.25565 .39481 L
s
1 0 0 r
.94229 .56809 m
.94229 .56809 L
s
.94229 .56809 m
.94229 .56809 L
s
.94229 .56809 m
.94229 .56809 L
s
.94229 .56809 m
.94229 .56809 L
s
.94229 .56809 m
.94229 .56809 L
s
.94229 .56809 m
.94229 .56809 L
s
.94229 .56809 m
.94229 .56809 L
s
.94229 .56809 m
.94229 .56809 L
s
1 .336 0 r
.67176 .39599 m
.67149 .39583 L
s
.67134 .39276 m
.67176 .39599 L
s
.67176 .39599 m
.66946 .39451 L
s
.67337 .39408 m
.67176 .39599 L
s
.67004 .38749 m
.67176 .39599 L
s
1 .111 0 r
.38052 .45378 m
.37991 .45333 L
s
.37991 .45333 m
.38034 .45272 L
s
1 .062 0 r
.71813 .6832 m
.71785 .68277 L
s
.71785 .68277 m
.71846 .68269 L
s
1 .199 0 r
.44076 .4826 m
.43978 .482 L
s
.43978 .482 m
.43997 .48081 L
s
1 .062 0 r
.71846 .68269 m
.71813 .6832 L
s
1 .068 0 r
.31837 .42406 m
.31875 .42436 L
s
.31796 .42438 m
.31837 .42406 L
s
.31837 .42406 m
.3183 .42403 L
s
1 .271 0 r
.47994 .74006 m
.47779 .74111 L
s
.47823 .73897 m
.47994 .74006 L
s
.46927 .73845 m
.47994 .74006 L
s
1 .063 0 r
.30445 .71179 m
.30475 .71135 L
s
1 .111 0 r
.38118 .45319 m
.38052 .45378 L
s
.38034 .45272 m
.38118 .45319 L
s
1 .606 0 r
.58242 .4841 m
.58575 .48186 L
s
1 .018 0 r
.88328 .71112 m
.88338 .71124 L
s
.8832 .71119 m
.88328 .71112 L
s
.88328 .71112 m
.88338 .71115 L
s
.88338 .71124 m
.8833 .71131 L
s
.88338 .71115 m
.88338 .71124 L
s
1 .068 0 r
.31833 .42468 m
.31796 .42438 L
s
.31796 .42438 m
.3183 .42403 L
s
.31875 .42436 m
.31833 .42468 L
s
.3183 .42403 m
.31875 .42436 L
s
1 .018 0 r
.8833 .71131 m
.8832 .71119 L
s
.8832 .71119 m
.88338 .71115 L
s
.88338 .71115 m
.8833 .71131 L
s
1 .111 0 r
.38034 .45272 m
.38052 .45378 L
s
1 .068 0 r
.3183 .42403 m
.31833 .42468 L
s
1 .172 0 r
.41061 .71096 m
.41113 .7114 L
s
.41118 .70967 m
.41061 .71096 L
s
.41234 .71096 m
.41061 .71096 L
s
.41234 .71096 m
.41113 .7114 L
s
.41118 .70967 m
.41234 .71096 L
s
.4117 .71011 m
.41234 .71096 L
s
.40641 .70886 m
.41234 .71096 L
s
.4117 .71011 m
.41118 .70967 L
s
.973 1 0 r
.42056 .37111 m
.41473 .36658 L
s
.41473 .36658 m
.42014 .36111 L
s
1 .199 0 r
.44179 .48134 m
.44076 .4826 L
s
.43997 .48081 m
.44179 .48134 L
s
1 .336 0 r
.67134 .39276 m
.66946 .39451 L
s
.67337 .39408 m
.67134 .39276 L
s
1 .047 0 r
.25569 .39484 m
.25594 .39506 L
s
.25539 .39504 m
.25569 .39484 L
s
.25569 .39484 m
.25565 .39481 L
s
1 .199 0 r
.43997 .48081 m
.44076 .4826 L
s
1 .047 0 r
.25594 .39506 m
.25565 .39527 L
s
.25565 .39481 m
.25594 .39506 L
s
.25565 .39527 m
.25539 .39504 L
s
.25539 .39504 m
.25565 .39481 L
s
.973 1 0 r
.42671 .36633 m
.42056 .37111 L
s
.42014 .36111 m
.42671 .36633 L
s
1 .09 0 r
.6567 .65328 m
.65638 .65351 L
s
.65635 .65263 m
.6567 .65328 L
s
.65693 .6528 m
.6567 .65328 L
s
.65603 .65286 m
.65635 .65263 L
s
.65635 .65263 m
.65693 .6528 L
s
1 .002 0 r
.36249 .56718 m
.36248 .56718 L
s
.36248 .56716 m
.36249 .56718 L
s
.36249 .56718 m
.36247 .56717 L
s
.36249 .56716 m
.36249 .56718 L
s
.36244 .56713 m
.36249 .56718 L
s
.36248 .56716 m
.36247 .56717 L
s
.36249 .56716 m
.36248 .56716 L
s
.36247 .56717 m
.36248 .56718 L
s
.36248 .56718 m
.36249 .56716 L
s
1 0 0 r
.87978 .53843 m
.87978 .53843 L
s
1 .022 0 r
.82041 .68192 m
.8209 .68151 L
s
1 .133 0 r
.59143 .62453 m
.59627 .62311 L
s
1 .59 0 r
.42181 .42365 m
.42015 .40866 L
s
1 .035 0 r
.19283 .36625 m
.19279 .36534 L
s
1 .047 0 r
.25565 .39481 m
.25565 .39527 L
s
1 .08 0 r
.81421 .33744 m
.81419 .33739 L
s
.81413 .33667 m
.81421 .33744 L
s
.81421 .33744 m
.81369 .33708 L
s
.81463 .33697 m
.81421 .33744 L
s
.81396 .33536 m
.81421 .33744 L
s
1 .271 0 r
.47779 .74111 m
.47823 .73897 L
s
1 .08 0 r
.81413 .33667 m
.81369 .33708 L
s
.81463 .33697 m
.81413 .33667 L
s
0 1 .331 r
.62174 .35117 m
.6171 .34904 L
s
.6171 .34904 m
.63556 .36304 L
s
1 .029 0 r
.87655 .36592 m
.87658 .3659 L
s
.87655 .36564 m
.87655 .36592 L
s
.87655 .36592 m
.87639 .36578 L
s
.87673 .36576 m
.87655 .36592 L
s
.87659 .36517 m
.87655 .36592 L
s
1 .022 0 r
.8208 .68148 m
.82091 .68162 L
s
.8207 .68156 m
.8208 .68148 L
s
.8208 .68148 m
.8209 .68151 L
s
.82091 .68162 m
.82082 .6817 L
s
.8209 .68151 m
.82091 .68162 L
s
1 .029 0 r
.87655 .36564 m
.87639 .36578 L
s
.87673 .36576 m
.87655 .36564 L
s
1 .606 0 r
.57899 .48065 m
.58242 .4841 L
s
1 .09 0 r
.65638 .65351 m
.65603 .65286 L
s
.65693 .6528 m
.65638 .65351 L
s
.65603 .65286 m
.65693 .6528 L
s
1 .022 0 r
.82082 .6817 m
.8207 .68156 L
s
.8207 .68156 m
.8209 .68151 L
s
1 .336 0 r
.66946 .39451 m
.67149 .39583 L
s
1 .022 0 r
.8209 .68151 m
.82082 .6817 L
s
1 .08 0 r
.81369 .33708 m
.81419 .33739 L
s
1 .029 0 r
.87639 .36578 m
.87658 .3659 L
s
.87658 .3659 m
.87673 .36576 L
s
1 .024 0 r
.24071 .68149 m
.24059 .68152 L
s
.24061 .68127 m
.24071 .68149 L
s
.24071 .68149 m
.24048 .68143 L
s
.24072 .68136 m
.24071 .68149 L
s
.24015 .68103 m
.24071 .68149 L
s
.24061 .68127 m
.24048 .68143 L
s
.24072 .68136 m
.24061 .68127 L
s
1 .08 0 r
.81419 .33739 m
.81463 .33697 L
s
1 .172 0 r
.41113 .7114 m
.4117 .71011 L
s
1 .024 0 r
.24048 .68143 m
.24059 .68152 L
s
1 .035 0 r
.19282 .36537 m
.19301 .36554 L
s
.1926 .36551 m
.19282 .36537 L
s
.19282 .36537 m
.19279 .36534 L
s
1 .136 0 r
.53313 .59524 m
.53311 .59546 L
s
.53311 .59414 m
.53313 .59524 L
s
.53422 .59478 m
.53313 .59524 L
s
1 .024 0 r
.24059 .68152 m
.24072 .68136 L
s
1 .035 0 r
.19301 .36554 m
.19278 .36568 L
s
.19279 .36534 m
.19301 .36554 L
s
.19278 .36568 m
.1926 .36551 L
s
.1926 .36551 m
.19279 .36534 L
s
1 .136 0 r
.53308 .59436 m
.53311 .59414 L
s
.53311 .59414 m
.53422 .59478 L
s
1 .035 0 r
.19279 .36534 m
.19278 .36568 L
s
1 .336 0 r
.67149 .39583 m
.67337 .39408 L
s
1 .133 0 r
.59565 .62377 m
.59531 .62404 L
s
.59529 .62274 m
.59565 .62377 L
s
.59627 .62311 m
.59565 .62377 L
s
.59495 .62302 m
.59529 .62274 L
s
.59529 .62274 m
.59627 .62311 L
s
1 0 0 r
.81718 .50875 m
.81718 .50875 L
s
.81718 .50875 m
.81718 .50875 L
s
.81718 .50875 m
.81718 .50875 L
s
.81719 .50875 m
.81718 .50875 L
s
.81719 .50874 m
.81718 .50875 L
s
.81718 .50875 m
.81718 .50875 L
s
.81719 .50875 m
.81718 .50875 L
s
.81718 .50875 m
.81719 .50875 L
s
.81718 .50875 m
.81718 .50875 L
s
1 .026 0 r
.75779 .65231 m
.7584 .65182 L
s
1 .136 0 r
.52867 .59488 m
.53422 .59478 L
s
1 0 0 r
.29955 .53746 m
.29955 .53746 L
s
1 .229 0 r
.35895 .39389 m
.35928 .38803 L
s
1 .028 0 r
.12984 .33646 m
.12983 .33573 L
s
1 .65 0 r
.65766 .3405 m
.66096 .33642 L
s
1 .136 0 r
.53422 .59478 m
.53311 .59546 L
s
.53308 .59436 m
.53422 .59478 L
s
1 .07 0 r
.69137 .45099 m
.69147 .45097 L
s
.69143 .45031 m
.69137 .45099 L
s
.69137 .45099 m
.69104 .45062 L
s
.69186 .45066 m
.69137 .45099 L
s
.69179 .44925 m
.69137 .45099 L
s
1 .026 0 r
.75827 .65179 m
.7584 .65196 L
s
.75815 .65187 m
.75827 .65179 L
s
.75827 .65179 m
.7584 .65182 L
s
0 .813 1 r
.54671 .65196 m
.53439 .65542 L
s
.5343 .62375 m
.54671 .65196 L
s
.54671 .65196 m
.51784 .64435 L
s
.55095 .63464 m
.54671 .65196 L
s
.48288 .5877 m
.54671 .65196 L
s
1 .026 0 r
.7584 .65196 m
.75829 .65205 L
s
.7584 .65182 m
.7584 .65196 L
s
1 .136 0 r
.53311 .59546 m
.53308 .59436 L
s
1 .028 0 r
.12985 .33575 m
.12999 .33589 L
s
.12967 .33586 m
.12985 .33575 L
s
.12985 .33575 m
.12983 .33573 L
s
1 .07 0 r
.69143 .45031 m
.69104 .45062 L
s
.69186 .45066 m
.69143 .45031 L
s
1 .026 0 r
.75829 .65205 m
.75815 .65187 L
s
.75815 .65187 m
.7584 .65182 L
s
.7584 .65182 m
.75829 .65205 L
s
1 .028 0 r
.12999 .33589 m
.12981 .336 L
s
.12983 .33573 m
.12999 .33589 L
s
1 .133 0 r
.59627 .62311 m
.59531 .62404 L
s
.59495 .62302 m
.59627 .62311 L
s
0 1 .511 r
.6228 .35408 m
.6271 .33373 L
s
1 .028 0 r
.12981 .336 m
.12967 .33586 L
s
.12967 .33586 m
.12983 .33573 L
s
1 .133 0 r
.59531 .62404 m
.59495 .62302 L
s
.425 1 0 r
.59674 .47943 m
.59101 .48006 L
s
.5907 .46524 m
.59674 .47943 L
s
.59674 .47943 m
.58263 .47527 L
s
.5991 .46999 m
.59674 .47943 L
s
.56683 .44491 m
.59674 .47943 L
s
1 .028 0 r
.12983 .33573 m
.12981 .336 L
s
1 .075 0 r
.34557 .68047 m
.34513 .6806 L
s
.34517 .67985 m
.34557 .68047 L
s
.34557 .68047 m
.34483 .68037 L
s
.34547 .68008 m
.34557 .68047 L
s
.34347 .67923 m
.34557 .68047 L
s
1 .07 0 r
.69147 .45097 m
.69186 .45066 L
s
.69104 .45062 m
.69147 .45097 L
s
1 .075 0 r
.34517 .67985 m
.34483 .68037 L
s
.34547 .68008 m
.34517 .67985 L
s
1 .021 0 r
.46634 .56548 m
.4664 .56553 L
s
.46641 .56533 m
.46634 .56548 L
s
.46655 .56548 m
.46634 .56548 L
s
.46655 .56548 m
.4664 .56553 L
s
.46641 .56533 m
.46655 .56548 L
s
.46647 .56537 m
.46655 .56548 L
s
.46584 .56521 m
.46655 .56548 L
s
.46647 .56537 m
.46641 .56533 L
s
1 .075 0 r
.34483 .68037 m
.34513 .6806 L
s
.939 1 0 r
.62338 .3998 m
.62878 .3931 L
s
1 .021 0 r
.4664 .56553 m
.46647 .56537 L
s
1 .007 0 r
.75446 .47918 m
.75448 .47918 L
s
.75447 .47911 m
.75446 .47918 L
s
.75446 .47918 m
.75444 .47914 L
s
.75451 .47915 m
.75446 .47918 L
s
.75452 .47901 m
.75446 .47918 L
s
.75447 .47911 m
.75444 .47914 L
s
.75451 .47915 m
.75447 .47911 L
s
.75448 .47918 m
.75451 .47915 L
s
.75444 .47914 m
.75448 .47918 L
s
1 .009 0 r
.92434 .68013 m
.92451 .67995 L
s
1 .032 0 r
.69509 .62267 m
.6959 .62208 L
s
1 0 0 r
.01 w
.52528 .42155 Mdot
.5 Mabswid
.23659 .50775 m
.23659 .50774 L
s
1 .121 0 r
.29603 .36409 m
.29637 .36096 L
s
1 0 0 r
.23659 .50774 m
.23659 .50774 L
s
.23659 .50774 m
.23659 .50774 L
s
.23659 .50774 m
.23659 .50774 L
s
.23659 .50774 m
.23659 .50774 L
s
.23659 .50774 m
.23659 .50774 L
s
.23659 .50774 m
.23659 .50774 L
s
.23659 .50774 m
.23659 .50774 L
s
.23659 .50774 m
.23659 .50774 L
s
1 .075 0 r
.34513 .6806 m
.34547 .68008 L
s
1 .009 0 r
.92447 .67995 m
.92452 .68 L
s
.92443 .67998 m
.92447 .67995 L
s
.92447 .67995 m
.92451 .67995 L
s
.92452 .68 m
.92448 .68003 L
s
.92451 .67995 m
.92452 .68 L
s
.92448 .68003 m
.92443 .67998 L
s
.92443 .67998 m
.92451 .67995 L
s
.92451 .67995 m
.92448 .68003 L
s
1 .229 0 r
.45315 .67991 m
.45372 .68043 L
s
.45377 .67815 m
.45315 .67991 L
s
.45542 .67975 m
.45315 .67991 L
s
1 .323 0 r
.52037 .70858 m
.52054 .70923 L
s
.52054 .70597 m
.52037 .70858 L
s
.52318 .70773 m
.52037 .70858 L
s
1 .229 0 r
.45434 .67866 m
.45377 .67815 L
s
.45377 .67815 m
.45542 .67975 L
s
.973 1 0 r
.42014 .36111 m
.42056 .37111 L
s
1 .229 0 r
.45542 .67975 m
.45372 .68043 L
s
.45434 .67866 m
.45542 .67975 L
s
.44703 .67743 m
.45542 .67975 L
s
1 .032 0 r
.69573 .62204 m
.69589 .62226 L
s
.69559 .62214 m
.69573 .62204 L
s
.69573 .62204 m
.6959 .62208 L
s
.69589 .62226 m
.69575 .62235 L
s
.6959 .62208 m
.69589 .62226 L
s
.69575 .62235 m
.69559 .62214 L
s
.69559 .62214 m
.6959 .62208 L
s
.6959 .62208 m
.69575 .62235 L
s
1 .323 0 r
.52071 .70662 m
.52054 .70597 L
s
.52054 .70597 m
.52318 .70773 L
s
0 1 .331 r
.63556 .36304 m
.61773 .37017 L
s
.62174 .35117 m
.63556 .36304 L
s
.54414 .34555 m
.63556 .36304 L
s
1 0 0 r
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
.92117 .50675 m
.92117 .50675 L
s
1 .009 0 r
.8617 .65048 m
.86187 .65031 L
s
1 .293 0 r
.57285 .73673 m
.58454 .7352 L
s
1 .039 0 r
.63232 .59299 m
.63345 .59234 L
s
1 0 0 r
.40294 .5355 m
.40294 .5355 L
s
0 1 .077 r
.46241 .39176 m
.48556 .33915 L
s
1 .001 0 r
.17356 .478 m
.17355 .47797 L
s
1 .077 0 r
.23303 .33426 m
.23328 .33226 L
s
1 .001 0 r
.17355 .47797 m
.17356 .47798 L
s
.17354 .47798 m
.17355 .47797 L
s
.17355 .47797 m
.17355 .47797 L
s
.17355 .47798 m
.17354 .47798 L
s
.17354 .47798 m
.17355 .47797 L
s
.17356 .47798 m
.17355 .47798 L
s
.17355 .47797 m
.17356 .47798 L
s
.17355 .47797 m
.17355 .47798 L
s
1 .398 0 r
.53589 .5073 m
.53699 .50662 L
s
.53699 .50662 m
.53588 .50352 L
s
.53699 .50662 m
.53301 .50633 L
s
1 .009 0 r
.86183 .6503 m
.86188 .65035 L
s
.86179 .65033 m
.86183 .6503 L
s
.86183 .6503 m
.86187 .65031 L
s
.86188 .65035 m
.86184 .65038 L
s
.86187 .65031 m
.86188 .65035 L
s
.86184 .65038 m
.86179 .65033 L
s
.86179 .65033 m
.86187 .65031 L
s
.86187 .65031 m
.86184 .65038 L
s
1 .323 0 r
.52318 .70773 m
.52054 .70923 L
s
.52071 .70662 m
.52318 .70773 L
s
.50997 .7071 m
.52318 .70773 L
s
1 .398 0 r
.53588 .50352 m
.53478 .5042 L
s
.53588 .50352 m
.53301 .50633 L
s
0 .434 1 r
.55411 .6789 m
.5404 .68317 L
s
.54024 .6474 m
.55411 .6789 L
s
.55411 .6789 m
.52181 .67052 L
s
.55896 .65982 m
.55411 .6789 L
s
.48262 .60782 m
.55411 .6789 L
s
1 .398 0 r
.53301 .50633 m
.53589 .5073 L
s
.53301 .50633 m
.53478 .5042 L
s
.54743 .50174 m
.53301 .50633 L
s
1 .293 0 r
.58259 .73636 m
.58222 .737 L
s
.58217 .73402 m
.58259 .73636 L
s
.58454 .7352 m
.58259 .73636 L
s
1 .039 0 r
.63321 .59229 m
.63338 .59256 L
s
.63306 .59239 m
.63321 .59229 L
s
.63321 .59229 m
.63345 .59234 L
s
.63338 .59256 m
.63323 .59266 L
s
.63345 .59234 m
.63338 .59256 L
s
1 .023 0 r
.28099 .65003 m
.28088 .65005 L
s
.28089 .64982 m
.28099 .65003 L
s
.28099 .65003 m
.28077 .64997 L
s
.281 .6499 m
.28099 .65003 L
s
.28046 .64957 m
.28099 .65003 L
s
1 .229 0 r
.45372 .68043 m
.45434 .67866 L
s
1 .023 0 r
.28089 .64982 m
.28077 .64997 L
s
.281 .6499 m
.28089 .64982 L
s
.28077 .64997 m
.28088 .65005 L
s
1 .039 0 r
.63323 .59266 m
.63306 .59239 L
s
.63306 .59239 m
.63345 .59234 L
s
1 .023 0 r
.28088 .65005 m
.281 .6499 L
s
1 .039 0 r
.63345 .59234 m
.63323 .59266 L
s
1 .293 0 r
.5818 .73466 m
.58217 .73402 L
s
.58217 .73402 m
.58454 .7352 L
s
1 .825 0 r
.42069 .38488 m
.4254 .38855 L
s
.41574 .38875 m
.42069 .38488 L
s
.42069 .38488 m
.4201 .38439 L
s
1 .002 0 r
.85848 .47702 m
.85849 .47702 L
s
.85849 .47701 m
.85848 .47702 L
s
.85848 .47702 m
.85848 .47702 L
s
.8585 .47702 m
.85848 .47702 L
s
.8585 .47699 m
.85848 .47702 L
s
.85849 .47701 m
.85848 .47702 L
s
.8585 .47702 m
.85849 .47701 L
s
.85849 .47702 m
.8585 .47702 L
s
.85848 .47702 m
.85849 .47702 L
s
1 .008 0 r
.79899 .62081 m
.79915 .62063 L
s
1 .032 0 r
.56948 .56328 m
.57063 .56292 L
s
1 .002 0 r
.33996 .50575 m
.33994 .50571 L
s
1 .607 0 r
.39947 .36193 m
.40559 .34661 L
s
1 .121 0 r
.29634 .36104 m
.29701 .36165 L
s
.29559 .36152 m
.29634 .36104 L
s
.29634 .36104 m
.29637 .36096 L
s
1 .002 0 r
.33995 .50571 m
.33996 .50571 L
s
.33993 .50572 m
.33995 .50571 L
s
.33995 .50571 m
.33994 .50571 L
s
.33994 .50572 m
.33993 .50572 L
s
.33993 .50572 m
.33994 .50571 L
s
.33996 .50571 m
.33994 .50572 L
s
.33994 .50571 m
.33996 .50571 L
s
.33994 .50571 m
.33994 .50572 L
s
1 .008 0 r
.79912 .62063 m
.79916 .62068 L
s
.79908 .62066 m
.79912 .62063 L
s
.79912 .62063 m
.79915 .62063 L
s
.79916 .62068 m
.79913 .62071 L
s
.79915 .62063 m
.79916 .62068 L
s
.79913 .62071 m
.79908 .62066 L
s
.79908 .62066 m
.79915 .62063 L
s
.79915 .62063 m
.79913 .62071 L
s
1 .032 0 r
.57049 .56309 m
.57041 .56315 L
s
.5704 .56284 m
.57049 .56309 L
s
.57063 .56292 m
.57049 .56309 L
s
.57032 .5629 m
.5704 .56284 L
s
.5704 .56284 m
.57063 .56292 L
s
1 .323 0 r
.52054 .70923 m
.52071 .70662 L
s
1 .121 0 r
.29701 .36165 m
.29626 .36214 L
s
.29637 .36096 m
.29701 .36165 L
s
1 .077 0 r
.23326 .33232 m
.23368 .33271 L
s
.23278 .33261 m
.23326 .33232 L
s
.23326 .33232 m
.23328 .33226 L
s
.425 1 0 r
.5907 .46524 m
.58263 .47527 L
s
.5991 .46999 m
.5907 .46524 L
s
1 .032 0 r
.57063 .56292 m
.57041 .56315 L
s
.57032 .5629 m
.57063 .56292 L
s
1 .068 0 r
.73282 .41907 m
.73287 .41904 L
s
.73282 .41842 m
.73282 .41907 L
s
.73282 .41907 m
.73245 .41874 L
s
.73324 .41872 m
.73282 .41907 L
s
.73293 .41736 m
.73282 .41907 L
s
1 .032 0 r
.57041 .56315 m
.57032 .5629 L
s
1 .121 0 r
.29626 .36214 m
.29559 .36152 L
s
.29559 .36152 m
.29637 .36096 L
s
1 .09 0 r
.38662 .6492 m
.38608 .64935 L
s
.38612 .64846 m
.38662 .6492 L
s
.38662 .6492 m
.38573 .6491 L
s
.38647 .64872 m
.38662 .6492 L
s
.384 .64773 m
.38662 .6492 L
s
1 .077 0 r
.23368 .33271 m
.23319 .33301 L
s
.23328 .33226 m
.23368 .33271 L
s
1 .09 0 r
.38612 .64846 m
.38573 .6491 L
s
.38647 .64872 m
.38612 .64846 L
s
1 .077 0 r
.23319 .33301 m
.23278 .33261 L
s
.23278 .33261 m
.23328 .33226 L
s
1 .09 0 r
.38573 .6491 m
.38608 .64935 L
s
1 .068 0 r
.73282 .41842 m
.73245 .41874 L
s
.73324 .41872 m
.73282 .41842 L
s
0 1 .566 r
.5346 .62027 m
.52457 .62274 L
s
.52457 .59746 m
.5346 .62027 L
s
.5346 .62027 m
.51129 .61402 L
s
.53791 .60606 m
.5346 .62027 L
s
.48313 .56782 m
.5346 .62027 L
s
1 .121 0 r
.29637 .36096 m
.29626 .36214 L
s
1 .077 0 r
.23328 .33226 m
.23319 .33301 L
s
1 .068 0 r
.73245 .41874 m
.73287 .41904 L
s
.73287 .41904 m
.73324 .41872 L
s
1 .012 0 r
.79568 .44748 m
.7957 .44748 L
s
.79569 .44737 m
.79568 .44748 L
s
.79568 .44748 m
.79563 .44742 L
s
.79577 .44743 m
.79568 .44748 L
s
.79575 .44719 m
.79568 .44748 L
s
.79569 .44737 m
.79563 .44742 L
s
.79577 .44743 m
.79569 .44737 L
s
1 .293 0 r
.58454 .7352 m
.58222 .737 L
s
.5818 .73466 m
.58454 .7352 L
s
1 .012 0 r
.7957 .44748 m
.79577 .44743 L
s
.79563 .44742 m
.7957 .44748 L
s
1 .229 0 r
.35927 .38816 m
.36056 .38928 L
s
.35788 .38913 m
.35927 .38816 L
s
.35927 .38816 m
.35928 .38803 L
s
1 .22 0 r
.71293 .361 m
.71265 .36088 L
s
.71253 .35889 m
.71293 .361 L
s
.71293 .361 m
.71132 .36009 L
s
.71386 .35968 m
.71293 .361 L
s
.71123 .35541 m
.71293 .361 L
s
1 .006 0 r
.21748 .61999 m
.21746 .61999 L
s
.21746 .61994 m
.21748 .61999 L
s
.21748 .61999 m
.21743 .61997 L
s
.21749 .61996 m
.21748 .61999 L
s
.21738 .61987 m
.21748 .61999 L
s
.21746 .61994 m
.21743 .61997 L
s
.21749 .61996 m
.21746 .61994 L
s
.21743 .61997 m
.21746 .61999 L
s
.21746 .61999 m
.21749 .61996 L
s
1 .09 0 r
.38608 .64935 m
.38647 .64872 L
s
1 .003 0 r
.96586 .64865 m
.96592 .64858 L
s
1 .158 0 r
.67667 .73499 m
.68189 .73287 L
s
1 .007 0 r
.73621 .59109 m
.73634 .59095 L
s
1 0 0 r
.50656 .53353 m
.50656 .53353 L
s
1 .005 0 r
.27692 .47597 m
.27687 .47585 L
s
1 .271 0 r
.33645 .33207 m
.33894 .32515 L
s
1 .003 0 r
.96591 .64858 m
.96593 .6486 L
s
.96589 .64859 m
.96591 .64858 L
s
.96591 .64858 m
.96592 .64858 L
s
.96593 .6486 m
.96591 .64861 L
s
.96592 .64858 m
.96593 .6486 L
s
.96591 .64861 m
.96589 .64859 L
s
.96589 .64859 m
.96592 .64858 L
s
.96592 .64858 m
.96591 .64861 L
s
1 .005 0 r
.27689 .47585 m
.27691 .47587 L
s
.27685 .47587 m
.27689 .47585 L
s
.27689 .47585 m
.27687 .47585 L
s
.27688 .47589 m
.27685 .47587 L
s
.27685 .47587 m
.27687 .47585 L
s
.27691 .47587 m
.27688 .47589 L
s
.27687 .47585 m
.27691 .47587 L
s
1 .007 0 r
.73632 .59095 m
.73635 .59099 L
s
.73628 .59097 m
.73632 .59095 L
s
.73632 .59095 m
.73634 .59095 L
s
.73635 .59099 m
.73632 .59101 L
s
.73634 .59095 m
.73635 .59099 L
s
1 .005 0 r
.27687 .47585 m
.27688 .47589 L
s
1 .007 0 r
.73632 .59101 m
.73628 .59097 L
s
.73628 .59097 m
.73634 .59095 L
s
.73634 .59095 m
.73632 .59101 L
s
1 .293 0 r
.58222 .737 m
.5818 .73466 L
s
1 .229 0 r
.36056 .38928 m
.35916 .39025 L
s
.35928 .38803 m
.36056 .38928 L
s
1 .22 0 r
.71253 .35889 m
.71132 .36009 L
s
.71386 .35968 m
.71253 .35889 L
s
1 .303 0 r
.49688 .64835 m
.49736 .64893 L
s
.49738 .64593 m
.49688 .64835 L
s
.49976 .64781 m
.49688 .64835 L
s
1 .398 0 r
.53478 .5042 m
.53589 .5073 L
s
.808 1 0 r
.61289 .33158 m
.61724 .33323 L
s
.61692 .32252 m
.61289 .33158 L
s
.62492 .33151 m
.61289 .33158 L
s
1 .229 0 r
.35916 .39025 m
.35788 .38913 L
s
.35788 .38913 m
.35928 .38803 L
s
.808 1 0 r
.62492 .33151 m
.61724 .33323 L
s
.61692 .32252 m
.62492 .33151 L
s
.62129 .32414 m
.62492 .33151 L
s
.58541 .31317 m
.62492 .33151 L
s
1 .303 0 r
.49786 .64651 m
.49738 .64593 L
s
.49738 .64593 m
.49976 .64781 L
s
.425 1 0 r
.58263 .47527 m
.59101 .48006 L
s
1 .344 0 r
.62955 .44647 m
.62961 .44635 L
s
.6295 .44314 m
.62955 .44647 L
s
.62955 .44647 m
.62753 .44479 L
s
.63158 .44471 m
.62955 .44647 L
s
.62959 .43783 m
.62955 .44647 L
s
1 .22 0 r
.71132 .36009 m
.71265 .36088 L
s
.808 1 0 r
.62129 .32414 m
.61692 .32252 L
s
1 .825 0 r
.42044 .39243 m
.41574 .38875 L
s
.41574 .38875 m
.4201 .38439 L
s
1 .741 0 r
.40627 .32576 m
.41036 .32988 L
s
.40192 .32828 m
.40627 .32576 L
s
.40627 .32576 m
.40764 .32529 L
s
1 .303 0 r
.49976 .64781 m
.49736 .64893 L
s
.49786 .64651 m
.49976 .64781 L
s
.48779 .6459 m
.49976 .64781 L
s
1 .229 0 r
.35928 .38803 m
.35916 .39025 L
s
1 .003 0 r
.90314 .61894 m
.90318 .61888 L
s
1 .241 0 r
.61378 .70533 m
.62263 .70288 L
s
1 .003 0 r
.67336 .56134 m
.67342 .56128 L
s
1 .032 0 r
.44358 .50375 m
.44292 .50307 L
s
0 .197 1 r
.50315 .35976 m
.64347 .3111 L
s
1 .007 0 r
.2138 .44615 m
.21376 .44598 L
s
1 .825 0 r
.4254 .38855 m
.42044 .39243 L
s
.4201 .38439 m
.4254 .38855 L
s
1 .003 0 r
.90317 .61888 m
.90319 .61889 L
s
.90316 .61889 m
.90317 .61888 L
s
.90317 .61888 m
.90318 .61888 L
s
.67341 .56127 m
.67343 .56129 L
s
.67339 .56128 m
.67341 .56127 L
s
.67341 .56127 m
.67342 .56128 L
s
.90319 .61889 m
.90318 .6189 L
s
.90318 .61888 m
.90319 .61889 L
s
.67343 .56129 m
.67341 .56131 L
s
.67342 .56128 m
.67343 .56129 L
s
.90318 .6189 m
.90316 .61889 L
s
.90316 .61889 m
.90318 .61888 L
s
.90318 .61888 m
.90318 .6189 L
s
.67341 .56131 m
.67339 .56128 L
s
.67339 .56128 m
.67342 .56128 L
s
.67342 .56128 m
.67341 .56131 L
s
1 .22 0 r
.71265 .36088 m
.71386 .35968 L
s
1 .007 0 r
.21377 .44598 m
.2138 .44601 L
s
.21372 .44602 m
.21377 .44598 L
s
.21377 .44598 m
.21376 .44598 L
s
.21376 .44605 m
.21372 .44602 L
s
.21372 .44602 m
.21376 .44598 L
s
.2138 .44601 m
.21376 .44605 L
s
.21376 .44598 m
.2138 .44601 L
s
.21376 .44598 m
.21376 .44605 L
s
1 .032 0 r
.44306 .50306 m
.44321 .50316 L
s
.44289 .50326 m
.44306 .50306 L
s
.44306 .50306 m
.44292 .50307 L
s
1 .344 0 r
.6295 .44314 m
.62753 .44479 L
s
.63158 .44471 m
.6295 .44314 L
s
1 .032 0 r
.44305 .50336 m
.44289 .50326 L
s
.44289 .50326 m
.44292 .50307 L
s
1 .158 0 r
.6814 .73366 m
.68088 .7341 L
s
.68081 .73249 m
.6814 .73366 L
s
.68189 .73287 m
.6814 .73366 L
s
1 .021 0 r
.32137 .61842 m
.32127 .61844 L
s
.32129 .61823 m
.32137 .61842 L
s
.32137 .61842 m
.32118 .61837 L
s
.32139 .61831 m
.32137 .61842 L
s
.32091 .618 m
.32137 .61842 L
s
1 .158 0 r
.68029 .73293 m
.68081 .73249 L
s
.68081 .73249 m
.68189 .73287 L
s
1 .021 0 r
.32129 .61823 m
.32118 .61837 L
s
.32139 .61831 m
.32129 .61823 L
s
1 .032 0 r
.44321 .50316 m
.44305 .50336 L
s
.44292 .50307 m
.44321 .50316 L
s
1 .021 0 r
.32118 .61837 m
.32127 .61844 L
s
1 .032 0 r
.44292 .50307 m
.44305 .50336 L
s
1 .021 0 r
.32127 .61844 m
.32139 .61831 L
s
0 .813 1 r
.5343 .62375 m
.51784 .64435 L
s
.55095 .63464 m
.5343 .62375 L
s
1 .003 0 r
.89993 .4452 m
.89994 .4452 L
s
.89993 .44517 m
.89993 .4452 L
s
.89993 .4452 m
.89991 .44518 L
s
.89995 .44519 m
.89993 .4452 L
s
.89995 .44512 m
.89993 .4452 L
s
.89993 .44517 m
.89991 .44518 L
s
.89995 .44519 m
.89993 .44517 L
s
.89994 .4452 m
.89995 .44519 L
s
.89991 .44518 m
.89994 .4452 L
s
1 .741 0 r
.41036 .32988 m
.40601 .33241 L
s
.40764 .32529 m
.41036 .32988 L
s
1 .336 0 r
.56204 .67564 m
.56174 .67629 L
s
.5617 .67293 m
.56204 .67564 L
s
.56445 .67436 m
.56204 .67564 L
s
1 .066 0 r
.78074 .73326 m
.78248 .73213 L
s
1 .002 0 r
.84034 .58919 m
.84037 .58915 L
s
1 .336 0 r
.55082 .67563 m
.56445 .67436 L
s
1 0 0 r
.61043 .53156 m
.61043 .53156 L
s
1 .039 0 r
.38052 .47393 m
.38016 .473 L
s
.808 1 0 r
.44012 .32986 m
.46742 .30351 L
s
1 .008 0 r
.1506 .4163 m
.15057 .41611 L
s
1 .002 0 r
.84036 .58915 m
.84038 .58916 L
s
.84036 .58916 m
.84036 .58915 L
s
.84036 .58915 m
.84037 .58915 L
s
.84038 .58916 m
.84037 .58917 L
s
.84037 .58915 m
.84038 .58916 L
s
.84037 .58917 m
.84036 .58916 L
s
.84036 .58916 m
.84037 .58915 L
s
.84037 .58915 m
.84037 .58917 L
s
1 .303 0 r
.49736 .64893 m
.49786 .64651 L
s
1 .008 0 r
.15058 .41611 m
.15062 .41615 L
s
.15053 .41615 m
.15058 .41611 L
s
.15058 .41611 m
.15057 .41611 L
s
.15062 .41615 m
.15057 .41618 L
s
.15057 .41611 m
.15062 .41615 L
s
.15057 .41618 m
.15053 .41615 L
s
.15053 .41615 m
.15057 .41611 L
s
.15057 .41611 m
.15057 .41618 L
s
1 .111 0 r
.42811 .61784 m
.42741 .61804 L
s
.42744 .61695 m
.42811 .61784 L
s
.42811 .61784 m
.427 .61776 L
s
.42785 .61724 m
.42811 .61784 L
s
.42468 .61613 m
.42811 .61784 L
s
.42744 .61695 m
.427 .61776 L
s
.42785 .61724 m
.42744 .61695 L
s
.427 .61776 m
.42741 .61804 L
s
1 .336 0 r
.5614 .67358 m
.5617 .67293 L
s
.5617 .67293 m
.56445 .67436 L
s
1 .344 0 r
.62753 .44479 m
.62961 .44635 L
s
1 .158 0 r
.68088 .7341 m
.68029 .73293 L
s
.68189 .73287 m
.68088 .7341 L
s
.68029 .73293 m
.68189 .73287 L
s
1 .344 0 r
.62961 .44635 m
.63158 .44471 L
s
1 .241 0 r
.62149 .70402 m
.62089 .70458 L
s
.62082 .70216 m
.62149 .70402 L
s
.62263 .70288 m
.62149 .70402 L
s
1 .062 0 r
.77429 .38693 m
.7743 .3869 L
s
.77425 .38633 m
.77429 .38693 L
s
.77429 .38693 m
.77391 .38664 L
s
.77464 .38659 m
.77429 .38693 L
s
.77421 .38535 m
.77429 .38693 L
s
1 .241 0 r
.62022 .70272 m
.62082 .70216 L
s
.62082 .70216 m
.62263 .70288 L
s
1 .015 0 r
.83707 .41564 m
.83709 .41564 L
s
.83707 .41549 m
.83707 .41564 L
s
.83707 .41564 m
.83699 .41557 L
s
.83717 .41556 m
.83707 .41564 L
s
.83712 .41525 m
.83707 .41564 L
s
1 .039 0 r
.38024 .473 m
.38045 .47316 L
s
.38001 .47321 m
.38024 .473 L
s
.38024 .473 m
.38016 .473 L
s
1 .062 0 r
.77425 .38633 m
.77391 .38664 L
s
.77464 .38659 m
.77425 .38633 L
s
1 .015 0 r
.83707 .41549 m
.83699 .41557 L
s
.83717 .41556 m
.83707 .41549 L
s
.83699 .41557 m
.83709 .41564 L
s
.83709 .41564 m
.83717 .41556 L
s
1 .039 0 r
.38022 .47336 m
.38001 .47321 L
s
.38001 .47321 m
.38016 .473 L
s
.38045 .47316 m
.38022 .47336 L
s
.38016 .473 m
.38045 .47316 L
s
1 .062 0 r
.77391 .38664 m
.7743 .3869 L
s
1 .111 0 r
.42741 .61804 m
.42785 .61724 L
s
1 .039 0 r
.38016 .473 m
.38022 .47336 L
s
1 .062 0 r
.7743 .3869 m
.77464 .38659 L
s
1 .066 0 r
.78211 .73202 m
.78243 .73247 L
s
.78183 .73224 m
.78211 .73202 L
s
.78211 .73202 m
.78248 .73213 L
s
.78243 .73247 m
.78215 .73269 L
s
.78248 .73213 m
.78243 .73247 L
s
1 .003 0 r
.25779 .5883 m
.25778 .5883 L
s
.25778 .58827 m
.25779 .5883 L
s
.25779 .5883 m
.25776 .58829 L
s
.2578 .58829 m
.25779 .5883 L
s
.25774 .58823 m
.25779 .5883 L
s
.25778 .58827 m
.25776 .58829 L
s
.2578 .58829 m
.25778 .58827 L
s
.25776 .58829 m
.25778 .5883 L
s
.25778 .5883 m
.2578 .58829 L
s
1 .825 0 r
.4201 .38439 m
.42044 .39243 L
s
1 .095 0 r
.71783 .70356 m
.72054 .70199 L
s
1 .001 0 r
.77748 .5594 m
.77748 .55939 L
s
1 .032 0 r
.31738 .44408 m
.31724 .44328 L
s
1 .001 0 r
.77748 .55939 m
.77749 .55939 L
s
.77748 .55939 m
.77748 .55939 L
s
.77748 .55939 m
.77748 .55939 L
s
.77749 .55939 m
.77748 .5594 L
s
.77748 .55939 m
.77749 .55939 L
s
.77748 .5594 m
.77748 .55939 L
s
.77748 .55939 m
.77748 .55939 L
s
.77748 .55939 m
.77748 .5594 L
s
1 .066 0 r
.78215 .73269 m
.78183 .73224 L
s
.78183 .73224 m
.78248 .73213 L
s
.78248 .73213 m
.78215 .73269 L
s
1 .091 0 r
.3043 .73215 m
.30377 .73231 L
s
.30383 .73139 m
.3043 .73215 L
s
.3043 .73215 m
.3034 .73202 L
s
.3042 .73168 m
.3043 .73215 L
s
.30178 .73065 m
.3043 .73215 L
s
0 .197 1 r
.55885 .70327 m
.54424 .70821 L
s
.54403 .66966 m
.55885 .70327 L
s
.55885 .70327 m
.52431 .69445 L
s
.56411 .68316 m
.55885 .70327 L
s
.48236 .62818 m
.55885 .70327 L
s
1 .091 0 r
.30383 .73139 m
.3034 .73202 L
s
.3042 .73168 m
.30383 .73139 L
s
1 .336 0 r
.56445 .67436 m
.56174 .67629 L
s
.5614 .67358 m
.56445 .67436 L
s
1 .091 0 r
.3034 .73202 m
.30377 .73231 L
s
1 .741 0 r
.40601 .33241 m
.40192 .32828 L
s
.40192 .32828 m
.40764 .32529 L
s
1 .032 0 r
.31728 .44329 m
.31746 .44344 L
s
.31708 .44344 m
.31728 .44329 L
s
.31728 .44329 m
.31724 .44328 L
s
.31726 .44359 m
.31708 .44344 L
s
.31708 .44344 m
.31724 .44328 L
s
.31746 .44344 m
.31726 .44359 L
s
.31724 .44328 m
.31746 .44344 L
s
.31724 .44328 m
.31726 .44359 L
s
1 .233 0 r
.41144 .73173 m
.41214 .73234 L
s
.41222 .72997 m
.41144 .73173 L
s
.41379 .73172 m
.41144 .73173 L
s
1 .241 0 r
.62263 .70288 m
.62089 .70458 L
s
.62022 .70272 m
.62263 .70288 L
s
1 .233 0 r
.41379 .73172 m
.41214 .73234 L
s
.41222 .72997 m
.41379 .73172 L
s
.41292 .73058 m
.41379 .73172 L
s
.40571 .7289 m
.41379 .73172 L
s
1 .091 0 r
.30377 .73231 m
.3042 .73168 L
s
1 .241 0 r
.62089 .70458 m
.62022 .70272 L
s
1 .233 0 r
.41292 .73058 m
.41222 .72997 L
s
0 1 .566 r
.52457 .59746 m
.51129 .61402 L
s
.53791 .60606 m
.52457 .59746 L
s
1 .336 0 r
.56174 .67629 m
.5614 .67358 L
s
1 0 0 r
.1945 .55844 m
.1945 .55844 L
s
.1945 .55844 m
.1945 .55844 L
s
.1945 .55844 m
.1945 .55844 L
s
.1945 .55844 m
.1945 .55844 L
s
.1945 .55843 m
.1945 .55844 L
s
.1945 .55844 m
.1945 .55844 L
s
.1945 .55844 m
.1945 .55844 L
s
.1945 .55844 m
.1945 .55844 L
s
.1945 .55844 m
.1945 .55844 L
s
1 .028 0 r
.88504 .73152 m
.88567 .73099 L
s
1 .001 0 r
.94472 .58728 m
.94473 .58727 L
s
1 .151 0 r
.65486 .67382 m
.65962 .6716 L
s
1 0 0 r
.71454 .52959 m
.71454 .52959 L
s
.425 1 0 r
.48435 .47189 m
.45208 .43707 L
s
1 .026 0 r
.25417 .41419 m
.25412 .41353 L
s
1 .001 0 r
.94472 .58727 m
.94473 .58727 L
s
.94472 .58727 m
.94472 .58727 L
s
.94472 .58727 m
.94473 .58727 L
s
.94473 .58727 m
.94473 .58727 L
s
.94473 .58727 m
.94473 .58727 L
s
.94473 .58727 m
.94472 .58727 L
s
.94472 .58727 m
.94473 .58727 L
s
.94473 .58727 m
.94473 .58727 L
s
1 .095 0 r
.71997 .70182 m
.72041 .70249 L
s
.71959 .70212 m
.71997 .70182 L
s
.71997 .70182 m
.72054 .70199 L
s
.72041 .70249 m
.72003 .70278 L
s
.72054 .70199 m
.72041 .70249 L
s
1 .271 0 r
.33852 .32532 m
.34 .32683 L
s
.33689 .32625 m
.33852 .32532 L
s
.33852 .32532 m
.33894 .32515 L
s
1 .158 0 r
.75401 .32727 m
.75378 .32717 L
s
.75367 .32575 m
.75401 .32727 L
s
.75401 .32727 m
.75281 .32664 L
s
.75464 .32628 m
.75401 .32727 L
s
.75258 .32322 m
.75401 .32727 L
s
1 .028 0 r
.88553 .73096 m
.88568 .73114 L
s
.8854 .73106 m
.88553 .73096 L
s
.88553 .73096 m
.88567 .73099 L
s
1 .026 0 r
.25414 .41354 m
.25429 .41367 L
s
.25398 .41366 m
.25414 .41354 L
s
.25414 .41354 m
.25412 .41353 L
s
1 .028 0 r
.88568 .73114 m
.88556 .73124 L
s
.88567 .73099 m
.88568 .73114 L
s
0 .434 1 r
.54024 .6474 m
.52181 .67052 L
s
.55896 .65982 m
.54024 .6474 L
s
1 .026 0 r
.25429 .41367 m
.25412 .41378 L
s
.25412 .41353 m
.25429 .41367 L
s
.25412 .41378 m
.25398 .41366 L
s
.25398 .41366 m
.25412 .41353 L
s
1 .028 0 r
.88556 .73124 m
.8854 .73106 L
s
.8854 .73106 m
.88567 .73099 L
s
.88567 .73099 m
.88556 .73124 L
s
1 .026 0 r
.25412 .41353 m
.25412 .41378 L
s
1 .741 0 r
.40764 .32529 m
.40601 .33241 L
s
1 .095 0 r
.72003 .70278 m
.71959 .70212 L
s
.71959 .70212 m
.72054 .70199 L
s
.72054 .70199 m
.72003 .70278 L
s
1 .016 0 r
.36184 .58665 m
.36177 .58666 L
s
.36177 .58651 m
.36184 .58665 L
s
.36184 .58665 m
.36169 .58661 L
s
.36185 .58656 m
.36184 .58665 L
s
.3615 .58633 m
.36184 .58665 L
s
0 .813 1 r
.51784 .64435 m
.53439 .65542 L
s
1 .158 0 r
.75367 .32575 m
.75281 .32664 L
s
.75464 .32628 m
.75367 .32575 L
s
1 .016 0 r
.36177 .58651 m
.36169 .58661 L
s
.36185 .58656 m
.36177 .58651 L
s
.36169 .58661 m
.36177 .58666 L
s
1 .271 0 r
.34 .32683 m
.33837 .32776 L
s
.33894 .32515 m
.34 .32683 L
s
1 .016 0 r
.36177 .58666 m
.36185 .58656 L
s
1 .008 0 r
.65141 .49993 m
.65144 .49993 L
s
.65143 .49985 m
.65141 .49993 L
s
.65141 .49993 m
.65139 .49988 L
s
.65148 .49989 m
.65141 .49993 L
s
.65152 .49973 m
.65141 .49993 L
s
.65143 .49985 m
.65139 .49988 L
s
.65148 .49989 m
.65143 .49985 L
s
.65144 .49993 m
.65148 .49989 L
s
.65139 .49988 m
.65144 .49993 L
s
1 .525 0 r
.65839 .35556 m
.6566 .35551 L
s
.6564 .35075 m
.65839 .35556 L
s
.65839 .35556 m
.65372 .35407 L
s
.65929 .35218 m
.65839 .35556 L
s
.6489 .34334 m
.65839 .35556 L
s
1 .59 0 r
.42058 .40895 m
.42395 .4116 L
s
.41702 .41174 m
.42058 .40895 L
s
.42058 .40895 m
.42015 .40866 L
s
1 .158 0 r
.75281 .32664 m
.75378 .32717 L
s
1 .035 0 r
.82213 .70178 m
.82293 .70112 L
s
1 0 0 r
.88184 .55746 m
.88184 .55746 L
s
1 .253 0 r
.59181 .64405 m
.60111 .64136 L
s
1 .344 0 r
.42121 .442 m
.42024 .43332 L
s
1 .022 0 r
.19089 .38427 m
.19087 .38371 L
s
1 0 0 r
.88184 .55746 m
.88184 .55746 L
s
.88184 .55746 m
.88184 .55746 L
s
.88184 .55746 m
.88184 .55746 L
s
.88184 .55746 m
.88184 .55746 L
s
.88184 .55746 m
.88184 .55746 L
s
.88184 .55746 m
.88184 .55746 L
s
.88184 .55746 m
.88184 .55746 L
s
.88184 .55746 m
.88184 .55746 L
s
1 .233 0 r
.41214 .73234 m
.41292 .73058 L
s
1 .344 0 r
.54009 .61516 m
.54004 .61574 L
s
.54003 .61235 m
.54009 .61516 L
s
.54287 .61399 m
.54009 .61516 L
s
1 .136 0 r
.46876 .58621 m
.46919 .58651 L
s
.46922 .58519 m
.46876 .58621 L
s
.47013 .58621 m
.46876 .58621 L
s
.47013 .58621 m
.46919 .58651 L
s
.46922 .58519 m
.47013 .58621 L
s
.46965 .58548 m
.47013 .58621 L
s
.46549 .58441 m
.47013 .58621 L
s
.46965 .58548 m
.46922 .58519 L
s
1 .039 0 r
.23939 .70163 m
.2392 .70168 L
s
.23923 .70128 m
.23939 .70163 L
s
.23939 .70163 m
.23902 .70154 L
s
.23941 .70142 m
.23939 .70163 L
s
.23849 .70089 m
.23939 .70163 L
s
1 .158 0 r
.75378 .32717 m
.75464 .32628 L
s
1 .039 0 r
.23923 .70128 m
.23902 .70154 L
s
.23941 .70142 m
.23923 .70128 L
s
1 .271 0 r
.33837 .32776 m
.33689 .32625 L
s
.33689 .32625 m
.33894 .32515 L
s
1 .039 0 r
.23902 .70154 m
.2392 .70168 L
s
1 .344 0 r
.53998 .61293 m
.54003 .61235 L
s
.54003 .61235 m
.54287 .61399 L
s
1 .022 0 r
.19089 .38373 m
.191 .38383 L
s
.19075 .38382 m
.19089 .38373 L
s
.19089 .38373 m
.19087 .38371 L
s
1 .039 0 r
.2392 .70168 m
.23941 .70142 L
s
1 .022 0 r
.191 .38383 m
.19087 .38393 L
s
.19087 .38371 m
.191 .38383 L
s
.19087 .38393 m
.19075 .38382 L
s
.19075 .38382 m
.19087 .38371 L
s
.19087 .38371 m
.19087 .38393 L
s
1 .035 0 r
.82275 .70107 m
.82294 .7013 L
s
.8226 .7012 m
.82275 .70107 L
s
.82275 .70107 m
.82293 .70112 L
s
.82294 .7013 m
.82278 .70143 L
s
.82293 .70112 m
.82294 .7013 L
s
1 .018 0 r
.87861 .38366 m
.87862 .38365 L
s
.87861 .38349 m
.87861 .38366 L
s
.87861 .38366 m
.87851 .38357 L
s
.87872 .38356 m
.87861 .38366 L
s
.87863 .3832 m
.87861 .38366 L
s
1 .151 0 r
.65923 .67239 m
.6587 .6728 L
s
.65864 .67129 m
.65923 .67239 L
s
.65962 .6716 m
.65923 .67239 L
s
.6581 .6717 m
.65864 .67129 L
s
.65864 .67129 m
.65962 .6716 L
s
1 .018 0 r
.87861 .38349 m
.87851 .38357 L
s
.87872 .38356 m
.87861 .38349 L
s
.87851 .38357 m
.87862 .38365 L
s
1 .035 0 r
.82278 .70143 m
.8226 .7012 L
s
.8226 .7012 m
.82293 .70112 L
s
1 .018 0 r
.87862 .38365 m
.87872 .38356 L
s
1 .055 0 r
.81581 .35467 m
.8158 .35463 L
s
.81576 .35413 m
.81581 .35467 L
s
.81581 .35467 m
.81545 .35441 L
s
.81611 .35434 m
.81581 .35467 L
s
.81564 .35323 m
.81581 .35467 L
s
1 .035 0 r
.82293 .70112 m
.82278 .70143 L
s
1 .271 0 r
.33894 .32515 m
.33837 .32776 L
s
0 1 .077 r
.60615 .38351 m
.61023 .38566 L
s
.60971 .36661 m
.60615 .38351 L
s
.62626 .37919 m
.60615 .38351 L
s
1 .525 0 r
.6564 .35075 m
.65372 .35407 L
s
.65929 .35218 m
.6564 .35075 L
s
1 .055 0 r
.81576 .35413 m
.81545 .35441 L
s
.81611 .35434 m
.81576 .35413 L
s
1 .136 0 r
.46919 .58651 m
.46965 .58548 L
s
.425 1 0 r
.59101 .48006 m
.5991 .46999 L
s
1 .114 0 r
.34563 .70099 m
.34496 .70119 L
s
.34502 .70004 m
.34563 .70099 L
s
.34563 .70099 m
.3445 .70084 L
s
.34548 .70039 m
.34563 .70099 L
s
.34241 .69911 m
.34563 .70099 L
s
1 .055 0 r
.81545 .35441 m
.8158 .35463 L
s
.8158 .35463 m
.81611 .35434 L
s
1 .001 0 r
.29825 .55651 m
.29825 .55651 L
s
.29825 .5565 m
.29825 .55651 L
s
.29825 .55651 m
.29825 .5565 L
s
.29825 .5565 m
.29825 .55651 L
s
.29824 .55649 m
.29825 .55651 L
s
.29825 .5565 m
.29825 .5565 L
s
.29825 .5565 m
.29825 .5565 L
s
.29825 .5565 m
.29825 .55651 L
s
.29825 .55651 m
.29825 .5565 L
s
1 .047 0 r
.75914 .67201 m
.76025 .67113 L
s
1 0 0 r
.81889 .52761 m
.81889 .52761 L
s
1 .344 0 r
.52869 .61425 m
.54287 .61399 L
s
1 .141 0 r
.35799 .41208 m
.35819 .40849 L
s
1 .018 0 r
.12754 .35432 m
.12753 .35384 L
s
1 .114 0 r
.34502 .70004 m
.3445 .70084 L
s
.34548 .70039 m
.34502 .70004 L
s
.3445 .70084 m
.34496 .70119 L
s
1 .323 0 r
.45527 .70081 m
.45609 .70156 L
s
.45616 .6983 m
.45527 .70081 L
s
.45851 .70058 m
.45527 .70081 L
s
1 .525 0 r
.65372 .35407 m
.6566 .35551 L
s
0 1 .566 r
.51129 .61402 m
.52457 .62274 L
s
1 .323 0 r
.45697 .69905 m
.45616 .6983 L
s
.45616 .6983 m
.45851 .70058 L
s
1 .344 0 r
.54287 .61399 m
.54004 .61574 L
s
.53998 .61293 m
.54287 .61399 L
s
1 .787 0 r
.62268 .41177 m
.61988 .41187 L
s
.61966 .40459 m
.62268 .41177 L
s
.62268 .41177 m
.61562 .4096 L
s
.62393 .40685 m
.62268 .41177 L
s
.60803 .39392 m
.62268 .41177 L
s
1 .018 0 r
.12754 .35385 m
.12764 .35394 L
s
.12742 .35392 m
.12754 .35385 L
s
.12754 .35385 m
.12753 .35384 L
s
1 .59 0 r
.4204 .4144 m
.41702 .41174 L
s
.41702 .41174 m
.42015 .40866 L
s
1 .151 0 r
.6587 .6728 m
.6581 .6717 L
s
.65962 .6716 m
.6587 .6728 L
s
.6581 .6717 m
.65962 .6716 L
s
1 .018 0 r
.12764 .35394 m
.12752 .35402 L
s
.12753 .35384 m
.12764 .35394 L
s
1 .323 0 r
.45851 .70058 m
.45609 .70156 L
s
.45697 .69905 m
.45851 .70058 L
s
.44657 .69733 m
.45851 .70058 L
s
1 .018 0 r
.12752 .35402 m
.12742 .35392 L
s
.12742 .35392 m
.12753 .35384 L
s
.12753 .35384 m
.12752 .35402 L
s
1 .59 0 r
.42395 .4116 m
.4204 .4144 L
s
.42015 .40866 m
.42395 .4116 L
s
1 .114 0 r
.34496 .70119 m
.34548 .70039 L
s
1 .253 0 r
.59993 .64261 m
.59928 .64316 L
s
.59922 .64064 m
.59993 .64261 L
s
.60111 .64136 m
.59993 .64261 L
s
1 .047 0 r
.76001 .67107 m
.76025 .67138 L
s
.7598 .67123 m
.76001 .67107 L
s
.76001 .67107 m
.76025 .67113 L
s
1 .253 0 r
.59857 .64119 m
.59922 .64064 L
s
.59922 .64064 m
.60111 .64136 L
s
1 .047 0 r
.76025 .67138 m
.76005 .67154 L
s
.76025 .67113 m
.76025 .67138 L
s
.808 1 0 r
.61724 .33323 m
.62129 .32414 L
s
1 .417 0 r
.52338 .72905 m
.52361 .72992 L
s
.52361 .72567 m
.52338 .72905 L
s
.52704 .72796 m
.52338 .72905 L
s
1 .047 0 r
.76005 .67154 m
.7598 .67123 L
s
.7598 .67123 m
.76025 .67113 L
s
1 .215 0 r
.67199 .41114 m
.67181 .41105 L
s
.67172 .40906 m
.67199 .41114 L
s
.67199 .41114 m
.67051 .41019 L
s
.67303 .40992 m
.67199 .41114 L
s
.67088 .40571 m
.67199 .41114 L
s
1 .047 0 r
.76025 .67113 m
.76005 .67154 L
s
1 .001 0 r
.75585 .49774 m
.75585 .49774 L
s
.75585 .49773 m
.75585 .49774 L
s
.75585 .49774 m
.75585 .49773 L
s
.75586 .49773 m
.75585 .49774 L
s
.75586 .49772 m
.75585 .49774 L
s
.75585 .49773 m
.75585 .49773 L
s
.75586 .49773 m
.75585 .49773 L
s
.75585 .49774 m
.75586 .49773 L
s
.75585 .49773 m
.75585 .49774 L
s
1 .014 0 r
.92666 .7 m
.92695 .69972 L
s
1 .068 0 r
.69608 .64221 m
.69781 .64097 L
s
1 0 0 r
.01 w
.52528 .43992 Mdot
.5 Mabswid
.23491 .52661 m
.23491 .52661 L
s
1 .08 0 r
.29469 .38212 m
.29492 .38008 L
s
0 1 .331 r
.61773 .37017 m
.62174 .35117 L
s
1 .344 0 r
.54004 .61574 m
.53998 .61293 L
s
1 .417 0 r
.52383 .72654 m
.52361 .72567 L
s
.52361 .72567 m
.52704 .72796 L
s
1 .014 0 r
.92688 .6997 m
.92697 .69979 L
s
.92682 .69976 m
.92688 .6997 L
s
.92688 .6997 m
.92695 .69972 L
s
.92697 .69979 m
.9269 .69985 L
s
.92695 .69972 m
.92697 .69979 L
s
.9269 .69985 m
.92682 .69976 L
s
.92682 .69976 m
.92695 .69972 L
s
.92695 .69972 m
.9269 .69985 L
s
0 1 .077 r
.61382 .36864 m
.60971 .36661 L
s
.60971 .36661 m
.62626 .37919 L
s
1 .215 0 r
.67172 .40906 m
.67051 .41019 L
s
.67303 .40992 m
.67172 .40906 L
s
1 .024 0 r
.69262 .46837 m
.69265 .46837 L
s
.69264 .46815 m
.69262 .46837 L
s
.69262 .46837 m
.69251 .46825 L
s
.69278 .46827 m
.69262 .46837 L
s
.69276 .46779 m
.69262 .46837 L
s
.69264 .46815 m
.69251 .46825 L
s
.69278 .46827 m
.69264 .46815 L
s
.69265 .46837 m
.69278 .46827 L
s
.69251 .46825 m
.69265 .46837 L
s
0 .434 1 r
.52181 .67052 m
.5404 .68317 L
s
1 .787 0 r
.61966 .40459 m
.61562 .4096 L
s
.62393 .40685 m
.61966 .40459 L
s
1 .215 0 r
.67051 .41019 m
.67181 .41105 L
s
1 .007 0 r
.40237 .55467 m
.40234 .55468 L
s
.40234 .55461 m
.40237 .55467 L
s
.40237 .55467 m
.4023 .55466 L
s
.40237 .55464 m
.40237 .55467 L
s
.40223 .55454 m
.40237 .55467 L
s
.40234 .55461 m
.4023 .55466 L
s
.40237 .55464 m
.40234 .55461 L
s
1 .59 0 r
.42015 .40866 m
.4204 .4144 L
s
1 .007 0 r
.4023 .55466 m
.40234 .55468 L
s
.40234 .55468 m
.40237 .55464 L
s
1 .323 0 r
.45609 .70156 m
.45697 .69905 L
s
1 .068 0 r
.69745 .64088 m
.69778 .64134 L
s
.69715 .64109 m
.69745 .64088 L
s
.69745 .64088 m
.69781 .64097 L
s
1 .253 0 r
.60111 .64136 m
.59928 .64316 L
s
.59857 .64119 m
.60111 .64136 L
s
1 .068 0 r
.69778 .64134 m
.69748 .64155 L
s
.69781 .64097 m
.69778 .64134 L
s
1 .525 0 r
.6566 .35551 m
.65929 .35218 L
s
1 .253 0 r
.59928 .64316 m
.59857 .64119 L
s
1 0 0 r
.92348 .52562 m
.92348 .52562 L
s
1 .016 0 r
.86366 .6702 m
.86398 .66987 L
s
1 .111 0 r
.63294 .61237 m
.6362 .61052 L
s
.285 1 0 r
.46204 .40996 m
.48117 .36692 L
s
1 0 0 r
.17151 .49671 m
.17151 .4967 L
s
1 .053 0 r
.23132 .35213 m
.2315 .35075 L
s
1 0 0 r
.17151 .4967 m
.17151 .4967 L
s
.17151 .4967 m
.17151 .4967 L
s
.17151 .4967 m
.17151 .4967 L
s
.17151 .49671 m
.17151 .4967 L
s
.17151 .4967 m
.17151 .4967 L
s
.17151 .4967 m
.17151 .49671 L
s
.17151 .4967 m
.17151 .4967 L
s
.17151 .4967 m
.17151 .49671 L
s
1 .215 0 r
.67181 .41105 m
.67303 .40992 L
s
1 .417 0 r
.52704 .72796 m
.52361 .72992 L
s
.52383 .72654 m
.52704 .72796 L
s
.50989 .72715 m
.52704 .72796 L
s
1 .042 0 r
.27999 .6701 m
.27978 .67015 L
s
.27981 .66973 m
.27999 .6701 L
s
.27999 .6701 m
.27959 .67 L
s
.28001 .66988 m
.27999 .6701 L
s
.27903 .66929 m
.27999 .6701 L
s
.27981 .66973 m
.27959 .67 L
s
.28001 .66988 m
.27981 .66973 L
s
1 .068 0 r
.69748 .64155 m
.69715 .64109 L
s
.69715 .64109 m
.69781 .64097 L
s
1 .042 0 r
.27959 .67 m
.27978 .67015 L
s
1 .068 0 r
.69781 .64097 m
.69748 .64155 L
s
1 .016 0 r
.86391 .66985 m
.864 .66995 L
s
.86383 .66991 m
.86391 .66985 L
s
.86391 .66985 m
.86398 .66987 L
s
.864 .66995 m
.86393 .67001 L
s
.86398 .66987 m
.864 .66995 L
s
.86393 .67001 m
.86383 .66991 L
s
.86383 .66991 m
.86398 .66987 L
s
1 .08 0 r
.2949 .38012 m
.29534 .38053 L
s
.2944 .38044 m
.2949 .38012 L
s
.2949 .38012 m
.29492 .38008 L
s
1 .151 0 r
.38759 .6699 m
.38668 .67017 L
s
.38674 .66866 m
.38759 .6699 L
s
.38759 .6699 m
.38609 .66974 L
s
.38734 .6691 m
.38759 .6699 L
s
.38318 .66747 m
.38759 .6699 L
s
1 .016 0 r
.86398 .66987 m
.86393 .67001 L
s
1 .787 0 r
.61562 .4096 m
.61988 .41187 L
s
1 .042 0 r
.27978 .67015 m
.28001 .66988 L
s
1 .141 0 r
.35818 .40856 m
.35898 .40926 L
s
.35732 .40916 m
.35818 .40856 L
s
.35818 .40856 m
.35819 .40849 L
s
1 .151 0 r
.38674 .66866 m
.38609 .66974 L
s
.38734 .6691 m
.38674 .66866 L
s
1 .08 0 r
.29534 .38053 m
.29485 .38085 L
s
.29492 .38008 m
.29534 .38053 L
s
1 .151 0 r
.38609 .66974 m
.38668 .67017 L
s
1 .08 0 r
.29485 .38085 m
.2944 .38044 L
s
.2944 .38044 m
.29492 .38008 L
s
1 .141 0 r
.35898 .40926 m
.35811 .40986 L
s
.35819 .40849 m
.35898 .40926 L
s
1 .607 0 r
.40446 .34695 m
.40782 .35035 L
s
.40088 .34904 m
.40446 .34695 L
s
.40446 .34695 m
.40559 .34661 L
s
1 .08 0 r
.29492 .38008 m
.29485 .38085 L
s
1 .141 0 r
.35811 .40986 m
.35732 .40916 L
s
.35732 .40916 m
.35819 .40849 L
s
1 .05 0 r
.85743 .3223 m
.85741 .32226 L
s
.85736 .32181 m
.85743 .3223 L
s
.85743 .3223 m
.85709 .32208 L
s
.85768 .322 m
.85743 .3223 L
s
.85721 .32099 m
.85743 .3223 L
s
1 .053 0 r
.23148 .35079 m
.23178 .35106 L
s
.23115 .35099 m
.23148 .35079 L
s
.23148 .35079 m
.2315 .35075 L
s
1 .05 0 r
.85736 .32181 m
.85709 .32208 L
s
.85768 .322 m
.85736 .32181 L
s
1 .457 0 r
.50136 .66931 m
.50209 .67023 L
s
.50212 .66564 m
.50136 .66931 L
s
.50574 .66851 m
.50136 .66931 L
s
1 .117 0 r
.50996 .55359 m
.51015 .55377 L
s
.51016 .55265 m
.50996 .55359 L
s
.51108 .55337 m
.50996 .55359 L
s
1 .053 0 r
.23178 .35106 m
.23144 .35127 L
s
.2315 .35075 m
.23178 .35106 L
s
1 0 0 r
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
.86044 .4957 m
.86044 .4957 L
s
1 .018 0 r
.80059 .64036 m
.80095 .63998 L
s
1 .199 0 r
.56974 .58249 m
.57703 .58029 L
s
1 0 0 r
.33888 .52463 m
.33888 .52463 L
s
1 .457 0 r
.39873 .37997 m
.40336 .36849 L
s
1 .039 0 r
.16788 .32211 m
.16801 .32108 L
s
1 .05 0 r
.85709 .32208 m
.85741 .32226 L
s
1 .053 0 r
.23144 .35127 m
.23115 .35099 L
s
.23115 .35099 m
.2315 .35075 L
s
1 .117 0 r
.51035 .55283 m
.51016 .55265 L
s
.51016 .55265 m
.51108 .55337 L
s
1 .141 0 r
.35819 .40849 m
.35811 .40986 L
s
1 .05 0 r
.85741 .32226 m
.85768 .322 L
s
1 .053 0 r
.2315 .35075 m
.23144 .35127 L
s
1 .117 0 r
.51108 .55337 m
.51015 .55377 L
s
.51035 .55283 m
.51108 .55337 L
s
.50645 .55258 m
.51108 .55337 L
s
1 .151 0 r
.38668 .67017 m
.38734 .6691 L
s
1 .018 0 r
.80087 .63996 m
.80097 .64007 L
s
.80078 .64003 m
.80087 .63996 L
s
.80087 .63996 m
.80095 .63998 L
s
1 .111 0 r
.63553 .61035 m
.636 .61114 L
s
.63508 .61065 m
.63553 .61035 L
s
.63553 .61035 m
.6362 .61052 L
s
.636 .61114 m
.63556 .61144 L
s
.6362 .61052 m
.636 .61114 L
s
1 .018 0 r
.80097 .64007 m
.80089 .64014 L
s
.80095 .63998 m
.80097 .64007 L
s
1 .417 0 r
.52361 .72992 m
.52383 .72654 L
s
1 .457 0 r
.50286 .66656 m
.50212 .66564 L
s
.50212 .66564 m
.50574 .66851 L
s
1 .018 0 r
.80089 .64014 m
.80078 .64003 L
s
.80078 .64003 m
.80095 .63998 L
s
.80095 .63998 m
.80089 .64014 L
s
1 .607 0 r
.40782 .35035 m
.40425 .35246 L
s
.40559 .34661 m
.40782 .35035 L
s
1 .039 0 r
.168 .32111 m
.16821 .32132 L
s
.16775 .32126 m
.168 .32111 L
s
.168 .32111 m
.16801 .32108 L
s
1 .117 0 r
.51015 .55377 m
.51035 .55283 L
s
1 .039 0 r
.16821 .32132 m
.16796 .32146 L
s
.16801 .32108 m
.16821 .32132 L
s
1 .013 0 r
.21582 .63969 m
.21576 .6397 L
s
.21577 .63958 m
.21582 .63969 L
s
.21582 .63969 m
.2157 .63966 L
s
.21584 .63963 m
.21582 .63969 L
s
.21558 .63943 m
.21582 .63969 L
s
0 1 .077 r
.62626 .37919 m
.61023 .38566 L
s
.61382 .36864 m
.62626 .37919 L
s
.54425 .36365 m
.62626 .37919 L
s
1 .013 0 r
.21577 .63958 m
.2157 .63966 L
s
.21584 .63963 m
.21577 .63958 L
s
.2157 .63966 m
.21576 .6397 L
s
1 .039 0 r
.16796 .32146 m
.16775 .32126 L
s
.16775 .32126 m
.16801 .32108 L
s
1 .013 0 r
.21576 .6397 m
.21584 .63963 L
s
1 .111 0 r
.63556 .61144 m
.63508 .61065 L
s
.63508 .61065 m
.6362 .61052 L
s
1 .039 0 r
.16801 .32108 m
.16796 .32146 L
s
1 .111 0 r
.6362 .61052 m
.63556 .61144 L
s
0 .197 1 r
.54403 .66966 m
.52431 .69445 L
s
.56411 .68316 m
.54403 .66966 L
s
1 .457 0 r
.50574 .66851 m
.50209 .67023 L
s
.50286 .66656 m
.50574 .66851 L
s
.48757 .66564 m
.50574 .66851 L
s
1 .004 0 r
.79731 .46583 m
.79731 .46583 L
s
.79731 .46579 m
.79731 .46583 L
s
.79731 .46583 m
.79729 .46581 L
s
.79733 .46581 m
.79731 .46583 L
s
.79733 .46574 m
.79731 .46583 L
s
.79731 .46579 m
.79729 .46581 L
s
.79733 .46581 m
.79731 .46579 L
s
.79731 .46583 m
.79733 .46581 L
s
.79729 .46581 m
.79731 .46583 L
s
1 .007 0 r
.96843 .66838 m
.96855 .66824 L
s
1 .021 0 r
.73744 .61048 m
.73786 .61004 L
s
0 .04 1 r
.56206 .72627 m
.54683 .7318 L
s
.54658 .69122 m
.56206 .72627 L
s
.56206 .72627 m
.52596 .71718 L
s
.5676 .70555 m
.56206 .72627 L
s
.4821 .6488 m
.56206 .72627 L
s
1 .001 0 r
.27547 .49469 m
.27546 .49467 L
s
1 .202 0 r
.33535 .34994 m
.33722 .3448 L
s
1 .001 0 r
.27546 .49467 m
.27547 .49467 L
s
.27546 .49467 m
.27546 .49467 L
s
.27546 .49467 m
.27546 .49467 L
s
.27546 .49468 m
.27546 .49467 L
s
.27546 .49467 m
.27546 .49467 L
s
.27547 .49467 m
.27546 .49468 L
s
.27546 .49467 m
.27547 .49467 L
s
.27546 .49467 m
.27546 .49468 L
s
1 .007 0 r
.96852 .66823 m
.96856 .66827 L
s
.96849 .66826 m
.96852 .66823 L
s
.96852 .66823 m
.96855 .66824 L
s
.96856 .66827 m
.96853 .6683 L
s
.96855 .66824 m
.96856 .66827 L
s
.96853 .6683 m
.96849 .66826 L
s
.96849 .66826 m
.96855 .66824 L
s
.96855 .66824 m
.96853 .6683 L
s
1 .199 0 r
.57611 .58131 m
.57559 .5817 L
s
.57556 .57976 m
.57611 .58131 L
s
.57703 .58029 m
.57611 .58131 L
s
1 .032 0 r
.73409 .43655 m
.73411 .43654 L
s
.73409 .43624 m
.73409 .43655 L
s
.73409 .43655 m
.73391 .43639 L
s
.73429 .43638 m
.73409 .43655 L
s
.73414 .43574 m
.73409 .43655 L
s
.73409 .43624 m
.73391 .43639 L
s
.73429 .43638 m
.73409 .43624 L
s
1 .021 0 r
.73777 .61003 m
.73789 .61016 L
s
.73767 .6101 m
.73777 .61003 L
s
.73777 .61003 m
.73786 .61004 L
s
1 .199 0 r
.57503 .58015 m
.57556 .57976 L
s
.57556 .57976 m
.57703 .58029 L
s
1 .021 0 r
.73789 .61016 m
.73779 .61023 L
s
.73786 .61004 m
.73789 .61016 L
s
1 .032 0 r
.73391 .43639 m
.73411 .43654 L
s
.73411 .43654 m
.73429 .43638 L
s
1 .021 0 r
.73779 .61023 m
.73767 .6101 L
s
.73767 .6101 m
.73786 .61004 L
s
.73786 .61004 m
.73779 .61023 L
s
1 .215 0 r
.43078 .63901 m
.42942 .63942 L
s
.42948 .63728 m
.43078 .63901 L
s
.43078 .63901 m
.42861 .63885 L
s
.43028 .63785 m
.43078 .63901 L
s
.42409 .63571 m
.43078 .63901 L
s
.425 1 0 r
.51517 .58096 m
.50887 .58223 L
s
.50895 .56682 m
.51517 .58096 L
s
.51517 .58096 m
.50075 .57701 L
s
.5171 .572 m
.51517 .58096 L
s
.48338 .54818 m
.51517 .58096 L
s
1 .215 0 r
.42948 .63728 m
.42861 .63885 L
s
.43028 .63785 m
.42948 .63728 L
s
.42861 .63885 m
.42942 .63942 L
s
1 .344 0 r
.42048 .43346 m
.42246 .43503 L
s
.4184 .43511 m
.42048 .43346 L
s
.42048 .43346 m
.42024 .43332 L
s
1 .607 0 r
.40425 .35246 m
.40088 .34904 L
s
.40088 .34904 m
.40559 .34661 L
s
1 .787 0 r
.61988 .41187 m
.62393 .40685 L
s
1 .006 0 r
.90534 .6385 m
.90545 .63836 L
s
1 .318 0 r
.6143 .7254 m
.62606 .72218 L
s
1 .024 0 r
.67422 .58057 m
.67472 .58008 L
s
1 0 0 r
.4431 .52264 m
.4431 .52264 L
s
0 .434 1 r
.50302 .37781 m
.63513 .33244 L
s
1 .002 0 r
.21198 .46471 m
.21196 .46465 L
s
1 .115 0 r
.2719 .31988 m
.27286 .31692 L
s
1 .046 0 r
.32073 .63847 m
.32051 .63852 L
s
.32054 .63806 m
.32073 .63847 L
s
.32073 .63847 m
.3203 .63836 L
s
.32075 .63822 m
.32073 .63847 L
s
.31971 .63757 m
.32073 .63847 L
s
1 .002 0 r
.21197 .46465 m
.21198 .46466 L
s
.21195 .46466 m
.21197 .46465 L
s
.21197 .46465 m
.21196 .46465 L
s
.21197 .46467 m
.21195 .46466 L
s
.21195 .46466 m
.21196 .46465 L
s
.21198 .46466 m
.21197 .46467 L
s
.21196 .46465 m
.21198 .46466 L
s
.21196 .46465 m
.21197 .46467 L
s
1 .006 0 r
.90543 .63836 m
.90546 .6384 L
s
.90539 .63839 m
.90543 .63836 L
s
.90543 .63836 m
.90545 .63836 L
s
1 .046 0 r
.32054 .63806 m
.3203 .63836 L
s
.32075 .63822 m
.32054 .63806 L
s
1 .006 0 r
.90546 .6384 m
.90543 .63842 L
s
.90545 .63836 m
.90546 .6384 L
s
.90543 .63842 m
.90539 .63839 L
s
.90539 .63839 m
.90545 .63836 L
s
.90545 .63836 m
.90543 .63842 L
s
1 .046 0 r
.3203 .63836 m
.32051 .63852 L
s
0 .04 1 r
.42186 .29069 m
.4416 .30108 L
s
.40106 .31575 m
.42186 .29069 L
s
.42186 .29069 m
.40439 .2893 L
s
1 .199 0 r
.57703 .58029 m
.57559 .5817 L
s
.57503 .58015 m
.57703 .58029 L
s
1 .046 0 r
.32051 .63852 m
.32075 .63822 L
s
1 .199 0 r
.57559 .5817 m
.57503 .58015 L
s
1 .024 0 r
.67462 .58007 m
.67474 .58022 L
s
.6745 .58014 m
.67462 .58007 L
s
.67462 .58007 m
.67472 .58008 L
s
.67474 .58022 m
.67463 .5803 L
s
.67472 .58008 m
.67474 .58022 L
s
.67463 .5803 m
.6745 .58014 L
s
.6745 .58014 m
.67472 .58008 L
s
.67472 .58008 m
.67463 .5803 L
s
1 .151 0 r
.71349 .37729 m
.7133 .37722 L
s
.71321 .37584 m
.71349 .37729 L
s
.71349 .37729 m
.71238 .37667 L
s
.71413 .37639 m
.71349 .37729 L
s
.71232 .37348 m
.71349 .37729 L
s
1 .344 0 r
.42038 .43668 m
.4184 .43511 L
s
.4184 .43511 m
.42024 .43332 L
s
1 .457 0 r
.50209 .67023 m
.50286 .66656 L
s
1 .344 0 r
.42246 .43503 m
.42038 .43668 L
s
.42024 .43332 m
.42246 .43503 L
s
1 .215 0 r
.42942 .63942 m
.43028 .63785 L
s
1 .607 0 r
.40559 .34661 m
.40425 .35246 L
s
1 .151 0 r
.71321 .37584 m
.71238 .37667 L
s
.71413 .37639 m
.71321 .37584 L
s
1 .001 0 r
.90213 .4637 m
.90213 .4637 L
s
.90213 .46369 m
.90213 .4637 L
s
.90213 .4637 m
.90213 .4637 L
s
.90214 .4637 m
.90213 .4637 L
s
.90214 .46368 m
.90213 .4637 L
s
.90213 .46369 m
.90213 .4637 L
s
.90214 .4637 m
.90213 .46369 L
s
.90213 .4637 m
.90214 .4637 L
s
.90213 .4637 m
.90213 .4637 L
s
1 .459 0 r
.56639 .69555 m
.56599 .69648 L
s
.56593 .69183 m
.56639 .69555 L
s
.56971 .69381 m
.56639 .69555 L
s
1 .006 0 r
.84218 .60859 m
.84227 .60846 L
s
1 .459 0 r
.55097 .69554 m
.56971 .69381 L
s
1 .021 0 r
.61093 .55062 m
.61144 .55022 L
s
1 .005 0 r
.37967 .49266 m
.37962 .49253 L
s
.973 1 0 r
.43963 .34775 m
.46322 .32517 L
s
1 .003 0 r
.14841 .43469 m
.1484 .43461 L
s
1 .151 0 r
.71238 .37667 m
.7133 .37722 L
s
1 .003 0 r
.1484 .43461 m
.14842 .43463 L
s
.14838 .43462 m
.1484 .43461 L
s
.1484 .43461 m
.1484 .43461 L
s
.14842 .43463 m
.1484 .43464 L
s
.1484 .43461 m
.14842 .43463 L
s
.1484 .43464 m
.14838 .43462 L
s
.14838 .43462 m
.1484 .43461 L
s
.1484 .43461 m
.1484 .43464 L
s
1 .005 0 r
.37963 .49253 m
.37966 .49255 L
s
.3796 .49256 m
.37963 .49253 L
s
.37963 .49253 m
.37962 .49253 L
s
1 .006 0 r
.84225 .60846 m
.84229 .60849 L
s
.84223 .60848 m
.84225 .60846 L
s
.84225 .60846 m
.84227 .60846 L
s
.84229 .60849 m
.84226 .60852 L
s
.84227 .60846 m
.84229 .60849 L
s
1 .005 0 r
.37963 .49258 m
.3796 .49256 L
s
.3796 .49256 m
.37962 .49253 L
s
.37966 .49255 m
.37963 .49258 L
s
.37962 .49253 m
.37966 .49255 L
s
1 .006 0 r
.84226 .60852 m
.84223 .60848 L
s
.84223 .60848 m
.84227 .60846 L
s
1 .005 0 r
.37962 .49253 m
.37963 .49258 L
s
1 .006 0 r
.84227 .60846 m
.84226 .60852 L
s
1 .344 0 r
.47348 .60838 m
.47459 .60916 L
s
.47464 .60577 m
.47348 .60838 L
s
.47697 .60837 m
.47348 .60838 L
s
.47697 .60837 m
.47459 .60916 L
s
.47464 .60577 m
.47697 .60837 L
s
.47575 .60654 m
.47697 .60837 L
s
.46514 .60384 m
.47697 .60837 L
s
1 .318 0 r
.69601 .31848 m
.69497 .3184 L
s
.69481 .31554 m
.69601 .31848 L
s
.69601 .31848 m
.69319 .31756 L
s
.6966 .31639 m
.69601 .31848 L
s
.6904 .31092 m
.69601 .31848 L
s
1 .021 0 r
.61133 .5502 m
.61143 .55034 L
s
.61124 .55026 m
.61133 .5502 L
s
.61133 .5502 m
.61144 .55022 L
s
.61143 .55034 m
.61134 .5504 L
s
.61144 .55022 m
.61143 .55034 L
s
1 .151 0 r
.7133 .37722 m
.71413 .37639 L
s
1 .344 0 r
.47575 .60654 m
.47464 .60577 L
s
1 .021 0 r
.61134 .5504 m
.61124 .55026 L
s
.61124 .55026 m
.61144 .55022 L
s
.61144 .55022 m
.61134 .5504 L
s
1 .459 0 r
.56552 .69275 m
.56593 .69183 L
s
.56593 .69183 m
.56971 .69381 L
s
1 .344 0 r
.42024 .43332 m
.42038 .43668 L
s
.973 1 0 r
.6096 .34694 m
.61336 .34842 L
s
.6131 .33908 m
.6096 .34694 L
s
.62004 .34687 m
.6096 .34694 L
s
1 .01 0 r
.25635 .60786 m
.25631 .60786 L
s
.25632 .60776 m
.25635 .60786 L
s
.25635 .60786 m
.25626 .60783 L
s
.25637 .6078 m
.25635 .60786 L
s
.25618 .60764 m
.25635 .60786 L
s
.25632 .60776 m
.25626 .60783 L
s
.25637 .6078 m
.25632 .60776 L
s
.973 1 0 r
.62004 .34687 m
.61336 .34842 L
s
.6131 .33908 m
.62004 .34687 L
s
.61687 .34054 m
.62004 .34687 L
s
.58576 .33111 m
.62004 .34687 L
s
1 .318 0 r
.69481 .31554 m
.69319 .31756 L
s
.6966 .31639 m
.69481 .31554 L
s
1 .01 0 r
.25626 .60783 m
.25631 .60786 L
s
.25631 .60786 m
.25637 .6078 L
s
1 .115 0 r
.27271 .31699 m
.27333 .31764 L
s
.272 .31739 m
.27271 .31699 L
s
.27271 .31699 m
.27286 .31692 L
s
1 .007 0 r
.83892 .43382 m
.83893 .43382 L
s
.83892 .43375 m
.83892 .43382 L
s
.83892 .43382 m
.83888 .43379 L
s
.83896 .43378 m
.83892 .43382 L
s
.83894 .43364 m
.83892 .43382 L
s
.83892 .43375 m
.83888 .43379 L
s
.83896 .43378 m
.83892 .43375 L
s
.83888 .43379 m
.83893 .43382 L
s
.83893 .43382 m
.83896 .43378 L
s
1 .318 0 r
.62455 .72367 m
.62375 .72445 L
s
.62366 .7212 m
.62455 .72367 L
s
.62606 .72218 m
.62455 .72367 L
s
1 .134 0 r
.71896 .72364 m
.72279 .72145 L
s
1 .004 0 r
.77895 .57864 m
.77901 .57855 L
s
1 0 0 r
.54756 .52064 m
.54756 .52064 L
s
1 .01 0 r
.31617 .46264 m
.31612 .46239 L
s
1 .417 0 r
.37616 .31765 m
.38349 .30765 L
s
1 .115 0 r
.27333 .31764 m
.27262 .31803 L
s
.27286 .31692 m
.27333 .31764 L
s
.973 1 0 r
.61687 .34054 m
.6131 .33908 L
s
1 .004 0 r
.779 .57855 m
.77902 .57857 L
s
.77898 .57856 m
.779 .57855 L
s
.779 .57855 m
.77901 .57855 L
s
.77902 .57857 m
.779 .57859 L
s
.77901 .57855 m
.77902 .57857 L
s
.779 .57859 m
.77898 .57856 L
s
.77898 .57856 m
.77901 .57855 L
s
1 .318 0 r
.69319 .31756 m
.69497 .3184 L
s
1 .004 0 r
.77901 .57855 m
.779 .57859 L
s
1 .318 0 r
.62287 .72198 m
.62366 .7212 L
s
.62366 .7212 m
.62606 .72218 L
s
1 .035 0 r
.77571 .40447 m
.77572 .40445 L
s
.77569 .40413 m
.77571 .40447 L
s
.77571 .40447 m
.7755 .40431 L
s
.77591 .40428 m
.77571 .40447 L
s
.77567 .40358 m
.77571 .40447 L
s
1 .01 0 r
.31613 .46239 m
.31619 .46244 L
s
.31607 .46244 m
.31613 .46239 L
s
.31613 .46239 m
.31612 .46239 L
s
.31613 .46249 m
.31607 .46244 L
s
.31607 .46244 m
.31612 .46239 L
s
.31619 .46244 m
.31613 .46249 L
s
.31612 .46239 m
.31619 .46244 L
s
0 .197 1 r
.52431 .69445 m
.54424 .70821 L
s
1 .01 0 r
.31612 .46239 m
.31613 .46249 L
s
1 .202 0 r
.3369 .34492 m
.33801 .34605 L
s
.33568 .34562 m
.3369 .34492 L
s
.3369 .34492 m
.33722 .3448 L
s
1 .115 0 r
.27262 .31803 m
.272 .31739 L
s
.272 .31739 m
.27286 .31692 L
s
1 .035 0 r
.77569 .40413 m
.7755 .40431 L
s
.77591 .40428 m
.77569 .40413 L
s
.425 1 0 r
.50895 .56682 m
.50075 .57701 L
s
.5171 .572 m
.50895 .56682 L
s
1 .117 0 r
.58733 .49134 m
.58764 .49134 L
s
.58761 .49023 m
.58733 .49134 L
s
.58733 .49134 m
.58697 .49067 L
s
.58828 .4909 m
.58733 .49134 L
s
.58881 .48859 m
.58733 .49134 L
s
1 .035 0 r
.7755 .40431 m
.77572 .40445 L
s
.77572 .40445 m
.77591 .40428 L
s
1 .115 0 r
.27286 .31692 m
.27262 .31803 L
s
1 .202 0 r
.33801 .34605 m
.33679 .34675 L
s
.33722 .3448 m
.33801 .34605 L
s
1 .117 0 r
.58761 .49023 m
.58697 .49067 L
s
.58828 .4909 m
.58761 .49023 L
s
.58764 .49134 m
.58828 .4909 L
s
1 .459 0 r
.56971 .69381 m
.56599 .69648 L
s
.56552 .69275 m
.56971 .69381 L
s
1 .202 0 r
.33679 .34675 m
.33568 .34562 L
s
.33568 .34562 m
.33722 .3448 L
s
1 .117 0 r
.58697 .49067 m
.58764 .49134 L
s
1 .002 0 r
.19258 .57771 m
.19258 .57771 L
s
.19258 .5777 m
.19258 .57771 L
s
.19258 .57771 m
.19257 .5777 L
s
.19259 .5777 m
.19258 .57771 L
s
.19256 .57768 m
.19258 .57771 L
s
.19258 .5777 m
.19257 .5777 L
s
.19259 .5777 m
.19258 .5777 L
s
.19257 .5777 m
.19258 .57771 L
s
.19258 .57771 m
.19259 .5777 L
s
1 .048 0 r
.36159 .60671 m
.36136 .60676 L
s
.36139 .60628 m
.36159 .60671 L
s
.36159 .60671 m
.36113 .60659 L
s
.36162 .60644 m
.36159 .60671 L
s
.36054 .60574 m
.36159 .60671 L
s
1 .002 0 r
.94717 .60669 m
.9472 .60665 L
s
1 .22 0 r
.65562 .69374 m
.66262 .69051 L
s
1 .002 0 r
.71564 .54866 m
.71567 .54862 L
s
1 .398 0 r
.48412 .49063 m
.47602 .48199 L
s
1 .012 0 r
.25259 .43259 m
.25256 .43229 L
s
1 .002 0 r
.71566 .54862 m
.71567 .54863 L
s
.71565 .54863 m
.71566 .54862 L
s
.71566 .54862 m
.71567 .54862 L
s
.71567 .54863 m
.71566 .54864 L
s
.71567 .54862 m
.71567 .54863 L
s
.94719 .60665 m
.9472 .60666 L
s
.94718 .60665 m
.94719 .60665 L
s
.94719 .60665 m
.9472 .60665 L
s
.71566 .54864 m
.71565 .54863 L
s
.71565 .54863 m
.71567 .54862 L
s
.71567 .54862 m
.71566 .54864 L
s
.9472 .60666 m
.9472 .60667 L
s
.9472 .60665 m
.9472 .60666 L
s
.9472 .60667 m
.94718 .60665 L
s
.94718 .60665 m
.9472 .60665 L
s
.9472 .60665 m
.9472 .60667 L
s
1 .344 0 r
.47459 .60916 m
.47575 .60654 L
s
1 .048 0 r
.36139 .60628 m
.36113 .60659 L
s
.36162 .60644 m
.36139 .60628 L
s
.36113 .60659 m
.36136 .60676 L
s
1 .318 0 r
.69497 .3184 m
.6966 .31639 L
s
1 .012 0 r
.25257 .4323 m
.25264 .43236 L
s
.2525 .43235 m
.25257 .4323 L
s
.25257 .4323 m
.25256 .43229 L
s
.25264 .43236 m
.25256 .43241 L
s
.25256 .43229 m
.25264 .43236 L
s
.25256 .43241 m
.2525 .43235 L
s
.2525 .43235 m
.25256 .43229 L
s
1 .202 0 r
.33722 .3448 m
.33679 .34675 L
s
1 .012 0 r
.25256 .43229 m
.25256 .43241 L
s
1 .048 0 r
.36136 .60676 m
.36162 .60644 L
s
1 .59 0 r
.54835 .63539 m
.54828 .63643 L
s
.54824 .63056 m
.54835 .63539 L
s
.55315 .63341 m
.54835 .63539 L
s
1 .134 0 r
.72198 .7212 m
.72259 .72215 L
s
.72145 .72163 m
.72198 .7212 L
s
.72198 .7212 m
.72279 .72145 L
s
1 .318 0 r
.62606 .72218 m
.62375 .72445 L
s
.62287 .72198 m
.62606 .72218 L
s
1 .606 0 r
.52462 .57703 m
.52564 .57806 L
s
.52564 .57213 m
.52462 .57703 L
s
.53046 .5759 m
.52462 .57703 L
s
0 1 .566 r
.52457 .62274 m
.53791 .60606 L
s
.425 1 0 r
.50075 .57701 m
.50887 .58223 L
s
1 .134 0 r
.72259 .72215 m
.72206 .72257 L
s
.72279 .72145 m
.72259 .72215 L
s
0 .04 1 r
.42064 .3264 m
.40106 .31575 L
s
.40106 .31575 m
.40439 .2893 L
s
1 .459 0 r
.56599 .69648 m
.56552 .69275 L
s
1 .318 0 r
.62375 .72445 m
.62287 .72198 L
s
1 .057 0 r
.23814 .72206 m
.23785 .72214 L
s
.2379 .72155 m
.23814 .72206 L
s
.23814 .72206 m
.2376 .72193 L
s
.23816 .72176 m
.23814 .72206 L
s
.23682 .72099 m
.23814 .72206 L
s
1 .59 0 r
.54818 .63159 m
.54824 .63056 L
s
.54824 .63056 m
.55315 .63341 L
s
1 .057 0 r
.2379 .72155 m
.2376 .72193 L
s
.23816 .72176 m
.2379 .72155 L
s
.2376 .72193 m
.23785 .72214 L
s
1 .417 0 r
.45741 .72191 m
.45847 .72292 L
s
.45856 .71866 m
.45741 .72191 L
s
.46161 .72162 m
.45741 .72191 L
s
1 .001 0 r
.88392 .57671 m
.88394 .57668 L
s
1 .051 0 r
.82386 .72188 m
.82505 .72091 L
s
1 .39 0 r
.5922 .66381 m
.6066 .6597 L
s
1 0 0 r
.65226 .51864 m
.65226 .51864 L
s
1 .136 0 r
.4206 .46058 m
.42021 .45719 L
s
.542 1 0 r
.48066 .31541 m
.53381 .29646 L
s
1 .012 0 r
.18894 .40251 m
.18892 .40221 L
s
1 .001 0 r
.88394 .57668 m
.88394 .57669 L
s
.88393 .57669 m
.88394 .57668 L
s
.88394 .57668 m
.88394 .57668 L
s
.88394 .57669 m
.88394 .57669 L
s
.88394 .57668 m
.88394 .57669 L
s
.88394 .57669 m
.88393 .57669 L
s
.88393 .57669 m
.88394 .57668 L
s
.88394 .57668 m
.88394 .57669 L
s
1 .158 0 r
.34585 .72182 m
.3449 .72211 L
s
.34499 .72049 m
.34585 .72182 L
s
.34585 .72182 m
.34426 .72161 L
s
.34563 .72099 m
.34585 .72182 L
s
.34134 .71922 m
.34585 .72182 L
s
1 .057 0 r
.23785 .72214 m
.23816 .72176 L
s
1 .606 0 r
.52667 .57315 m
.52564 .57213 L
s
.52564 .57213 m
.53046 .5759 L
s
0 .813 1 r
.53439 .65542 m
.55095 .63464 L
s
1 .417 0 r
.45962 .71966 m
.45856 .71866 L
s
.45856 .71866 m
.46161 .72162 L
s
1 .012 0 r
.18893 .40221 m
.189 .40227 L
s
.18886 .40226 m
.18893 .40221 L
s
.18893 .40221 m
.18892 .40221 L
s
.189 .40227 m
.18892 .40232 L
s
.18892 .40221 m
.189 .40227 L
s
.18892 .40232 m
.18886 .40226 L
s
.18886 .40226 m
.18892 .40221 L
s
1 .158 0 r
.34499 .72049 m
.34426 .72161 L
s
.34563 .72099 m
.34499 .72049 L
s
1 .012 0 r
.18892 .40221 m
.18892 .40232 L
s
1 .134 0 r
.72206 .72257 m
.72145 .72163 L
s
.72145 .72163 m
.72279 .72145 L
s
1 .417 0 r
.46161 .72162 m
.45847 .72292 L
s
.45962 .71966 m
.46161 .72162 L
s
.44611 .71745 m
.46161 .72162 L
s
1 .158 0 r
.34426 .72161 m
.3449 .72211 L
s
1 .134 0 r
.72279 .72145 m
.72206 .72257 L
s
1 .114 0 r
.75495 .34403 m
.75478 .34397 L
s
.7547 .34293 m
.75495 .34403 L
s
.75495 .34403 m
.75408 .34358 L
s
.7554 .34332 m
.75495 .34403 L
s
.75391 .34113 m
.75495 .34403 L
s
0 .04 1 r
.62946 .31496 m
.61952 .3194 L
s
.61842 .28364 m
.62946 .31496 L
s
.64867 .29102 m
.62946 .31496 L
s
1 .114 0 r
.7547 .34293 m
.75408 .34358 L
s
.7554 .34332 m
.7547 .34293 L
s
1 .136 0 r
.63018 .45982 m
.63021 .45978 L
s
.63016 .4585 m
.63018 .45982 L
s
.63018 .45982 m
.62938 .45916 L
s
.63099 .45912 m
.63018 .45982 L
s
.6302 .45643 m
.63018 .45982 L
s
1 .051 0 r
.82479 .72084 m
.82507 .72117 L
s
.82456 .72103 m
.82479 .72084 L
s
.82479 .72084 m
.82505 .72091 L
s
1 .01 0 r
.88069 .40169 m
.8807 .40168 L
s
.88069 .40159 m
.88069 .40169 L
s
.88069 .40169 m
.88063 .40164 L
s
.88075 .40163 m
.88069 .40169 L
s
.8807 .40144 m
.88069 .40169 L
s
1 .114 0 r
.75408 .34358 m
.75478 .34397 L
s
1 .01 0 r
.88069 .40159 m
.88063 .40164 L
s
.88075 .40163 m
.88069 .40159 L
s
1 .051 0 r
.82507 .72117 m
.82484 .72136 L
s
.82505 .72091 m
.82507 .72117 L
s
1 .01 0 r
.88063 .40164 m
.8807 .40168 L
s
.8807 .40168 m
.88075 .40163 L
s
1 .606 0 r
.53046 .5759 m
.52564 .57806 L
s
.52667 .57315 m
.53046 .5759 L
s
.50634 .57186 m
.53046 .5759 L
s
1 .006 0 r
.29701 .57588 m
.29699 .57588 L
s
.29699 .57582 m
.29701 .57588 L
s
.29701 .57588 m
.29695 .57586 L
s
.29702 .57585 m
.29701 .57588 L
s
.29691 .57574 m
.29701 .57588 L
s
.29699 .57582 m
.29695 .57586 L
s
.29702 .57585 m
.29699 .57582 L
s
.29695 .57586 m
.29699 .57588 L
s
.29699 .57588 m
.29702 .57585 L
s
1 .051 0 r
.82484 .72136 m
.82456 .72103 L
s
.82456 .72103 m
.82505 .72091 L
s
1 .158 0 r
.3449 .72211 m
.34563 .72099 L
s
1 .073 0 r
.76051 .69194 m
.76226 .69057 L
s
1 0 0 r
.8206 .54669 m
.82061 .54668 L
s
1 .59 0 r
.52871 .63384 m
.55315 .63341 L
s
1 .07 0 r
.35701 .43049 m
.35711 .42872 L
s
1 .011 0 r
.12521 .37239 m
.1252 .3721 L
s
1 0 0 r
.82061 .54668 m
.82061 .54668 L
s
.82061 .54668 m
.82061 .54668 L
s
.82061 .54668 m
.82061 .54668 L
s
.82061 .54668 m
.82061 .54669 L
s
.82061 .54668 m
.82061 .54668 L
s
.82061 .54669 m
.82061 .54668 L
s
.82061 .54668 m
.82061 .54668 L
s
.82061 .54668 m
.82061 .54669 L
s
1 .051 0 r
.82505 .72091 m
.82484 .72136 L
s
1 .114 0 r
.75478 .34397 m
.7554 .34332 L
s
1 .136 0 r
.63016 .4585 m
.62938 .45916 L
s
.63099 .45912 m
.63016 .4585 L
s
1 .035 0 r
.81745 .37221 m
.81744 .37219 L
s
.81741 .37186 m
.81745 .37221 L
s
.81745 .37221 m
.81722 .37205 L
s
.81764 .372 m
.81745 .37221 L
s
.81734 .3713 m
.81745 .37221 L
s
1 .011 0 r
.12521 .3721 m
.12527 .37216 L
s
.12514 .37215 m
.12521 .3721 L
s
.12521 .3721 m
.1252 .3721 L
s
.12527 .37216 m
.1252 .37221 L
s
.1252 .3721 m
.12527 .37216 L
s
.1252 .37221 m
.12514 .37215 L
s
.12514 .37215 m
.1252 .3721 L
s
.1252 .3721 m
.1252 .37221 L
s
1 .035 0 r
.81741 .37186 m
.81722 .37205 L
s
.81764 .372 m
.81741 .37186 L
s
1 .457 0 r
.40251 .3687 m
.40506 .37129 L
s
.3998 .37031 m
.40251 .3687 L
s
.40251 .3687 m
.40336 .36849 L
s
1 .22 0 r
.66205 .69166 m
.66126 .69227 L
s
.66117 .69005 m
.66205 .69166 L
s
.66262 .69051 m
.66205 .69166 L
s
.66038 .69066 m
.66117 .69005 L
s
.66117 .69005 m
.66262 .69051 L
s
1 .035 0 r
.81722 .37205 m
.81744 .37219 L
s
.81744 .37219 m
.81764 .372 L
s
1 .136 0 r
.62938 .45916 m
.63021 .45978 L
s
.63021 .45978 m
.63099 .45912 L
s
1 .59 0 r
.55315 .63341 m
.54828 .63643 L
s
.54818 .63159 m
.55315 .63341 L
s
0 .04 1 r
.54658 .69122 m
.52596 .71718 L
s
.5676 .70555 m
.54658 .69122 L
s
1 0 0 r
.23321 .54571 m
.23321 .54571 L
s
.23321 .54571 m
.23321 .54571 L
s
.23321 .54571 m
.23321 .54571 L
s
.23322 .54571 m
.23321 .54571 L
s
.23321 .5457 m
.23321 .54571 L
s
.23321 .54571 m
.23321 .54571 L
s
.23322 .54571 m
.23321 .54571 L
s
.23321 .54571 m
.23321 .54571 L
s
.23321 .54571 m
.23322 .54571 L
s
1 .022 0 r
.92901 .72011 m
.92945 .71968 L
s
1 .116 0 r
.69708 .66197 m
.70006 .65987 L
s
1 0 0 r
.75721 .51664 m
.75721 .51664 L
s
.01 w
.52528 .4585 Mdot
1 .046 0 r
.5 Mabswid
.29334 .40037 m
.29347 .3992 L
s
1 .047 0 r
.4025 .57477 m
.4023 .5748 L
s
.40231 .57435 m
.4025 .57477 L
s
.4025 .57477 m
.40207 .57465 L
s
.40254 .5745 m
.4025 .57477 L
s
.40151 .5738 m
.4025 .57477 L
s
1 .457 0 r
.40506 .37129 m
.40235 .3729 L
s
.40336 .36849 m
.40506 .37129 L
s
1 .073 0 r
.76189 .69048 m
.76227 .69096 L
s
.76156 .69073 m
.76189 .69048 L
s
.76189 .69048 m
.76226 .69057 L
s
1 .047 0 r
.40231 .57435 m
.40207 .57465 L
s
.40254 .5745 m
.40231 .57435 L
s
1 .22 0 r
.38883 .69096 m
.38749 .69137 L
s
.38758 .68914 m
.38883 .69096 L
s
.38883 .69096 m
.38662 .69072 L
s
.38846 .6898 m
.38883 .69096 L
s
.38234 .68743 m
.38883 .69096 L
s
1 .073 0 r
.76227 .69096 m
.76194 .69122 L
s
.76226 .69057 m
.76227 .69096 L
s
1 .047 0 r
.40207 .57465 m
.4023 .5748 L
s
1 .07 0 r
.3571 .42874 m
.3575 .42909 L
s
.35667 .42905 m
.3571 .42874 L
s
.3571 .42874 m
.35711 .42872 L
s
1 .136 0 r
.42031 .45723 m
.42109 .45785 L
s
.41949 .45788 m
.42031 .45723 L
s
.42031 .45723 m
.42021 .45719 L
s
1 .047 0 r
.4023 .5748 m
.40254 .5745 L
s
1 .417 0 r
.45847 .72292 m
.45962 .71966 L
s
1 .22 0 r
.38758 .68914 m
.38662 .69072 L
s
.38846 .6898 m
.38758 .68914 L
s
1 .07 0 r
.3575 .42909 m
.35707 .4294 L
s
.35711 .42872 m
.3575 .42909 L
s
1 .022 0 r
.92935 .71965 m
.92947 .71979 L
s
.92925 .71974 m
.92935 .71965 L
s
.92935 .71965 m
.92945 .71968 L
s
1 .073 0 r
.76194 .69122 m
.76156 .69073 L
s
.76156 .69073 m
.76226 .69057 L
s
1 .22 0 r
.38662 .69072 m
.38749 .69137 L
s
1 .022 0 r
.92947 .71979 m
.92937 .71987 L
s
.92945 .71968 m
.92947 .71979 L
s
1 .07 0 r
.35707 .4294 m
.35667 .42905 L
s
.35667 .42905 m
.35711 .42872 L
s
0 .04 1 r
.60832 .28768 m
.61842 .28364 L
s
.61842 .28364 m
.64867 .29102 L
s
1 .073 0 r
.76226 .69057 m
.76194 .69122 L
s
1 .39 0 r
.60475 .66161 m
.60376 .66248 L
s
.60366 .65856 m
.60475 .66161 L
s
.6066 .6597 m
.60475 .66161 L
s
1 .022 0 r
.92937 .71987 m
.92925 .71974 L
s
.92925 .71974 m
.92945 .71968 L
s
1 .22 0 r
.66126 .69227 m
.66038 .69066 L
s
.66262 .69051 m
.66126 .69227 L
s
.66038 .69066 m
.66262 .69051 L
s
1 .022 0 r
.92945 .71968 m
.92937 .71987 L
s
1 .07 0 r
.35711 .42872 m
.35707 .4294 L
s
1 .066 0 r
.2791 .69051 m
.27878 .69059 L
s
.27883 .68992 m
.2791 .69051 L
s
.2791 .69051 m
.27847 .69035 L
s
.27913 .69016 m
.2791 .69051 L
s
.27759 .68924 m
.2791 .69051 L
s
1 .39 0 r
.60266 .65943 m
.60366 .65856 L
s
.60366 .65856 m
.6066 .6597 L
s
1 .136 0 r
.42027 .45851 m
.41949 .45788 L
s
.41949 .45788 m
.42021 .45719 L
s
.42109 .45785 m
.42027 .45851 L
s
.42021 .45719 m
.42109 .45785 L
s
1 .607 0 r
.50573 .69045 m
.50672 .69171 L
s
.50675 .68556 m
.50573 .69045 L
s
.51157 .68939 m
.50573 .69045 L
s
1 .066 0 r
.27883 .68992 m
.27847 .69035 L
s
.27913 .69016 m
.27883 .68992 L
s
1 .39 0 r
.65672 .3705 m
.65538 .37049 L
s
.65523 .36691 m
.65672 .3705 L
s
.65672 .3705 m
.65323 .36939 L
s
.65739 .368 m
.65672 .3705 L
s
.64963 .36145 m
.65672 .3705 L
s
1 .046 0 r
.29346 .39922 m
.29372 .39946 L
s
.29317 .39941 m
.29346 .39922 L
s
.29346 .39922 m
.29347 .3992 L
s
1 .066 0 r
.27847 .69035 m
.27878 .69059 L
s
0 1 .077 r
.61023 .38566 m
.61382 .36864 L
s
.808 1 0 r
.46201 .30347 m
.46778 .31149 L
s
.45601 .30617 m
.46201 .30347 L
s
.46201 .30347 m
.46742 .30351 L
s
1 .046 0 r
.29372 .39946 m
.29343 .39965 L
s
.29347 .3992 m
.29372 .39946 L
s
1 .59 0 r
.54828 .63643 m
.54818 .63159 L
s
1 .046 0 r
.29343 .39965 m
.29317 .39941 L
s
.29317 .39941 m
.29347 .3992 L
s
1 .457 0 r
.40235 .3729 m
.3998 .37031 L
s
.3998 .37031 m
.40336 .36849 L
s
1 .003 0 r
.69372 .48663 m
.69373 .48663 L
s
.69373 .4866 m
.69372 .48663 L
s
.69372 .48663 m
.69371 .48661 L
s
.69374 .48661 m
.69372 .48663 L
s
.69374 .48655 m
.69372 .48663 L
s
.69373 .4866 m
.69371 .48661 L
s
.69374 .48661 m
.69373 .4866 L
s
.69373 .48663 m
.69374 .48661 L
s
.69371 .48661 m
.69373 .48663 L
s
1 .136 0 r
.42021 .45719 m
.42027 .45851 L
s
1 .066 0 r
.27878 .69059 m
.27913 .69016 L
s
1 .046 0 r
.29347 .3992 m
.29343 .39965 L
s
1 .026 0 r
.86565 .69014 m
.86617 .68961 L
s
1 0 0 r
.92581 .54472 m
.92581 .54472 L
s
1 .215 0 r
.63358 .63197 m
.63993 .62842 L
s
.787 1 0 r
.46167 .42838 m
.47519 .39826 L
s
1 0 0 r
.16943 .51563 m
.16943 .51563 L
s
1 .033 0 r
.2296 .37021 m
.22971 .36935 L
s
1 0 0 r
.92581 .54472 m
.92581 .54472 L
s
.92581 .54472 m
.92581 .54472 L
s
.92581 .54472 m
.92581 .54472 L
s
.92581 .54472 m
.92581 .54472 L
s
.92581 .54472 m
.92581 .54472 L
s
.92581 .54472 m
.92581 .54472 L
s
.92581 .54472 m
.92581 .54472 L
s
.92581 .54472 m
.92581 .54472 L
s
0 1 .511 r
.48541 .29349 m
.4996 .30756 L
s
.47087 .30198 m
.48541 .29349 L
s
.48541 .29349 m
.49098 .29153 L
s
1 .607 0 r
.50774 .68682 m
.50675 .68556 L
s
.50675 .68556 m
.51157 .68939 L
s
1 .606 0 r
.52564 .57806 m
.52667 .57315 L
s
.973 1 0 r
.61336 .34842 m
.61687 .34054 L
s
1 .22 0 r
.38749 .69137 m
.38846 .6898 L
s
1 .026 0 r
.86605 .68958 m
.8662 .68974 L
s
.86593 .68968 m
.86605 .68958 L
s
.86605 .68958 m
.86617 .68961 L
s
1 .39 0 r
.65523 .36691 m
.65323 .36939 L
s
.65739 .368 m
.65523 .36691 L
s
1 .026 0 r
.8662 .68974 m
.86608 .68985 L
s
.86617 .68961 m
.8662 .68974 L
s
1 .336 0 r
.434 .66063 m
.43186 .6613 L
s
.43195 .65792 m
.434 .66063 L
s
.434 .66063 m
.43059 .66039 L
s
.43322 .65883 m
.434 .66063 L
s
.42349 .65552 m
.434 .66063 L
s
.808 1 0 r
.46778 .31149 m
.46179 .31422 L
s
.46742 .30351 m
.46778 .31149 L
s
1 .026 0 r
.86608 .68985 m
.86593 .68968 L
s
.86593 .68968 m
.86617 .68961 L
s
1 .116 0 r
.69944 .65971 m
.7 .6605 L
s
.69893 .66008 m
.69944 .65971 L
s
.69944 .65971 m
.70006 .65987 L
s
1 .026 0 r
.86617 .68961 m
.86608 .68985 L
s
1 .033 0 r
.2297 .36937 m
.22989 .36954 L
s
.22949 .3695 m
.2297 .36937 L
s
.2297 .36937 m
.22971 .36935 L
s
1 .116 0 r
.7 .6605 m
.6995 .66087 L
s
.70006 .65987 m
.7 .6605 L
s
1 .033 0 r
.22989 .36954 m
.22967 .36967 L
s
.22971 .36935 m
.22989 .36954 L
s
1 .457 0 r
.40336 .36849 m
.40235 .3729 L
s
1 .033 0 r
.22967 .36967 m
.22949 .3695 L
s
.22949 .3695 m
.22971 .36935 L
s
1 .336 0 r
.43195 .65792 m
.43059 .66039 L
s
.43322 .65883 m
.43195 .65792 L
s
1 .033 0 r
.22971 .36935 m
.22967 .36967 L
s
1 .336 0 r
.43059 .66039 m
.43186 .6613 L
s
1 .39 0 r
.65323 .36939 m
.65538 .37049 L
s
1 .59 0 r
.47913 .63122 m
.48105 .6326 L
s
.48113 .62672 m
.47913 .63122 L
s
.48514 .63119 m
.47913 .63122 L
s
1 .607 0 r
.51157 .68939 m
.50672 .69171 L
s
.50774 .68682 m
.51157 .68939 L
s
.48735 .68561 m
.51157 .68939 L
s
1 .59 0 r
.48514 .63119 m
.48105 .6326 L
s
.48113 .62672 m
.48514 .63119 L
s
.48306 .62809 m
.48514 .63119 L
s
.46479 .6235 m
.48514 .63119 L
s
.285 1 0 r
.59585 .39832 m
.59918 .4002 L
s
.59881 .38428 m
.59585 .39832 L
s
.61256 .39477 m
.59585 .39832 L
s
1 .091 0 r
.79654 .311 m
.7964 .31094 L
s
.79632 .31012 m
.79654 .311 L
s
.79654 .311 m
.79583 .31065 L
s
.79688 .31042 m
.79654 .311 L
s
.79564 .30867 m
.79654 .311 L
s
0 .197 1 r
.42386 .31214 m
.44292 .32236 L
s
.4038 .33636 m
.42386 .31214 L
s
.42386 .31214 m
.40705 .31112 L
s
1 .002 0 r
.33781 .54377 m
.33781 .54377 L
s
.33781 .54376 m
.33781 .54377 L
s
.33781 .54377 m
.3378 .54377 L
s
.33782 .54376 m
.33781 .54377 L
s
.33779 .54373 m
.33781 .54377 L
s
.33781 .54376 m
.3378 .54377 L
s
.33782 .54376 m
.33781 .54376 L
s
.3378 .54377 m
.33781 .54377 L
s
.33781 .54377 m
.33782 .54376 L
s
1 .59 0 r
.48306 .62809 m
.48113 .62672 L
s
1 .033 0 r
.8022 .66013 m
.80286 .65945 L
s
1 0 0 r
.86241 .51463 m
.86241 .51463 L
s
1 .481 0 r
.57 .60193 m
.58775 .59664 L
s
1 .303 0 r
.39799 .39822 m
.40107 .39066 L
s
1 .026 0 r
.16579 .34002 m
.16587 .33933 L
s
1 .116 0 r
.6995 .66087 m
.69893 .66008 L
s
.69893 .66008 m
.70006 .65987 L
s
1 .417 0 r
.3821 .30777 m
.38426 .31041 L
s
.37977 .3089 m
.3821 .30777 L
s
.3821 .30777 m
.38349 .30765 L
s
1 .091 0 r
.79632 .31012 m
.79583 .31065 L
s
.79688 .31042 m
.79632 .31012 L
s
1 .116 0 r
.70006 .65987 m
.6995 .66087 L
s
1 .034 0 r
.85931 .3398 m
.8593 .33977 L
s
.85926 .33946 m
.85931 .3398 L
s
.85931 .3398 m
.85908 .33965 L
s
.85948 .33959 m
.85931 .3398 L
s
.85916 .33891 m
.85931 .3398 L
s
1 .091 0 r
.79583 .31065 m
.7964 .31094 L
s
1 .034 0 r
.85926 .33946 m
.85908 .33965 L
s
.85948 .33959 m
.85926 .33946 L
s
.787 1 0 r
.54292 .60163 m
.54505 .6038 L
s
.54498 .5918 m
.54292 .60163 L
s
.55466 .59939 m
.54292 .60163 L
s
1 .034 0 r
.85908 .33965 m
.8593 .33977 L
s
0 .434 1 r
.5404 .68317 m
.55896 .65982 L
s
1 .111 0 r
.67231 .42694 m
.67222 .4269 L
s
.67217 .42586 m
.67231 .42694 L
s
.67231 .42694 m
.67154 .42645 L
s
.67285 .42631 m
.67231 .42694 L
s
.67174 .42415 m
.67231 .42694 L
s
1 .034 0 r
.8593 .33977 m
.85948 .33959 L
s
1 .026 0 r
.16587 .33935 m
.16601 .33949 L
s
.1657 .33945 m
.16587 .33935 L
s
.16587 .33935 m
.16587 .33933 L
s
1 .091 0 r
.7964 .31094 m
.79688 .31042 L
s
1 .417 0 r
.38426 .31041 m
.38193 .31154 L
s
.38349 .30765 m
.38426 .31041 L
s
1 .023 0 r
.2142 .6597 m
.2141 .65972 L
s
.21412 .65949 m
.2142 .6597 L
s
.2142 .6597 m
.21399 .65963 L
s
.21424 .65958 m
.2142 .6597 L
s
.21376 .65921 m
.2142 .6597 L
s
1 .39 0 r
.6066 .6597 m
.60376 .66248 L
s
.60266 .65943 m
.6066 .6597 L
s
1 .026 0 r
.16601 .33949 m
.16584 .33959 L
s
.16587 .33933 m
.16601 .33949 L
s
1 .033 0 r
.80272 .65942 m
.80291 .65963 L
s
.80256 .65955 m
.80272 .65942 L
s
.80272 .65942 m
.80286 .65945 L
s
1 .026 0 r
.16584 .33959 m
.1657 .33945 L
s
.1657 .33945 m
.16587 .33933 L
s
1 .023 0 r
.21412 .65949 m
.21399 .65963 L
s
.21424 .65958 m
.21412 .65949 L
s
.21399 .65963 m
.2141 .65972 L
s
1 .033 0 r
.80291 .65963 m
.80275 .65976 L
s
.80286 .65945 m
.80291 .65963 L
s
1 .026 0 r
.16587 .33933 m
.16584 .33959 L
s
1 .39 0 r
.60376 .66248 m
.60266 .65943 L
s
1 .023 0 r
.2141 .65972 m
.21424 .65958 L
s
1 .111 0 r
.67217 .42586 m
.67154 .42645 L
s
.67285 .42631 m
.67217 .42586 L
s
1 .033 0 r
.80275 .65976 m
.80256 .65955 L
s
.80256 .65955 m
.80286 .65945 L
s
.80286 .65945 m
.80275 .65976 L
s
1 .398 0 r
.47767 .48182 m
.47971 .48305 L
s
.47559 .48439 m
.47767 .48182 L
s
.47767 .48182 m
.47602 .48199 L
s
1 .111 0 r
.67154 .42645 m
.67222 .4269 L
s
.425 1 0 r
.50887 .58223 m
.5171 .572 L
s
1 .111 0 r
.67222 .4269 m
.67285 .42631 L
s
1 0 0 r
.79892 .48452 m
.79892 .48451 L
s
.79892 .48451 m
.79892 .48452 L
s
.79892 .48452 m
.79892 .48451 L
s
.79892 .48451 m
.79892 .48452 L
s
.79892 .4845 m
.79892 .48452 L
s
.79892 .48451 m
.79892 .48451 L
s
.79892 .48451 m
.79892 .48451 L
s
.79892 .48451 m
.79892 .48451 L
s
.79892 .48451 m
.79892 .48451 L
s
1 .011 0 r
.97103 .68833 m
.97123 .6881 L
s
1 .046 0 r
.73869 .6301 m
.7396 .62916 L
s
1 0 0 r
.274 .51362 m
.274 .51362 L
s
1 .137 0 r
.33424 .36803 m
.33551 .36455 L
s
1 .022 0 r
.1019 .30979 m
.10196 .30922 L
s
1 .39 0 r
.65538 .37049 m
.65739 .368 L
s
1 .398 0 r
.47762 .48562 m
.47559 .48439 L
s
.47559 .48439 m
.47602 .48199 L
s
1 .011 0 r
.97118 .68809 m
.97125 .68816 L
s
.97113 .68814 m
.97118 .68809 L
s
.97118 .68809 m
.97123 .6881 L
s
.97125 .68816 m
.97119 .6882 L
s
.97123 .6881 m
.97125 .68816 L
s
.97119 .6882 m
.97113 .68814 L
s
.97113 .68814 m
.97123 .6881 L
s
.97123 .6881 m
.97119 .6882 L
s
.285 1 0 r
.60216 .38608 m
.59881 .38428 L
s
.59881 .38428 m
.61256 .39477 L
s
.787 1 0 r
.54712 .59394 m
.54498 .5918 L
s
.54498 .5918 m
.55466 .59939 L
s
0 .04 1 r
.52596 .71718 m
.54683 .7318 L
s
1 .08 0 r
.32029 .65893 m
.31991 .65902 L
s
.31996 .65822 m
.32029 .65893 L
s
.32029 .65893 m
.31953 .65874 L
s
.32033 .6585 m
.32029 .65893 L
s
.31851 .65737 m
.32029 .65893 L
s
1 .032 0 r
.44328 .54242 m
.44314 .54244 L
s
.44315 .54213 m
.44328 .54242 L
s
.44328 .54242 m
.44298 .54234 L
s
.44331 .54223 m
.44328 .54242 L
s
.44262 .54175 m
.44328 .54242 L
s
1 .022 0 r
.10196 .30924 m
.10207 .30935 L
s
.10182 .30932 m
.10196 .30924 L
s
.10196 .30924 m
.10196 .30922 L
s
1 .032 0 r
.44315 .54213 m
.44298 .54234 L
s
.44331 .54223 m
.44315 .54213 L
s
1 .022 0 r
.10207 .30935 m
.10193 .30943 L
s
.10196 .30922 m
.10207 .30935 L
s
1 .032 0 r
.44298 .54234 m
.44314 .54244 L
s
1 .336 0 r
.43186 .6613 m
.43322 .65883 L
s
1 .022 0 r
.10193 .30943 m
.10182 .30932 L
s
.10182 .30932 m
.10196 .30922 L
s
1 .08 0 r
.31996 .65822 m
.31953 .65874 L
s
.32033 .6585 m
.31996 .65822 L
s
1 .022 0 r
.10196 .30922 m
.10193 .30943 L
s
1 .215 0 r
.63862 .62806 m
.63955 .6296 L
s
.63776 .62865 m
.63862 .62806 L
s
.63862 .62806 m
.63993 .62842 L
s
1 .575 0 r
.64429 .30922 m
.64103 .30967 L
s
.64083 .30448 m
.64429 .30922 L
s
.64429 .30922 m
.6385 .30871 L
s
.64337 .30544 m
.64429 .30922 L
s
.62742 .29846 m
.64429 .30922 L
s
1 .032 0 r
.44314 .54244 m
.44331 .54223 L
s
1 .08 0 r
.31953 .65874 m
.31991 .65902 L
s
1 .215 0 r
.63955 .6296 m
.63869 .6302 L
s
.63993 .62842 m
.63955 .6296 L
s
1 .046 0 r
.73941 .62912 m
.73966 .62941 L
s
.73918 .62928 m
.73941 .62912 L
s
.73941 .62912 m
.7396 .62916 L
s
.73966 .62941 m
.73944 .62957 L
s
.7396 .62916 m
.73966 .62941 L
s
1 .01 0 r
.73535 .4546 m
.73536 .4546 L
s
.73535 .4545 m
.73535 .4546 L
s
.73535 .4546 m
.73529 .45455 L
s
.73542 .45455 m
.73535 .4546 L
s
.73537 .45434 m
.73535 .4546 L
s
.73535 .4545 m
.73529 .45455 L
s
.73542 .45455 m
.73535 .4545 L
s
1 .08 0 r
.31991 .65902 m
.32033 .6585 L
s
1 .417 0 r
.38193 .31154 m
.37977 .3089 L
s
.37977 .3089 m
.38349 .30765 L
s
1 .01 0 r
.73529 .45455 m
.73536 .4546 L
s
.73536 .4546 m
.73542 .45455 L
s
1 .046 0 r
.73944 .62957 m
.73918 .62928 L
s
.73918 .62928 m
.7396 .62916 L
s
.7396 .62916 m
.73944 .62957 L
s
1 .575 0 r
.64083 .30448 m
.6385 .30871 L
s
.64337 .30544 m
.64083 .30448 L
s
.6385 .30871 m
.64103 .30967 L
s
1 .012 0 r
.90757 .65829 m
.90778 .65804 L
s
1 .07 0 r
.6751 .60002 m
.67659 .59859 L
s
0 .813 1 r
.50289 .39607 m
.62139 .35577 L
s
1 0 0 r
.21014 .48348 m
.21014 .48347 L
s
1 .081 0 r
.27041 .3378 m
.27109 .33572 L
s
1 0 0 r
.21014 .48347 m
.21014 .48347 L
s
.21013 .48347 m
.21014 .48347 L
s
.21014 .48347 m
.21014 .48347 L
s
.21014 .48347 m
.21013 .48347 L
s
.21013 .48347 m
.21014 .48347 L
s
.21014 .48347 m
.21014 .48347 L
s
.21014 .48347 m
.21014 .48347 L
s
.21014 .48347 m
.21014 .48347 L
s
1 .417 0 r
.38349 .30765 m
.38193 .31154 L
s
1 .012 0 r
.90773 .65803 m
.9078 .6581 L
s
.90767 .65808 m
.90773 .65803 L
s
.90773 .65803 m
.90778 .65804 L
s
1 .607 0 r
.50672 .69171 m
.50774 .68682 L
s
1 .012 0 r
.9078 .6581 m
.90774 .65815 L
s
.90778 .65804 m
.9078 .6581 L
s
.90774 .65815 m
.90767 .65808 L
s
.90767 .65808 m
.90778 .65804 L
s
.90778 .65804 m
.90774 .65815 L
s
1 .398 0 r
.47971 .48305 m
.47762 .48562 L
s
.47602 .48199 m
.47971 .48305 L
s
1 .215 0 r
.63869 .6302 m
.63776 .62865 L
s
.63776 .62865 m
.63993 .62842 L
s
.63993 .62842 m
.63869 .6302 L
s
.787 1 0 r
.55466 .59939 m
.54505 .6038 L
s
.54712 .59394 m
.55466 .59939 L
s
.50623 .59136 m
.55466 .59939 L
s
1 .398 0 r
.47602 .48199 m
.47762 .48562 L
s
1 .59 0 r
.48105 .6326 m
.48306 .62809 L
s
1 .481 0 r
.5855 .5991 m
.58423 .60008 L
s
.58415 .59532 m
.5855 .5991 L
s
.58775 .59664 m
.5855 .5991 L
s
1 .575 0 r
.57056 .71569 m
.57006 .7169 L
s
.56998 .71101 m
.57056 .71569 L
s
.57475 .71352 m
.57056 .71569 L
s
0 1 .511 r
.4996 .30756 m
.48511 .31614 L
s
.49098 .29153 m
.4996 .30756 L
s
1 0 0 r
.90435 .48246 m
.90435 .48246 L
s
.90435 .48245 m
.90435 .48246 L
s
.90435 .48246 m
.90435 .48246 L
s
.90435 .48246 m
.90435 .48246 L
s
.90435 .48245 m
.90435 .48246 L
s
.90435 .48245 m
.90435 .48246 L
s
.90435 .48246 m
.90435 .48245 L
s
.90435 .48246 m
.90435 .48246 L
s
.90435 .48246 m
.90435 .48246 L
s
1 .013 0 r
.84405 .62822 m
.84425 .62794 L
s
1 .575 0 r
.55112 .71567 m
.57475 .71352 L
s
1 .136 0 r
.61143 .56991 m
.6148 .56729 L
s
1 0 0 r
.37881 .51161 m
.37881 .51161 L
s
1 .825 0 r
.43912 .36584 m
.45814 .34782 L
s
1 .001 0 r
.1462 .4533 m
.14619 .45327 L
s
1 .055 0 r
.20651 .30754 m
.20692 .3061 L
s
1 .001 0 r
.1462 .45327 m
.1462 .45328 L
s
.14619 .45328 m
.1462 .45327 L
s
.1462 .45327 m
.14619 .45327 L
s
1 .07 0 r
.67627 .59853 m
.67665 .59898 L
s
.67593 .59877 m
.67627 .59853 L
s
.67627 .59853 m
.67659 .59859 L
s
1 .001 0 r
.1462 .45328 m
.14619 .45328 L
s
.14619 .45327 m
.1462 .45328 L
s
.14619 .45328 m
.14619 .45328 L
s
.14619 .45328 m
.14619 .45327 L
s
.14619 .45327 m
.14619 .45328 L
s
1 .07 0 r
.67665 .59898 m
.67631 .59922 L
s
.67659 .59859 m
.67665 .59898 L
s
1 .137 0 r
.33529 .36462 m
.33605 .3654 L
s
.33446 .3651 m
.33529 .36462 L
s
.33529 .36462 m
.33551 .36455 L
s
1 .013 0 r
.8442 .62793 m
.84428 .62801 L
s
.84414 .62798 m
.8442 .62793 L
s
.8442 .62793 m
.84425 .62794 L
s
1 .481 0 r
.58288 .5963 m
.58415 .59532 L
s
.58415 .59532 m
.58775 .59664 L
s
.285 1 0 r
.61256 .39477 m
.59918 .4002 L
s
.60216 .38608 m
.61256 .39477 L
s
.54436 .38197 m
.61256 .39477 L
s
1 .013 0 r
.84428 .62801 m
.84422 .62806 L
s
.84425 .62794 m
.84428 .62801 L
s
.84422 .62806 m
.84414 .62798 L
s
.84414 .62798 m
.84425 .62794 L
s
.84425 .62794 m
.84422 .62806 L
s
1 .081 0 r
.27098 .33577 m
.27143 .33622 L
s
.27048 .33605 m
.27098 .33577 L
s
.27098 .33577 m
.27109 .33572 L
s
0 .197 1 r
.42271 .34683 m
.4038 .33636 L
s
.4038 .33636 m
.40705 .31112 L
s
1 .07 0 r
.67631 .59922 m
.67593 .59877 L
s
.67593 .59877 m
.67659 .59859 L
s
.67659 .59859 m
.67631 .59922 L
s
1 .137 0 r
.33605 .3654 m
.33522 .36588 L
s
.33551 .36455 m
.33605 .3654 L
s
1 .081 0 r
.27143 .33622 m
.27092 .3365 L
s
.27109 .33572 m
.27143 .33622 L
s
1 .575 0 r
.56947 .71221 m
.56998 .71101 L
s
.56998 .71101 m
.57475 .71352 L
s
1 .022 0 r
.25498 .62775 m
.25489 .62777 L
s
.25491 .62755 m
.25498 .62775 L
s
.25498 .62775 m
.25478 .62768 L
s
.25502 .62763 m
.25498 .62775 L
s
.25459 .62727 m
.25498 .62775 L
s
.25491 .62755 m
.25478 .62768 L
s
.25502 .62763 m
.25491 .62755 L
s
.25478 .62768 m
.25489 .62777 L
s
1 .081 0 r
.27092 .3365 m
.27048 .33605 L
s
.27048 .33605 m
.27109 .33572 L
s
1 .022 0 r
.25489 .62777 m
.25502 .62763 L
s
1 .137 0 r
.33522 .36588 m
.33446 .3651 L
s
.33446 .3651 m
.33551 .36455 L
s
1 .081 0 r
.27109 .33572 m
.27092 .3365 L
s
1 .481 0 r
.61755 .4233 m
.61582 .42339 L
s
.61569 .41888 m
.61755 .4233 L
s
.61755 .4233 m
.6132 .42197 L
s
.61831 .42029 m
.61755 .4233 L
s
.60852 .4124 m
.61755 .4233 L
s
1 .055 0 r
.20686 .30614 m
.20716 .30645 L
s
.20651 .30633 m
.20686 .30614 L
s
.20686 .30614 m
.20692 .3061 L
s
1 .1 0 r
.36175 .62738 m
.36129 .62748 L
s
.36134 .62649 m
.36175 .62738 L
s
.36175 .62738 m
.36081 .62714 L
s
.36182 .62683 m
.36175 .62738 L
s
.35957 .62539 m
.36175 .62738 L
s
1 .137 0 r
.33551 .36455 m
.33522 .36588 L
s
1 .09 0 r
.71412 .39402 m
.71401 .39399 L
s
.71396 .39315 m
.71412 .39402 L
s
.71412 .39402 m
.71346 .39365 L
s
.71451 .39349 m
.71412 .39402 L
s
.71342 .39175 m
.71412 .39402 L
s
1 .002 0 r
.84078 .45231 m
.84078 .45231 L
s
.84078 .45229 m
.84078 .45231 L
s
.84078 .45231 m
.84077 .4523 L
s
.84079 .4523 m
.84078 .45231 L
s
.84078 .45226 m
.84078 .45231 L
s
.84078 .45229 m
.84077 .4523 L
s
.84079 .4523 m
.84078 .45229 L
s
.84077 .4523 m
.84078 .45231 L
s
.84078 .45231 m
.84079 .4523 L
s
1 .055 0 r
.20716 .30645 m
.20681 .30664 L
s
.20692 .3061 m
.20716 .30645 L
s
1 .013 0 r
.78044 .5981 m
.78064 .59781 L
s
1 .398 0 r
.54769 .53976 m
.56236 .5352 L
s
1 .001 0 r
.31494 .48143 m
.31493 .48139 L
s
1 .323 0 r
.37528 .33558 m
.38098 .32787 L
s
1 .001 0 r
.31493 .48139 m
.31494 .4814 L
s
.31492 .4814 m
.31493 .48139 L
s
.31493 .48139 m
.31493 .48139 L
s
.31493 .4814 m
.31492 .4814 L
s
.31492 .4814 m
.31493 .48139 L
s
.31494 .4814 m
.31493 .4814 L
s
.31493 .48139 m
.31494 .4814 L
s
.31493 .48139 m
.31493 .4814 L
s
1 .1 0 r
.36134 .62649 m
.36081 .62714 L
s
.36182 .62683 m
.36134 .62649 L
s
1 .055 0 r
.20681 .30664 m
.20651 .30633 L
s
.20651 .30633 m
.20692 .3061 L
s
1 .09 0 r
.71396 .39315 m
.71346 .39365 L
s
.71451 .39349 m
.71396 .39315 L
s
1 .1 0 r
.36081 .62714 m
.36129 .62748 L
s
1 .055 0 r
.20692 .3061 m
.20681 .30664 L
s
.808 1 0 r
.46179 .31422 m
.45601 .30617 L
s
.45601 .30617 m
.46742 .30351 L
s
1 .013 0 r
.7806 .5978 m
.78068 .59788 L
s
.78053 .59786 m
.7806 .5978 L
s
.7806 .5978 m
.78064 .59781 L
s
.78068 .59788 m
.78061 .59793 L
s
.78064 .59781 m
.78068 .59788 L
s
1 .09 0 r
.71346 .39365 m
.71401 .39399 L
s
1 .013 0 r
.78061 .59793 m
.78053 .59786 L
s
.78053 .59786 m
.78064 .59781 L
s
.78064 .59781 m
.78061 .59793 L
s
1 .09 0 r
.71401 .39399 m
.71451 .39349 L
s
1 .1 0 r
.36129 .62748 m
.36182 .62683 L
s
1 .016 0 r
.77716 .42243 m
.77716 .42242 L
s
.77715 .42227 m
.77716 .42243 L
s
.77716 .42243 m
.77706 .42236 L
s
.77725 .42234 m
.77716 .42243 L
s
.77714 .42202 m
.77716 .42243 L
s
1 .481 0 r
.61569 .41888 m
.6132 .42197 L
s
.61831 .42029 m
.61569 .41888 L
s
1 .016 0 r
.77715 .42227 m
.77706 .42236 L
s
.77725 .42234 m
.77715 .42227 L
s
1 .825 0 r
.55633 .65581 m
.55626 .65734 L
s
.55618 .64903 m
.55633 .65581 L
s
.5631 .65306 m
.55633 .65581 L
s
1 .016 0 r
.77706 .42236 m
.77716 .42242 L
s
.77716 .42242 m
.77725 .42234 L
s
1 .136 0 r
.61411 .56715 m
.61477 .56808 L
s
.61348 .56756 m
.61411 .56715 L
s
.61411 .56715 m
.6148 .56729 L
s
1 .303 0 r
.40051 .39077 m
.4022 .3925 L
s
.3987 .39186 m
.40051 .39077 L
s
.40051 .39077 m
.40107 .39066 L
s
1 .575 0 r
.64103 .30967 m
.64337 .30544 L
s
.808 1 0 r
.46742 .30351 m
.46179 .31422 L
s
1 .136 0 r
.61477 .56808 m
.61414 .56848 L
s
.6148 .56729 m
.61477 .56808 L
s
1 .005 0 r
.19067 .59726 m
.19066 .59726 L
s
.19066 .59721 m
.19067 .59726 L
s
.19067 .59726 m
.19063 .59724 L
s
.19069 .59723 m
.19067 .59726 L
s
.19061 .59714 m
.19067 .59726 L
s
.19066 .59721 m
.19063 .59724 L
s
.19069 .59723 m
.19066 .59721 L
s
1 .241 0 r
.69564 .33458 m
.69485 .33453 L
s
.69473 .33234 m
.69564 .33458 L
s
.69564 .33458 m
.69349 .33388 L
s
.69609 .333 m
.69564 .33458 L
s
.69137 .32887 m
.69564 .33458 L
s
1 .005 0 r
.19063 .59724 m
.19066 .59726 L
s
.19066 .59726 m
.19069 .59723 L
s
.542 1 0 r
.52723 .30529 m
.52309 .30688 L
s
.5231 .29371 m
.52723 .30529 L
s
.53381 .29646 m
.52723 .30529 L
s
1 .005 0 r
.94965 .62633 m
.94972 .62623 L
s
1 .293 0 r
.65638 .71389 m
.66577 .70963 L
s
1 .013 0 r
.71676 .56796 m
.71695 .56767 L
s
1 0 0 r
.48387 .50958 m
.48387 .50958 L
s
1 .004 0 r
.25098 .45121 m
.25098 .45112 L
s
1 .168 0 r
.31136 .30528 m
.31383 .3011 L
s
1 .481 0 r
.6132 .42197 m
.61582 .42339 L
s
1 .004 0 r
.25098 .45112 m
.251 .45114 L
s
.25096 .45113 m
.25098 .45112 L
s
.25098 .45112 m
.25098 .45112 L
s
.251 .45114 m
.25098 .45115 L
s
.25098 .45112 m
.251 .45114 L
s
.25098 .45115 m
.25096 .45113 L
s
.25096 .45113 m
.25098 .45112 L
s
1 .005 0 r
.9497 .62623 m
.94973 .62625 L
s
.94968 .62625 m
.9497 .62623 L
s
.9497 .62623 m
.94972 .62623 L
s
1 .004 0 r
.25098 .45112 m
.25098 .45115 L
s
1 .005 0 r
.94973 .62625 m
.94971 .62627 L
s
.94972 .62623 m
.94973 .62625 L
s
.94971 .62627 m
.94968 .62625 L
s
.94968 .62625 m
.94972 .62623 L
s
.94972 .62623 m
.94971 .62627 L
s
1 .013 0 r
.71691 .56767 m
.71698 .56774 L
s
.71684 .56772 m
.71691 .56767 L
s
.71691 .56767 m
.71695 .56767 L
s
.71698 .56774 m
.71691 .56779 L
s
.71695 .56767 m
.71698 .56774 L
s
.71691 .56779 m
.71684 .56772 L
s
.71684 .56772 m
.71695 .56767 L
s
.71695 .56767 m
.71691 .56779 L
s
1 .303 0 r
.4022 .3925 m
.40039 .39359 L
s
.40107 .39066 m
.4022 .3925 L
s
1 .241 0 r
.69473 .33234 m
.69349 .33388 L
s
.69609 .333 m
.69473 .33234 L
s
1 .136 0 r
.61414 .56848 m
.61348 .56756 L
s
.61348 .56756 m
.6148 .56729 L
s
1 .575 0 r
.57475 .71352 m
.57006 .7169 L
s
.56947 .71221 m
.57475 .71352 L
s
0 .197 1 r
.62499 .33398 m
.61534 .3385 L
s
.61432 .30376 m
.62499 .33398 L
s
.64347 .3111 m
.62499 .33398 L
s
1 .825 0 r
.55611 .65054 m
.55618 .64903 L
s
.55618 .64903 m
.5631 .65306 L
s
1 .136 0 r
.6148 .56729 m
.61414 .56848 L
s
1 .241 0 r
.69349 .33388 m
.69485 .33453 L
s
1 .481 0 r
.58775 .59664 m
.58423 .60008 L
s
.58288 .5963 m
.58775 .59664 L
s
.58423 .60008 m
.58288 .5963 L
s
.808 1 0 r
.56174 .30454 m
.56166 .30527 L
s
.56153 .2945 m
.56174 .30454 L
s
.57155 .29966 m
.56174 .30454 L
s
.542 1 0 r
.51894 .29524 m
.5231 .29371 L
s
.5231 .29371 m
.53381 .29646 L
s
1 .303 0 r
.40039 .39359 m
.3987 .39186 L
s
.3987 .39186 m
.40107 .39066 L
s
.285 1 0 r
.55813 .62548 m
.56125 .6287 L
s
.56106 .61156 m
.55813 .62548 L
s
.57482 .62235 m
.55813 .62548 L
s
1 .004 0 r
.88604 .59618 m
.88609 .5961 L
s
1 .525 0 r
.59259 .6838 m
.61213 .67829 L
s
1 .008 0 r
.65301 .53778 m
.65312 .53758 L
s
1 .021 0 r
.41998 .47937 m
.41992 .47885 L
s
.717 1 0 r
.4804 .33335 m
.52739 .31675 L
s
1 .005 0 r
.18696 .42096 m
.18695 .42083 L
s
1 .004 0 r
.88607 .5961 m
.8861 .59612 L
s
.88605 .59611 m
.88607 .5961 L
s
.88607 .5961 m
.88609 .5961 L
s
.8861 .59612 m
.88608 .59613 L
s
.88609 .5961 m
.8861 .59612 L
s
.88608 .59613 m
.88605 .59611 L
s
.88605 .59611 m
.88609 .5961 L
s
.88609 .5961 m
.88608 .59613 L
s
1 .005 0 r
.18695 .42083 m
.18698 .42085 L
s
.18692 .42085 m
.18695 .42083 L
s
.18695 .42083 m
.18695 .42083 L
s
.18698 .42085 m
.18695 .42088 L
s
.18695 .42083 m
.18698 .42085 L
s
.18695 .42088 m
.18692 .42085 L
s
.18692 .42085 m
.18695 .42083 L
s
.18695 .42083 m
.18695 .42088 L
s
1 .008 0 r
.6531 .53758 m
.65315 .53763 L
s
.65305 .53761 m
.6531 .53758 L
s
.6531 .53758 m
.65312 .53758 L
s
.65315 .53763 m
.6531 .53766 L
s
.65312 .53758 m
.65315 .53763 L
s
.6531 .53766 m
.65305 .53761 L
s
.65305 .53761 m
.65312 .53758 L
s
.65312 .53758 m
.6531 .53766 L
s
1 .133 0 r
.40362 .59601 m
.40302 .59612 L
s
.40307 .59481 m
.40362 .59601 L
s
.40362 .59601 m
.40237 .59568 L
s
.40373 .59526 m
.40362 .59601 L
s
.40078 .59329 m
.40362 .59601 L
s
0 1 .331 r
.48353 .31589 m
.49677 .32906 L
s
.46997 .32391 m
.48353 .31589 L
s
.48353 .31589 m
.48871 .31429 L
s
1 .241 0 r
.69485 .33453 m
.69609 .333 L
s
1 .021 0 r
.41994 .47886 m
.42006 .47895 L
s
.41981 .47896 m
.41994 .47886 L
s
.41994 .47886 m
.41992 .47885 L
s
1 .303 0 r
.40107 .39066 m
.40039 .39359 L
s
1 .575 0 r
.57006 .7169 m
.56947 .71221 L
s
1 .021 0 r
.41993 .47905 m
.41981 .47896 L
s
.41981 .47896 m
.41992 .47885 L
s
.42006 .47895 m
.41993 .47905 L
s
.41992 .47885 m
.42006 .47895 L
s
1 .133 0 r
.40307 .59481 m
.40237 .59568 L
s
.40373 .59526 m
.40307 .59481 L
s
1 .021 0 r
.41992 .47885 m
.41993 .47905 L
s
1 .398 0 r
.56052 .53732 m
.55944 .53806 L
s
.5594 .53418 m
.56052 .53732 L
s
.56236 .5352 m
.56052 .53732 L
s
0 .434 1 r
.42725 .3357 m
.4452 .34552 L
s
.40837 .35853 m
.42725 .3357 L
s
.42725 .3357 m
.41148 .33508 L
s
1 .133 0 r
.40237 .59568 m
.40302 .59612 L
s
1 .825 0 r
.48455 .65409 m
.48726 .65609 L
s
.48736 .64778 m
.48455 .65409 L
s
.49299 .65405 m
.48455 .65409 L
s
.60541 .36196 m
.60845 .36319 L
s
.60824 .3556 m
.60541 .36196 L
s
.61386 .3619 m
.60541 .36196 L
s
1 .02 0 r
.29587 .59566 m
.2958 .59567 L
s
.29582 .59547 m
.29587 .59566 L
s
.29587 .59566 m
.2957 .59559 L
s
.29592 .59555 m
.29587 .59566 L
s
.29557 .59522 m
.29587 .59566 L
s
1 .398 0 r
.49174 .53723 m
.4901 .53748 L
s
.49015 .53361 m
.49174 .53723 L
s
.49174 .53723 m
.48805 .5362 L
s
.4922 .53489 m
.49174 .53723 L
s
.48363 .52877 m
.49174 .53723 L
s
1 .825 0 r
.49299 .65405 m
.48726 .65609 L
s
.48736 .64778 m
.49299 .65405 L
s
.49008 .64976 m
.49299 .65405 L
s
.46443 .64339 m
.49299 .65405 L
s
.61386 .3619 m
.60845 .36319 L
s
.60824 .3556 m
.61386 .3619 L
s
.61128 .35682 m
.61386 .3619 L
s
.58612 .34927 m
.61386 .3619 L
s
1 .02 0 r
.29582 .59547 m
.2957 .59559 L
s
.29592 .59555 m
.29582 .59547 L
s
.2957 .59559 m
.2958 .59567 L
s
1 .481 0 r
.61582 .42339 m
.61831 .42029 L
s
.973 1 0 r
.45856 .32505 m
.46355 .332 L
s
.45336 .32745 m
.45856 .32505 L
s
.45856 .32505 m
.46322 .32517 L
s
1 .398 0 r
.55831 .53491 m
.5594 .53418 L
s
.5594 .53418 m
.56236 .5352 L
s
1 .02 0 r
.2958 .59567 m
.29592 .59555 L
s
0 .197 1 r
.54424 .70821 m
.56411 .68316 L
s
.808 1 0 r
.56145 .29519 m
.56153 .2945 L
s
.56153 .2945 m
.57155 .29966 L
s
1 .825 0 r
.49008 .64976 m
.48736 .64778 L
s
.61128 .35682 m
.60824 .3556 L
s
1 .293 0 r
.39018 .71229 m
.38839 .71286 L
s
.38851 .70986 m
.39018 .71229 L
s
.39018 .71229 m
.38722 .71197 L
s
.38968 .71075 m
.39018 .71229 L
s
.3815 .70762 m
.39018 .71229 L
s
1 .004 0 r
.88279 .42 m
.88279 .42 L
s
.88279 .41996 m
.88279 .42 L
s
.88279 .42 m
.88276 .41998 L
s
.88281 .41998 m
.88279 .42 L
s
.88279 .41989 m
.88279 .42 L
s
.88279 .41996 m
.88276 .41998 L
s
.88281 .41998 m
.88279 .41996 L
s
.88276 .41998 m
.88279 .42 L
s
.88279 .42 m
.88281 .41998 L
s
1 .133 0 r
.40302 .59612 m
.40373 .59526 L
s
1 .104 0 r
.76189 .71211 m
.76441 .71017 L
s
1 .003 0 r
.82234 .566 m
.82237 .56594 L
s
1 .825 0 r
.52873 .65366 m
.5631 .65306 L
s
1 0 0 r
.58918 .50756 m
.58918 .50756 L
s
1 .024 0 r
.35602 .44912 m
.35605 .44852 L
s
1 .575 0 r
.41647 .30301 m
.4323 .29144 L
s
1 .006 0 r
.12285 .39067 m
.12285 .39052 L
s
1 .003 0 r
.82237 .56594 m
.82238 .56595 L
s
.82235 .56595 m
.82237 .56594 L
s
.82237 .56594 m
.82237 .56594 L
s
.82238 .56595 m
.82237 .56597 L
s
.82237 .56594 m
.82238 .56595 L
s
.82237 .56597 m
.82235 .56595 L
s
.82235 .56595 m
.82237 .56594 L
s
.82237 .56594 m
.82237 .56597 L
s
1 .293 0 r
.38851 .70986 m
.38722 .71197 L
s
.38968 .71075 m
.38851 .70986 L
s
1 .006 0 r
.12285 .39052 m
.12289 .39055 L
s
.12281 .39055 m
.12285 .39052 L
s
.12285 .39052 m
.12285 .39052 L
s
.12289 .39055 m
.12285 .39058 L
s
.12285 .39052 m
.12289 .39055 L
s
.12285 .39058 m
.12281 .39055 L
s
.12281 .39055 m
.12285 .39052 L
s
.12285 .39052 m
.12285 .39058 L
s
1 .293 0 r
.38722 .71197 m
.38839 .71286 L
s
.973 1 0 r
.46355 .332 m
.45836 .33442 L
s
.46322 .32517 m
.46355 .332 L
s
1 .398 0 r
.49015 .53361 m
.48805 .5362 L
s
.4922 .53489 m
.49015 .53361 L
s
.285 1 0 r
.5642 .61471 m
.56106 .61156 L
s
.56106 .61156 m
.57482 .62235 L
s
1 .075 0 r
.75594 .36114 m
.75583 .36111 L
s
.75578 .36042 m
.75594 .36114 L
s
.75594 .36114 m
.75537 .36085 L
s
.75624 .36068 m
.75594 .36114 L
s
.75526 .35925 m
.75594 .36114 L
s
0 .197 1 r
.60452 .30791 m
.61432 .30376 L
s
.61432 .30376 m
.64347 .3111 L
s
.787 1 0 r
.54505 .6038 m
.54712 .59394 L
s
1 .024 0 r
.35605 .44853 m
.35618 .44865 L
s
.3559 .44863 m
.35605 .44853 L
s
.35605 .44853 m
.35605 .44852 L
s
1 .459 0 r
.43732 .6825 m
.43438 .68345 L
s
.43451 .67878 m
.43732 .6825 L
s
.43732 .6825 m
.43264 .68217 L
s
.43625 .68006 m
.43732 .6825 L
s
.42289 .67556 m
.43732 .6825 L
s
1 .075 0 r
.75578 .36042 m
.75537 .36085 L
s
.75624 .36068 m
.75578 .36042 L
s
1 .024 0 r
.35618 .44865 m
.35604 .44875 L
s
.35605 .44852 m
.35618 .44865 L
s
.35604 .44875 m
.3559 .44863 L
s
.3559 .44863 m
.35605 .44852 L
s
1 .741 0 r
.50969 .71168 m
.51091 .71329 L
s
.51095 .70569 m
.50969 .71168 L
s
.51686 .7104 m
.50969 .71168 L
s
1 .024 0 r
.35605 .44852 m
.35604 .44875 L
s
1 .168 0 r
.31338 .30118 m
.31427 .30221 L
s
.31239 .30166 m
.31338 .30118 L
s
.31338 .30118 m
.31383 .3011 L
s
1 .019 0 r
.81912 .39009 m
.81912 .39008 L
s
.8191 .3899 m
.81912 .39009 L
s
.81912 .39009 m
.819 .39 L
s
.81923 .38997 m
.81912 .39009 L
s
.81906 .38959 m
.81912 .39009 L
s
1 .075 0 r
.75537 .36085 m
.75583 .36111 L
s
1 .019 0 r
.8191 .3899 m
.819 .39 L
s
.81923 .38997 m
.8191 .3899 L
s
1 .398 0 r
.48805 .5362 m
.4901 .53748 L
s
1 .019 0 r
.819 .39 m
.81912 .39008 L
s
.81912 .39008 m
.81923 .38997 L
s
1 .825 0 r
.5631 .65306 m
.55626 .65734 L
s
.55611 .65054 m
.5631 .65306 L
s
1 .075 0 r
.75583 .36111 m
.75624 .36068 L
s
1 .168 0 r
.31427 .30221 m
.31328 .30269 L
s
.31383 .3011 m
.31427 .30221 L
s
.425 1 0 r
.45879 .4367 m
.46681 .44141 L
s
.45048 .44687 m
.45879 .4367 L
s
.45879 .4367 m
.45208 .43707 L
s
1 .199 0 r
.44629 .56524 m
.44544 .56539 L
s
.44548 .56343 m
.44629 .56524 L
s
.44629 .56524 m
.44443 .56473 L
s
.44649 .56409 m
.44629 .56524 L
s
.44213 .56109 m
.44629 .56524 L
s
1 .459 0 r
.43451 .67878 m
.43264 .68217 L
s
.43625 .68006 m
.43451 .67878 L
s
.43264 .68217 m
.43438 .68345 L
s
0 1 .511 r
.48511 .31614 m
.47087 .30198 L
s
.47087 .30198 m
.49098 .29153 L
s
1 .003 0 r
.23152 .56508 m
.23151 .56508 L
s
.23152 .56506 m
.23152 .56508 L
s
.23152 .56508 m
.2315 .56507 L
s
.23153 .56507 m
.23152 .56508 L
s
.23149 .56502 m
.23152 .56508 L
s
.23152 .56506 m
.2315 .56507 L
s
.23153 .56507 m
.23152 .56506 L
s
.2315 .56507 m
.23151 .56508 L
s
.23151 .56508 m
.23153 .56507 L
s
1 .095 0 r
.27831 .71123 m
.27784 .71135 L
s
.27791 .71038 m
.27831 .71123 L
s
.27831 .71123 m
.2774 .711 L
s
.27835 .71073 m
.27831 .71123 L
s
.27613 .70942 m
.27831 .71123 L
s
1 .172 0 r
.69809 .68197 m
.70256 .67886 L
s
1 .001 0 r
.75858 .53578 m
.75859 .53576 L
s
1 0 0 r
.01 w
.52528 .4773 Mdot
1 .021 0 r
.5 Mabswid
.29197 .41883 m
.29203 .41829 L
s
1 .001 0 r
.75858 .53576 m
.75859 .53577 L
s
.75858 .53576 m
.75858 .53576 L
s
.75858 .53576 m
.75859 .53576 L
s
.75859 .53577 m
.75858 .53577 L
s
.75859 .53576 m
.75859 .53577 L
s
.75858 .53577 m
.75858 .53576 L
s
.75858 .53576 m
.75859 .53576 L
s
.75859 .53576 m
.75858 .53577 L
s
1 .741 0 r
.51217 .70729 m
.51095 .70569 L
s
.51095 .70569 m
.51686 .7104 L
s
1 .293 0 r
.665 .71115 m
.66395 .71198 L
s
.66382 .70898 m
.665 .71115 L
s
.66577 .70963 m
.665 .71115 L
s
.66277 .70981 m
.66382 .70898 L
s
.66382 .70898 m
.66577 .70963 L
s
1 .199 0 r
.44548 .56343 m
.44443 .56473 L
s
.44649 .56409 m
.44548 .56343 L
s
1 .095 0 r
.27791 .71038 m
.2774 .711 L
s
.27835 .71073 m
.27791 .71038 L
s
1 .168 0 r
.31328 .30269 m
.31239 .30166 L
s
.31239 .30166 m
.31383 .3011 L
s
1 .095 0 r
.2774 .711 m
.27784 .71135 L
s
1 .199 0 r
.44443 .56473 m
.44544 .56539 L
s
1 .021 0 r
.29203 .4183 m
.29215 .41841 L
s
.2919 .41839 m
.29203 .4183 L
s
.29203 .4183 m
.29203 .41829 L
s
1 .168 0 r
.31383 .3011 m
.31328 .30269 L
s
1 .021 0 r
.29215 .41841 m
.29202 .4185 L
s
.29203 .41829 m
.29215 .41841 L
s
.29202 .4185 m
.2919 .41839 L
s
.2919 .41839 m
.29203 .41829 L
s
.29203 .41829 m
.29202 .4185 L
s
1 .104 0 r
.76387 .71003 m
.76441 .71072 L
s
.7634 .7104 m
.76387 .71003 L
s
.76387 .71003 m
.76441 .71017 L
s
1 .293 0 r
.38839 .71286 m
.38968 .71075 L
s
1 .095 0 r
.27784 .71135 m
.27835 .71073 L
s
1 .104 0 r
.76441 .71072 m
.76394 .71109 L
s
.76441 .71017 m
.76441 .71072 L
s
1 .398 0 r
.56236 .5352 m
.55944 .53806 L
s
.55831 .53491 m
.56236 .5352 L
s
.55944 .53806 m
.55831 .53491 L
s
1 .323 0 r
.37991 .32794 m
.38158 .33 L
s
.37809 .32883 m
.37991 .32794 L
s
.37991 .32794 m
.38098 .32787 L
s
0 .04 1 r
.4416 .30108 m
.42064 .3264 L
s
.40439 .2893 m
.4416 .30108 L
s
1 .398 0 r
.4901 .53748 m
.4922 .53489 L
s
1 .741 0 r
.51686 .7104 m
.51091 .71329 L
s
.51217 .70729 m
.51686 .7104 L
s
.48712 .70582 m
.51686 .7104 L
s
1 .104 0 r
.76394 .71109 m
.7634 .7104 L
s
.7634 .7104 m
.76441 .71017 L
s
1 .199 0 r
.44544 .56539 m
.44649 .56409 L
s
1 .104 0 r
.76441 .71017 m
.76394 .71109 L
s
1 .323 0 r
.38158 .33 m
.37977 .33089 L
s
.38098 .32787 m
.38158 .33 L
s
1 0 0 r
.16734 .53479 m
.16734 .53479 L
s
.16734 .53479 m
.16734 .53479 L
s
.16734 .53479 m
.16734 .53479 L
s
.16734 .53479 m
.16734 .53479 L
s
.16734 .53478 m
.16734 .53479 L
s
.16734 .53479 m
.16734 .53479 L
s
.16734 .53479 m
.16734 .53479 L
s
.16734 .53479 m
.16734 .53479 L
s
.16734 .53479 m
.16734 .53479 L
s
1 .001 0 r
.92817 .56404 m
.92818 .56402 L
s
1 .039 0 r
.86765 .71032 m
.86843 .70953 L
s
1 .336 0 r
.63421 .65181 m
.64421 .64628 L
s
1 0 0 r
.69473 .50553 m
.69473 .50553 L
s
1 .606 0 r
.4613 .44702 m
.46803 .43216 L
s
.808 1 0 r
.52182 .30074 m
.57155 .29966 L
s
1 .018 0 r
.22786 .3885 m
.22792 .38803 L
s
1 .001 0 r
.92818 .56402 m
.92819 .56402 L
s
.92818 .56402 m
.92818 .56402 L
s
.92818 .56402 m
.92818 .56402 L
s
.92819 .56402 m
.92818 .56403 L
s
.92818 .56402 m
.92819 .56402 L
s
.92818 .56403 m
.92818 .56402 L
s
.92818 .56402 m
.92818 .56402 L
s
.92818 .56402 m
.92818 .56403 L
s
.425 1 0 r
.45848 .45162 m
.45048 .44687 L
s
.45048 .44687 m
.45208 .43707 L
s
.285 1 0 r
.57482 .62235 m
.56125 .6287 L
s
.5642 .61471 m
.57482 .62235 L
s
.50612 .6111 m
.57482 .62235 L
s
1 .525 0 r
.60962 .68085 m
.60827 .68206 L
s
.60814 .67673 m
.60962 .68085 L
s
.61213 .67829 m
.60962 .68085 L
s
1 .018 0 r
.22791 .38804 m
.22802 .38814 L
s
.2278 .38811 m
.22791 .38804 L
s
.22791 .38804 m
.22792 .38803 L
s
.22802 .38814 m
.2279 .38821 L
s
.22792 .38803 m
.22802 .38814 L
s
.2279 .38821 m
.2278 .38811 L
s
.2278 .38811 m
.22792 .38803 L
s
.22792 .38803 m
.2279 .38821 L
s
1 .168 0 r
.73617 .30024 m
.73564 .30019 L
s
.73554 .29867 m
.73617 .30024 L
s
.73617 .30024 m
.73467 .29974 L
s
.73651 .29912 m
.73617 .30024 L
s
.73327 .29618 m
.73617 .30024 L
s
1 .525 0 r
.60679 .67794 m
.60814 .67673 L
s
.60814 .67673 m
.61213 .67829 L
s
1 .021 0 r
.63081 .47575 m
.63082 .47575 L
s
.63081 .47555 m
.63081 .47575 L
s
.63081 .47575 m
.63069 .47565 L
s
.63094 .47565 m
.63081 .47575 L
s
.63082 .47524 m
.63081 .47575 L
s
.63081 .47555 m
.63069 .47565 L
s
.63094 .47565 m
.63081 .47555 L
s
1 .293 0 r
.66395 .71198 m
.66277 .70981 L
s
.66577 .70963 m
.66395 .71198 L
s
.66277 .70981 m
.66577 .70963 L
s
1 .021 0 r
.63069 .47565 m
.63082 .47575 L
s
1 .039 0 r
.86826 .70949 m
.86848 .70974 L
s
.86807 .70965 m
.86826 .70949 L
s
.86826 .70949 m
.86843 .70953 L
s
1 .021 0 r
.63082 .47575 m
.63094 .47565 L
s
1 .825 0 r
.55626 .65734 m
.55611 .65054 L
s
1 .039 0 r
.86848 .70974 m
.8683 .70989 L
s
.86843 .70953 m
.86848 .70974 L
s
0 .434 1 r
.4262 .36857 m
.40837 .35853 L
s
.40837 .35853 m
.41148 .33508 L
s
1 .014 0 r
.33687 .56338 m
.33683 .56339 L
s
.33684 .56325 m
.33687 .56338 L
s
.33687 .56338 m
.33675 .56333 L
s
.33691 .5633 m
.33687 .56338 L
s
.33668 .56306 m
.33687 .56338 L
s
.33684 .56325 m
.33675 .56333 L
s
.33691 .5633 m
.33684 .56325 L
s
.33675 .56333 m
.33683 .56339 L
s
1 .168 0 r
.73554 .29867 m
.73467 .29974 L
s
.73651 .29912 m
.73554 .29867 L
s
1 .014 0 r
.33683 .56339 m
.33691 .5633 L
s
1 .039 0 r
.8683 .70989 m
.86807 .70965 L
s
.86807 .70965 m
.86843 .70953 L
s
.86843 .70953 m
.8683 .70989 L
s
0 1 .331 r
.49677 .32906 m
.48324 .33716 L
s
.48871 .31429 m
.49677 .32906 L
s
1 .168 0 r
.73467 .29974 m
.73564 .30019 L
s
.285 1 0 r
.59918 .4002 m
.60216 .38608 L
s
.808 1 0 r
.57155 .29966 m
.56166 .30527 L
s
.56145 .29519 m
.57155 .29966 L
s
1 .053 0 r
.80384 .68015 m
.80489 .67907 L
s
1 0 0 r
.86439 .53378 m
.8644 .53378 L
s
1 .787 0 r
.57026 .6216 m
.59956 .61297 L
s
1 .162 0 r
.39724 .41669 m
.39889 .41268 L
s
1 .016 0 r
.16367 .35814 m
.16372 .35772 L
s
1 0 0 r
.8644 .53378 m
.8644 .53378 L
s
.86439 .53378 m
.8644 .53378 L
s
.8644 .53378 m
.8644 .53378 L
s
.8644 .53378 m
.8644 .53378 L
s
.8644 .53378 m
.8644 .53378 L
s
.8644 .53378 m
.86439 .53378 L
s
.86439 .53378 m
.8644 .53378 L
s
.8644 .53378 m
.8644 .53378 L
s
1 .323 0 r
.37977 .33089 m
.37809 .32883 L
s
.37809 .32883 m
.38098 .32787 L
s
1 .459 0 r
.43438 .68345 m
.43625 .68006 L
s
1 .038 0 r
.21263 .68001 m
.21247 .68005 L
s
.2125 .67966 m
.21263 .68001 L
s
.21263 .68001 m
.21228 .6799 L
s
.21269 .67981 m
.21263 .68001 L
s
.21193 .67923 m
.21263 .68001 L
s
.2125 .67966 m
.21228 .6799 L
s
.21269 .67981 m
.2125 .67966 L
s
1 .016 0 r
.16372 .35773 m
.1638 .35782 L
s
.16361 .35779 m
.16372 .35773 L
s
.16372 .35773 m
.16372 .35772 L
s
1 .038 0 r
.21228 .6799 m
.21247 .68005 L
s
1 .172 0 r
.70162 .67861 m
.70247 .6798 L
s
.70086 .67918 m
.70162 .67861 L
s
.70162 .67861 m
.70256 .67886 L
s
1 .016 0 r
.1638 .35782 m
.1637 .35788 L
s
.16372 .35772 m
.1638 .35782 L
s
.1637 .35788 m
.16361 .35779 L
s
.16361 .35779 m
.16372 .35772 L
s
1 .323 0 r
.38098 .32787 m
.37977 .33089 L
s
1 .016 0 r
.16372 .35772 m
.1637 .35788 L
s
1 .038 0 r
.21247 .68005 m
.21269 .67981 L
s
1 .172 0 r
.70247 .6798 m
.70171 .68036 L
s
.70256 .67886 m
.70247 .6798 L
s
1 .168 0 r
.73564 .30019 m
.73651 .29912 L
s
1 .121 0 r
.32001 .67976 m
.31943 .6799 L
s
.31951 .67867 m
.32001 .67976 L
s
.32001 .67976 m
.31886 .67947 L
s
.32008 .6791 m
.32001 .67976 L
s
.31728 .6774 m
.32001 .67976 L
s
1 .021 0 r
.86122 .35759 m
.86122 .35757 L
s
.86119 .35738 m
.86122 .35759 L
s
.86122 .35759 m
.86108 .35749 L
s
.86133 .35746 m
.86122 .35759 L
s
.86113 .35704 m
.86122 .35759 L
s
.86119 .35738 m
.86108 .35749 L
s
.86133 .35746 m
.86119 .35738 L
s
1 .063 0 r
.79787 .32825 m
.79777 .32821 L
s
.79771 .32764 m
.79787 .32825 L
s
.79787 .32825 m
.79737 .32801 L
s
.79811 .32785 m
.79787 .32825 L
s
.79724 .32663 m
.79787 .32825 L
s
1 .021 0 r
.86108 .35749 m
.86122 .35757 L
s
.86122 .35757 m
.86133 .35746 L
s
1 .121 0 r
.31951 .67867 m
.31886 .67947 L
s
.32008 .6791 m
.31951 .67867 L
s
1 .063 0 r
.79771 .32764 m
.79737 .32801 L
s
.79811 .32785 m
.79771 .32764 L
s
1 .121 0 r
.31886 .67947 m
.31943 .6799 L
s
1 .063 0 r
.79737 .32801 m
.79777 .32821 L
s
1 .053 0 r
.80466 .67901 m
.80496 .67935 L
s
.8044 .67922 m
.80466 .67901 L
s
.80466 .67901 m
.80489 .67907 L
s
.80496 .67935 m
.80471 .67955 L
s
.80489 .67907 m
.80496 .67935 L
s
1 .063 0 r
.79777 .32821 m
.79811 .32785 L
s
1 .825 0 r
.48726 .65609 m
.49008 .64976 L
s
.60845 .36319 m
.61128 .35682 L
s
1 .001 0 r
.27252 .5328 m
.27252 .5328 L
s
.27252 .53279 m
.27252 .5328 L
s
.27252 .5328 m
.27252 .53279 L
s
.27253 .53279 m
.27252 .5328 L
s
.27252 .53278 m
.27252 .5328 L
s
.27252 .53279 m
.27252 .53279 L
s
.27253 .53279 m
.27252 .53279 L
s
.27252 .53279 m
.27252 .5328 L
s
.27252 .5328 m
.27253 .53279 L
s
1 .017 0 r
.97366 .70852 m
.97396 .70818 L
s
1 .08 0 r
.73995 .64994 m
.74156 .64831 L
s
1 0 0 r
.80054 .50349 m
.80054 .50349 L
s
1 .081 0 r
.33311 .38633 m
.33387 .38428 L
s
1 .014 0 r
.0994 .32775 m
.09944 .32737 L
s
1 .053 0 r
.80471 .67955 m
.8044 .67922 L
s
.8044 .67922 m
.80489 .67907 L
s
0 .813 1 r
.433 .36271 m
.44913 .37172 L
s
.4161 .38321 m
.433 .36271 L
s
.433 .36271 m
.41897 .36251 L
s
1 .172 0 r
.70171 .68036 m
.70086 .67918 L
s
.70086 .67918 m
.70256 .67886 L
s
1 .053 0 r
.80489 .67907 m
.80471 .67955 L
s
1 .121 0 r
.31943 .6799 m
.32008 .6791 L
s
1 .172 0 r
.70256 .67886 m
.70171 .68036 L
s
1 .014 0 r
.09944 .32738 m
.09952 .32746 L
s
.09934 .32743 m
.09944 .32738 L
s
.09944 .32738 m
.09944 .32737 L
s
.09952 .32746 m
.09942 .32751 L
s
.09944 .32737 m
.09952 .32746 L
s
.973 1 0 r
.45836 .33442 m
.45336 .32745 L
s
.45336 .32745 m
.46322 .32517 L
s
1 .017 0 r
.97389 .70816 m
.97399 .70826 L
s
.97381 .70823 m
.97389 .70816 L
s
.97389 .70816 m
.97396 .70818 L
s
1 .014 0 r
.09942 .32751 m
.09934 .32743 L
s
.09934 .32743 m
.09944 .32737 L
s
1 .017 0 r
.97399 .70826 m
.97391 .70833 L
s
.97396 .70818 m
.97399 .70826 L
s
1 .014 0 r
.09944 .32737 m
.09942 .32751 L
s
1 .017 0 r
.97391 .70833 m
.97381 .70823 L
s
.97381 .70823 m
.97396 .70818 L
s
.97396 .70818 m
.97391 .70833 L
s
1 .253 0 r
.65501 .38565 m
.65413 .38566 L
s
.65404 .3833 m
.65501 .38565 L
s
.65501 .38565 m
.65272 .38493 L
s
.65545 .38403 m
.65501 .38565 L
s
.65037 .37978 m
.65501 .38565 L
s
0 1 .511 r
.49098 .29153 m
.48511 .31614 L
s
1 .481 0 r
.45171 .59059 m
.44965 .591 L
s
.44976 .58623 m
.45171 .59059 L
s
.45171 .59059 m
.44722 .58938 L
s
.4522 .58785 m
.45171 .59059 L
s
.44163 .58065 m
.45171 .59059 L
s
1 .741 0 r
.51091 .71329 m
.51217 .70729 L
s
.973 1 0 r
.46322 .32517 m
.45836 .33442 L
s
1 .001 0 r
.73661 .4732 m
.73661 .4732 L
s
.73661 .47318 m
.73661 .4732 L
s
.73661 .4732 m
.7366 .47319 L
s
.73662 .47319 m
.73661 .4732 L
s
.73661 .47316 m
.73661 .4732 L
s
.73661 .47318 m
.7366 .47319 L
s
.73662 .47319 m
.73661 .47318 L
s
.7366 .47319 m
.73661 .4732 L
s
.73661 .4732 m
.73662 .47319 L
s
1 .019 0 r
.90983 .67832 m
.91017 .67791 L
s
1 .141 0 r
.67598 .6197 m
.67901 .61684 L
s
0 1 .566 r
.50276 .41455 m
.59832 .38238 L
s
1 0 0 r
.20828 .50247 m
.20828 .50247 L
s
1 .052 0 r
.2689 .35593 m
.26934 .3546 L
s
1 .525 0 r
.61213 .67829 m
.60827 .68206 L
s
.60679 .67794 m
.61213 .67829 L
s
1 .253 0 r
.65404 .3833 m
.65272 .38493 L
s
.65545 .38403 m
.65404 .3833 L
s
0 1 .566 r
.44284 .39549 m
.45587 .40294 L
s
.42924 .41204 m
.44284 .39549 L
s
.44284 .39549 m
.43167 .39567 L
s
1 .039 0 r
.6728 .44377 m
.67277 .44376 L
s
.67276 .44339 m
.6728 .44377 L
s
.6728 .44377 m
.67253 .4436 L
s
.67299 .44355 m
.6728 .44377 L
s
.6726 .4428 m
.6728 .44377 L
s
1 .525 0 r
.60827 .68206 m
.60679 .67794 L
s
1 .039 0 r
.67276 .44339 m
.67253 .4436 L
s
.67299 .44355 m
.67276 .44339 L
s
0 1 .077 r
.48097 .34036 m
.49279 .35218 L
s
.46884 .34764 m
.48097 .34036 L
s
.48097 .34036 m
.48556 .33915 L
s
1 .08 0 r
.74121 .64824 m
.74165 .64875 L
s
.74082 .64853 m
.74121 .64824 L
s
.74121 .64824 m
.74156 .64831 L
s
0 .04 1 r
.40439 .2893 m
.42064 .3264 L
s
1 .039 0 r
.67253 .4436 m
.67277 .44376 L
s
1 .08 0 r
.74165 .64875 m
.74126 .64904 L
s
.74156 .64831 m
.74165 .64875 L
s
1 .253 0 r
.65272 .38493 m
.65413 .38566 L
s
1 .039 0 r
.67277 .44376 m
.67299 .44355 L
s
1 .081 0 r
.33374 .38431 m
.33419 .38478 L
s
.33324 .3846 m
.33374 .38431 L
s
.33374 .38431 m
.33387 .38428 L
s
1 .019 0 r
.91009 .67789 m
.91021 .67801 L
s
.90999 .67797 m
.91009 .67789 L
s
.91009 .67789 m
.91017 .67791 L
s
.91021 .67801 m
.91011 .67809 L
s
.91017 .67791 m
.91021 .67801 L
s
.91011 .67809 m
.90999 .67797 L
s
.90999 .67797 m
.91017 .67791 L
s
.91017 .67791 m
.91011 .67809 L
s
1 .081 0 r
.33419 .38478 m
.33369 .38507 L
s
.33387 .38428 m
.33419 .38478 L
s
1 .166 0 r
.36223 .64856 m
.36147 .64874 L
s
.36155 .64706 m
.36223 .64856 L
s
.36223 .64856 m
.36066 .64816 L
s
.36235 .64765 m
.36223 .64856 L
s
.35859 .64527 m
.36223 .64856 L
s
1 .08 0 r
.74126 .64904 m
.74082 .64853 L
s
.74082 .64853 m
.74156 .64831 L
s
1 .398 0 r
.5748 .4726 m
.57329 .47275 L
s
.57323 .46893 m
.5748 .4726 L
s
.5748 .4726 m
.57115 .47152 L
s
.57537 .47016 m
.5748 .4726 L
s
.56707 .46378 m
.5748 .4726 L
s
1 .081 0 r
.33369 .38507 m
.33324 .3846 L
s
.33324 .3846 m
.33387 .38428 L
s
1 .162 0 r
.39859 .41272 m
.3995 .41365 L
s
.39762 .41331 m
.39859 .41272 L
s
.39859 .41272 m
.39889 .41268 L
s
1 .08 0 r
.74156 .64831 m
.74126 .64904 L
s
1 .481 0 r
.44976 .58623 m
.44722 .58938 L
s
.4522 .58785 m
.44976 .58623 L
s
1 .081 0 r
.33387 .38428 m
.33369 .38507 L
s
0 1 .077 r
.56926 .64834 m
.57314 .65244 L
s
.57284 .63144 m
.56926 .64834 L
s
.5896 .64459 m
.56926 .64834 L
s
.542 1 0 r
.53381 .29646 m
.52309 .30688 L
s
.51894 .29524 m
.53381 .29646 L
s
.808 1 0 r
.56166 .30527 m
.56145 .29519 L
s
1 .166 0 r
.36155 .64706 m
.36066 .64816 L
s
.36235 .64765 m
.36155 .64706 L
s
1 .052 0 r
.26927 .35463 m
.26956 .35492 L
s
.26895 .35481 m
.26927 .35463 L
s
.26927 .35463 m
.26934 .3546 L
s
1 .162 0 r
.3995 .41365 m
.39853 .41424 L
s
.39889 .41268 m
.3995 .41365 L
s
1 .005 0 r
.378 .5309 m
.37799 .5309 L
s
.37799 .53085 m
.378 .5309 L
s
.378 .5309 m
.37796 .53088 L
s
.37802 .53088 m
.378 .5309 L
s
.37795 .53078 m
.378 .5309 L
s
.37799 .53085 m
.37796 .53088 L
s
.37802 .53088 m
.37799 .53085 L
s
1 .336 0 r
.64215 .6457 m
.64362 .64813 L
s
.64079 .64665 m
.64215 .6457 L
s
.64215 .6457 m
.64421 .64628 L
s
1 .005 0 r
.37796 .53088 m
.37799 .5309 L
s
.37799 .5309 m
.37802 .53088 L
s
1 .052 0 r
.26956 .35492 m
.26923 .35511 L
s
.26934 .3546 m
.26956 .35492 L
s
1 .166 0 r
.36066 .64816 m
.36147 .64874 L
s
1 .336 0 r
.64362 .64813 m
.64226 .64909 L
s
.64421 .64628 m
.64362 .64813 L
s
1 .023 0 r
.84593 .64808 m
.84631 .64757 L
s
1 0 0 r
.90659 .50145 m
.90659 .50145 L
s
1 .344 0 r
.61194 .58943 m
.62058 .5828 L
s
1 .59 0 r
.43861 .38415 m
.45226 .37134 L
s
1 0 0 r
.14396 .47213 m
.14396 .47212 L
s
1 .038 0 r
.20462 .3255 m
.20491 .32452 L
s
1 0 0 r
.14396 .47212 m
.14396 .47212 L
s
.14396 .47212 m
.14396 .47212 L
s
.14396 .47212 m
.14396 .47212 L
s
.14396 .47212 m
.14396 .47212 L
s
.14396 .47212 m
.14396 .47212 L
s
.14396 .47212 m
.14396 .47212 L
s
.14396 .47212 m
.14396 .47212 L
s
.14396 .47212 m
.14396 .47212 L
s
1 .052 0 r
.26923 .35511 m
.26895 .35481 L
s
.26895 .35481 m
.26934 .3546 L
s
1 .481 0 r
.44722 .58938 m
.44965 .591 L
s
.542 1 0 r
.52309 .30688 m
.51894 .29524 L
s
1 .04 0 r
.25369 .648 m
.25353 .64803 L
s
.25357 .64762 m
.25369 .648 L
s
.25369 .648 m
.25333 .64787 L
s
.25377 .64778 m
.25369 .648 L
s
.25299 .64714 m
.25369 .648 L
s
1 .052 0 r
.26934 .3546 m
.26923 .35511 L
s
1 .253 0 r
.65413 .38566 m
.65545 .38403 L
s
1 .162 0 r
.39853 .41424 m
.39762 .41331 L
s
.39762 .41331 m
.39889 .41268 L
s
1 .04 0 r
.25357 .64762 m
.25333 .64787 L
s
.25377 .64778 m
.25357 .64762 L
s
.25333 .64787 m
.25353 .64803 L
s
1 .398 0 r
.57323 .46893 m
.57115 .47152 L
s
.57537 .47016 m
.57323 .46893 L
s
1 .04 0 r
.25353 .64803 m
.25377 .64778 L
s
1 .023 0 r
.84622 .64755 m
.84636 .64769 L
s
.8461 .64765 m
.84622 .64755 L
s
.84622 .64755 m
.84631 .64757 L
s
1 .162 0 r
.39889 .41268 m
.39853 .41424 L
s
1 .023 0 r
.84636 .64769 m
.84624 .64779 L
s
.84631 .64757 m
.84636 .64769 L
s
1 .459 0 r
.64158 .32502 m
.63896 .32541 L
s
.6388 .32122 m
.64158 .32502 L
s
.64158 .32502 m
.63693 .32462 L
s
.64084 .32201 m
.64158 .32502 L
s
.62802 .31646 m
.64158 .32502 L
s
1 .023 0 r
.84624 .64779 m
.8461 .64765 L
s
.8461 .64765 m
.84631 .64757 L
s
1 .166 0 r
.36147 .64874 m
.36235 .64765 L
s
1 .023 0 r
.84631 .64757 m
.84624 .64779 L
s
1 .398 0 r
.57115 .47152 m
.57329 .47275 L
s
1 .038 0 r
.20487 .32455 m
.20507 .32476 L
s
.20463 .32468 m
.20487 .32455 L
s
.20487 .32455 m
.20491 .32452 L
s
1 .253 0 r
.40548 .61816 m
.40435 .6184 L
s
.40444 .61586 m
.40548 .61816 L
s
.40548 .61816 m
.4031 .61753 L
s
.4057 .61673 m
.40548 .61816 L
s
.40004 .61302 m
.40548 .61816 L
s
1 .575 0 r
.4292 .29117 m
.43171 .29532 L
s
.42653 .29221 m
.4292 .29117 L
s
.4292 .29117 m
.4323 .29144 L
s
1 .038 0 r
.20507 .32476 m
.20483 .32489 L
s
.20491 .32452 m
.20507 .32476 L
s
.20483 .32489 m
.20463 .32468 L
s
.20463 .32468 m
.20491 .32452 L
s
.973 1 0 r
.48922 .67672 m
.49263 .6793 L
s
.49273 .66883 m
.48922 .67672 L
s
.49977 .67667 m
.48922 .67672 L
s
1 .575 0 r
.43171 .29532 m
.42904 .29637 L
s
.4323 .29144 m
.43171 .29532 L
s
1 .055 0 r
.83994 .29531 m
.83985 .29528 L
s
.8398 .29478 m
.83994 .29531 L
s
.83994 .29531 m
.8395 .2951 L
s
.84014 .29495 m
.83994 .29531 L
s
.83937 .29389 m
.83994 .29531 L
s
1 .459 0 r
.6388 .32122 m
.63693 .32462 L
s
.64084 .32201 m
.6388 .32122 L
s
.63693 .32462 m
.63896 .32541 L
s
1 .038 0 r
.20491 .32452 m
.20483 .32489 L
s
.973 1 0 r
.49977 .67667 m
.49263 .6793 L
s
.49273 .66883 m
.49977 .67667 L
s
.49616 .67138 m
.49977 .67667 L
s
.46407 .66352 m
.49977 .67667 L
s
0 .813 1 r
.43212 .3924 m
.4161 .38321 L
s
.4161 .38321 m
.41897 .36251 L
s
1 .055 0 r
.8398 .29478 m
.8395 .2951 L
s
.84014 .29495 m
.8398 .29478 L
s
.717 1 0 r
.5216 .32448 m
.51791 .32596 L
s
.51794 .31424 m
.5216 .32448 L
s
.52739 .31675 m
.5216 .32448 L
s
1 .055 0 r
.8395 .2951 m
.83985 .29528 L
s
1 .825 0 r
.4544 .34765 m
.45842 .35326 L
s
.45019 .34963 m
.4544 .34765 L
s
.4544 .34765 m
.45814 .34782 L
s
0 .434 1 r
.61781 .35375 m
.60864 .35825 L
s
.60775 .3253 m
.61781 .35375 L
s
.63513 .33244 m
.61781 .35375 L
s
1 0 0 r
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
.84265 .47109 m
.84265 .47109 L
s
1 .029 0 r
.78195 .6178 m
.7824 .61715 L
s
.425 1 0 r
.54782 .55911 m
.60663 .54104 L
s
1 0 0 r
.31369 .50043 m
.31369 .50043 L
s
1 .229 0 r
.37439 .35372 m
.37844 .34829 L
s
1 .029 0 r
.14026 .29503 m
.14046 .29426 L
s
.973 1 0 r
.49616 .67138 m
.49273 .66883 L
s
1 .141 0 r
.67837 .61671 m
.67913 .61763 L
s
.67768 .61719 m
.67837 .61671 L
s
.67837 .61671 m
.67901 .61684 L
s
1 .253 0 r
.40444 .61586 m
.4031 .61753 L
s
.4057 .61673 m
.40444 .61586 L
s
1 .055 0 r
.83985 .29528 m
.84014 .29495 L
s
.973 1 0 r
.5633 .67638 m
.56323 .67836 L
s
.56312 .6679 m
.5633 .67638 L
s
.57179 .67297 m
.5633 .67638 L
s
1 .141 0 r
.67913 .61763 m
.67843 .61812 L
s
.67901 .61684 m
.67913 .61763 L
s
1 .253 0 r
.4031 .61753 m
.40435 .6184 L
s
0 .04 1 r
.54683 .7318 m
.5676 .70555 L
s
.425 1 0 r
.46681 .44141 m
.45848 .45162 L
s
.45208 .43707 m
.46681 .44141 L
s
.787 1 0 r
.58122 .41206 m
.58354 .41345 L
s
.58332 .40205 m
.58122 .41206 L
s
.59312 .40954 m
.58122 .41206 L
s
0 1 .077 r
.57675 .63541 m
.57284 .63144 L
s
.57284 .63144 m
.5896 .64459 L
s
0 1 .566 r
.44221 .41961 m
.42924 .41204 L
s
.42924 .41204 m
.43167 .39567 L
s
1 .825 0 r
.45842 .35326 m
.45422 .35526 L
s
.45814 .34782 m
.45842 .35326 L
s
0 1 .331 r
.48324 .33716 m
.46997 .32391 L
s
.46997 .32391 m
.48871 .31429 L
s
1 .029 0 r
.14044 .29429 m
.14059 .29445 L
s
.14025 .29438 m
.14044 .29429 L
s
.14044 .29429 m
.14046 .29426 L
s
.7823 .61714 m
.78247 .61731 L
s
.78215 .61726 m
.7823 .61714 L
s
.7823 .61714 m
.7824 .61715 L
s
.14059 .29445 m
.1404 .29455 L
s
.14046 .29426 m
.14059 .29445 L
s
.78247 .61731 m
.78232 .61743 L
s
.7824 .61715 m
.78247 .61731 L
s
1 .336 0 r
.64226 .64909 m
.64079 .64665 L
s
.64079 .64665 m
.64421 .64628 L
s
.717 1 0 r
.51424 .31568 m
.51794 .31424 L
s
.51794 .31424 m
.52739 .31675 L
s
1 .029 0 r
.1404 .29455 m
.14025 .29438 L
s
.14025 .29438 m
.14046 .29426 L
s
.78232 .61743 m
.78215 .61726 L
s
.78215 .61726 m
.7824 .61715 L
s
1 .336 0 r
.64421 .64628 m
.64226 .64909 L
s
1 .029 0 r
.14046 .29426 m
.1404 .29455 L
s
.7824 .61715 m
.78232 .61743 L
s
1 .481 0 r
.44965 .591 m
.4522 .58785 L
s
1 .141 0 r
.67843 .61812 m
.67768 .61719 L
s
.67768 .61719 m
.67901 .61684 L
s
1 .011 0 r
.18878 .6171 m
.18874 .61711 L
s
.18876 .61699 m
.18878 .6171 L
s
.18878 .6171 m
.18869 .61706 L
s
.18882 .61704 m
.18878 .6171 L
s
.18863 .61684 m
.18878 .6171 L
s
.18876 .61699 m
.18869 .61706 L
s
.18882 .61704 m
.18876 .61699 L
s
1 .141 0 r
.67901 .61684 m
.67843 .61812 L
s
1 .011 0 r
.18869 .61706 m
.18874 .61711 L
s
.18874 .61711 m
.18882 .61704 L
s
1 .787 0 r
.59582 .61699 m
.59375 .61865 L
s
.59359 .61077 m
.59582 .61699 L
s
.59956 .61297 m
.59582 .61699 L
s
1 .005 0 r
.77864 .44081 m
.77864 .44081 L
s
.77863 .44076 m
.77864 .44081 L
s
.77864 .44081 m
.77861 .44079 L
s
.77867 .44079 m
.77864 .44081 L
s
.77863 .44069 m
.77864 .44081 L
s
.77863 .44076 m
.77861 .44079 L
s
.77867 .44079 m
.77863 .44076 L
s
1 .398 0 r
.57329 .47275 m
.57537 .47016 L
s
1 .005 0 r
.77861 .44079 m
.77864 .44081 L
s
.77864 .44081 m
.77867 .44079 L
s
1 .043 0 r
.71487 .41134 m
.71482 .41132 L
s
.71479 .41092 m
.71487 .41134 L
s
.71487 .41134 m
.71455 .41116 L
s
.71506 .41108 m
.71487 .41134 L
s
.71454 .41025 m
.71487 .41134 L
s
1 .009 0 r
.95216 .6462 m
.95229 .64601 L
s
1 .039 0 r
.7179 .58748 m
.71846 .58661 L
s
1 0 0 r
.24936 .47005 m
.24936 .47003 L
s
1 .121 0 r
.3101 .32325 m
.31188 .32024 L
s
1 0 0 r
.24936 .47003 m
.24936 .47004 L
s
.24936 .47004 m
.24936 .47003 L
s
.24936 .47003 m
.24936 .47003 L
s
.24936 .47004 m
.24936 .47004 L
s
.24936 .47003 m
.24936 .47004 L
s
.24936 .47004 m
.24936 .47004 L
s
.24936 .47004 m
.24936 .47003 L
s
.24936 .47003 m
.24936 .47004 L
s
.973 1 0 r
.56305 .66985 m
.56312 .6679 L
s
.56312 .6679 m
.57179 .67297 L
s
1 .043 0 r
.71479 .41092 m
.71455 .41116 L
s
.71506 .41108 m
.71479 .41092 L
s
1 .253 0 r
.40435 .6184 m
.4057 .61673 L
s
1 .009 0 r
.95226 .64601 m
.95231 .64606 L
s
.95222 .64604 m
.95226 .64601 L
s
.95226 .64601 m
.95229 .64601 L
s
1 .043 0 r
.71455 .41116 m
.71482 .41132 L
s
1 .009 0 r
.95231 .64606 m
.95227 .64609 L
s
.95229 .64601 m
.95231 .64606 L
s
.95227 .64609 m
.95222 .64604 L
s
.95222 .64604 m
.95229 .64601 L
s
.95229 .64601 m
.95227 .64609 L
s
1 .043 0 r
.71482 .41132 m
.71506 .41108 L
s
1 .787 0 r
.59152 .61242 m
.59359 .61077 L
s
.59359 .61077 m
.59956 .61297 L
s
.787 1 0 r
.58565 .4034 m
.58332 .40205 L
s
.58332 .40205 m
.59312 .40954 L
s
1 .787 0 r
.45767 .61656 m
.45431 .61732 L
s
.45447 .60943 m
.45767 .61656 L
s
.45767 .61656 m
.4503 .6146 L
s
.45849 .61213 m
.45767 .61656 L
s
.44113 .60046 m
.45767 .61656 L
s
0 1 .077 r
.49279 .35218 m
.48069 .35952 L
s
.48556 .33915 m
.49279 .35218 L
s
1 .741 0 r
.586 .29334 m
.58742 .29389 L
s
.58728 .28718 m
.586 .29334 L
s
.59326 .2917 m
.586 .29334 L
s
1 .575 0 r
.44045 .70446 m
.43676 .70571 L
s
.43691 .69979 m
.44045 .70446 L
s
.44045 .70446 m
.43456 .70406 L
s
.43912 .70144 m
.44045 .70446 L
s
.42228 .69585 m
.44045 .70446 L
s
1 .039 0 r
.71834 .58659 m
.71857 .58682 L
s
.71813 .58675 m
.71834 .58659 L
s
.71834 .58659 m
.71846 .58661 L
s
.71857 .58682 m
.71836 .58698 L
s
.71846 .58661 m
.71857 .58682 L
s
.425 1 0 r
.45208 .43707 m
.45848 .45162 L
s
1 .039 0 r
.71836 .58698 m
.71813 .58675 L
s
.71813 .58675 m
.71846 .58661 L
s
0 .434 1 r
.59845 .32947 m
.60775 .3253 L
s
.60775 .3253 m
.63513 .33244 L
s
0 .197 1 r
.44292 .32236 m
.42271 .34683 L
s
.40705 .31112 m
.44292 .32236 L
s
1 .039 0 r
.71846 .58661 m
.71836 .58698 L
s
.285 1 0 r
.56125 .6287 m
.5642 .61471 L
s
1 .575 0 r
.43691 .69979 m
.43456 .70406 L
s
.43912 .70144 m
.43691 .69979 L
s
.43456 .70406 m
.43676 .70571 L
s
1 .009 0 r
.88817 .61589 m
.88829 .61569 L
s
1 .65 0 r
.59299 .70402 m
.61734 .69724 L
s
1 .058 0 r
.65377 .55714 m
.65456 .5558 L
s
1 0 0 r
.41936 .49838 m
.41936 .49838 L
s
.939 1 0 r
.48013 .3515 m
.51915 .33785 L
s
1 .002 0 r
.18495 .43963 m
.18495 .43959 L
s
1 .077 0 r
.24573 .29274 m
.24669 .29078 L
s
1 .043 0 r
.29486 .61587 m
.29472 .6159 L
s
.29475 .61547 m
.29486 .61587 L
s
.29486 .61587 m
.2945 .61572 L
s
.29497 .61564 m
.29486 .61587 L
s
.29421 .61493 m
.29486 .61587 L
s
1 .002 0 r
.18495 .43959 m
.18496 .4396 L
s
.18494 .43959 m
.18495 .43959 L
s
.18495 .43959 m
.18495 .43959 L
s
.18496 .4396 m
.18495 .4396 L
s
.18495 .43959 m
.18496 .4396 L
s
.18495 .4396 m
.18494 .43959 L
s
.18494 .43959 m
.18495 .43959 L
s
.18495 .43959 m
.18495 .4396 L
s
1 .741 0 r
.58871 .28771 m
.58728 .28718 L
s
.58728 .28718 m
.59326 .2917 L
s
1 .459 0 r
.63896 .32541 m
.64084 .32201 L
s
1 .043 0 r
.29475 .61547 m
.2945 .61572 L
s
.29497 .61564 m
.29475 .61547 L
s
.973 1 0 r
.5564 .32199 m
.55631 .32269 L
s
.55621 .3133 m
.5564 .32199 L
s
.56488 .3178 m
.5564 .32199 L
s
1 .009 0 r
.88826 .61569 m
.88831 .61574 L
s
.88821 .61573 m
.88826 .61569 L
s
.88826 .61569 m
.88829 .61569 L
s
.88831 .61574 m
.88827 .61578 L
s
.88829 .61569 m
.88831 .61574 L
s
.88827 .61578 m
.88821 .61573 L
s
.88821 .61573 m
.88829 .61569 L
s
1 .043 0 r
.2945 .61572 m
.29472 .6159 L
s
1 .009 0 r
.88829 .61569 m
.88827 .61578 L
s
1 .043 0 r
.29472 .6159 m
.29497 .61564 L
s
.285 1 0 r
.47739 .36773 m
.48717 .37755 L
s
.46735 .37384 m
.47739 .36773 L
s
.47739 .36773 m
.48117 .36692 L
s
1 .575 0 r
.42904 .29637 m
.42653 .29221 L
s
.42653 .29221 m
.4323 .29144 L
s
1 .166 0 r
.69532 .35096 m
.69477 .35094 L
s
.69469 .34941 m
.69532 .35096 L
s
.69532 .35096 m
.69383 .35048 L
s
.69563 .34987 m
.69532 .35096 L
s
.69236 .34704 m
.69532 .35096 L
s
1 .575 0 r
.4323 .29144 m
.42904 .29637 L
s
1 .787 0 r
.45447 .60943 m
.4503 .6146 L
s
.45849 .61213 m
.45447 .60943 L
s
.787 1 0 r
.59312 .40954 m
.58354 .41345 L
s
.58565 .4034 m
.59312 .40954 L
s
.54448 .4005 m
.59312 .40954 L
s
0 1 .077 r
.5896 .64459 m
.57314 .65244 L
s
.57675 .63541 m
.5896 .64459 L
s
.50601 .63107 m
.5896 .64459 L
s
1 .166 0 r
.69469 .34941 m
.69383 .35048 L
s
.69563 .34987 m
.69469 .34941 L
s
1 .121 0 r
.31156 .32029 m
.31221 .32104 L
s
.31084 .32065 m
.31156 .32029 L
s
.31156 .32029 m
.31188 .32024 L
s
1 .741 0 r
.59326 .2917 m
.58742 .29389 L
s
.58871 .28771 m
.59326 .2917 L
s
.56361 .28584 m
.59326 .2917 L
s
1 .166 0 r
.69383 .35048 m
.69477 .35094 L
s
1 .058 0 r
.65439 .55578 m
.65473 .55612 L
s
.65407 .55601 m
.65439 .55578 L
s
.65439 .55578 m
.65456 .5558 L
s
1 .121 0 r
.31221 .32104 m
.31149 .3214 L
s
.31188 .32024 m
.31221 .32104 L
s
1 .001 0 r
.88491 .4386 m
.88491 .4386 L
s
.88491 .43859 m
.88491 .4386 L
s
.88491 .4386 m
.8849 .43859 L
s
.88492 .43859 m
.88491 .4386 L
s
.88491 .43857 m
.88491 .4386 L
s
.88491 .43859 m
.8849 .43859 L
s
.88492 .43859 m
.88491 .43859 L
s
.8849 .43859 m
.88491 .4386 L
s
.88491 .4386 m
.88492 .43859 L
s
1 .008 0 r
.8241 .58554 m
.8242 .58535 L
s
.973 1 0 r
.52875 .67372 m
.57179 .67297 L
s
1 .117 0 r
.58956 .52675 m
.59106 .52402 L
s
1 .003 0 r
.35501 .46796 m
.35502 .46788 L
s
1 .459 0 r
.41582 .32099 m
.42852 .3118 L
s
1 .003 0 r
.12047 .40917 m
.12047 .4091 L
s
1 .058 0 r
.65473 .55612 m
.65442 .55635 L
s
.65456 .5558 m
.65473 .55612 L
s
1 .003 0 r
.12047 .40911 m
.12048 .40912 L
s
.12045 .40912 m
.12047 .40911 L
s
.12047 .40911 m
.12047 .4091 L
s
.12048 .40912 m
.12047 .40913 L
s
.12047 .4091 m
.12048 .40912 L
s
.12047 .40913 m
.12045 .40912 L
s
.12045 .40912 m
.12047 .4091 L
s
.35502 .46788 m
.35504 .4679 L
s
.355 .4679 m
.35502 .46788 L
s
.35502 .46788 m
.35502 .46788 L
s
.973 1 0 r
.55612 .31397 m
.55621 .3133 L
s
.55621 .3133 m
.56488 .3178 L
s
1 .003 0 r
.12047 .4091 m
.12047 .40913 L
s
.35504 .4679 m
.35502 .46791 L
s
.35502 .46788 m
.35504 .4679 L
s
.35502 .46791 m
.355 .4679 L
s
.355 .4679 m
.35502 .46788 L
s
.35502 .46788 m
.35502 .46791 L
s
1 .008 0 r
.82418 .58535 m
.82423 .58539 L
s
.82413 .58538 m
.82418 .58535 L
s
.82418 .58535 m
.8242 .58535 L
s
1 .058 0 r
.65442 .55635 m
.65407 .55601 L
s
.65407 .55601 m
.65456 .5558 L
s
1 .008 0 r
.82423 .58539 m
.82418 .58543 L
s
.8242 .58535 m
.82423 .58539 L
s
.82418 .58543 m
.82413 .58538 L
s
.82413 .58538 m
.8242 .58535 L
s
1 .077 0 r
.24653 .29083 m
.24694 .29129 L
s
.24606 .29106 m
.24653 .29083 L
s
.24653 .29083 m
.24669 .29078 L
s
1 .008 0 r
.8242 .58535 m
.82418 .58543 L
s
1 .058 0 r
.65456 .5558 m
.65442 .55635 L
s
1 .077 0 r
.24694 .29129 m
.24647 .29152 L
s
.24669 .29078 m
.24694 .29129 L
s
1 .121 0 r
.31149 .3214 m
.31084 .32065 L
s
.31084 .32065 m
.31188 .32024 L
s
1 .229 0 r
.37768 .34833 m
.37887 .34979 L
s
.37639 .34897 m
.37768 .34833 L
s
.37768 .34833 m
.37844 .34829 L
s
1 .787 0 r
.4503 .6146 m
.45431 .61732 L
s
1 .121 0 r
.31188 .32024 m
.31149 .3214 L
s
1 .166 0 r
.69477 .35094 m
.69563 .34987 L
s
1 .077 0 r
.24647 .29152 m
.24606 .29106 L
s
.24606 .29106 m
.24669 .29078 L
s
0 .04 1 r
.64867 .29102 m
.61952 .3194 L
s
.60832 .28768 m
.64867 .29102 L
s
1 .229 0 r
.37887 .34979 m
.37758 .35044 L
s
.37844 .34829 m
.37887 .34979 L
s
1 .077 0 r
.24669 .29078 m
.24647 .29152 L
s
1 .344 0 r
.6188 .58242 m
.6205 .58479 L
s
.61719 .58347 m
.6188 .58242 L
s
.6188 .58242 m
.62058 .5828 L
s
1 .825 0 r
.45422 .35526 m
.45019 .34963 L
s
.45019 .34963 m
.45814 .34782 L
s
1 .344 0 r
.6205 .58479 m
.6189 .58584 L
s
.62058 .5828 m
.6205 .58479 L
s
1 .009 0 r
.82083 .40832 m
.82083 .40831 L
s
.82082 .40823 m
.82083 .40832 L
s
.82083 .40832 m
.82077 .40828 L
s
.82088 .40827 m
.82083 .40832 L
s
.8208 .40809 m
.82083 .40832 L
s
.22985 .58476 m
.22982 .58477 L
s
.22983 .58468 m
.22985 .58476 L
s
.22985 .58476 m
.22978 .58473 L
s
.22988 .58472 m
.22985 .58476 L
s
.22975 .58456 m
.22985 .58476 L
s
.973 1 0 r
.57179 .67297 m
.56323 .67836 L
s
.56305 .66985 m
.57179 .67297 L
s
1 .009 0 r
.82082 .40823 m
.82077 .40828 L
s
.82088 .40827 m
.82082 .40823 L
s
.22983 .58468 m
.22978 .58473 L
s
.22988 .58472 m
.22983 .58468 L
s
.82077 .40828 m
.82083 .40831 L
s
.22978 .58473 m
.22982 .58477 L
s
.82083 .40831 m
.82088 .40827 L
s
.22982 .58477 m
.22988 .58472 L
s
1 .233 0 r
.69912 .70221 m
.70522 .69803 L
s
1 .007 0 r
.75996 .55515 m
.76002 .55499 L
s
1 0 0 r
.01 w
.52528 .49633 Mdot
1 .007 0 r
.5 Mabswid
.29059 .43751 m
.29061 .43733 L
s
1 .233 0 r
.35144 .29045 m
.35658 .28513 L
s
0 1 .331 r
.48871 .31429 m
.48324 .33716 L
s
1 .043 0 r
.75701 .37866 m
.75695 .37864 L
s
.75692 .37825 m
.75701 .37866 L
s
.75701 .37866 m
.75668 .37849 L
s
.75718 .3784 m
.75701 .37866 L
s
.75662 .37758 m
.75701 .37866 L
s
.75692 .37825 m
.75668 .37849 L
s
.75718 .3784 m
.75692 .37825 L
s
1 .007 0 r
.76001 .55499 m
.76005 .55503 L
s
.75997 .55502 m
.76001 .55499 L
s
.76001 .55499 m
.76002 .55499 L
s
.29061 .43734 m
.29065 .43737 L
s
.29057 .43737 m
.29061 .43734 L
s
.29061 .43734 m
.29061 .43733 L
s
.76005 .55503 m
.76001 .55506 L
s
.76002 .55499 m
.76005 .55503 L
s
.29065 .43737 m
.2906 .4374 L
s
.29061 .43733 m
.29065 .43737 L
s
1 .825 0 r
.45814 .34782 m
.45422 .35526 L
s
1 .007 0 r
.76001 .55506 m
.75997 .55502 L
s
.75997 .55502 m
.76002 .55499 L
s
.2906 .4374 m
.29057 .43737 L
s
.29057 .43737 m
.29061 .43733 L
s
.76002 .55499 m
.76001 .55506 L
s
.29061 .43733 m
.2906 .4374 L
s
1 .043 0 r
.75668 .37849 m
.75695 .37864 L
s
.75695 .37864 m
.75718 .3784 L
s
1 .229 0 r
.37758 .35044 m
.37639 .34897 L
s
.37639 .34897 m
.37844 .34829 L
s
.787 1 0 r
.47254 .39867 m
.47946 .40566 L
s
.46542 .40307 m
.47254 .39867 L
s
.47254 .39867 m
.47519 .39826 L
s
0 .04 1 r
.61952 .3194 m
.60832 .28768 L
s
1 .229 0 r
.37844 .34829 m
.37758 .35044 L
s
1 .606 0 r
.46673 .43227 m
.47018 .43578 L
s
.46317 .43452 m
.46673 .43227 L
s
.46673 .43227 m
.46803 .43216 L
s
1 .293 0 r
.67793 .28954 m
.67643 .28966 L
s
.6763 .28701 m
.67793 .28954 L
s
.67793 .28954 m
.67501 .28912 L
s
.67772 .28755 m
.67793 .28954 L
s
.67008 .28352 m
.67793 .28954 L
s
1 .575 0 r
.43676 .70571 m
.43912 .70144 L
s
1 .117 0 r
.59075 .524 m
.59142 .52469 L
s
.59009 .52445 m
.59075 .524 L
s
.59075 .524 m
.59106 .52402 L
s
1 .001 0 r
.16523 .55419 m
.16522 .55419 L
s
.16522 .55418 m
.16523 .55419 L
s
.16523 .55419 m
.16522 .55418 L
s
.16523 .55418 m
.16523 .55419 L
s
.16521 .55416 m
.16523 .55419 L
s
.16522 .55418 m
.16522 .55418 L
s
.16523 .55418 m
.16522 .55418 L
s
.16522 .55418 m
.16522 .55419 L
s
.16522 .55419 m
.16523 .55418 L
s
1 .043 0 r
.33613 .5836 m
.336 .58361 L
s
.33603 .58319 m
.33613 .5836 L
s
.33613 .5836 m
.33577 .58344 L
s
.33626 .58336 m
.33613 .5836 L
s
.33557 .58261 m
.33613 .5836 L
s
1 .003 0 r
.93056 .58359 m
.93059 .58353 L
s
1 .459 0 r
.63486 .67188 m
.64862 .66437 L
s
1 .003 0 r
.69574 .52473 m
.69576 .52465 L
s
1 .117 0 r
.46092 .46587 m
.46221 .46304 L
s
.973 1 0 r
.5218 .31872 m
.56488 .3178 L
s
1 .008 0 r
.22609 .40701 m
.22612 .4068 L
s
.285 1 0 r
.48717 .37755 m
.47715 .3837 L
s
.48117 .36692 m
.48717 .37755 L
s
1 .117 0 r
.59142 .52469 m
.59077 .52514 L
s
.59106 .52402 m
.59142 .52469 L
s
1 .003 0 r
.93058 .58353 m
.9306 .58354 L
s
.93057 .58354 m
.93058 .58353 L
s
.93058 .58353 m
.93059 .58353 L
s
1 .787 0 r
.59956 .61297 m
.59375 .61865 L
s
.59152 .61242 m
.59956 .61297 L
s
1 .003 0 r
.9306 .58354 m
.93059 .58355 L
s
.93059 .58353 m
.9306 .58354 L
s
.93059 .58355 m
.93057 .58354 L
s
.93057 .58354 m
.93059 .58353 L
s
.69576 .52465 m
.69577 .52467 L
s
.69574 .52467 m
.69576 .52465 L
s
.69576 .52465 m
.69576 .52465 L
s
.93059 .58353 m
.93059 .58355 L
s
.69577 .52467 m
.69576 .52468 L
s
.69576 .52465 m
.69577 .52467 L
s
.69576 .52468 m
.69574 .52467 L
s
.69574 .52467 m
.69576 .52465 L
s
.69576 .52465 m
.69576 .52468 L
s
1 .043 0 r
.33603 .58319 m
.33577 .58344 L
s
.33626 .58336 m
.33603 .58319 L
s
1 .293 0 r
.6763 .28701 m
.67501 .28912 L
s
.67772 .28755 m
.6763 .28701 L
s
1 .344 0 r
.6189 .58584 m
.61719 .58347 L
s
.61719 .58347 m
.62058 .5828 L
s
1 .008 0 r
.22612 .4068 m
.22617 .40685 L
s
.22607 .40684 m
.22612 .4068 L
s
.22612 .4068 m
.22612 .4068 L
s
0 .197 1 r
.40705 .31112 m
.42271 .34683 L
s
1 .293 0 r
.67501 .28912 m
.67643 .28966 L
s
1 .008 0 r
.22617 .40685 m
.22611 .40688 L
s
.22612 .4068 m
.22617 .40685 L
s
1 .043 0 r
.33577 .58344 m
.336 .58361 L
s
1 .008 0 r
.22611 .40688 m
.22607 .40684 L
s
.22607 .40684 m
.22612 .4068 L
s
.22612 .4068 m
.22611 .40688 L
s
1 .787 0 r
.59375 .61865 m
.59152 .61242 L
s
.973 1 0 r
.49263 .6793 m
.49616 .67138 L
s
1 .043 0 r
.336 .58361 m
.33626 .58336 L
s
1 .117 0 r
.59077 .52514 m
.59009 .52445 L
s
.59009 .52445 m
.59106 .52402 L
s
1 .344 0 r
.62058 .5828 m
.6189 .58584 L
s
1 .168 0 r
.31985 .70091 m
.31904 .70113 L
s
.31914 .6994 m
.31985 .70091 L
s
.31985 .70091 m
.31824 .70051 L
s
.31994 .70001 m
.31985 .70091 L
s
.31605 .69767 m
.31985 .70091 L
s
1 .117 0 r
.59106 .52402 m
.59077 .52514 L
s
0 1 .077 r
.48069 .35952 m
.46884 .34764 L
s
.46884 .34764 m
.48556 .33915 L
s
.939 1 0 r
.46296 .64197 m
.45844 .6431 L
s
.45865 .63236 m
.46296 .64197 L
s
.46296 .64197 m
.45301 .63937 L
s
.46408 .63607 m
.46296 .64197 L
s
.44063 .62049 m
.46296 .64197 L
s
1 .606 0 r
.47018 .43578 m
.46662 .43803 L
s
.46803 .43216 m
.47018 .43578 L
s
1 .168 0 r
.31914 .6994 m
.31824 .70051 L
s
.31994 .70001 m
.31914 .6994 L
s
1 .055 0 r
.2111 .70062 m
.21087 .70068 L
s
.21092 .70011 m
.2111 .70062 L
s
.2111 .70062 m
.2106 .70045 L
s
.21119 .70033 m
.2111 .70062 L
s
.21007 .69949 m
.2111 .70062 L
s
1 .199 0 r
.61279 .43562 m
.61206 .43566 L
s
.61201 .43377 m
.61279 .43562 L
s
.61279 .43562 m
.61097 .43507 L
s
.61311 .43437 m
.61279 .43562 L
s
.60902 .43111 m
.61279 .43562 L
s
1 .741 0 r
.58742 .29389 m
.58871 .28771 L
s
1 .59 0 r
.6004 .3767 m
.60257 .37762 L
s
.60243 .37212 m
.6004 .3767 L
s
.60649 .37667 m
.6004 .3767 L
s
.973 1 0 r
.56488 .3178 m
.55631 .32269 L
s
.55612 .31397 m
.56488 .3178 L
s
1 .59 0 r
.60649 .37667 m
.60257 .37762 L
s
.60243 .37212 m
.60649 .37667 L
s
.60461 .37303 m
.60649 .37667 L
s
.58648 .36764 m
.60649 .37667 L
s
1 .055 0 r
.21092 .70011 m
.2106 .70045 L
s
.21119 .70033 m
.21092 .70011 L
s
1 .168 0 r
.31824 .70051 m
.31904 .70113 L
s
1 .787 0 r
.45431 .61732 m
.45849 .61213 L
s
1 .055 0 r
.2106 .70045 m
.21087 .70068 L
s
1 .59 0 r
.60461 .37303 m
.60243 .37212 L
s
1 .077 0 r
.80549 .7004 m
.80703 .69885 L
s
1 .002 0 r
.86641 .55316 m
.86642 .55313 L
s
.939 1 0 r
.57053 .6415 m
.6103 .62994 L
s
1 0 0 r
.63144 .49427 m
.63144 .49427 L
s
1 .058 0 r
.39648 .43538 m
.39708 .43394 L
s
1 .65 0 r
.4574 .28814 m
.4812 .2795 L
s
1 .009 0 r
.16152 .37648 m
.16155 .37626 L
s
1 .65 0 r
.61421 .70039 m
.61254 .70195 L
s
.61237 .69526 m
.61421 .70039 L
s
.61734 .69724 m
.61421 .70039 L
s
1 .002 0 r
.86642 .55313 m
.86643 .55313 L
s
.86641 .55313 m
.86642 .55313 L
s
.86642 .55313 m
.86642 .55313 L
s
.86643 .55313 m
.86642 .55314 L
s
.86642 .55313 m
.86643 .55313 L
s
.86642 .55314 m
.86641 .55313 L
s
.86641 .55313 m
.86642 .55313 L
s
.86642 .55313 m
.86642 .55314 L
s
1 .055 0 r
.21087 .70068 m
.21119 .70033 L
s
1 .199 0 r
.61201 .43377 m
.61097 .43507 L
s
.61311 .43437 m
.61201 .43377 L
s
1 .009 0 r
.16155 .37626 m
.16159 .37631 L
s
.16149 .3763 m
.16155 .37626 L
s
.16155 .37626 m
.16155 .37626 L
s
.16159 .37631 m
.16154 .37634 L
s
.16155 .37626 m
.16159 .37631 L
s
.16154 .37634 m
.16149 .3763 L
s
.16149 .3763 m
.16155 .37626 L
s
.16155 .37626 m
.16154 .37634 L
s
.973 1 0 r
.56323 .67836 m
.56305 .66985 L
s
.787 1 0 r
.47946 .40566 m
.47235 .41008 L
s
.47519 .39826 m
.47946 .40566 L
s
1 .199 0 r
.61097 .43507 m
.61206 .43566 L
s
1 .65 0 r
.61069 .69681 m
.61237 .69526 L
s
.61237 .69526 m
.61734 .69724 L
s
1 .168 0 r
.31904 .70113 m
.31994 .70001 L
s
1 .121 0 r
.73661 .31711 m
.73623 .31708 L
s
.73615 .31597 m
.73661 .31711 L
s
.73661 .31711 m
.73552 .31675 L
s
.73686 .3163 m
.73661 .31711 L
s
.7345 .31418 m
.73661 .31711 L
s
0 1 .331 r
.57722 .67051 m
.58166 .67531 L
s
.58126 .65147 m
.57722 .67051 L
s
.60017 .66634 m
.57722 .67051 L
s
1 .293 0 r
.67643 .28966 m
.67772 .28755 L
s
1 .121 0 r
.73615 .31597 m
.73552 .31675 L
s
.73686 .3163 m
.73615 .31597 L
s
1 .011 0 r
.86318 .37568 m
.86317 .37567 L
s
.86316 .37557 m
.86318 .37568 L
s
.86318 .37568 m
.8631 .37563 L
s
.86323 .37561 m
.86318 .37568 L
s
.86313 .37538 m
.86318 .37568 L
s
1 .39 0 r
.4077 .64081 m
.40596 .64122 L
s
.4061 .63728 m
.4077 .64081 L
s
.4077 .64081 m
.40401 .63985 L
s
.40804 .63865 m
.4077 .64081 L
s
.39929 .63298 m
.4077 .64081 L
s
.717 1 0 r
.52739 .31675 m
.51791 .32596 L
s
.51424 .31568 m
.52739 .31675 L
s
1 .121 0 r
.73552 .31675 m
.73623 .31708 L
s
1 .011 0 r
.86316 .37557 m
.8631 .37563 L
s
.86323 .37561 m
.86316 .37557 L
s
.8631 .37563 m
.86317 .37567 L
s
.86317 .37567 m
.86323 .37561 L
s
1 .606 0 r
.46662 .43803 m
.46317 .43452 L
s
.46317 .43452 m
.46803 .43216 L
s
1 .59 0 r
.44959 .37117 m
.45247 .3752 L
s
.44656 .37263 m
.44959 .37117 L
s
.44959 .37117 m
.45226 .37134 L
s
1 .117 0 r
.46196 .46305 m
.46263 .46373 L
s
.46128 .46349 m
.46196 .46305 L
s
.46196 .46305 m
.46221 .46304 L
s
1 .005 0 r
.27106 .55229 m
.27105 .55229 L
s
.27105 .55224 m
.27106 .55229 L
s
.27106 .55229 m
.27102 .55227 L
s
.27108 .55226 m
.27106 .55229 L
s
.27102 .55217 m
.27106 .55229 L
s
.27105 .55224 m
.27102 .55227 L
s
.27108 .55226 m
.27105 .55224 L
s
1 .241 0 r
.36292 .67012 m
.36179 .6704 L
s
.36191 .66795 m
.36292 .67012 L
s
.36292 .67012 m
.36062 .66954 L
s
.36309 .66881 m
.36292 .67012 L
s
.35759 .66538 m
.36292 .67012 L
s
1 .005 0 r
.27102 .55227 m
.27105 .55229 L
s
.27105 .55229 m
.27108 .55226 L
s
1 .058 0 r
.39697 .43395 m
.3973 .43429 L
s
.39662 .43417 m
.39697 .43395 L
s
.39697 .43395 m
.39708 .43394 L
s
1 .199 0 r
.61206 .43566 m
.61311 .43437 L
s
1 .121 0 r
.74122 .67003 m
.7437 .66756 L
s
1 0 0 r
.80217 .5227 m
.80218 .52269 L
s
1 .039 0 r
.33197 .40485 m
.33233 .40387 L
s
1 .009 0 r
.09687 .34592 m
.09689 .34569 L
s
1 0 0 r
.80218 .52269 m
.80218 .5227 L
s
.80217 .5227 m
.80218 .52269 L
s
.80218 .52269 m
.80218 .52269 L
s
.80218 .5227 m
.80218 .5227 L
s
.80218 .52269 m
.80218 .5227 L
s
.80218 .5227 m
.80217 .5227 L
s
.80217 .5227 m
.80218 .52269 L
s
.80218 .52269 m
.80218 .5227 L
s
1 .058 0 r
.3973 .43429 m
.39695 .4345 L
s
.39708 .43394 m
.3973 .43429 L
s
.717 1 0 r
.51791 .32596 m
.51424 .31568 L
s
1 .117 0 r
.46263 .46373 m
.46194 .46417 L
s
.46221 .46304 m
.46263 .46373 L
s
1 .04 0 r
.79925 .34583 m
.79919 .34581 L
s
.79916 .34544 m
.79925 .34583 L
s
.79925 .34583 m
.79894 .34567 L
s
.79941 .34557 m
.79925 .34583 L
s
.79885 .3448 m
.79925 .34583 L
s
1 .233 0 r
.70393 .69767 m
.70509 .69928 L
s
.70289 .69845 m
.70393 .69767 L
s
.70393 .69767 m
.70522 .69803 L
s
.35561 .28514 m
.35674 .28673 L
s
.35436 .28567 m
.35561 .28514 L
s
.35561 .28514 m
.35658 .28513 L
s
1 .058 0 r
.39695 .4345 m
.39662 .43417 L
s
.39662 .43417 m
.39708 .43394 L
s
1 .121 0 r
.73623 .31708 m
.73686 .3163 L
s
1 .009 0 r
.09689 .3457 m
.09694 .34574 L
s
.09684 .34573 m
.09689 .3457 L
s
.09689 .3457 m
.09689 .34569 L
s
.09694 .34574 m
.09688 .34578 L
s
.09689 .34569 m
.09694 .34574 L
s
1 .04 0 r
.79916 .34544 m
.79894 .34567 L
s
.79941 .34557 m
.79916 .34544 L
s
1 .59 0 r
.45247 .3752 m
.44945 .37667 L
s
.45226 .37134 m
.45247 .3752 L
s
1 .009 0 r
.09688 .34578 m
.09684 .34573 L
s
.09684 .34573 m
.09689 .34569 L
s
1 .077 0 r
.80669 .69876 m
.80713 .69925 L
s
.80631 .69907 m
.80669 .69876 L
s
.80669 .69876 m
.80703 .69885 L
s
1 .009 0 r
.09689 .34569 m
.09688 .34578 L
s
1 .04 0 r
.79894 .34567 m
.79919 .34581 L
s
1 .233 0 r
.70509 .69928 m
.70406 .70007 L
s
.70522 .69803 m
.70509 .69928 L
s
.35674 .28673 m
.35549 .28725 L
s
.35658 .28513 m
.35674 .28673 L
s
1 .058 0 r
.39708 .43394 m
.39695 .4345 L
s
1 .077 0 r
.80713 .69925 m
.80675 .69955 L
s
.80703 .69885 m
.80713 .69925 L
s
1 .117 0 r
.46194 .46417 m
.46128 .46349 L
s
.46128 .46349 m
.46221 .46304 L
s
1 .241 0 r
.36191 .66795 m
.36062 .66954 L
s
.36309 .66881 m
.36191 .66795 L
s
1 .04 0 r
.79919 .34581 m
.79941 .34557 L
s
.939 1 0 r
.45865 .63236 m
.45301 .63937 L
s
.46408 .63607 m
.45865 .63236 L
s
0 .434 1 r
.4452 .34552 m
.4262 .36857 L
s
.41148 .33508 m
.4452 .34552 L
s
.787 1 0 r
.58354 .41345 m
.58565 .4034 L
s
1 .39 0 r
.4061 .63728 m
.40401 .63985 L
s
.40804 .63865 m
.4061 .63728 L
s
.808 1 0 r
.49304 .69909 m
.49704 .70218 L
s
.49714 .68989 m
.49304 .69909 L
s
.50535 .69903 m
.49304 .69909 L
s
1 .117 0 r
.46221 .46304 m
.46194 .46417 L
s
1 .077 0 r
.80675 .69955 m
.80631 .69907 L
s
.80631 .69907 m
.80703 .69885 L
s
.808 1 0 r
.50535 .69903 m
.49704 .70218 L
s
.49714 .68989 m
.50535 .69903 L
s
.50115 .69295 m
.50535 .69903 L
s
.4637 .68388 m
.50535 .69903 L
s
1 .241 0 r
.36062 .66954 m
.36179 .6704 L
s
1 .077 0 r
.80703 .69885 m
.80675 .69955 L
s
1 .039 0 r
.33227 .40389 m
.33249 .40411 L
s
.33203 .40403 m
.33227 .40389 L
s
.33227 .40389 m
.33233 .40387 L
s
0 .813 1 r
.60598 .37468 m
.59762 .37893 L
s
.59693 .34915 m
.60598 .37468 L
s
.62139 .35577 m
.60598 .37468 L
s
1 .039 0 r
.33249 .40411 m
.33225 .40425 L
s
.33233 .40387 m
.33249 .40411 L
s
1 .606 0 r
.46803 .43216 m
.46662 .43803 L
s
1 .39 0 r
.40401 .63985 m
.40596 .64122 L
s
1 .039 0 r
.33225 .40425 m
.33203 .40403 L
s
.33203 .40403 m
.33233 .40387 L
s
.808 1 0 r
.50115 .69295 m
.49714 .68989 L
s
1 .039 0 r
.33233 .40387 m
.33225 .40425 L
s
1 0 0 r
.20639 .5217 m
.20639 .5217 L
s
.20639 .52169 m
.20639 .5217 L
s
.20639 .5217 m
.20639 .5217 L
s
.2064 .5217 m
.20639 .5217 L
s
.20639 .52169 m
.20639 .5217 L
s
.20639 .52169 m
.20639 .5217 L
s
.2064 .5217 m
.20639 .52169 L
s
.20639 .5217 m
.20639 .5217 L
s
.20639 .5217 m
.2064 .5217 L
s
1 .029 0 r
.91212 .69858 m
.91262 .69797 L
s
1 .229 0 r
.67688 .63962 m
.68182 .635 L
s
1 0 0 r
.73786 .49221 m
.73786 .49221 L
s
.425 1 0 r
.50262 .43325 m
.56122 .41372 L
s
1 .029 0 r
.26738 .37428 m
.26763 .37354 L
s
1 .039 0 r
.37744 .55109 m
.37735 .5511 L
s
.37737 .55072 m
.37744 .55109 L
s
.37744 .55109 m
.37714 .55093 L
s
.37759 .55088 m
.37744 .55109 L
s
.37707 .55017 m
.37744 .55109 L
s
1 .233 0 r
.70406 .70007 m
.70289 .69845 L
s
.70289 .69845 m
.70522 .69803 L
s
.35549 .28725 m
.35436 .28567 L
s
.35436 .28567 m
.35658 .28513 L
s
1 .039 0 r
.37737 .55072 m
.37714 .55093 L
s
.37759 .55088 m
.37737 .55072 L
s
.973 1 0 r
.55631 .32269 m
.55612 .31397 L
s
1 .039 0 r
.37714 .55093 m
.37735 .5511 L
s
.939 1 0 r
.45301 .63937 m
.45844 .6431 L
s
1 .233 0 r
.70522 .69803 m
.70406 .70007 L
s
.35658 .28513 m
.35549 .28725 L
s
1 .039 0 r
.37735 .5511 m
.37759 .55088 L
s
0 1 .331 r
.58574 .65612 m
.58126 .65147 L
s
.58126 .65147 m
.60017 .66634 L
s
1 .459 0 r
.42604 .31155 m
.42804 .31488 L
s
.42389 .31241 m
.42604 .31155 L
s
.42604 .31155 m
.42852 .3118 L
s
1 .241 0 r
.36179 .6704 m
.36309 .66881 L
s
1 .459 0 r
.42804 .31488 m
.4259 .31575 L
s
.42852 .3118 m
.42804 .31488 L
s
.285 1 0 r
.47715 .3837 m
.46735 .37384 L
s
.46735 .37384 m
.48117 .36692 L
s
1 .029 0 r
.9125 .69794 m
.91268 .69812 L
s
.91236 .69806 m
.9125 .69794 L
s
.9125 .69794 m
.91262 .69797 L
s
.26759 .37355 m
.26775 .37372 L
s
.26741 .37366 m
.26759 .37355 L
s
.26759 .37355 m
.26763 .37354 L
s
.91268 .69812 m
.91254 .69824 L
s
.91262 .69797 m
.91268 .69812 L
s
.26775 .37372 m
.26757 .37382 L
s
.26763 .37354 m
.26775 .37372 L
s
.939 1 0 r
.51436 .3442 m
.51128 .3455 L
s
.51132 .3357 m
.51436 .3442 L
s
.51915 .33785 m
.51436 .3442 L
s
1 .063 0 r
.25248 .66859 m
.25223 .66864 L
s
.25228 .66799 m
.25248 .66859 L
s
.25248 .66859 m
.25191 .66838 L
s
.2526 .66825 m
.25248 .66859 L
s
.25137 .66724 m
.25248 .66859 L
s
1 .029 0 r
.91254 .69824 m
.91236 .69806 L
s
.91236 .69806 m
.91262 .69797 L
s
.26757 .37382 m
.26741 .37366 L
s
.26741 .37366 m
.26763 .37354 L
s
.91262 .69797 m
.91254 .69824 L
s
.26763 .37354 m
.26757 .37382 L
s
.787 1 0 r
.47235 .41008 m
.46542 .40307 L
s
.46542 .40307 m
.47519 .39826 L
s
0 1 .077 r
.48556 .33915 m
.48069 .35952 L
s
1 .063 0 r
.25228 .66799 m
.25191 .66838 L
s
.2526 .66825 m
.25228 .66799 L
s
0 1 .566 r
.45587 .40294 m
.44221 .41961 L
s
.43167 .39567 m
.45587 .40294 L
s
1 .063 0 r
.25191 .66838 m
.25223 .66864 L
s
1 .121 0 r
.74316 .66743 m
.74384 .66822 L
s
.74256 .66789 m
.74316 .66743 L
s
.74316 .66743 m
.7437 .66756 L
s
1 .005 0 r
.67351 .46181 m
.6735 .46181 L
s
.6735 .46176 m
.67351 .46181 L
s
.67351 .46181 m
.67347 .46179 L
s
.67353 .46178 m
.67351 .46181 L
s
.67348 .46168 m
.67351 .46181 L
s
.6735 .46176 m
.67347 .46179 L
s
.67353 .46178 m
.6735 .46176 L
s
.67347 .46179 m
.6735 .46181 L
s
.6735 .46181 m
.67353 .46178 L
s
1 .063 0 r
.25223 .66864 m
.2526 .66825 L
s
1 .121 0 r
.74384 .66822 m
.74324 .66867 L
s
.7437 .66756 m
.74384 .66822 L
s
1 .59 0 r
.60257 .37762 m
.60461 .37303 L
s
1 .038 0 r
.84784 .66817 m
.84845 .66737 L
s
1 0 0 r
.90886 .52068 m
.90886 .52067 L
s
1 .59 0 r
.61245 .60917 m
.6274 .59785 L
s
1 .344 0 r
.4381 .40268 m
.44609 .39525 L
s
1 0 0 r
.14169 .49118 m
.14169 .49118 L
s
1 .023 0 r
.20272 .34368 m
.20289 .34307 L
s
1 0 0 r
.90886 .52067 m
.90886 .52067 L
s
.90886 .52067 m
.90886 .52067 L
s
.90886 .52067 m
.90886 .52067 L
s
.90886 .52067 m
.90886 .52067 L
s
.90886 .52067 m
.90886 .52067 L
s
.90886 .52067 m
.90886 .52067 L
s
.90886 .52067 m
.90886 .52067 L
s
.90886 .52067 m
.90886 .52067 L
s
1 .39 0 r
.40596 .64122 m
.40804 .63865 L
s
.939 1 0 r
.50823 .33697 m
.51132 .3357 L
s
.51132 .3357 m
.51915 .33785 L
s
0 .813 1 r
.58847 .35314 m
.59693 .34915 L
s
.59693 .34915 m
.62139 .35577 L
s
1 .121 0 r
.74324 .66867 m
.74256 .66789 L
s
.74256 .66789 m
.7437 .66756 L
s
1 .023 0 r
.20287 .34309 m
.203 .34322 L
s
.20272 .34317 m
.20287 .34309 L
s
.20287 .34309 m
.20289 .34307 L
s
.203 .34322 m
.20285 .3433 L
s
.20289 .34307 m
.203 .34322 L
s
1 .121 0 r
.7437 .66756 m
.74324 .66867 L
s
1 .023 0 r
.20285 .3433 m
.20272 .34317 L
s
.20272 .34317 m
.20289 .34307 L
s
1 .65 0 r
.61734 .69724 m
.61254 .70195 L
s
.61069 .69681 m
.61734 .69724 L
s
1 .023 0 r
.20289 .34307 m
.20285 .3433 L
s
1 .59 0 r
.44945 .37667 m
.44656 .37263 L
s
.44656 .37263 m
.45226 .37134 L
s
1 .038 0 r
.84831 .66733 m
.84854 .66756 L
s
.84812 .66749 m
.84831 .66733 L
s
.84831 .66733 m
.84845 .66737 L
s
1 .65 0 r
.61254 .70195 m
.61069 .69681 L
s
.808 1 0 r
.56911 .69708 m
.56906 .69949 L
s
.5689 .68719 m
.56911 .69708 L
s
.57904 .69316 m
.56911 .69708 L
s
1 .038 0 r
.84854 .66756 m
.84835 .66772 L
s
.84845 .66737 m
.84854 .66756 L
s
.425 1 0 r
.59908 .54947 m
.59493 .55248 L
s
.5946 .53693 m
.59908 .54947 L
s
.60663 .54104 m
.59908 .54947 L
s
1 .038 0 r
.84835 .66772 m
.84812 .66749 L
s
.84812 .66749 m
.84845 .66737 L
s
.84845 .66737 m
.84835 .66772 L
s
1 .59 0 r
.45226 .37134 m
.44945 .37667 L
s
1 .001 0 r
.31244 .51969 m
.31244 .51969 L
s
.31244 .51968 m
.31244 .51969 L
s
.31244 .51969 m
.31243 .51969 L
s
.31245 .51969 m
.31244 .51969 L
s
.31243 .51966 m
.31244 .51969 L
s
.31244 .51968 m
.31243 .51969 L
s
.31245 .51969 m
.31244 .51968 L
s
.31243 .51969 m
.31244 .51969 L
s
.31244 .51969 m
.31245 .51969 L
s
1 .095 0 r
.7784 .28354 m
.77812 .2835 L
s
.77804 .28264 m
.7784 .28354 L
s
.7784 .28354 m
.77755 .28326 L
s
.77861 .28289 m
.7784 .28354 L
s
.7768 .28121 m
.7784 .28354 L
s
1 .052 0 r
.78348 .63773 m
.78429 .63659 L
s
1 0 0 r
.84454 .49014 m
.84454 .49014 L
s
0 1 .566 r
.54796 .57869 m
.64502 .54922 L
s
1 .141 0 r
.3735 .37207 m
.376 .36875 L
s
1 .019 0 r
.13797 .31304 m
.1381 .31253 L
s
1 .65 0 r
.47834 .28352 m
.47637 .28418 L
s
.47647 .27829 m
.47834 .28352 L
s
.4812 .2795 m
.47834 .28352 L
s
1 .095 0 r
.77804 .28264 m
.77755 .28326 L
s
.77861 .28289 m
.77804 .28264 L
s
1 .038 0 r
.84163 .31287 m
.84157 .31285 L
s
.84153 .3125 m
.84163 .31287 L
s
.84163 .31287 m
.84133 .31273 L
s
.84177 .31262 m
.84163 .31287 L
s
.84124 .3119 m
.84163 .31287 L
s
1 .133 0 r
.65356 .40139 m
.6531 .4014 L
s
.65305 .40015 m
.65356 .40139 L
s
.65356 .40139 m
.65235 .40102 L
s
.65379 .40054 m
.65356 .40139 L
s
.65111 .39832 m
.65356 .40139 L
s
1 .038 0 r
.84153 .3125 m
.84133 .31273 L
s
.84177 .31262 m
.84153 .3125 L
s
1 .095 0 r
.77755 .28326 m
.77812 .2835 L
s
1 .038 0 r
.84133 .31273 m
.84157 .31285 L
s
1 .459 0 r
.64578 .66353 m
.6478 .66688 L
s
.64392 .66487 m
.64578 .66353 L
s
.64578 .66353 m
.64862 .66437 L
s
1 .019 0 r
.13809 .31254 m
.13819 .31265 L
s
.13796 .31261 m
.13809 .31254 L
s
.13809 .31254 m
.1381 .31253 L
s
0 .813 1 r
.44913 .37172 m
.43212 .3924 L
s
.41897 .36251 m
.44913 .37172 L
s
1 .65 0 r
.4745 .27895 m
.47647 .27829 L
s
.47647 .27829 m
.4812 .2795 L
s
1 .019 0 r
.13819 .31265 m
.13807 .31272 L
s
.1381 .31253 m
.13819 .31265 L
s
1 .038 0 r
.84157 .31285 m
.84177 .31262 L
s
1 .019 0 r
.13807 .31272 m
.13796 .31261 L
s
.13796 .31261 m
.1381 .31253 L
s
1 .459 0 r
.6478 .66688 m
.64594 .66822 L
s
.64862 .66437 m
.6478 .66688 L
s
1 .019 0 r
.1381 .31253 m
.13807 .31272 L
s
1 .133 0 r
.65305 .40015 m
.65235 .40102 L
s
.65379 .40054 m
.65305 .40015 L
s
.425 1 0 r
.59043 .53988 m
.5946 .53693 L
s
.5946 .53693 m
.60663 .54104 L
s
1 .021 0 r
.18691 .63725 m
.18684 .63726 L
s
.18686 .63705 m
.18691 .63725 L
s
.18691 .63725 m
.18673 .63717 L
s
.18697 .63714 m
.18691 .63725 L
s
.18662 .63678 m
.18691 .63725 L
s
.787 1 0 r
.47519 .39826 m
.47235 .41008 L
s
0 .434 1 r
.41148 .33508 m
.4262 .36857 L
s
1 .133 0 r
.65235 .40102 m
.6531 .4014 L
s
1 .095 0 r
.77812 .2835 m
.77861 .28289 L
s
1 .459 0 r
.4259 .31575 m
.42389 .31241 L
s
.42389 .31241 m
.42852 .3118 L
s
1 .021 0 r
.18686 .63705 m
.18673 .63717 L
s
.18697 .63714 m
.18686 .63705 L
s
.18673 .63717 m
.18684 .63726 L
s
.18684 .63726 m
.18697 .63714 L
s
1 .459 0 r
.42852 .3118 m
.4259 .31575 L
s
.808 1 0 r
.56885 .68956 m
.5689 .68719 L
s
.5689 .68719 m
.57904 .69316 L
s
.717 1 0 r
.46723 .66651 m
.46175 .66801 L
s
.462 .65488 m
.46723 .66651 L
s
.46723 .66651 m
.45515 .6634 L
s
.46861 .65946 m
.46723 .66651 L
s
.44012 .64078 m
.46723 .66651 L
s
0 1 .077 r
.57314 .65244 m
.57675 .63541 L
s
1 .052 0 r
.7841 .63655 m
.78442 .63686 L
s
.78383 .63677 m
.7841 .63655 L
s
.7841 .63655 m
.78429 .63659 L
s
.78442 .63686 m
.78414 .63708 L
s
.78429 .63659 m
.78442 .63686 L
s
1 .133 0 r
.6531 .4014 m
.65379 .40054 L
s
0 1 .331 r
.60017 .66634 m
.58166 .67531 L
s
.58574 .65612 m
.60017 .66634 L
s
.50589 .65128 m
.60017 .66634 L
s
1 .001 0 r
.78014 .45959 m
.78014 .45959 L
s
.78014 .45958 m
.78014 .45959 L
s
.78014 .45959 m
.78014 .45959 L
s
.78014 .45958 m
.78014 .45959 L
s
.78014 .45957 m
.78014 .45959 L
s
.78014 .45958 m
.78014 .45959 L
s
.78014 .45958 m
.78014 .45958 L
s
.78014 .45959 m
.78014 .45959 L
s
.78014 .45959 m
.78014 .45958 L
s
1 .014 0 r
.9547 .66631 m
.95492 .666 L
s
1 .081 0 r
.71904 .60724 m
.72024 .60542 L
s
1 0 0 r
.24772 .48911 m
.24772 .48911 L
s
1 .08 0 r
.30882 .34143 m
.30999 .33947 L
s
1 .017 0 r
.07315 .28237 m
.07325 .28192 L
s
1 .052 0 r
.78414 .63708 m
.78383 .63677 L
s
.78383 .63677 m
.78429 .63659 L
s
0 1 .566 r
.43167 .39567 m
.44221 .41961 L
s
.285 1 0 r
.48117 .36692 m
.47715 .3837 L
s
1 .052 0 r
.78429 .63659 m
.78414 .63708 L
s
1 .014 0 r
.95486 .66599 m
.95496 .66607 L
s
.95479 .66605 m
.95486 .66599 L
s
.95486 .66599 m
.95492 .666 L
s
.95496 .66607 m
.95488 .66613 L
s
.95492 .666 m
.95496 .66607 L
s
1 .017 0 r
.07324 .28193 m
.07333 .28203 L
s
.07313 .28199 m
.07324 .28193 L
s
.07324 .28193 m
.07325 .28192 L
s
1 .014 0 r
.95488 .66613 m
.95479 .66605 L
s
.95479 .66605 m
.95492 .666 L
s
1 .075 0 r
.29399 .63651 m
.29373 .63656 L
s
.29379 .63581 m
.29399 .63651 L
s
.29399 .63651 m
.29334 .63626 L
s
.29418 .63611 m
.29399 .63651 L
s
.29283 .63488 m
.29399 .63651 L
s
1 .017 0 r
.07333 .28203 m
.07322 .28208 L
s
.07325 .28192 m
.07333 .28203 L
s
1 .014 0 r
.95492 .666 m
.95488 .66613 L
s
1 .229 0 r
.68078 .63477 m
.68201 .63627 L
s
.67965 .63558 m
.68078 .63477 L
s
.68078 .63477 m
.68182 .635 L
s
1 .017 0 r
.07322 .28208 m
.07313 .28199 L
s
.07313 .28199 m
.07325 .28192 L
s
.07325 .28192 m
.07322 .28208 L
s
1 .075 0 r
.29379 .63581 m
.29334 .63626 L
s
.29418 .63611 m
.29379 .63581 L
s
1 .336 0 r
.63863 .34092 m
.63669 .34122 L
s
.63658 .33812 m
.63863 .34092 L
s
.63863 .34092 m
.6352 .34062 L
s
.63807 .33872 m
.63863 .34092 L
s
.62864 .33467 m
.63863 .34092 L
s
1 .021 0 r
.41879 .51813 m
.41877 .51813 L
s
.41878 .51793 m
.41879 .51813 L
s
.41879 .51813 m
.41865 .51803 L
s
.4189 .51803 m
.41879 .51813 L
s
.41873 .51762 m
.41879 .51813 L
s
1 .229 0 r
.68201 .63627 m
.68088 .63708 L
s
.68182 .635 m
.68201 .63627 L
s
1 .021 0 r
.41878 .51793 m
.41865 .51803 L
s
.4189 .51803 m
.41878 .51793 L
s
1 .075 0 r
.29334 .63626 m
.29373 .63656 L
s
1 .021 0 r
.41865 .51803 m
.41877 .51813 L
s
.41877 .51813 m
.4189 .51803 L
s
1 .014 0 r
.71577 .42932 m
.71576 .42932 L
s
.71575 .42918 m
.71577 .42932 L
s
.71577 .42932 m
.71567 .42926 L
s
.71584 .42924 m
.71577 .42932 L
s
.71566 .42897 m
.71577 .42932 L
s
.71575 .42918 m
.71567 .42926 L
s
.71584 .42924 m
.71575 .42918 L
s
1 .075 0 r
.29373 .63656 m
.29418 .63611 L
s
0 .197 1 r
.64347 .3111 m
.61534 .3385 L
s
.60452 .30791 m
.64347 .3111 L
s
1 .336 0 r
.63658 .33812 m
.6352 .34062 L
s
.63807 .33872 m
.63658 .33812 L
s
.6352 .34062 m
.63669 .34122 L
s
1 .014 0 r
.71567 .42926 m
.71576 .42932 L
s
.939 1 0 r
.45844 .6431 m
.46408 .63607 L
s
1 .014 0 r
.71576 .42932 m
.71584 .42924 L
s
1 .016 0 r
.89033 .63583 m
.89055 .63547 L
s
1 .162 0 r
.65453 .57673 m
.65677 .57303 L
s
1 .787 0 r
.47986 .36986 m
.50895 .35978 L
s
1 0 0 r
.18293 .45852 m
.18293 .45851 L
s
1 .053 0 r
.24406 .31076 m
.24473 .30941 L
s
1 0 0 r
.18293 .45851 m
.18293 .45851 L
s
.18293 .45851 m
.18293 .45851 L
s
.18293 .45851 m
.18293 .45851 L
s
.18293 .45851 m
.18293 .45851 L
s
.18293 .45851 m
.18293 .45851 L
s
.18293 .45851 m
.18293 .45851 L
s
.18293 .45851 m
.18293 .45851 L
s
.18293 .45851 m
.18293 .45851 L
s
1 .141 0 r
.37553 .36875 m
.37627 .36966 L
s
.37473 .36916 m
.37553 .36875 L
s
.37553 .36875 m
.376 .36875 L
s
.37627 .36966 m
.37547 .37007 L
s
.376 .36875 m
.37627 .36966 L
s
1 .08 0 r
.30978 .33949 m
.31021 .33999 L
s
.30931 .33973 m
.30978 .33949 L
s
.30978 .33949 m
.30999 .33947 L
s
1 .016 0 r
.8905 .63546 m
.8906 .63555 L
s
.89041 .63553 m
.8905 .63546 L
s
.8905 .63546 m
.89055 .63547 L
s
1 .229 0 r
.68088 .63708 m
.67965 .63558 L
s
.67965 .63558 m
.68182 .635 L
s
1 .08 0 r
.31021 .33999 m
.30973 .34023 L
s
.30999 .33947 m
.31021 .33999 L
s
1 .016 0 r
.8906 .63555 m
.89051 .63562 L
s
.89055 .63547 m
.8906 .63555 L
s
1 .081 0 r
.71997 .60538 m
.72046 .60587 L
s
.71954 .60571 m
.71997 .60538 L
s
.71997 .60538 m
.72024 .60542 L
s
1 .016 0 r
.89051 .63562 m
.89041 .63553 L
s
.89041 .63553 m
.89055 .63547 L
s
.89055 .63547 m
.89051 .63562 L
s
1 .081 0 r
.72046 .60587 m
.72002 .6062 L
s
.72024 .60542 m
.72046 .60587 L
s
1 .229 0 r
.68182 .635 m
.68088 .63708 L
s
1 .08 0 r
.30973 .34023 m
.30931 .33973 L
s
.30931 .33973 m
.30999 .33947 L
s
.939 1 0 r
.60519 .63532 m
.60242 .63765 L
s
.60217 .62689 m
.60519 .63532 L
s
.6103 .62994 m
.60519 .63532 L
s
1 .459 0 r
.64594 .66822 m
.64392 .66487 L
s
.64392 .66487 m
.64862 .66437 L
s
0 .197 1 r
.61534 .3385 m
.60452 .30791 L
s
1 .081 0 r
.72002 .6062 m
.71954 .60571 L
s
.71954 .60571 m
.72024 .60542 L
s
1 .08 0 r
.30999 .33947 m
.30973 .34023 L
s
1 .459 0 r
.64862 .66437 m
.64594 .66822 L
s
1 .141 0 r
.37547 .37007 m
.37473 .36916 L
s
.37473 .36916 m
.376 .36875 L
s
1 .607 0 r
.58229 .31 m
.58345 .31049 L
s
.58334 .30493 m
.58229 .31 L
s
.58828 .30866 m
.58229 .31 L
s
1 .825 0 r
.54975 .33954 m
.54966 .34016 L
s
.5496 .33253 m
.54975 .33954 L
s
.55659 .33619 m
.54975 .33954 L
s
1 .081 0 r
.72024 .60542 m
.72002 .6062 L
s
1 .141 0 r
.376 .36875 m
.37547 .37007 L
s
1 .053 0 r
.24462 .30943 m
.24491 .30976 L
s
.24429 .3096 m
.24462 .30943 L
s
.24462 .30943 m
.24473 .30941 L
s
.24491 .30976 m
.24458 .30992 L
s
.24473 .30941 m
.24491 .30976 L
s
.717 1 0 r
.462 .65488 m
.45515 .6634 L
s
.46861 .65946 m
.462 .65488 L
s
1 0 0 r
.88705 .45747 m
.88705 .45747 L
s
.88705 .45746 m
.88705 .45747 L
s
.88705 .45747 m
.88705 .45747 L
s
.88705 .45747 m
.88705 .45747 L
s
.88705 .45746 m
.88705 .45747 L
s
.88705 .45746 m
.88705 .45747 L
s
.88705 .45747 m
.88705 .45746 L
s
.88705 .45747 m
.88705 .45747 L
s
.88705 .45747 m
.88705 .45747 L
s
1 .018 0 r
.82588 .60531 m
.8261 .60489 L
s
.808 1 0 r
.52877 .69402 m
.57904 .69316 L
s
1 .606 0 r
.58994 .54617 m
.59783 .53199 L
s
1 0 0 r
.354 .48703 m
.354 .48703 L
s
1 .336 0 r
.41517 .33918 m
.4245 .33249 L
s
1 .039 0 r
.17923 .28004 m
.17966 .27903 L
s
1 .001 0 r
.11806 .42789 m
.11806 .42787 L
s
.11806 .42787 m
.11806 .42788 L
s
.11805 .42788 m
.11806 .42787 L
s
.11806 .42787 m
.11806 .42787 L
s
.11806 .42788 m
.11806 .42788 L
s
.11806 .42787 m
.11806 .42788 L
s
.11806 .42788 m
.11805 .42788 L
s
.11805 .42788 m
.11806 .42787 L
s
1 .053 0 r
.24458 .30992 m
.24429 .3096 L
s
.24429 .3096 m
.24473 .30941 L
s
1 .001 0 r
.11806 .42787 m
.11806 .42788 L
s
.939 1 0 r
.59939 .62919 m
.60217 .62689 L
s
.60217 .62689 m
.6103 .62994 L
s
1 .053 0 r
.24473 .30941 m
.24458 .30992 L
s
1 .607 0 r
.58451 .30541 m
.58334 .30493 L
s
.58334 .30493 m
.58828 .30866 L
s
0 .813 1 r
.41897 .36251 m
.43212 .3924 L
s
1 .018 0 r
.82605 .60488 m
.82616 .60498 L
s
.82595 .60496 m
.82605 .60488 L
s
.82605 .60488 m
.8261 .60489 L
s
.82616 .60498 m
.82607 .60506 L
s
.8261 .60489 m
.82616 .60498 L
s
.82607 .60506 m
.82595 .60496 L
s
.82595 .60496 m
.8261 .60489 L
s
.8261 .60489 m
.82607 .60506 L
s
1 .336 0 r
.63669 .34122 m
.63807 .33872 L
s
1 .825 0 r
.54951 .33312 m
.5496 .33253 L
s
.5496 .33253 m
.55659 .33619 L
s
1 .65 0 r
.4812 .2795 m
.47637 .28418 L
s
.4745 .27895 m
.4812 .2795 L
s
1 .019 0 r
.22821 .60479 m
.22816 .60479 L
s
.22817 .6046 m
.22821 .60479 L
s
.22821 .60479 m
.22805 .60471 L
s
.22828 .60469 m
.22821 .60479 L
s
.22799 .60434 m
.22821 .60479 L
s
1 .344 0 r
.44452 .39512 m
.44622 .39749 L
s
.44275 .396 m
.44452 .39512 L
s
.44452 .39512 m
.44609 .39525 L
s
1 .019 0 r
.22817 .6046 m
.22805 .60471 L
s
.22828 .60469 m
.22817 .6046 L
s
1 .039 0 r
.17959 .27906 m
.1798 .27929 L
s
.17934 .27917 m
.17959 .27906 L
s
.17959 .27906 m
.17966 .27903 L
s
1 .65 0 r
.47637 .28418 m
.4745 .27895 L
s
1 .019 0 r
.22805 .60471 m
.22816 .60479 L
s
.22816 .60479 m
.22828 .60469 L
s
1 .039 0 r
.1798 .27929 m
.17955 .27941 L
s
.17966 .27903 m
.1798 .27929 L
s
.17955 .27941 m
.17934 .27917 L
s
.17934 .27917 m
.17966 .27903 L
s
1 .344 0 r
.44622 .39749 m
.44444 .39837 L
s
.44609 .39525 m
.44622 .39749 L
s
1 .039 0 r
.17966 .27903 m
.17955 .27941 L
s
0 1 .566 r
.58605 .39744 m
.57914 .40106 L
s
.57873 .37684 m
.58605 .39744 L
s
.59832 .38238 m
.58605 .39744 L
s
.808 1 0 r
.49704 .70218 m
.50115 .69295 L
s
1 .607 0 r
.58828 .30866 m
.58345 .31049 L
s
.58451 .30541 m
.58828 .30866 L
s
.56384 .30388 m
.58828 .30866 L
s
1 .525 0 r
.40992 .66364 m
.40756 .66425 L
s
.40775 .65888 m
.40992 .66364 L
s
.40992 .66364 m
.40493 .66237 L
s
.41038 .66075 m
.40992 .66364 L
s
.39853 .65317 m
.40992 .66364 L
s
1 .1 0 r
.69515 .36777 m
.69482 .36776 L
s
.69476 .36683 m
.69515 .36777 L
s
.69515 .36777 m
.69425 .36748 L
s
.69533 .36712 m
.69515 .36777 L
s
.69336 .36542 m
.69515 .36777 L
s
1 .09 0 r
.33561 .60444 m
.33535 .60448 L
s
.3354 .60358 m
.33561 .60444 L
s
.33561 .60444 m
.33486 .6041 L
s
.33589 .60396 m
.33561 .60444 L
s
.33443 .6024 m
.33561 .60444 L
s
1 .003 0 r
.82257 .42689 m
.82257 .42689 L
s
.82257 .42686 m
.82257 .42689 L
s
.82257 .42689 m
.82256 .42687 L
s
.82259 .42687 m
.82257 .42689 L
s
.82257 .42682 m
.82257 .42689 L
s
.82257 .42686 m
.82256 .42687 L
s
.82259 .42687 m
.82257 .42686 L
s
.808 1 0 r
.57904 .69316 m
.56906 .69949 L
s
.56885 .68956 m
.57904 .69316 L
s
1 .003 0 r
.82256 .42687 m
.82257 .42689 L
s
.82257 .42689 m
.82259 .42687 L
s
1 .021 0 r
.76136 .57475 m
.76156 .57426 L
s
1 0 0 r
.01 w
.52528 .51558 Mdot
1 .001 0 r
.5 Mabswid
.28919 .45641 m
.2892 .45638 L
s
1 .172 0 r
.3504 .30847 m
.35422 .30456 L
s
1 .001 0 r
.2892 .45638 m
.2892 .45639 L
s
.28919 .45639 m
.2892 .45638 L
s
.2892 .45638 m
.2892 .45638 L
s
.2892 .45639 m
.28919 .45639 L
s
.2892 .45638 m
.2892 .45639 L
s
.28919 .45639 m
.28919 .45639 L
s
.28919 .45639 m
.2892 .45638 L
s
.2892 .45638 m
.28919 .45639 L
s
1 .1 0 r
.69476 .36683 m
.69425 .36748 L
s
.69533 .36712 m
.69476 .36683 L
s
1 .09 0 r
.3354 .60358 m
.33486 .6041 L
s
.33589 .60396 m
.3354 .60358 L
s
.717 1 0 r
.45515 .6634 m
.46175 .66801 L
s
1 .1 0 r
.69425 .36748 m
.69482 .36776 L
s
.939 1 0 r
.51915 .33785 m
.51128 .3455 L
s
.50823 .33697 m
.51915 .33785 L
s
1 .09 0 r
.33486 .6041 m
.33535 .60448 L
s
1 .021 0 r
.76151 .57425 m
.76164 .57437 L
s
.7614 .57435 m
.76151 .57425 L
s
.76151 .57425 m
.76156 .57426 L
s
.76164 .57437 m
.76153 .57446 L
s
.76156 .57426 m
.76164 .57437 L
s
1 .09 0 r
.33535 .60448 m
.33589 .60396 L
s
1 .021 0 r
.76153 .57446 m
.7614 .57435 L
s
.7614 .57435 m
.76156 .57426 L
s
.939 1 0 r
.51128 .3455 m
.50823 .33697 L
s
1 .021 0 r
.76156 .57426 m
.76153 .57446 L
s
1 .1 0 r
.69482 .36776 m
.69533 .36712 L
s
1 .02 0 r
.75818 .39663 m
.75815 .39663 L
s
.75814 .39644 m
.75818 .39663 L
s
.75818 .39663 m
.75803 .39656 L
s
.75826 .39651 m
.75818 .39663 L
s
.758 .39614 m
.75818 .39663 L
s
1 .162 0 r
.65629 .57296 m
.65724 .57393 L
s
.6554 .57361 m
.65629 .57296 L
s
.65629 .57296 m
.65677 .57303 L
s
1 .02 0 r
.75814 .39644 m
.75803 .39656 L
s
.75826 .39651 m
.75814 .39644 L
s
.75803 .39656 m
.75815 .39663 L
s
.75815 .39663 m
.75826 .39651 L
s
1 .525 0 r
.40775 .65888 m
.40493 .66237 L
s
.41038 .66075 m
.40775 .65888 L
s
1 .162 0 r
.65724 .57393 m
.65635 .57458 L
s
.65677 .57303 m
.65724 .57393 L
s
1 .004 0 r
.1631 .57387 m
.16309 .57387 L
s
.1631 .57383 m
.1631 .57387 L
s
.1631 .57387 m
.16307 .57385 L
s
.16312 .57385 m
.1631 .57387 L
s
.16307 .57377 m
.1631 .57387 L
s
0 1 .511 r
.58298 .69228 m
.58784 .69767 L
s
.58736 .67169 m
.58298 .69228 L
s
.60785 .68782 m
.58298 .69228 L
s
1 .004 0 r
.1631 .57383 m
.16307 .57385 L
s
.16312 .57385 m
.1631 .57383 L
s
.16307 .57385 m
.16309 .57387 L
s
.16309 .57387 m
.16312 .57385 L
s
1 .006 0 r
.93298 .60337 m
.93305 .60323 L
s
1 .575 0 r
.63551 .69219 m
.65289 .68283 L
s
1 .024 0 r
.69676 .54416 m
.69691 .54359 L
s
1 0 0 r
.46053 .48495 m
.46053 .48495 L
s
1 .825 0 r
.52178 .33693 m
.55659 .33619 L
s
1 .003 0 r
.22431 .42574 m
.22432 .42568 L
s
1 .104 0 r
.28555 .27772 m
.28748 .2752 L
s
1 .003 0 r
.22432 .42568 m
.22433 .42569 L
s
.2243 .42569 m
.22432 .42568 L
s
.22432 .42568 m
.22432 .42568 L
s
.22433 .42569 m
.22431 .4257 L
s
.22432 .42568 m
.22433 .42569 L
s
.22431 .4257 m
.2243 .42569 L
s
.2243 .42569 m
.22432 .42568 L
s
.22432 .42568 m
.22431 .4257 L
s
1 .006 0 r
.93303 .60323 m
.93307 .60326 L
s
.933 .60326 m
.93303 .60323 L
s
.93303 .60323 m
.93305 .60323 L
s
0 1 .566 r
.57175 .38029 m
.57873 .37684 L
s
.57873 .37684 m
.59832 .38238 L
s
1 .006 0 r
.93307 .60326 m
.93304 .60329 L
s
.93305 .60323 m
.93307 .60326 L
s
.93304 .60329 m
.933 .60326 L
s
.933 .60326 m
.93305 .60323 L
s
1 .344 0 r
.44444 .39837 m
.44275 .396 L
s
.44275 .396 m
.44609 .39525 L
s
1 .006 0 r
.93305 .60323 m
.93304 .60329 L
s
1 .162 0 r
.65635 .57458 m
.6554 .57361 L
s
.6554 .57361 m
.65677 .57303 L
s
1 .525 0 r
.40493 .66237 m
.40756 .66425 L
s
1 .318 0 r
.36366 .69195 m
.36218 .69236 L
s
.36233 .68907 m
.36366 .69195 L
s
.36366 .69195 m
.36062 .69119 L
s
.36389 .69023 m
.36366 .69195 L
s
.35659 .68574 m
.36366 .69195 L
s
1 .344 0 r
.44609 .39525 m
.44444 .39837 L
s
.285 1 0 r
.43989 .60303 m
.44342 .60396 L
s
.44384 .58668 m
.43989 .60303 L
s
.43989 .60303 m
.43358 .59364 L
s
.45366 .59694 m
.43989 .60303 L
s
.45895 .56361 m
.43989 .60303 L
s
1 .024 0 r
.69687 .54359 m
.69702 .54371 L
s
.69674 .5437 m
.69687 .54359 L
s
.69687 .54359 m
.69691 .54359 L
s
1 .162 0 r
.65677 .57303 m
.65635 .57458 L
s
1 .024 0 r
.69702 .54371 m
.69688 .54382 L
s
.69691 .54359 m
.69702 .54371 L
s
.69688 .54382 m
.69674 .5437 L
s
.69674 .5437 m
.69691 .54359 L
s
.69691 .54359 m
.69688 .54382 L
s
1 .825 0 r
.55659 .33619 m
.54966 .34016 L
s
.54951 .33312 m
.55659 .33619 L
s
1 .606 0 r
.56312 .42503 m
.56424 .42576 L
s
.56417 .41998 m
.56312 .42503 L
s
.5691 .42377 m
.56312 .42503 L
s
1 .318 0 r
.36233 .68907 m
.36062 .69119 L
s
.36389 .69023 m
.36233 .68907 L
s
1 .417 0 r
.61711 .2766 m
.61841 .27701 L
s
.6183 .27322 m
.61711 .2766 L
s
.62142 .27621 m
.61711 .2766 L
s
1 .005 0 r
.86844 .57278 m
.86849 .57265 L
s
.717 1 0 r
.5708 .66165 m
.61928 .64772 L
s
1 .021 0 r
.63208 .51353 m
.63208 .51302 L
s
1 .008 0 r
.39571 .45429 m
.3958 .45408 L
s
1 .525 0 r
.45699 .30618 m
.47631 .29922 L
s
1 .004 0 r
.15935 .39504 m
.15936 .39494 L
s
.15936 .39495 m
.15938 .39497 L
s
.15933 .39496 m
.15936 .39495 L
s
.15936 .39495 m
.15936 .39494 L
s
.15938 .39497 m
.15936 .39498 L
s
.15936 .39494 m
.15938 .39497 L
s
.15936 .39498 m
.15933 .39496 L
s
.15933 .39496 m
.15936 .39494 L
s
1 .318 0 r
.36062 .69119 m
.36218 .69236 L
s
1 .004 0 r
.15936 .39494 m
.15936 .39498 L
s
1 .22 0 r
.67688 .30608 m
.67575 .30619 L
s
.67565 .30417 m
.67688 .30608 L
s
.67688 .30608 m
.67467 .30577 L
s
.67672 .30459 m
.67688 .30608 L
s
.67094 .30157 m
.67688 .30608 L
s
1 .005 0 r
.86848 .57265 m
.86851 .57268 L
s
.86845 .57268 m
.86848 .57265 L
s
.86848 .57265 m
.86849 .57265 L
s
.86851 .57268 m
.86848 .5727 L
s
.86849 .57265 m
.86851 .57268 L
s
.86848 .5727 m
.86845 .57268 L
s
.86845 .57268 m
.86849 .57265 L
s
.86849 .57265 m
.86848 .5727 L
s
1 .008 0 r
.39578 .45409 m
.39583 .45413 L
s
.39573 .45412 m
.39578 .45409 L
s
.39578 .45409 m
.3958 .45408 L
s
1 .606 0 r
.5653 .4207 m
.56417 .41998 L
s
.56417 .41998 m
.5691 .42377 L
s
1 .008 0 r
.39583 .45413 m
.39578 .45416 L
s
.3958 .45408 m
.39583 .45413 L
s
.39578 .45416 m
.39573 .45412 L
s
.39573 .45412 m
.3958 .45408 L
s
.3958 .45408 m
.39578 .45416 L
s
1 .417 0 r
.61961 .27363 m
.6183 .27322 L
s
.6183 .27322 m
.62142 .27621 L
s
1 .607 0 r
.58345 .31049 m
.58451 .30541 L
s
1 .172 0 r
.3535 .30456 m
.35434 .30574 L
s
.35257 .30495 m
.3535 .30456 L
s
.3535 .30456 m
.35422 .30456 L
s
1 .417 0 r
.62142 .27621 m
.61841 .27701 L
s
.61961 .27363 m
.62142 .27621 L
s
.60606 .27071 m
.62142 .27621 L
s
1 .22 0 r
.67565 .30417 m
.67467 .30577 L
s
.67672 .30459 m
.67565 .30417 L
s
1 .021 0 r
.63208 .51302 m
.63221 .51312 L
s
.63196 .51313 m
.63208 .51302 L
s
.63208 .51302 m
.63208 .51302 L
s
1 .22 0 r
.67467 .30577 m
.67575 .30619 L
s
1 .111 0 r
.37724 .57242 m
.377 .57245 L
s
.37705 .57134 m
.37724 .57242 L
s
.37724 .57242 m
.37637 .57196 L
s
.37768 .57183 m
.37724 .57242 L
s
.37619 .56981 m
.37724 .57242 L
s
1 .172 0 r
.35434 .30574 m
.35341 .30613 L
s
.35422 .30456 m
.35434 .30574 L
s
1 .021 0 r
.63208 .51323 m
.63196 .51313 L
s
.63196 .51313 m
.63208 .51302 L
s
.63221 .51312 m
.63208 .51323 L
s
.63208 .51302 m
.63221 .51312 L
s
.63208 .51302 m
.63208 .51323 L
s
1 .104 0 r
.28713 .27523 m
.28766 .27591 L
s
.28653 .27549 m
.28713 .27523 L
s
.28713 .27523 m
.28748 .2752 L
s
.28766 .27591 m
.28706 .27617 L
s
.28748 .2752 m
.28766 .27591 L
s
1 .111 0 r
.37705 .57134 m
.37637 .57196 L
s
.37768 .57183 m
.37705 .57134 L
s
1 .016 0 r
.26964 .57217 m
.2696 .57217 L
s
.26961 .57201 m
.26964 .57217 L
s
.26964 .57217 m
.26951 .5721 L
s
.2697 .57209 m
.26964 .57217 L
s
.2695 .57179 m
.26964 .57217 L
s
.26961 .57201 m
.26951 .5721 L
s
.2697 .57209 m
.26961 .57201 L
s
.26951 .5721 m
.2696 .57217 L
s
.2696 .57217 m
.2697 .57209 L
s
.808 1 0 r
.56906 .69949 m
.56885 .68956 L
s
1 .111 0 r
.37637 .57196 m
.377 .57245 L
s
1 .606 0 r
.5691 .42377 m
.56424 .42576 L
s
.5653 .4207 m
.5691 .42377 L
s
.54459 .41926 m
.5691 .42377 L
s
1 .59 0 r
.62431 .59716 m
.62725 .60127 L
s
.62154 .59899 m
.62431 .59716 L
s
.62431 .59716 m
.6274 .59785 L
s
1 .787 0 r
.5054 .36447 m
.50308 .36549 L
s
.50313 .35813 m
.5054 .36447 L
s
.50895 .35978 m
.5054 .36447 L
s
0 1 .511 r
.59227 .67691 m
.58736 .67169 L
s
.58736 .67169 m
.60785 .68782 L
s
1 .005 0 r
.86517 .39408 m
.86516 .39407 L
s
.86516 .39403 m
.86517 .39408 L
s
.86517 .39408 m
.86513 .39405 L
s
.86519 .39405 m
.86517 .39408 L
s
.86514 .39395 m
.86517 .39408 L
s
1 .336 0 r
.42268 .33228 m
.42416 .33473 L
s
.4211 .33294 m
.42268 .33228 L
s
.42268 .33228 m
.4245 .33249 L
s
1 .005 0 r
.86516 .39403 m
.86513 .39405 L
s
.86519 .39405 m
.86516 .39403 L
s
.86513 .39405 m
.86516 .39407 L
s
.86516 .39407 m
.86519 .39405 L
s
1 .104 0 r
.28706 .27617 m
.28653 .27549 L
s
.28653 .27549 m
.28748 .2752 L
s
1 .336 0 r
.42416 .33473 m
.42258 .33539 L
s
.4245 .33249 m
.42416 .33473 L
s
.787 1 0 r
.44585 .57185 m
.44837 .57234 L
s
.44865 .56022 m
.44585 .57185 L
s
.44585 .57185 m
.44141 .56508 L
s
.45561 .56746 m
.44585 .57185 L
s
.45935 .54359 m
.44585 .57185 L
s
1 .525 0 r
.40756 .66425 m
.41038 .66075 L
s
1 .111 0 r
.377 .57245 m
.37768 .57183 L
s
0 1 .077 r
.43544 .6311 m
.43969 .63247 L
s
.44022 .61133 m
.43544 .6311 L
s
.43544 .6311 m
.42775 .6199 L
s
.45213 .62384 m
.43544 .6311 L
s
.45854 .58388 m
.43544 .6311 L
s
1 .104 0 r
.28748 .2752 m
.28706 .27617 L
s
1 .168 0 r
.74251 .69035 m
.74596 .68695 L
s
1 .004 0 r
.80383 .54215 m
.80385 .54206 L
s
1 0 0 r
.56732 .48287 m
.56732 .48287 L
s
1 .013 0 r
.33082 .42359 m
.33093 .42327 L
s
1 .293 0 r
.39213 .27539 m
.4009 .2698 L
s
1 .005 0 r
.09431 .36431 m
.09432 .36419 L
s
1 .004 0 r
.80384 .54206 m
.80387 .54208 L
s
.80382 .54208 m
.80384 .54206 L
s
.80384 .54206 m
.80385 .54206 L
s
1 .172 0 r
.35341 .30613 m
.35257 .30495 L
s
.35257 .30495 m
.35422 .30456 L
s
1 .004 0 r
.80387 .54208 m
.80385 .54209 L
s
.80385 .54206 m
.80387 .54208 L
s
.80385 .54209 m
.80382 .54208 L
s
.80382 .54208 m
.80385 .54206 L
s
1 .005 0 r
.09432 .36419 m
.09435 .36421 L
s
.09429 .36421 m
.09432 .36419 L
s
.09432 .36419 m
.09432 .36419 L
s
.542 1 0 r
.47053 .69028 m
.4643 .69213 L
s
.46457 .67704 m
.47053 .69028 L
s
.47053 .69028 m
.45676 .68678 L
s
.47213 .68235 m
.47053 .69028 L
s
.4396 .6613 m
.47053 .69028 L
s
1 .004 0 r
.80385 .54206 m
.80385 .54209 L
s
1 .005 0 r
.09435 .36421 m
.09432 .36423 L
s
.09432 .36419 m
.09435 .36421 L
s
.09432 .36423 m
.09429 .36421 L
s
.09429 .36421 m
.09432 .36419 L
s
.09432 .36419 m
.09432 .36423 L
s
1 .318 0 r
.36218 .69236 m
.36389 .69023 L
s
1 .172 0 r
.35422 .30456 m
.35341 .30613 L
s
1 .59 0 r
.62725 .60127 m
.62448 .6031 L
s
.6274 .59785 m
.62725 .60127 L
s
1 .013 0 r
.33091 .42327 m
.33099 .42335 L
s
.33084 .42332 m
.33091 .42327 L
s
.33091 .42327 m
.33093 .42327 L
s
.33099 .42335 m
.33091 .42339 L
s
.33093 .42327 m
.33099 .42335 L
s
.33091 .42339 m
.33084 .42332 L
s
.33084 .42332 m
.33093 .42327 L
s
1 .787 0 r
.50081 .35914 m
.50313 .35813 L
s
.50313 .35813 m
.50895 .35978 L
s
1 .013 0 r
.33093 .42327 m
.33091 .42339 L
s
1 .08 0 r
.73715 .33432 m
.73689 .3343 L
s
.73684 .33356 m
.73715 .33432 L
s
.73715 .33432 m
.73643 .33408 L
s
.73731 .33378 m
.73715 .33432 L
s
.73575 .3324 m
.73715 .33432 L
s
1 .22 0 r
.67575 .30619 m
.67672 .30459 L
s
1 .08 0 r
.73684 .33356 m
.73643 .33408 L
s
.73731 .33378 m
.73684 .33356 L
s
1 .022 0 r
.80071 .36376 m
.80068 .36375 L
s
.80066 .36354 m
.80071 .36376 L
s
.80071 .36376 m
.80053 .36367 L
s
.8008 .36362 m
.80071 .36376 L
s
.80049 .36319 m
.80071 .36376 L
s
1 .08 0 r
.73643 .33408 m
.73689 .3343 L
s
1 .022 0 r
.80066 .36354 m
.80053 .36367 L
s
.8008 .36362 m
.80066 .36354 L
s
.80053 .36367 m
.80068 .36375 L
s
1 .825 0 r
.54966 .34016 m
.54951 .33312 L
s
1 .022 0 r
.80068 .36375 m
.8008 .36362 L
s
.425 1 0 r
.55386 .42283 m
.54946 .42518 L
s
.54935 .41017 m
.55386 .42283 L
s
.56122 .41372 m
.55386 .42283 L
s
1 .08 0 r
.73689 .3343 m
.73731 .33378 L
s
1 .091 0 r
.25133 .6895 m
.25097 .68958 L
s
.25104 .68864 m
.25133 .6895 L
s
.25133 .6895 m
.2505 .68921 L
s
.25151 .68902 m
.25133 .6895 L
s
.24973 .68759 m
.25133 .6895 L
s
1 .002 0 r
.2045 .54119 m
.2045 .54119 L
s
.2045 .54117 m
.2045 .54119 L
s
.2045 .54119 m
.20448 .54118 L
s
.20451 .54118 m
.2045 .54119 L
s
.20449 .54114 m
.2045 .54119 L
s
.2045 .54117 m
.20448 .54118 L
s
.20451 .54118 m
.2045 .54117 L
s
.20448 .54118 m
.2045 .54119 L
s
.2045 .54119 m
.20451 .54118 L
s
1 .323 0 r
.67778 .65977 m
.68483 .65327 L
s
1 .001 0 r
.73914 .51148 m
.73914 .51145 L
s
1 .398 0 r
.50249 .45217 m
.51728 .44729 L
s
1 .013 0 r
.26584 .39285 m
.26595 .39251 L
s
1 .001 0 r
.73914 .51145 m
.73915 .51145 L
s
.73913 .51145 m
.73914 .51145 L
s
.73914 .51145 m
.73914 .51145 L
s
.73914 .51146 m
.73913 .51145 L
s
.73913 .51145 m
.73914 .51145 L
s
.73915 .51145 m
.73914 .51146 L
s
.73914 .51145 m
.73915 .51145 L
s
.73914 .51145 m
.73914 .51146 L
s
.425 1 0 r
.60663 .54104 m
.59493 .55248 L
s
.59043 .53988 m
.60663 .54104 L
s
1 .091 0 r
.25104 .68864 m
.2505 .68921 L
s
.25151 .68902 m
.25104 .68864 L
s
.939 1 0 r
.6103 .62994 m
.60242 .63765 L
s
.59939 .62919 m
.6103 .62994 L
s
1 .013 0 r
.26594 .39252 m
.26601 .39259 L
s
.26585 .39257 m
.26594 .39252 L
s
.26594 .39252 m
.26595 .39251 L
s
.26601 .39259 m
.26592 .39264 L
s
.26595 .39251 m
.26601 .39259 L
s
1 .091 0 r
.2505 .68921 m
.25097 .68958 L
s
1 .013 0 r
.26592 .39264 m
.26585 .39257 L
s
.26585 .39257 m
.26595 .39251 L
s
.26595 .39251 m
.26592 .39264 L
s
1 .417 0 r
.61841 .27701 m
.61961 .27363 L
s
.717 1 0 r
.46175 .66801 m
.46861 .65946 L
s
.939 1 0 r
.60242 .63765 m
.59939 .62919 L
s
1 .091 0 r
.25097 .68958 m
.25151 .68902 L
s
.425 1 0 r
.59493 .55248 m
.59043 .53988 L
s
.54491 .41246 m
.54935 .41017 L
s
.54935 .41017 m
.56122 .41372 L
s
1 .336 0 r
.42258 .33539 m
.4211 .33294 L
s
.4211 .33294 m
.4245 .33249 L
s
.4245 .33249 m
.42258 .33539 L
s
1 .136 0 r
.41849 .5404 m
.41839 .54041 L
s
.41843 .53907 m
.41849 .5404 L
s
.41849 .5404 m
.41759 .53976 L
s
.41923 .53972 m
.41849 .5404 L
s
.41809 .53709 m
.41849 .5404 L
s
.285 1 0 r
.44384 .58668 m
.43358 .59364 L
s
.45366 .59694 m
.44384 .58668 L
s
0 .434 1 r
.63513 .33244 m
.60864 .35825 L
s
.59845 .32947 m
.63513 .33244 L
s
1 .575 0 r
.51875 .27308 m
.51814 .2734 L
s
.51815 .26818 m
.51875 .27308 L
s
.52294 .27022 m
.51875 .27308 L
s
1 0 0 r
.1394 .51046 m
.1394 .51046 L
s
.1394 .51046 m
.1394 .51046 L
s
.1394 .51046 m
.1394 .51046 L
s
.1394 .51046 m
.1394 .51046 L
s
.1394 .51045 m
.1394 .51046 L
s
.1394 .51046 m
.1394 .51046 L
s
.1394 .51046 m
.1394 .51046 L
s
.1394 .51046 m
.1394 .51046 L
s
.1394 .51046 m
.1394 .51046 L
s
1 .055 0 r
.84976 .68851 m
.85068 .68733 L
s
1 .001 0 r
.91115 .54013 m
.91116 .5401 L
s
1 .825 0 r
.61298 .62916 m
.63405 .6134 L
s
1 0 0 r
.67437 .48078 m
.67437 .48078 L
s
1 .136 0 r
.43758 .42143 m
.44073 .41852 L
s
1 .575 0 r
.49897 .27305 m
.52294 .27022 L
s
1 .013 0 r
.20079 .36208 m
.20088 .36175 L
s
1 .001 0 r
.91116 .5401 m
.91117 .54011 L
s
.91115 .54011 m
.91116 .5401 L
s
.91116 .5401 m
.91116 .5401 L
s
.91117 .54011 m
.91116 .54011 L
s
.91116 .5401 m
.91117 .54011 L
s
.91116 .54011 m
.91115 .54011 L
s
.91115 .54011 m
.91116 .5401 L
s
.91116 .5401 m
.91116 .54011 L
s
1 .136 0 r
.41843 .53907 m
.41759 .53976 L
s
.41923 .53972 m
.41843 .53907 L
s
1 .606 0 r
.56424 .42576 m
.5653 .4207 L
s
1 .013 0 r
.20087 .36175 m
.20094 .36183 L
s
.20079 .3618 m
.20087 .36175 L
s
.20087 .36175 m
.20088 .36175 L
s
1 .344 0 r
.59503 .39151 m
.5963 .39207 L
s
.59623 .38882 m
.59503 .39151 L
s
.59862 .39149 m
.59503 .39151 L
s
1 .013 0 r
.20094 .36183 m
.20086 .36187 L
s
.20088 .36175 m
.20094 .36183 L
s
1 .525 0 r
.474 .30245 m
.4724 .30303 L
s
.47248 .29821 m
.474 .30245 L
s
.47631 .29922 m
.474 .30245 L
s
1 .344 0 r
.59862 .39149 m
.5963 .39207 L
s
.59623 .38882 m
.59862 .39149 L
s
.5975 .38937 m
.59862 .39149 L
s
.58685 .38624 m
.59862 .39149 L
s
1 .013 0 r
.20086 .36187 m
.20079 .3618 L
s
.20079 .3618 m
.20088 .36175 L
s
.20088 .36175 m
.20086 .36187 L
s
1 .344 0 r
.5975 .38937 m
.59623 .38882 L
s
1 .032 0 r
.61012 .45076 m
.61001 .45076 L
s
.61 .45046 m
.61012 .45076 L
s
.61012 .45076 m
.60983 .45067 L
s
.61017 .45056 m
.61012 .45076 L
s
.60952 .45004 m
.61012 .45076 L
s
1 .136 0 r
.41759 .53976 m
.41839 .54041 L
s
1 .032 0 r
.61 .45046 m
.60983 .45067 L
s
.61017 .45056 m
.61 .45046 L
s
1 .136 0 r
.41839 .54041 m
.41923 .53972 L
s
1 .032 0 r
.60983 .45067 m
.61001 .45076 L
s
1 .575 0 r
.51753 .26849 m
.51815 .26818 L
s
.51815 .26818 m
.52294 .27022 L
s
.787 1 0 r
.44865 .56022 m
.44141 .56508 L
s
.45561 .56746 m
.44865 .56022 L
s
1 .59 0 r
.62448 .6031 m
.62154 .59899 L
s
.62154 .59899 m
.6274 .59785 L
s
1 .525 0 r
.47087 .29878 m
.47248 .29821 L
s
.47248 .29821 m
.47631 .29922 L
s
1 .032 0 r
.61001 .45076 m
.61017 .45056 L
s
1 .168 0 r
.74522 .68677 m
.74616 .68786 L
s
.74438 .68741 m
.74522 .68677 L
s
.74522 .68677 m
.74596 .68695 L
s
.542 1 0 r
.46457 .67704 m
.45676 .68678 L
s
.47213 .68235 m
.46457 .67704 L
s
1 .168 0 r
.74616 .68786 m
.74533 .6885 L
s
.74596 .68695 m
.74616 .68786 L
s
0 1 .511 r
.60785 .68782 m
.58784 .69767 L
s
.59227 .67691 m
.60785 .68782 L
s
.50577 .67174 m
.60785 .68782 L
s
1 .01 0 r
.31121 .53937 m
.31119 .53937 L
s
.3112 .53927 m
.31121 .53937 L
s
.31121 .53937 m
.31114 .53932 L
s
.31126 .53932 m
.31121 .53937 L
s
.31116 .53912 m
.31121 .53937 L
s
.3112 .53927 m
.31114 .53932 L
s
.31126 .53932 m
.3112 .53927 L
s
0 .434 1 r
.60864 .35825 m
.59845 .32947 L
s
1 .01 0 r
.31114 .53932 m
.31119 .53937 L
s
.31119 .53937 m
.31126 .53932 L
s
1 .59 0 r
.6274 .59785 m
.62448 .6031 L
s
1 .055 0 r
.85047 .68729 m
.8508 .68762 L
s
.85018 .68752 m
.85047 .68729 L
s
.85047 .68729 m
.85068 .68733 L
s
.8508 .68762 m
.85052 .68785 L
s
.85068 .68733 m
.8508 .68762 L
s
1 .081 0 r
.78502 .65789 m
.78629 .65613 L
s
1 0 0 r
.84645 .50942 m
.84645 .50942 L
s
0 .813 1 r
.54809 .59851 m
.66993 .56195 L
s
1 .07 0 r
.37259 .39065 m
.37384 .38901 L
s
1 .012 0 r
.13566 .33126 m
.13574 .33095 L
s
1 0 0 r
.84645 .50942 m
.84645 .50942 L
s
.84645 .50942 m
.84645 .50942 L
s
.84645 .50942 m
.84645 .50942 L
s
.84645 .50942 m
.84645 .50942 L
s
.84645 .50942 m
.84645 .50942 L
s
.84645 .50942 m
.84645 .50942 L
s
.84645 .50942 m
.84645 .50942 L
s
.84645 .50942 m
.84645 .50942 L
s
1 .158 0 r
.71736 .2718 m
.71662 .27183 L
s
.71652 .2704 m
.71736 .2718 L
s
.71736 .2718 m
.71579 .27152 L
s
.71735 .27071 m
.71736 .2718 L
s
.7134 .26836 m
.71736 .2718 L
s
0 1 .331 r
.58166 .67531 m
.58574 .65612 L
s
1 .055 0 r
.85052 .68785 m
.85018 .68752 L
s
.85018 .68752 m
.85068 .68733 L
s
1 .293 0 r
.4004 .27179 m
.39909 .27225 L
s
.3992 .26959 m
.4004 .27179 L
s
.4009 .2698 m
.4004 .27179 L
s
.39789 .27005 m
.3992 .26959 L
s
.3992 .26959 m
.4009 .2698 L
s
1 .055 0 r
.85068 .68733 m
.85052 .68785 L
s
1 .168 0 r
.74533 .6885 m
.74438 .68741 L
s
.74438 .68741 m
.74596 .68695 L
s
1 .012 0 r
.13573 .33096 m
.13579 .33103 L
s
.13565 .331 m
.13573 .33096 L
s
.13573 .33096 m
.13574 .33095 L
s
1 .034 0 r
.18507 .6577 m
.18495 .65772 L
s
.18499 .65738 m
.18507 .6577 L
s
.18507 .6577 m
.18478 .65757 L
s
.18517 .65753 m
.18507 .6577 L
s
.18459 .65695 m
.18507 .6577 L
s
1 .012 0 r
.13579 .33103 m
.13571 .33107 L
s
.13574 .33095 m
.13579 .33103 L
s
.13571 .33107 m
.13565 .331 L
s
.13565 .331 m
.13574 .33095 L
s
.13574 .33095 m
.13571 .33107 L
s
1 .158 0 r
.71652 .2704 m
.71579 .27152 L
s
.71735 .27071 m
.71652 .2704 L
s
1 .034 0 r
.18499 .65738 m
.18478 .65757 L
s
.18517 .65753 m
.18499 .65738 L
s
1 .158 0 r
.71579 .27152 m
.71662 .27183 L
s
1 .034 0 r
.18478 .65757 m
.18495 .65772 L
s
1 .168 0 r
.74596 .68695 m
.74533 .6885 L
s
1 .114 0 r
.29322 .65754 m
.29283 .65763 L
s
.29291 .65646 m
.29322 .65754 L
s
.29322 .65754 m
.29222 .65715 L
s
.29351 .65694 m
.29322 .65754 L
s
.29144 .65506 m
.29322 .65754 L
s
1 .034 0 r
.18495 .65772 m
.18517 .65753 L
s
1 .398 0 r
.51547 .44955 m
.51431 .45018 L
s
.51432 .44635 m
.51547 .44955 L
s
.51728 .44729 m
.51547 .44955 L
s
1 .023 0 r
.84337 .33073 m
.84333 .33072 L
s
.84331 .3305 m
.84337 .33073 L
s
.84337 .33073 m
.84318 .33064 L
s
.84346 .33058 m
.84337 .33073 L
s
.84313 .33013 m
.84337 .33073 L
s
.84331 .3305 m
.84318 .33064 L
s
.84346 .33058 m
.84331 .3305 L
s
.84318 .33064 m
.84333 .33072 L
s
1 .066 0 r
.77943 .30089 m
.77923 .30087 L
s
.77918 .30026 m
.77943 .30089 L
s
.77943 .30089 m
.77884 .30069 L
s
.77958 .30044 m
.77943 .30089 L
s
.7783 .29926 m
.77943 .30089 L
s
1 .023 0 r
.84333 .33072 m
.84346 .33058 L
s
1 .114 0 r
.29291 .65646 m
.29222 .65715 L
s
.29351 .65694 m
.29291 .65646 L
s
1 .398 0 r
.51316 .44698 m
.51432 .44635 L
s
.51432 .44635 m
.51728 .44729 L
s
1 .066 0 r
.77918 .30026 m
.77884 .30069 L
s
.77958 .30044 m
.77918 .30026 L
s
.77884 .30069 m
.77923 .30087 L
s
1 .114 0 r
.29222 .65715 m
.29283 .65763 L
s
1 .136 0 r
.44012 .41846 m
.44078 .4194 L
s
.43941 .41882 m
.44012 .41846 L
s
.44012 .41846 m
.44073 .41852 L
s
.542 1 0 r
.45676 .68678 m
.4643 .69213 L
s
1 .136 0 r
.44078 .4194 m
.44008 .41975 L
s
.44073 .41852 m
.44078 .4194 L
s
1 .066 0 r
.77923 .30087 m
.77958 .30044 L
s
1 .606 0 r
.45298 .53812 m
.45426 .53828 L
s
.45439 .53228 m
.45298 .53812 L
s
.45298 .53812 m
.45078 .53467 L
s
.45787 .53588 m
.45298 .53812 L
s
.45975 .52381 m
.45298 .53812 L
s
1 0 0 r
.24606 .50841 m
.24606 .50841 L
s
.24606 .5084 m
.24606 .50841 L
s
.24606 .50841 m
.24606 .5084 L
s
.24606 .5084 m
.24606 .50841 L
s
.24606 .50839 m
.24606 .50841 L
s
.24606 .5084 m
.24606 .5084 L
s
.24606 .5084 m
.24606 .5084 L
s
.24606 .50841 m
.24606 .5084 L
s
.24606 .5084 m
.24606 .50841 L
s
1 .158 0 r
.71662 .27183 m
.71735 .27071 L
s
1 .022 0 r
.95727 .68666 m
.9576 .68619 L
s
1 .137 0 r
.7202 .62724 m
.72224 .62419 L
s
1 0 0 r
.78167 .47868 m
.78167 .47868 L
s
1 .046 0 r
.30752 .35984 m
.3082 .35872 L
s
1 .011 0 r
.07045 .30042 m
.07051 .30012 L
s
1 .114 0 r
.29283 .65763 m
.29351 .65694 L
s
1 .07 0 r
.3736 .38901 m
.37397 .38946 L
s
.3732 .38921 m
.3736 .38901 L
s
.3736 .38901 m
.37384 .38901 L
s
1 .787 0 r
.50895 .35978 m
.50308 .36549 L
s
.50081 .35914 m
.50895 .35978 L
s
1 .344 0 r
.5963 .39207 m
.5975 .38937 L
s
1 .07 0 r
.37397 .38946 m
.37357 .38967 L
s
.37384 .38901 m
.37397 .38946 L
s
0 1 .331 r
.43215 .65686 m
.4369 .65867 L
s
.43752 .6347 m
.43215 .65686 L
s
.43215 .65686 m
.42346 .64445 L
s
.45093 .64882 m
.43215 .65686 L
s
.45813 .6044 m
.43215 .65686 L
s
1 .011 0 r
.07051 .30013 m
.07057 .30019 L
s
.07043 .30017 m
.07051 .30013 L
s
.07051 .30013 m
.07051 .30012 L
s
.07057 .30019 m
.07049 .30023 L
s
.07051 .30012 m
.07057 .30019 L
s
1 .65 0 r
.41194 .68646 m
.40901 .68728 L
s
.40924 .68055 m
.41194 .68646 L
s
.41194 .68646 m
.40573 .6849 L
s
.41251 .68292 m
.41194 .68646 L
s
.39777 .67362 m
.41194 .68646 L
s
1 .011 0 r
.07049 .30023 m
.07043 .30017 L
s
.07043 .30017 m
.07051 .30012 L
s
1 .787 0 r
.50308 .36549 m
.50081 .35914 L
s
1 .011 0 r
.07051 .30012 m
.07049 .30023 L
s
1 .081 0 r
.78601 .65607 m
.7865 .65656 L
s
.78558 .65641 m
.78601 .65607 L
s
.78601 .65607 m
.78629 .65613 L
s
1 .07 0 r
.37357 .38967 m
.3732 .38921 L
s
.3732 .38921 m
.37384 .38901 L
s
0 1 .077 r
.44022 .61133 m
.42775 .6199 L
s
.45213 .62384 m
.44022 .61133 L
s
1 .022 0 r
.95752 .68617 m
.95766 .6863 L
s
.95741 .68627 m
.95752 .68617 L
s
.95752 .68617 m
.9576 .68619 L
s
.787 1 0 r
.44837 .57234 m
.45561 .56746 L
s
1 .07 0 r
.37384 .38901 m
.37357 .38967 L
s
1 .022 0 r
.95766 .6863 m
.95755 .6864 L
s
.9576 .68619 m
.95766 .6863 L
s
1 .136 0 r
.44008 .41975 m
.43941 .41882 L
s
.43941 .41882 m
.44073 .41852 L
s
1 .575 0 r
.52294 .27022 m
.51814 .2734 L
s
.51753 .26849 m
.52294 .27022 L
s
1 .081 0 r
.7865 .65656 m
.78607 .6569 L
s
.78629 .65613 m
.7865 .65656 L
s
1 .022 0 r
.95755 .6864 m
.95741 .68627 L
s
.95741 .68627 m
.9576 .68619 L
s
.9576 .68619 m
.95755 .6864 L
s
1 .136 0 r
.44073 .41852 m
.44008 .41975 L
s
1 .293 0 r
.39909 .27225 m
.39789 .27005 L
s
.4009 .2698 m
.39909 .27225 L
s
.39789 .27005 m
.4009 .2698 L
s
1 .081 0 r
.78607 .6569 m
.78558 .65641 L
s
.78558 .65641 m
.78629 .65613 L
s
.285 1 0 r
.44342 .60396 m
.45366 .59694 L
s
1 .575 0 r
.64929 .68174 m
.65184 .68597 L
s
.64695 .68346 m
.64929 .68174 L
s
.64929 .68174 m
.65289 .68283 L
s
1 .046 0 r
.30808 .35873 m
.30832 .35902 L
s
.3078 .35887 m
.30808 .35873 L
s
.30808 .35873 m
.3082 .35872 L
s
1 .081 0 r
.78629 .65613 m
.78607 .6569 L
s
1 .046 0 r
.30832 .35902 m
.30805 .35916 L
s
.3082 .35872 m
.30832 .35902 L
s
1 .575 0 r
.65184 .68597 m
.64951 .68769 L
s
.65289 .68283 m
.65184 .68597 L
s
1 .046 0 r
.30805 .35916 m
.3078 .35887 L
s
.3078 .35887 m
.3082 .35872 L
s
.3082 .35872 m
.30805 .35916 L
s
1 .002 0 r
.71682 .44795 m
.71682 .44795 L
s
.71682 .44793 m
.71682 .44795 L
s
.71682 .44795 m
.71681 .44794 L
s
.71683 .44794 m
.71682 .44795 L
s
.7168 .44791 m
.71682 .44795 L
s
.71682 .44793 m
.71681 .44794 L
s
.71683 .44794 m
.71682 .44793 L
s
.71681 .44794 m
.71682 .44795 L
s
.71682 .44795 m
.71683 .44794 L
s
1 .026 0 r
.89252 .65601 m
.89288 .65542 L
s
1 .303 0 r
.6553 .59655 m
.65953 .58966 L
s
1 .481 0 r
.47959 .38845 m
.49743 .38233 L
s
1 0 0 r
.18088 .47763 m
.18088 .47763 L
s
1 .033 0 r
.24238 .32899 m
.2428 .32814 L
s
1 .047 0 r
.65274 .41817 m
.65257 .41818 L
s
.65256 .41773 m
.65274 .41817 L
s
.65274 .41817 m
.65231 .41804 L
s
.65282 .41787 m
.65274 .41817 L
s
.65187 .41709 m
.65274 .41817 L
s
1 .525 0 r
.47631 .29922 m
.4724 .30303 L
s
.47087 .29878 m
.47631 .29922 L
s
1 .047 0 r
.65256 .41773 m
.65231 .41804 L
s
.65282 .41787 m
.65256 .41773 L
s
.65231 .41804 m
.65257 .41818 L
s
1 .525 0 r
.4724 .30303 m
.47087 .29878 L
s
1 .606 0 r
.45439 .53228 m
.45078 .53467 L
s
.45787 .53588 m
.45439 .53228 L
s
1 .047 0 r
.65257 .41818 m
.65282 .41787 L
s
1 .117 0 r
.45884 .50705 m
.45909 .50707 L
s
.45911 .50592 m
.45884 .50705 L
s
.45884 .50705 m
.45842 .50638 L
s
.45978 .50661 m
.45884 .50705 L
s
.46014 .50426 m
.45884 .50705 L
s
1 .65 0 r
.40924 .68055 m
.40573 .6849 L
s
.41251 .68292 m
.40924 .68055 L
s
1 .575 0 r
.51814 .2734 m
.51753 .26849 L
s
1 .026 0 r
.89279 .6554 m
.89296 .65556 L
s
.89265 .65552 m
.89279 .6554 L
s
.89279 .6554 m
.89288 .65542 L
s
.89296 .65556 m
.89282 .65567 L
s
.89288 .65542 m
.89296 .65556 L
s
1 .151 0 r
.33528 .62582 m
.33484 .62591 L
s
.33493 .62437 m
.33528 .62582 L
s
.33528 .62582 m
.33401 .62526 L
s
.33575 .62502 m
.33528 .62582 L
s
.33329 .62243 m
.33528 .62582 L
s
1 .033 0 r
.24273 .32816 m
.24291 .32836 L
s
.24252 .32826 m
.24273 .32816 L
s
.24273 .32816 m
.2428 .32814 L
s
1 .026 0 r
.89282 .65567 m
.89265 .65552 L
s
.89265 .65552 m
.89288 .65542 L
s
1 .117 0 r
.45911 .50592 m
.45842 .50638 L
s
.45978 .50661 m
.45911 .50592 L
s
1 .033 0 r
.24291 .32836 m
.2427 .32847 L
s
.2428 .32814 m
.24291 .32836 L
s
1 .026 0 r
.89288 .65542 m
.89282 .65567 L
s
1 .398 0 r
.51728 .44729 m
.51431 .45018 L
s
.51316 .44698 m
.51728 .44729 L
s
1 .033 0 r
.2427 .32847 m
.24252 .32826 L
s
.24252 .32826 m
.2428 .32814 L
s
1 .398 0 r
.51431 .45018 m
.51316 .44698 L
s
1 .033 0 r
.2428 .32814 m
.2427 .32847 L
s
1 .606 0 r
.59618 .53185 m
.59974 .53545 L
s
.59274 .53424 m
.59618 .53185 L
s
.59618 .53185 m
.59783 .53199 L
s
1 .323 0 r
.68334 .65292 m
.6851 .65507 L
s
.68173 .65409 m
.68334 .65292 L
s
.68334 .65292 m
.68483 .65327 L
s
1 .117 0 r
.45909 .50707 m
.45978 .50661 L
s
1 .151 0 r
.33493 .62437 m
.33401 .62526 L
s
.33575 .62502 m
.33493 .62437 L
s
1 .65 0 r
.40573 .6849 m
.40901 .68728 L
s
1 .003 0 r
.35297 .50641 m
.35297 .50641 L
s
.35297 .50638 m
.35297 .50641 L
s
.35297 .50641 m
.35295 .50639 L
s
.35299 .5064 m
.35297 .50641 L
s
.35297 .50633 m
.35297 .50641 L
s
.35297 .50638 m
.35295 .50639 L
s
.35299 .5064 m
.35297 .50638 L
s
.35297 .50641 m
.35299 .5064 L
s
.35295 .50639 m
.35297 .50641 L
s
1 .117 0 r
.45842 .50638 m
.45909 .50707 L
s
1 .323 0 r
.6851 .65507 m
.68349 .65624 L
s
.68483 .65327 m
.6851 .65507 L
s
1 .033 0 r
.82769 .62532 m
.82808 .62455 L
s
1 0 0 r
.88922 .47658 m
.88922 .47658 L
s
.787 1 0 r
.59033 .56582 m
.60636 .53736 L
s
1 .215 0 r
.41451 .3576 m
.42051 .35334 L
s
1 .026 0 r
.17715 .2981 m
.17744 .29742 L
s
1 0 0 r
.11562 .44684 m
.11562 .44683 L
s
.11562 .44683 m
.11562 .44684 L
s
.11562 .44684 m
.11562 .44683 L
s
.11562 .44683 m
.11562 .44683 L
s
.11562 .44684 m
.11562 .44684 L
s
.11562 .44683 m
.11562 .44684 L
s
.11562 .44684 m
.11562 .44684 L
s
.11562 .44684 m
.11562 .44683 L
s
.11562 .44683 m
.11562 .44684 L
s
1 .151 0 r
.33401 .62526 m
.33484 .62591 L
s
1 .035 0 r
.22661 .62516 m
.22651 .62517 L
s
.22654 .62482 m
.22661 .62516 L
s
.22661 .62516 m
.22632 .62502 L
s
.22673 .62498 m
.22661 .62516 L
s
.2262 .62436 m
.22661 .62516 L
s
1 .606 0 r
.45426 .53828 m
.45787 .53588 L
s
1 .137 0 r
.72179 .6241 m
.72261 .62493 L
s
.72105 .62467 m
.72179 .6241 L
s
.72179 .6241 m
.72224 .62419 L
s
1 .035 0 r
.22654 .62482 m
.22632 .62502 L
s
.22673 .62498 m
.22654 .62482 L
s
.22632 .62502 m
.22651 .62517 L
s
1 .151 0 r
.33484 .62591 m
.33575 .62502 L
s
1 .59 0 r
.5419 .35721 m
.54182 .35769 L
s
.54179 .35217 m
.5419 .35721 L
s
.54681 .35482 m
.5419 .35721 L
s
1 .035 0 r
.22651 .62517 m
.22673 .62498 L
s
1 .026 0 r
.1774 .29744 m
.17754 .2976 L
s
.17723 .29752 m
.1774 .29744 L
s
.1774 .29744 m
.17744 .29742 L
s
1 .137 0 r
.72261 .62493 m
.72187 .6255 L
s
.72224 .62419 m
.72261 .62493 L
s
1 .026 0 r
.17754 .2976 m
.17737 .29768 L
s
.17744 .29742 m
.17754 .2976 L
s
1 .215 0 r
.6357 .35709 m
.63445 .3573 L
s
.63438 .35529 m
.6357 .35709 L
s
.6357 .35709 m
.63349 .3569 L
s
.63534 .35568 m
.6357 .35709 L
s
.62926 .3531 m
.6357 .35709 L
s
1 .026 0 r
.17737 .29768 m
.17723 .29752 L
s
.17723 .29752 m
.17744 .29742 L
s
.17744 .29742 m
.17737 .29768 L
s
1 .033 0 r
.82799 .62454 m
.8282 .62473 L
s
.82781 .62469 m
.82799 .62454 L
s
.82799 .62454 m
.82808 .62455 L
s
.8282 .62473 m
.82802 .62488 L
s
.82808 .62455 m
.8282 .62473 L
s
1 .215 0 r
.63438 .35529 m
.63349 .3569 L
s
.63534 .35568 m
.63438 .35529 L
s
1 .606 0 r
.59974 .53545 m
.59631 .53785 L
s
.59783 .53199 m
.59974 .53545 L
s
1 .215 0 r
.63349 .3569 m
.63445 .3573 L
s
1 .033 0 r
.82802 .62488 m
.82781 .62469 L
s
.82781 .62469 m
.82808 .62455 L
s
1 .137 0 r
.72187 .6255 m
.72105 .62467 L
s
.72105 .62467 m
.72224 .62419 L
s
1 .344 0 r
.41846 .56513 m
.4182 .56519 L
s
.41831 .56175 m
.41846 .56513 L
s
.41846 .56513 m
.41617 .56351 L
s
.42034 .56343 m
.41846 .56513 L
s
.41744 .5568 m
.41846 .56513 L
s
1 .033 0 r
.82808 .62455 m
.82802 .62488 L
s
.787 1 0 r
.44141 .56508 m
.44837 .57234 L
s
1 .057 0 r
.82194 .26742 m
.82178 .2674 L
s
.82173 .26688 m
.82194 .26742 L
s
.82194 .26742 m
.82144 .26725 L
s
.82208 .26703 m
.82194 .26742 L
s
.82101 .266 m
.82194 .26742 L
s
1 .59 0 r
.5417 .35264 m
.54179 .35217 L
s
.54179 .35217 m
.54681 .35482 L
s
1 .137 0 r
.72224 .62419 m
.72187 .6255 L
s
1 .215 0 r
.37734 .5947 m
.37688 .59478 L
s
.37698 .59261 m
.37734 .5947 L
s
.37734 .5947 m
.37565 .59382 L
s
.3782 .59357 m
.37734 .5947 L
s
.37529 .58967 m
.37734 .5947 L
s
1 .057 0 r
.82173 .26688 m
.82144 .26725 L
s
.82208 .26703 m
.82173 .26688 L
s
.717 1 0 r
.61302 .65421 m
.60968 .65713 L
s
.60935 .64395 m
.61302 .65421 L
s
.61928 .64772 m
.61302 .65421 L
s
1 .057 0 r
.82144 .26725 m
.82178 .2674 L
s
1 .457 0 r
.57808 .32674 m
.57895 .32714 L
s
.57888 .32289 m
.57808 .32674 L
s
.58262 .32573 m
.57808 .32674 L
s
1 0 0 r
.82435 .44578 m
.82435 .44578 L
s
.82435 .44577 m
.82435 .44578 L
s
.82435 .44578 m
.82435 .44577 L
s
.82435 .44577 m
.82435 .44578 L
s
.82435 .44577 m
.82435 .44578 L
s
.82435 .44577 m
.82435 .44577 L
s
.82435 .44577 m
.82435 .44577 L
s
.82435 .44577 m
.82435 .44578 L
s
.82435 .44578 m
.82435 .44577 L
s
1 .046 0 r
.76277 .59459 m
.76321 .59352 L
s
1 0 0 r
.01 w
.52528 .53506 Mdot
.5 Mabswid
.28778 .47553 m
.28778 .47553 L
s
1 .116 0 r
.34935 .32671 m
.35193 .32409 L
s
1 .022 0 r
.11185 .26718 m
.11206 .26661 L
s
1 .323 0 r
.68349 .65624 m
.68173 .65409 L
s
.68173 .65409 m
.68483 .65327 L
s
1 .057 0 r
.82178 .2674 m
.82208 .26703 L
s
1 .457 0 r
.57976 .32328 m
.57888 .32289 L
s
.57888 .32289 m
.58262 .32573 L
s
1 .323 0 r
.68483 .65327 m
.68349 .65624 L
s
1 .022 0 r
.11203 .26662 m
.11215 .26675 L
s
.11189 .26669 m
.11203 .26662 L
s
.11203 .26662 m
.11206 .26661 L
s
.11215 .26675 m
.112 .26682 L
s
.11206 .26661 m
.11215 .26675 L
s
1 .215 0 r
.37698 .59261 m
.37565 .59382 L
s
.3782 .59357 m
.37698 .59261 L
s
1 .606 0 r
.45078 .53467 m
.45426 .53828 L
s
1 .022 0 r
.112 .26682 m
.11189 .26669 L
s
.11189 .26669 m
.11206 .26661 L
s
.11206 .26661 m
.112 .26682 L
s
1 .575 0 r
.64951 .68769 m
.64695 .68346 L
s
.64695 .68346 m
.65289 .68283 L
s
1 .344 0 r
.41831 .56175 m
.41617 .56351 L
s
.42034 .56343 m
.41831 .56175 L
s
0 1 .077 r
.43969 .63247 m
.45213 .62384 L
s
.717 1 0 r
.60599 .64683 m
.60935 .64395 L
s
.60935 .64395 m
.61928 .64772 L
s
1 .575 0 r
.65289 .68283 m
.64951 .68769 L
s
0 .813 1 r
.62139 .35577 m
.59762 .37893 L
s
.58847 .35314 m
.62139 .35577 L
s
1 .215 0 r
.63445 .3573 m
.63534 .35568 L
s
1 .046 0 r
.76311 .59351 m
.7634 .59376 L
s
.76286 .59371 m
.76311 .59351 L
s
.76311 .59351 m
.76321 .59352 L
s
1 .01 0 r
.16098 .59384 m
.16096 .59384 L
s
.16097 .59374 m
.16098 .59384 L
s
.16098 .59384 m
.1609 .59379 L
s
.16102 .59379 m
.16098 .59384 L
s
.16089 .59361 m
.16098 .59384 L
s
1 .215 0 r
.37565 .59382 m
.37688 .59478 L
s
1 .01 0 r
.16097 .59374 m
.1609 .59379 L
s
.16102 .59379 m
.16097 .59374 L
s
1 .606 0 r
.59631 .53785 m
.59274 .53424 L
s
.59274 .53424 m
.59783 .53199 L
s
1 .01 0 r
.1609 .59379 m
.16096 .59384 L
s
.16096 .59384 m
.16102 .59379 L
s
1 .046 0 r
.7634 .59376 m
.76314 .59397 L
s
.76321 .59352 m
.7634 .59376 L
s
1 .457 0 r
.58262 .32573 m
.57895 .32714 L
s
.57976 .32328 m
.58262 .32573 L
s
.56407 .32213 m
.58262 .32573 L
s
1 .006 0 r
.75945 .41507 m
.75945 .41507 L
s
.75944 .41501 m
.75945 .41507 L
s
.75945 .41507 m
.75941 .41505 L
s
.75948 .41503 m
.75945 .41507 L
s
.7594 .41491 m
.75945 .41507 L
s
.75944 .41501 m
.75941 .41505 L
s
.75948 .41503 m
.75944 .41501 L
s
.75941 .41505 m
.75945 .41507 L
s
.75945 .41507 m
.75948 .41503 L
s
1 .046 0 r
.76314 .59397 m
.76286 .59371 L
s
.76286 .59371 m
.76321 .59352 L
s
1 .481 0 r
.49527 .38517 m
.49383 .38583 L
s
.49388 .38128 m
.49527 .38517 L
s
.49743 .38233 m
.49527 .38517 L
s
.285 1 0 r
.43358 .59364 m
.44342 .60396 L
s
1 .048 0 r
.69524 .38516 m
.69508 .38516 L
s
.69505 .3847 m
.69524 .38516 L
s
.69524 .38516 m
.6948 .38502 L
s
.69533 .38484 m
.69524 .38516 L
s
.69437 .38402 m
.69524 .38516 L
s
1 .046 0 r
.76321 .59352 m
.76314 .59397 L
s
1 .011 0 r
.93543 .62339 m
.93555 .62313 L
s
1 .07 0 r
.69779 .56383 m
.69823 .56214 L
s
1 .59 0 r
.52176 .35535 m
.54681 .35482 L
s
1 0 0 r
.2225 .4447 m
.2225 .44469 L
s
1 .073 0 r
.28411 .29578 m
.28548 .29402 L
s
1 0 0 r
.2225 .44469 m
.22251 .44469 L
s
.2225 .44469 m
.2225 .44469 L
s
.2225 .44469 m
.2225 .44469 L
s
.22251 .44469 m
.2225 .44469 L
s
.2225 .44469 m
.22251 .44469 L
s
.2225 .44469 m
.2225 .44469 L
s
.2225 .44469 m
.2225 .44469 L
s
.2225 .44469 m
.2225 .44469 L
s
1 .65 0 r
.40901 .68728 m
.41251 .68292 L
s
1 .215 0 r
.37688 .59478 m
.3782 .59357 L
s
1 .048 0 r
.69505 .3847 m
.6948 .38502 L
s
.69533 .38484 m
.69505 .3847 L
s
.6948 .38502 m
.69508 .38516 L
s
1 .011 0 r
.93552 .62313 m
.93559 .62319 L
s
.93546 .62318 m
.93552 .62313 L
s
.93552 .62313 m
.93555 .62313 L
s
1 .481 0 r
.49243 .38194 m
.49388 .38128 L
s
.49388 .38128 m
.49743 .38233 L
s
1 .011 0 r
.93559 .62319 m
.93553 .62324 L
s
.93555 .62313 m
.93559 .62319 L
s
.93553 .62324 m
.93546 .62318 L
s
.93546 .62318 m
.93555 .62313 L
s
.93555 .62313 m
.93553 .62324 L
s
1 .048 0 r
.69508 .38516 m
.69533 .38484 L
s
1 .344 0 r
.41617 .56351 m
.4182 .56519 L
s
0 .813 1 r
.59762 .37893 m
.58847 .35314 L
s
1 .344 0 r
.4182 .56519 m
.42034 .56343 L
s
1 .59 0 r
.54681 .35482 m
.54182 .35769 L
s
.5417 .35264 m
.54681 .35482 L
s
1 .215 0 r
.41934 .35318 m
.42029 .35476 L
s
.41832 .35362 m
.41934 .35318 L
s
.41934 .35318 m
.42051 .35334 L
s
.42029 .35476 m
.41927 .3552 L
s
.42051 .35334 m
.42029 .35476 L
s
1 .116 0 r
.35144 .32408 m
.35201 .32488 L
s
.35081 .32436 m
.35144 .32408 L
s
.35144 .32408 m
.35193 .32409 L
s
.35201 .32488 m
.35138 .32515 L
s
.35193 .32409 m
.35201 .32488 L
s
.542 1 0 r
.4643 .69213 m
.47213 .68235 L
s
1 .606 0 r
.59783 .53199 m
.59631 .53785 L
s
0 1 .566 r
.63228 .56302 m
.62572 .5681 L
s
.62494 .54239 m
.63228 .56302 L
s
.64502 .54922 m
.63228 .56302 L
s
0 1 .331 r
.43752 .6347 m
.42346 .64445 L
s
.45093 .64882 m
.43752 .6347 L
s
1 .012 0 r
.8705 .59263 m
.87061 .59235 L
s
.542 1 0 r
.57107 .68203 m
.62656 .6663 L
s
1 .136 0 r
.63272 .53303 m
.63274 .52969 L
s
1 0 0 r
.39493 .47343 m
.39493 .47343 L
s
1 .39 0 r
.45658 .32442 m
.47099 .31929 L
s
1 .051 0 r
.2188 .26482 m
.21962 .26353 L
s
1 .001 0 r
.15715 .41382 m
.15715 .41379 L
s
.15715 .41379 m
.15716 .4138 L
s
.15715 .4138 m
.15715 .41379 L
s
.15715 .41379 m
.15715 .41379 L
s
.15716 .4138 m
.15715 .41381 L
s
.15715 .41379 m
.15716 .4138 L
s
.15715 .41381 m
.15715 .4138 L
s
.15715 .4138 m
.15715 .41379 L
s
.15715 .41379 m
.15715 .41381 L
s
1 .073 0 r
.28523 .29404 m
.2856 .29452 L
s
.2848 .29422 m
.28523 .29404 L
s
.28523 .29404 m
.28548 .29402 L
s
1 .116 0 r
.35138 .32515 m
.35081 .32436 L
s
.35081 .32436 m
.35193 .32409 L
s
1 .073 0 r
.2856 .29452 m
.28518 .29471 L
s
.28548 .29402 m
.2856 .29452 L
s
.425 1 0 r
.56122 .41372 m
.54946 .42518 L
s
.54491 .41246 m
.56122 .41372 L
s
1 .116 0 r
.35193 .32409 m
.35138 .32515 L
s
1 .035 0 r
.26826 .59247 m
.26819 .59248 L
s
.26822 .59213 m
.26826 .59247 L
s
.26826 .59247 m
.26799 .59232 L
s
.26841 .59229 m
.26826 .59247 L
s
.26796 .59164 m
.26826 .59247 L
s
1 .07 0 r
.69812 .56213 m
.69856 .5625 L
s
.69772 .56246 m
.69812 .56213 L
s
.69812 .56213 m
.69823 .56214 L
s
1 .012 0 r
.87058 .59234 m
.87066 .59241 L
s
.87052 .5924 m
.87058 .59234 L
s
.87058 .59234 m
.87061 .59235 L
s
.87066 .59241 m
.87059 .59246 L
s
.87061 .59235 m
.87066 .59241 L
s
.87059 .59246 m
.87052 .5924 L
s
.87052 .5924 m
.87061 .59235 L
s
1 .035 0 r
.26822 .59213 m
.26799 .59232 L
s
.26841 .59229 m
.26822 .59213 L
s
1 .012 0 r
.87061 .59235 m
.87059 .59246 L
s
1 .035 0 r
.26799 .59232 m
.26819 .59248 L
s
1 .07 0 r
.69856 .5625 m
.69816 .56283 L
s
.69823 .56214 m
.69856 .5625 L
s
1 .073 0 r
.28518 .29471 m
.2848 .29422 L
s
.2848 .29422 m
.28548 .29402 L
s
1 .035 0 r
.26819 .59248 m
.26841 .59229 L
s
1 .07 0 r
.69816 .56283 m
.69772 .56246 L
s
.69772 .56246 m
.69823 .56214 L
s
1 .073 0 r
.28548 .29402 m
.28518 .29471 L
s
.425 1 0 r
.54946 .42518 m
.54491 .41246 L
s
1 .07 0 r
.69823 .56214 m
.69816 .56283 L
s
1 .215 0 r
.41927 .3552 m
.41832 .35362 L
s
.41832 .35362 m
.42051 .35334 L
s
.42051 .35334 m
.41927 .3552 L
s
0 1 .566 r
.42478 .56727 m
.43306 .56219 L
s
.43306 .56219 m
.42556 .54156 L
s
.43306 .56219 m
.40633 .5603 L
s
1 .457 0 r
.57895 .32714 m
.57976 .32328 L
s
1 .051 0 r
.21948 .26355 m
.21975 .26388 L
s
.21916 .26369 m
.21948 .26355 L
s
.21948 .26355 m
.21962 .26353 L
s
.21975 .26388 m
.21943 .26402 L
s
.21962 .26353 m
.21975 .26388 L
s
1 .303 0 r
.65862 .58952 m
.66042 .59134 L
s
.65694 .59075 m
.65862 .58952 L
s
.65862 .58952 m
.65953 .58966 L
s
1 .59 0 r
.54182 .35769 m
.5417 .35264 L
s
0 1 .511 r
.42965 .68115 m
.43476 .68337 L
s
.43545 .65726 m
.42965 .68115 L
s
.42965 .68115 m
.42023 .66794 L
s
.44994 .67259 m
.42965 .68115 L
s
.45771 .62517 m
.42965 .68115 L
s
1 .051 0 r
.21943 .26402 m
.21916 .26369 L
s
.21916 .26369 m
.21962 .26353 L
s
1 .002 0 r
.86719 .41277 m
.86719 .41277 L
s
.86719 .41276 m
.86719 .41277 L
s
.86719 .41277 m
.86718 .41277 L
s
.8672 .41276 m
.86719 .41277 L
s
.86719 .41273 m
.86719 .41277 L
s
.86719 .41276 m
.86718 .41277 L
s
.8672 .41276 m
.86719 .41276 L
s
.86718 .41277 m
.86719 .41277 L
s
.86719 .41277 m
.8672 .41276 L
s
1 .012 0 r
.8055 .56182 m
.80557 .56154 L
s
1 .398 0 r
.56757 .50219 m
.55968 .49337 L
s
1 .002 0 r
.32965 .44255 m
.32966 .44251 L
s
1 .22 0 r
.39133 .29346 m
.39796 .28928 L
s
1 .002 0 r
.09172 .38291 m
.09173 .38286 L
s
1 .051 0 r
.21962 .26353 m
.21943 .26402 L
s
1 .002 0 r
.32966 .44251 m
.32967 .44252 L
s
.32965 .44252 m
.32966 .44251 L
s
.32966 .44251 m
.32966 .44251 L
s
.32967 .44252 m
.32966 .44253 L
s
.32966 .44251 m
.32967 .44252 L
s
.09173 .38286 m
.09174 .38287 L
s
.09171 .38287 m
.09173 .38286 L
s
.09173 .38286 m
.09173 .38286 L
s
.32966 .44253 m
.32965 .44252 L
s
.32965 .44252 m
.32966 .44251 L
s
.32966 .44251 m
.32966 .44253 L
s
.09174 .38287 m
.09172 .38288 L
s
.09173 .38286 m
.09174 .38287 L
s
.09172 .38288 m
.09171 .38287 L
s
.09171 .38287 m
.09173 .38286 L
s
.09173 .38286 m
.09172 .38288 L
s
1 .323 0 r
.61516 .29334 m
.61617 .29368 L
s
.61608 .29071 m
.61516 .29334 L
s
.61852 .29305 m
.61516 .29334 L
s
0 1 .566 r
.61831 .5473 m
.62494 .54239 L
s
.62494 .54239 m
.64502 .54922 L
s
1 .012 0 r
.80555 .56154 m
.80563 .5616 L
s
.80549 .56159 m
.80555 .56154 L
s
.80555 .56154 m
.80557 .56154 L
s
.80563 .5616 m
.80556 .56166 L
s
.80557 .56154 m
.80563 .5616 L
s
.80556 .56166 m
.80549 .56159 L
s
.80549 .56159 m
.80557 .56154 L
s
.80557 .56154 m
.80556 .56166 L
s
1 .323 0 r
.6171 .29105 m
.61608 .29071 L
s
.61608 .29071 m
.61852 .29305 L
s
1 .303 0 r
.66042 .59134 m
.65874 .59258 L
s
.65953 .58966 m
.66042 .59134 L
s
1 .151 0 r
.67591 .32291 m
.67513 .32299 L
s
.67506 .3216 m
.67591 .32291 L
s
.67591 .32291 m
.67439 .3227 L
s
.6758 .32189 m
.67591 .32291 L
s
.67182 .31984 m
.67591 .32291 L
s
1 .323 0 r
.61852 .29305 m
.61617 .29368 L
s
.6171 .29105 m
.61852 .29305 L
s
.60654 .28879 m
.61852 .29305 L
s
1 .151 0 r
.67506 .3216 m
.67439 .3227 L
s
.6758 .32189 m
.67506 .3216 L
s
0 1 .566 r
.59832 .38238 m
.57914 .40106 L
s
.57175 .38029 m
.59832 .38238 L
s
1 .151 0 r
.67439 .3227 m
.67513 .32299 L
s
1 .481 0 r
.49743 .38233 m
.49383 .38583 L
s
.49243 .38194 m
.49743 .38233 L
s
.49383 .38583 m
.49243 .38194 L
s
1 .59 0 r
.41854 .59089 m
.4181 .59106 L
s
.41829 .5851 m
.41854 .59089 L
s
.41854 .59089 m
.41461 .58814 L
s
.42178 .58801 m
.41854 .59089 L
s
.41679 .57674 m
.41854 .59089 L
s
1 .01 0 r
.80224 .38206 m
.80223 .38206 L
s
.80222 .38196 m
.80224 .38206 L
s
.80224 .38206 m
.80216 .38202 L
s
.80228 .382 m
.80224 .38206 L
s
.80214 .3818 m
.80224 .38206 L
s
.80222 .38196 m
.80216 .38202 L
s
.80228 .382 m
.80222 .38196 L
s
.80216 .38202 m
.80223 .38206 L
s
.80223 .38206 m
.80228 .382 L
s
1 .007 0 r
.2026 .56099 m
.20259 .56099 L
s
.2026 .56092 m
.2026 .56099 L
s
.2026 .56099 m
.20255 .56096 L
s
.20263 .56095 m
.2026 .56099 L
s
.20256 .56082 m
.2026 .56099 L
s
.2026 .56092 m
.20255 .56096 L
s
.20263 .56095 m
.2026 .56092 L
s
.20255 .56096 m
.20259 .56099 L
s
.20259 .56099 m
.20263 .56095 L
s
1 .303 0 r
.65874 .59258 m
.65694 .59075 L
s
.65694 .59075 m
.65953 .58966 L
s
0 1 .566 r
.42556 .54156 m
.41721 .54646 L
s
.42556 .54156 m
.40633 .5603 L
s
1 .417 0 r
.6787 .68017 m
.68787 .67183 L
s
1 .01 0 r
.74042 .53099 m
.74044 .53073 L
s
1 0 0 r
.50235 .47131 m
.50235 .47131 L
s
1 .004 0 r
.26428 .41164 m
.26432 .41154 L
s
1 .134 0 r
.326 .26246 m
.32935 .25952 L
s
1 .046 0 r
.73782 .35193 m
.73768 .35193 L
s
.73765 .3515 m
.73782 .35193 L
s
.73782 .35193 m
.73741 .3518 L
s
.73792 .35163 m
.73782 .35193 L
s
.73702 .35084 m
.73782 .35193 L
s
1 .004 0 r
.26431 .41154 m
.26433 .41156 L
s
.26428 .41155 m
.26431 .41154 L
s
.26431 .41154 m
.26432 .41154 L
s
0 1 .566 r
.57914 .40106 m
.57175 .38029 L
s
1 .004 0 r
.26433 .41156 m
.26431 .41158 L
s
.26432 .41154 m
.26433 .41156 L
s
.26431 .41158 m
.26428 .41155 L
s
.26428 .41155 m
.26432 .41154 L
s
.26432 .41154 m
.26431 .41158 L
s
1 .046 0 r
.73765 .3515 m
.73741 .3518 L
s
.73792 .35163 m
.73765 .3515 L
s
.73741 .3518 m
.73768 .35193 L
s
1 .01 0 r
.74043 .53073 m
.7405 .53078 L
s
.74037 .53078 m
.74043 .53073 L
s
.74043 .53073 m
.74044 .53073 L
s
.74044 .53083 m
.74037 .53078 L
s
.74037 .53078 m
.74044 .53073 L
s
.7405 .53078 m
.74044 .53083 L
s
.74044 .53073 m
.7405 .53078 L
s
1 .151 0 r
.67513 .32299 m
.6758 .32189 L
s
1 .01 0 r
.74044 .53073 m
.74044 .53083 L
s
1 .136 0 r
.63271 .52969 m
.63356 .53034 L
s
.63191 .53037 m
.63271 .52969 L
s
.63271 .52969 m
.63274 .52969 L
s
1 .046 0 r
.73768 .35193 m
.73792 .35163 L
s
1 .303 0 r
.65953 .58966 m
.65874 .59258 L
s
1 .39 0 r
.46927 .32167 m
.46807 .32213 L
s
.46814 .31851 m
.46927 .32167 L
s
.47099 .31929 m
.46927 .32167 L
s
0 1 .566 r
.40633 .5603 m
.42478 .56727 L
s
.40633 .5603 m
.41721 .54646 L
s
.50193 .53016 m
.40633 .5603 L
s
1 .39 0 r
.46693 .31896 m
.46814 .31851 L
s
.46814 .31851 m
.47099 .31929 L
s
1 .136 0 r
.63276 .53103 m
.63191 .53037 L
s
.63191 .53037 m
.63274 .52969 L
s
0 1 .077 r
.42775 .6199 m
.43969 .63247 L
s
1 .136 0 r
.63356 .53034 m
.63276 .53103 L
s
.63274 .52969 m
.63356 .53034 L
s
.425 1 0 r
.45482 .53316 m
.45975 .53022 L
s
.45975 .53022 m
.45515 .51753 L
s
.45975 .53022 m
.44334 .52904 L
s
1 .323 0 r
.61617 .29368 m
.6171 .29105 L
s
1 .136 0 r
.63274 .52969 m
.63276 .53103 L
s
1 .001 0 r
.13708 .52999 m
.13708 .52999 L
s
.13708 .52998 m
.13708 .52999 L
s
.13708 .52999 m
.13707 .52998 L
s
.13709 .52998 m
.13708 .52999 L
s
.13708 .52996 m
.13708 .52999 L
s
.13708 .52998 m
.13707 .52998 L
s
.13709 .52998 m
.13708 .52998 L
s
.13708 .52999 m
.13709 .52998 L
s
.13707 .52998 m
.13708 .52999 L
s
1 .459 0 r
.51469 .29115 m
.51419 .29144 L
s
.51421 .28722 m
.51469 .29115 L
s
.51805 .28888 m
.51469 .29115 L
s
1 .003 0 r
.91348 .55982 m
.9135 .55974 L
s
.973 1 0 r
.6135 .64938 m
.63997 .62985 L
s
1 .005 0 r
.67526 .50011 m
.67523 .49998 L
s
1 .021 0 r
.43705 .4404 m
.43753 .43996 L
s
1 .459 0 r
.49881 .29113 m
.51805 .28888 L
s
1 .006 0 r
.19884 .38069 m
.19888 .38055 L
s
0 .813 1 r
.40561 .59626 m
.41612 .58963 L
s
.41612 .58963 m
.40677 .56399 L
s
.41612 .58963 m
.38283 .58732 L
s
1 .003 0 r
.91349 .55974 m
.91351 .55975 L
s
.91347 .55975 m
.91349 .55974 L
s
.91349 .55974 m
.9135 .55974 L
s
.91351 .55975 m
.9135 .55977 L
s
.9135 .55974 m
.91351 .55975 L
s
.9135 .55977 m
.91347 .55975 L
s
.91347 .55975 m
.9135 .55974 L
s
.9135 .55974 m
.9135 .55977 L
s
1 .005 0 r
.67524 .49998 m
.67527 .5 L
s
.67521 .50001 m
.67524 .49998 L
s
.67524 .49998 m
.67523 .49998 L
s
1 .006 0 r
.19887 .38055 m
.1989 .38058 L
s
.19884 .38057 m
.19887 .38055 L
s
.19887 .38055 m
.19888 .38055 L
s
.1989 .38058 m
.19887 .3806 L
s
.19888 .38055 m
.1989 .38058 L
s
1 .005 0 r
.67524 .50003 m
.67521 .50001 L
s
.67521 .50001 m
.67523 .49998 L
s
.67527 .5 m
.67524 .50003 L
s
.67523 .49998 m
.67527 .5 L
s
1 .006 0 r
.19887 .3806 m
.19884 .38057 L
s
.19884 .38057 m
.19888 .38055 L
s
1 .005 0 r
.67523 .49998 m
.67524 .50003 L
s
1 .006 0 r
.19888 .38055 m
.19887 .3806 L
s
1 .59 0 r
.41829 .5851 m
.41461 .58814 L
s
.42178 .58801 m
.41829 .5851 L
s
1 .032 0 r
.31002 .55959 m
.30998 .55959 L
s
.31 .55927 m
.31002 .55959 L
s
.31002 .55959 m
.30979 .55944 L
s
.31018 .55943 m
.31002 .55959 L
s
.30987 .55881 m
.31002 .55959 L
s
1 .021 0 r
.43744 .43995 m
.43754 .44009 L
s
.43733 .44 m
.43744 .43995 L
s
.43744 .43995 m
.43753 .43996 L
s
.43754 .44009 m
.43743 .44015 L
s
.43753 .43996 m
.43754 .44009 L
s
1 .032 0 r
.31 .55927 m
.30979 .55944 L
s
.31018 .55943 m
.31 .55927 L
s
1 .22 0 r
.39758 .29077 m
.39659 .29113 L
s
.39667 .28911 m
.39758 .29077 L
s
.39796 .28928 m
.39758 .29077 L
s
.39568 .28946 m
.39667 .28911 L
s
.39667 .28911 m
.39796 .28928 L
s
1 .158 0 r
.29253 .67891 m
.29197 .67905 L
s
.29208 .67741 m
.29253 .67891 L
s
.29253 .67891 m
.29113 .67838 L
s
.29293 .67808 m
.29253 .67891 L
s
.29003 .67549 m
.29253 .67891 L
s
1 .021 0 r
.43743 .44015 m
.43733 .44 L
s
.43733 .44 m
.43753 .43996 L
s
1 .032 0 r
.30979 .55944 m
.30998 .55959 L
s
1 .021 0 r
.43753 .43996 m
.43743 .44015 L
s
1 .459 0 r
.5137 .28751 m
.51421 .28722 L
s
.51421 .28722 m
.51805 .28888 L
s
1 .032 0 r
.30998 .55959 m
.31018 .55943 L
s
0 1 .511 r
.58784 .69767 m
.59227 .67691 L
s
.425 1 0 r
.45515 .51753 m
.45019 .5204 L
s
.45515 .51753 m
.44334 .52904 L
s
0 1 .331 r
.4369 .65867 m
.45093 .64882 L
s
1 .134 0 r
.32872 .2595 m
.32934 .26046 L
s
.32802 .25976 m
.32872 .2595 L
s
.32872 .2595 m
.32935 .25952 L
s
1 .158 0 r
.29208 .67741 m
.29113 .67838 L
s
.29293 .67808 m
.29208 .67741 L
s
1 .134 0 r
.32934 .26046 m
.32864 .26072 L
s
.32935 .25952 m
.32934 .26046 L
s
1 .05 0 r
.18324 .67846 m
.18308 .6785 L
s
.18313 .67798 m
.18324 .67846 L
s
.18324 .67846 m
.18281 .67828 L
s
.18339 .67821 m
.18324 .67846 L
s
.18254 .67737 m
.18324 .67846 L
s
1 .417 0 r
.5551 .26029 m
.55537 .26049 L
s
.55534 .25669 m
.5551 .26029 L
s
.5589 .25881 m
.5551 .26029 L
s
.425 1 0 r
.44334 .52904 m
.45482 .53316 L
s
.44334 .52904 m
.45019 .5204 L
s
.50207 .51031 m
.44334 .52904 L
s
1 .158 0 r
.29113 .67838 m
.29197 .67905 L
s
1 .05 0 r
.18313 .67798 m
.18281 .67828 L
s
.18339 .67821 m
.18313 .67798 L
s
1 .825 0 r
.62967 .61237 m
.63382 .61816 L
s
.62579 .61499 m
.62967 .61237 L
s
.62967 .61237 m
.63405 .6134 L
s
1 .117 0 r
.54831 .43935 m
.54852 .4395 L
s
.54851 .43837 m
.54831 .43935 L
s
.54946 .43911 m
.54831 .43935 L
s
1 .115 0 r
.78659 .6783 m
.7884 .67582 L
s
1 .002 0 r
.84838 .52894 m
.84839 .52889 L
s
0 .434 1 r
.54823 .61856 m
.68572 .57781 L
s
1 0 0 r
.61002 .4692 m
.61002 .4692 L
s
1 .024 0 r
.37167 .40945 m
.37209 .4089 L
s
1 .318 0 r
.43346 .26009 m
.4452 .25575 L
s
1 .006 0 r
.13331 .34971 m
.13335 .34954 L
s
1 .05 0 r
.18281 .67828 m
.18308 .6785 L
s
1 .002 0 r
.84839 .52889 m
.8484 .5289 L
s
.84837 .5289 m
.84839 .52889 L
s
.84839 .52889 m
.84839 .52889 L
s
.84839 .52891 m
.84837 .5289 L
s
.84837 .5289 m
.84839 .52889 L
s
.8484 .5289 m
.84839 .52891 L
s
.84839 .52889 m
.8484 .5289 L
s
.84839 .52889 m
.84839 .52891 L
s
1 .117 0 r
.54872 .43852 m
.54851 .43837 L
s
.54851 .43837 m
.54946 .43911 L
s
1 .05 0 r
.18308 .6785 m
.18339 .67821 L
s
1 .006 0 r
.13335 .34954 m
.13338 .34958 L
s
.13331 .34957 m
.13335 .34954 L
s
.13335 .34954 m
.13335 .34954 L
s
.13338 .34958 m
.13334 .3496 L
s
.13335 .34954 m
.13338 .34958 L
s
.13334 .3496 m
.13331 .34957 L
s
.13331 .34957 m
.13335 .34954 L
s
.13335 .34954 m
.13334 .3496 L
s
1 .117 0 r
.54946 .43911 m
.54852 .4395 L
s
.54872 .43852 m
.54946 .43911 L
s
.54471 .43825 m
.54946 .43911 L
s
1 .417 0 r
.55561 .25689 m
.55534 .25669 L
s
.55534 .25669 m
.5589 .25881 L
s
1 .158 0 r
.29197 .67905 m
.29293 .67808 L
s
1 .134 0 r
.32864 .26072 m
.32802 .25976 L
s
.32802 .25976 m
.32935 .25952 L
s
.32935 .25952 m
.32864 .26072 L
s
1 .024 0 r
.37201 .4089 m
.37214 .40905 L
s
.37188 .40897 m
.37201 .4089 L
s
.37201 .4089 m
.37209 .4089 L
s
.37214 .40905 m
.372 .40912 L
s
.37209 .4089 m
.37214 .40905 L
s
1 .825 0 r
.63382 .61816 m
.62994 .62078 L
s
.63405 .6134 m
.63382 .61816 L
s
1 .22 0 r
.39659 .29113 m
.39568 .28946 L
s
.39796 .28928 m
.39659 .29113 L
s
.39568 .28946 m
.39796 .28928 L
s
1 .024 0 r
.372 .40912 m
.37188 .40897 L
s
.37188 .40897 m
.37209 .4089 L
s
.37209 .4089 m
.372 .40912 L
s
1 .39 0 r
.47099 .31929 m
.46807 .32213 L
s
.46693 .31896 m
.47099 .31929 L
s
1 .59 0 r
.41461 .58814 m
.4181 .59106 L
s
1 .39 0 r
.46807 .32213 m
.46693 .31896 L
s
0 .813 1 r
.40677 .56399 m
.39616 .57034 L
s
.40677 .56399 m
.38283 .58732 L
s
1 .117 0 r
.54852 .4395 m
.54872 .43852 L
s
1 .59 0 r
.4181 .59106 m
.42178 .58801 L
s
1 .013 0 r
.84518 .3489 m
.84516 .34889 L
s
.84514 .34878 m
.84518 .3489 L
s
.84518 .3489 m
.84507 .34885 L
s
.84522 .34882 m
.84518 .3489 L
s
.84504 .34857 m
.84518 .3489 L
s
.84514 .34878 m
.84507 .34885 L
s
.84522 .34882 m
.84514 .34878 L
s
.717 1 0 r
.61928 .64772 m
.60968 .65713 L
s
.60599 .64683 m
.61928 .64772 L
s
1 .013 0 r
.84507 .34885 m
.84516 .34889 L
s
1 .233 0 r
.65462 .25919 m
.65554 .25947 L
s
.65544 .25735 m
.65462 .25919 L
s
.65707 .25917 m
.65462 .25919 L
s
.65707 .25917 m
.65554 .25947 L
s
.65544 .25735 m
.65707 .25917 L
s
.65636 .25762 m
.65707 .25917 L
s
.64917 .25534 m
.65707 .25917 L
s
1 .013 0 r
.84516 .34889 m
.84522 .34882 L
s
1 .233 0 r
.65636 .25762 m
.65544 .25735 L
s
1 .22 0 r
.33506 .64761 m
.33441 .64776 L
s
.33454 .6455 m
.33506 .64761 L
s
.33506 .64761 m
.3332 .64681 L
s
.33575 .64645 m
.33506 .64761 L
s
.33213 .6427 m
.33506 .64761 L
s
1 .114 0 r
.7174 .28893 m
.71686 .28896 L
s
.7168 .28791 m
.7174 .28893 L
s
.7174 .28893 m
.71627 .28873 L
s
.71739 .28814 m
.7174 .28893 L
s
.71454 .28645 m
.7174 .28893 L
s
1 .004 0 r
.24438 .52801 m
.24438 .52801 L
s
.24438 .52797 m
.24438 .52801 L
s
.24438 .52801 m
.24436 .52799 L
s
.2444 .52799 m
.24438 .52801 L
s
.24438 .52792 m
.24438 .52801 L
s
.24438 .52797 m
.24436 .52799 L
s
.2444 .52799 m
.24438 .52797 L
s
1 .459 0 r
.51805 .28888 m
.51419 .29144 L
s
.5137 .28751 m
.51805 .28888 L
s
1 .004 0 r
.24438 .52801 m
.2444 .52799 L
s
.24436 .52799 m
.24438 .52801 L
s
1 .202 0 r
.72138 .64748 m
.72439 .64301 L
s
1 .001 0 r
.78321 .49803 m
.78321 .49801 L
s
1 .021 0 r
.30621 .37846 m
.30652 .37795 L
s
1 .007 0 r
.06771 .31868 m
.06775 .31851 L
s
1 .001 0 r
.78321 .49801 m
.78321 .49801 L
s
.78321 .49801 m
.78321 .49801 L
s
.78321 .49801 m
.78321 .49801 L
s
.78321 .49802 m
.78321 .49801 L
s
.78321 .49801 m
.78321 .49801 L
s
.78321 .49801 m
.78321 .49802 L
s
.78321 .49801 m
.78321 .49801 L
s
.78321 .49801 m
.78321 .49802 L
s
1 .336 0 r
.3776 .61757 m
.37688 .61773 L
s
.37703 .61431 m
.3776 .61757 L
s
.3776 .61757 m
.37496 .61621 L
s
.37895 .61582 m
.3776 .61757 L
s
.37438 .60978 m
.3776 .61757 L
s
1 .114 0 r
.7168 .28791 m
.71627 .28873 L
s
.71739 .28814 m
.7168 .28791 L
s
.717 1 0 r
.60968 .65713 m
.60599 .64683 L
s
1 .114 0 r
.71627 .28873 m
.71686 .28896 L
s
1 .417 0 r
.5589 .25881 m
.55537 .26049 L
s
.55561 .25689 m
.5589 .25881 L
s
.54119 .25772 m
.5589 .25881 L
s
1 .042 0 r
.78055 .31856 m
.78042 .31855 L
s
.78039 .31816 m
.78055 .31856 L
s
.78055 .31856 m
.78017 .31844 L
s
.78064 .31828 m
.78055 .31856 L
s
.77983 .31753 m
.78055 .31856 L
s
1 .007 0 r
.06774 .31851 m
.06778 .31855 L
s
.0677 .31854 m
.06774 .31851 L
s
.06774 .31851 m
.06775 .31851 L
s
.06778 .31855 m
.06773 .31857 L
s
.06775 .31851 m
.06778 .31855 L
s
.06773 .31857 m
.0677 .31854 L
s
.0677 .31854 m
.06775 .31851 L
s
.06775 .31851 m
.06773 .31857 L
s
1 .042 0 r
.78039 .31816 m
.78017 .31844 L
s
.78064 .31828 m
.78039 .31816 L
s
.78017 .31844 m
.78042 .31855 L
s
1 .021 0 r
.30647 .37795 m
.30658 .37809 L
s
.30634 .37802 m
.30647 .37795 L
s
.30647 .37795 m
.30652 .37795 L
s
1 .22 0 r
.33454 .6455 m
.3332 .64681 L
s
.33575 .64645 m
.33454 .6455 L
s
1 .021 0 r
.30658 .37809 m
.30645 .37815 L
s
.30652 .37795 m
.30658 .37809 L
s
1 .042 0 r
.78042 .31855 m
.78064 .31828 L
s
0 .813 1 r
.38283 .58732 m
.40561 .59626 L
s
.38283 .58732 m
.39616 .57034 L
s
.50179 .55026 m
.38283 .58732 L
s
1 .021 0 r
.30645 .37815 m
.30634 .37802 L
s
.30634 .37802 m
.30652 .37795 L
s
.30652 .37795 m
.30645 .37815 L
s
1 .114 0 r
.71686 .28896 m
.71739 .28814 L
s
1 .22 0 r
.3332 .64681 m
.33441 .64776 L
s
1 .459 0 r
.51419 .29144 m
.5137 .28751 L
s
1 .336 0 r
.37703 .61431 m
.37496 .61621 L
s
.37895 .61582 m
.37703 .61431 L
s
1 .115 0 r
.78799 .67572 m
.78869 .67642 L
s
.78738 .67621 m
.78799 .67572 L
s
.78799 .67572 m
.7884 .67582 L
s
1 .318 0 r
.44382 .25776 m
.44281 .25807 L
s
.44289 .25517 m
.44382 .25776 L
s
.4452 .25575 m
.44382 .25776 L
s
1 0 0 r
.1788 .49699 m
.1788 .49699 L
s
.1788 .49698 m
.1788 .49699 L
s
.1788 .49699 m
.1788 .49699 L
s
.1788 .49699 m
.1788 .49699 L
s
.1788 .49698 m
.1788 .49699 L
s
.1788 .49698 m
.1788 .49699 L
s
.1788 .49699 m
.1788 .49698 L
s
.1788 .49699 m
.1788 .49699 L
s
.1788 .49699 m
.1788 .49699 L
s
1 .039 0 r
.89473 .67643 m
.89527 .67557 L
s
1 .457 0 r
.65609 .61661 m
.66252 .60626 L
s
1 0 0 r
.71796 .46707 m
.71796 .46707 L
s
1 .199 0 r
.47931 .40726 m
.48673 .40474 L
s
1 .018 0 r
.24067 .34744 m
.24091 .34698 L
s
1 .233 0 r
.65554 .25947 m
.65636 .25762 L
s
1 .115 0 r
.78869 .67642 m
.78808 .67691 L
s
.7884 .67582 m
.78869 .67642 L
s
1 .22 0 r
.33441 .64776 m
.33575 .64645 L
s
1 .825 0 r
.41859 .61651 m
.41797 .61685 L
s
.41824 .60842 m
.41859 .61651 L
s
.41859 .61651 m
.41307 .61272 L
s
.42313 .61254 m
.41859 .61651 L
s
.41613 .59693 m
.41859 .61651 L
s
1 .136 0 r
.59047 .40713 m
.59097 .40736 L
s
.59094 .40606 m
.59047 .40713 L
s
.59189 .40712 m
.59047 .40713 L
s
1 .318 0 r
.44188 .25547 m
.44289 .25517 L
s
.44289 .25517 m
.4452 .25575 L
s
1 .136 0 r
.59189 .40712 m
.59097 .40736 L
s
.59094 .40606 m
.59189 .40712 L
s
.59144 .40629 m
.59189 .40712 L
s
.58722 .40506 m
.59189 .40712 L
s
.59144 .40629 m
.59094 .40606 L
s
0 1 .511 r
.43545 .65726 m
.42023 .66794 L
s
.44994 .67259 m
.43545 .65726 L
s
1 .115 0 r
.78808 .67691 m
.78738 .67621 L
s
.78738 .67621 m
.7884 .67582 L
s
1 .018 0 r
.24087 .34698 m
.24097 .3471 L
s
.24075 .34704 m
.24087 .34698 L
s
.24087 .34698 m
.24091 .34698 L
s
.24097 .3471 m
.24085 .34716 L
s
.24091 .34698 m
.24097 .3471 L
s
1 .417 0 r
.55537 .26049 m
.55561 .25689 L
s
1 .018 0 r
.24085 .34716 m
.24075 .34704 L
s
.24075 .34704 m
.24091 .34698 L
s
.24091 .34698 m
.24085 .34716 L
s
1 .115 0 r
.7884 .67582 m
.78808 .67691 L
s
1 .336 0 r
.37496 .61621 m
.37688 .61773 L
s
1 .024 0 r
.3519 .52644 m
.3519 .52645 L
s
.35191 .52621 m
.3519 .52644 L
s
.3519 .52644 m
.35176 .52632 L
s
.35205 .52634 m
.3519 .52644 L
s
.35193 .52586 m
.3519 .52644 L
s
.35191 .52621 m
.35176 .52632 L
s
.35205 .52634 m
.35191 .52621 L
s
.3519 .52645 m
.35205 .52634 L
s
.35176 .52632 m
.3519 .52645 L
s
1 .039 0 r
.89514 .67554 m
.89539 .67576 L
s
.89493 .67571 m
.89514 .67554 L
s
.89514 .67554 m
.89527 .67557 L
s
1 .055 0 r
.22505 .64587 m
.22489 .6459 L
s
.22494 .64533 m
.22505 .64587 L
s
.22505 .64587 m
.22459 .64565 L
s
.22525 .64559 m
.22505 .64587 L
s
.2244 .64461 m
.22505 .64587 L
s
1 .039 0 r
.89539 .67576 m
.89518 .67594 L
s
.89527 .67557 m
.89539 .67576 L
s
1 .398 0 r
.56124 .49318 m
.56342 .49446 L
s
.55912 .49582 m
.56124 .49318 L
s
.56124 .49318 m
.55968 .49337 L
s
1 .039 0 r
.89518 .67594 m
.89493 .67571 L
s
.89493 .67571 m
.89527 .67557 L
s
1 .055 0 r
.22494 .64533 m
.22459 .64565 L
s
.22525 .64559 m
.22494 .64533 L
s
1 .336 0 r
.37688 .61773 m
.37895 .61582 L
s
1 .039 0 r
.89527 .67557 m
.89518 .67594 L
s
1 .136 0 r
.59097 .40736 m
.59144 .40629 L
s
1 .007 0 r
.65275 .43624 m
.65273 .43624 L
s
.65273 .43617 m
.65275 .43624 L
s
.65275 .43624 m
.65269 .43622 L
s
.65276 .43619 m
.65275 .43624 L
s
.65263 .43608 m
.65275 .43624 L
s
.65273 .43617 m
.65269 .43622 L
s
.65276 .43619 m
.65273 .43617 L
s
.65269 .43622 m
.65273 .43624 L
s
.65273 .43624 m
.65276 .43619 L
s
1 .055 0 r
.22459 .64565 m
.22489 .6459 L
s
.22489 .6459 m
.22525 .64559 L
s
1 .053 0 r
.82951 .64557 m
.83014 .64436 L
s
1 0 0 r
.89142 .49594 m
.89142 .49593 L
s
.285 1 0 r
.59072 .58572 m
.61368 .54544 L
s
1 .111 0 r
.41384 .37623 m
.41695 .37405 L
s
1 .016 0 r
.17505 .31638 m
.17523 .31596 L
s
1 0 0 r
.11315 .46601 m
.11315 .46601 L
s
.89142 .49593 m
.89142 .49593 L
s
.89142 .49593 m
.89142 .49593 L
s
.89142 .49593 m
.89142 .49593 L
s
.89142 .49593 m
.89142 .49593 L
s
.89142 .49593 m
.89142 .49593 L
s
.89142 .49593 m
.89142 .49593 L
s
.89142 .49593 m
.89142 .49593 L
s
.89142 .49593 m
.89142 .49593 L
s
1 .398 0 r
.56129 .4971 m
.55912 .49582 L
s
.55912 .49582 m
.55968 .49337 L
s
.49027 .4965 m
.49148 .4958 L
s
.49148 .4958 m
.49031 .49258 L
s
.49148 .4958 m
.48732 .4955 L
s
1 .199 0 r
.48584 .40591 m
.48523 .4062 L
s
.48526 .40429 m
.48584 .40591 L
s
.48673 .40474 m
.48584 .40591 L
s
1 .016 0 r
.17521 .31597 m
.17529 .31607 L
s
.1751 .31602 m
.17521 .31597 L
s
.17521 .31597 m
.17523 .31596 L
s
.17529 .31607 m
.17519 .31612 L
s
.17523 .31596 m
.17529 .31607 L
s
.17519 .31612 m
.1751 .31602 L
s
.1751 .31602 m
.17523 .31596 L
s
1 .199 0 r
.48465 .40458 m
.48526 .40429 L
s
.48526 .40429 m
.48673 .40474 L
s
1 .016 0 r
.17523 .31596 m
.17519 .31612 L
s
1 .398 0 r
.49031 .49258 m
.48911 .49327 L
s
.49031 .49258 m
.48732 .4955 L
s
.48732 .4955 m
.49027 .4965 L
s
.48732 .4955 m
.48911 .49327 L
s
.50221 .49069 m
.48732 .4955 L
s
1 .318 0 r
.4452 .25575 m
.44281 .25807 L
s
.44188 .25547 m
.4452 .25575 L
s
1 .825 0 r
.62994 .62078 m
.62579 .61499 L
s
.62579 .61499 m
.63405 .6134 L
s
1 .318 0 r
.44281 .25807 m
.44188 .25547 L
s
1 .053 0 r
.82999 .64433 m
.83033 .64463 L
s
.8297 .64457 m
.82999 .64433 L
s
.82999 .64433 m
.83014 .64436 L
s
.83033 .64463 m
.83004 .64488 L
s
.83014 .64436 m
.83033 .64463 L
s
1 .001 0 r
.28634 .49491 m
.28634 .49491 L
s
.28634 .4949 m
.28634 .49491 L
s
.28634 .49491 m
.28634 .49491 L
s
.28635 .49491 m
.28634 .49491 L
s
.28634 .49489 m
.28634 .49491 L
s
.28634 .4949 m
.28634 .49491 L
s
.28635 .49491 m
.28634 .4949 L
s
.28634 .49491 m
.28635 .49491 L
s
.28634 .49491 m
.28634 .49491 L
s
1 .08 0 r
.76421 .61467 m
.76498 .61281 L
s
1 0 0 r
.82615 .46495 m
.82615 .46495 L
s
.01 w
.52528 .55478 Mdot
1 .068 0 r
.5 Mabswid
.34829 .34517 m
.34981 .34364 L
s
1 .014 0 r
.10936 .28528 m
.10949 .2849 L
s
1 .825 0 r
.41824 .60842 m
.41307 .61272 L
s
.42313 .61254 m
.41824 .60842 L
s
1 .344 0 r
.53356 .37508 m
.5335 .37538 L
s
.5335 .37212 m
.53356 .37508 L
s
.53644 .37369 m
.53356 .37508 L
s
1 .053 0 r
.83004 .64488 m
.8297 .64457 L
s
.8297 .64457 m
.83014 .64436 L
s
1 .417 0 r
.68593 .67133 m
.68822 .67413 L
s
.68384 .67287 m
.68593 .67133 L
s
.68593 .67133 m
.68787 .67183 L
s
1 .825 0 r
.63405 .6134 m
.62994 .62078 L
s
1 .053 0 r
.83014 .64436 m
.83004 .64488 L
s
0 1 .331 r
.42346 .64445 m
.4369 .65867 L
s
1 .039 0 r
.82344 .28508 m
.82333 .28506 L
s
.82329 .2847 m
.82344 .28508 L
s
.82344 .28508 m
.82309 .28496 L
s
.82353 .28481 m
.82344 .28508 L
s
.82279 .28411 m
.82344 .28508 L
s
1 .014 0 r
.10948 .28491 m
.10955 .285 L
s
.10938 .28496 m
.10948 .28491 L
s
.10948 .28491 m
.10949 .2849 L
s
1 .202 0 r
.72373 .64287 m
.72494 .6441 L
s
.72263 .64372 m
.72373 .64287 L
s
.72373 .64287 m
.72439 .64301 L
s
1 .014 0 r
.10955 .285 m
.10946 .28504 L
s
.10949 .2849 m
.10955 .285 L
s
1 .039 0 r
.82329 .2847 m
.82309 .28496 L
s
.82353 .28481 m
.82329 .2847 L
s
1 .091 0 r
.75955 .25501 m
.75915 .25501 L
s
.75909 .25419 m
.75955 .25501 L
s
.75955 .25501 m
.75866 .25483 L
s
.75959 .25437 m
.75955 .25501 L
s
.75741 .25295 m
.75955 .25501 L
s
1 .014 0 r
.10946 .28504 m
.10938 .28496 L
s
.10938 .28496 m
.10949 .2849 L
s
1 .039 0 r
.82309 .28496 m
.82333 .28506 L
s
1 .111 0 r
.41634 .37396 m
.41684 .37478 L
s
.41582 .37419 m
.41634 .37396 L
s
.41634 .37396 m
.41695 .37405 L
s
1 .199 0 r
.48673 .40474 m
.48523 .4062 L
s
.48465 .40458 m
.48673 .40474 L
s
1 .014 0 r
.10949 .2849 m
.10946 .28504 L
s
1 .111 0 r
.41684 .37478 m
.41631 .37501 L
s
.41695 .37405 m
.41684 .37478 L
s
1 .199 0 r
.48523 .4062 m
.48465 .40458 L
s
1 .344 0 r
.53344 .37242 m
.5335 .37212 L
s
.5335 .37212 m
.53644 .37369 L
s
1 .091 0 r
.75909 .25419 m
.75866 .25483 L
s
.75959 .25437 m
.75909 .25419 L
s
1 .039 0 r
.82333 .28506 m
.82353 .28481 L
s
1 .398 0 r
.56342 .49446 m
.56129 .4971 L
s
.55968 .49337 m
.56342 .49446 L
s
0 .434 1 r
.39357 .622 m
.40551 .61426 L
s
.40551 .61426 m
.395 .5855 L
s
.40551 .61426 m
.36812 .61171 L
s
1 .091 0 r
.75866 .25483 m
.75915 .25501 L
s
1 .417 0 r
.68822 .67413 m
.68613 .67567 L
s
.68787 .67183 m
.68822 .67413 L
s
1 .202 0 r
.72494 .6441 m
.72385 .64495 L
s
.72439 .64301 m
.72494 .6441 L
s
1 .018 0 r
.15886 .61411 m
.15881 .61412 L
s
.15883 .61393 m
.15886 .61411 L
s
.15886 .61411 m
.15872 .61403 L
s
.15893 .61402 m
.15886 .61411 L
s
.15869 .61369 m
.15886 .61411 L
s
.15883 .61393 m
.15872 .61403 L
s
.15893 .61402 m
.15883 .61393 L
s
.15872 .61403 m
.15881 .61412 L
s
.15881 .61412 m
.15893 .61402 L
s
1 .398 0 r
.55968 .49337 m
.56129 .4971 L
s
1 .091 0 r
.75915 .25501 m
.75959 .25437 L
s
1 .111 0 r
.41631 .37501 m
.41582 .37419 L
s
.41582 .37419 m
.41695 .37405 L
s
.41695 .37405 m
.41631 .37501 L
s
1 .068 0 r
.34952 .34363 m
.34986 .3441 L
s
.34915 .3438 m
.34952 .34363 L
s
.34952 .34363 m
.34981 .34364 L
s
1 .202 0 r
.72385 .64495 m
.72263 .64372 L
s
.72263 .64372 m
.72439 .64301 L
s
1 .068 0 r
.34986 .3441 m
.34948 .34427 L
s
.34981 .34364 m
.34986 .3441 L
s
1 .001 0 r
.76082 .43394 m
.76082 .43394 L
s
.76082 .43393 m
.76082 .43394 L
s
.76082 .43394 m
.76081 .43394 L
s
.76082 .43393 m
.76082 .43394 L
s
.76081 .43392 m
.76082 .43394 L
s
.542 1 0 r
.61937 .67363 m
.61557 .67707 L
s
.61517 .66191 m
.61937 .67363 L
s
.62656 .6663 m
.61937 .67363 L
s
1 .001 0 r
.76082 .43393 m
.76081 .43394 L
s
.76082 .43393 m
.76082 .43393 L
s
.76081 .43394 m
.76082 .43394 L
s
.76082 .43394 m
.76082 .43393 L
s
1 .018 0 r
.9379 .64365 m
.93811 .64323 L
s
1 .141 0 r
.69883 .58373 m
.69974 .58036 L
s
1 .344 0 r
.52173 .37399 m
.53644 .37369 L
s
1 0 0 r
.22067 .46388 m
.22067 .46388 L
s
1 .047 0 r
.28266 .31407 m
.28353 .31295 L
s
1 .111 0 r
.63323 .3738 m
.63258 .37392 L
s
.63254 .37287 m
.63323 .3738 L
s
.63323 .3738 m
.63208 .3737 L
s
.63304 .37308 m
.63323 .3738 L
s
.62989 .37175 m
.63323 .3738 L
s
1 .068 0 r
.34948 .34427 m
.34915 .3438 L
s
.34915 .3438 m
.34981 .34364 L
s
.34981 .34364 m
.34948 .34427 L
s
1 .202 0 r
.72439 .64301 m
.72385 .64495 L
s
1 .111 0 r
.63254 .37287 m
.63208 .3737 L
s
.63304 .37308 m
.63254 .37287 L
s
.63208 .3737 m
.63258 .37392 L
s
1 .344 0 r
.53644 .37369 m
.5335 .37538 L
s
.53344 .37242 m
.53644 .37369 L
s
1 .018 0 r
.93806 .64322 m
.93818 .64332 L
s
.93796 .64331 m
.93806 .64322 L
s
.93806 .64322 m
.93811 .64323 L
s
1 .08 0 r
.7648 .61278 m
.7653 .61322 L
s
.76435 .61314 m
.7648 .61278 L
s
.7648 .61278 m
.76498 .61281 L
s
1 .303 0 r
.57365 .34365 m
.57423 .34393 L
s
.57418 .34109 m
.57365 .34365 L
s
.57668 .34299 m
.57365 .34365 L
s
1 .398 0 r
.48911 .49327 m
.49027 .4965 L
s
1 .018 0 r
.93818 .64332 m
.93808 .64341 L
s
.93811 .64323 m
.93818 .64332 L
s
.93808 .64341 m
.93796 .64331 L
s
.93796 .64331 m
.93811 .64323 L
s
.93811 .64323 m
.93808 .64341 L
s
1 .08 0 r
.7653 .61322 m
.76486 .61359 L
s
.76498 .61281 m
.7653 .61322 L
s
1 .062 0 r
.26694 .61318 m
.26681 .61321 L
s
.26686 .61258 m
.26694 .61318 L
s
.26694 .61318 m
.26647 .61292 L
s
.26721 .61287 m
.26694 .61318 L
s
.26641 .61174 m
.26694 .61318 L
s
1 .08 0 r
.76486 .61359 m
.76435 .61314 L
s
.76435 .61314 m
.76498 .61281 L
s
1 .303 0 r
.57476 .34137 m
.57418 .34109 L
s
.57418 .34109 m
.57668 .34299 L
s
1 .047 0 r
.28337 .31295 m
.28361 .31326 L
s
.2831 .31307 m
.28337 .31295 L
s
.28337 .31295 m
.28353 .31295 L
s
1 .062 0 r
.26686 .61258 m
.26647 .61292 L
s
.26721 .61287 m
.26686 .61258 L
s
1 .016 0 r
.69568 .40322 m
.69562 .40323 L
s
.69562 .40307 m
.69568 .40322 L
s
.69568 .40322 m
.69553 .40318 L
s
.69571 .40312 m
.69568 .40322 L
s
.69539 .40285 m
.69568 .40322 L
s
.69562 .40307 m
.69553 .40318 L
s
.69571 .40312 m
.69562 .40307 L
s
1 .047 0 r
.28361 .31326 m
.28334 .31339 L
s
.28353 .31295 m
.28361 .31326 L
s
1 .016 0 r
.69553 .40318 m
.69562 .40323 L
s
.542 1 0 r
.61135 .66529 m
.61517 .66191 L
s
.61517 .66191 m
.62656 .6663 L
s
1 .08 0 r
.76498 .61281 m
.76486 .61359 L
s
1 .016 0 r
.69562 .40323 m
.69571 .40312 L
s
1 .062 0 r
.26647 .61292 m
.26681 .61321 L
s
1 .417 0 r
.68613 .67567 m
.68384 .67287 L
s
.68384 .67287 m
.68787 .67183 L
s
1 .008 0 r
.39406 .493 m
.39408 .493 L
s
.39408 .49291 m
.39406 .493 L
s
.39406 .493 m
.39403 .49295 L
s
.39413 .49296 m
.39406 .493 L
s
.39415 .49279 m
.39406 .493 L
s
1 .111 0 r
.63258 .37392 m
.63304 .37308 L
s
1 .008 0 r
.39408 .49291 m
.39403 .49295 L
s
.39413 .49296 m
.39408 .49291 L
s
.39408 .493 m
.39413 .49296 L
s
1 .062 0 r
.26681 .61321 m
.26721 .61287 L
s
1 .008 0 r
.39403 .49295 m
.39408 .493 L
s
1 .047 0 r
.28334 .31339 m
.2831 .31307 L
s
.2831 .31307 m
.28353 .31295 L
s
.28353 .31295 m
.28334 .31339 L
s
1 .303 0 r
.57668 .34299 m
.57423 .34393 L
s
.57476 .34137 m
.57668 .34299 L
s
.56431 .34061 m
.57668 .34299 L
s
1 .825 0 r
.41307 .61272 m
.41797 .61685 L
s
1 .022 0 r
.87259 .61272 m
.87278 .61221 L
s
1 .344 0 r
.63337 .55275 m
.63343 .5443 L
s
1 .253 0 r
.45617 .34289 m
.46559 .33957 L
s
1 .035 0 r
.21695 .28293 m
.21751 .28205 L
s
1 0 0 r
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
.15493 .43283 m
.15493 .43283 L
s
1 .344 0 r
.5335 .37538 m
.53344 .37242 L
s
0 1 .511 r
.43476 .68337 m
.44994 .67259 L
s
1 .417 0 r
.68787 .67183 m
.68613 .67567 L
s
1 .825 0 r
.41797 .61685 m
.42313 .61254 L
s
0 .434 1 r
.395 .5855 m
.38293 .59291 L
s
.395 .5855 m
.36812 .61171 L
s
1 .022 0 r
.87273 .6122 m
.87288 .61231 L
s
.87261 .6123 m
.87273 .6122 L
s
.87273 .6122 m
.87278 .61221 L
s
.87288 .61231 m
.87276 .61242 L
s
.87278 .61221 m
.87288 .61231 L
s
.87276 .61242 m
.87261 .6123 L
s
.87261 .6123 m
.87278 .61221 L
s
.87278 .61221 m
.87276 .61242 L
s
1 .035 0 r
.21741 .28207 m
.21759 .28229 L
s
.2172 .28216 m
.21741 .28207 L
s
.21741 .28207 m
.21751 .28205 L
s
.21759 .28229 m
.21738 .28239 L
s
.21751 .28205 m
.21759 .28229 L
s
.21738 .28239 m
.2172 .28216 L
s
.2172 .28216 m
.21751 .28205 L
s
.21751 .28205 m
.21738 .28239 L
s
1 0 0 r
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
.86925 .43175 m
.86925 .43175 L
s
1 .026 0 r
.8072 .58174 m
.80735 .58111 L
s
.425 1 0 r
.56783 .52174 m
.53596 .48653 L
s
1 0 0 r
.32846 .46175 m
.32846 .46175 L
s
1 .151 0 r
.39052 .31175 m
.39508 .3089 L
s
1 .001 0 r
.0891 .40175 m
.0891 .40173 L
s
1 .028 0 r
.15116 .25176 m
.15154 .25104 L
s
1 .001 0 r
.0891 .40173 m
.0891 .40174 L
s
.0891 .40173 m
.0891 .40173 L
s
.0891 .40173 m
.0891 .40173 L
s
.0891 .40174 m
.0891 .40174 L
s
.0891 .40173 m
.0891 .40174 L
s
.0891 .40174 m
.0891 .40173 L
s
.0891 .40173 m
.0891 .40173 L
s
.0891 .40173 m
.0891 .40174 L
s
0 .434 1 r
.36812 .61171 m
.39357 .622 L
s
.36812 .61171 m
.38293 .59291 L
s
.50164 .57061 m
.36812 .61171 L
s
1 .303 0 r
.57423 .34393 m
.57476 .34137 L
s
.973 1 0 r
.41854 .6415 m
.41776 .64204 L
s
.4181 .63145 m
.41854 .6415 L
s
.41854 .6415 m
.41165 .63685 L
s
.42422 .63662 m
.41854 .6415 L
s
.41546 .61737 m
.41854 .6415 L
s
1 .141 0 r
.69952 .58032 m
.70041 .58108 L
s
.6987 .58099 m
.69952 .58032 L
s
.69952 .58032 m
.69974 .58036 L
s
1 .028 0 r
.15148 .25105 m
.15163 .25123 L
s
.1513 .25113 m
.15148 .25105 L
s
.15148 .25105 m
.15154 .25104 L
s
1 .026 0 r
.80731 .58111 m
.80748 .58124 L
s
.80716 .58123 m
.80731 .58111 L
s
.80731 .58111 m
.80735 .58111 L
s
1 .028 0 r
.15163 .25123 m
.15145 .25131 L
s
.15154 .25104 m
.15163 .25123 L
s
1 .026 0 r
.80748 .58124 m
.80733 .58137 L
s
.80735 .58111 m
.80748 .58124 L
s
.425 1 0 r
.45019 .5204 m
.45482 .53316 L
s
1 .026 0 r
.80733 .58137 m
.80716 .58123 L
s
.80716 .58123 m
.80735 .58111 L
s
1 .028 0 r
.15145 .25131 m
.1513 .25113 L
s
.1513 .25113 m
.15154 .25104 L
s
.15154 .25104 m
.15145 .25131 L
s
1 .253 0 r
.46447 .34111 m
.46368 .34142 L
s
.46373 .33904 m
.46447 .34111 L
s
.46559 .33957 m
.46447 .34111 L
s
1 .026 0 r
.80735 .58111 m
.80733 .58137 L
s
1 .015 0 r
.2007 .58111 m
.20067 .58112 L
s
.20069 .58096 m
.2007 .58111 L
s
.2007 .58111 m
.20059 .58104 L
s
.20078 .58104 m
.2007 .58111 L
s
.20061 .58074 m
.2007 .58111 L
s
.20069 .58096 m
.20059 .58104 L
s
.20078 .58104 m
.20069 .58096 L
s
1 .141 0 r
.70041 .58108 m
.69959 .58175 L
s
.69974 .58036 m
.70041 .58108 L
s
1 .253 0 r
.46293 .33935 m
.46373 .33904 L
s
.46373 .33904 m
.46559 .33957 L
s
1 .015 0 r
.20059 .58104 m
.20067 .58112 L
s
.20067 .58112 m
.20078 .58104 L
s
1 .141 0 r
.69959 .58175 m
.6987 .58099 L
s
.6987 .58099 m
.69974 .58036 L
s
1 .003 0 r
.80385 .40072 m
.80384 .40072 L
s
.80384 .40069 m
.80385 .40072 L
s
.80385 .40072 m
.80382 .40071 L
s
.80386 .4007 m
.80385 .40072 L
s
.80382 .40064 m
.80385 .40072 L
s
.80384 .40069 m
.80382 .40071 L
s
.80386 .4007 m
.80384 .40069 L
s
.80382 .40071 m
.80384 .40072 L
s
.80384 .40072 m
.80386 .4007 L
s
1 .032 0 r
.74172 .55073 m
.74178 .54994 L
s
1 .001 0 r
.2627 .43066 m
.26271 .43065 L
s
1 .095 0 r
.3248 .28058 m
.32719 .27849 L
s
1 .001 0 r
.26271 .43065 m
.26271 .43065 L
s
.2627 .43065 m
.26271 .43065 L
s
.26271 .43065 m
.26271 .43065 L
s
.26271 .43065 m
.26271 .43065 L
s
.26271 .43065 m
.26271 .43065 L
s
.26271 .43065 m
.2627 .43065 L
s
.2627 .43065 m
.26271 .43065 L
s
.26271 .43065 m
.26271 .43065 L
s
1 .141 0 r
.69974 .58036 m
.69959 .58175 L
s
1 .459 0 r
.37788 .64069 m
.3769 .64096 L
s
.37711 .63622 m
.37788 .64069 L
s
.37788 .64069 m
.37426 .63885 L
s
.37975 .63832 m
.37788 .64069 L
s
.37346 .63013 m
.37788 .64069 L
s
1 .229 0 r
.61317 .31031 m
.61389 .31057 L
s
.61382 .30844 m
.61317 .31031 L
s
.61556 .3101 m
.61317 .31031 L
s
.61455 .30869 m
.61382 .30844 L
s
.61382 .30844 m
.61556 .3101 L
s
1 .068 0 r
.30888 .58038 m
.30879 .58039 L
s
.30884 .57971 m
.30888 .58038 L
s
.30888 .58038 m
.3084 .58006 L
s
.30923 .58004 m
.30888 .58038 L
s
.30857 .57874 m
.30888 .58038 L
s
1 .09 0 r
.67516 .34015 m
.67469 .34021 L
s
.67465 .33936 m
.67516 .34015 L
s
.67516 .34015 m
.67425 .34002 L
s
.6751 .33954 m
.67516 .34015 L
s
.67271 .33832 m
.67516 .34015 L
s
1 .229 0 r
.61556 .3101 m
.61389 .31057 L
s
.61455 .30869 m
.61556 .3101 L
s
.60704 .3071 m
.61556 .3101 L
s
1 .09 0 r
.67465 .33936 m
.67425 .34002 L
s
.6751 .33954 m
.67465 .33936 L
s
.67425 .34002 m
.67469 .34021 L
s
1 .068 0 r
.30884 .57971 m
.3084 .58006 L
s
.30923 .58004 m
.30884 .57971 L
s
1 .032 0 r
.74176 .54994 m
.74196 .55009 L
s
.74157 .5501 m
.74176 .54994 L
s
.74176 .54994 m
.74178 .54994 L
s
1 .021 0 r
.73868 .37 m
.73861 .37 L
s
.73859 .3698 m
.73868 .37 L
s
.73868 .37 m
.73848 .36994 L
s
.73872 .36986 m
.73868 .37 L
s
.7383 .3695 m
.73868 .37 L
s
1 .151 0 r
.39482 .30992 m
.39414 .31017 L
s
.3942 .30877 m
.39482 .30992 L
s
.39508 .3089 m
.39482 .30992 L
s
.39351 .30903 m
.3942 .30877 L
s
.3942 .30877 m
.39508 .3089 L
s
1 .021 0 r
.73859 .3698 m
.73848 .36994 L
s
.73872 .36986 m
.73859 .3698 L
s
.73848 .36994 m
.73861 .37 L
s
1 .032 0 r
.74178 .55026 m
.74157 .5501 L
s
.74157 .5501 m
.74178 .54994 L
s
.74196 .55009 m
.74178 .55026 L
s
.74178 .54994 m
.74196 .55009 L
s
1 .021 0 r
.73861 .37 m
.73872 .36986 L
s
1 .068 0 r
.3084 .58006 m
.30879 .58039 L
s
1 .032 0 r
.74178 .54994 m
.74178 .55026 L
s
1 .068 0 r
.30879 .58039 m
.30923 .58004 L
s
1 .253 0 r
.46559 .33957 m
.46368 .34142 L
s
.46293 .33935 m
.46559 .33957 L
s
1 .003 0 r
.13474 .54979 m
.13474 .54979 L
s
.13474 .54976 m
.13474 .54979 L
s
.13474 .54979 m
.13472 .54978 L
s
.13476 .54978 m
.13474 .54979 L
s
.13473 .54971 m
.13474 .54979 L
s
.13474 .54976 m
.13472 .54978 L
s
.13476 .54978 m
.13474 .54976 L
s
1 .09 0 r
.67469 .34021 m
.6751 .33954 L
s
1 .003 0 r
.13474 .54979 m
.13476 .54978 L
s
.13472 .54978 m
.13474 .54979 L
s
1 .253 0 r
.46368 .34142 m
.46293 .33935 L
s
1 .336 0 r
.51034 .30945 m
.50997 .30968 L
s
.50998 .30656 m
.51034 .30945 L
s
.51281 .30779 m
.51034 .30945 L
s
1 .008 0 r
.91583 .57974 m
.91588 .57956 L
s
.808 1 0 r
.61404 .66985 m
.64502 .64728 L
s
1 .039 0 r
.67617 .51967 m
.67597 .51872 L
s
1 0 0 r
.43651 .4596 m
.43651 .4596 L
s
1 .336 0 r
.49865 .30943 m
.51281 .30779 L
s
1 .002 0 r
.19686 .39954 m
.19687 .39949 L
s
1 .066 0 r
.25899 .24936 m
.2604 .2478 L
s
1 .002 0 r
.19687 .39949 m
.19688 .3995 L
s
.19686 .3995 m
.19687 .39949 L
s
.19687 .39949 m
.19687 .39949 L
s
.19688 .3995 m
.19687 .39951 L
s
.19687 .39949 m
.19688 .3995 L
s
.19687 .39951 m
.19686 .3995 L
s
.19686 .3995 m
.19687 .39949 L
s
.19687 .39949 m
.19687 .39951 L
s
1 .459 0 r
.37711 .63622 m
.37426 .63885 L
s
.37975 .63832 m
.37711 .63622 L
s
1 .008 0 r
.91586 .57956 m
.91591 .5796 L
s
.91582 .5796 m
.91586 .57956 L
s
.91586 .57956 m
.91588 .57956 L
s
.91591 .5796 m
.91587 .57963 L
s
.91588 .57956 m
.91591 .5796 L
s
.91587 .57963 m
.91582 .5796 L
s
.91582 .5796 m
.91588 .57956 L
s
1 .293 0 r
.33488 .6697 m
.33401 .66993 L
s
.33418 .66688 m
.33488 .6697 L
s
.33488 .6697 m
.33239 .66864 L
s
.3358 .66817 m
.33488 .6697 L
s
.33095 .66321 m
.33488 .6697 L
s
1 .008 0 r
.91588 .57956 m
.91587 .57963 L
s
1 .095 0 r
.32674 .27847 m
.32719 .27915 L
s
.32624 .27866 m
.32674 .27847 L
s
.32674 .27847 m
.32719 .27849 L
s
.32719 .27915 m
.32669 .27934 L
s
.32719 .27849 m
.32719 .27915 L
s
1 .336 0 r
.50961 .30679 m
.50998 .30656 L
s
.50998 .30656 m
.51281 .30779 L
s
1 .457 0 r
.66113 .60601 m
.66388 .60878 L
s
.65858 .6079 m
.66113 .60601 L
s
.66113 .60601 m
.66252 .60626 L
s
1 .151 0 r
.39414 .31017 m
.39351 .30903 L
s
.39508 .3089 m
.39414 .31017 L
s
.39351 .30903 m
.39508 .3089 L
s
0 1 .566 r
.64502 .54922 m
.62572 .5681 L
s
.61831 .5473 m
.64502 .54922 L
s
1 .229 0 r
.61389 .31057 m
.61455 .30869 L
s
.973 1 0 r
.4181 .63145 m
.41165 .63685 L
s
.42422 .63662 m
.4181 .63145 L
s
1 .095 0 r
.32669 .27934 m
.32624 .27866 L
s
.32624 .27866 m
.32719 .27849 L
s
1 .039 0 r
.676 .51872 m
.67624 .51889 L
s
.67577 .51894 m
.676 .51872 L
s
.676 .51872 m
.67597 .51872 L
s
0 .813 1 r
.65371 .5791 m
.64571 .58566 L
s
.64454 .55329 m
.65371 .5791 L
s
.66993 .56195 m
.65371 .5791 L
s
1 .095 0 r
.32719 .27849 m
.32669 .27934 L
s
1 .039 0 r
.67602 .51911 m
.67577 .51894 L
s
.67577 .51894 m
.67597 .51872 L
s
.67624 .51889 m
.67602 .51911 L
s
.67597 .51872 m
.67624 .51889 L
s
1 .293 0 r
.33418 .66688 m
.33239 .66864 L
s
.3358 .66817 m
.33418 .66688 L
s
1 .039 0 r
.67597 .51872 m
.67602 .51911 L
s
1 .066 0 r
.26014 .24781 m
.26047 .24827 L
s
.25977 .24796 m
.26014 .24781 L
s
.26014 .24781 m
.2604 .2478 L
s
.26047 .24827 m
.26009 .24841 L
s
.2604 .2478 m
.26047 .24827 L
s
1 .459 0 r
.37426 .63885 m
.3769 .64096 L
s
1 .007 0 r
.85034 .54869 m
.85036 .54852 L
s
0 .197 1 r
.54837 .63885 m
.6962 .5956 L
s
1 .032 0 r
.61054 .48859 m
.60992 .48787 L
s
1 .003 0 r
.37074 .42848 m
.3708 .42841 L
s
1 .241 0 r
.43291 .27821 m
.44183 .27494 L
s
1 .003 0 r
.13094 .36837 m
.13096 .3683 L
s
1 .457 0 r
.66388 .60878 m
.66132 .61068 L
s
.66252 .60626 m
.66388 .60878 L
s
1 .003 0 r
.13095 .3683 m
.13097 .36832 L
s
.13094 .36831 m
.13095 .3683 L
s
.13095 .3683 m
.13096 .3683 L
s
.37078 .4284 m
.3708 .42843 L
s
.37077 .42841 m
.37078 .4284 L
s
.37078 .4284 m
.3708 .42841 L
s
.13097 .36832 m
.13095 .36833 L
s
.13096 .3683 m
.13097 .36832 L
s
.3708 .42843 m
.37078 .42844 L
s
.3708 .42841 m
.3708 .42843 L
s
.13095 .36833 m
.13094 .36831 L
s
.13094 .36831 m
.13096 .3683 L
s
.13096 .3683 m
.13095 .36833 L
s
.37078 .42844 m
.37077 .42841 L
s
.37077 .42841 m
.3708 .42841 L
s
.3708 .42841 m
.37078 .42844 L
s
0 1 .566 r
.62572 .5681 m
.61831 .5473 L
s
1 .007 0 r
.85035 .54852 m
.8504 .54856 L
s
.85031 .54856 m
.85035 .54852 L
s
.85035 .54852 m
.85036 .54852 L
s
.85036 .54859 m
.85031 .54856 L
s
.85031 .54856 m
.85036 .54852 L
s
.8504 .54856 m
.85036 .54859 L
s
.85036 .54852 m
.8504 .54856 L
s
.85036 .54852 m
.85036 .54859 L
s
1 .066 0 r
.26009 .24841 m
.25977 .24796 L
s
.25977 .24796 m
.2604 .2478 L
s
.2604 .2478 m
.26009 .24841 L
s
1 .293 0 r
.33239 .66864 m
.33401 .66993 L
s
1 .323 0 r
.55212 .27784 m
.55234 .27801 L
s
.55231 .27503 m
.55212 .27784 L
s
.55508 .27669 m
.55212 .27784 L
s
1 .336 0 r
.51281 .30779 m
.50997 .30968 L
s
.50961 .30679 m
.51281 .30779 L
s
1 .032 0 r
.61004 .48786 m
.61022 .48796 L
s
.60987 .48807 m
.61004 .48786 L
s
.61004 .48786 m
.60992 .48787 L
s
.61005 .48817 m
.60987 .48807 L
s
.60987 .48807 m
.60992 .48787 L
s
1 .459 0 r
.3769 .64096 m
.37975 .63832 L
s
1 .032 0 r
.61022 .48796 m
.61005 .48817 L
s
.60992 .48787 m
.61022 .48796 L
s
1 .323 0 r
.55252 .27521 m
.55231 .27503 L
s
.55231 .27503 m
.55508 .27669 L
s
1 .032 0 r
.60992 .48787 m
.61005 .48817 L
s
1 .012 0 r
.2427 .54796 m
.24269 .54796 L
s
.2427 .54785 m
.2427 .54796 L
s
.2427 .54796 m
.24262 .5479 L
s
.24277 .54791 m
.2427 .54796 L
s
.24267 .54767 m
.2427 .54796 L
s
.2427 .54785 m
.24262 .5479 L
s
.24277 .54791 m
.2427 .54785 L
s
.24269 .54796 m
.24277 .54791 L
s
.24262 .5479 m
.24269 .54796 L
s
1 .293 0 r
.33401 .66993 m
.3358 .66817 L
s
1 .006 0 r
.84704 .36739 m
.84703 .36739 L
s
.84703 .36733 m
.84704 .36739 L
s
.84704 .36739 m
.84699 .36737 L
s
.84706 .36735 m
.84704 .36739 L
s
.84698 .36725 m
.84704 .36739 L
s
.84703 .36733 m
.84699 .36737 L
s
.84706 .36735 m
.84703 .36733 L
s
.84699 .36737 m
.84703 .36739 L
s
0 1 .566 r
.41721 .54646 m
.42478 .56727 L
s
1 .006 0 r
.84703 .36739 m
.84706 .36735 L
s
1 .457 0 r
.66132 .61068 m
.65858 .6079 L
s
.65858 .6079 m
.66252 .60626 L
s
1 .336 0 r
.50997 .30968 m
.50961 .30679 L
s
1 .271 0 r
.72256 .66796 m
.72663 .66201 L
s
1 .005 0 r
.78477 .5176 m
.78477 .51748 L
s
1 0 0 r
.54483 .45746 m
.54483 .45746 L
s
1 .007 0 r
.30488 .39732 m
.30498 .39715 L
s
1 .158 0 r
.36709 .24696 m
.37208 .24402 L
s
1 .003 0 r
.06494 .33717 m
.06496 .33708 L
s
0 1 .511 r
.42023 .66794 m
.43476 .68337 L
s
1 .003 0 r
.06495 .33708 m
.06497 .3371 L
s
.06493 .3371 m
.06495 .33708 L
s
.06495 .33708 m
.06496 .33708 L
s
.06497 .3371 m
.06495 .33712 L
s
.06496 .33708 m
.06497 .3371 L
s
.06495 .33712 m
.06493 .3371 L
s
.06493 .3371 m
.06496 .33708 L
s
.06496 .33708 m
.06495 .33712 L
s
1 .005 0 r
.78477 .51748 m
.7848 .5175 L
s
.78474 .5175 m
.78477 .51748 L
s
.78477 .51748 m
.78477 .51748 L
s
.78477 .51753 m
.78474 .5175 L
s
.78474 .5175 m
.78477 .51748 L
s
.7848 .5175 m
.78477 .51753 L
s
.78477 .51748 m
.7848 .5175 L
s
1 .007 0 r
.30496 .39715 m
.305 .3972 L
s
.30492 .39718 m
.30496 .39715 L
s
.30496 .39715 m
.30498 .39715 L
s
.305 .3972 m
.30496 .39722 L
s
.30498 .39715 m
.305 .3972 L
s
1 .005 0 r
.78477 .51748 m
.78477 .51753 L
s
1 .007 0 r
.30496 .39722 m
.30492 .39718 L
s
.30492 .39718 m
.30498 .39715 L
s
.30498 .39715 m
.30496 .39722 L
s
0 .813 1 r
.63643 .55957 m
.64454 .55329 L
s
.64454 .55329 m
.66993 .56195 L
s
1 .323 0 r
.55508 .27669 m
.55234 .27801 L
s
.55252 .27521 m
.55508 .27669 L
s
.54128 .27585 m
.55508 .27669 L
s
1 .07 0 r
.35078 .54735 m
.35079 .54736 L
s
.35082 .54665 m
.35078 .54735 L
s
.35078 .54735 m
.35037 .54698 L
s
.35123 .54703 m
.35078 .54735 L
s
.35088 .54563 m
.35078 .54735 L
s
.35082 .54665 m
.35037 .54698 L
s
.35123 .54703 m
.35082 .54665 L
s
1 .241 0 r
.44078 .27646 m
.44001 .27671 L
s
.44008 .27449 m
.44078 .27646 L
s
.44183 .27494 m
.44078 .27646 L
s
1 .023 0 r
.78178 .3366 m
.7817 .33659 L
s
.78169 .33637 m
.78178 .3366 L
s
.78178 .3366 m
.78156 .33653 L
s
.78183 .33644 m
.78178 .3366 L
s
.78137 .33603 m
.78178 .3366 L
s
0 .197 1 r
.38562 .646 m
.39851 .63739 L
s
.39851 .63739 m
.38725 .60661 L
s
.39851 .63739 m
.35844 .6347 L
s
1 .023 0 r
.78169 .33637 m
.78156 .33653 L
s
.78183 .33644 m
.78169 .33637 L
s
.78156 .33653 m
.7817 .33659 L
s
1 .241 0 r
.4393 .27473 m
.44008 .27449 L
s
.44008 .27449 m
.44183 .27494 L
s
1 .172 0 r
.65397 .27631 m
.65465 .27653 L
s
.65458 .27494 m
.65397 .27631 L
s
.65579 .2763 m
.65397 .27631 L
s
.65579 .2763 m
.65465 .27653 L
s
.65458 .27494 m
.65579 .2763 L
s
.65526 .27516 m
.65579 .2763 L
s
.64992 .27347 m
.65579 .2763 L
s
1 .075 0 r
.71757 .30638 m
.71722 .30641 L
s
.71717 .30571 m
.71757 .30638 L
s
.71757 .30638 m
.71682 .30625 L
s
.71756 .30587 m
.71757 .30638 L
s
.71569 .30477 m
.71757 .30638 L
s
1 .457 0 r
.66252 .60626 m
.66132 .61068 L
s
1 .07 0 r
.35079 .54736 m
.35123 .54703 L
s
1 .023 0 r
.7817 .33659 m
.78183 .33644 L
s
1 .172 0 r
.65526 .27516 m
.65458 .27494 L
s
1 .07 0 r
.35037 .54698 m
.35079 .54736 L
s
1 .075 0 r
.71717 .30571 m
.71682 .30625 L
s
.71756 .30587 m
.71717 .30571 L
s
.71682 .30625 m
.71722 .30641 L
s
1 .344 0 r
.63336 .54427 m
.63553 .54596 L
s
.6313 .54604 m
.63336 .54427 L
s
.63336 .54427 m
.63343 .5443 L
s
1 .002 0 r
.1767 .5166 m
.1767 .5166 L
s
.1767 .51659 m
.1767 .5166 L
s
.1767 .5166 m
.17669 .51659 L
s
.17671 .5166 m
.1767 .5166 L
s
.1767 .51656 m
.1767 .5166 L
s
.1767 .51659 m
.17669 .51659 L
s
.17671 .5166 m
.1767 .51659 L
s
.1767 .5166 m
.17671 .5166 L
s
.17669 .51659 m
.1767 .5166 L
s
1 .607 0 r
.65688 .63692 m
.66549 .62325 L
s
1 .002 0 r
.71913 .48647 m
.71911 .48643 L
s
1 .032 0 r
.47904 .42629 m
.48022 .4259 L
s
1 .008 0 r
.23894 .36612 m
.23905 .36591 L
s
1 .002 0 r
.71911 .48643 m
.71913 .48644 L
s
.7191 .48644 m
.71911 .48643 L
s
.71911 .48643 m
.71911 .48643 L
s
.71912 .48645 m
.7191 .48644 L
s
.7191 .48644 m
.71911 .48643 L
s
.71913 .48644 m
.71912 .48645 L
s
.71911 .48643 m
.71913 .48644 L
s
.71911 .48643 m
.71912 .48645 L
s
1 .075 0 r
.71722 .30641 m
.71756 .30587 L
s
.973 1 0 r
.41165 .63685 m
.41776 .64204 L
s
1 .08 0 r
.22352 .66692 m
.22329 .66697 L
s
.22336 .66614 m
.22352 .66692 L
s
.22352 .66692 m
.22285 .6666 L
s
.2238 .66651 m
.22352 .66692 L
s
.22257 .66511 m
.22352 .66692 L
s
1 .008 0 r
.23903 .36591 m
.23908 .36596 L
s
.23898 .36594 m
.23903 .36591 L
s
.23903 .36591 m
.23905 .36591 L
s
.23908 .36596 m
.23903 .36599 L
s
.23905 .36591 m
.23908 .36596 L
s
.23903 .36599 m
.23898 .36594 L
s
.23898 .36594 m
.23905 .36591 L
s
.23905 .36591 m
.23903 .36599 L
s
1 .032 0 r
.48008 .42608 m
.47998 .42613 L
s
.47999 .42582 m
.48008 .42608 L
s
.48022 .4259 m
.48008 .42608 L
s
.47989 .42587 m
.47999 .42582 L
s
.47999 .42582 m
.48022 .4259 L
s
1 .323 0 r
.55234 .27801 m
.55252 .27521 L
s
1 .08 0 r
.22336 .66614 m
.22285 .6666 L
s
.2238 .66651 m
.22336 .66614 L
s
.973 1 0 r
.41776 .64204 m
.42422 .63662 L
s
1 .032 0 r
.48022 .4259 m
.47998 .42613 L
s
.47989 .42587 m
.48022 .4259 L
s
.47998 .42613 m
.47989 .42587 L
s
.787 1 0 r
.60296 .53704 m
.61019 .54435 L
s
.59602 .54191 m
.60296 .53704 L
s
.60296 .53704 m
.60636 .53736 L
s
1 .08 0 r
.22285 .6666 m
.22329 .66697 L
s
.22329 .66697 m
.2238 .66651 L
s
1 .172 0 r
.65465 .27653 m
.65526 .27516 L
s
1 .158 0 r
.37174 .24511 m
.37105 .24533 L
s
.37112 .24389 m
.37174 .24511 L
s
.37208 .24402 m
.37174 .24511 L
s
.37042 .2441 m
.37112 .24389 L
s
.37112 .24389 m
.37208 .24402 L
s
1 .344 0 r
.63347 .54773 m
.6313 .54604 L
s
.6313 .54604 m
.63343 .5443 L
s
1 .271 0 r
.59242 .24501 m
.59296 .24517 L
s
.5929 .2427 m
.59242 .24501 L
s
.59514 .24439 m
.59242 .24501 L
s
.973 1 0 r
.63445 .6285 m
.63965 .63576 L
s
.62959 .63182 m
.63445 .6285 L
s
.63445 .6285 m
.63997 .62985 L
s
1 .344 0 r
.63553 .54596 m
.63347 .54773 L
s
.63343 .5443 m
.63553 .54596 L
s
.542 1 0 r
.62656 .6663 m
.61557 .67707 L
s
.61135 .66529 m
.62656 .6663 L
s
1 .241 0 r
.44183 .27494 m
.44001 .27671 L
s
.4393 .27473 m
.44183 .27494 L
s
.44001 .27671 m
.4393 .27473 L
s
1 .271 0 r
.59344 .24286 m
.5929 .2427 L
s
.5929 .2427 m
.59514 .24439 L
s
1 0 0 r
.11064 .48542 m
.11064 .48542 L
s
.11064 .48542 m
.11064 .48542 L
s
.11064 .48542 m
.11064 .48542 L
s
.11065 .48542 m
.11064 .48542 L
s
.11064 .48542 m
.11064 .48542 L
s
.11064 .48542 m
.11064 .48542 L
s
.11065 .48542 m
.11064 .48542 L
s
.11064 .48542 m
.11065 .48542 L
s
.11064 .48542 m
.11064 .48542 L
s
1 .077 0 r
.83136 .66606 m
.83228 .66433 L
s
1 .001 0 r
.89364 .51552 m
.89364 .51549 L
s
0 1 .077 r
.59112 .60585 m
.61927 .5571 L
s
1 0 0 r
.6534 .45531 m
.6534 .45531 L
s
1 .039 0 r
.41317 .39509 m
.41425 .39434 L
s
1 .293 0 r
.47545 .24455 m
.48758 .24243 L
s
1 .009 0 r
.17293 .33488 m
.17303 .33465 L
s
1 .001 0 r
.89364 .51549 m
.89365 .5155 L
s
.89363 .5155 m
.89364 .51549 L
s
.89364 .51549 m
.89364 .51549 L
s
.89364 .5155 m
.89363 .5155 L
s
.89363 .5155 m
.89364 .51549 L
s
.89365 .5155 m
.89364 .5155 L
s
.89364 .51549 m
.89365 .5155 L
s
.89364 .51549 m
.89364 .5155 L
s
.542 1 0 r
.61557 .67707 m
.61135 .66529 L
s
1 .009 0 r
.17301 .33466 m
.17306 .33471 L
s
.17295 .33469 m
.17301 .33466 L
s
.17301 .33466 m
.17303 .33465 L
s
1 .271 0 r
.59514 .24439 m
.59296 .24517 L
s
.59344 .24286 m
.59514 .24439 L
s
.58407 .24214 m
.59514 .24439 L
s
1 .009 0 r
.17306 .33471 m
.173 .33474 L
s
.17303 .33465 m
.17306 .33471 L
s
.173 .33474 m
.17295 .33469 L
s
.17295 .33469 m
.17303 .33465 L
s
.17303 .33465 m
.173 .33474 L
s
.973 1 0 r
.63965 .63576 m
.6348 .6391 L
s
.63997 .62985 m
.63965 .63576 L
s
.808 1 0 r
.41839 .66582 m
.41748 .66658 L
s
.41787 .65414 m
.41839 .66582 L
s
.41839 .66582 m
.41035 .66047 L
s
.425 .66022 m
.41839 .66582 L
s
.41478 .63805 m
.41839 .66582 L
s
1 .158 0 r
.37105 .24533 m
.37042 .2441 L
s
.37208 .24402 m
.37105 .24533 L
s
.37042 .2441 m
.37208 .24402 L
s
1 .293 0 r
.48563 .24404 m
.48514 .2442 L
s
.48517 .24152 m
.48563 .24404 L
s
.48758 .24243 m
.48563 .24404 L
s
0 .197 1 r
.38725 .60661 m
.3742 .61482 L
s
.38725 .60661 m
.35844 .6347 L
s
1 .039 0 r
.41404 .3943 m
.41421 .39459 L
s
.41386 .39439 m
.41404 .3943 L
s
.41404 .3943 m
.41425 .39434 L
s
.41421 .39459 m
.41403 .39467 L
s
.41425 .39434 m
.41421 .39459 L
s
1 .344 0 r
.63343 .5443 m
.63347 .54773 L
s
1 .039 0 r
.41403 .39467 m
.41386 .39439 L
s
.41386 .39439 m
.41425 .39434 L
s
.41425 .39434 m
.41403 .39467 L
s
1 .293 0 r
.48468 .24168 m
.48517 .24152 L
s
.48517 .24152 m
.48758 .24243 L
s
1 .021 0 r
.5881 .42442 m
.58817 .42446 L
s
.58817 .42426 m
.5881 .42442 L
s
.58831 .42442 m
.5881 .42442 L
s
.58831 .42442 m
.58817 .42446 L
s
.58817 .42426 m
.58831 .42442 L
s
.58825 .42429 m
.58831 .42442 L
s
.5876 .42411 m
.58831 .42442 L
s
.58825 .42429 m
.58817 .42426 L
s
.58817 .42446 m
.58825 .42429 L
s
1 .007 0 r
.28487 .51465 m
.28488 .51465 L
s
.28488 .51458 m
.28487 .51465 L
s
.28487 .51465 m
.28484 .51461 L
s
.28492 .51462 m
.28487 .51465 L
s
.28489 .51448 m
.28487 .51465 L
s
.28488 .51458 m
.28484 .51461 L
s
.28492 .51462 m
.28488 .51458 L
s
.28488 .51465 m
.28492 .51462 L
s
.28484 .51461 m
.28488 .51465 L
s
1 .121 0 r
.76566 .63499 m
.76685 .63218 L
s
1 0 0 r
.82798 .48436 m
.82798 .48435 L
s
.01 w
.52528 .57474 Mdot
1 .032 0 r
.5 Mabswid
.34721 .36385 m
.34794 .36314 L
s
1 .009 0 r
.10683 .3036 m
.10692 .30337 L
s
1 0 0 r
.82798 .48435 m
.82798 .48435 L
s
.82798 .48435 m
.82798 .48435 L
s
.82798 .48435 m
.82798 .48435 L
s
.82798 .48435 m
.82798 .48435 L
s
.82798 .48435 m
.82798 .48435 L
s
.82798 .48435 m
.82798 .48435 L
s
.82798 .48435 m
.82798 .48435 L
s
.82798 .48435 m
.82798 .48435 L
s
1 .009 0 r
.1069 .30338 m
.10695 .30343 L
s
.10685 .30341 m
.1069 .30338 L
s
.1069 .30338 m
.10692 .30337 L
s
.10695 .30343 m
.10689 .30346 L
s
.10692 .30337 m
.10695 .30343 L
s
.10689 .30346 m
.10685 .30341 L
s
.10685 .30341 m
.10692 .30337 L
s
.10692 .30337 m
.10689 .30346 L
s
1 .271 0 r
.59296 .24517 m
.59344 .24286 L
s
.787 1 0 r
.61019 .54435 m
.60325 .54924 L
s
.60636 .53736 m
.61019 .54435 L
s
1 .077 0 r
.83206 .66428 m
.83255 .66472 L
s
.83164 .66463 m
.83206 .66428 L
s
.83206 .66428 m
.83228 .66433 L
s
0 .197 1 r
.35844 .6347 m
.38562 .646 L
s
.35844 .6347 m
.3742 .61482 L
s
.50149 .59121 m
.35844 .6347 L
s
1 .029 0 r
.15673 .63469 m
.15666 .6347 L
s
.1567 .63441 m
.15673 .63469 L
s
.15673 .63469 m
.15651 .63456 L
s
.15685 .63455 m
.15673 .63469 L
s
.15647 .63402 m
.15673 .63469 L
s
.1567 .63441 m
.15651 .63456 L
s
.15685 .63455 m
.1567 .63441 L
s
1 .077 0 r
.83255 .66472 m
.83213 .66508 L
s
.83228 .66433 m
.83255 .66472 L
s
1 .032 0 r
.3478 .36313 m
.34796 .36335 L
s
.34762 .36321 m
.3478 .36313 L
s
.3478 .36313 m
.34794 .36314 L
s
1 .029 0 r
.15651 .63456 m
.15666 .6347 L
s
1 .032 0 r
.34796 .36335 m
.34778 .36343 L
s
.34794 .36314 m
.34796 .36335 L
s
1 .029 0 r
.15666 .6347 m
.15685 .63455 L
s
1 .024 0 r
.825 .30303 m
.82493 .30302 L
s
.82491 .3028 m
.825 .30303 L
s
.825 .30303 m
.82478 .30296 L
s
.82506 .30287 m
.825 .30303 L
s
.8246 .30243 m
.825 .30303 L
s
1 .077 0 r
.83213 .66508 m
.83164 .66463 L
s
.83164 .66463 m
.83228 .66433 L
s
1 .024 0 r
.82491 .3028 m
.82478 .30296 L
s
.82506 .30287 m
.82491 .3028 L
s
.82478 .30296 m
.82493 .30302 L
s
1 .032 0 r
.34778 .36343 m
.34762 .36321 L
s
.34762 .36321 m
.34794 .36314 L
s
.34794 .36314 m
.34778 .36343 L
s
1 .136 0 r
.5264 .39329 m
.52637 .39342 L
s
.52637 .39212 m
.5264 .39329 L
s
.52754 .39274 m
.5264 .39329 L
s
1 .024 0 r
.82493 .30302 m
.82506 .30287 L
s
1 .058 0 r
.39274 .5138 m
.39285 .51381 L
s
.39288 .51323 m
.39274 .5138 L
s
.39274 .5138 m
.39252 .51346 L
s
.39321 .51358 m
.39274 .5138 L
s
.39335 .5124 m
.39274 .5138 L
s
1 .077 0 r
.83228 .66433 m
.83213 .66508 L
s
1 .095 0 r
.26567 .63429 m
.26546 .63434 L
s
.26554 .63336 m
.26567 .63429 L
s
.26567 .63429 m
.26492 .63389 L
s
.26608 .63381 m
.26567 .63429 L
s
.26483 .63208 m
.26567 .63429 L
s
1 .136 0 r
.52634 .39225 m
.52637 .39212 L
s
.52637 .39212 m
.52754 .39274 L
s
1 .293 0 r
.48758 .24243 m
.48514 .2442 L
s
.48468 .24168 m
.48758 .24243 L
s
1 .058 0 r
.39288 .51323 m
.39252 .51346 L
s
.39321 .51358 m
.39288 .51323 L
s
1 .063 0 r
.76032 .27253 m
.76004 .27254 L
s
.76 .27195 m
.76032 .27253 L
s
.76032 .27253 m
.7597 .2724 L
s
.76035 .27209 m
.76032 .27253 L
s
.75882 .2711 m
.76032 .27253 L
s
1 .058 0 r
.39285 .51381 m
.39321 .51358 L
s
1 .063 0 r
.76 .27195 m
.7597 .2724 L
s
.76035 .27209 m
.76 .27195 L
s
.7597 .2724 m
.76004 .27254 L
s
1 .095 0 r
.26554 .63336 m
.26492 .63389 L
s
.26608 .63381 m
.26554 .63336 L
s
1 .134 0 r
.69717 .24222 m
.69637 .24233 L
s
.6963 .24111 m
.69717 .24222 L
s
.69717 .24222 m
.69577 .24215 L
s
.69689 .24129 m
.69717 .24222 L
s
.69296 .23972 m
.69717 .24222 L
s
1 .058 0 r
.39252 .51346 m
.39285 .51381 L
s
1 0 0 r
.21882 .48331 m
.21882 .48331 L
s
.21882 .4833 m
.21882 .48331 L
s
.21882 .48331 m
.21882 .4833 L
s
.21883 .4833 m
.21882 .48331 L
s
.21882 .4833 m
.21882 .48331 L
s
.21882 .4833 m
.21882 .4833 L
s
.21883 .4833 m
.21882 .4833 L
s
1 .134 0 r
.69577 .24215 m
.69637 .24233 L
s
.6963 .24111 m
.69577 .24215 L
s
1 0 0 r
.21882 .48331 m
.21883 .4833 L
s
.21882 .4833 m
.21882 .48331 L
s
1 .028 0 r
.94041 .66416 m
.94073 .66353 L
s
1 .229 0 r
.69988 .60387 m
.70137 .59843 L
s
1 0 0 r
.76224 .45315 m
.76224 .45315 L
s
1 .136 0 r
.52171 .39286 m
.52754 .39274 L
s
1 .026 0 r
.28118 .33258 m
.28167 .33195 L
s
1 .134 0 r
.69689 .24129 m
.6963 .24111 L
s
1 .136 0 r
.52754 .39274 m
.52637 .39342 L
s
.52634 .39225 m
.52754 .39274 L
s
1 .095 0 r
.26492 .63389 m
.26546 .63434 L
s
1 .293 0 r
.48514 .2442 m
.48468 .24168 L
s
1 .063 0 r
.76004 .27254 m
.76035 .27209 L
s
1 .095 0 r
.26546 .63434 m
.26608 .63381 L
s
1 .271 0 r
.72573 .6618 m
.72738 .66346 L
s
.72426 .66295 m
.72573 .6618 L
s
.72573 .6618 m
.72663 .66201 L
s
1 .575 0 r
.3781 .66385 m
.37686 .66425 L
s
.37713 .65825 m
.3781 .66385 L
s
.3781 .66385 m
.37354 .66157 L
s
.38045 .66092 m
.3781 .66385 L
s
.37253 .65073 m
.3781 .66385 L
s
1 .026 0 r
.28159 .33195 m
.28172 .33213 L
s
.28143 .33202 m
.28159 .33195 L
s
.28159 .33195 m
.28167 .33195 L
s
.28172 .33213 m
.28157 .3322 L
s
.28167 .33195 m
.28172 .33213 L
s
1 .136 0 r
.52637 .39342 m
.52634 .39225 L
s
1 .028 0 r
.94064 .66351 m
.94083 .66367 L
s
.9405 .66365 m
.94064 .66351 L
s
.94064 .66351 m
.94073 .66353 L
s
1 .026 0 r
.28157 .3322 m
.28143 .33202 L
s
.28143 .33202 m
.28167 .33195 L
s
.28167 .33195 m
.28157 .3322 L
s
1 .028 0 r
.94083 .66367 m
.94068 .6638 L
s
.94073 .66353 m
.94083 .66367 L
s
.94068 .6638 m
.9405 .66365 L
s
.9405 .66365 m
.94073 .66353 L
s
.94073 .66353 m
.94068 .6638 L
s
1 .134 0 r
.69637 .24233 m
.69689 .24129 L
s
1 .271 0 r
.72738 .66346 m
.7259 .66462 L
s
.72663 .66201 m
.72738 .66346 L
s
1 .002 0 r
.69646 .42196 m
.69645 .42196 L
s
.69645 .42194 m
.69646 .42196 L
s
.69646 .42196 m
.69644 .42195 L
s
.69647 .42195 m
.69646 .42196 L
s
.69642 .42191 m
.69646 .42196 L
s
.69645 .42194 m
.69644 .42195 L
s
.69647 .42195 m
.69645 .42194 L
s
.69644 .42195 m
.69645 .42196 L
s
.69645 .42196 m
.69647 .42195 L
s
.808 1 0 r
.41787 .65414 m
.41035 .66047 L
s
.425 .66022 m
.41787 .65414 L
s
1 .035 0 r
.8747 .63305 m
.87502 .63223 L
s
1 .59 0 r
.63403 .57272 m
.63414 .55826 L
s
1 .133 0 r
.45575 .36158 m
.46071 .35985 L
s
1 .022 0 r
.21507 .30126 m
.21542 .30072 L
s
1 0 0 r
.15268 .45207 m
.15268 .45207 L
s
1 .121 0 r
.76656 .63211 m
.76734 .6328 L
s
.76588 .63268 m
.76656 .63211 L
s
.76656 .63211 m
.76685 .63218 L
s
.76734 .6328 m
.76665 .63337 L
s
.76685 .63218 m
.76734 .6328 L
s
1 .271 0 r
.7259 .66462 m
.72426 .66295 L
s
.72426 .66295 m
.72663 .66201 L
s
1 .022 0 r
.21536 .30072 m
.21548 .30087 L
s
.21523 .30078 m
.21536 .30072 L
s
.21536 .30072 m
.21542 .30072 L
s
.21548 .30087 m
.21534 .30093 L
s
.21542 .30072 m
.21548 .30087 L
s
1 .039 0 r
.6317 .39134 m
.63147 .39138 L
s
.63145 .39101 m
.6317 .39134 L
s
.6317 .39134 m
.63129 .39131 L
s
.63163 .39109 m
.6317 .39134 L
s
.63052 .39063 m
.6317 .39134 L
s
1 .121 0 r
.76665 .63337 m
.76588 .63268 L
s
.76588 .63268 m
.76685 .63218 L
s
1 .039 0 r
.63145 .39101 m
.63129 .39131 L
s
.63163 .39109 m
.63145 .39101 L
s
.63129 .39131 m
.63147 .39138 L
s
1 .022 0 r
.21534 .30093 m
.21523 .30078 L
s
.21523 .30078 m
.21542 .30072 L
s
.21542 .30072 m
.21534 .30093 L
s
1 .162 0 r
.56957 .36093 m
.56988 .36109 L
s
.56986 .35955 m
.56957 .36093 L
s
.5712 .36058 m
.56957 .36093 L
s
1 .035 0 r
.87493 .63221 m
.87517 .63241 L
s
.87474 .63238 m
.87493 .63221 L
s
.87493 .63221 m
.87502 .63223 L
s
1 .039 0 r
.63147 .39138 m
.63163 .39109 L
s
1 .575 0 r
.37713 .65825 m
.37354 .66157 L
s
.38045 .66092 m
.37713 .65825 L
s
1 .121 0 r
.76685 .63218 m
.76665 .63337 L
s
.787 1 0 r
.60325 .54924 m
.59602 .54191 L
s
.59602 .54191 m
.60636 .53736 L
s
1 .035 0 r
.87517 .63241 m
.87497 .63258 L
s
.87502 .63223 m
.87517 .63241 L
s
.87497 .63258 m
.87474 .63238 L
s
.87474 .63238 m
.87502 .63223 L
s
1 .271 0 r
.72663 .66201 m
.7259 .66462 L
s
1 .162 0 r
.57017 .35972 m
.56986 .35955 L
s
.56986 .35955 m
.5712 .36058 L
s
0 .813 1 r
.39616 .57034 m
.40561 .59626 L
s
1 .035 0 r
.87502 .63223 m
.87497 .63258 L
s
1 .133 0 r
.46012 .36065 m
.4597 .36083 L
s
.45973 .35957 m
.46012 .36065 L
s
.46071 .35985 m
.46012 .36065 L
s
.45931 .35974 m
.45973 .35957 L
s
.45973 .35957 m
.46071 .35985 L
s
1 .162 0 r
.5712 .36058 m
.56988 .36109 L
s
.57017 .35972 m
.5712 .36058 L
s
.56454 .35931 m
.5712 .36058 L
s
1 .002 0 r
.32725 .48121 m
.32725 .48121 L
s
.32725 .4812 m
.32725 .48121 L
s
.32725 .48121 m
.32724 .4812 L
s
.32726 .48121 m
.32725 .48121 L
s
.32727 .48117 m
.32725 .48121 L
s
.32725 .4812 m
.32724 .4812 L
s
.32726 .48121 m
.32725 .4812 L
s
.32725 .48121 m
.32726 .48121 L
s
.32724 .4812 m
.32725 .48121 L
s
1 .047 0 r
.80891 .6019 m
.80919 .60078 L
s
1 0 0 r
.87135 .45099 m
.87135 .45099 L
s
0 1 .566 r
.56809 .54153 m
.51516 .48373 L
s
1 .09 0 r
.3897 .33027 m
.39243 .32858 L
s
1 0 0 r
.08645 .42081 m
.08645 .42081 L
s
1 .018 0 r
.14888 .26991 m
.14914 .26943 L
s
1 0 0 r
.08645 .42081 m
.08645 .42081 L
s
.08645 .42081 m
.08645 .42081 L
s
.08645 .42081 m
.08645 .42081 L
s
.08645 .42081 m
.08645 .42081 L
s
.08645 .42081 m
.08645 .42081 L
s
.08645 .42081 m
.08645 .42081 L
s
.08645 .42081 m
.08645 .42081 L
s
.08645 .42081 m
.08645 .42081 L
s
1 .116 0 r
.30778 .60169 m
.30763 .60173 L
s
.30771 .60054 m
.30778 .60169 L
s
.30778 .60169 m
.30696 .60115 L
s
.30838 .60112 m
.30778 .60169 L
s
.30725 .59892 m
.30778 .60169 L
s
.973 1 0 r
.6348 .6391 m
.62959 .63182 L
s
.62959 .63182 m
.63997 .62985 L
s
1 .018 0 r
.1491 .26944 m
.1492 .26956 L
s
.14898 .26949 m
.1491 .26944 L
s
.1491 .26944 m
.14914 .26943 L
s
.1492 .26956 m
.14908 .26961 L
s
.14914 .26943 m
.1492 .26956 L
s
1 .028 0 r
.19881 .60158 m
.19876 .60159 L
s
.19878 .6013 m
.19881 .60158 L
s
.19881 .60158 m
.1986 .60145 L
s
.19894 .60144 m
.19881 .60158 L
s
.19863 .60091 m
.19881 .60158 L
s
1 .018 0 r
.14908 .26961 m
.14898 .26949 L
s
.14898 .26949 m
.14914 .26943 L
s
.14914 .26943 m
.14908 .26961 L
s
1 .028 0 r
.19878 .6013 m
.1986 .60145 L
s
.19894 .60144 m
.19878 .6013 L
s
.1986 .60145 m
.19876 .60159 L
s
.19876 .60159 m
.19894 .60144 L
s
1 .116 0 r
.30771 .60054 m
.30696 .60115 L
s
.30838 .60112 m
.30771 .60054 L
s
1 .162 0 r
.56988 .36109 m
.57017 .35972 L
s
1 .133 0 r
.46071 .35985 m
.4597 .36083 L
s
.45931 .35974 m
.46071 .35985 L
s
.4597 .36083 m
.45931 .35974 L
s
1 .575 0 r
.37354 .66157 m
.37686 .66425 L
s
1 .116 0 r
.30696 .60115 m
.30763 .60173 L
s
.30763 .60173 m
.30838 .60112 L
s
1 .047 0 r
.80912 .60076 m
.80942 .60101 L
s
.80885 .601 m
.80912 .60076 L
s
.80912 .60076 m
.80919 .60078 L
s
.973 1 0 r
.63997 .62985 m
.6348 .6391 L
s
1 .047 0 r
.80942 .60101 m
.80916 .60124 L
s
.80919 .60078 m
.80942 .60101 L
s
.80916 .60124 m
.80885 .601 L
s
.80885 .601 m
.80919 .60078 L
s
1 .055 0 r
.80334 .23859 m
.80312 .23859 L
s
.80307 .23808 m
.80334 .23859 L
s
.80334 .23859 m
.80281 .23847 L
s
.80339 .2382 m
.80334 .23859 L
s
.80211 .2373 m
.80334 .23859 L
s
1 .09 0 r
.39228 .32918 m
.39187 .32934 L
s
.39191 .32849 m
.39228 .32918 L
s
.39243 .32858 m
.39228 .32918 L
s
.3915 .32865 m
.39191 .32849 L
s
.39191 .32849 m
.39243 .32858 L
s
1 0 0 r
.80552 .41972 m
.80552 .41972 L
s
.80552 .41972 m
.80552 .41972 L
s
.80552 .41972 m
.80551 .41972 L
s
.80552 .41972 m
.80552 .41972 L
s
.80551 .41971 m
.80552 .41972 L
s
.80552 .41972 m
.80551 .41972 L
s
.80552 .41972 m
.80552 .41972 L
s
.80551 .41972 m
.80552 .41972 L
s
.80552 .41972 m
.80552 .41972 L
s
1 .068 0 r
.74304 .57071 m
.74316 .56905 L
s
1 0 0 r
.2611 .44991 m
.2611 .44991 L
s
1 .062 0 r
.32358 .29891 m
.32514 .29756 L
s
1 .055 0 r
.80307 .23808 m
.80281 .23847 L
s
.80339 .2382 m
.80307 .23808 L
s
1 .047 0 r
.80919 .60078 m
.80916 .60124 L
s
1 .055 0 r
.80281 .23847 m
.80312 .23859 L
s
.80312 .23859 m
.80339 .2382 L
s
1 .09 0 r
.39187 .32934 m
.3915 .32865 L
s
.39243 .32858 m
.39187 .32934 L
s
.3915 .32865 m
.39243 .32858 L
s
1 .575 0 r
.37686 .66425 m
.38045 .66092 L
s
.787 1 0 r
.60636 .53736 m
.60325 .54924 L
s
1 .021 0 r
.43549 .47948 m
.43558 .47949 L
s
.43559 .47929 m
.43549 .47948 L
s
.43549 .47948 m
.43548 .47935 L
s
.43569 .47943 m
.43549 .47948 L
s
.43597 .47904 m
.43549 .47948 L
s
.43559 .47929 m
.43548 .47935 L
s
.43569 .47943 m
.43559 .47929 L
s
.43558 .47949 m
.43569 .47943 L
s
.43548 .47935 m
.43558 .47949 L
s
1 .062 0 r
.32484 .29755 m
.32513 .29799 L
s
.32452 .29767 m
.32484 .29755 L
s
.32484 .29755 m
.32514 .29756 L
s
.32513 .29799 m
.32481 .29812 L
s
.32514 .29756 m
.32513 .29799 L
s
1 .008 0 r
.13239 .56988 m
.13237 .56989 L
s
.13238 .56981 m
.13239 .56988 L
s
.13239 .56988 m
.13233 .56985 L
s
.13243 .56985 m
.13239 .56988 L
s
.13235 .5697 m
.13239 .56988 L
s
1 .229 0 r
.70101 .59835 m
.70246 .5996 L
s
.69968 .59945 m
.70101 .59835 L
s
.70101 .59835 m
.70137 .59843 L
s
1 .008 0 r
.13238 .56981 m
.13233 .56985 L
s
.13243 .56985 m
.13238 .56981 L
s
.13237 .56989 m
.13243 .56985 L
s
.13233 .56985 m
.13237 .56989 L
s
1 .007 0 r
.73972 .38855 m
.7397 .38855 L
s
.73969 .38848 m
.73972 .38855 L
s
.73972 .38855 m
.73966 .38853 L
s
.73973 .3885 m
.73972 .38855 L
s
.7396 .38839 m
.73972 .38855 L
s
.73969 .38848 m
.73966 .38853 L
s
.73973 .3885 m
.73969 .38848 L
s
.808 1 0 r
.41035 .66047 m
.41748 .66658 L
s
1 .007 0 r
.73966 .38853 m
.7397 .38855 L
s
.7397 .38855 m
.73973 .3885 L
s
1 .215 0 r
.50602 .32796 m
.50577 .32813 L
s
.50579 .32611 m
.50602 .32796 L
s
.5076 .32691 m
.50602 .32796 L
s
1 .014 0 r
.9182 .59991 m
.9183 .59957 L
s
1 .111 0 r
.67709 .53948 m
.6765 .53676 L
s
1 .215 0 r
.49849 .32795 m
.5076 .32691 L
s
1 0 0 r
.19486 .41861 m
.19486 .4186 L
s
1 .045 0 r
.25737 .26752 m
.25834 .26645 L
s
1 0 0 r
.19486 .4186 m
.19486 .4186 L
s
.19486 .4186 m
.19486 .4186 L
s
.19486 .4186 m
.19486 .4186 L
s
.19486 .4186 m
.19486 .4186 L
s
.19486 .4186 m
.19486 .4186 L
s
.19486 .4186 m
.19486 .4186 L
s
.19486 .4186 m
.19486 .4186 L
s
.19486 .4186 m
.19486 .4186 L
s
1 .062 0 r
.32481 .29812 m
.32452 .29767 L
s
.32452 .29767 m
.32514 .29756 L
s
.32514 .29756 m
.32481 .29812 L
s
1 .068 0 r
.74311 .56904 m
.74355 .56938 L
s
.74272 .56939 m
.74311 .56904 L
s
.74311 .56904 m
.74316 .56905 L
s
.808 1 0 r
.41748 .66658 m
.425 .66022 L
s
1 .215 0 r
.50554 .32627 m
.50579 .32611 L
s
.50579 .32611 m
.5076 .32691 L
s
1 .043 0 r
.67479 .35791 m
.67457 .35794 L
s
.67455 .35753 m
.67479 .35791 L
s
.67479 .35791 m
.67435 .35785 L
s
.67476 .35762 m
.67479 .35791 L
s
.67361 .35703 m
.67479 .35791 L
s
1 .014 0 r
.91827 .59957 m
.91837 .59964 L
s
.91819 .59964 m
.91827 .59957 L
s
.91827 .59957 m
.9183 .59957 L
s
.91837 .59964 m
.91829 .59971 L
s
.9183 .59957 m
.91837 .59964 L
s
1 .043 0 r
.67455 .35753 m
.67435 .35785 L
s
.67476 .35762 m
.67455 .35753 L
s
1 .014 0 r
.91829 .59971 m
.91819 .59964 L
s
.91819 .59964 m
.9183 .59957 L
s
1 .043 0 r
.67435 .35785 m
.67457 .35794 L
s
1 .141 0 r
.61134 .32761 m
.61179 .32777 L
s
.61175 .32645 m
.61134 .32761 L
s
.61283 .32748 m
.61134 .32761 L
s
1 .068 0 r
.74316 .56973 m
.74272 .56939 L
s
.74272 .56939 m
.74316 .56905 L
s
1 .014 0 r
.9183 .59957 m
.91829 .59971 L
s
1 .068 0 r
.74355 .56938 m
.74316 .56973 L
s
.74316 .56905 m
.74355 .56938 L
s
1 .229 0 r
.70246 .5996 m
.70113 .6007 L
s
.70137 .59843 m
.70246 .5996 L
s
1 .141 0 r
.6122 .32661 m
.61175 .32645 L
s
.61175 .32645 m
.61283 .32748 L
s
.61283 .32748 m
.61179 .32777 L
s
.6122 .32661 m
.61283 .32748 L
s
.60753 .32563 m
.61283 .32748 L
s
1 .229 0 r
.70113 .6007 m
.69968 .59945 L
s
.69968 .59945 m
.70137 .59843 L
s
1 .068 0 r
.74316 .56905 m
.74316 .56973 L
s
1 .043 0 r
.67457 .35794 m
.67476 .35762 L
s
0 .04 1 r
.38004 .66909 m
.3936 .65978 L
s
.3936 .65978 m
.38181 .62759 L
s
.3936 .65978 m
.35166 .657 L
s
1 .045 0 r
.25817 .26646 m
.25839 .26677 L
s
.25791 .26656 m
.25817 .26646 L
s
.25817 .26646 m
.25834 .26645 L
s
1 .141 0 r
.34962 .56908 m
.34962 .56911 L
s
.3497 .56767 m
.34962 .56908 L
s
.34962 .56908 m
.34879 .56835 L
s
.35053 .56844 m
.34962 .56908 L
s
.34982 .56564 m
.34962 .56908 L
s
1 .045 0 r
.25839 .26677 m
.25813 .26687 L
s
.25834 .26645 m
.25839 .26677 L
s
.25813 .26687 m
.25791 .26656 L
s
.25791 .26656 m
.25834 .26645 L
s
.25834 .26645 m
.25813 .26687 L
s
1 .215 0 r
.5076 .32691 m
.50577 .32813 L
s
.50554 .32627 m
.5076 .32691 L
s
1 .141 0 r
.3497 .56767 m
.34879 .56835 L
s
.35053 .56844 m
.3497 .56767 L
s
1 .229 0 r
.70137 .59843 m
.70113 .6007 L
s
1 .015 0 r
.85232 .56868 m
.85237 .56831 L
s
0 .04 1 r
.54851 .65939 m
.70357 .61461 L
s
1 .199 0 r
.61106 .50821 m
.60718 .50377 L
s
1 0 0 r
.3698 .44774 m
.3698 .44774 L
s
1 .166 0 r
.43235 .29656 m
.43853 .29431 L
s
1 .001 0 r
.12853 .38727 m
.12854 .38725 L
s
1 .035 0 r
.19108 .23609 m
.19173 .23522 L
s
1 .001 0 r
.12854 .38725 m
.12854 .38725 L
s
.12853 .38725 m
.12854 .38725 L
s
.12854 .38725 m
.12854 .38725 L
s
.12854 .38725 m
.12854 .38725 L
s
.12854 .38725 m
.12854 .38725 L
s
.12854 .38725 m
.12853 .38725 L
s
.12853 .38725 m
.12854 .38725 L
s
.12854 .38725 m
.12854 .38725 L
s
1 .141 0 r
.61179 .32777 m
.6122 .32661 L
s
.34962 .56911 m
.35053 .56844 L
s
1 .015 0 r
.85235 .5683 m
.85246 .56838 L
s
.85227 .56838 m
.85235 .5683 L
s
.85235 .5683 m
.85237 .56831 L
s
1 .215 0 r
.50577 .32813 m
.50554 .32627 L
s
1 .015 0 r
.85237 .56846 m
.85227 .56838 L
s
.85227 .56838 m
.85237 .56831 L
s
.85246 .56838 m
.85237 .56846 L
s
.85237 .56831 m
.85246 .56838 L
s
1 .141 0 r
.34879 .56835 m
.34962 .56911 L
s
1 .015 0 r
.85237 .56831 m
.85237 .56846 L
s
1 .026 0 r
.24101 .56831 m
.24099 .56831 L
s
.24101 .56805 m
.24101 .56831 L
s
.24101 .56831 m
.24084 .56818 L
s
.24116 .56819 m
.24101 .56831 L
s
.24095 .56767 m
.24101 .56831 L
s
.24101 .56805 m
.24084 .56818 L
s
.24116 .56819 m
.24101 .56805 L
s
1 .035 0 r
.19162 .23523 m
.1918 .23547 L
s
.19141 .23531 m
.19162 .23523 L
s
.19162 .23523 m
.19173 .23522 L
s
1 .026 0 r
.24099 .56831 m
.24116 .56819 L
s
.24084 .56818 m
.24099 .56831 L
s
1 .035 0 r
.1918 .23547 m
.19158 .23555 L
s
.19173 .23522 m
.1918 .23547 L
s
.19158 .23555 m
.19141 .23531 L
s
.19141 .23531 m
.19173 .23522 L
s
.19173 .23522 m
.19158 .23555 L
s
1 .229 0 r
.54909 .2956 m
.54924 .29574 L
s
.54923 .29361 m
.54909 .2956 L
s
.5512 .29479 m
.54909 .2956 L
s
1 .111 0 r
.67659 .53675 m
.6773 .53724 L
s
.67594 .53737 m
.67659 .53675 L
s
.67659 .53675 m
.6765 .53676 L
s
1 .002 0 r
.84896 .38619 m
.84896 .38619 L
s
.84896 .38617 m
.84896 .38619 L
s
.84896 .38619 m
.84895 .38618 L
s
.84897 .38618 m
.84896 .38619 L
s
.84894 .38614 m
.84896 .38619 L
s
.84896 .38617 m
.84895 .38618 L
s
.84897 .38618 m
.84896 .38617 L
s
.84895 .38618 m
.84896 .38619 L
s
.84896 .38619 m
.84897 .38618 L
s
1 .016 0 r
.78635 .53742 m
.78634 .53702 L
s
1 .117 0 r
.54495 .47691 m
.54013 .47605 L
s
1 .114 0 r
.36612 .26513 m
.36974 .26302 L
s
1 .001 0 r
.30354 .4164 m
.30355 .41638 L
s
1 .002 0 r
.06213 .35589 m
.06214 .35585 L
s
1 .001 0 r
.30355 .41638 m
.30355 .41638 L
s
.30354 .41638 m
.30355 .41638 L
s
.30355 .41638 m
.30355 .41638 L
s
.30355 .41638 m
.30355 .41639 L
s
.30355 .41638 m
.30355 .41638 L
s
.30355 .41639 m
.30354 .41638 L
s
.30354 .41638 m
.30355 .41638 L
s
.30355 .41638 m
.30355 .41639 L
s
1 .229 0 r
.54937 .29375 m
.54923 .29361 L
s
.54923 .29361 m
.5512 .29479 L
s
1 .166 0 r
.43781 .29535 m
.43727 .29553 L
s
.43731 .29399 m
.43781 .29535 L
s
.43853 .29431 m
.43781 .29535 L
s
1 .002 0 r
.06214 .35585 m
.06215 .35586 L
s
.06213 .35586 m
.06214 .35585 L
s
.06214 .35585 m
.06214 .35585 L
s
.06215 .35586 m
.06213 .35586 L
s
.06214 .35585 m
.06215 .35586 L
s
.06213 .35586 m
.06213 .35586 L
s
.06213 .35586 m
.06214 .35585 L
s
.06214 .35585 m
.06213 .35586 L
s
1 .111 0 r
.67664 .53786 m
.67594 .53737 L
s
.67594 .53737 m
.6765 .53676 L
s
1 .166 0 r
.43678 .29417 m
.43731 .29399 L
s
.43731 .29399 m
.43853 .29431 L
s
1 .111 0 r
.6773 .53724 m
.67664 .53786 L
s
.6765 .53676 m
.6773 .53724 L
s
1 .117 0 r
.5411 .4768 m
.54088 .47663 L
s
.54088 .47663 m
.54109 .47565 L
s
.54088 .47663 m
.54013 .47605 L
s
1 .016 0 r
.78633 .53702 m
.78644 .53709 L
s
.78624 .53711 m
.78633 .53702 L
s
.78633 .53702 m
.78634 .53702 L
s
.78635 .53718 m
.78624 .53711 L
s
.78624 .53711 m
.78634 .53702 L
s
.78644 .53709 m
.78635 .53718 L
s
.78634 .53702 m
.78644 .53709 L
s
.78634 .53702 m
.78635 .53718 L
s
1 .117 0 r
.54109 .47565 m
.5413 .47581 L
s
.54109 .47565 m
.54013 .47605 L
s
1 .111 0 r
.6765 .53676 m
.67664 .53786 L
s
1 .229 0 r
.5512 .29479 m
.54924 .29574 L
s
.54937 .29375 m
.5512 .29479 L
s
.54138 .2942 m
.5512 .29479 L
s
0 .04 1 r
.38181 .62759 m
.36807 .63648 L
s
.38181 .62759 m
.35166 .657 L
s
1 .607 0 r
.66363 .62287 m
.66729 .62659 L
s
.66022 .62542 m
.66363 .62287 L
s
.66363 .62287 m
.66549 .62325 L
s
1 .011 0 r
.78312 .355 m
.78309 .355 L
s
.78308 .3549 m
.78312 .355 L
s
.78312 .355 m
.78302 .35497 L
s
.78314 .35493 m
.78312 .355 L
s
.78294 .35475 m
.78312 .355 L
s
.78308 .3549 m
.78302 .35497 L
s
.78314 .35493 m
.78308 .3549 L
s
1 .117 0 r
.54013 .47605 m
.5411 .4768 L
s
.54013 .47605 m
.5413 .47581 L
s
1 .011 0 r
.78302 .35497 m
.78309 .355 L
s
.78309 .355 m
.78314 .35493 L
s
1 .005 0 r
.17458 .53651 m
.17457 .53651 L
s
.17458 .53646 m
.17458 .53651 L
s
.17458 .53651 m
.17455 .53649 L
s
.17461 .53649 m
.17458 .53651 L
s
.17457 .53638 m
.17458 .53651 L
s
.17458 .53646 m
.17455 .53649 L
s
.17461 .53649 m
.17458 .53646 L
s
.17457 .53651 m
.17461 .53649 L
s
.17455 .53649 m
.17457 .53651 L
s
1 .166 0 r
.43853 .29431 m
.43727 .29553 L
s
.43678 .29417 m
.43853 .29431 L
s
1 .117 0 r
.5413 .47581 m
.5411 .4768 L
s
1 .166 0 r
.43727 .29553 m
.43678 .29417 L
s
0 .434 1 r
.66727 .59696 m
.65841 .60458 L
s
.65694 .56788 m
.66727 .59696 L
s
.68572 .57781 m
.66727 .59696 L
s
1 .741 0 r
.65768 .65748 m
.66829 .64087 L
s
1 .014 0 r
.72031 .50611 m
.7202 .50576 L
s
1 0 0 r
.47875 .44557 m
.47875 .44557 L
s
1 .003 0 r
.2372 .38502 m
.23723 .38495 L
s
1 .08 0 r
.29982 .23365 m
.30199 .23194 L
s
1 .003 0 r
.23723 .38496 m
.23724 .38497 L
s
.23721 .38496 m
.23723 .38496 L
s
.23723 .38496 m
.23723 .38495 L
s
.23724 .38497 m
.23722 .38498 L
s
.23723 .38495 m
.23724 .38497 L
s
.23722 .38498 m
.23721 .38496 L
s
.23721 .38496 m
.23723 .38495 L
s
.23723 .38495 m
.23722 .38498 L
s
1 .114 0 r
.36949 .2638 m
.36899 .26397 L
s
.36904 .26291 m
.36949 .2638 L
s
.36974 .26302 m
.36949 .2638 L
s
.36854 .26308 m
.36904 .26291 L
s
.36904 .26291 m
.36974 .26302 L
s
1 .229 0 r
.54924 .29574 m
.54937 .29375 L
s
1 .043 0 r
.71793 .32423 m
.71773 .32424 L
s
.7177 .32384 m
.71793 .32423 L
s
.71793 .32423 m
.7175 .32415 L
s
.71793 .32393 m
.71793 .32423 L
s
.71685 .32331 m
.71793 .32423 L
s
1 .014 0 r
.72022 .50576 m
.72031 .50582 L
s
.72013 .50585 m
.72022 .50576 L
s
.72022 .50576 m
.7202 .50576 L
s
.72022 .5059 m
.72013 .50585 L
s
.72013 .50585 m
.7202 .50576 L
s
1 .162 0 r
.39085 .53612 m
.39116 .53616 L
s
.39122 .53453 m
.39085 .53612 L
s
.39085 .53612 m
.39022 .53518 L
s
.39216 .53551 m
.39085 .53612 L
s
.39254 .53224 m
.39085 .53612 L
s
1 .043 0 r
.7177 .32384 m
.7175 .32415 L
s
.71793 .32393 m
.7177 .32384 L
s
.7175 .32415 m
.71773 .32424 L
s
1 .014 0 r
.72031 .50582 m
.72022 .5059 L
s
.7202 .50576 m
.72031 .50582 L
s
.7202 .50576 m
.72022 .5059 L
s
1 .116 0 r
.65342 .29374 m
.65388 .29389 L
s
.65383 .29281 m
.65342 .29374 L
s
.65465 .29373 m
.65342 .29374 L
s
.65465 .29373 m
.65388 .29389 L
s
.65383 .29281 m
.65465 .29373 L
s
.65429 .29296 m
.65465 .29373 L
s
.65068 .29183 m
.65465 .29373 L
s
.65429 .29296 m
.65383 .29281 L
s
1 .043 0 r
.71773 .32424 m
.71793 .32393 L
s
0 .04 1 r
.35166 .657 m
.38004 .66909 L
s
.35166 .657 m
.36807 .63648 L
s
.50134 .61208 m
.35166 .657 L
s
1 .162 0 r
.39122 .53453 m
.39022 .53518 L
s
.39216 .53551 m
.39122 .53453 L
s
1 .607 0 r
.66729 .62659 m
.66389 .62915 L
s
.66549 .62325 m
.66729 .62659 L
s
1 .114 0 r
.36899 .26397 m
.36854 .26308 L
s
.36974 .26302 m
.36899 .26397 L
s
.36854 .26308 m
.36974 .26302 L
s
1 .162 0 r
.39116 .53616 m
.39216 .53551 L
s
1 .199 0 r
.60793 .50366 m
.60905 .50431 L
s
.60686 .505 m
.60793 .50366 L
s
.60793 .50366 m
.60718 .50377 L
s
1 .08 0 r
.30158 .23192 m
.30194 .23251 L
s
.30117 .23205 m
.30158 .23192 L
s
.30158 .23192 m
.30199 .23194 L
s
.30194 .23251 m
.30153 .23265 L
s
.30199 .23194 m
.30194 .23251 L
s
1 .001 0 r
.10811 .50508 m
.10811 .50508 L
s
.10811 .50507 m
.10811 .50508 L
s
.10811 .50508 m
.10811 .50507 L
s
.10812 .50508 m
.10811 .50508 L
s
.10811 .50506 m
.10811 .50508 L
s
.10811 .50507 m
.10811 .50507 L
s
.10812 .50508 m
.10811 .50507 L
s
.10811 .50508 m
.10812 .50508 L
s
.10811 .50507 m
.10811 .50508 L
s
1 .004 0 r
.89589 .53535 m
.89589 .53525 L
s
0 1 .331 r
.59152 .62623 m
.62344 .57166 L
s
1 .007 0 r
.65418 .47477 m
.65406 .47462 L
s
1 .005 0 r
.41248 .41418 m
.41263 .41408 L
s
1 .22 0 r
.47514 .26273 m
.48432 .26114 L
s
1 .004 0 r
.17078 .3536 m
.17082 .3535 L
s
1 .116 0 r
.65388 .29389 m
.65429 .29296 L
s
1 .199 0 r
.60798 .50565 m
.60686 .505 L
s
.60686 .505 m
.60718 .50377 L
s
1 .004 0 r
.17081 .3535 m
.17083 .35353 L
s
.17079 .35352 m
.17081 .3535 L
s
.17081 .3535 m
.17082 .3535 L
s
1 .005 0 r
.4126 .41407 m
.41263 .41411 L
s
.41258 .41409 m
.4126 .41407 L
s
.4126 .41407 m
.41263 .41408 L
s
.41263 .41411 m
.4126 .41413 L
s
.41263 .41408 m
.41263 .41411 L
s
1 .004 0 r
.17083 .35353 m
.17081 .35354 L
s
.17082 .3535 m
.17083 .35353 L
s
.89589 .53525 m
.89592 .53527 L
s
.89587 .53527 m
.89589 .53525 L
s
.89589 .53525 m
.89589 .53525 L
s
.17081 .35354 m
.17079 .35352 L
s
.17079 .35352 m
.17082 .3535 L
s
.17082 .3535 m
.17081 .35354 L
s
.8959 .53529 m
.89587 .53527 L
s
.89587 .53527 m
.89589 .53525 L
s
.89592 .53527 m
.8959 .53529 L
s
.89589 .53525 m
.89592 .53527 L
s
1 .005 0 r
.4126 .41413 m
.41258 .41409 L
s
.41258 .41409 m
.41263 .41408 L
s
.41263 .41408 m
.4126 .41413 L
s
1 .004 0 r
.89589 .53525 m
.8959 .53529 L
s
1 .007 0 r
.65408 .47461 m
.65412 .47464 L
s
.65405 .47466 m
.65408 .47461 L
s
.65408 .47461 m
.65406 .47462 L
s
.65409 .47468 m
.65405 .47466 L
s
.65405 .47466 m
.65406 .47462 L
s
.65412 .47464 m
.65409 .47468 L
s
.65406 .47462 m
.65412 .47464 L
s
.65406 .47462 m
.65409 .47468 L
s
1 .162 0 r
.39022 .53518 m
.39116 .53616 L
s
1 .202 0 r
.59071 .26246 m
.59111 .26259 L
s
.59107 .26073 m
.59071 .26246 L
s
.59275 .26199 m
.59071 .26246 L
s
1 .08 0 r
.30153 .23265 m
.30117 .23205 L
s
.30117 .23205 m
.30199 .23194 L
s
1 .22 0 r
.48284 .26234 m
.48247 .26247 L
s
.4825 .26044 m
.48284 .26234 L
s
.48432 .26114 m
.48284 .26234 L
s
1 .08 0 r
.30199 .23194 m
.30153 .23265 L
s
1 .202 0 r
.59147 .26086 m
.59107 .26073 L
s
.59107 .26073 m
.59275 .26199 L
s
1 .021 0 r
.28337 .53484 m
.28337 .53484 L
s
.28339 .53463 m
.28337 .53484 L
s
.28337 .53484 m
.28325 .53472 L
s
.28351 .53474 m
.28337 .53484 L
s
.28342 .53432 m
.28337 .53484 L
s
1 .22 0 r
.48212 .26057 m
.4825 .26044 L
s
.4825 .26044 m
.48432 .26114 L
s
1 .021 0 r
.28339 .53463 m
.28325 .53472 L
s
.28351 .53474 m
.28339 .53463 L
s
.28337 .53484 m
.28351 .53474 L
s
.28325 .53472 m
.28337 .53484 L
s
1 .202 0 r
.59275 .26199 m
.59111 .26259 L
s
.59147 .26086 m
.59275 .26199 L
s
.58443 .26032 m
.59275 .26199 L
s
1 .199 0 r
.60905 .50431 m
.60798 .50565 L
s
.60718 .50377 m
.60905 .50431 L
s
0 .434 1 r
.64794 .57515 m
.65694 .56788 L
s
.65694 .56788 m
.68572 .57781 L
s
1 .134 0 r
.26442 .65576 m
.26413 .65584 L
s
.26424 .65444 m
.26442 .65576 L
s
.26442 .65576 m
.26337 .65519 L
s
.265 .65509 m
.26442 .65576 L
s
.26324 .65267 m
.26442 .65576 L
s
1 .607 0 r
.66389 .62915 m
.66022 .62542 L
s
.66022 .62542 m
.66549 .62325 L
s
1 .199 0 r
.60718 .50377 m
.60798 .50565 L
s
1 .043 0 r
.15461 .65558 m
.15451 .6556 L
s
.15456 .65516 m
.15461 .65558 L
s
.15461 .65558 m
.15427 .65539 L
s
.15479 .65537 m
.15461 .65558 L
s
.15421 .65459 m
.15461 .65558 L
s
1 .168 0 r
.76713 .65556 m
.76879 .65169 L
s
1 .003 0 r
.82983 .50401 m
.82982 .50394 L
s
1 0 0 r
.01 w
.52528 .59494 Mdot
.5 Mabswid
.58798 .44339 m
.58798 .44339 L
s
1 .01 0 r
.34613 .38277 m
.34636 .38253 L
s
1 .168 0 r
.40883 .23121 m
.41508 .22886 L
s
1 .005 0 r
.10428 .32215 m
.10432 .32202 L
s
1 .003 0 r
.82982 .50394 m
.82984 .50395 L
s
.82981 .50395 m
.82982 .50394 L
s
.82982 .50394 m
.82982 .50394 L
s
.82982 .50397 m
.82981 .50395 L
s
.82981 .50395 m
.82982 .50394 L
s
.82984 .50395 m
.82982 .50397 L
s
.82982 .50394 m
.82984 .50395 L
s
.82982 .50394 m
.82982 .50397 L
s
1 .005 0 r
.10431 .32203 m
.10434 .32205 L
s
.10428 .32204 m
.10431 .32203 L
s
.10431 .32203 m
.10432 .32202 L
s
1 .043 0 r
.15456 .65516 m
.15427 .65539 L
s
.15479 .65537 m
.15456 .65516 L
s
1 .005 0 r
.10434 .32205 m
.10431 .32207 L
s
.10432 .32202 m
.10434 .32205 L
s
.10431 .32207 m
.10428 .32204 L
s
.10428 .32204 m
.10432 .32202 L
s
.10432 .32202 m
.10431 .32207 L
s
1 .134 0 r
.26424 .65444 m
.26337 .65519 L
s
.265 .65509 m
.26424 .65444 L
s
1 .01 0 r
.34632 .38253 m
.34637 .3826 L
s
.34626 .38256 m
.34632 .38253 L
s
.34632 .38253 m
.34636 .38253 L
s
.34637 .3826 m
.34631 .38263 L
s
.34636 .38253 m
.34637 .3826 L
s
1 .043 0 r
.15427 .65539 m
.15451 .6556 L
s
1 .01 0 r
.34631 .38263 m
.34626 .38256 L
s
.34626 .38256 m
.34636 .38253 L
s
.34636 .38253 m
.34631 .38263 L
s
1 .043 0 r
.15451 .6556 m
.15479 .65537 L
s
0 .434 1 r
.38293 .59291 m
.39357 .622 L
s
1 .22 0 r
.48432 .26114 m
.48247 .26247 L
s
.48212 .26057 m
.48432 .26114 L
s
1 .134 0 r
.26337 .65519 m
.26413 .65584 L
s
1 .202 0 r
.59111 .26259 m
.59147 .26086 L
s
1 .134 0 r
.26413 .65584 m
.265 .65509 L
s
1 .22 0 r
.48247 .26247 m
.48212 .26057 L
s
1 .013 0 r
.82665 .32131 m
.82661 .3213 L
s
.8266 .32118 m
.82665 .32131 L
s
.82665 .32131 m
.82653 .32127 L
s
.82668 .32121 m
.82665 .32131 L
s
.82643 .32098 m
.82665 .32131 L
s
.8266 .32118 m
.82653 .32127 L
s
.82668 .32121 m
.8266 .32118 L
s
.82653 .32127 m
.82661 .3213 L
s
1 .607 0 r
.66549 .62325 m
.66389 .62915 L
s
1 .013 0 r
.82661 .3213 m
.82668 .32121 L
s
.808 1 0 r
.63855 .64562 m
.64463 .65412 L
s
.63287 .64957 m
.63855 .64562 L
s
.63855 .64562 m
.64502 .64728 L
s
1 .003 0 r
.21694 .50301 m
.21694 .50301 L
s
.21695 .50299 m
.21694 .50301 L
s
.21694 .50301 m
.21693 .503 L
s
.21696 .503 m
.21694 .50301 L
s
.21695 .50295 m
.21694 .50301 L
s
1 .021 0 r
.52241 .41203 m
.52241 .41205 L
s
.52241 .41185 m
.52241 .41203 L
s
.52259 .41195 m
.52241 .41203 L
s
1 .003 0 r
.21695 .50299 m
.21693 .503 L
s
.21696 .503 m
.21695 .50299 L
s
.21694 .50301 m
.21696 .503 L
s
.21693 .503 m
.21694 .50301 L
s
1 .021 0 r
.5224 .41187 m
.52241 .41185 L
s
.52241 .41185 m
.52259 .41195 L
s
1 .323 0 r
.70095 .62426 m
.70307 .61661 L
s
1 .001 0 r
.76369 .47262 m
.76368 .4726 L
s
1 .021 0 r
.52169 .41196 m
.52259 .41195 L
s
1 .012 0 r
.27969 .35131 m
.27992 .35103 L
s
1 .001 0 r
.76368 .4726 m
.76369 .47261 L
s
.76368 .47261 m
.76368 .4726 L
s
.76368 .4726 m
.76368 .4726 L
s
.76368 .47261 m
.76368 .47261 L
s
.76368 .47261 m
.76368 .4726 L
s
.76369 .47261 m
.76368 .47261 L
s
.76368 .4726 m
.76369 .47261 L
s
1 .021 0 r
.52259 .41195 m
.52241 .41205 L
s
.5224 .41187 m
.52259 .41195 L
s
1 .001 0 r
.76368 .4726 m
.76368 .47261 L
s
1 .168 0 r
.41436 .22995 m
.4138 .2301 L
s
.41386 .22856 m
.41436 .22995 L
s
.41508 .22886 m
.41436 .22995 L
s
1 .021 0 r
.52241 .41205 m
.5224 .41187 L
s
1 .168 0 r
.4133 .2287 m
.41386 .22856 L
s
.41386 .22856 m
.41508 .22886 L
s
1 .012 0 r
.27987 .35103 m
.27994 .35111 L
s
.2798 .35106 m
.27987 .35103 L
s
.27987 .35103 m
.27992 .35103 L
s
.27994 .35111 m
.27987 .35114 L
s
.27992 .35103 m
.27994 .35111 L
s
.27987 .35114 m
.2798 .35106 L
s
.2798 .35106 m
.27992 .35103 L
s
.27992 .35103 m
.27987 .35114 L
s
1 .04 0 r
.76121 .29037 m
.76103 .29038 L
s
.761 .29 m
.76121 .29037 L
s
.76121 .29037 m
.76081 .29029 L
s
.76122 .29009 m
.76121 .29037 L
s
.76025 .28946 m
.76121 .29037 L
s
.761 .29 m
.76081 .29029 L
s
.76122 .29009 m
.761 .29 L
s
.76081 .29029 m
.76103 .29038 L
s
1 .233 0 r
.52622 .22957 m
.52617 .22966 L
s
.52617 .22752 m
.52622 .22957 L
s
.52819 .22854 m
.52622 .22957 L
s
1 .04 0 r
.76103 .29038 m
.76122 .29009 L
s
.808 1 0 r
.64463 .65412 m
.63896 .65809 L
s
.64502 .64728 m
.64463 .65412 L
s
1 .095 0 r
.697 .25968 m
.69643 .25977 L
s
.69638 .25889 m
.697 .25968 L
s
.697 .25968 m
.696 .25963 L
s
.6968 .25903 m
.697 .25968 L
s
.69398 .25791 m
.697 .25968 L
s
1 .233 0 r
.52612 .22761 m
.52617 .22752 L
s
.52617 .22752 m
.52819 .22854 L
s
1 .095 0 r
.696 .25963 m
.69643 .25977 L
s
.69638 .25889 m
.696 .25963 L
s
.6968 .25903 m
.69638 .25889 L
s
1 .172 0 r
.30671 .62343 m
.30649 .62351 L
s
.30661 .62172 m
.30671 .62343 L
s
.30671 .62343 m
.30549 .62264 L
s
.30761 .6226 m
.30671 .62343 L
s
.30591 .61934 m
.30671 .62343 L
s
1 .59 0 r
.63401 .55817 m
.63777 .56111 L
s
.63046 .56124 m
.63401 .55817 L
s
.63401 .55817 m
.63414 .55826 L
s
1 .168 0 r
.41508 .22886 m
.4138 .2301 L
s
.4133 .2287 m
.41508 .22886 L
s
.4138 .2301 m
.4133 .2287 L
s
1 0 0 r
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
.1504 .47155 m
.1504 .47155 L
s
1 .051 0 r
.87684 .65363 m
.87731 .65244 L
s
1 .825 0 r
.63469 .59294 m
.63485 .57278 L
s
1 0 0 r
.69747 .4412 m
.69747 .4412 L
s
1 .047 0 r
.45532 .38051 m
.45709 .3799 L
s
1 .233 0 r
.5181 .22877 m
.52819 .22854 L
s
1 .012 0 r
.21318 .31981 m
.21337 .31952 L
s
1 .095 0 r
.69643 .25977 m
.6968 .25903 L
s
1 .168 0 r
.63237 .22862 m
.63287 .22875 L
s
.63281 .22721 m
.63237 .22862 L
s
.63414 .22839 m
.63237 .22862 L
s
1 .012 0 r
.21333 .31952 m
.2134 .3196 L
s
.21326 .31955 m
.21333 .31952 L
s
.21333 .31952 m
.21337 .31952 L
s
.2134 .3196 m
.21332 .31963 L
s
.21337 .31952 m
.2134 .3196 L
s
1 .233 0 r
.52819 .22854 m
.52617 .22966 L
s
.52612 .22761 m
.52819 .22854 L
s
1 .012 0 r
.21332 .31963 m
.21326 .31955 L
s
.21326 .31955 m
.21337 .31952 L
s
1 .168 0 r
.63331 .22734 m
.63281 .22721 L
s
.63281 .22721 m
.63414 .22839 L
s
1 .012 0 r
.21337 .31952 m
.21332 .31963 L
s
1 .172 0 r
.30661 .62172 m
.30549 .62264 L
s
.30761 .6226 m
.30661 .62172 L
s
1 .047 0 r
.45688 .38018 m
.45673 .38024 L
s
.45674 .37979 m
.45688 .38018 L
s
.45709 .3799 m
.45688 .38018 L
s
1 .168 0 r
.63414 .22839 m
.63287 .22875 L
s
.63331 .22734 m
.63414 .22839 L
s
.62764 .22632 m
.63414 .22839 L
s
1 .047 0 r
.45659 .37986 m
.45674 .37979 L
s
.45674 .37979 m
.45709 .3799 L
s
1 .136 0 r
.43221 .50156 m
.43283 .50167 L
s
.43287 .50031 m
.43221 .50156 L
s
.43221 .50156 m
.43215 .50071 L
s
.43355 .50127 m
.43221 .50156 L
s
.43543 .49872 m
.43221 .50156 L
s
.43287 .50031 m
.43215 .50071 L
s
.43355 .50127 m
.43287 .50031 L
s
1 .047 0 r
.45709 .3799 m
.45673 .38024 L
s
.45659 .37986 m
.45709 .3799 L
s
.45673 .38024 m
.45659 .37986 L
s
1 .136 0 r
.43283 .50167 m
.43355 .50127 L
s
0 .813 1 r
.66993 .56195 m
.64571 .58566 L
s
.63643 .55957 m
.66993 .56195 L
s
1 .172 0 r
.30549 .62264 m
.30649 .62351 L
s
.30649 .62351 m
.30761 .6226 L
s
1 .013 0 r
.32593 .50115 m
.32596 .50115 L
s
.32596 .50102 m
.32593 .50115 L
s
.32593 .50115 m
.32588 .50107 L
s
.32604 .5011 m
.32593 .50115 L
s
.32606 .50084 m
.32593 .50115 L
s
.32596 .50102 m
.32588 .50107 L
s
.32604 .5011 m
.32596 .50102 L
s
1 .233 0 r
.52617 .22966 m
.52612 .22761 L
s
1 .013 0 r
.32596 .50115 m
.32604 .5011 L
s
.32588 .50107 m
.32596 .50115 L
s
1 .168 0 r
.76839 .65159 m
.76947 .65255 L
s
.76744 .65238 m
.76839 .65159 L
s
.76839 .65159 m
.76879 .65169 L
s
1 .051 0 r
.87718 .65241 m
.87753 .65269 L
s
.8769 .65266 m
.87718 .65241 L
s
.87718 .65241 m
.87731 .65244 L
s
1 .045 0 r
.19691 .62239 m
.19683 .62241 L
s
.19688 .62194 m
.19691 .62239 L
s
.19691 .62239 m
.19658 .62218 L
s
.19714 .62217 m
.19691 .62239 L
s
.19663 .62132 m
.19691 .62239 L
s
1 .005 0 r
.63133 .40984 m
.6313 .40984 L
s
.6313 .40979 m
.63133 .40984 L
s
.63133 .40984 m
.63128 .40983 L
s
.63132 .4098 m
.63133 .40984 L
s
.63117 .40974 m
.63133 .40984 L
s
.6313 .40979 m
.63128 .40983 L
s
.63132 .4098 m
.6313 .40979 L
s
.63128 .40983 m
.6313 .40984 L
s
.6313 .40984 m
.63132 .4098 L
s
1 .051 0 r
.87753 .65269 m
.87724 .65295 L
s
.87731 .65244 m
.87753 .65269 L
s
1 .073 0 r
.81065 .6223 m
.81109 .62056 L
s
1 0 0 r
.87346 .47047 m
.87346 .47047 L
s
0 .813 1 r
.56835 .56157 m
.50164 .48956 L
s
1 .043 0 r
.38887 .34901 m
.39019 .3482 L
s
1 0 0 r
.08376 .44011 m
.08376 .44011 L
s
1 .011 0 r
.14658 .28828 m
.14674 .28799 L
s
1 0 0 r
.87346 .47047 m
.87346 .47047 L
s
.87346 .47047 m
.87346 .47047 L
s
.87346 .47047 m
.87346 .47047 L
s
.87346 .47047 m
.87346 .47047 L
s
.87346 .47047 m
.87346 .47047 L
s
.87346 .47047 m
.87346 .47047 L
s
.87346 .47047 m
.87346 .47047 L
s
.87346 .47047 m
.87346 .47047 L
s
1 .051 0 r
.87724 .65295 m
.8769 .65266 L
s
.8769 .65266 m
.87731 .65244 L
s
1 .045 0 r
.19688 .62194 m
.19658 .62218 L
s
.19714 .62217 m
.19688 .62194 L
s
1 .168 0 r
.63287 .22875 m
.63331 .22734 L
s
1 .051 0 r
.87731 .65244 m
.87724 .65295 L
s
1 .168 0 r
.76947 .65255 m
.76852 .65334 L
s
.76879 .65169 m
.76947 .65255 L
s
1 .045 0 r
.19658 .62218 m
.19683 .62241 L
s
1 .136 0 r
.43215 .50071 m
.43283 .50167 L
s
1 .045 0 r
.19683 .62241 m
.19714 .62217 L
s
1 .011 0 r
.14671 .28799 m
.14677 .28807 L
s
.14664 .28802 m
.14671 .28799 L
s
.14671 .28799 m
.14674 .28799 L
s
.14677 .28807 m
.1467 .2881 L
s
.14674 .28799 m
.14677 .28807 L
s
.1467 .2881 m
.14664 .28802 L
s
.14664 .28802 m
.14674 .28799 L
s
.14674 .28799 m
.1467 .2881 L
s
1 .168 0 r
.76852 .65334 m
.76744 .65238 L
s
.76744 .65238 m
.76879 .65169 L
s
1 .59 0 r
.63421 .56418 m
.63046 .56124 L
s
.63046 .56124 m
.63414 .55826 L
s
0 .813 1 r
.64571 .58566 m
.63643 .55957 L
s
1 .59 0 r
.63777 .56111 m
.63421 .56418 L
s
.63414 .55826 m
.63777 .56111 L
s
1 .043 0 r
.39012 .34849 m
.38992 .34857 L
s
.38994 .34816 m
.39012 .34849 L
s
.39019 .3482 m
.39012 .34849 L
s
.38974 .34823 m
.38994 .34816 L
s
.38994 .34816 m
.39019 .3482 L
s
1 .058 0 r
.56661 .37882 m
.56672 .37889 L
s
.56671 .37832 m
.56661 .37882 L
s
.5672 .3787 m
.56661 .37882 L
s
1 .229 0 r
.34843 .59142 m
.34843 .5915 L
s
.34855 .58915 m
.34843 .59142 L
s
.34843 .59142 m
.34707 .59025 L
s
.34991 .59039 m
.34843 .59142 L
s
.34874 .5859 m
.34843 .59142 L
s
1 .058 0 r
.56682 .37839 m
.56671 .37832 L
s
.56671 .37832 m
.5672 .3787 L
s
.5672 .3787 m
.56672 .37889 L
s
.56682 .37839 m
.5672 .3787 L
s
.56479 .37824 m
.5672 .3787 L
s
1 .168 0 r
.76879 .65169 m
.76852 .65334 L
s
1 .043 0 r
.38992 .34857 m
.38974 .34823 L
s
.39019 .3482 m
.38992 .34857 L
s
.38974 .34823 m
.39019 .3482 L
s
1 .058 0 r
.56672 .37889 m
.56682 .37839 L
s
1 .001 0 r
.25948 .46941 m
.25948 .46941 L
s
.25948 .4694 m
.25948 .46941 L
s
.25948 .46941 m
.25948 .4694 L
s
.25949 .46941 m
.25948 .46941 L
s
.25949 .46939 m
.25948 .46941 L
s
.25948 .4694 m
.25948 .4694 L
s
.25949 .46941 m
.25948 .4694 L
s
.25948 .46941 m
.25949 .46941 L
s
.25948 .4694 m
.25948 .46941 L
s
1 .116 0 r
.74437 .59093 m
.74458 .58813 L
s
1 0 0 r
.80723 .43901 m
.80723 .43901 L
s
1 .035 0 r
.32234 .31747 m
.32323 .31671 L
s
1 .229 0 r
.34855 .58915 m
.34707 .59025 L
s
.34991 .59039 m
.34855 .58915 L
s
1 .073 0 r
.81097 .62053 m
.81145 .62092 L
s
.81055 .6209 m
.81097 .62053 L
s
.81097 .62053 m
.81109 .62056 L
s
1 .038 0 r
.80465 .25637 m
.8045 .25637 L
s
.80447 .25603 m
.80465 .25637 L
s
.80465 .25637 m
.80428 .25629 L
s
.80468 .25611 m
.80465 .25637 L
s
.80381 .2555 m
.80465 .25637 L
s
.80447 .25603 m
.80428 .25629 L
s
.80468 .25611 m
.80447 .25603 L
s
.80428 .25629 m
.8045 .25637 L
s
1 .073 0 r
.81145 .62092 m
.81104 .62129 L
s
.81109 .62056 m
.81145 .62092 L
s
.81104 .62129 m
.81055 .6209 L
s
.81055 .6209 m
.81109 .62056 L
s
1 .035 0 r
.32306 .3167 m
.32323 .31696 L
s
.32288 .31678 m
.32306 .3167 L
s
.32306 .3167 m
.32323 .31671 L
s
.32323 .31696 m
.32304 .31703 L
s
.32323 .31671 m
.32323 .31696 L
s
1 .038 0 r
.8045 .25637 m
.80468 .25611 L
s
1 .229 0 r
.34843 .5915 m
.34991 .59039 L
s
1 .035 0 r
.32304 .31703 m
.32288 .31678 L
s
.32288 .31678 m
.32323 .31671 L
s
1 .073 0 r
.81109 .62056 m
.81104 .62129 L
s
1 .035 0 r
.32323 .31671 m
.32304 .31703 L
s
1 .014 0 r
.13001 .59027 m
.12999 .59028 L
s
.13001 .59013 m
.13001 .59027 L
s
.13001 .59027 m
.12991 .5902 L
s
.13009 .59021 m
.13001 .59027 L
s
.12994 .58993 m
.13001 .59027 L
s
1 .229 0 r
.34707 .59025 m
.34843 .5915 L
s
1 .08 0 r
.73981 .22548 m
.73936 .22553 L
s
.73931 .22479 m
.73981 .22548 L
s
.73981 .22548 m
.73897 .22541 L
s
.7397 .22491 m
.73981 .22548 L
s
.73745 .22386 m
.73981 .22548 L
s
1 .014 0 r
.13001 .59013 m
.12991 .5902 L
s
.13009 .59021 m
.13001 .59013 L
s
.12999 .59028 m
.13009 .59021 L
s
.12991 .5902 m
.12999 .59028 L
s
1 .08 0 r
.73931 .22479 m
.73897 .22541 L
s
.7397 .22491 m
.73931 .22479 L
s
.73897 .22541 m
.73936 .22553 L
s
1 .59 0 r
.63414 .55826 m
.63421 .56418 L
s
1 .001 0 r
.74093 .40753 m
.74093 .40753 L
s
.74093 .40752 m
.74093 .40753 L
s
.74093 .40753 m
.74092 .40753 L
s
.74093 .40752 m
.74093 .40753 L
s
.74091 .40751 m
.74093 .40753 L
s
.74093 .40752 m
.74092 .40753 L
s
.74093 .40752 m
.74093 .40752 L
s
.74092 .40753 m
.74093 .40753 L
s
.74093 .40753 m
.74093 .40752 L
s
1 .303 0 r
.38856 .55953 m
.38912 .55964 L
s
.38925 .55655 m
.38856 .55953 L
s
.38856 .55953 m
.38736 .55779 L
s
.39101 .5584 m
.38856 .55953 L
s
.39173 .55233 m
.38856 .55953 L
s
1 .111 0 r
.50223 .34671 m
.5021 .3468 L
s
.50211 .34575 m
.50223 .34671 L
s
.50305 .34617 m
.50223 .34671 L
s
1 .023 0 r
.92061 .62033 m
.92077 .61977 L
s
1 .215 0 r
.67802 .55952 m
.67687 .55428 L
s
1 .111 0 r
.49832 .3467 m
.50305 .34617 L
s
1 0 0 r
.19284 .43791 m
.19284 .43791 L
s
1 .028 0 r
.25573 .2859 m
.25634 .28523 L
s
1 .111 0 r
.50198 .34584 m
.50211 .34575 L
s
.50211 .34575 m
.50305 .34617 L
s
1 .08 0 r
.73936 .22553 m
.7397 .22491 L
s
1 .028 0 r
.25623 .28523 m
.25637 .28543 L
s
.25607 .2853 m
.25623 .28523 L
s
.25623 .28523 m
.25634 .28523 L
s
.25637 .28543 m
.25621 .2855 L
s
.25634 .28523 m
.25637 .28543 L
s
1 .023 0 r
.92072 .61976 m
.92088 .61989 L
s
.92059 .61988 m
.92072 .61976 L
s
.92072 .61976 m
.92077 .61977 L
s
.92088 .61989 m
.92075 .62001 L
s
.92077 .61977 m
.92088 .61989 L
s
.92075 .62001 m
.92059 .61988 L
s
.92059 .61988 m
.92077 .61977 L
s
1 .111 0 r
.50305 .34617 m
.5021 .3468 L
s
.50198 .34584 m
.50305 .34617 L
s
1 .028 0 r
.25621 .2855 m
.25607 .2853 L
s
.25607 .2853 m
.25634 .28523 L
s
1 .023 0 r
.92077 .61977 m
.92075 .62001 L
s
1 .028 0 r
.25634 .28523 m
.25621 .2855 L
s
1 .303 0 r
.38925 .55655 m
.38736 .55779 L
s
.39101 .5584 m
.38925 .55655 L
s
1 .111 0 r
.5021 .3468 m
.50198 .34584 L
s
1 .014 0 r
.67491 .37626 m
.67483 .37627 L
s
.67483 .37613 m
.67491 .37626 L
s
.67491 .37626 m
.67476 .37624 L
s
.6749 .37616 m
.67491 .37626 L
s
.67452 .37597 m
.67491 .37626 L
s
.425 1 0 r
.5424 .48583 m
.55108 .49093 L
s
.53382 .49644 m
.5424 .48583 L
s
.5424 .48583 m
.53596 .48653 L
s
1 .014 0 r
.67483 .37613 m
.67476 .37624 L
s
.6749 .37616 m
.67483 .37613 L
s
.67476 .37624 m
.67483 .37627 L
s
.67483 .37627 m
.6749 .37616 L
s
1 .047 0 r
.23931 .58905 m
.23927 .58906 L
s
.23931 .58858 m
.23931 .58905 L
s
.23931 .58905 m
.239 .58882 L
s
.23958 .58883 m
.23931 .58905 L
s
.23921 .58792 m
.23931 .58905 L
s
1 .003 0 r
.36878 .46731 m
.3688 .46731 L
s
.3688 .46728 m
.36878 .46731 L
s
.36878 .46731 m
.36878 .46729 L
s
.36881 .4673 m
.36878 .46731 L
s
.36884 .46724 m
.36878 .46731 L
s
.3688 .46728 m
.36878 .46729 L
s
.36881 .4673 m
.3688 .46728 L
s
1 .116 0 r
.7445 .58809 m
.74526 .58868 L
s
.74382 .5887 m
.7445 .58809 L
s
.7445 .58809 m
.74458 .58813 L
s
1 .003 0 r
.3688 .46731 m
.36881 .4673 L
s
.36878 .46729 m
.3688 .46731 L
s
1 .047 0 r
.23931 .58858 m
.239 .58882 L
s
.23958 .58883 m
.23931 .58858 L
s
1 .028 0 r
.85432 .58892 m
.85442 .58824 L
s
1 .481 0 r
.61158 .52808 m
.60212 .51736 L
s
1 .1 0 r
.43178 .31513 m
.43551 .31378 L
s
1 0 0 r
.1261 .40639 m
.1261 .40639 L
s
1 .023 0 r
.18904 .25428 m
.18947 .2537 L
s
1 0 0 r
.1261 .40639 m
.1261 .40639 L
s
.1261 .40639 m
.1261 .40639 L
s
.1261 .40639 m
.1261 .40639 L
s
.1261 .40639 m
.1261 .40639 L
s
.1261 .40639 m
.1261 .40639 L
s
.1261 .40639 m
.1261 .40639 L
s
.1261 .40639 m
.1261 .40639 L
s
.1261 .40639 m
.1261 .40639 L
s
1 .047 0 r
.23927 .58906 m
.23958 .58883 L
s
1 .303 0 r
.38912 .55964 m
.39101 .5584 L
s
1 .047 0 r
.239 .58882 m
.23927 .58906 L
s
1 .07 0 r
.60994 .34537 m
.61016 .34546 L
s
.61015 .34479 m
.60994 .34537 L
s
.61068 .34531 m
.60994 .34537 L
s
.61037 .34488 m
.61015 .34479 L
s
.61015 .34479 m
.61068 .34531 L
s
.808 1 0 r
.63896 .65809 m
.63287 .64957 L
s
.63287 .64957 m
.64502 .64728 L
s
1 .07 0 r
.61068 .34531 m
.61016 .34546 L
s
.61037 .34488 m
.61068 .34531 L
s
.60804 .34439 m
.61068 .34531 L
s
1 .116 0 r
.74458 .58928 m
.74382 .5887 L
s
.74382 .5887 m
.74458 .58813 L
s
.74526 .58868 m
.74458 .58928 L
s
.74458 .58813 m
.74526 .58868 L
s
1 .023 0 r
.1894 .25371 m
.18952 .25387 L
s
.18925 .25377 m
.1894 .25371 L
s
.1894 .25371 m
.18947 .2537 L
s
.18952 .25387 m
.18937 .25393 L
s
.18947 .2537 m
.18952 .25387 L
s
.285 1 0 r
.60878 .54493 m
.61912 .55539 L
s
.59886 .55191 m
.60878 .54493 L
s
.60878 .54493 m
.61368 .54544 L
s
1 .323 0 r
.70256 .61647 m
.70463 .61825 L
s
.70066 .61804 m
.70256 .61647 L
s
.70256 .61647 m
.70307 .61661 L
s
1 .023 0 r
.18937 .25393 m
.18925 .25377 L
s
.18925 .25377 m
.18947 .2537 L
s
.18947 .2537 m
.18937 .25393 L
s
1 .028 0 r
.85439 .58823 m
.85458 .58837 L
s
.85423 .58838 m
.85439 .58823 L
s
.85439 .58823 m
.85442 .58824 L
s
1 .116 0 r
.74458 .58813 m
.74458 .58928 L
s
1 .028 0 r
.85442 .58852 m
.85423 .58838 L
s
.85423 .58838 m
.85442 .58824 L
s
1 .07 0 r
.61016 .34546 m
.61037 .34488 L
s
1 .028 0 r
.85458 .58837 m
.85442 .58852 L
s
.85442 .58824 m
.85458 .58837 L
s
1 .1 0 r
.43508 .31441 m
.43475 .31452 L
s
.43478 .31358 m
.43508 .31441 L
s
.43551 .31378 m
.43508 .31441 L
s
1 .028 0 r
.85442 .58824 m
.85442 .58852 L
s
1 .1 0 r
.43445 .3137 m
.43478 .31358 L
s
.43478 .31358 m
.43551 .31378 L
s
1 .303 0 r
.38736 .55779 m
.38912 .55964 L
s
.808 1 0 r
.64502 .64728 m
.63896 .65809 L
s
1 0 0 r
.85093 .40528 m
.85093 .40528 L
s
.85093 .40528 m
.85093 .40528 L
s
.85093 .40528 m
.85093 .40528 L
s
.85093 .40528 m
.85093 .40528 L
s
.85093 .40527 m
.85093 .40528 L
s
.85093 .40528 m
.85093 .40528 L
s
.85093 .40528 m
.85093 .40528 L
s
.85093 .40528 m
.85093 .40528 L
s
.85093 .40528 m
.85093 .40528 L
s
1 .035 0 r
.78796 .55747 m
.78792 .55662 L
s
1 .606 0 r
.54507 .49659 m
.51983 .49215 L
s
1 0 0 r
.30218 .43571 m
.30218 .43571 L
s
1 .075 0 r
.36515 .28351 m
.36752 .28214 L
s
1 0 0 r
.05929 .37483 m
.05929 .37482 L
s
.05929 .37482 m
.05929 .37482 L
s
.05929 .37482 m
.05929 .37482 L
s
.05929 .37482 m
.05929 .37482 L
s
.05929 .37482 m
.05929 .37483 L
s
.05929 .37482 m
.05929 .37482 L
s
.05929 .37483 m
.05929 .37482 L
s
.05929 .37482 m
.05929 .37482 L
s
.05929 .37482 m
.05929 .37483 L
s
1 .323 0 r
.70463 .61825 m
.70273 .61982 L
s
.70307 .61661 m
.70463 .61825 L
s
.425 1 0 r
.54248 .50159 m
.53382 .49644 L
s
.53382 .49644 m
.53596 .48653 L
s
1 .1 0 r
.43551 .31378 m
.43475 .31452 L
s
.43445 .3137 m
.43551 .31378 L
s
.43475 .31452 m
.43445 .3137 L
s
1 .141 0 r
.54627 .31364 m
.54636 .31374 L
s
.54635 .3124 m
.54627 .31364 L
s
.54757 .31314 m
.54627 .31364 L
s
1 .323 0 r
.70273 .61982 m
.70066 .61804 L
s
.70066 .61804 m
.70307 .61661 L
s
1 .141 0 r
.54644 .3125 m
.54635 .3124 L
s
.54635 .3124 m
.54757 .31314 L
s
1 .035 0 r
.78791 .55661 m
.78814 .55677 L
s
.78771 .5568 m
.78791 .55661 L
s
.78791 .55661 m
.78792 .55662 L
s
1 .032 0 r
.4775 .46555 m
.4776 .46549 L
s
.4776 .46549 m
.47751 .46523 L
s
.4776 .46549 m
.47727 .46547 L
s
.47751 .46523 m
.47741 .46528 L
s
.47751 .46523 m
.47727 .46547 L
s
.47727 .46547 m
.4775 .46555 L
s
.47727 .46547 m
.47741 .46528 L
s
.47847 .46507 m
.47727 .46547 L
s
1 .035 0 r
.78794 .55697 m
.78771 .5568 L
s
.78771 .5568 m
.78792 .55662 L
s
.78814 .55677 m
.78794 .55697 L
s
.78792 .55662 m
.78814 .55677 L
s
1 .141 0 r
.54757 .31314 m
.54636 .31374 L
s
.54644 .3125 m
.54757 .31314 L
s
.54148 .31278 m
.54757 .31314 L
s
1 .012 0 r
.17243 .55674 m
.17242 .55674 L
s
.17244 .55662 m
.17243 .55674 L
s
.17243 .55674 m
.17236 .55668 L
s
.17251 .55668 m
.17243 .55674 L
s
.17242 .55645 m
.17243 .55674 L
s
1 .075 0 r
.36736 .28265 m
.36703 .28276 L
s
.36707 .28207 m
.36736 .28265 L
s
.36752 .28214 m
.36736 .28265 L
s
.36673 .28218 m
.36707 .28207 L
s
.36707 .28207 m
.36752 .28214 L
s
1 .012 0 r
.17244 .55662 m
.17236 .55668 L
s
.17251 .55668 m
.17244 .55662 L
s
1 .035 0 r
.78792 .55662 m
.78794 .55697 L
s
1 .012 0 r
.17242 .55674 m
.17251 .55668 L
s
.17236 .55668 m
.17242 .55674 L
s
1 .032 0 r
.47741 .46528 m
.4775 .46555 L
s
1 .003 0 r
.78457 .37377 m
.78456 .37377 L
s
.78456 .37374 m
.78457 .37377 L
s
.78457 .37377 m
.78454 .37376 L
s
.78458 .37375 m
.78457 .37377 L
s
.78452 .37369 m
.78457 .37377 L
s
.78456 .37374 m
.78454 .37376 L
s
.78458 .37375 m
.78456 .37374 L
s
.78454 .37376 m
.78456 .37377 L
s
.78456 .37377 m
.78458 .37375 L
s
1 .043 0 r
.72151 .52599 m
.72116 .52493 L
s
1 .055 0 r
.29844 .25186 m
.29995 .25067 L
s
1 0 0 r
.23543 .40415 m
.23543 .40415 L
s
.23543 .40415 m
.23544 .40415 L
s
.23543 .40415 m
.23543 .40415 L
s
.23543 .40415 m
.23543 .40415 L
s
.23544 .40415 m
.23543 .40415 L
s
.23543 .40415 m
.23544 .40415 L
s
.23543 .40415 m
.23543 .40415 L
s
.23543 .40415 m
.23543 .40415 L
s
.23543 .40415 m
.23543 .40415 L
s
1 .323 0 r
.70307 .61661 m
.70273 .61982 L
s
1 .141 0 r
.54636 .31374 m
.54644 .3125 L
s
1 .075 0 r
.36703 .28276 m
.36673 .28218 L
s
.36752 .28214 m
.36703 .28276 L
s
.36673 .28218 m
.36752 .28214 L
s
1 .344 0 r
.42667 .52579 m
.42825 .5261 L
s
.42836 .52262 m
.42667 .52579 L
s
.42667 .52579 m
.42651 .52365 L
s
.4301 .52508 m
.42667 .52579 L
s
.43487 .51864 m
.42667 .52579 L
s
1 .606 0 r
.52489 .49608 m
.52382 .49518 L
s
.52382 .49518 m
.52489 .49001 L
s
.52382 .49518 m
.51983 .49215 L
s
1 .215 0 r
.67705 .55423 m
.67843 .5552 L
s
.67578 .55546 m
.67705 .55423 L
s
.67705 .55423 m
.67687 .55428 L
s
1 .02 0 r
.71853 .3425 m
.71843 .34251 L
s
.71842 .34232 m
.71853 .3425 L
s
.71853 .3425 m
.71833 .34247 L
s
.71853 .34236 m
.71853 .3425 L
s
.71802 .34208 m
.71853 .3425 L
s
1 .055 0 r
.29967 .25065 m
.29992 .25107 L
s
.29938 .25075 m
.29967 .25065 L
s
.29967 .25065 m
.29995 .25067 L
s
0 .197 1 r
.3742 .61482 m
.38562 .646 L
s
1 .055 0 r
.29992 .25107 m
.29963 .25117 L
s
.29995 .25067 m
.29992 .25107 L
s
1 .02 0 r
.71842 .34232 m
.71833 .34247 L
s
.71853 .34236 m
.71842 .34232 L
s
.71833 .34247 m
.71843 .34251 L
s
1 .344 0 r
.42836 .52262 m
.42651 .52365 L
s
.4301 .52508 m
.42836 .52262 L
s
1 .043 0 r
.72122 .52493 m
.72149 .52511 L
s
.72097 .52518 m
.72122 .52493 L
s
.72122 .52493 m
.72116 .52493 L
s
1 .02 0 r
.71843 .34251 m
.71853 .34236 L
s
1 .043 0 r
.72124 .52536 m
.72097 .52518 L
s
.72097 .52518 m
.72116 .52493 L
s
1 .606 0 r
.52489 .49001 m
.52596 .4909 L
s
.52489 .49001 m
.51983 .49215 L
s
1 .043 0 r
.72149 .52511 m
.72124 .52536 L
s
.72116 .52493 m
.72149 .52511 L
s
1 .344 0 r
.42825 .5261 m
.4301 .52508 L
s
1 .046 0 r
.28181 .55551 m
.28182 .55552 L
s
.28185 .55506 m
.28181 .55551 L
s
.28181 .55551 m
.28155 .55526 L
s
.28212 .55531 m
.28181 .55551 L
s
.28194 .55439 m
.28181 .55551 L
s
1 .055 0 r
.29963 .25117 m
.29938 .25075 L
s
.29938 .25075 m
.29995 .25067 L
s
1 .043 0 r
.72116 .52493 m
.72124 .52536 L
s
1 .055 0 r
.29995 .25067 m
.29963 .25117 L
s
1 .003 0 r
.10555 .52501 m
.10555 .52501 L
s
.10556 .52498 m
.10555 .52501 L
s
.10555 .52501 m
.10554 .52499 L
s
.10557 .525 m
.10555 .52501 L
s
.10555 .52494 m
.10555 .52501 L
s
.10556 .52498 m
.10554 .52499 L
s
.10557 .525 m
.10556 .52498 L
s
.10555 .52501 m
.10557 .525 L
s
.10554 .52499 m
.10555 .52501 L
s
1 .215 0 r
.67715 .55643 m
.67578 .55546 L
s
.67578 .55546 m
.67687 .55428 L
s
1 .01 0 r
.89816 .55542 m
.89818 .55518 L
s
0 1 .511 r
.59193 .64685 m
.62663 .58832 L
s
1 .047 0 r
.65498 .49447 m
.65408 .4934 L
s
1 0 0 r
.41179 .43351 m
.41179 .43351 L
s
1 .151 0 r
.47484 .28112 m
.48115 .28004 L
s
1 .001 0 r
.1686 .37255 m
.16861 .37253 L
s
1 .043 0 r
.23165 .22017 m
.23265 .21917 L
s
1 .046 0 r
.28185 .55506 m
.28155 .55526 L
s
.28212 .55531 m
.28185 .55506 L
s
1 .001 0 r
.16861 .37253 m
.16862 .37253 L
s
.1686 .37253 m
.16861 .37253 L
s
.16861 .37253 m
.16861 .37253 L
s
.16862 .37253 m
.16861 .37254 L
s
.16861 .37253 m
.16862 .37253 L
s
.16861 .37254 m
.1686 .37253 L
s
.1686 .37253 m
.16861 .37253 L
s
.16861 .37253 m
.16861 .37254 L
s
.285 1 0 r
.61912 .55539 m
.60923 .56242 L
s
.61368 .54544 m
.61912 .55539 L
s
1 .068 0 r
.65307 .31153 m
.65334 .31163 L
s
.65331 .31099 m
.65307 .31153 L
s
.65379 .31153 m
.65307 .31153 L
s
.65379 .31153 m
.65334 .31163 L
s
.65331 .31099 m
.65379 .31153 L
s
.65358 .31108 m
.65379 .31153 L
s
.65145 .31042 m
.65379 .31153 L
s
.65358 .31108 m
.65331 .31099 L
s
1 .046 0 r
.28182 .55552 m
.28212 .55531 L
s
.28155 .55526 m
.28182 .55552 L
s
1 .01 0 r
.89817 .55518 m
.89824 .55523 L
s
.89812 .55523 m
.89817 .55518 L
s
.89817 .55518 m
.89818 .55518 L
s
.89818 .55528 m
.89812 .55523 L
s
.89812 .55523 m
.89818 .55518 L
s
.89824 .55523 m
.89818 .55528 L
s
.89818 .55518 m
.89824 .55523 L
s
.89818 .55518 m
.89818 .55528 L
s
1 .215 0 r
.67843 .5552 m
.67715 .55643 L
s
.67687 .55428 m
.67843 .5552 L
s
1 .151 0 r
.48013 .28086 m
.47988 .28096 L
s
.4799 .27955 m
.48013 .28086 L
s
.48115 .28004 m
.48013 .28086 L
s
.47964 .27965 m
.4799 .27955 L
s
.4799 .27955 m
.48115 .28004 L
s
1 .068 0 r
.65334 .31163 m
.65358 .31108 L
s
0 .197 1 r
.67625 .61594 m
.66684 .62438 L
s
.66516 .58472 m
.67625 .61594 L
s
.6962 .5956 m
.67625 .61594 L
s
1 .043 0 r
.23247 .21918 m
.23268 .21948 L
s
.23223 .21926 m
.23247 .21918 L
s
.23247 .21918 m
.23265 .21917 L
s
.23268 .21948 m
.23243 .21957 L
s
.23265 .21917 m
.23268 .21948 L
s
1 .215 0 r
.67687 .55428 m
.67715 .55643 L
s
1 .047 0 r
.65425 .49338 m
.65452 .49353 L
s
.654 .4937 m
.65425 .49338 L
s
.65425 .49338 m
.65408 .4934 L
s
.65427 .49385 m
.654 .4937 L
s
.654 .4937 m
.65408 .4934 L
s
1 .043 0 r
.23243 .21957 m
.23223 .21926 L
s
.23223 .21926 m
.23265 .21917 L
s
.23265 .21917 m
.23243 .21957 L
s
1 .137 0 r
.58909 .28018 m
.58936 .28027 L
s
.58934 .27899 m
.58909 .28018 L
s
.59049 .27986 m
.58909 .28018 L
s
1 .741 0 r
.66599 .64033 m
.67051 .64493 L
s
.6618 .64351 m
.66599 .64033 L
s
.66599 .64033 m
.66829 .64087 L
s
1 .047 0 r
.65452 .49353 m
.65427 .49385 L
s
.65408 .4934 m
.65452 .49353 L
s
1 .137 0 r
.58961 .27909 m
.58934 .27899 L
s
.58934 .27899 m
.59049 .27986 L
s
1 .151 0 r
.48115 .28004 m
.47988 .28096 L
s
.47964 .27965 m
.48115 .28004 L
s
1 .047 0 r
.65408 .4934 m
.65427 .49385 L
s
1 .009 0 r
.8317 .5239 m
.83167 .52368 L
s
1 0 0 r
.01 w
.52528 .61538 Mdot
1 .021 0 r
.5 Mabswid
.58836 .4629 m
.58764 .46259 L
s
1 .001 0 r
.34503 .40191 m
.34506 .40188 L
s
1 .121 0 r
.40811 .24943 m
.41266 .24773 L
s
1 .002 0 r
.10169 .34092 m
.10171 .34086 L
s
1 .001 0 r
.34505 .40188 m
.34506 .40189 L
s
.34504 .40188 m
.34505 .40188 L
s
.34505 .40188 m
.34506 .40188 L
s
.34506 .40189 m
.34505 .40189 L
s
.34506 .40188 m
.34506 .40189 L
s
.34505 .40189 m
.34504 .40188 L
s
.34504 .40188 m
.34506 .40188 L
s
.34506 .40188 m
.34505 .40189 L
s
1 .002 0 r
.10171 .34087 m
.10172 .34088 L
s
.10169 .34087 m
.10171 .34087 L
s
.10171 .34087 m
.10171 .34086 L
s
.10172 .34088 m
.1017 .34088 L
s
.10171 .34086 m
.10172 .34088 L
s
.1017 .34088 m
.10169 .34087 L
s
.10169 .34087 m
.10171 .34086 L
s
.10171 .34086 m
.1017 .34088 L
s
1 .137 0 r
.59049 .27986 m
.58936 .28027 L
s
.58961 .27909 m
.59049 .27986 L
s
.58479 .27873 m
.59049 .27986 L
s
1 .151 0 r
.47988 .28096 m
.47964 .27965 L
s
1 .009 0 r
.83168 .52368 m
.83173 .52372 L
s
.83163 .52373 m
.83168 .52368 L
s
.83168 .52368 m
.83167 .52368 L
s
.83168 .52377 m
.83163 .52373 L
s
.83163 .52373 m
.83167 .52368 L
s
.83173 .52372 m
.83168 .52377 L
s
.83167 .52368 m
.83173 .52372 L
s
1 .021 0 r
.58778 .46276 m
.58771 .46272 L
s
.58771 .46272 m
.58778 .46255 L
s
.58771 .46272 m
.58764 .46259 L
s
.58778 .46255 m
.58786 .46259 L
s
.58778 .46255 m
.58764 .46259 L
s
1 .009 0 r
.83167 .52368 m
.83168 .52377 L
s
1 .344 0 r
.42651 .52365 m
.42825 .5261 L
s
1 .021 0 r
.58786 .46259 m
.58778 .46276 L
s
.58764 .46259 m
.58778 .46276 L
s
.58764 .46259 m
.58786 .46259 L
s
1 .233 0 r
.30565 .64551 m
.30535 .64564 L
s
.30551 .64319 m
.30565 .64551 L
s
.30565 .64551 m
.30399 .64444 L
s
.30688 .64439 m
.30565 .64551 L
s
.30456 .64002 m
.30565 .64551 L
s
1 .137 0 r
.58936 .28027 m
.58961 .27909 L
s
1 .121 0 r
.41213 .24852 m
.41173 .24863 L
s
.41177 .24751 m
.41213 .24852 L
s
.41266 .24773 m
.41213 .24852 L
s
1 .008 0 r
.21503 .52305 m
.21503 .52305 L
s
.21504 .52297 m
.21503 .52305 L
s
.21503 .52305 m
.21498 .52301 L
s
.21509 .52302 m
.21503 .52305 L
s
.21506 .52285 m
.21503 .52305 L
s
1 .121 0 r
.41136 .24762 m
.41177 .24751 L
s
.41177 .24751 m
.41266 .24773 L
s
1 .008 0 r
.21504 .52297 m
.21498 .52301 L
s
.21509 .52302 m
.21504 .52297 L
s
.21503 .52305 m
.21509 .52302 L
s
.21498 .52301 m
.21503 .52305 L
s
1 .006 0 r
.82838 .3399 m
.82836 .3399 L
s
.82836 .33984 m
.82838 .3399 L
s
.82838 .3399 m
.82833 .33988 L
s
.82839 .33986 m
.82838 .3399 L
s
.82828 .33976 m
.82838 .3399 L
s
.82836 .33984 m
.82833 .33988 L
s
.82839 .33986 m
.82836 .33984 L
s
.82833 .33988 m
.82836 .3399 L
s
.82836 .3399 m
.82839 .33986 L
s
1 .233 0 r
.30551 .64319 m
.30399 .64444 L
s
.30688 .64439 m
.30551 .64319 L
s
1 .741 0 r
.67051 .64493 m
.66632 .64811 L
s
.66829 .64087 m
.67051 .64493 L
s
1 .417 0 r
.70203 .64491 m
.7048 .63507 L
s
1 .006 0 r
.76516 .49233 m
.7651 .49218 L
s
1 0 0 r
.52167 .4313 m
.52167 .4313 L
s
1 .091 0 r
.34131 .2177 m
.34428 .21603 L
s
1 .004 0 r
.27818 .37027 m
.27825 .37018 L
s
.27824 .37018 m
.27826 .37021 L
s
.27822 .37019 m
.27824 .37018 L
s
.27824 .37018 m
.27825 .37018 L
s
.27826 .37021 m
.27824 .37022 L
s
.27825 .37018 m
.27826 .37021 L
s
.27824 .37022 m
.27822 .37019 L
s
.27822 .37019 m
.27825 .37018 L
s
.27825 .37018 m
.27824 .37022 L
s
1 .006 0 r
.76511 .49218 m
.76515 .4922 L
s
.76507 .49222 m
.76511 .49218 L
s
.76511 .49218 m
.7651 .49218 L
s
.76511 .49224 m
.76507 .49222 L
s
.76507 .49222 m
.7651 .49218 L
s
.76515 .4922 m
.76511 .49224 L
s
.7651 .49218 m
.76515 .4922 L
s
.7651 .49218 m
.76511 .49224 L
s
1 .606 0 r
.51983 .49215 m
.52489 .49608 L
s
.51983 .49215 m
.52596 .4909 L
s
1 .323 0 r
.34721 .61416 m
.34721 .6143 L
s
.34739 .61093 m
.34721 .61416 L
s
.34721 .61416 m
.34528 .61251 L
s
.34931 .61272 m
.34721 .61416 L
s
.34765 .6064 m
.34721 .61416 L
s
0 .197 1 r
.6556 .59276 m
.66516 .58472 L
s
.66516 .58472 m
.6962 .5956 L
s
1 .121 0 r
.41266 .24773 m
.41173 .24863 L
s
.41136 .24762 m
.41266 .24773 L
s
1 .457 0 r
.3861 .58345 m
.38696 .58366 L
s
.38715 .57895 m
.3861 .58345 L
s
.3861 .58345 m
.38429 .58085 L
s
.38982 .58176 m
.3861 .58345 L
s
.3909 .57267 m
.3861 .58345 L
s
1 .121 0 r
.41173 .24863 m
.41136 .24762 L
s
1 .233 0 r
.30399 .64444 m
.30535 .64564 L
s
1 .172 0 r
.52409 .24758 m
.52405 .24766 L
s
.52405 .24606 m
.52409 .24758 L
s
.52555 .24682 m
.52409 .24758 L
s
1 .233 0 r
.30535 .64564 m
.30688 .64439 L
s
1 .022 0 r
.76223 .30856 m
.76213 .30857 L
s
.76211 .30836 m
.76223 .30856 L
s
.76223 .30856 m
.76201 .30852 L
s
.76224 .3084 m
.76223 .30856 L
s
.76169 .30806 m
.76223 .30856 L
s
.76211 .30836 m
.76201 .30852 L
s
.76224 .3084 m
.76211 .30836 L
s
.76201 .30852 m
.76213 .30857 L
s
1 .172 0 r
.52402 .24613 m
.52405 .24606 L
s
.52405 .24606 m
.52555 .24682 L
s
1 .022 0 r
.76213 .30857 m
.76224 .3084 L
s
1 .091 0 r
.34406 .21667 m
.34366 .21678 L
s
.34371 .21595 m
.34406 .21667 L
s
.34428 .21603 m
.34406 .21667 L
s
.34331 .21606 m
.34371 .21595 L
s
.34371 .21595 m
.34428 .21603 L
s
1 .606 0 r
.52596 .4909 m
.52489 .49608 L
s
1 .323 0 r
.34739 .61093 m
.34528 .61251 L
s
.34931 .61272 m
.34739 .61093 L
s
1 .001 0 r
.14809 .49129 m
.14809 .49129 L
s
.14809 .49128 m
.14809 .49129 L
s
.14809 .49129 m
.14808 .49128 L
s
.14809 .49129 m
.14809 .49129 L
s
.14809 .49126 m
.14809 .49129 L
s
.14809 .49128 m
.14808 .49128 L
s
.14809 .49129 m
.14809 .49128 L
s
.14809 .49129 m
.14809 .49129 L
s
.14808 .49128 m
.14809 .49129 L
s
.973 1 0 r
.63536 .6134 m
.63558 .58839 L
s
1 .002 0 r
.69853 .46073 m
.69849 .46068 L
s
1 .172 0 r
.51806 .24699 m
.52555 .24682 L
s
1 .007 0 r
.45489 .39966 m
.45514 .39957 L
s
1 .005 0 r
.21126 .33859 m
.21134 .33846 L
s
1 .002 0 r
.6985 .46068 m
.69851 .46068 L
s
.69849 .46069 m
.6985 .46068 L
s
.6985 .46068 m
.69849 .46068 L
s
.6985 .4607 m
.69849 .46069 L
s
.69849 .46069 m
.69849 .46068 L
s
.69851 .46068 m
.6985 .4607 L
s
.69849 .46068 m
.69851 .46068 L
s
1 .007 0 r
.45511 .39961 m
.45509 .39962 L
s
.45509 .39956 m
.45511 .39961 L
s
.45514 .39957 m
.45511 .39961 L
s
1 .002 0 r
.69849 .46068 m
.6985 .4607 L
s
1 .007 0 r
.45507 .39957 m
.45509 .39956 L
s
.45509 .39956 m
.45514 .39957 L
s
1 .062 0 r
.69699 .27747 m
.69661 .27753 L
s
.69658 .27695 m
.69699 .27747 L
s
.69699 .27747 m
.69634 .27744 L
s
.69686 .27704 m
.69699 .27747 L
s
.69502 .27632 m
.69699 .27747 L
s
.69634 .27744 m
.69661 .27753 L
s
.69658 .27695 m
.69634 .27744 L
s
1 .007 0 r
.45514 .39957 m
.45509 .39962 L
s
.45507 .39957 m
.45514 .39957 L
s
1 .005 0 r
.21133 .33846 m
.21135 .3385 L
s
.21129 .33848 m
.21133 .33846 L
s
.21133 .33846 m
.21134 .33846 L
s
1 .007 0 r
.45509 .39962 m
.45507 .39957 L
s
1 .005 0 r
.21135 .3385 m
.21132 .33851 L
s
.21134 .33846 m
.21135 .3385 L
s
1 .062 0 r
.69686 .27704 m
.69658 .27695 L
s
1 .005 0 r
.21132 .33851 m
.21129 .33848 L
s
.21129 .33848 m
.21134 .33846 L
s
1 .039 0 r
.32446 .52169 m
.32452 .5217 L
s
.32454 .5213 m
.32446 .52169 L
s
.32446 .52169 m
.3243 .52146 L
s
.32477 .52154 m
.32446 .52169 L
s
.32483 .52074 m
.32446 .52169 L
s
1 .005 0 r
.21134 .33846 m
.21132 .33851 L
s
1 .172 0 r
.52555 .24682 m
.52405 .24766 L
s
.52402 .24613 m
.52555 .24682 L
s
1 .039 0 r
.32454 .5213 m
.3243 .52146 L
s
.32477 .52154 m
.32454 .5213 L
s
.32452 .5217 m
.32477 .52154 L
s
1 .091 0 r
.34366 .21678 m
.34331 .21606 L
s
.34428 .21603 m
.34366 .21678 L
s
.425 1 0 r
.55108 .49093 m
.54248 .50159 L
s
.53596 .48653 m
.55108 .49093 L
s
1 .039 0 r
.3243 .52146 m
.32452 .5217 L
s
1 .091 0 r
.34331 .21606 m
.34428 .21603 L
s
1 .457 0 r
.38715 .57895 m
.38429 .58085 L
s
.38982 .58176 m
.38715 .57895 L
s
1 .062 0 r
.69661 .27753 m
.69686 .27704 L
s
.285 1 0 r
.60923 .56242 m
.59886 .55191 L
s
.59886 .55191 m
.61368 .54544 L
s
1 .066 0 r
.19502 .64353 m
.19491 .64356 L
s
.19497 .64287 m
.19502 .64353 L
s
.19502 .64353 m
.19453 .64322 L
s
.19535 .64321 m
.19502 .64353 L
s
.19461 .64198 m
.19502 .64353 L
s
1 .741 0 r
.66632 .64811 m
.6618 .64351 L
s
.6618 .64351 m
.66829 .64087 L
s
1 .172 0 r
.52405 .24766 m
.52402 .24613 L
s
1 .066 0 r
.19497 .64287 m
.19453 .64322 L
s
.19535 .64321 m
.19497 .64287 L
s
1 .121 0 r
.63171 .24621 m
.63207 .24631 L
s
.63203 .24518 m
.63171 .24621 L
s
.633 .24604 m
.63171 .24621 L
s
1 .323 0 r
.34721 .6143 m
.34931 .61272 L
s
1 .121 0 r
.63239 .24528 m
.63203 .24518 L
s
.63203 .24518 m
.633 .24604 L
s
1 .066 0 r
.19453 .64322 m
.19491 .64356 L
s
.19491 .64356 m
.19535 .64321 L
s
1 .121 0 r
.633 .24604 m
.63207 .24631 L
s
.63239 .24528 m
.633 .24604 L
s
.62827 .24455 m
.633 .24604 L
s
1 .323 0 r
.34528 .61251 m
.34721 .6143 L
s
1 .481 0 r
.60397 .51709 m
.6067 .51869 L
s
.60135 .52035 m
.60397 .51709 L
s
.60397 .51709 m
.60212 .51736 L
s
1 0 0 r
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
.08104 .45964 m
.08104 .45964 L
s
1 .104 0 r
.8124 .64295 m
.81305 .6405 L
s
1 .002 0 r
.87561 .49019 m
.8756 .49015 L
s
0 .434 1 r
.56862 .58185 m
.49314 .50136 L
s
1 0 0 r
.63182 .42909 m
.63182 .42909 L
s
1 .014 0 r
.38803 .36798 m
.38847 .36772 L
s
1 .158 0 r
.45124 .21522 m
.45778 .21382 L
s
1 .006 0 r
.14425 .30688 m
.14433 .30672 L
s
1 .002 0 r
.8756 .49015 m
.87561 .49016 L
s
.87559 .49016 m
.8756 .49015 L
s
.8756 .49015 m
.8756 .49015 L
s
.8756 .49017 m
.87559 .49016 L
s
.87559 .49016 m
.8756 .49015 L
s
.87561 .49016 m
.8756 .49017 L
s
.8756 .49015 m
.87561 .49016 L
s
.8756 .49015 m
.8756 .49017 L
s
1 .457 0 r
.38696 .58366 m
.38982 .58176 L
s
1 .006 0 r
.14432 .30672 m
.14435 .30676 L
s
.14428 .30674 m
.14432 .30672 L
s
.14432 .30672 m
.14433 .30672 L
s
.14435 .30676 m
.14431 .30678 L
s
.14433 .30672 m
.14435 .30676 L
s
.14431 .30678 m
.14428 .30674 L
s
.14428 .30674 m
.14433 .30672 L
s
.14433 .30672 m
.14431 .30678 L
s
1 .014 0 r
.38844 .36781 m
.38838 .36784 L
s
.38838 .3677 m
.38844 .36781 L
s
.38847 .36772 m
.38844 .36781 L
s
.38832 .36773 m
.38838 .3677 L
s
.38838 .3677 m
.38847 .36772 L
s
.38838 .36784 m
.38832 .36773 L
s
.38847 .36772 m
.38838 .36784 L
s
.38832 .36773 m
.38847 .36772 L
s
1 .121 0 r
.63207 .24631 m
.63239 .24528 L
s
1 .59 0 r
.42022 .55095 m
.42293 .55155 L
s
.42311 .54552 m
.42022 .55095 L
s
.42022 .55095 m
.41993 .54733 L
s
.42611 .54974 m
.42022 .55095 L
s
.43431 .5388 m
.42022 .55095 L
s
1 .481 0 r
.60409 .52195 m
.60135 .52035 L
s
.60135 .52035 m
.60212 .51736 L
s
1 .158 0 r
.45678 .21475 m
.45646 .21483 L
s
.45649 .21337 m
.45678 .21475 L
s
.45778 .21382 m
.45678 .21475 L
s
.45616 .21345 m
.45649 .21337 L
s
.45649 .21337 m
.45778 .21382 L
s
1 .741 0 r
.66829 .64087 m
.66632 .64811 L
s
.425 1 0 r
.53596 .48653 m
.54248 .50159 L
s
1 .004 0 r
.25781 .48922 m
.25782 .48922 L
s
.25782 .48918 m
.25781 .48922 L
s
.25781 .48922 m
.25779 .4892 L
s
.25785 .48921 m
.25781 .48922 L
s
.25785 .48912 m
.25781 .48922 L
s
.25782 .48918 m
.25779 .4892 L
s
.25785 .48921 m
.25782 .48918 L
s
.25782 .48922 m
.25785 .48921 L
s
1 .008 0 r
.56529 .39749 m
.56531 .3975 L
s
.5653 .39742 m
.56529 .39749 L
s
.56537 .39747 m
.56529 .39749 L
s
1 .004 0 r
.25779 .4892 m
.25782 .48922 L
s
1 .008 0 r
.56532 .39743 m
.5653 .39742 L
s
.5653 .39742 m
.56537 .39747 L
s
.56537 .39747 m
.56531 .3975 L
s
.56532 .39743 m
.56537 .39747 L
s
.56503 .39741 m
.56537 .39747 L
s
1 .168 0 r
.56706 .21404 m
.56724 .21409 L
s
.56721 .21255 m
.56706 .21404 L
s
.56867 .21347 m
.56706 .21404 L
s
1 .008 0 r
.56531 .3975 m
.56532 .39743 L
s
1 .457 0 r
.38429 .58085 m
.38696 .58366 L
s
1 .172 0 r
.74572 .61141 m
.74604 .60725 L
s
1 0 0 r
.80897 .45855 m
.80896 .45854 L
s
1 .016 0 r
.32109 .33626 m
.3215 .33592 L
s
1 0 0 r
.80896 .45854 m
.80896 .45854 L
s
.80896 .45854 m
.80896 .45854 L
s
.80896 .45854 m
.80896 .45854 L
s
.80896 .45854 m
.80896 .45854 L
s
.80896 .45854 m
.80896 .45854 L
s
.80896 .45854 m
.80896 .45854 L
s
.80896 .45854 m
.80896 .45854 L
s
.80896 .45854 m
.80896 .45854 L
s
1 .168 0 r
.56739 .21261 m
.56721 .21255 L
s
.56721 .21255 m
.56867 .21347 L
s
1 .158 0 r
.45778 .21382 m
.45646 .21483 L
s
.45616 .21345 m
.45778 .21382 L
s
1 .59 0 r
.42311 .54552 m
.41993 .54733 L
s
.42611 .54974 m
.42311 .54552 L
s
1 .016 0 r
.32142 .33591 m
.3215 .33603 L
s
.32134 .33594 m
.32142 .33591 L
s
.32142 .33591 m
.3215 .33592 L
s
.3215 .33603 m
.32141 .33606 L
s
.3215 .33592 m
.3215 .33603 L
s
.32141 .33606 m
.32134 .33594 L
s
.32134 .33594 m
.3215 .33592 L
s
.3215 .33592 m
.32141 .33606 L
s
1 .158 0 r
.45646 .21483 m
.45616 .21345 L
s
1 .168 0 r
.56867 .21347 m
.56724 .21409 L
s
.56739 .21261 m
.56867 .21347 L
s
.56144 .21273 m
.56867 .21347 L
s
1 .023 0 r
.12762 .61097 m
.12758 .61098 L
s
.12761 .61074 m
.12762 .61097 L
s
.12762 .61097 m
.12745 .61086 L
s
.12774 .61086 m
.12762 .61097 L
s
.1275 .61041 m
.12762 .61097 L
s
.12761 .61074 m
.12745 .61086 L
s
.12774 .61086 m
.12761 .61074 L
s
1 .59 0 r
.42293 .55155 m
.42611 .54974 L
s
1 .023 0 r
.12758 .61098 m
.12774 .61086 L
s
.80605 .27446 m
.80596 .27446 L
s
.80594 .27424 m
.80605 .27446 L
s
.80605 .27446 m
.80582 .27441 L
s
.80607 .27429 m
.80605 .27446 L
s
.80552 .27391 m
.80605 .27446 L
s
.12745 .61086 m
.12758 .61098 L
s
.80594 .27424 m
.80582 .27441 L
s
.80607 .27429 m
.80594 .27424 L
s
.80582 .27441 m
.80596 .27446 L
s
.80596 .27446 m
.80607 .27429 L
s
1 .104 0 r
.81287 .64044 m
.81356 .64101 L
s
.81227 .64098 m
.81287 .64044 L
s
.81287 .64044 m
.81305 .6405 L
s
1 .168 0 r
.56724 .21409 m
.56739 .21261 L
s
1 .481 0 r
.6067 .51869 m
.60409 .52195 L
s
.60212 .51736 m
.6067 .51869 L
s
1 .104 0 r
.81356 .64101 m
.81296 .64154 L
s
.81305 .6405 m
.81356 .64101 L
s
1 0 0 r
.19078 .45746 m
.19078 .45746 L
s
.19078 .45746 m
.19078 .45746 L
s
.19078 .45746 m
.19078 .45746 L
s
.19079 .45746 m
.19078 .45746 L
s
.19079 .45746 m
.19078 .45746 L
s
.19078 .45746 m
.19078 .45746 L
s
.19079 .45746 m
.19078 .45746 L
s
.19078 .45746 m
.19079 .45746 L
s
.19078 .45746 m
.19078 .45746 L
s
1 .039 0 r
.49952 .36569 m
.49948 .36572 L
s
.49948 .36535 m
.49952 .36569 L
s
.49981 .3655 m
.49952 .36569 L
s
1 .035 0 r
.92305 .641 m
.92329 .64017 L
s
1 .336 0 r
.67896 .57982 m
.67716 .57166 L
s
1 0 0 r
.74224 .42687 m
.74224 .42687 L
s
1 .039 0 r
.49816 .36569 m
.49981 .3655 L
s
1 .015 0 r
.25407 .3045 m
.2544 .30414 L
s
1 .104 0 r
.81296 .64154 m
.81227 .64098 L
s
.81227 .64098 m
.81305 .6405 L
s
1 .039 0 r
.49944 .36539 m
.49948 .36535 L
s
.49948 .36535 m
.49981 .3655 L
s
.285 1 0 r
.61368 .54544 m
.60923 .56242 L
s
1 .055 0 r
.7404 .24322 m
.74009 .24325 L
s
.74006 .24274 m
.7404 .24322 L
s
.7404 .24322 m
.73982 .24317 L
s
.74033 .24282 m
.7404 .24322 L
s
.73876 .2421 m
.7404 .24322 L
s
.74006 .24274 m
.73982 .24317 L
s
.74033 .24282 m
.74006 .24274 L
s
.73982 .24317 m
.74009 .24325 L
s
1 .039 0 r
.49981 .3655 m
.49948 .36572 L
s
.49944 .36539 m
.49981 .3655 L
s
1 .015 0 r
.25434 .30414 m
.25442 .30425 L
s
.25425 .30418 m
.25434 .30414 L
s
.25434 .30414 m
.2544 .30414 L
s
.25442 .30425 m
.25433 .30429 L
s
.2544 .30414 m
.25442 .30425 L
s
1 .039 0 r
.49948 .36572 m
.49944 .36539 L
s
1 .073 0 r
.23761 .61017 m
.23755 .6102 L
s
.23761 .60944 m
.23761 .61017 L
s
.23761 .61017 m
.23712 .60981 L
s
.23804 .60983 m
.23761 .61017 L
s
.23744 .60841 m
.23761 .61017 L
s
1 .104 0 r
.81305 .6405 m
.81296 .64154 L
s
1 .015 0 r
.25433 .30429 m
.25425 .30418 L
s
.25425 .30418 m
.2544 .30414 L
s
.2544 .30414 m
.25433 .30429 L
s
1 .481 0 r
.60212 .51736 m
.60409 .52195 L
s
1 .073 0 r
.23761 .60944 m
.23712 .60981 L
s
.23804 .60983 m
.23761 .60944 L
s
1 .055 0 r
.74009 .24325 m
.74033 .24282 L
s
1 .024 0 r
.36745 .48751 m
.36753 .48752 L
s
.36754 .48729 m
.36745 .48751 L
s
.36745 .48751 m
.3674 .48736 L
s
.36767 .48745 m
.36745 .48751 L
s
.36788 .48697 m
.36745 .48751 L
s
.36754 .48729 m
.3674 .48736 L
s
.36767 .48745 m
.36754 .48729 L
s
.36753 .48752 m
.36767 .48745 L
s
1 .199 0 r
.4721 .48779 m
.47273 .48744 L
s
.47273 .48744 m
.47213 .48579 L
s
.47273 .48744 m
.4706 .48728 L
s
1 .073 0 r
.23755 .6102 m
.23804 .60983 L
s
1 .035 0 r
.92322 .64016 m
.92346 .64034 L
s
.92302 .64034 m
.92322 .64016 L
s
.92322 .64016 m
.92329 .64017 L
s
1 .073 0 r
.23712 .60981 m
.23755 .6102 L
s
1 .024 0 r
.3674 .48736 m
.36753 .48752 L
s
1 .199 0 r
.47213 .48579 m
.4715 .48614 L
s
.47213 .48579 m
.4706 .48728 L
s
1 .104 0 r
.67459 .2119 m
.67497 .212 L
s
.67492 .21104 m
.67459 .2119 L
s
.67571 .21184 m
.67459 .2119 L
s
1 .035 0 r
.92346 .64034 m
.92326 .64052 L
s
.92329 .64017 m
.92346 .64034 L
s
.92326 .64052 m
.92302 .64034 L
s
.92302 .64034 m
.92329 .64017 L
s
1 .199 0 r
.4706 .48728 m
.4721 .48779 L
s
.4706 .48728 m
.4715 .48614 L
s
.47818 .48482 m
.4706 .48728 L
s
1 .104 0 r
.67531 .21113 m
.67492 .21104 L
s
.67492 .21104 m
.67571 .21184 L
s
.67571 .21184 m
.67497 .212 L
s
.67531 .21113 m
.67571 .21184 L
s
.67191 .21024 m
.67571 .21184 L
s
1 .035 0 r
.92329 .64017 m
.92326 .64052 L
s
1 .825 0 r
.63468 .5726 m
.63997 .57675 L
s
.62967 .57695 m
.63468 .5726 L
s
.63468 .5726 m
.63485 .57278 L
s
1 .002 0 r
.67549 .39518 m
.67548 .39518 L
s
.67548 .39517 m
.67549 .39518 L
s
.67549 .39518 m
.67547 .39518 L
s
.67549 .39517 m
.67549 .39518 L
s
.67544 .39514 m
.67549 .39518 L
s
.67548 .39517 m
.67547 .39518 L
s
.67549 .39517 m
.67548 .39517 L
s
.67547 .39518 m
.67548 .39518 L
s
.67548 .39518 m
.67549 .39517 L
s
1 .045 0 r
.85635 .60941 m
.85651 .60832 L
s
1 .787 0 r
.61212 .54819 m
.59648 .53068 L
s
1 .048 0 r
.4312 .33393 m
.43302 .33328 L
s
1 0 0 r
.12364 .42575 m
.12364 .42575 L
s
1 .014 0 r
.18696 .27271 m
.18723 .27235 L
s
.18718 .27236 m
.18726 .27245 L
s
.18709 .27239 m
.18718 .27236 L
s
.18718 .27236 m
.18723 .27235 L
s
.18726 .27245 m
.18717 .27249 L
s
.18723 .27235 m
.18726 .27245 L
s
1 .104 0 r
.67497 .212 m
.67531 .21113 L
s
1 .014 0 r
.18717 .27249 m
.18709 .27239 L
s
.18709 .27239 m
.18723 .27235 L
s
.18723 .27235 m
.18717 .27249 L
s
1 .048 0 r
.43281 .33358 m
.43265 .33364 L
s
.43266 .33318 m
.43281 .33358 L
s
.43302 .33328 m
.43281 .33358 L
s
.4325 .33324 m
.43266 .33318 L
s
.43266 .33318 m
.43302 .33328 L
s
.43302 .33328 m
.43265 .33364 L
s
.4325 .33324 m
.43302 .33328 L
s
.43265 .33364 m
.4325 .33324 L
s
1 .199 0 r
.4715 .48614 m
.4721 .48779 L
s
1 .024 0 r
.60919 .36371 m
.60927 .36374 L
s
.60926 .36352 m
.60919 .36371 L
s
.60945 .36369 m
.60919 .36371 L
s
.60934 .36355 m
.60926 .36352 L
s
.60926 .36352 m
.60945 .36369 L
s
.60945 .36369 m
.60927 .36374 L
s
.60934 .36355 m
.60945 .36369 L
s
.60855 .36338 m
.60945 .36369 L
s
1 .045 0 r
.85646 .6083 m
.85676 .60853 L
s
.8562 .60854 m
.85646 .6083 L
s
.85646 .6083 m
.85651 .60832 L
s
1 .59 0 r
.41993 .54733 m
.42293 .55155 L
s
1 .024 0 r
.60927 .36374 m
.60934 .36355 L
s
1 .045 0 r
.8565 .60877 m
.8562 .60854 L
s
.8562 .60854 m
.85651 .60832 L
s
.85676 .60853 m
.8565 .60877 L
s
.85651 .60832 m
.85676 .60853 L
s
1 .172 0 r
.74592 .60719 m
.74705 .60807 L
s
.7449 .60811 m
.74592 .60719 L
s
.74592 .60719 m
.74604 .60725 L
s
0 .434 1 r
.68572 .57781 m
.65841 .60458 L
s
.64794 .57515 m
.68572 .57781 L
s
1 .001 0 r
.30079 .45529 m
.30079 .45529 L
s
.30079 .45528 m
.30079 .45529 L
s
.30079 .45529 m
.30078 .45528 L
s
.30079 .45529 m
.30079 .45529 L
s
.3008 .45527 m
.30079 .45529 L
s
.30079 .45528 m
.30078 .45528 L
s
.30079 .45529 m
.30079 .45528 L
s
.30079 .45529 m
.30079 .45529 L
s
1 .045 0 r
.85651 .60832 m
.8565 .60877 L
s
1 .001 0 r
.30078 .45528 m
.30079 .45529 L
s
1 .062 0 r
.78958 .57778 m
.78951 .57627 L
s
1 0 0 r
.85294 .42464 m
.85294 .42464 L
s
.787 1 0 r
.54519 .51652 m
.49424 .50766 L
s
1 .043 0 r
.36416 .30213 m
.36552 .30135 L
s
1 0 0 r
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
.05641 .39401 m
.05641 .39401 L
s
1 .172 0 r
.74604 .60898 m
.7449 .60811 L
s
.7449 .60811 m
.74604 .60725 L
s
.74705 .60807 m
.74604 .60898 L
s
.74604 .60725 m
.74705 .60807 L
s
1 .043 0 r
.36543 .30164 m
.36524 .3017 L
s
.36526 .3013 m
.36543 .30164 L
s
.36552 .30135 m
.36543 .30164 L
s
.36507 .30137 m
.36526 .3013 L
s
.36526 .3013 m
.36552 .30135 L
s
1 .022 0 r
.17027 .57729 m
.17025 .5773 L
s
.17027 .57707 m
.17027 .57729 L
s
.17027 .57729 m
.17013 .57718 L
s
.1704 .57719 m
.17027 .57729 L
s
.17024 .57676 m
.17027 .57729 L
s
.17027 .57707 m
.17013 .57718 L
s
.1704 .57719 m
.17027 .57707 L
s
.17025 .5773 m
.1704 .57719 L
s
.17013 .57718 m
.17025 .5773 L
s
0 .04 1 r
.36807 .63648 m
.38004 .66909 L
s
1 .043 0 r
.36524 .3017 m
.36507 .30137 L
s
.36552 .30135 m
.36524 .3017 L
s
1 .07 0 r
.54397 .33201 m
.54402 .33206 L
s
.54401 .33139 m
.54397 .33201 L
s
.54462 .33177 m
.54397 .33201 L
s
1 .043 0 r
.36507 .30137 m
.36552 .30135 L
s
1 .07 0 r
.54406 .33145 m
.54401 .33139 L
s
.54401 .33139 m
.54462 .33177 L
s
1 .172 0 r
.74604 .60725 m
.74604 .60898 L
s
0 .434 1 r
.65841 .60458 m
.64794 .57515 L
s
1 .825 0 r
.63496 .58111 m
.62967 .57695 L
s
.62967 .57695 m
.63485 .57278 L
s
1 .07 0 r
.54462 .33177 m
.54402 .33206 L
s
.54406 .33145 m
.54462 .33177 L
s
.54158 .33158 m
.54462 .33177 L
s
1 .417 0 r
.70412 .63485 m
.70682 .63718 L
s
.70166 .63692 m
.70412 .63485 L
s
.70412 .63485 m
.7048 .63507 L
s
1 .607 0 r
.38368 .60744 m
.38481 .60779 L
s
.38508 .60146 m
.38368 .60744 L
s
.38368 .60744 m
.38126 .60402 L
s
.38863 .60522 m
.38368 .60744 L
s
.39006 .59326 m
.38368 .60744 L
s
1 0 0 r
.78613 .39289 m
.78612 .39289 L
s
.78612 .39288 m
.78613 .39289 L
s
.78613 .39289 m
.78612 .39289 L
s
.78613 .39289 m
.78613 .39289 L
s
.78612 .39288 m
.78613 .39289 L
s
.78612 .39288 m
.78612 .39289 L
s
.78613 .39289 m
.78612 .39288 L
s
.78612 .39289 m
.78612 .39289 L
s
.78612 .39289 m
.78613 .39289 L
s
1 .09 0 r
.72272 .54611 m
.722 .54393 L
s
1 0 0 r
.23364 .42353 m
.23364 .42353 L
s
1 .035 0 r
.29704 .27029 m
.298 .26954 L
s
1 .825 0 r
.63997 .57675 m
.63496 .58111 L
s
.63485 .57278 m
.63997 .57675 L
s
1 .062 0 r
.7895 .57625 m
.78991 .57655 L
s
.78913 .5766 m
.7895 .57625 L
s
.7895 .57625 m
.78951 .57627 L
s
1 .07 0 r
.54402 .33206 m
.54406 .33145 L
s
1 .08 0 r
.28021 .57666 m
.28023 .57668 L
s
.28029 .57586 m
.28021 .57666 L
s
.28021 .57666 m
.27976 .57623 L
s
.28075 .57631 m
.28021 .57666 L
s
.28043 .57472 m
.28021 .57666 L
s
1 .05 0 r
.78404 .20882 m
.78378 .20883 L
s
.78374 .20838 m
.78404 .20882 L
s
.78404 .20882 m
.78352 .20875 L
s
.784 .20845 m
.78404 .20882 L
s
.78265 .20775 m
.78404 .20882 L
s
1 .062 0 r
.78955 .57689 m
.78913 .5766 L
s
.78913 .5766 m
.78951 .57627 L
s
1 .05 0 r
.78374 .20838 m
.78352 .20875 L
s
.784 .20845 m
.78374 .20838 L
s
.78352 .20875 m
.78378 .20883 L
s
1 .062 0 r
.78991 .57655 m
.78955 .57689 L
s
.78951 .57627 m
.78991 .57655 L
s
1 .08 0 r
.28029 .57586 m
.27976 .57623 L
s
.28075 .57631 m
.28029 .57586 L
s
1 .062 0 r
.78951 .57627 m
.78955 .57689 L
s
1 .035 0 r
.29782 .26953 m
.29798 .26979 L
s
.29763 .26959 m
.29782 .26953 L
s
.29782 .26953 m
.298 .26954 L
s
.29798 .26979 m
.29779 .26986 L
s
.298 .26954 m
.29798 .26979 L
s
1 .05 0 r
.78378 .20883 m
.784 .20845 L
s
1 .08 0 r
.28023 .57668 m
.28075 .57631 L
s
.27976 .57623 m
.28023 .57668 L
s
1 .035 0 r
.29779 .26986 m
.29763 .26959 L
s
.29763 .26959 m
.298 .26954 L
s
.298 .26954 m
.29779 .26986 L
s
1 .825 0 r
.41399 .57605 m
.41777 .57698 L
s
.41804 .56845 m
.41399 .57605 L
s
.41399 .57605 m
.41356 .57104 L
s
.42224 .57438 m
.41399 .57605 L
s
.43374 .55922 m
.41399 .57605 L
s
1 .006 0 r
.10296 .54522 m
.10296 .54522 L
s
.10297 .54516 m
.10296 .54522 L
s
.10296 .54522 m
.10292 .54519 L
s
.103 .5452 m
.10296 .54522 L
s
.10296 .54507 m
.10296 .54522 L
s
.10297 .54516 m
.10292 .54519 L
s
.103 .5452 m
.10297 .54516 L
s
.10296 .54522 m
.103 .5452 L
s
.71938 .36121 m
.71935 .36121 L
s
.71934 .36115 m
.71938 .36121 L
s
.71938 .36121 m
.71931 .3612 L
s
.71938 .36117 m
.71938 .36121 L
s
.71922 .36108 m
.71938 .36121 L
s
.10292 .54519 m
.10296 .54522 L
s
.71934 .36115 m
.71931 .3612 L
s
.71938 .36117 m
.71934 .36115 L
s
1 .417 0 r
.70682 .63718 m
.70436 .63924 L
s
.7048 .63507 m
.70682 .63718 L
s
1 .006 0 r
.71931 .3612 m
.71935 .36121 L
s
1 .005 0 r
.41093 .45318 m
.41096 .45318 L
s
.41096 .45313 m
.41093 .45318 L
s
.41093 .45318 m
.41094 .45314 L
s
.41099 .45317 m
.41093 .45318 L
s
.41109 .45307 m
.41093 .45318 L
s
.41096 .45313 m
.41094 .45314 L
s
.41099 .45317 m
.41096 .45313 L
s
.41096 .45318 m
.41099 .45317 L
s
1 .006 0 r
.71935 .36121 m
.71938 .36117 L
s
1 .005 0 r
.41094 .45314 m
.41096 .45318 L
s
1 .417 0 r
.34598 .6371 m
.34598 .63732 L
s
.34621 .63293 m
.34598 .6371 L
s
.34598 .6371 m
.34348 .63499 L
s
.34871 .63525 m
.34598 .6371 L
s
.34654 .62717 m
.34598 .6371 L
s
1 .018 0 r
.90047 .57574 m
.9005 .5753 L
s
1 .133 0 r
.65578 .51441 m
.65323 .51142 L
s
1 .09 0 r
.47453 .29975 m
.47831 .2991 L
s
1 0 0 r
.1664 .39174 m
.1664 .39174 L
s
1 .029 0 r
.22983 .23841 m
.23052 .23774 L
s
1 0 0 r
.1664 .39174 m
.1664 .39174 L
s
.1664 .39174 m
.1664 .39174 L
s
.1664 .39174 m
.1664 .39174 L
s
.1664 .39174 m
.1664 .39174 L
s
.1664 .39174 m
.1664 .39174 L
s
.1664 .39174 m
.1664 .39174 L
s
.1664 .39174 m
.1664 .39174 L
s
.1664 .39174 m
.1664 .39174 L
s
1 .09 0 r
.4777 .29959 m
.47755 .29966 L
s
.47756 .29881 m
.4777 .29959 L
s
.47831 .2991 m
.4777 .29959 L
s
1 .417 0 r
.70436 .63924 m
.70166 .63692 L
s
.70166 .63692 m
.7048 .63507 L
s
1 .09 0 r
.47741 .29887 m
.47756 .29881 L
s
.47756 .29881 m
.47831 .2991 L
s
1 .607 0 r
.38508 .60146 m
.38126 .60402 L
s
.38863 .60522 m
.38508 .60146 L
s
1 .018 0 r
.90048 .5753 m
.9006 .57538 L
s
.90038 .5754 m
.90048 .5753 L
s
.90048 .5753 m
.9005 .5753 L
s
.9005 .57548 m
.90038 .5754 L
s
.90038 .5754 m
.9005 .5753 L
s
.9006 .57538 m
.9005 .57548 L
s
.9005 .5753 m
.9006 .57538 L
s
1 .029 0 r
.23039 .23774 m
.23053 .23795 L
s
.23023 .2378 m
.23039 .23774 L
s
.23039 .23774 m
.23052 .23774 L
s
.23053 .23795 m
.23037 .23801 L
s
.23052 .23774 m
.23053 .23795 L
s
1 .018 0 r
.9005 .5753 m
.9005 .57548 L
s
1 .09 0 r
.72211 .54391 m
.72269 .54429 L
s
.72159 .54445 m
.72211 .54391 L
s
.72211 .54391 m
.722 .54393 L
s
1 .029 0 r
.23037 .23801 m
.23023 .2378 L
s
.23023 .2378 m
.23052 .23774 L
s
.23052 .23774 m
.23037 .23801 L
s
1 .09 0 r
.47831 .2991 m
.47755 .29966 L
s
.47741 .29887 m
.47831 .2991 L
s
1 .032 0 r
.653 .32976 m
.65313 .32981 L
s
.65312 .3295 m
.653 .32976 L
s
.65334 .32976 m
.653 .32976 L
s
.65334 .32976 m
.65313 .32981 L
s
.65312 .3295 m
.65334 .32976 L
s
.65324 .32955 m
.65334 .32976 L
s
.65223 .32924 m
.65334 .32976 L
s
.65324 .32955 m
.65312 .3295 L
s
1 .09 0 r
.72217 .54483 m
.72159 .54445 L
s
.72159 .54445 m
.722 .54393 L
s
.47755 .29966 m
.47741 .29887 L
s
.787 1 0 r
.50443 .51561 m
.50236 .5137 L
s
.50236 .5137 m
.50451 .50329 L
s
.50236 .5137 m
.49424 .50766 L
s
1 .032 0 r
.65313 .32981 m
.65324 .32955 L
s
1 .09 0 r
.72269 .54429 m
.72217 .54483 L
s
.722 .54393 m
.72269 .54429 L
s
1 .825 0 r
.41804 .56845 m
.41356 .57104 L
s
.42224 .57438 m
.41804 .56845 L
s
1 .09 0 r
.722 .54393 m
.72217 .54483 L
s
1 .417 0 r
.34621 .63293 m
.34348 .63499 L
s
.34871 .63525 m
.34621 .63293 L
s
1 .825 0 r
.63485 .57278 m
.63496 .58111 L
s
1 .019 0 r
.8336 .54403 m
.83354 .54355 L
s
1 0 0 r
.01 w
.52528 .63609 Mdot
1 .136 0 r
.5 Mabswid
.58875 .48266 m
.58396 .48063 L
s
1 0 0 r
.34391 .42129 m
.34391 .42129 L
s
1 .08 0 r
.40739 .26787 m
.41039 .26676 L
s
1 .001 0 r
.09907 .35992 m
.09908 .35991 L
s
.09907 .35991 m
.09908 .35991 L
s
.09907 .35991 m
.09907 .35991 L
s
.09907 .35991 m
.09908 .35991 L
s
.09908 .35991 m
.09907 .35991 L
s
.09908 .35991 m
.09908 .35991 L
s
.09907 .35991 m
.09907 .35991 L
s
.09907 .35991 m
.09908 .35991 L
s
.09908 .35991 m
.09907 .35991 L
s
1 .417 0 r
.7048 .63507 m
.70436 .63924 L
s
1 .607 0 r
.38481 .60779 m
.38863 .60522 L
s
1 .081 0 r
.58772 .29821 m
.58789 .29828 L
s
.58787 .29751 m
.58772 .29821 L
s
.58856 .29803 m
.58772 .29821 L
s
1 .019 0 r
.83354 .54355 m
.83367 .54364 L
s
.83343 .54366 m
.83354 .54355 L
s
.83354 .54355 m
.83354 .54355 L
s
1 .825 0 r
.41777 .57698 m
.42224 .57438 L
s
1 .081 0 r
.58803 .29757 m
.58787 .29751 L
s
.58787 .29751 m
.58856 .29803 L
s
1 .019 0 r
.83356 .54375 m
.83343 .54366 L
s
.83343 .54366 m
.83354 .54355 L
s
.83367 .54364 m
.83356 .54375 L
s
.83354 .54355 m
.83367 .54364 L
s
0 .04 1 r
.68256 .63569 m
.67277 .64482 L
s
.67095 .60299 m
.68256 .63569 L
s
.70357 .61461 m
.68256 .63569 L
s
1 .019 0 r
.83354 .54355 m
.83356 .54375 L
s
1 .081 0 r
.58856 .29803 m
.58789 .29828 L
s
.58803 .29757 m
.58856 .29803 L
s
.58516 .29736 m
.58856 .29803 L
s
1 .08 0 r
.41004 .26727 m
.40977 .26735 L
s
.4098 .2666 m
.41004 .26727 L
s
.41039 .26676 m
.41004 .26727 L
s
.40953 .26668 m
.4098 .2666 L
s
.4098 .2666 m
.41039 .26676 L
s
1 .336 0 r
.67744 .57156 m
.67961 .57309 L
s
.67543 .5735 m
.67744 .57156 L
s
.67744 .57156 m
.67716 .57166 L
s
1 .018 0 r
.21308 .54344 m
.21308 .54345 L
s
.2131 .54326 m
.21308 .54344 L
s
.21308 .54344 m
.21297 .54334 L
s
.2132 .54337 m
.21308 .54344 L
s
.21314 .54299 m
.21308 .54344 L
s
.2131 .54326 m
.21297 .54334 L
s
.2132 .54337 m
.2131 .54326 L
s
.787 1 0 r
.50451 .50329 m
.50659 .50515 L
s
.50451 .50329 m
.49424 .50766 L
s
1 .018 0 r
.21308 .54345 m
.2132 .54337 L
s
.21297 .54334 m
.21308 .54345 L
s
1 .081 0 r
.58789 .29828 m
.58803 .29757 L
s
1 .417 0 r
.34598 .63732 m
.34871 .63525 L
s
1 .08 0 r
.41039 .26676 m
.40977 .26735 L
s
.40953 .26668 m
.41039 .26676 L
s
1 .021 0 r
.52092 .45099 m
.52093 .45097 L
s
.52093 .45097 m
.52092 .45079 L
s
.52093 .45097 m
.52074 .45089 L
s
1 .133 0 r
.65372 .51134 m
.65449 .51178 L
s
.653 .51225 m
.65372 .51134 L
s
.65372 .51134 m
.65323 .51142 L
s
1 .08 0 r
.40977 .26735 m
.40953 .26668 L
s
1 .021 0 r
.52092 .45079 m
.52092 .45081 L
s
.52092 .45079 m
.52074 .45089 L
s
1 .002 0 r
.83019 .35881 m
.83018 .35881 L
s
.83018 .35879 m
.83019 .35881 L
s
.83019 .35881 m
.83017 .3588 L
s
.83019 .3588 m
.83019 .35881 L
s
.83016 .35876 m
.83019 .35881 L
s
.83018 .35879 m
.83017 .3588 L
s
.83019 .3588 m
.83018 .35879 L
s
.83017 .3588 m
.83018 .35881 L
s
.83018 .35881 m
.83019 .3588 L
s
1 .021 0 r
.52074 .45089 m
.52092 .45099 L
s
.52074 .45089 m
.52092 .45081 L
s
.52165 .45088 m
.52074 .45089 L
s
1 .02 0 r
.76664 .51228 m
.76645 .5118 L
s
1 .063 0 r
.34017 .23595 m
.34225 .23479 L
s
1 0 0 r
.27665 .38947 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
.27666 .38946 m
.27666 .38946 L
s
1 .133 0 r
.65377 .51269 m
.653 .51225 L
s
.653 .51225 m
.65323 .51142 L
s
1 .021 0 r
.52092 .45081 m
.52092 .45099 L
s
1 .417 0 r
.34348 .63499 m
.34598 .63732 L
s
1 .136 0 r
.58493 .48172 m
.58442 .48145 L
s
.58442 .48145 m
.58491 .48036 L
s
.58442 .48145 m
.58396 .48063 L
s
1 .081 0 r
.32281 .54287 m
.32294 .54289 L
s
.32299 .54206 m
.32281 .54287 L
s
.32281 .54287 m
.32246 .54239 L
s
.32346 .54256 m
.32281 .54287 L
s
.32359 .5409 m
.32281 .54287 L
s
1 .136 0 r
.58491 .48036 m
.58542 .48062 L
s
.58491 .48036 m
.58396 .48063 L
s
1 .336 0 r
.6776 .57503 m
.67543 .5735 L
s
.67543 .5735 m
.67716 .57166 L
s
1 .081 0 r
.32299 .54206 m
.32246 .54239 L
s
.32346 .54256 m
.32299 .54206 L
s
1 .02 0 r
.76648 .5118 m
.76661 .51188 L
s
.76637 .51192 m
.76648 .5118 L
s
.76648 .5118 m
.76645 .5118 L
s
.7665 .512 m
.76637 .51192 L
s
.76637 .51192 m
.76645 .5118 L
s
1 .607 0 r
.38126 .60402 m
.38481 .60779 L
s
1 .02 0 r
.76661 .51188 m
.7665 .512 L
s
.76645 .5118 m
.76661 .51188 L
s
.76645 .5118 m
.7665 .512 L
s
1 .081 0 r
.32294 .54289 m
.32346 .54256 L
s
1 .133 0 r
.65449 .51178 m
.65377 .51269 L
s
.65323 .51142 m
.65449 .51178 L
s
1 .081 0 r
.32246 .54239 m
.32294 .54289 L
s
1 .063 0 r
.3421 .23523 m
.34182 .23532 L
s
.34185 .23473 m
.3421 .23523 L
s
.34225 .23479 m
.3421 .23523 L
s
1 .336 0 r
.67961 .57309 m
.6776 .57503 L
s
.67716 .57166 m
.67961 .57309 L
s
1 .133 0 r
.65323 .51142 m
.65377 .51269 L
s
1 .063 0 r
.34157 .23481 m
.34185 .23473 L
s
.34185 .23473 m
.34225 .23479 L
s
1 .116 0 r
.52209 .26583 m
.52207 .26589 L
s
.52207 .26481 m
.52209 .26583 L
s
.52308 .26533 m
.52209 .26583 L
s
.52204 .26486 m
.52207 .26481 L
s
.52207 .26481 m
.52308 .26533 L
s
1 .01 0 r
.7634 .32711 m
.76336 .32711 L
s
.76335 .32702 m
.7634 .32711 L
s
.7634 .32711 m
.7633 .32709 L
s
.7634 .32704 m
.7634 .32711 L
s
.76316 .32688 m
.7634 .32711 L
s
.76335 .32702 m
.7633 .32709 L
s
.7634 .32704 m
.76335 .32702 L
s
.7633 .32709 m
.76336 .32711 L
s
1 .136 0 r
.58542 .48062 m
.58493 .48172 L
s
.58396 .48063 m
.58493 .48172 L
s
1 .01 0 r
.76336 .32711 m
.7634 .32704 L
s
1 .136 0 r
.58396 .48063 m
.58542 .48062 L
s
1 .004 0 r
.14574 .51132 m
.14574 .51132 L
s
.14575 .51128 m
.14574 .51132 L
s
.14574 .51132 m
.14572 .51129 L
s
.14577 .5113 m
.14574 .51132 L
s
.14575 .51122 m
.14574 .51132 L
s
1 .063 0 r
.34182 .23532 m
.34157 .23481 L
s
.34225 .23479 m
.34182 .23532 L
s
1 .004 0 r
.14575 .51128 m
.14572 .51129 L
s
.14577 .5113 m
.14575 .51128 L
s
1 .063 0 r
.34157 .23481 m
.34225 .23479 L
s
1 .004 0 r
.14574 .51132 m
.14577 .5113 L
s
.14572 .51129 m
.14574 .51132 L
s
.808 1 0 r
.63605 .63411 m
.63631 .6052 L
s
1 .016 0 r
.6996 .4805 m
.69931 .48013 L
s
1 0 0 r
.45446 .41905 m
.45446 .41905 L
s
1 .116 0 r
.51801 .26544 m
.52308 .26533 L
s
1 .002 0 r
.20931 .35761 m
.20934 .35757 L
s
1 .05 0 r
.27287 .20399 m
.27429 .20294 L
s
1 .002 0 r
.20933 .35757 m
.20934 .35758 L
s
.20932 .35757 m
.20933 .35757 L
s
.20933 .35757 m
.20934 .35757 L
s
.20934 .35758 m
.20933 .35758 L
s
.20934 .35757 m
.20934 .35758 L
s
.20933 .35758 m
.20932 .35757 L
s
.20932 .35757 m
.20934 .35757 L
s
.20934 .35757 m
.20933 .35758 L
s
1 .116 0 r
.52308 .26533 m
.52207 .26589 L
s
.52204 .26486 m
.52308 .26533 L
s
1 .481 0 r
.46313 .51198 m
.46467 .51109 L
s
.46467 .51109 m
.46322 .5071 L
s
.46467 .51109 m
.45951 .51072 L
s
0 1 .077 r
.61322 .55637 m
.62588 .56919 L
s
.6011 .56497 m
.61322 .55637 L
s
.61322 .55637 m
.61927 .5571 L
s
1 .016 0 r
.69936 .48013 m
.69946 .48018 L
s
.69927 .48023 m
.69936 .48013 L
s
.69936 .48013 m
.69931 .48013 L
s
1 .336 0 r
.67716 .57166 m
.6776 .57503 L
s
1 .016 0 r
.69937 .48029 m
.69927 .48023 L
s
.69927 .48023 m
.69931 .48013 L
s
.69946 .48018 m
.69937 .48029 L
s
.69931 .48013 m
.69946 .48018 L
s
.69931 .48013 m
.69937 .48029 L
s
1 .481 0 r
.46322 .5071 m
.46168 .50798 L
s
.46322 .5071 m
.45951 .51072 L
s
1 .116 0 r
.52207 .26589 m
.52204 .26486 L
s
0 .04 1 r
.66099 .61167 m
.67095 .60299 L
s
.67095 .60299 m
.70357 .61461 L
s
1 .035 0 r
.69719 .29561 m
.69698 .29564 L
s
.69696 .29531 m
.69719 .29561 L
s
.69719 .29561 m
.69682 .29559 L
s
.69712 .29537 m
.69719 .29561 L
s
.69608 .29496 m
.69719 .29561 L
s
1 .481 0 r
.45951 .51072 m
.46313 .51198 L
s
.45951 .51072 m
.46168 .50798 L
s
.47789 .50481 m
.45951 .51072 L
s
1 .035 0 r
.69682 .29559 m
.69698 .29564 L
s
.69696 .29531 m
.69682 .29559 L
s
.69712 .29537 m
.69696 .29531 L
s
1 .05 0 r
.27403 .20292 m
.27425 .2033 L
s
.27377 .20299 m
.27403 .20292 L
s
.27403 .20292 m
.27429 .20294 L
s
.27425 .2033 m
.27399 .20338 L
s
.27429 .20294 m
.27425 .2033 L
s
1 .035 0 r
.69698 .29564 m
.69712 .29537 L
s
1 .05 0 r
.27399 .20338 m
.27377 .20299 L
s
.27377 .20299 m
.27429 .20294 L
s
.27429 .20294 m
.27399 .20338 L
s
1 .001 0 r
.07829 .47943 m
.07829 .47943 L
s
.07829 .47942 m
.07829 .47943 L
s
.07829 .47943 m
.07828 .47943 L
s
.07829 .47943 m
.07829 .47943 L
s
.07829 .47941 m
.07829 .47943 L
s
.07829 .47942 m
.07828 .47943 L
s
.07829 .47943 m
.07829 .47942 L
s
.07829 .47943 m
.07829 .47943 L
s
.07828 .47943 m
.07829 .47943 L
s
1 .005 0 r
.87778 .51016 m
.87776 .51003 L
s
0 .197 1 r
.56888 .60238 m
.48759 .51676 L
s
1 .005 0 r
.63248 .44867 m
.63231 .44857 L
s
1 .002 0 r
.38718 .38719 m
.38724 .38715 L
s
1 .114 0 r
.45078 .23348 m
.45552 .23248 L
s
1 .003 0 r
.14189 .3257 m
.14192 .32564 L
s
1 .002 0 r
.38724 .38717 m
.38723 .38717 L
s
.38723 .38715 m
.38724 .38717 L
s
.38724 .38715 m
.38724 .38717 L
s
.38722 .38715 m
.38723 .38715 L
s
.38723 .38715 m
.38724 .38715 L
s
.38723 .38717 m
.38722 .38715 L
s
.38724 .38715 m
.38723 .38717 L
s
.38722 .38715 m
.38724 .38715 L
s
1 .003 0 r
.14192 .32564 m
.14193 .32566 L
s
.1419 .32565 m
.14192 .32564 L
s
.14192 .32564 m
.14192 .32564 L
s
.14193 .32566 m
.14191 .32566 L
s
.14192 .32564 m
.14193 .32566 L
s
.14191 .32566 m
.1419 .32565 L
s
.1419 .32565 m
.14192 .32564 L
s
.14192 .32564 m
.14191 .32566 L
s
1 .005 0 r
.63235 .44857 m
.63237 .44858 L
s
.63232 .44861 m
.63235 .44857 L
s
.63235 .44857 m
.63231 .44857 L
s
.63235 .44862 m
.63232 .44861 L
s
.63232 .44861 m
.63231 .44857 L
s
.87776 .51003 m
.87779 .51005 L
s
.87773 .51006 m
.87776 .51003 L
s
.87776 .51003 m
.87776 .51003 L
s
.63237 .44858 m
.63235 .44862 L
s
.63231 .44857 m
.63237 .44858 L
s
.63231 .44857 m
.63235 .44862 L
s
.87776 .51008 m
.87773 .51006 L
s
.87773 .51006 m
.87776 .51003 L
s
.87779 .51005 m
.87776 .51008 L
s
.87776 .51003 m
.87779 .51005 L
s
.87776 .51003 m
.87776 .51008 L
s
1 .08 0 r
.63118 .26409 m
.63142 .26416 L
s
.6314 .26341 m
.63118 .26409 L
s
.63203 .26398 m
.63118 .26409 L
s
.63163 .26348 m
.6314 .26341 L
s
.6314 .26341 m
.63203 .26398 L
s
.63203 .26398 m
.63142 .26416 L
s
.63163 .26348 m
.63203 .26398 L
s
.62891 .263 m
.63203 .26398 L
s
1 .114 0 r
.45479 .23314 m
.45455 .23321 L
s
.45458 .23215 m
.45479 .23314 L
s
.45552 .23248 m
.45479 .23314 L
s
.45434 .23221 m
.45458 .23215 L
s
.45458 .23215 m
.45552 .23248 L
s
1 .08 0 r
.63142 .26416 m
.63163 .26348 L
s
1 .825 0 r
.41356 .57104 m
.41777 .57698 L
s
1 .013 0 r
.25608 .50942 m
.25609 .50942 L
s
.2561 .50928 m
.25608 .50942 L
s
.25608 .50942 m
.25602 .50934 L
s
.25618 .50937 m
.25608 .50942 L
s
.25619 .50909 m
.25608 .50942 L
s
.2561 .50928 m
.25602 .50934 L
s
.25618 .50937 m
.2561 .50928 L
s
.25609 .50942 m
.25618 .50937 L
s
.25602 .50934 m
.25609 .50942 L
s
1 .114 0 r
.45552 .23248 m
.45455 .23321 L
s
.45434 .23221 m
.45552 .23248 L
s
.45455 .23321 m
.45434 .23221 L
s
1 .233 0 r
.74709 .63213 m
.74753 .62655 L
s
1 .003 0 r
.81072 .47833 m
.81069 .47825 L
s
1 0 0 r
.56527 .41681 m
.56527 .41681 L
s
1 .095 0 r
.38346 .20148 m
.38703 .20011 L
s
1 .005 0 r
.31983 .35528 m
.31996 .35518 L
s
1 .003 0 r
.8107 .47825 m
.81072 .47826 L
s
.81068 .47827 m
.8107 .47825 L
s
.8107 .47825 m
.81069 .47825 L
s
.8107 .47828 m
.81068 .47827 L
s
.81068 .47827 m
.81069 .47825 L
s
.81072 .47826 m
.8107 .47828 L
s
.81069 .47825 m
.81072 .47826 L
s
1 .005 0 r
.31993 .35517 m
.31995 .35521 L
s
.3199 .35519 m
.31993 .35517 L
s
.31993 .35517 m
.31996 .35518 L
s
.31995 .35521 m
.31993 .35522 L
s
.31996 .35518 m
.31995 .35521 L
s
1 .003 0 r
.81069 .47825 m
.8107 .47828 L
s
1 .005 0 r
.31993 .35522 m
.3199 .35519 L
s
.3199 .35519 m
.31996 .35518 L
s
.31996 .35518 m
.31993 .35522 L
s
1 .035 0 r
.12521 .63198 m
.12515 .63199 L
s
.1252 .63163 m
.12521 .63198 L
s
.12521 .63198 m
.12496 .63181 L
s
.1254 .63181 m
.12521 .63198 L
s
.12504 .63114 m
.12521 .63198 L
s
.1252 .63163 m
.12496 .63181 L
s
.1254 .63181 m
.1252 .63163 L
s
1 .121 0 r
.56574 .23194 m
.56587 .23199 L
s
.56586 .23086 m
.56574 .23194 L
s
.56692 .23153 m
.56574 .23194 L
s
1 .035 0 r
.12515 .63199 m
.1254 .63181 L
s
.12496 .63181 m
.12515 .63199 L
s
1 .121 0 r
.56599 .23091 m
.56586 .23086 L
s
.56586 .23086 m
.56692 .23153 L
s
1 .104 0 r
.2359 .63165 m
.23581 .6317 L
s
.2359 .6306 m
.2359 .63165 L
s
.2359 .63165 m
.2352 .63113 L
s
.23651 .63117 m
.2359 .63165 L
s
.23565 .62916 m
.2359 .63165 L
s
1 .07 0 r
.36561 .50855 m
.36585 .50859 L
s
.36589 .50787 m
.36561 .50855 L
s
.36561 .50855 m
.36547 .50811 L
s
.36627 .50835 m
.36561 .50855 L
s
.3669 .50695 m
.36561 .50855 L
s
1 .121 0 r
.56692 .23153 m
.56587 .23199 L
s
.56599 .23091 m
.56692 .23153 L
s
.56166 .231 m
.56692 .23153 L
s
1 .095 0 r
.38662 .20074 m
.3863 .20082 L
s
.38634 .19995 m
.38662 .20074 L
s
.38703 .20011 m
.38662 .20074 L
s
1 .07 0 r
.36589 .50787 m
.36547 .50811 L
s
.36627 .50835 m
.36589 .50787 L
s
1 .095 0 r
.38601 .20002 m
.38634 .19995 L
s
.38634 .19995 m
.38703 .20011 L
s
1 .07 0 r
.36585 .50859 m
.36627 .50835 L
s
.973 1 0 r
.40849 .60066 m
.4132 .60192 L
s
.41356 .59119 m
.40849 .60066 L
s
.40849 .60066 m
.40794 .59448 L
s
.4188 .59861 m
.40849 .60066 L
s
.43317 .57989 m
.40849 .60066 L
s
1 .104 0 r
.2359 .6306 m
.2352 .63113 L
s
.23651 .63117 m
.2359 .6306 L
s
1 .013 0 r
.80755 .29286 m
.8075 .29286 L
s
.80749 .29274 m
.80755 .29286 L
s
.80755 .29286 m
.80743 .29283 L
s
.80756 .29277 m
.80755 .29286 L
s
.80726 .29256 m
.80755 .29286 L
s
.80749 .29274 m
.80743 .29283 L
s
.80756 .29277 m
.80749 .29274 L
s
.80743 .29283 m
.8075 .29286 L
s
1 .481 0 r
.46168 .50798 m
.46313 .51198 L
s
1 .013 0 r
.8075 .29286 m
.80756 .29277 L
s
1 .741 0 r
.38139 .63128 m
.38278 .63178 L
s
.38311 .62397 m
.38139 .63128 L
s
.38139 .63128 m
.37842 .62715 L
s
.38747 .6286 m
.38139 .63128 L
s
.38922 .6141 m
.38139 .63128 L
s
1 .07 0 r
.36547 .50811 m
.36585 .50859 L
s
1 .002 0 r
.1887 .47729 m
.1887 .47729 L
s
.1887 .47727 m
.1887 .47729 L
s
.1887 .47729 m
.18869 .47728 L
s
.18871 .47728 m
.1887 .47729 L
s
.18871 .47724 m
.1887 .47729 L
s
1 .121 0 r
.56587 .23199 m
.56599 .23091 L
s
1 .002 0 r
.1887 .47727 m
.18869 .47728 L
s
.18871 .47728 m
.1887 .47727 L
s
.1887 .47729 m
.18871 .47728 L
s
.18869 .47728 m
.1887 .47729 L
s
1 .104 0 r
.23581 .6317 m
.23651 .63117 L
s
1 .005 0 r
.49818 .3849 m
.49817 .38491 L
s
.49817 .38486 m
.49818 .3849 L
s
.49822 .38488 m
.49818 .3849 L
s
1 .459 0 r
.67991 .60036 m
.67744 .58926 L
s
1 .001 0 r
.74359 .44646 m
.74357 .44644 L
s
1 .005 0 r
.49799 .3849 m
.49822 .38488 L
s
1 .007 0 r
.25239 .32334 m
.25254 .32318 L
s
1 .005 0 r
.49817 .38486 m
.49817 .38486 L
s
.49817 .38486 m
.49822 .38488 L
s
1 .104 0 r
.2352 .63113 m
.23581 .6317 L
s
1 .001 0 r
.74358 .44644 m
.74358 .44644 L
s
.74357 .44645 m
.74358 .44644 L
s
.74358 .44644 m
.74357 .44644 L
s
.74358 .44645 m
.74357 .44645 L
s
.74357 .44645 m
.74357 .44644 L
s
.74358 .44644 m
.74358 .44645 L
s
.74357 .44644 m
.74358 .44644 L
s
.74357 .44644 m
.74358 .44645 L
s
1 .005 0 r
.49822 .38488 m
.49817 .38491 L
s
.49817 .38486 m
.49822 .38488 L
s
.49817 .38491 m
.49817 .38486 L
s
1 .095 0 r
.38703 .20011 m
.3863 .20082 L
s
.38601 .20002 m
.38703 .20011 L
s
1 .007 0 r
.25251 .32318 m
.25254 .32323 L
s
.25247 .3232 m
.25251 .32318 L
s
.25251 .32318 m
.25254 .32318 L
s
.25254 .32323 m
.2525 .32325 L
s
.25254 .32318 m
.25254 .32323 L
s
1 .095 0 r
.3863 .20082 m
.38601 .20002 L
s
1 .007 0 r
.2525 .32325 m
.25247 .3232 L
s
.25247 .3232 m
.25254 .32318 L
s
.25254 .32318 m
.2525 .32325 L
s
.787 1 0 r
.49424 .50766 m
.50443 .51561 L
s
.49424 .50766 m
.50659 .50515 L
s
0 1 .077 r
.62588 .56919 m
.61379 .57787 L
s
.61927 .5571 m
.62588 .56919 L
s
1 .035 0 r
.74113 .26127 m
.74093 .26129 L
s
.74091 .26096 m
.74113 .26127 L
s
.74113 .26127 m
.74076 .26123 L
s
.74108 .26102 m
.74113 .26127 L
s
.74008 .26056 m
.74113 .26127 L
s
.74091 .26096 m
.74076 .26123 L
s
.74108 .26102 m
.74091 .26096 L
s
.74076 .26123 m
.74093 .26129 L
s
.74093 .26129 m
.74108 .26102 L
s
1 .134 0 r
.4991 .19916 m
.49899 .1992 L
s
.499 .19797 m
.4991 .19916 L
s
.50016 .19849 m
.4991 .19916 L
s
.49889 .19801 m
.499 .19797 L
s
.499 .19797 m
.50016 .19849 L
s
1 0 0 r
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
.12115 .44536 m
.12115 .44536 L
s
1 .066 0 r
.85841 .63015 m
.85864 .62858 L
s
.939 1 0 r
.61266 .56855 m
.5914 .54503 L
s
1 0 0 r
.67637 .41456 m
.67637 .41456 L
s
1 .016 0 r
.43062 .35296 m
.43122 .35275 L
s
1 .134 0 r
.49433 .19896 m
.50016 .19849 L
s
1 .008 0 r
.18486 .29136 m
.18501 .29117 L
s
1 .073 0 r
.67471 .22968 m
.67498 .22975 L
s
.67495 .22907 m
.67471 .22968 L
s
.6755 .22963 m
.67471 .22968 L
s
.67522 .22914 m
.67495 .22907 L
s
.67495 .22907 m
.6755 .22963 L
s
1 .016 0 r
.43115 .35284 m
.4311 .35286 L
s
.4311 .35271 m
.43115 .35284 L
s
.43122 .35275 m
.43115 .35284 L
s
1 .073 0 r
.6755 .22963 m
.67498 .22975 L
s
.67522 .22914 m
.6755 .22963 L
s
.67282 .22852 m
.6755 .22963 L
s
1 .016 0 r
.43105 .35273 m
.4311 .35271 L
s
.4311 .35271 m
.43122 .35275 L
s
1 .008 0 r
.18498 .29117 m
.18502 .29122 L
s
.18493 .29119 m
.18498 .29117 L
s
.18498 .29117 m
.18501 .29117 L
s
.18502 .29122 m
.18497 .29124 L
s
.18501 .29117 m
.18502 .29122 L
s
.18497 .29124 m
.18493 .29119 L
s
.18493 .29119 m
.18501 .29117 L
s
.18501 .29117 m
.18497 .29124 L
s
.973 1 0 r
.41356 .59119 m
.40794 .59448 L
s
.4188 .59861 m
.41356 .59119 L
s
1 .016 0 r
.43122 .35275 m
.4311 .35286 L
s
.43105 .35273 m
.43122 .35275 L
s
.4311 .35286 m
.43105 .35273 L
s
1 .134 0 r
.50016 .19849 m
.49899 .1992 L
s
.49889 .19801 m
.50016 .19849 L
s
1 .741 0 r
.38311 .62397 m
.37842 .62715 L
s
.38747 .6286 m
.38311 .62397 L
s
1 .073 0 r
.67498 .22975 m
.67522 .22914 L
s
1 .134 0 r
.49899 .1992 m
.49889 .19801 L
s
.973 1 0 r
.4132 .60192 m
.4188 .59861 L
s
.787 1 0 r
.50659 .50515 m
.50443 .51561 L
s
1 .007 0 r
.2993 .47523 m
.29932 .47523 L
s
.29933 .47516 m
.2993 .47523 L
s
.2993 .47523 m
.29928 .47518 L
s
.29936 .4752 m
.2993 .47523 L
s
.29941 .47507 m
.2993 .47523 L
s
.29933 .47516 m
.29928 .47518 L
s
.29936 .4752 m
.29933 .47516 L
s
.29932 .47523 m
.29936 .4752 L
s
.29928 .47518 m
.29932 .47523 L
s
1 .003 0 r
.60915 .38265 m
.60916 .38266 L
s
.60916 .38263 m
.60915 .38265 L
s
.60919 .38265 m
.60915 .38265 L
s
.60917 .38263 m
.60916 .38263 L
s
.60916 .38263 m
.60919 .38265 L
s
.60919 .38265 m
.60916 .38266 L
s
.60917 .38263 m
.60919 .38265 L
s
.60907 .38261 m
.60919 .38265 L
s
.60916 .38266 m
.60917 .38263 L
s
1 .115 0 r
.60908 .19771 m
.60932 .19776 L
s
.60929 .19671 m
.60908 .19771 L
s
.61027 .19743 m
.60908 .19771 L
s
1 .095 0 r
.79122 .59834 m
.79111 .59602 L
s
1 0 0 r
.85497 .44425 m
.85497 .44424 L
s
.285 1 0 r
.54531 .5367 m
.47271 .52422 L
s
1 .02 0 r
.36316 .32097 m
.36379 .32061 L
s
1 0 0 r
.0535 .41343 m
.0535 .41343 L
s
.85497 .44424 m
.85497 .44424 L
s
.85497 .44424 m
.85497 .44424 L
s
.85497 .44424 m
.85497 .44424 L
s
.85497 .44424 m
.85497 .44424 L
s
.85497 .44424 m
.85497 .44424 L
s
.85497 .44424 m
.85497 .44424 L
s
.85497 .44424 m
.85497 .44424 L
s
.85497 .44424 m
.85497 .44424 L
s
1 .115 0 r
.60953 .19676 m
.60929 .19671 L
s
.60929 .19671 m
.61027 .19743 L
s
1 .066 0 r
.85856 .62854 m
.85901 .62888 L
s
.85818 .6289 m
.85856 .62854 L
s
.85856 .62854 m
.85864 .62858 L
s
1 .121 0 r
.27857 .59823 m
.27859 .59828 L
s
.27869 .59701 m
.27857 .59823 L
s
.27857 .59823 m
.27788 .59758 L
s
.2794 .59771 m
.27857 .59823 L
s
.27891 .59529 m
.27857 .59823 L
s
1 .035 0 r
.16808 .59818 m
.16805 .59819 L
s
.16809 .59782 m
.16808 .59818 L
s
.16808 .59818 m
.16785 .598 L
s
.16829 .59802 m
.16808 .59818 L
s
.16803 .59732 m
.16808 .59818 L
s
1 .02 0 r
.36375 .32075 m
.36366 .32078 L
s
.36367 .32059 m
.36375 .32075 L
s
.36379 .32061 m
.36375 .32075 L
s
.36358 .32062 m
.36367 .32059 L
s
.36367 .32059 m
.36379 .32061 L
s
1 .115 0 r
.61027 .19743 m
.60932 .19776 L
s
.60953 .19676 m
.61027 .19743 L
s
.60547 .19644 m
.61027 .19743 L
s
1 .035 0 r
.16809 .59782 m
.16785 .598 L
s
.16829 .59802 m
.16809 .59782 L
s
1 .066 0 r
.85863 .62924 m
.85818 .6289 L
s
.85818 .6289 m
.85864 .62858 L
s
.85901 .62888 m
.85863 .62924 L
s
.85864 .62858 m
.85901 .62888 L
s
1 .02 0 r
.36366 .32078 m
.36358 .32062 L
s
.36379 .32061 m
.36366 .32078 L
s
.36358 .32062 m
.36379 .32061 L
s
1 .035 0 r
.16805 .59819 m
.16829 .59802 L
s
.16785 .598 m
.16805 .59819 L
s
1 .787 0 r
.59954 .53018 m
.60405 .53285 L
s
.59522 .53558 m
.59954 .53018 L
s
.59954 .53018 m
.59648 .53068 L
s
1 .121 0 r
.27869 .59701 m
.27788 .59758 L
s
.2794 .59771 m
.27869 .59701 L
s
1 .066 0 r
.85864 .62858 m
.85863 .62924 L
s
1 .741 0 r
.38278 .63178 m
.38747 .6286 L
s
1 .121 0 r
.27859 .59828 m
.2794 .59771 L
s
1 .115 0 r
.60932 .19776 m
.60953 .19676 L
s
1 .121 0 r
.27788 .59758 m
.27859 .59828 L
s
1 .024 0 r
.54249 .35077 m
.54251 .35079 L
s
.5425 .35056 m
.54249 .35077 L
s
.54271 .35069 m
.54249 .35077 L
s
.54252 .35058 m
.5425 .35056 L
s
.5425 .35056 m
.54271 .35069 L
s
1 .233 0 r
.74736 .62644 m
.74891 .62764 L
s
.74597 .62769 m
.74736 .62644 L
s
.74736 .62644 m
.74753 .62655 L
s
1 .024 0 r
.54271 .35069 m
.54251 .35079 L
s
.54252 .35058 m
.54271 .35069 L
s
.54168 .35063 m
.54271 .35069 L
s
1 0 0 r
.23182 .44315 m
.23182 .44315 L
s
.23182 .44314 m
.23182 .44315 L
s
.23182 .44315 m
.23182 .44314 L
s
.23183 .44314 m
.23182 .44315 L
s
.23183 .44314 m
.23182 .44315 L
s
.23182 .44314 m
.23182 .44314 L
s
.23183 .44314 m
.23182 .44314 L
s
.23182 .44315 m
.23183 .44314 L
s
.23182 .44314 m
.23182 .44315 L
s
.78774 .4123 m
.78774 .4123 L
s
1 .151 0 r
.72395 .56649 m
.72273 .56284 L
s
1 .019 0 r
.29562 .28895 m
.29615 .28854 L
s
1 .024 0 r
.54251 .35079 m
.54252 .35058 L
s
1 .787 0 r
.59973 .53826 m
.59522 .53558 L
s
.59522 .53558 m
.59648 .53068 L
s
1 .019 0 r
.29605 .28853 m
.29614 .28868 L
s
.29595 .28857 m
.29605 .28853 L
s
.29605 .28853 m
.29615 .28854 L
s
.29614 .28868 m
.29604 .28871 L
s
.29615 .28854 m
.29614 .28868 L
s
.29604 .28871 m
.29595 .28857 L
s
.29595 .28857 m
.29615 .28854 L
s
1 .039 0 r
.40926 .47363 m
.40948 .47367 L
s
.40949 .47328 m
.40926 .47363 L
s
.40926 .47363 m
.4093 .47338 L
s
.40967 .47358 m
.40926 .47363 L
s
.41038 .47288 m
.40926 .47363 L
s
1 .019 0 r
.29615 .28854 m
.29604 .28871 L
s
1 .039 0 r
.40949 .47328 m
.4093 .47338 L
s
.40967 .47358 m
.40949 .47328 L
s
.40948 .47367 m
.40967 .47358 L
s
1 .787 0 r
.45332 .53678 m
.45587 .53525 L
s
.45587 .53525 m
.4535 .5287 L
s
.45587 .53525 m
.44739 .53465 L
s
1 .034 0 r
.7852 .22676 m
.78503 .22677 L
s
.785 .22645 m
.7852 .22676 L
s
.7852 .22676 m
.78485 .22671 L
s
.78518 .22651 m
.7852 .22676 L
s
.78425 .22603 m
.7852 .22676 L
s
.785 .22645 m
.78485 .22671 L
s
.78518 .22651 m
.785 .22645 L
s
.78485 .22671 m
.78503 .22677 L
s
1 .233 0 r
.74752 .6289 m
.74597 .62769 L
s
.74597 .62769 m
.74753 .62655 L
s
.74891 .62764 m
.74752 .6289 L
s
.74753 .62655 m
.74891 .62764 L
s
1 .039 0 r
.4093 .47338 m
.40948 .47367 L
s
1 .095 0 r
.79109 .59599 m
.79173 .59645 L
s
.79053 .59652 m
.79109 .59599 L
s
.79109 .59599 m
.79111 .59602 L
s
1 .034 0 r
.78503 .22677 m
.78518 .22651 L
s
1 .011 0 r
.10034 .56573 m
.10033 .56573 L
s
.10035 .56562 m
.10034 .56573 L
s
.10034 .56573 m
.10027 .56567 L
s
.10041 .56568 m
.10034 .56573 L
s
.10033 .56545 m
.10034 .56573 L
s
.10035 .56562 m
.10027 .56567 L
s
.10041 .56568 m
.10035 .56562 L
s
1 .787 0 r
.4535 .5287 m
.45094 .53021 L
s
.4535 .5287 m
.44739 .53465 L
s
1 .011 0 r
.10033 .56573 m
.10041 .56568 L
s
.10027 .56567 m
.10033 .56573 L
s
1 .095 0 r
.79117 .59698 m
.79053 .59652 L
s
.79053 .59652 m
.79111 .59602 L
s
.79173 .59645 m
.79117 .59698 L
s
.79111 .59602 m
.79173 .59645 L
s
1 .787 0 r
.44739 .53465 m
.45332 .53678 L
s
.44739 .53465 m
.45094 .53021 L
s
.47759 .52506 m
.44739 .53465 L
s
1 .001 0 r
.72044 .38033 m
.72044 .38033 L
s
.72044 .38032 m
.72044 .38033 L
s
.72044 .38033 m
.72043 .38033 L
s
.72044 .38032 m
.72044 .38033 L
s
.72042 .38031 m
.72044 .38033 L
s
.72044 .38032 m
.72043 .38033 L
s
.72044 .38032 m
.72044 .38032 L
s
.72043 .38033 m
.72044 .38033 L
s
.72044 .38033 m
.72044 .38032 L
s
1 .029 0 r
.9028 .59631 m
.90285 .59561 L
s
1 .253 0 r
.65659 .5346 m
.6517 .52891 L
s
1 .043 0 r
.47421 .3186 m
.47604 .31829 L
s
1 0 0 r
.16416 .41117 m
.16416 .41117 L
s
1 .018 0 r
.228 .25689 m
.22842 .25647 L
s
1 .741 0 r
.37842 .62715 m
.38278 .63178 L
s
1 .043 0 r
.47575 .31852 m
.47567 .31856 L
s
.47568 .31815 m
.47575 .31852 L
s
.47604 .31829 m
.47575 .31852 L
s
1 .095 0 r
.79111 .59602 m
.79117 .59698 L
s
1 .233 0 r
.74753 .62655 m
.74752 .6289 L
s
1 .066 0 r
.71844 .19506 m
.71872 .19513 L
s
.71868 .19453 m
.71844 .19506 L
s
.71915 .19506 m
.71844 .19506 L
s
.71915 .19506 m
.71872 .19513 L
s
.71868 .19453 m
.71915 .19506 L
s
.71896 .19459 m
.71915 .19506 L
s
.71689 .19391 m
.71915 .19506 L
s
1 .043 0 r
.4756 .31818 m
.47568 .31815 L
s
.47568 .31815 m
.47604 .31829 L
s
1 .066 0 r
.71896 .19459 m
.71868 .19453 L
s
.973 1 0 r
.63536 .58809 m
.64201 .59334 L
s
.62907 .59357 m
.63536 .58809 L
s
.63536 .58809 m
.63558 .58839 L
s
1 .018 0 r
.22834 .25647 m
.22843 .2566 L
s
.22824 .25651 m
.22834 .25647 L
s
.22834 .25647 m
.22842 .25647 L
s
.22843 .2566 m
.22833 .25664 L
s
.22842 .25647 m
.22843 .2566 L
s
1 .043 0 r
.47604 .31829 m
.47567 .31856 L
s
.4756 .31818 m
.47604 .31829 L
s
1 .018 0 r
.22833 .25664 m
.22824 .25651 L
s
.22824 .25651 m
.22842 .25647 L
s
.22842 .25647 m
.22833 .25664 L
s
1 .043 0 r
.47567 .31856 m
.4756 .31818 L
s
1 .066 0 r
.71872 .19513 m
.71896 .19459 L
s
0 1 .077 r
.61379 .57787 m
.6011 .56497 L
s
.6011 .56497 m
.61927 .5571 L
s
1 .029 0 r
.90282 .5956 m
.90302 .59574 L
s
.90266 .59576 m
.90282 .5956 L
s
.90282 .5956 m
.90285 .59561 L
s
.90286 .5959 m
.90266 .59576 L
s
.90266 .59576 m
.90285 .59561 L
s
.90302 .59574 m
.90286 .5959 L
s
.90285 .59561 m
.90302 .59574 L
s
.90285 .59561 m
.90286 .5959 L
s
0 .197 1 r
.6962 .5956 m
.66684 .62438 L
s
.6556 .59276 m
.6962 .5956 L
s
1 .137 0 r
.32101 .5646 m
.32123 .56465 L
s
.32132 .56323 m
.32101 .5646 L
s
.32101 .5646 m
.32043 .5638 L
s
.32212 .56408 m
.32101 .5646 L
s
.32233 .5613 m
.32101 .5646 L
s
1 .01 0 r
.65327 .34845 m
.65331 .34847 L
s
.65331 .34837 m
.65327 .34845 L
s
.65338 .34845 m
.65327 .34845 L
s
.65338 .34845 m
.65331 .34847 L
s
.65331 .34837 m
.65338 .34845 L
s
.65335 .34839 m
.65338 .34845 L
s
.65302 .34829 m
.65338 .34845 L
s
.65335 .34839 m
.65331 .34837 L
s
.65331 .34847 m
.65335 .34839 L
s
1 .001 0 r
.34275 .44094 m
.34276 .44094 L
s
.34276 .44093 m
.34275 .44094 L
s
.34275 .44094 m
.34275 .44093 L
s
.34277 .44094 m
.34275 .44094 L
s
.34278 .44091 m
.34275 .44094 L
s
.34276 .44093 m
.34275 .44093 L
s
.34277 .44094 m
.34276 .44093 L
s
.34276 .44094 m
.34277 .44094 L
s
.34275 .44093 m
.34276 .44094 L
s
1 .035 0 r
.83551 .56442 m
.83541 .56356 L
s
1 .344 0 r
.58915 .50267 m
.57688 .49753 L
s
1 .046 0 r
.40666 .28653 m
.40838 .2859 L
s
1 0 0 r
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
.09642 .37916 m
.09642 .37916 L
s
0 1 .566 r
.52603 .48259 m
.54032 .49103 L
s
.51182 .50015 m
.52603 .48259 L
s
.52603 .48259 m
.51516 .48373 L
s
1 .137 0 r
.32132 .56323 m
.32043 .5638 L
s
.32212 .56408 m
.32132 .56323 L
s
1 .033 0 r
.21109 .5642 m
.21109 .56421 L
s
.21112 .56387 m
.21109 .5642 L
s
.21109 .5642 m
.2109 .56402 L
s
.21132 .56406 m
.21109 .5642 L
s
.21119 .56338 m
.21109 .5642 L
s
.21112 .56387 m
.2109 .56402 L
s
.21132 .56406 m
.21112 .56387 L
s
1 .046 0 r
.40819 .28619 m
.40803 .28624 L
s
.40805 .28581 m
.40819 .28619 L
s
.40838 .2859 m
.40819 .28619 L
s
.40789 .28586 m
.40805 .28581 L
s
.40805 .28581 m
.40838 .2859 L
s
1 .137 0 r
.32123 .56465 m
.32212 .56408 L
s
1 .033 0 r
.21109 .56421 m
.21132 .56406 L
s
.2109 .56402 m
.21109 .56421 L
s
1 .151 0 r
.72293 .56279 m
.72391 .56344 L
s
.72204 .56371 m
.72293 .56279 L
s
.72293 .56279 m
.72273 .56284 L
s
1 .136 0 r
.51685 .47147 m
.51688 .4713 L
s
.51688 .4713 m
.51685 .47011 L
s
.51688 .4713 m
.51566 .47081 L
s
1 .046 0 r
.40838 .2859 m
.40803 .28624 L
s
.40789 .28586 m
.40838 .2859 L
s
.40803 .28624 m
.40789 .28586 L
s
0 .197 1 r
.66684 .62438 m
.6556 .59276 L
s
1 .136 0 r
.51685 .47011 m
.51682 .47028 L
s
.51685 .47011 m
.51566 .47081 L
s
1 .035 0 r
.83541 .56355 m
.83565 .56371 L
s
.83521 .56375 m
.83541 .56355 L
s
.83541 .56355 m
.83541 .56356 L
s
1 .137 0 r
.32043 .5638 m
.32123 .56465 L
s
1 .035 0 r
.83545 .56391 m
.83521 .56375 L
s
.83521 .56375 m
.83541 .56356 L
s
1 .787 0 r
.60405 .53285 m
.59973 .53826 L
s
.59648 .53068 m
.60405 .53285 L
s
1 .039 0 r
.58677 .31663 m
.58685 .31666 L
s
.58684 .31629 m
.58677 .31663 L
s
.58717 .31654 m
.58677 .31663 L
s
1 .151 0 r
.72302 .56435 m
.72204 .56371 L
s
.72204 .56371 m
.72273 .56284 L
s
1 .035 0 r
.83565 .56371 m
.83545 .56391 L
s
.83541 .56356 m
.83565 .56371 L
s
1 .039 0 r
.58692 .31632 m
.58684 .31629 L
s
.58684 .31629 m
.58717 .31654 L
s
.58717 .31654 m
.58685 .31666 L
s
.58692 .31632 m
.58717 .31654 L
s
.58554 .31622 m
.58717 .31654 L
s
1 .035 0 r
.83541 .56356 m
.83545 .56391 L
s
.285 1 0 r
.48721 .53557 m
.48437 .53273 L
s
.48437 .53273 m
.48742 .51794 L
s
.48437 .53273 m
.47271 .52422 L
s
.973 1 0 r
.40794 .59448 m
.4132 .60192 L
s
1 .039 0 r
.58685 .31666 m
.58692 .31632 L
s
1 .136 0 r
.51566 .47081 m
.51685 .47147 L
s
.51566 .47081 m
.51682 .47028 L
s
.52162 .4707 m
.51566 .47081 L
s
1 .151 0 r
.72391 .56344 m
.72302 .56435 L
s
.72273 .56284 m
.72391 .56344 L
s
1 0 0 r
.83206 .37802 m
.83206 .37802 L
s
.83206 .37801 m
.83206 .37802 L
s
.83206 .37802 m
.83206 .37801 L
s
.83206 .37801 m
.83206 .37802 L
s
.83205 .37801 m
.83206 .37802 L
s
.83206 .37801 m
.83206 .37801 L
s
.83206 .37801 m
.83206 .37801 L
s
.83206 .37801 m
.83206 .37802 L
s
.83206 .37802 m
.83206 .37801 L
s
1 .043 0 r
.76814 .53249 m
.76774 .53145 L
s
1 .04 0 r
.33902 .25443 m
.34035 .2537 L
s
1 0 0 r
.2751 .40891 m
.2751 .40891 L
s
1 .151 0 r
.72273 .56284 m
.72302 .56435 L
s
1 .136 0 r
.51682 .47028 m
.51685 .47147 L
s
1 .787 0 r
.59648 .53068 m
.59973 .53826 L
s
1 .04 0 r
.34025 .25398 m
.34007 .25403 L
s
.34009 .25365 m
.34025 .25398 L
s
.34035 .2537 m
.34025 .25398 L
s
.33991 .25371 m
.34009 .25365 L
s
.34009 .25365 m
.34035 .2537 L
s
.808 1 0 r
.40382 .62473 m
.40929 .62632 L
s
.40972 .61372 m
.40382 .62473 L
s
.40382 .62473 m
.40316 .61764 L
s
.41583 .62237 m
.40382 .62473 L
s
.43259 .60083 m
.40382 .62473 L
s
1 .04 0 r
.34007 .25403 m
.33991 .25371 L
s
.34035 .2537 m
.34007 .25403 L
s
.33991 .25371 m
.34035 .2537 L
s
1 .043 0 r
.7678 .53144 m
.76808 .53161 L
s
.76756 .5317 m
.7678 .53144 L
s
.7678 .53144 m
.76774 .53145 L
s
.973 1 0 r
.63571 .59883 m
.62907 .59357 L
s
.62907 .59357 m
.63558 .58839 L
s
1 .043 0 r
.76784 .53187 m
.76756 .5317 L
s
.76756 .5317 m
.76774 .53145 L
s
1 .009 0 r
.14336 .53165 m
.14336 .53165 L
s
.14337 .53156 m
.14336 .53165 L
s
.14336 .53165 m
.14331 .5316 L
s
.14342 .53161 m
.14336 .53165 L
s
.14339 .53143 m
.14336 .53165 L
s
1 .068 0 r
.52037 .28434 m
.52036 .28438 L
s
.52036 .28374 m
.52037 .28434 L
s
.52095 .28405 m
.52037 .28434 L
s
1 .009 0 r
.14337 .53156 m
.14331 .5316 L
s
.14342 .53161 m
.14337 .53156 L
s
1 .043 0 r
.76808 .53161 m
.76784 .53187 L
s
.76774 .53145 m
.76808 .53161 L
s
1 .009 0 r
.14336 .53165 m
.14342 .53161 L
s
.14331 .5316 m
.14336 .53165 L
s
1 .068 0 r
.52034 .28378 m
.52036 .28374 L
s
.52036 .28374 m
.52095 .28405 L
s
1 .043 0 r
.76774 .53145 m
.76784 .53187 L
s
1 .007 0 r
.45381 .43879 m
.45383 .43877 L
s
.45383 .43877 m
.45381 .43872 L
s
.45383 .43877 m
.45376 .43877 L
s
.973 1 0 r
.64201 .59334 m
.63571 .59883 L
s
.63558 .58839 m
.64201 .59334 L
s
1 .007 0 r
.45381 .43872 m
.45379 .43873 L
s
.45381 .43872 m
.45376 .43877 L
s
.45376 .43877 m
.45381 .43879 L
s
.45376 .43877 m
.45379 .43873 L
s
.45401 .43868 m
.45376 .43877 L
s
1 .003 0 r
.76472 .34601 m
.7647 .34601 L
s
.7647 .34598 m
.76472 .34601 L
s
.76472 .34601 m
.76468 .34601 L
s
.76472 .34599 m
.76472 .34601 L
s
.76464 .34594 m
.76472 .34601 L
s
.7647 .34598 m
.76468 .34601 L
s
.76472 .34599 m
.7647 .34598 L
s
.76468 .34601 m
.7647 .34601 L
s
1 .007 0 r
.45379 .43873 m
.45381 .43879 L
s
1 .003 0 r
.7647 .34601 m
.76472 .34599 L
s
1 .048 0 r
.70069 .50051 m
.69979 .49941 L
s
1 .068 0 r
.51797 .28411 m
.52095 .28405 L
s
1 0 0 r
.20734 .37686 m
.20735 .37685 L
s
1 .034 0 r
.27129 .22228 m
.27227 .22157 L
s
1 0 0 r
.20735 .37685 m
.20735 .37685 L
s
.20734 .37685 m
.20735 .37685 L
s
.20735 .37685 m
.20735 .37685 L
s
.20735 .37685 m
.20735 .37685 L
s
.20735 .37685 m
.20735 .37685 L
s
.20735 .37685 m
.20734 .37685 L
s
.20734 .37685 m
.20735 .37685 L
s
.20735 .37685 m
.20735 .37685 L
s
1 .068 0 r
.52095 .28405 m
.52036 .28438 L
s
.52034 .28378 m
.52095 .28405 L
s
.285 1 0 r
.48742 .51794 m
.49028 .52068 L
s
.48742 .51794 m
.47271 .52422 L
s
1 .068 0 r
.52036 .28438 m
.52034 .28378 L
s
0 1 .566 r
.52604 .50872 m
.51182 .50015 L
s
.51182 .50015 m
.51516 .48373 L
s
1 .034 0 r
.27209 .22156 m
.27224 .22182 L
s
.27191 .22161 m
.27209 .22156 L
s
.27209 .22156 m
.27227 .22157 L
s
.27224 .22182 m
.27206 .22187 L
s
.27227 .22157 m
.27224 .22182 L
s
.27206 .22187 m
.27191 .22161 L
s
.27191 .22161 m
.27227 .22157 L
s
.27227 .22157 m
.27206 .22187 L
s
1 .459 0 r
.67783 .58909 m
.68082 .59121 L
s
.67506 .59177 m
.67783 .58909 L
s
.67783 .58909 m
.67744 .58926 L
s
1 .253 0 r
.65263 .52875 m
.65412 .52961 L
s
.65124 .53049 m
.65263 .52875 L
s
.65263 .52875 m
.6517 .52891 L
s
0 1 .077 r
.61927 .5571 m
.61379 .57787 L
s
1 .048 0 r
.69995 .49939 m
.70024 .49955 L
s
.69969 .49972 m
.69995 .49939 L
s
.69995 .49939 m
.69979 .49941 L
s
.69998 .49988 m
.69969 .49972 L
s
.69969 .49972 m
.69979 .49941 L
s
1 .787 0 r
.45094 .53021 m
.45332 .53678 L
s
1 .016 0 r
.69766 .31413 m
.69756 .31415 L
s
.69755 .31399 m
.69766 .31413 L
s
.69766 .31413 m
.69748 .31412 L
s
.69762 .31402 m
.69766 .31413 L
s
.69714 .31383 m
.69766 .31413 L
s
.69748 .31412 m
.69756 .31415 L
s
.69755 .31399 m
.69748 .31412 L
s
.69762 .31402 m
.69755 .31399 L
s
1 .344 0 r
.57937 .50031 m
.57806 .49961 L
s
.57806 .49961 m
.57931 .49681 L
s
.57806 .49961 m
.57688 .49753 L
s
1 .016 0 r
.69756 .31415 m
.69762 .31402 L
s
1 .253 0 r
.65273 .53135 m
.65124 .53049 L
s
.65124 .53049 m
.6517 .52891 L
s
1 .048 0 r
.70024 .49955 m
.69998 .49988 L
s
.69979 .49941 m
.70024 .49955 L
s
.69979 .49941 m
.69998 .49988 L
s
1 .344 0 r
.57931 .49681 m
.58062 .49751 L
s
.57931 .49681 m
.57688 .49753 L
s
1 .002 0 r
.0755 .49949 m
.0755 .49949 L
s
.0755 .49947 m
.0755 .49949 L
s
.0755 .49949 m
.07549 .49947 L
s
.07551 .49948 m
.0755 .49949 L
s
.0755 .49944 m
.0755 .49949 L
s
.0755 .49947 m
.07549 .49947 L
s
.07551 .49948 m
.0755 .49947 L
s
.0755 .49949 m
.07551 .49948 L
s
.07549 .49947 m
.0755 .49949 L
s
1 .141 0 r
.3633 .53038 m
.36379 .53046 L
s
.36386 .52902 m
.3633 .53038 L
s
.3633 .53038 m
.36302 .5295 L
s
.36463 .52998 m
.3633 .53038 L
s
.36591 .52718 m
.3633 .53038 L
s
1 .011 0 r
.87997 .53037 m
.87992 .53009 L
s
0 .04 1 r
.56916 .62317 m
.48379 .53439 L
s
1 .039 0 r
.63315 .4685 m
.63195 .4678 L
s
1 0 0 r
.38632 .40663 m
.38632 .40663 L
s
1 .075 0 r
.45031 .25197 m
.45343 .25131 L
s
1 .001 0 r
.1395 .34477 m
.13951 .34475 L
s
.13951 .34475 m
.13951 .34475 L
s
.1395 .34475 m
.13951 .34475 L
s
.13951 .34475 m
.13951 .34475 L
s
.13951 .34475 m
.1395 .34476 L
s
.13951 .34475 m
.13951 .34475 L
s
.1395 .34476 m
.1395 .34475 L
s
.1395 .34475 m
.13951 .34475 L
s
.13951 .34475 m
.1395 .34476 L
s
.808 1 0 r
.40972 .61372 m
.40316 .61764 L
s
.41583 .62237 m
.40972 .61372 L
s
1 .075 0 r
.45296 .25175 m
.4528 .25179 L
s
.45282 .25109 m
.45296 .25175 L
s
.45343 .25131 m
.45296 .25175 L
s
1 .011 0 r
.87993 .53008 m
.88001 .53013 L
s
.87986 .53015 m
.87993 .53008 L
s
.87993 .53008 m
.87992 .53009 L
s
.87994 .5302 m
.87986 .53015 L
s
.87986 .53015 m
.87992 .53009 L
s
.88001 .53013 m
.87994 .5302 L
s
.87992 .53009 m
.88001 .53013 L
s
1 .075 0 r
.45266 .25114 m
.45282 .25109 L
s
.45282 .25109 m
.45343 .25131 L
s
1 .141 0 r
.36386 .52902 m
.36302 .5295 L
s
.36463 .52998 m
.36386 .52902 L
s
1 .011 0 r
.87992 .53009 m
.87994 .5302 L
s
1 .029 0 r
.25426 .53002 m
.2543 .53003 L
s
.25432 .52973 m
.25426 .53002 L
s
.25426 .53002 m
.25413 .52985 L
s
.25449 .52991 m
.25426 .53002 L
s
.25451 .52931 m
.25426 .53002 L
s
1 .141 0 r
.36379 .53046 m
.36463 .52998 L
s
1 .029 0 r
.25432 .52973 m
.25413 .52985 L
s
.25449 .52991 m
.25432 .52973 L
s
1 .039 0 r
.63218 .46775 m
.63236 .46784 L
s
.63201 .46805 m
.63218 .46775 L
s
.63218 .46775 m
.63195 .4678 L
s
.63219 .46814 m
.63201 .46805 L
s
.63201 .46805 m
.63195 .4678 L
s
1 .029 0 r
.2543 .53003 m
.25449 .52991 L
s
1 .459 0 r
.67805 .5939 m
.67506 .59177 L
s
.67506 .59177 m
.67744 .58926 L
s
1 .029 0 r
.25413 .52985 m
.2543 .53003 L
s
1 .046 0 r
.63087 .28231 m
.631 .28235 L
s
.63099 .28192 m
.63087 .28231 L
s
.63136 .28224 m
.63087 .28231 L
s
.63113 .28196 m
.63099 .28192 L
s
.63099 .28192 m
.63136 .28224 L
s
1 .075 0 r
.45343 .25131 m
.4528 .25179 L
s
.45266 .25114 m
.45343 .25131 L
s
1 .046 0 r
.63136 .28224 m
.631 .28235 L
s
.63113 .28196 m
.63136 .28224 L
s
.62956 .28169 m
.63136 .28224 L
s
1 .039 0 r
.63236 .46784 m
.63219 .46814 L
s
.63195 .4678 m
.63236 .46784 L
s
.63195 .4678 m
.63219 .46814 L
s
1 .075 0 r
.4528 .25179 m
.45266 .25114 L
s
1 .253 0 r
.65412 .52961 m
.65273 .53135 L
s
.6517 .52891 m
.65412 .52961 L
s
1 .046 0 r
.631 .28235 m
.63113 .28196 L
s
.808 1 0 r
.40929 .62632 m
.41583 .62237 L
s
1 .141 0 r
.36302 .5295 m
.36379 .53046 L
s
1 .253 0 r
.6517 .52891 m
.65273 .53135 L
s
1 .01 0 r
.8125 .49836 m
.8124 .49811 L
s
1 .008 0 r
.56552 .43645 m
.56517 .43639 L
s
1 .066 0 r
.38258 .21978 m
.38509 .21882 L
s
1 .001 0 r
.31854 .37454 m
.31856 .37453 L
s
1 .459 0 r
.68082 .59121 m
.67805 .5939 L
s
.67744 .58926 m
.68082 .59121 L
s
1 .001 0 r
.31856 .37453 m
.31856 .37454 L
s
.31855 .37453 m
.31856 .37453 L
s
.31856 .37453 m
.31856 .37453 L
s
.31856 .37454 m
.31856 .37454 L
s
.31856 .37453 m
.31856 .37454 L
s
.31856 .37454 m
.31855 .37453 L
s
.31855 .37453 m
.31856 .37453 L
s
.31856 .37453 m
.31856 .37454 L
s
1 .008 0 r
.56524 .43644 m
.56523 .43643 L
s
.56523 .43643 m
.56524 .43636 L
s
.56523 .43643 m
.56517 .43639 L
s
.56524 .43636 m
.56526 .43637 L
s
.56524 .43636 m
.56517 .43639 L
s
.56517 .43639 m
.56524 .43644 L
s
.56517 .43639 m
.56526 .43637 L
s
.56526 .43637 m
.56524 .43644 L
s
1 .01 0 r
.81242 .49811 m
.81248 .49815 L
s
.81236 .49817 m
.81242 .49811 L
s
.81242 .49811 m
.8124 .49811 L
s
.81243 .49821 m
.81236 .49817 L
s
.81236 .49817 m
.8124 .49811 L
s
.81248 .49815 m
.81243 .49821 L
s
.8124 .49811 m
.81248 .49815 L
s
.8124 .49811 m
.81243 .49821 L
s
.973 1 0 r
.63558 .58839 m
.63571 .59883 L
s
1 .066 0 r
.3848 .21927 m
.38457 .21932 L
s
.3846 .21871 m
.3848 .21927 L
s
.38509 .21882 m
.3848 .21927 L
s
.38437 .21876 m
.3846 .21871 L
s
.3846 .21871 m
.38509 .21882 L
s
1 .08 0 r
.56459 .25011 m
.56467 .25015 L
s
.56466 .2494 m
.56459 .25011 L
s
.56536 .24985 m
.56459 .25011 L
s
.56475 .24944 m
.56466 .2494 L
s
.56466 .2494 m
.56536 .24985 L
s
1 .344 0 r
.58062 .49751 m
.57937 .50031 L
s
.57688 .49753 m
.57937 .50031 L
s
1 .08 0 r
.56536 .24985 m
.56467 .25015 L
s
.56475 .24944 m
.56536 .24985 L
s
.56189 .2495 m
.56536 .24985 L
s
1 .066 0 r
.38509 .21882 m
.38457 .21932 L
s
.38437 .21876 m
.38509 .21882 L
s
1 .344 0 r
.57688 .49753 m
.58062 .49751 L
s
1 .066 0 r
.38457 .21932 m
.38437 .21876 L
s
1 .006 0 r
.18657 .49742 m
.18657 .49742 L
s
.18658 .49736 m
.18657 .49742 L
s
.18657 .49742 m
.18654 .49738 L
s
.18661 .49739 m
.18657 .49742 L
s
.18661 .49728 m
.18657 .49742 L
s
.18658 .49736 m
.18654 .49738 L
s
.18661 .49739 m
.18658 .49736 L
s
1 .459 0 r
.67744 .58926 m
.67805 .5939 L
s
1 .006 0 r
.18657 .49742 m
.18661 .49739 L
s
.80915 .31157 m
.80913 .31157 L
s
.80912 .31152 m
.80915 .31157 L
s
.80915 .31157 m
.8091 .31156 L
s
.80916 .31153 m
.80915 .31157 L
s
.80902 .31144 m
.80915 .31157 L
s
.80912 .31152 m
.8091 .31156 L
s
.80916 .31153 m
.80912 .31152 L
s
.8091 .31156 m
.80913 .31157 L
s
.18654 .49738 m
.18657 .49742 L
s
.80913 .31157 m
.80916 .31153 L
s
1 .08 0 r
.56467 .25015 m
.56475 .24944 L
s
1 .575 0 r
.68088 .62116 m
.67776 .60732 L
s
1 .007 0 r
.74495 .4663 m
.74483 .46615 L
s
1 0 0 r
.49782 .40436 m
.49782 .40436 L
s
1 .002 0 r
.25068 .34241 m
.25073 .34236 L
s
1 .055 0 r
.31475 .18755 m
.3166 .18655 L
s
1 .002 0 r
.25072 .34236 m
.25073 .34238 L
s
.25071 .34237 m
.25072 .34236 L
s
.25072 .34236 m
.25073 .34236 L
s
.25073 .34238 m
.25072 .34239 L
s
.25073 .34236 m
.25073 .34238 L
s
.25072 .34239 m
.25071 .34237 L
s
.25071 .34237 m
.25073 .34236 L
s
.939 1 0 r
.44444 .56134 m
.44792 .55918 L
s
.44792 .55918 m
.44471 .55032 L
s
.44792 .55918 m
.43645 .55837 L
s
1 .002 0 r
.25073 .34236 m
.25072 .34239 L
s
1 .007 0 r
.74485 .46614 m
.74489 .46617 L
s
.74481 .46619 m
.74485 .46614 L
s
.74485 .46614 m
.74483 .46615 L
s
.74486 .46621 m
.74481 .46619 L
s
.74481 .46619 m
.74483 .46615 L
s
.74489 .46617 m
.74486 .46621 L
s
.74483 .46615 m
.74489 .46617 L
s
.74483 .46615 m
.74486 .46621 L
s
1 .055 0 r
.31646 .18694 m
.31621 .187 L
s
.31625 .18649 m
.31646 .18694 L
s
.3166 .18655 m
.31646 .18694 L
s
.31601 .18655 m
.31625 .18649 L
s
.31625 .18649 m
.3166 .18655 L
s
.939 1 0 r
.44471 .55032 m
.44121 .55245 L
s
.44471 .55032 m
.43645 .55837 L
s
1 .019 0 r
.742 .27964 m
.74189 .27965 L
s
.74188 .27947 m
.742 .27964 L
s
.742 .27964 m
.7418 .27962 L
s
.74198 .2795 m
.742 .27964 L
s
.74142 .27925 m
.742 .27964 L
s
.74188 .27947 m
.7418 .27962 L
s
.74198 .2795 m
.74188 .27947 L
s
.7418 .27962 m
.74189 .27965 L
s
1 .055 0 r
.31621 .187 m
.31601 .18655 L
s
.3166 .18655 m
.31621 .187 L
s
.31601 .18655 m
.3166 .18655 L
s
1 .019 0 r
.74189 .27965 m
.74198 .2795 L
s
.939 1 0 r
.43645 .55837 m
.44444 .56134 L
s
.43645 .55837 m
.44121 .55245 L
s
.47729 .54555 m
.43645 .55837 L
s
1 .095 0 r
.49756 .21741 m
.49748 .21745 L
s
.49748 .21656 m
.49756 .21741 L
s
.49832 .21694 m
.49756 .21741 L
s
.4974 .21659 m
.49748 .21656 L
s
.49748 .21656 m
.49832 .21694 L
s
1 .001 0 r
.11862 .46522 m
.11862 .46522 L
s
.11862 .46521 m
.11862 .46522 L
s
.11862 .46522 m
.11861 .46522 L
s
.11862 .46522 m
.11862 .46522 L
s
.11862 .4652 m
.11862 .46522 L
s
.11862 .46521 m
.11861 .46522 L
s
.11862 .46522 m
.11862 .46521 L
s
.11862 .46522 m
.11862 .46522 L
s
.11861 .46522 m
.11862 .46522 L
s
1 .168 0 r
.2769 .62017 m
.27693 .62025 L
s
.27706 .61847 m
.2769 .62017 L
s
.2769 .62017 m
.27593 .61928 L
s
.27806 .61945 m
.2769 .62017 L
s
.27737 .61613 m
.2769 .62017 L
s
.717 1 0 r
.6132 .58917 m
.58725 .5608 L
s
1 .002 0 r
.67731 .43421 m
.67726 .43417 L
s
1 .095 0 r
.49414 .21727 m
.49832 .21694 L
s
1 .002 0 r
.43002 .37223 m
.43011 .3722 L
s
1 .003 0 r
.18274 .31024 m
.1828 .31016 L
s
1 .002 0 r
.4301 .37221 m
.43009 .37221 L
s
.43009 .37219 m
.4301 .37221 L
s
.43011 .3722 m
.4301 .37221 L
s
.43008 .3722 m
.43009 .37219 L
s
.43009 .37219 m
.43011 .3722 L
s
.67727 .43417 m
.67728 .43418 L
s
.67726 .43419 m
.67727 .43417 L
s
.67727 .43417 m
.67726 .43417 L
s
.67727 .43419 m
.67726 .43419 L
s
.67726 .43419 m
.67726 .43417 L
s
.43011 .3722 m
.43009 .37221 L
s
.43008 .3722 m
.43011 .3722 L
s
.43009 .37221 m
.43008 .3722 L
s
.67728 .43418 m
.67727 .43419 L
s
.67726 .43417 m
.67728 .43418 L
s
.67726 .43417 m
.67727 .43419 L
s
1 .003 0 r
.18279 .31016 m
.18281 .31018 L
s
.18277 .31017 m
.18279 .31016 L
s
.18279 .31016 m
.1828 .31016 L
s
.18281 .31018 m
.18278 .31019 L
s
.1828 .31016 m
.18281 .31018 L
s
.18278 .31019 m
.18277 .31017 L
s
.18277 .31017 m
.1828 .31016 L
s
.1828 .31016 m
.18278 .31019 L
s
0 1 .331 r
.61655 .57068 m
.6309 .58523 L
s
.60284 .5805 m
.61655 .57068 L
s
.61655 .57068 m
.62344 .57166 L
s
1 .095 0 r
.49832 .21694 m
.49748 .21745 L
s
.4974 .21659 m
.49832 .21694 L
s
1 .168 0 r
.27706 .61847 m
.27593 .61928 L
s
.27806 .61945 m
.27706 .61847 L
s
1 .047 0 r
.67496 .24776 m
.67513 .24781 L
s
.67511 .24737 m
.67496 .24776 L
s
.67547 .24773 m
.67496 .24776 L
s
.67529 .24742 m
.67511 .24737 L
s
.67511 .24737 m
.67547 .24773 L
s
.67547 .24773 m
.67513 .24781 L
s
.67529 .24742 m
.67547 .24773 L
s
.67374 .24702 m
.67547 .24773 L
s
1 .095 0 r
.49748 .21745 m
.4974 .21659 L
s
1 .021 0 r
.29767 .49561 m
.29773 .49562 L
s
.29774 .4954 m
.29767 .49561 L
s
.29767 .49561 m
.29761 .49548 L
s
.29786 .49554 m
.29767 .49561 L
s
.29799 .49511 m
.29767 .49561 L
s
.29774 .4954 m
.29761 .49548 L
s
.29786 .49554 m
.29774 .4954 L
s
.29773 .49562 m
.29786 .49554 L
s
1 .047 0 r
.67513 .24781 m
.67529 .24742 L
s
1 .021 0 r
.29761 .49548 m
.29773 .49562 L
s
1 .168 0 r
.27693 .62025 m
.27806 .61945 L
s
1 .051 0 r
.16587 .61939 m
.16583 .61941 L
s
.16589 .61887 m
.16587 .61939 L
s
.16587 .61939 m
.16553 .61913 L
s
.16618 .61916 m
.16587 .61939 L
s
.1658 .61815 m
.16587 .61939 L
s
1 .168 0 r
.27593 .61928 m
.27693 .62025 L
s
1 .051 0 r
.16589 .61887 m
.16553 .61913 L
s
.16618 .61916 m
.16589 .61887 L
s
.16583 .61941 m
.16618 .61916 L
s
1 0 0 r
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
.05055 .43309 m
.05055 .43309 L
s
1 .134 0 r
.79288 .61915 m
.79273 .61592 L
s
1 .002 0 r
.85703 .4641 m
.85701 .46406 L
s
0 1 .077 r
.54544 .55713 m
.45679 .54207 L
s
1 0 0 r
.60959 .40208 m
.60959 .40208 L
s
1 .006 0 r
.36215 .34006 m
.36235 .33994 L
s
1 .091 0 r
.4263 .185 m
.43005 .18409 L
s
1 .002 0 r
.85702 .46406 m
.85703 .46406 L
s
.85701 .46407 m
.85702 .46406 L
s
.85702 .46406 m
.85701 .46406 L
s
1 .051 0 r
.16553 .61913 m
.16583 .61941 L
s
1 .002 0 r
.85702 .46407 m
.85701 .46407 L
s
.85701 .46407 m
.85701 .46406 L
s
.85703 .46406 m
.85702 .46407 L
s
.85701 .46406 m
.85703 .46406 L
s
.85701 .46406 m
.85702 .46407 L
s
1 .111 0 r
.40645 .49506 m
.40707 .4952 L
s
.40711 .49407 m
.40645 .49506 L
s
.40645 .49506 m
.40656 .49435 L
s
.40762 .49492 m
.40645 .49506 L
s
.40966 .49294 m
.40645 .49506 L
s
1 .006 0 r
.36234 .33998 m
.36231 .33999 L
s
.36231 .33993 m
.36234 .33998 L
s
.36235 .33994 m
.36234 .33998 L
s
.36228 .33995 m
.36231 .33993 L
s
.36231 .33993 m
.36235 .33994 L
s
.36231 .33999 m
.36228 .33995 L
s
.36235 .33994 m
.36231 .33999 L
s
.36228 .33995 m
.36235 .33994 L
s
1 .111 0 r
.40711 .49407 m
.40656 .49435 L
s
.40762 .49492 m
.40711 .49407 L
s
.40707 .4952 m
.40762 .49492 L
s
1 .091 0 r
.42951 .18465 m
.42929 .18469 L
s
.42932 .18385 m
.42951 .18465 L
s
.43005 .18409 m
.42951 .18465 L
s
1 .081 0 r
.60854 .21565 m
.60871 .21569 L
s
.60869 .21494 m
.60854 .21565 L
s
.60938 .21545 m
.60854 .21565 L
s
1 .091 0 r
.4291 .18389 m
.42932 .18385 L
s
.42932 .18385 m
.43005 .18409 L
s
1 .081 0 r
.60886 .21498 m
.60869 .21494 L
s
.60869 .21494 m
.60938 .21545 L
s
.60938 .21545 m
.60871 .21569 L
s
.60886 .21498 m
.60938 .21545 L
s
.60597 .21475 m
.60938 .21545 L
s
1 .111 0 r
.40656 .49435 m
.40707 .4952 L
s
1 .091 0 r
.43005 .18409 m
.42929 .18469 L
s
.4291 .18389 m
.43005 .18409 L
s
1 .081 0 r
.60871 .21569 m
.60886 .21498 L
s
1 .091 0 r
.42929 .18469 m
.4291 .18389 L
s
1 .003 0 r
.22996 .46306 m
.22996 .46306 L
s
.22997 .46303 m
.22996 .46306 L
s
.22996 .46306 m
.22995 .46304 L
s
.22998 .46305 m
.22996 .46306 L
s
.22999 .46299 m
.22996 .46306 L
s
.22997 .46303 m
.22995 .46304 L
s
.22998 .46305 m
.22997 .46303 L
s
.22996 .46306 m
.22998 .46305 L
s
.22995 .46304 m
.22996 .46306 L
s
.54189 .36992 m
.5419 .36993 L
s
.5419 .36989 m
.54189 .36992 L
s
.54192 .36991 m
.54189 .36992 L
s
.5419 .3699 m
.5419 .36989 L
s
.5419 .36989 m
.54192 .36991 L
s
.54192 .36991 m
.5419 .36993 L
s
.5419 .3699 m
.54192 .36991 L
s
.54178 .3699 m
.54192 .36991 L
s
1 0 0 r
.78938 .43196 m
.78937 .43195 L
s
1 .22 0 r
.72519 .58712 m
.7234 .58182 L
s
1 .009 0 r
.29418 .30784 m
.29442 .30766 L
s
1 .003 0 r
.5419 .36993 m
.5419 .3699 L
s
1 0 0 r
.78937 .43195 m
.78938 .43196 L
s
.78937 .43196 m
.78937 .43195 L
s
.78937 .43195 m
.78937 .43195 L
s
.78937 .43196 m
.78937 .43196 L
s
.78937 .43196 m
.78937 .43195 L
s
.78938 .43196 m
.78937 .43196 L
s
.78937 .43195 m
.78938 .43196 L
s
.78937 .43195 m
.78937 .43196 L
s
1 .009 0 r
.29438 .30766 m
.29442 .30772 L
s
.29433 .30767 m
.29438 .30766 L
s
.29438 .30766 m
.29442 .30766 L
s
.29442 .30772 m
.29437 .30774 L
s
.29442 .30766 m
.29442 .30772 L
s
.29437 .30774 m
.29433 .30767 L
s
.29433 .30767 m
.29442 .30766 L
s
.29442 .30766 m
.29437 .30774 L
s
1 .202 0 r
.31911 .58678 m
.31943 .58688 L
s
.31956 .58476 m
.31911 .58678 L
s
.31911 .58678 m
.31824 .58561 L
s
.32075 .58602 m
.31911 .58678 L
s
.32106 .58196 m
.31911 .58678 L
s
.808 1 0 r
.40316 .61764 m
.40929 .62632 L
s
1 .104 0 r
.54177 .18301 m
.54181 .18303 L
s
.5418 .18208 m
.54177 .18301 L
s
.54273 .18258 m
.54177 .18301 L
s
1 .018 0 r
.09769 .58654 m
.09767 .58655 L
s
.0977 .58636 m
.09769 .58654 L
s
.09769 .58654 m
.09757 .58644 L
s
.0978 .58646 m
.09769 .58654 L
s
.09767 .58609 m
.09769 .58654 L
s
.0977 .58636 m
.09757 .58644 L
s
.0978 .58646 m
.0977 .58636 L
s
.09767 .58655 m
.0978 .58646 L
s
1 .021 0 r
.78647 .24499 m
.78636 .245 L
s
.78634 .2448 m
.78647 .24499 L
s
.78647 .24499 m
.78624 .24496 L
s
.78645 .24484 m
.78647 .24499 L
s
.78588 .24454 m
.78647 .24499 L
s
1 .104 0 r
.54184 .1821 m
.5418 .18208 L
s
.5418 .18208 m
.54273 .18258 L
s
1 .018 0 r
.09757 .58644 m
.09767 .58655 L
s
1 .021 0 r
.78634 .2448 m
.78624 .24496 L
s
.78645 .24484 m
.78634 .2448 L
s
.78624 .24496 m
.78636 .245 L
s
1 .202 0 r
.31956 .58476 m
.31824 .58561 L
s
.32075 .58602 m
.31956 .58476 L
s
1 .021 0 r
.78636 .245 m
.78645 .24484 L
s
.285 1 0 r
.47271 .52422 m
.48721 .53557 L
s
.47271 .52422 m
.49028 .52068 L
s
1 .104 0 r
.54273 .18258 m
.54181 .18303 L
s
.54184 .1821 m
.54273 .18258 L
s
.53812 .18244 m
.54273 .18258 L
s
1 0 0 r
.1619 .43084 m
.1619 .43084 L
s
.1619 .43084 m
.1619 .43084 L
s
.1619 .43084 m
.1619 .43084 L
s
.1619 .43084 m
.1619 .43084 L
s
.16191 .43084 m
.1619 .43084 L
s
.1619 .43084 m
.1619 .43084 L
s
.1619 .43084 m
.1619 .43084 L
s
.1619 .43084 m
.1619 .43084 L
s
.1619 .43084 m
.1619 .43084 L
s
1 .043 0 r
.90516 .61714 m
.90523 .6161 L
s
1 .39 0 r
.65741 .55504 m
.64984 .54633 L
s
1 0 0 r
.72164 .39979 m
.72164 .39979 L
s
1 .014 0 r
.47389 .33769 m
.47449 .33759 L
s
1 .01 0 r
.22614 .27559 m
.22637 .27537 L
s
1 .014 0 r
.4744 .33767 m
.47437 .33768 L
s
.47437 .33754 m
.4744 .33767 L
s
.47449 .33759 m
.4744 .33767 L
s
.47435 .33755 m
.47437 .33754 L
s
.47437 .33754 m
.47449 .33759 L
s
1 .202 0 r
.31943 .58688 m
.32075 .58602 L
s
1 .014 0 r
.47449 .33759 m
.47437 .33768 L
s
.47435 .33755 m
.47449 .33759 L
s
.47437 .33768 m
.47435 .33755 L
s
1 .01 0 r
.22633 .27537 m
.22637 .27544 L
s
.22627 .27539 m
.22633 .27537 L
s
.22633 .27537 m
.22637 .27537 L
s
.22637 .27544 m
.22632 .27546 L
s
.22637 .27537 m
.22637 .27544 L
s
.22632 .27546 m
.22627 .27539 L
s
.22627 .27539 m
.22637 .27537 L
s
.22637 .27537 m
.22632 .27546 L
s
1 .104 0 r
.54181 .18303 m
.54184 .1821 L
s
1 .134 0 r
.79271 .61586 m
.79361 .61651 L
s
.79191 .61662 m
.79271 .61586 L
s
.79271 .61586 m
.79273 .61592 L
s
1 .045 0 r
.71916 .21302 m
.71936 .21307 L
s
.71933 .21265 m
.71916 .21302 L
s
.71966 .21302 m
.71916 .21302 L
s
.71966 .21302 m
.71936 .21307 L
s
.71933 .21265 m
.71966 .21302 L
s
.71952 .2127 m
.71966 .21302 L
s
.71809 .21223 m
.71966 .21302 L
s
.71952 .2127 m
.71933 .21265 L
s
1 .202 0 r
.31824 .58561 m
.31943 .58688 L
s
1 .134 0 r
.79282 .61727 m
.79191 .61662 L
s
.79191 .61662 m
.79273 .61592 L
s
1 .344 0 r
.50939 .49276 m
.50948 .49229 L
s
.50948 .49229 m
.5094 .48924 L
s
.50948 .49229 m
.50634 .49106 L
s
1 .045 0 r
.71936 .21307 m
.71952 .2127 L
s
1 .134 0 r
.79361 .61651 m
.79282 .61727 L
s
.79273 .61592 m
.79361 .61651 L
s
1 .043 0 r
.90519 .61609 m
.90549 .6163 L
s
.90495 .61632 m
.90519 .61609 L
s
.90519 .61609 m
.90523 .6161 L
s
1 .053 0 r
.20906 .58533 m
.20906 .58535 L
s
.20912 .58479 m
.20906 .58533 L
s
.20906 .58533 m
.20875 .58503 L
s
.20943 .5851 m
.20906 .58533 L
s
.20922 .58403 m
.20906 .58533 L
s
1 .01 0 r
.3414 .46101 m
.34145 .46102 L
s
.34145 .46091 m
.3414 .46101 L
s
.3414 .46101 m
.34139 .46094 L
s
.3415 .46099 m
.3414 .46101 L
s
.34164 .46078 m
.3414 .46101 L
s
1 .043 0 r
.90525 .61654 m
.90495 .61632 L
s
.90495 .61632 m
.90523 .6161 L
s
1 .01 0 r
.34145 .46091 m
.34139 .46094 L
s
.3415 .46099 m
.34145 .46091 L
s
.34145 .46102 m
.3415 .46099 L
s
1 .043 0 r
.90549 .6163 m
.90525 .61654 L
s
.90523 .6161 m
.90549 .6163 L
s
0 1 .331 r
.6309 .58523 m
.61723 .59515 L
s
.62344 .57166 m
.6309 .58523 L
s
1 .053 0 r
.20912 .58479 m
.20875 .58503 L
s
.20943 .5851 m
.20912 .58479 L
s
1 .01 0 r
.34139 .46094 m
.34145 .46102 L
s
1 .134 0 r
.79273 .61592 m
.79282 .61727 L
s
1 .344 0 r
.5094 .48924 m
.50931 .48971 L
s
.5094 .48924 m
.50634 .49106 L
s
1 .043 0 r
.90523 .6161 m
.90525 .61654 L
s
1 .053 0 r
.20906 .58535 m
.20943 .5851 L
s
1 .001 0 r
.65385 .3676 m
.65386 .3676 L
s
.65386 .36759 m
.65385 .3676 L
s
.65387 .3676 m
.65385 .3676 L
s
.65387 .3676 m
.65386 .3676 L
s
.65386 .36759 m
.65387 .3676 L
s
.65386 .36759 m
.65387 .3676 L
s
.65382 .36757 m
.65387 .3676 L
s
.65386 .36759 m
.65386 .36759 L
s
.65386 .3676 m
.65386 .36759 L
s
1 .055 0 r
.83746 .58506 m
.83729 .5837 L
s
1 .59 0 r
.58955 .52292 m
.56835 .51415 L
s
1 .021 0 r
.40591 .30544 m
.40672 .30514 L
s
1 0 0 r
.09373 .39864 m
.09373 .39864 L
s
1 .053 0 r
.20875 .58503 m
.20906 .58535 L
s
1 .021 0 r
.40663 .30528 m
.40655 .3053 L
s
.40656 .3051 m
.40663 .30528 L
s
.40672 .30514 m
.40663 .30528 L
s
.40649 .30513 m
.40656 .3051 L
s
.40656 .3051 m
.40672 .30514 L
s
1 .077 0 r
.65248 .18093 m
.6527 .18097 L
s
.65267 .18026 m
.65248 .18093 L
s
.6533 .1808 m
.65248 .18093 L
s
.6529 .1803 m
.65267 .18026 L
s
.65267 .18026 m
.6533 .1808 L
s
1 .021 0 r
.40672 .30514 m
.40655 .3053 L
s
.40649 .30513 m
.40672 .30514 L
s
.40655 .3053 m
.40649 .30513 L
s
1 .077 0 r
.6533 .1808 m
.6527 .18097 L
s
.6529 .1803 m
.6533 .1808 L
s
.65023 .17988 m
.6533 .1808 L
s
.6527 .18097 m
.6529 .1803 L
s
1 .344 0 r
.50634 .49106 m
.50939 .49276 L
s
.50634 .49106 m
.50931 .48971 L
s
.5216 .49076 m
.50634 .49106 L
s
0 1 .566 r
.54032 .49103 m
.52604 .50872 L
s
.51516 .48373 m
.54032 .49103 L
s
.285 1 0 r
.49028 .52068 m
.48721 .53557 L
s
1 .013 0 r
.58632 .33545 m
.58634 .33546 L
s
.58634 .33534 m
.58632 .33545 L
s
.58645 .33542 m
.58632 .33545 L
s
.58637 .33535 m
.58634 .33534 L
s
.58634 .33534 m
.58645 .33542 L
s
.58645 .33542 m
.58634 .33546 L
s
.58637 .33535 m
.58645 .33542 L
s
.58591 .33532 m
.58645 .33542 L
s
1 .055 0 r
.83729 .58368 m
.83767 .58394 L
s
.83697 .58401 m
.83729 .58368 L
s
.83729 .58368 m
.83729 .5837 L
s
.939 1 0 r
.44121 .55245 m
.44444 .56134 L
s
1 .013 0 r
.58634 .33546 m
.58637 .33535 L
s
1 0 0 r
.27353 .4286 m
.27353 .4286 L
s
.27353 .42859 m
.27353 .4286 L
s
.27353 .4286 m
.27353 .42859 L
s
.27353 .4286 m
.27353 .4286 L
s
.27354 .42859 m
.27353 .4286 L
s
.27353 .42859 m
.27353 .42859 L
s
.27353 .4286 m
.27353 .42859 L
s
.27353 .4286 m
.27353 .4286 L
s
.27353 .42859 m
.27353 .4286 L
s
.83398 .3975 m
.83398 .3975 L
s
1 .075 0 r
.76966 .55294 m
.76895 .55113 L
s
1 .022 0 r
.33785 .27314 m
.33859 .27274 L
s
1 .055 0 r
.83735 .58426 m
.83697 .58401 L
s
.83697 .58401 m
.83729 .5837 L
s
.83767 .58394 m
.83735 .58426 L
s
.83729 .5837 m
.83767 .58394 L
s
1 .229 0 r
.36066 .55281 m
.36145 .55297 L
s
.36157 .5506 m
.36066 .55281 L
s
.36066 .55281 m
.36019 .5514 L
s
.36283 .55217 m
.36066 .55281 L
s
.36491 .54767 m
.36066 .55281 L
s
1 .055 0 r
.83729 .5837 m
.83735 .58426 L
s
1 .022 0 r
.33854 .27289 m
.33844 .27292 L
s
.33845 .27271 m
.33854 .27289 L
s
.33859 .27274 m
.33854 .27289 L
s
.33835 .27274 m
.33845 .27271 L
s
.33845 .27271 m
.33859 .27274 L
s
.939 1 0 r
.59558 .54428 m
.6017 .54795 L
s
.58971 .55162 m
.59558 .54428 L
s
.59558 .54428 m
.5914 .54503 L
s
1 .022 0 r
.33844 .27292 m
.33835 .27274 L
s
.33859 .27274 m
.33844 .27292 L
s
.33835 .27274 m
.33859 .27274 L
s
1 .047 0 r
.45212 .45928 m
.45227 .4592 L
s
.45227 .4592 m
.45213 .45881 L
s
.45227 .4592 m
.45176 .45916 L
s
.45213 .45881 m
.45197 .45889 L
s
.45213 .45881 m
.45176 .45916 L
s
.45176 .45916 m
.45212 .45928 L
s
.45176 .45916 m
.45197 .45889 L
s
.45357 .45856 m
.45176 .45916 L
s
0 .04 1 r
.70357 .61461 m
.67277 .64482 L
s
.66099 .61167 m
.70357 .61461 L
s
1 .229 0 r
.36157 .5506 m
.36019 .5514 L
s
.36283 .55217 m
.36157 .5506 L
s
1 .22 0 r
.72369 .58173 m
.72514 .58269 L
s
.72239 .58307 m
.72369 .58173 L
s
.72369 .58173 m
.7234 .58182 L
s
0 1 .077 r
.47448 .55596 m
.47112 .55235 L
s
.47112 .55235 m
.47482 .53432 L
s
.47112 .55235 m
.45679 .54207 L
s
1 .016 0 r
.14095 .55229 m
.14095 .55229 L
s
.14097 .55213 m
.14095 .55229 L
s
.14095 .55229 m
.14085 .5522 L
s
.14106 .55222 m
.14095 .55229 L
s
.141 .55189 m
.14095 .55229 L
s
1 .344 0 r
.50931 .48971 m
.50939 .49276 L
s
1 .016 0 r
.14097 .55213 m
.14085 .5522 L
s
.14106 .55222 m
.14097 .55213 L
s
.14095 .55229 m
.14106 .55222 L
s
1 .047 0 r
.45197 .45889 m
.45212 .45928 L
s
1 .016 0 r
.14085 .5522 m
.14095 .55229 L
s
1 .229 0 r
.36145 .55297 m
.36283 .55217 L
s
1 .032 0 r
.51906 .30313 m
.51906 .30315 L
s
.51906 .30285 m
.51906 .30313 L
s
.51934 .30299 m
.51906 .30313 L
s
1 .22 0 r
.72383 .58404 m
.72239 .58307 L
s
.72239 .58307 m
.7234 .58182 L
s
1 .032 0 r
.51905 .30287 m
.51906 .30285 L
s
.51906 .30285 m
.51934 .30299 L
s
.808 1 0 r
.63605 .60475 m
.64383 .61093 L
s
.62868 .6112 m
.63605 .60475 L
s
.63605 .60475 m
.63631 .6052 L
s
1 0 0 r
.76615 .36525 m
.76615 .36525 L
s
.76615 .36525 m
.76615 .36525 L
s
.76615 .36525 m
.76615 .36525 L
s
.76615 .36525 m
.76615 .36525 L
s
.76614 .36524 m
.76615 .36525 L
s
.76615 .36525 m
.76615 .36525 L
s
.76615 .36525 m
.76615 .36525 L
s
.76615 .36525 m
.76615 .36525 L
s
.76615 .36525 m
.76615 .36525 L
s
1 .1 0 r
.70179 .52078 m
.69991 .51851 L
s
1 .032 0 r
.51792 .30302 m
.51934 .30299 L
s
1 0 0 r
.20535 .39635 m
.20535 .39635 L
s
1 .021 0 r
.2697 .24081 m
.27031 .24037 L
s
1 .032 0 r
.51934 .30299 m
.51906 .30315 L
s
.51905 .30287 m
.51934 .30299 L
s
.51906 .30315 m
.51905 .30287 L
s
1 .075 0 r
.76907 .55111 m
.76956 .55141 L
s
.76863 .55157 m
.76907 .55111 L
s
.76907 .55111 m
.76895 .55113 L
s
1 .021 0 r
.2702 .24036 m
.27029 .24052 L
s
.27009 .24039 m
.2702 .24036 L
s
.2702 .24036 m
.27031 .24037 L
s
.27029 .24052 m
.27018 .24055 L
s
.27031 .24037 m
.27029 .24052 L
s
.939 1 0 r
.59581 .55531 m
.58971 .55162 L
s
.58971 .55162 m
.5914 .54503 L
s
1 .075 0 r
.76912 .55188 m
.76863 .55157 L
s
.76863 .55157 m
.76895 .55113 L
s
1 .22 0 r
.72514 .58269 m
.72383 .58404 L
s
.7234 .58182 m
.72514 .58269 L
s
.717 1 0 r
.43703 .5854 m
.44129 .58267 L
s
.44129 .58267 m
.43739 .57191 L
s
.44129 .58267 m
.42735 .5817 L
s
1 .021 0 r
.27018 .24055 m
.27009 .24039 L
s
.27009 .24039 m
.27031 .24037 L
s
.27031 .24037 m
.27018 .24055 L
s
1 .043 0 r
.764 .17813 m
.76374 .17816 L
s
.7637 .17776 m
.764 .17813 L
s
.764 .17813 m
.76354 .17811 L
s
.76391 .17781 m
.764 .17813 L
s
.76261 .1773 m
.764 .17813 L
s
.76354 .17811 m
.76374 .17816 L
s
.7637 .17776 m
.76354 .17811 L
s
.76391 .17781 m
.7637 .17776 L
s
0 .04 1 r
.67277 .64482 m
.66099 .61167 L
s
1 .075 0 r
.76956 .55141 m
.76912 .55188 L
s
.76895 .55113 m
.76956 .55141 L
s
1 .229 0 r
.36019 .5514 m
.36145 .55297 L
s
1 .075 0 r
.76895 .55113 m
.76912 .55188 L
s
1 .043 0 r
.76374 .17816 m
.76391 .17781 L
s
1 .22 0 r
.7234 .58182 m
.72383 .58404 L
s
1 .052 0 r
.25236 .55105 m
.25243 .55107 L
s
.25247 .55053 m
.25236 .55105 L
s
.25236 .55105 m
.25213 .55074 L
s
.25278 .55085 m
.25236 .55105 L
s
.25281 .54978 m
.25236 .55105 L
s
1 .005 0 r
.07267 .51982 m
.07267 .51983 L
s
.07268 .51978 m
.07267 .51982 L
s
.07267 .51982 m
.07264 .5198 L
s
.0727 .51981 m
.07267 .51982 L
s
.07268 .51971 m
.07267 .51982 L
s
.07268 .51978 m
.07264 .5198 L
s
.0727 .51981 m
.07268 .51978 L
s
1 .052 0 r
.25247 .55053 m
.25213 .55074 L
s
.25278 .55085 m
.25247 .55053 L
s
1 .005 0 r
.07267 .51983 m
.0727 .51981 L
s
.07264 .5198 m
.07267 .51983 L
s
.69838 .33304 m
.69835 .33304 L
s
.69835 .33299 m
.69838 .33304 L
s
.69838 .33304 m
.69833 .33303 L
s
.69837 .333 m
.69838 .33304 L
s
.69822 .33294 m
.69838 .33304 L
s
.69833 .33303 m
.69835 .33304 L
s
.69835 .33299 m
.69833 .33303 L
s
.69837 .333 m
.69835 .33299 L
s
.69835 .33304 m
.69837 .333 L
s
.717 1 0 r
.43739 .57191 m
.4331 .5746 L
s
.43739 .57191 m
.42735 .5817 L
s
1 .002 0 r
.38539 .42636 m
.3854 .42636 L
s
.3854 .42634 m
.38539 .42636 L
s
.38539 .42636 m
.38539 .42635 L
s
.38541 .42636 m
.38539 .42636 L
s
.38545 .42633 m
.38539 .42636 L
s
.3854 .42636 m
.38541 .42636 L
s
.38541 .42636 m
.3854 .42634 L
s
.3854 .42634 m
.38539 .42635 L
s
.38539 .42635 m
.3854 .42636 L
s
1 .052 0 r
.25243 .55107 m
.25278 .55085 L
s
1 .021 0 r
.8822 .55084 m
.88211 .55032 L
s
1 .111 0 r
.63382 .48858 m
.63035 .48658 L
s
1 .043 0 r
.44984 .27069 m
.45163 .27032 L
s
1 0 0 r
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
.13708 .36407 m
.13708 .36407 L
s
0 1 .566 r
.51516 .48373 m
.52604 .50872 L
s
1 .052 0 r
.25213 .55074 m
.25243 .55107 L
s
1 .043 0 r
.45136 .27056 m
.45127 .27059 L
s
.45128 .27019 m
.45136 .27056 L
s
.45163 .27032 m
.45136 .27056 L
s
.45119 .27022 m
.45128 .27019 L
s
.45128 .27019 m
.45163 .27032 L
s
0 1 .077 r
.47482 .53432 m
.47821 .5378 L
s
.47482 .53432 m
.45679 .54207 L
s
.717 1 0 r
.42735 .5817 m
.43703 .5854 L
s
.42735 .5817 m
.4331 .5746 L
s
.47699 .56631 m
.42735 .5817 L
s
1 .043 0 r
.45163 .27032 m
.45127 .27059 L
s
.45119 .27022 m
.45163 .27032 L
s
1 .021 0 r
.88211 .55031 m
.88226 .5504 L
s
.88199 .55044 m
.88211 .55031 L
s
.88211 .55031 m
.88211 .55032 L
s
1 .043 0 r
.45127 .27059 m
.45119 .27022 L
s
1 .021 0 r
.88214 .55053 m
.88199 .55044 L
s
.88199 .55044 m
.88211 .55032 L
s
.88226 .5504 m
.88214 .55053 L
s
.88211 .55032 m
.88226 .5504 L
s
1 .1 0 r
.70026 .51845 m
.70086 .51879 L
s
.69972 .51914 m
.70026 .51845 L
s
.70026 .51845 m
.69991 .51851 L
s
1 .021 0 r
.88211 .55032 m
.88214 .55053 L
s
1 .1 0 r
.70032 .51948 m
.69972 .51914 L
s
.69972 .51914 m
.69991 .51851 L
s
1 .021 0 r
.63082 .30089 m
.63089 .30091 L
s
.63088 .30071 m
.63082 .30089 L
s
.63105 .30086 m
.63082 .30089 L
s
.63094 .30073 m
.63088 .30071 L
s
.63088 .30071 m
.63105 .30086 L
s
.63105 .30086 m
.63089 .30091 L
s
.63094 .30073 m
.63105 .30086 L
s
.63021 .3006 m
.63105 .30086 L
s
1 .1 0 r
.70086 .51879 m
.70032 .51948 L
s
.69991 .51851 m
.70086 .51879 L
s
1 .021 0 r
.63089 .30091 m
.63094 .30073 L
s
1 .1 0 r
.69991 .51851 m
.70032 .51948 L
s
1 .022 0 r
.81431 .51863 m
.81408 .51809 L
s
1 .058 0 r
.56578 .45634 m
.5633 .45589 L
s
1 .042 0 r
.38168 .23831 m
.38329 .2377 L
s
1 0 0 r
.31725 .39405 m
.31725 .39405 L
s
1 .058 0 r
.5638 .45628 m
.56369 .4562 L
s
.56369 .4562 m
.56379 .45569 L
s
.56369 .4562 m
.5633 .45589 L
s
.56379 .45569 m
.56391 .45577 L
s
.56379 .45569 m
.5633 .45589 L
s
1 .111 0 r
.63103 .48642 m
.63155 .48668 L
s
.63055 .48729 m
.63103 .48642 L
s
.63103 .48642 m
.63035 .48658 L
s
.63107 .48755 m
.63055 .48729 L
s
.63055 .48729 m
.63035 .48658 L
s
1 .042 0 r
.3831 .23799 m
.38296 .23802 L
s
.38298 .23763 m
.3831 .23799 L
s
.38329 .2377 m
.3831 .23799 L
s
.38283 .23766 m
.38298 .23763 L
s
.38298 .23763 m
.38329 .2377 L
s
1 .022 0 r
.81411 .51808 m
.81426 .51817 L
s
.81398 .51822 m
.81411 .51808 L
s
.81411 .51808 m
.81408 .51809 L
s
.81413 .51831 m
.81398 .51822 L
s
.81398 .51822 m
.81408 .51809 L
s
1 .058 0 r
.5633 .45589 m
.5638 .45628 L
s
.5633 .45589 m
.56391 .45577 L
s
0 1 .331 r
.61723 .59515 m
.60284 .5805 L
s
.60284 .5805 m
.62344 .57166 L
s
1 .022 0 r
.81426 .51817 m
.81413 .51831 L
s
.81408 .51809 m
.81426 .51817 L
s
.81408 .51809 m
.81413 .51831 L
s
1 .058 0 r
.56391 .45577 m
.5638 .45628 L
s
1 .575 0 r
.67825 .60706 m
.68202 .60976 L
s
.67476 .61046 m
.67825 .60706 L
s
.67825 .60706 m
.67776 .60732 L
s
1 .042 0 r
.38329 .2377 m
.38296 .23802 L
s
.38283 .23766 m
.38329 .2377 L
s
.38296 .23802 m
.38283 .23766 L
s
1 .39 0 r
.65128 .54605 m
.65359 .54741 L
s
.64913 .54876 m
.65128 .54605 L
s
.65128 .54605 m
.64984 .54633 L
s
1 .013 0 r
.18439 .51788 m
.1844 .51788 L
s
.18441 .51775 m
.18439 .51788 L
s
.18439 .51788 m
.18433 .5178 L
s
.18448 .51783 m
.18439 .51788 L
s
.18448 .51756 m
.18439 .51788 L
s
1 .046 0 r
.56367 .26858 m
.56372 .2686 L
s
.56372 .26817 m
.56367 .26858 L
s
.56412 .26843 m
.56367 .26858 L
s
1 .013 0 r
.18441 .51775 m
.18433 .5178 L
s
.18448 .51783 m
.18441 .51775 L
s
1 .111 0 r
.63155 .48668 m
.63107 .48755 L
s
.63035 .48658 m
.63155 .48668 L
s
.63035 .48658 m
.63107 .48755 L
s
1 .013 0 r
.1844 .51788 m
.18448 .51783 L
s
1 .046 0 r
.56377 .26819 m
.56372 .26817 L
s
.56372 .26817 m
.56412 .26843 L
s
1 .013 0 r
.18433 .5178 m
.1844 .51788 L
s
1 .046 0 r
.56412 .26843 m
.56372 .2686 L
s
.56377 .26819 m
.56412 .26843 L
s
.56212 .26823 m
.56412 .26843 L
s
.808 1 0 r
.63647 .6174 m
.62868 .6112 L
s
.62868 .6112 m
.63631 .6052 L
s
1 .59 0 r
.57265 .51896 m
.57041 .5177 L
s
.57041 .5177 m
.57256 .51287 L
s
.57041 .5177 m
.56835 .51415 L
s
1 .005 0 r
.49746 .42411 m
.49746 .4241 L
s
.49746 .4241 m
.49746 .42405 L
s
.49746 .4241 m
.49741 .42409 L
s
1 .002 0 r
.81084 .3306 m
.81084 .3306 L
s
.81084 .33058 m
.81084 .3306 L
s
.81084 .3306 m
.81083 .3306 L
s
.81085 .33059 m
.81084 .3306 L
s
.8108 .33056 m
.81084 .3306 L
s
1 .005 0 r
.49746 .42405 m
.49745 .42406 L
s
.49746 .42405 m
.49741 .42409 L
s
1 .002 0 r
.81084 .33058 m
.81083 .3306 L
s
.81085 .33059 m
.81084 .33058 L
s
.81083 .3306 m
.81084 .3306 L
s
1 .39 0 r
.65144 .55011 m
.64913 .54876 L
s
.64913 .54876 m
.64984 .54633 L
s
1 .002 0 r
.81084 .3306 m
.81085 .33059 L
s
1 .005 0 r
.49741 .42409 m
.49746 .42411 L
s
.49741 .42409 m
.49745 .42406 L
s
.49764 .42406 m
.49741 .42409 L
s
1 .046 0 r
.56372 .2686 m
.56377 .26819 L
s
1 .005 0 r
.49745 .42406 m
.49746 .42411 L
s
1 .021 0 r
.74633 .48639 m
.74595 .4859 L
s
1 0 0 r
.24896 .36173 m
.24896 .36172 L
s
1 .038 0 r
.31343 .20589 m
.3147 .20521 L
s
1 0 0 r
.24896 .36172 m
.24896 .36172 L
s
.24896 .36172 m
.24896 .36172 L
s
.24896 .36172 m
.24896 .36172 L
s
.24896 .36172 m
.24896 .36172 L
s
.24896 .36172 m
.24896 .36172 L
s
.24896 .36172 m
.24896 .36172 L
s
.24896 .36172 m
.24896 .36172 L
s
.24896 .36172 m
.24896 .36172 L
s
1 .59 0 r
.57256 .51287 m
.57481 .51411 L
s
.57256 .51287 m
.56835 .51415 L
s
.808 1 0 r
.64383 .61093 m
.63647 .6174 L
s
.63631 .6052 m
.64383 .61093 L
s
1 .215 0 r
.40267 .51733 m
.40388 .51763 L
s
.40396 .51541 m
.40267 .51733 L
s
.40267 .51733 m
.40288 .51597 L
s
.40496 .51706 m
.40267 .51733 L
s
.40893 .51325 m
.40267 .51733 L
s
1 .021 0 r
.74601 .48589 m
.74615 .48596 L
s
.7459 .48604 m
.74601 .48589 L
s
.74601 .48589 m
.74595 .4859 L
s
.74603 .48611 m
.7459 .48604 L
s
.7459 .48604 m
.74595 .4859 L
s
1 .038 0 r
.3146 .20548 m
.31443 .20552 L
s
.31446 .20517 m
.3146 .20548 L
s
.3147 .20521 m
.3146 .20548 L
s
.31429 .20521 m
.31446 .20517 L
s
.31446 .20517 m
.3147 .20521 L
s
1 .021 0 r
.74615 .48596 m
.74603 .48611 L
s
.74595 .4859 m
.74615 .48596 L
s
.74595 .4859 m
.74603 .48611 L
s
1 .215 0 r
.40396 .51541 m
.40288 .51597 L
s
.40496 .51706 m
.40396 .51541 L
s
.40388 .51763 m
.40496 .51706 L
s
1 .038 0 r
.31443 .20552 m
.31429 .20521 L
s
.3147 .20521 m
.31443 .20552 L
s
.31429 .20521 m
.3147 .20521 L
s
1 .575 0 r
.67853 .61316 m
.67476 .61046 L
s
.67476 .61046 m
.67776 .60732 L
s
.939 1 0 r
.6017 .54795 m
.59581 .55531 L
s
.5914 .54503 m
.6017 .54795 L
s
1 .009 0 r
.74304 .29835 m
.74299 .29836 L
s
.74299 .29828 m
.74304 .29835 L
s
.74304 .29835 m
.74295 .29834 L
s
.74303 .29829 m
.74304 .29835 L
s
.74278 .29818 m
.74304 .29835 L
s
.74299 .29828 m
.74295 .29834 L
s
.74303 .29829 m
.74299 .29828 L
s
.74295 .29834 m
.74299 .29836 L
s
.74299 .29836 m
.74303 .29829 L
s
1 .062 0 r
.49617 .2359 m
.49612 .23593 L
s
.49612 .23534 m
.49617 .2359 L
s
.49666 .23559 m
.49617 .2359 L
s
1 .003 0 r
.11605 .48537 m
.11605 .48537 L
s
.11605 .48534 m
.11605 .48537 L
s
.11605 .48537 m
.11604 .48535 L
s
.11607 .48536 m
.11605 .48537 L
s
.11607 .4853 m
.11605 .48537 L
s
.11605 .48534 m
.11604 .48535 L
s
.11607 .48536 m
.11605 .48534 L
s
.11605 .48537 m
.11607 .48536 L
s
.11604 .48535 m
.11605 .48537 L
s
1 .062 0 r
.49607 .23537 m
.49612 .23534 L
s
.49612 .23534 m
.49666 .23559 L
s
1 .046 0 r
.29586 .51648 m
.29599 .5165 L
s
.29602 .51603 m
.29586 .51648 L
s
.29586 .51648 m
.29573 .5162 L
s
.29628 .51634 m
.29586 .51648 L
s
.29657 .51541 m
.29586 .51648 L
s
.542 1 0 r
.61375 .61004 m
.58402 .57794 L
s
1 .014 0 r
.67827 .45411 m
.67787 .45383 L
s
1 0 0 r
.42943 .39174 m
.42943 .39174 L
s
1 .062 0 r
.49394 .23581 m
.49666 .23559 L
s
1 .001 0 r
.18058 .32937 m
.1806 .32934 L
s
.1806 .32934 m
.1806 .32935 L
s
.18059 .32934 m
.1806 .32934 L
s
.1806 .32934 m
.1806 .32934 L
s
.1806 .32935 m
.1806 .32935 L
s
.1806 .32934 m
.1806 .32935 L
s
.1806 .32935 m
.18059 .32934 L
s
.18059 .32934 m
.1806 .32934 L
s
.1806 .32934 m
.1806 .32935 L
s
1 .046 0 r
.29602 .51603 m
.29573 .5162 L
s
.29628 .51634 m
.29602 .51603 L
s
.29599 .5165 m
.29628 .51634 L
s
1 .014 0 r
.67794 .45382 m
.67802 .45385 L
s
.67788 .45392 m
.67794 .45382 L
s
.67794 .45382 m
.67787 .45383 L
s
.67795 .45396 m
.67788 .45392 L
s
.67788 .45392 m
.67787 .45383 L
s
1 .062 0 r
.49666 .23559 m
.49612 .23593 L
s
.49607 .23537 m
.49666 .23559 L
s
1 .014 0 r
.67802 .45385 m
.67795 .45396 L
s
.67787 .45383 m
.67802 .45385 L
s
.67787 .45383 m
.67795 .45396 L
s
1 .39 0 r
.65359 .54741 m
.65144 .55011 L
s
.64984 .54633 m
.65359 .54741 L
s
1 .046 0 r
.29573 .5162 m
.29599 .5165 L
s
1 .575 0 r
.68202 .60976 m
.67853 .61316 L
s
.67776 .60732 m
.68202 .60976 L
s
1 .062 0 r
.49612 .23593 m
.49607 .23537 L
s
1 .215 0 r
.40288 .51597 m
.40388 .51763 L
s
1 .39 0 r
.64984 .54633 m
.65144 .55011 L
s
1 .026 0 r
.67536 .26617 m
.67546 .2662 L
s
.67544 .26595 m
.67536 .26617 L
s
.67564 .26615 m
.67536 .26617 L
s
.939 1 0 r
.5914 .54503 m
.59581 .55531 L
s
1 .026 0 r
.67554 .26598 m
.67544 .26595 L
s
.67544 .26595 m
.67564 .26615 L
s
.67564 .26615 m
.67546 .2662 L
s
.67554 .26598 m
.67564 .26615 L
s
.67468 .26576 m
.67564 .26615 L
s
1 .271 0 r
.31715 .60929 m
.31758 .60945 L
s
.31776 .60657 m
.31715 .60929 L
s
.31715 .60929 m
.31598 .60774 L
s
.31935 .60828 m
.31715 .60929 L
s
.31977 .60289 m
.31715 .60929 L
s
1 .026 0 r
.67546 .2662 m
.67554 .26598 L
s
1 0 0 r
.04756 .45301 m
.04756 .45301 L
s
.04756 .453 m
.04756 .45301 L
s
.04756 .45301 m
.04756 .453 L
s
.04757 .453 m
.04756 .45301 L
s
.04757 .45299 m
.04756 .45301 L
s
.04756 .453 m
.04756 .453 L
s
.04757 .453 m
.04756 .453 L
s
.04756 .45301 m
.04757 .453 L
s
.04756 .453 m
.04756 .45301 L
s
1 .006 0 r
.85912 .4842 m
.85906 .48406 L
s
0 1 .331 r
.54556 .57782 m
.44533 .561 L
s
1 .003 0 r
.61012 .42179 m
.61 .42175 L
s
1 .001 0 r
.36112 .35938 m
.36115 .35936 L
s
1 .063 0 r
.42568 .20335 m
.42831 .20271 L
s
1 .001 0 r
.36115 .35937 m
.36114 .35937 L
s
.36114 .35936 m
.36115 .35937 L
s
.36115 .35936 m
.36115 .35937 L
s
.36114 .35936 m
.36114 .35936 L
s
.36114 .35936 m
.36115 .35936 L
s
.36114 .35937 m
.36114 .35936 L
s
.36115 .35936 m
.36114 .35937 L
s
.36114 .35936 m
.36115 .35936 L
s
1 .003 0 r
.61002 .42177 m
.61001 .42177 L
s
.61001 .42177 m
.61002 .42174 L
s
.61001 .42177 m
.61 .42175 L
s
.61002 .42174 m
.61003 .42174 L
s
.61002 .42174 m
.61 .42175 L
s
.61 .42175 m
.61002 .42177 L
s
.61 .42175 m
.61003 .42174 L
s
.61003 .42174 m
.61002 .42177 L
s
1 .006 0 r
.85907 .48406 m
.85911 .48408 L
s
.85904 .4841 m
.85907 .48406 L
s
.85907 .48406 m
.85906 .48406 L
s
.85907 .48412 m
.85904 .4841 L
s
.85904 .4841 m
.85906 .48406 L
s
.85911 .48408 m
.85907 .48412 L
s
.85906 .48406 m
.85911 .48408 L
s
.85906 .48406 m
.85907 .48412 L
s
1 .063 0 r
.42793 .2031 m
.42778 .20314 L
s
.42779 .20254 m
.42793 .2031 L
s
.42831 .20271 m
.42793 .2031 L
s
.42764 .20258 m
.42779 .20254 L
s
.42779 .20254 m
.42831 .20271 L
s
1 .271 0 r
.31776 .60657 m
.31598 .60774 L
s
.31935 .60828 m
.31776 .60657 L
s
1 .575 0 r
.67776 .60732 m
.67853 .61316 L
s
1 .063 0 r
.42831 .20271 m
.42778 .20314 L
s
.42764 .20258 m
.42831 .20271 L
s
1 .052 0 r
.60814 .23387 m
.60825 .2339 L
s
.60824 .23341 m
.60814 .23387 L
s
.60868 .23375 m
.60814 .23387 L
s
1 .063 0 r
.42778 .20314 m
.42764 .20258 L
s
1 .052 0 r
.60835 .23344 m
.60824 .23341 L
s
.60824 .23341 m
.60868 .23375 L
s
.60868 .23375 m
.60825 .2339 L
s
.60835 .23344 m
.60868 .23375 L
s
.60648 .2333 m
.60868 .23375 L
s
1 .271 0 r
.31758 .60945 m
.31935 .60828 L
s
1 .008 0 r
.22803 .4833 m
.22804 .48331 L
s
.22805 .48322 m
.22803 .4833 L
s
.22803 .4833 m
.228 .48325 L
s
.2281 .48328 m
.22803 .4833 L
s
.22813 .4831 m
.22803 .4833 L
s
.22805 .48322 m
.228 .48325 L
s
.2281 .48328 m
.22805 .48322 L
s
.22804 .48331 m
.2281 .48328 L
s
1 .052 0 r
.60825 .2339 m
.60835 .23344 L
s
1 .008 0 r
.228 .48325 m
.22804 .48331 L
s
1 .003 0 r
.79104 .45188 m
.79098 .4518 L
s
1 .293 0 r
.72645 .608 m
.72406 .60099 L
s
1 0 0 r
.54189 .38943 m
.54189 .38943 L
s
1 .003 0 r
.29273 .32697 m
.29281 .32692 L
s
1 .057 0 r
.35733 .17085 m
.35949 .17 L
s
.808 1 0 r
.63631 .6052 m
.63647 .6174 L
s
0 1 .331 r
.62344 .57166 m
.61723 .59515 L
s
1 .59 0 r
.57481 .51411 m
.57265 .51896 L
s
.56835 .51415 m
.57265 .51896 L
s
1 .003 0 r
.29279 .32692 m
.2928 .32694 L
s
.29278 .32692 m
.29279 .32692 L
s
.29279 .32692 m
.29281 .32692 L
s
.2928 .32694 m
.29279 .32694 L
s
.29281 .32692 m
.2928 .32694 L
s
.29279 .32694 m
.29278 .32692 L
s
.29278 .32692 m
.29281 .32692 L
s
.29281 .32692 m
.29279 .32694 L
s
.79099 .4518 m
.79101 .45181 L
s
.79098 .45182 m
.79099 .4518 L
s
.79099 .4518 m
.79098 .4518 L
s
.791 .45183 m
.79098 .45182 L
s
.79098 .45182 m
.79098 .4518 L
s
.79101 .45181 m
.791 .45183 L
s
.79098 .4518 m
.79101 .45181 L
s
.79098 .4518 m
.791 .45183 L
s
1 .59 0 r
.56835 .51415 m
.57481 .51411 L
s
1 .271 0 r
.31598 .60774 m
.31758 .60945 L
s
1 .028 0 r
.09501 .60766 m
.09498 .60767 L
s
.09502 .60738 m
.09501 .60766 L
s
.09501 .60766 m
.09482 .60751 L
s
.09518 .60754 m
.09501 .60766 L
s
.09498 .60698 m
.09501 .60766 L
s
1 .057 0 r
.35924 .17039 m
.35904 .17043 L
s
.35907 .16991 m
.35924 .17039 L
s
.35949 .17 m
.35924 .17039 L
s
.35886 .16994 m
.35907 .16991 L
s
.35907 .16991 m
.35949 .17 L
s
1 .028 0 r
.09502 .60738 m
.09482 .60751 L
s
.09518 .60754 m
.09502 .60738 L
s
.09498 .60767 m
.09518 .60754 L
s
.09482 .60751 m
.09498 .60767 L
s
1 .59 0 r
.50051 .51454 m
.50068 .51369 L
s
.50068 .51369 m
.50055 .50844 L
s
.50068 .51369 m
.49527 .51159 L
s
1 .057 0 r
.35949 .17 m
.35904 .17043 L
s
.35886 .16994 m
.35949 .17 L
s
.35904 .17043 m
.35886 .16994 L
s
1 .073 0 r
.54078 .2012 m
.54081 .20122 L
s
.54081 .20053 m
.54078 .2012 L
s
.54146 .20089 m
.54078 .2012 L
s
.54083 .20055 m
.54081 .20053 L
s
.54081 .20053 m
.54146 .20089 L
s
1 .011 0 r
.78784 .26353 m
.78778 .26353 L
s
.78777 .26343 m
.78784 .26353 L
s
.78784 .26353 m
.78772 .26351 L
s
.78783 .26345 m
.78784 .26353 L
s
.78752 .26329 m
.78784 .26353 L
s
.78777 .26343 m
.78772 .26351 L
s
.78783 .26345 m
.78777 .26343 L
s
.78772 .26351 m
.78778 .26353 L
s
.78778 .26353 m
.78783 .26345 L
s
1 .073 0 r
.54146 .20089 m
.54081 .20122 L
s
.54083 .20055 m
.54146 .20089 L
s
.5382 .2008 m
.54146 .20089 L
s
1 .001 0 r
.1596 .45079 m
.15961 .45079 L
s
.15961 .45077 m
.1596 .45079 L
s
.1596 .45079 m
.1596 .45078 L
s
.15961 .45078 m
.1596 .45079 L
s
.15962 .45076 m
.1596 .45079 L
s
.15961 .45077 m
.1596 .45078 L
s
.15961 .45078 m
.15961 .45077 L
s
.15961 .45079 m
.15961 .45078 L
s
.1596 .45078 m
.15961 .45079 L
s
1 .525 0 r
.65824 .57574 m
.64796 .56406 L
s
1 .001 0 r
.72288 .41951 m
.72286 .41949 L
s
1 .002 0 r
.47357 .35702 m
.47365 .35701 L
s
1 .004 0 r
.22425 .29453 m
.22436 .29443 L
s
1 .002 0 r
.47363 .35702 m
.47363 .35702 L
s
.47363 .357 m
.47363 .35702 L
s
.47365 .35701 m
.47363 .35702 L
s
.47363 .357 m
.47363 .357 L
s
.47363 .357 m
.47365 .35701 L
s
1 .001 0 r
.72286 .41949 m
.72287 .4195 L
s
.72286 .4195 m
.72286 .41949 L
s
.72286 .41949 m
.72286 .41949 L
s
.72286 .4195 m
.72286 .4195 L
s
.72286 .4195 m
.72286 .41949 L
s
1 .002 0 r
.47365 .35701 m
.47363 .35702 L
s
.47363 .357 m
.47365 .35701 L
s
.47363 .35702 m
.47363 .357 L
s
1 .001 0 r
.72287 .4195 m
.72286 .4195 L
s
.72286 .41949 m
.72287 .4195 L
s
.72286 .41949 m
.72286 .4195 L
s
0 .813 1 r
.51549 .48805 m
.5334 .49873 L
s
.4976 .51015 m
.51549 .48805 L
s
.51549 .48805 m
.50164 .48956 L
s
1 .004 0 r
.22434 .29443 m
.22436 .29446 L
s
.22431 .29444 m
.22434 .29443 L
s
.22434 .29443 m
.22436 .29443 L
s
.22436 .29446 m
.22433 .29447 L
s
.22436 .29443 m
.22436 .29446 L
s
.22433 .29447 m
.22431 .29444 L
s
.22431 .29444 m
.22436 .29443 L
s
.22436 .29443 m
.22433 .29447 L
s
0 1 .511 r
.61911 .58707 m
.6347 .60291 L
s
.60423 .59783 m
.61911 .58707 L
s
.61911 .58707 m
.62663 .58832 L
s
1 .323 0 r
.35786 .57563 m
.35898 .57589 L
s
.35915 .57249 m
.35786 .57563 L
s
.35786 .57563 m
.35719 .57365 L
s
.36094 .57473 m
.35786 .57563 L
s
.3639 .56841 m
.35786 .57563 L
s
1 .073 0 r
.54081 .20122 m
.54083 .20055 L
s
1 .59 0 r
.50055 .50844 m
.50037 .50928 L
s
.50055 .50844 m
.49527 .51159 L
s
1 .077 0 r
.20699 .6068 m
.207 .60684 L
s
.20708 .60602 m
.20699 .6068 L
s
.20699 .6068 m
.20655 .60638 L
s
.20753 .60648 m
.20699 .6068 L
s
.20723 .60494 m
.20699 .6068 L
s
.20708 .60602 m
.20655 .60638 L
s
.20753 .60648 m
.20708 .60602 L
s
1 .032 0 r
.33974 .4816 m
.33988 .48162 L
s
.3399 .4813 m
.33974 .4816 L
s
.33974 .4816 m
.33971 .48139 L
s
.34006 .48153 m
.33974 .4816 L
s
.34048 .4809 m
.33974 .4816 L
s
.3399 .4813 m
.33971 .48139 L
s
.34006 .48153 m
.3399 .4813 L
s
.33988 .48162 m
.34006 .48153 L
s
.717 1 0 r
.4331 .5746 m
.43703 .5854 L
s
1 .077 0 r
.207 .60684 m
.20753 .60648 L
s
1 .032 0 r
.33971 .48139 m
.33988 .48162 L
s
1 .077 0 r
.20655 .60638 m
.207 .60684 L
s
1 .028 0 r
.71998 .23128 m
.7201 .23131 L
s
.72009 .23104 m
.71998 .23128 L
s
.72029 .23127 m
.71998 .23128 L
s
.72029 .23127 m
.7201 .23131 L
s
.72009 .23104 m
.72029 .23127 L
s
.72021 .23108 m
.72029 .23127 L
s
.71931 .23078 m
.72029 .23127 L
s
.72021 .23108 m
.72009 .23104 L
s
1 .323 0 r
.35915 .57249 m
.35719 .57365 L
s
.36094 .57473 m
.35915 .57249 L
s
1 .028 0 r
.7201 .23131 m
.72021 .23108 L
s
1 .323 0 r
.35898 .57589 m
.36094 .57473 L
s
1 .08 0 r
.47273 .16826 m
.47263 .16827 L
s
.47264 .16753 m
.47273 .16826 L
s
.47334 .16782 m
.47273 .16826 L
s
1 0 0 r
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
.09101 .41837 m
.09101 .41837 L
s
1 .08 0 r
.83942 .60596 m
.83918 .60401 L
s
1 .825 0 r
.58995 .54343 m
.56008 .53122 L
s
1 0 0 r
.65463 .38711 m
.65463 .38711 L
s
1 .08 0 r
.46984 .16825 m
.47334 .16782 L
s
1 .007 0 r
.40516 .32458 m
.40542 .32448 L
s
.40539 .32453 m
.40537 .32454 L
s
.40537 .32447 m
.40539 .32453 L
s
.40542 .32448 m
.40539 .32453 L
s
.40534 .32448 m
.40537 .32447 L
s
.40537 .32447 m
.40542 .32448 L
s
1 .08 0 r
.47254 .16755 m
.47264 .16753 L
s
.47264 .16753 m
.47334 .16782 L
s
1 .007 0 r
.40542 .32448 m
.40537 .32454 L
s
.40534 .32448 m
.40542 .32448 L
s
.40537 .32454 m
.40534 .32448 L
s
.542 1 0 r
.43102 .60901 m
.43593 .60577 L
s
.43593 .60577 m
.43146 .5935 L
s
.43593 .60577 m
.42 .60468 L
s
1 .08 0 r
.47334 .16782 m
.47263 .16827 L
s
.47254 .16755 m
.47334 .16782 L
s
1 .133 0 r
.44899 .48072 m
.44943 .48049 L
s
.44943 .48049 m
.44902 .47936 L
s
.44943 .48049 m
.44798 .48038 L
s
1 .053 0 r
.65258 .19896 m
.65274 .199 L
s
.65272 .1985 m
.65258 .19896 L
s
.65316 .19888 m
.65258 .19896 L
s
1 .133 0 r
.44902 .47936 m
.44858 .4796 L
s
.44902 .47936 m
.44798 .48038 L
s
1 .053 0 r
.65287 .19853 m
.65272 .1985 L
s
.65272 .1985 m
.65316 .19888 L
s
1 .08 0 r
.47263 .16827 m
.47254 .16755 L
s
1 .133 0 r
.44798 .48038 m
.44899 .48072 L
s
.44798 .48038 m
.44858 .4796 L
s
.45312 .47869 m
.44798 .48038 L
s
1 .053 0 r
.65316 .19888 m
.65274 .199 L
s
.65287 .19853 m
.65316 .19888 L
s
.65101 .19824 m
.65316 .19888 L
s
1 .59 0 r
.49527 .51159 m
.50051 .51454 L
s
.49527 .51159 m
.50037 .50928 L
s
.52158 .51108 m
.49527 .51159 L
s
1 .053 0 r
.65274 .199 m
.65287 .19853 L
s
.542 1 0 r
.43146 .5935 m
.42653 .59668 L
s
.43146 .5935 m
.42 .60468 L
s
1 .004 0 r
.27188 .4486 m
.27189 .4486 L
s
.27189 .44856 m
.27188 .4486 L
s
.27188 .4486 m
.27187 .44858 L
s
.27191 .44859 m
.27188 .4486 L
s
.27195 .44851 m
.27188 .4486 L
s
.27189 .44856 m
.27187 .44858 L
s
.27191 .44859 m
.27189 .44856 L
s
.27189 .4486 m
.27191 .44859 L
s
.27187 .44858 m
.27189 .4486 L
s
1 .002 0 r
.58635 .35468 m
.58635 .35468 L
s
.58635 .35466 m
.58635 .35468 L
s
.58637 .35467 m
.58635 .35468 L
s
.58636 .35466 m
.58635 .35466 L
s
.58635 .35466 m
.58637 .35467 L
s
.58637 .35467 m
.58635 .35468 L
s
.58636 .35466 m
.58637 .35467 L
s
.5863 .35466 m
.58637 .35467 L
s
.58635 .35468 m
.58636 .35466 L
s
1 .114 0 r
.7712 .57365 m
.77011 .57091 L
s
1 0 0 r
.83592 .41723 m
.83592 .41722 L
s
1 .01 0 r
.33667 .29209 m
.337 .29191 L
s
1 0 0 r
.83592 .41722 m
.83592 .41722 L
s
.83592 .41723 m
.83592 .41722 L
s
.83592 .41722 m
.83592 .41722 L
s
.83592 .41723 m
.83592 .41723 L
s
.83592 .41723 m
.83592 .41722 L
s
.83592 .41722 m
.83592 .41723 L
s
.83592 .41722 m
.83592 .41722 L
s
.83592 .41722 m
.83592 .41723 L
s
1 .323 0 r
.35719 .57365 m
.35898 .57589 L
s
1 .01 0 r
.33698 .29198 m
.33693 .29199 L
s
.33694 .2919 m
.33698 .29198 L
s
.337 .29191 m
.33698 .29198 L
s
.33689 .29191 m
.33694 .2919 L
s
.33694 .2919 m
.337 .29191 L
s
1 .133 0 r
.44858 .4796 m
.44899 .48072 L
s
1 .01 0 r
.33693 .29199 m
.33689 .29191 L
s
.337 .29191 m
.33693 .29199 L
s
.33689 .29191 m
.337 .29191 L
s
.542 1 0 r
.42 .60468 m
.43102 .60901 L
s
.42 .60468 m
.42653 .59668 L
s
.47668 .58733 m
.42 .60468 L
s
0 1 .077 r
.45679 .54207 m
.47448 .55596 L
s
.45679 .54207 m
.47821 .5378 L
s
1 .08 0 r
.83919 .60398 m
.83974 .60436 L
s
.83872 .60445 m
.83919 .60398 L
s
.83919 .60398 m
.83918 .60401 L
s
1 .026 0 r
.13849 .57326 m
.13849 .57327 L
s
.13852 .57299 m
.13849 .57326 L
s
.13849 .57326 m
.13834 .57311 L
s
.13868 .57315 m
.13849 .57326 L
s
.13857 .57261 m
.13849 .57326 L
s
.13852 .57299 m
.13834 .57311 L
s
.13868 .57315 m
.13852 .57299 L
s
1 .08 0 r
.83927 .60483 m
.83872 .60445 L
s
.83872 .60445 m
.83918 .60401 L
s
1 .077 0 r
.58522 .16633 m
.58533 .16635 L
s
.58531 .16564 m
.58522 .16633 L
s
.58599 .16608 m
.58522 .16633 L
s
1 .026 0 r
.13849 .57327 m
.13868 .57315 L
s
.13834 .57311 m
.13849 .57327 L
s
1 .077 0 r
.58542 .16565 m
.58531 .16564 L
s
.58531 .16564 m
.58599 .16608 L
s
1 .08 0 r
.83974 .60436 m
.83927 .60483 L
s
.83918 .60401 m
.83974 .60436 L
s
1 .077 0 r
.58599 .16608 m
.58533 .16635 L
s
.58542 .16565 m
.58599 .16608 L
s
.58263 .16565 m
.58599 .16608 L
s
1 .08 0 r
.83918 .60401 m
.83927 .60483 L
s
0 .813 1 r
.51539 .52103 m
.4976 .51015 L
s
.4976 .51015 m
.50164 .48956 L
s
1 .077 0 r
.58533 .16635 m
.58542 .16565 L
s
1 .01 0 r
.51825 .32221 m
.51824 .32222 L
s
.51824 .32211 m
.51825 .32221 L
s
.51834 .32216 m
.51825 .32221 L
s
.51824 .32212 m
.51824 .32211 L
s
.51824 .32211 m
.51834 .32216 L
s
1 0 0 r
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
.20333 .41609 m
.20333 .41609 L
s
1 .166 0 r
.7029 .5413 m
.69976 .53755 L
s
1 0 0 r
.76766 .38478 m
.76766 .38478 L
s
1 .01 0 r
.51787 .32217 m
.51834 .32216 L
s
1 .011 0 r
.26809 .25956 m
.26842 .25933 L
s
1 .01 0 r
.51834 .32216 m
.51824 .32222 L
s
.51824 .32212 m
.51834 .32216 L
s
.51824 .32222 m
.51824 .32212 L
s
1 .59 0 r
.50037 .50928 m
.50051 .51454 L
s
0 1 .331 r
.46532 .57674 m
.4616 .57248 L
s
.4616 .57248 m
.46576 .55213 L
s
.4616 .57248 m
.44533 .561 L
s
1 .011 0 r
.26836 .25932 m
.26841 .25941 L
s
.2683 .25934 m
.26836 .25932 L
s
.26836 .25932 m
.26842 .25933 L
s
.26841 .25941 m
.26835 .25943 L
s
.26842 .25933 m
.26841 .25941 L
s
1 .081 0 r
.25039 .57247 m
.25049 .57251 L
s
.25056 .57166 m
.25039 .57247 L
s
.25039 .57247 m
.25002 .572 L
s
.25104 .57217 m
.25039 .57247 L
s
.25109 .57051 m
.25039 .57247 L
s
1 .011 0 r
.26835 .25943 m
.2683 .25934 L
s
.2683 .25934 m
.26842 .25933 L
s
.26842 .25933 m
.26835 .25943 L
s
1 .081 0 r
.25056 .57166 m
.25002 .572 L
s
.25104 .57217 m
.25056 .57166 L
s
.25049 .57251 m
.25104 .57217 L
s
1 .029 0 r
.76505 .19623 m
.76488 .19625 L
s
.76485 .19598 m
.76505 .19623 L
s
.76505 .19623 m
.76474 .19621 L
s
.76499 .19601 m
.76505 .19623 L
s
.76411 .19567 m
.76505 .19623 L
s
.76474 .19621 m
.76488 .19625 L
s
.76485 .19598 m
.76474 .19621 L
s
1 .081 0 r
.25002 .572 m
.25049 .57251 L
s
1 .029 0 r
.76499 .19601 m
.76485 .19598 L
s
.76488 .19625 m
.76499 .19601 L
s
1 .293 0 r
.72444 .60084 m
.72638 .60214 L
s
.7227 .60266 m
.72444 .60084 L
s
.72444 .60084 m
.72406 .60099 L
s
1 .014 0 r
.38412 .44652 m
.38421 .44654 L
s
.38421 .4464 m
.38412 .44652 L
s
.38412 .44652 m
.38415 .44643 L
s
.38428 .44651 m
.38412 .44652 L
s
.38457 .44626 m
.38412 .44652 L
s
.38421 .44654 m
.38428 .44651 L
s
.38428 .44651 m
.38421 .4464 L
s
.38421 .4464 m
.38415 .44643 L
s
1 .009 0 r
.0698 .54045 m
.0698 .54046 L
s
.06981 .54037 m
.0698 .54045 L
s
.0698 .54045 m
.06975 .5404 L
s
.06986 .54042 m
.0698 .54045 L
s
.06983 .54024 m
.0698 .54045 L
s
1 .114 0 r
.77029 .57086 m
.77104 .57133 L
s
.76962 .57158 m
.77029 .57086 L
s
.77029 .57086 m
.77011 .57091 L
s
1 .009 0 r
.06981 .54037 m
.06975 .5404 L
s
.06986 .54042 m
.06981 .54037 L
s
.0698 .54046 m
.06986 .54042 L
s
.06975 .5404 m
.0698 .54046 L
s
1 .014 0 r
.38415 .44643 m
.38421 .44654 L
s
0 1 .511 r
.6347 .60291 m
.61987 .61378 L
s
.62663 .58832 m
.6347 .60291 L
s
1 .114 0 r
.77038 .57206 m
.76962 .57158 L
s
.76962 .57158 m
.77011 .57091 L
s
1 .001 0 r
.69933 .3523 m
.69933 .35231 L
s
.69933 .3523 m
.69933 .3523 L
s
.69933 .3523 m
.69932 .3523 L
s
.69933 .3523 m
.69933 .3523 L
s
.69931 .35229 m
.69933 .3523 L
s
.69932 .3523 m
.69933 .35231 L
s
.69933 .3523 m
.69932 .3523 L
s
.69933 .3523 m
.69933 .3523 L
s
.69933 .35231 m
.69933 .3523 L
s
1 .034 0 r
.88445 .57156 m
.88431 .57073 L
s
1 .215 0 r
.63451 .50891 m
.62773 .50505 L
s
1 .02 0 r
.44937 .28964 m
.4502 .28947 L
s
1 0 0 r
.13463 .38362 m
.13463 .38362 L
s
1 .02 0 r
.45007 .28959 m
.45003 .2896 L
s
.45004 .28941 m
.45007 .28959 L
s
.4502 .28947 m
.45007 .28959 L
s
.44999 .28943 m
.45004 .28941 L
s
.45004 .28941 m
.4502 .28947 L
s
1 .336 0 r
.39837 .54015 m
.40026 .54064 L
s
.4004 .53713 m
.39837 .54015 L
s
.39837 .54015 m
.3987 .53804 L
s
.40196 .53973 m
.39837 .54015 L
s
.40819 .53381 m
.39837 .54015 L
s
1 .02 0 r
.4502 .28947 m
.45003 .2896 L
s
.44999 .28943 m
.4502 .28947 L
s
.45003 .2896 m
.44999 .28943 L
s
1 .114 0 r
.77104 .57133 m
.77038 .57206 L
s
.77011 .57091 m
.77104 .57133 L
s
1 .293 0 r
.72463 .60396 m
.7227 .60266 L
s
.7227 .60266 m
.72406 .60099 L
s
1 .051 0 r
.69712 .16385 m
.6973 .16389 L
s
.69728 .16341 m
.69712 .16385 L
s
.69768 .1638 m
.69712 .16385 L
s
1 .114 0 r
.77011 .57091 m
.77038 .57206 L
s
1 .051 0 r
.69746 .16344 m
.69728 .16341 L
s
.69728 .16341 m
.69768 .1638 L
s
1 .336 0 r
.4004 .53713 m
.3987 .53804 L
s
.40196 .53973 m
.4004 .53713 L
s
1 .051 0 r
.69768 .1638 m
.6973 .16389 L
s
.69746 .16344 m
.69768 .1638 L
s
.69571 .16304 m
.69768 .1638 L
s
1 .336 0 r
.40026 .54064 m
.40196 .53973 L
s
1 .034 0 r
.88432 .57072 m
.88455 .57087 L
s
.88412 .57092 m
.88432 .57072 L
s
.88432 .57072 m
.88431 .57073 L
s
.88435 .57107 m
.88412 .57092 L
s
.88412 .57092 m
.88431 .57073 L
s
.88455 .57087 m
.88435 .57107 L
s
.88431 .57073 m
.88455 .57087 L
s
1 .051 0 r
.6973 .16389 m
.69746 .16344 L
s
0 1 .077 r
.47821 .5378 m
.47448 .55596 L
s
1 .034 0 r
.88431 .57073 m
.88435 .57107 L
s
1 .293 0 r
.72638 .60214 m
.72463 .60396 L
s
.72406 .60099 m
.72638 .60214 L
s
1 .007 0 r
.63107 .31985 m
.63109 .31986 L
s
.63109 .3198 m
.63107 .31985 L
s
.63114 .31984 m
.63107 .31985 L
s
.63111 .3198 m
.63109 .3198 L
s
.63109 .3198 m
.63114 .31984 L
s
.63114 .31984 m
.63109 .31986 L
s
.63111 .3198 m
.63114 .31984 L
s
.63087 .31976 m
.63114 .31984 L
s
0 1 .331 r
.46576 .55213 m
.46953 .55622 L
s
.46576 .55213 m
.44533 .561 L
s
1 .007 0 r
.63109 .31986 m
.63111 .3198 L
s
1 .001 0 r
.31592 .41381 m
.31592 .41381 L
s
.31592 .4138 m
.31592 .41381 L
s
.31592 .41381 m
.31592 .4138 L
s
.31592 .41381 m
.31592 .41381 L
s
.31593 .41379 m
.31592 .41381 L
s
.31592 .4138 m
.31592 .4138 L
s
.31592 .41381 m
.31592 .4138 L
s
.31592 .41381 m
.31592 .41381 L
s
.31592 .4138 m
.31592 .41381 L
s
1 .04 0 r
.81613 .53917 m
.81572 .53819 L
s
1 .162 0 r
.56603 .47648 m
.55912 .47525 L
s
1 .023 0 r
.38077 .25707 m
.38167 .25674 L
s
.38157 .25689 m
.38149 .25692 L
s
.3815 .25669 m
.38157 .25689 L
s
.38167 .25674 m
.38157 .25689 L
s
.38141 .25672 m
.3815 .25669 L
s
.3815 .25669 m
.38167 .25674 L
s
1 .293 0 r
.72406 .60099 m
.72463 .60396 L
s
1 .023 0 r
.38167 .25674 m
.38149 .25692 L
s
.38141 .25672 m
.38167 .25674 L
s
.38149 .25692 m
.38141 .25672 L
s
1 .162 0 r
.56051 .47632 m
.56019 .47609 L
s
.56019 .47609 m
.56049 .47467 L
s
.56019 .47609 m
.55912 .47525 L
s
1 .166 0 r
.70035 .53744 m
.70135 .53801 L
s
.69943 .53859 m
.70035 .53744 L
s
.70035 .53744 m
.69976 .53755 L
s
1 .023 0 r
.18215 .53868 m
.18217 .53868 L
s
.1822 .53844 m
.18215 .53868 L
s
.18215 .53868 m
.18204 .53854 L
s
.18233 .53859 m
.18215 .53868 L
s
.18233 .5381 m
.18215 .53868 L
s
1 .162 0 r
.56049 .47467 m
.56081 .4749 L
s
.56049 .47467 m
.55912 .47525 L
s
1 .023 0 r
.1822 .53844 m
.18204 .53854 L
s
.18233 .53859 m
.1822 .53844 L
s
.717 1 0 r
.59237 .5598 m
.59983 .56433 L
s
.58521 .56877 m
.59237 .5598 L
s
.59237 .5598 m
.58725 .5608 L
s
1 .166 0 r
.70044 .53917 m
.69943 .53859 L
s
.69943 .53859 m
.69976 .53755 L
s
1 .023 0 r
.18217 .53868 m
.18233 .53859 L
s
.18204 .53854 m
.18217 .53868 L
s
1 .04 0 r
.81578 .53818 m
.81605 .53834 L
s
.81555 .53843 m
.81578 .53818 L
s
.81578 .53818 m
.81572 .53819 L
s
.81582 .5386 m
.81555 .53843 L
s
.81555 .53843 m
.81572 .53819 L
s
1 .039 0 r
.49611 .44435 m
.49616 .4443 L
s
.49616 .4443 m
.49611 .44396 L
s
.49616 .4443 m
.49577 .44419 L
s
.49611 .44396 m
.49607 .44401 L
s
.49611 .44396 m
.49577 .44419 L
s
1 .04 0 r
.81605 .53834 m
.81582 .5386 L
s
.81572 .53819 m
.81605 .53834 L
s
.81572 .53819 m
.81582 .5386 L
s
1 .039 0 r
.49577 .44419 m
.49611 .44435 L
s
.49577 .44419 m
.49607 .44401 L
s
.49747 .44401 m
.49577 .44419 L
s
1 .021 0 r
.56308 .28735 m
.5631 .28737 L
s
.5631 .28716 m
.56308 .28735 L
s
.56328 .28728 m
.56308 .28735 L
s
.56312 .28718 m
.5631 .28716 L
s
.5631 .28716 m
.56328 .28728 L
s
.56328 .28728 m
.5631 .28737 L
s
.56312 .28718 m
.56328 .28728 L
s
.56235 .28719 m
.56328 .28728 L
s
1 .039 0 r
.49607 .44401 m
.49611 .44435 L
s
1 .021 0 r
.5631 .28737 m
.56312 .28718 L
s
1 0 0 r
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
.81261 .34992 m
.81261 .34992 L
s
1 .046 0 r
.74773 .50674 m
.74689 .50568 L
s
1 0 0 r
.24721 .38128 m
.24721 .38128 L
s
1 .023 0 r
.31209 .22446 m
.31289 .22404 L
s
1 .336 0 r
.3987 .53804 m
.40026 .54064 L
s
1 .166 0 r
.70135 .53801 m
.70044 .53917 L
s
.69976 .53755 m
.70135 .53801 L
s
1 .162 0 r
.55912 .47525 m
.56051 .47632 L
s
.55912 .47525 m
.56081 .4749 L
s
1 .023 0 r
.31282 .22421 m
.31272 .22423 L
s
.31274 .22401 m
.31282 .22421 L
s
.31289 .22404 m
.31282 .22421 L
s
.31263 .22404 m
.31274 .22401 L
s
.31274 .22401 m
.31289 .22404 L
s
1 .166 0 r
.69976 .53755 m
.70044 .53917 L
s
1 .08 0 r
.29388 .53783 m
.2941 .53787 L
s
.29416 .53704 m
.29388 .53783 L
s
.29388 .53783 m
.29365 .53733 L
s
.29461 .53758 m
.29388 .53783 L
s
.29512 .53596 m
.29388 .53783 L
s
1 .215 0 r
.62905 .50471 m
.63006 .50523 L
s
.62811 .50641 m
.62905 .50471 L
s
.62905 .50471 m
.62773 .50505 L
s
.62912 .50694 m
.62811 .50641 L
s
.62811 .50641 m
.62773 .50505 L
s
1 .162 0 r
.56081 .4749 m
.56051 .47632 L
s
1 .023 0 r
.31272 .22423 m
.31263 .22404 L
s
.31289 .22404 m
.31272 .22423 L
s
.31263 .22404 m
.31289 .22404 L
s
1 .08 0 r
.29416 .53704 m
.29365 .53733 L
s
.29461 .53758 m
.29416 .53704 L
s
.2941 .53787 m
.29461 .53758 L
s
1 .046 0 r
.74704 .50566 m
.74733 .50581 L
s
.74679 .50598 m
.74704 .50566 L
s
.74704 .50566 m
.74689 .50568 L
s
.717 1 0 r
.59265 .57333 m
.58521 .56877 L
s
.58521 .56877 m
.58725 .5608 L
s
1 .046 0 r
.74707 .50613 m
.74679 .50598 L
s
.74679 .50598 m
.74689 .50568 L
s
1 .08 0 r
.29365 .53733 m
.2941 .53787 L
s
1 .046 0 r
.74733 .50581 m
.74707 .50613 L
s
.74689 .50568 m
.74733 .50581 L
s
1 .006 0 r
.11344 .50581 m
.11344 .50581 L
s
.11345 .50574 m
.11344 .50581 L
s
.11344 .50581 m
.11341 .50577 L
s
.11349 .50578 m
.11344 .50581 L
s
.11348 .50565 m
.11344 .50581 L
s
.11345 .50574 m
.11341 .50577 L
s
.11349 .50578 m
.11345 .50574 L
s
.11344 .50581 m
.11349 .50578 L
s
.11341 .50577 m
.11344 .50581 L
s
1 .046 0 r
.74689 .50568 m
.74707 .50613 L
s
1 .003 0 r
.74424 .3174 m
.74422 .3174 L
s
.74422 .31738 m
.74424 .3174 L
s
.74424 .3174 m
.74421 .3174 L
s
.74424 .31738 m
.74424 .3174 L
s
.74416 .31735 m
.74424 .3174 L
s
.74422 .31738 m
.74421 .3174 L
s
.74424 .31738 m
.74422 .31738 L
s
.74421 .3174 m
.74422 .3174 L
s
1 .035 0 r
.49501 .25463 m
.49498 .25465 L
s
.49498 .25432 m
.49501 .25463 L
s
.49529 .25446 m
.49501 .25463 L
s
1 .003 0 r
.74422 .3174 m
.74424 .31738 L
s
1 .002 0 r
.42875 .41153 m
.42876 .41153 L
s
.42876 .41153 m
.42875 .41151 L
s
.42876 .41153 m
.42874 .41153 L
s
.42875 .41151 m
.42875 .41151 L
s
.42875 .41151 m
.42874 .41153 L
s
.42874 .41153 m
.42875 .41153 L
s
.42874 .41153 m
.42875 .41151 L
s
.42882 .4115 m
.42874 .41153 L
s
.42875 .41151 m
.42875 .41153 L
s
1 .035 0 r
.49495 .25433 m
.49498 .25432 L
s
.49498 .25432 m
.49529 .25446 L
s
1 .043 0 r
.67924 .47426 m
.67801 .47341 L
s
1 .035 0 r
.49374 .25458 m
.49529 .25446 L
s
1 0 0 r
.1784 .34873 m
.17841 .34873 L
s
.1784 .34873 m
.17841 .34873 L
s
.1784 .34873 m
.1784 .34873 L
s
.1784 .34873 m
.17841 .34873 L
s
.17841 .34873 m
.1784 .34873 L
s
.17841 .34873 m
.17841 .34873 L
s
.1784 .34873 m
.1784 .34873 L
s
.1784 .34873 m
.17841 .34873 L
s
.17841 .34873 m
.1784 .34873 L
s
1 .035 0 r
.49529 .25446 m
.49498 .25465 L
s
.49495 .25433 m
.49529 .25446 L
s
.49498 .25465 m
.49495 .25433 L
s
1 .215 0 r
.63006 .50523 m
.62912 .50694 L
s
.62773 .50505 m
.63006 .50523 L
s
.62773 .50505 m
.62912 .50694 L
s
1 .043 0 r
.67824 .47336 m
.67846 .47347 L
s
.67804 .47369 m
.67824 .47336 L
s
.67824 .47336 m
.67801 .47341 L
s
.67826 .4738 m
.67804 .47369 L
s
.67804 .47369 m
.67801 .47341 L
s
1 .525 0 r
.64993 .56364 m
.65305 .5655 L
s
.64701 .56731 m
.64993 .56364 L
s
.64993 .56364 m
.64796 .56406 L
s
1 .043 0 r
.67846 .47347 m
.67826 .4738 L
s
.67801 .47341 m
.67846 .47347 L
s
.67801 .47341 m
.67826 .4738 L
s
1 .825 0 r
.56614 .53799 m
.563 .53617 L
s
.563 .53617 m
.56603 .52937 L
s
.563 .53617 m
.56008 .53122 L
s
1 .012 0 r
.67593 .28492 m
.67598 .28493 L
s
.67597 .28482 m
.67593 .28492 L
s
.67606 .28491 m
.67593 .28492 L
s
.67602 .28483 m
.67597 .28482 L
s
.67597 .28482 m
.67606 .28491 L
s
.67606 .28491 m
.67598 .28493 L
s
.67602 .28483 m
.67606 .28491 L
s
.67562 .28473 m
.67606 .28491 L
s
.67598 .28493 m
.67602 .28483 L
s
1 .002 0 r
.04453 .47319 m
.04454 .47319 L
s
.04454 .47318 m
.04453 .47319 L
s
.04453 .47319 m
.04453 .47318 L
s
.04455 .47319 m
.04453 .47319 L
s
.04454 .47315 m
.04453 .47319 L
s
.04454 .47318 m
.04453 .47318 L
s
.04455 .47319 m
.04454 .47318 L
s
.04454 .47319 m
.04455 .47319 L
s
.04453 .47318 m
.04454 .47319 L
s
1 .013 0 r
.86123 .50456 m
.8611 .50424 L
s
0 1 .511 r
.54569 .59877 m
.43697 .58075 L
s
1 .024 0 r
.61066 .44175 m
.60974 .44145 L
s
1 0 0 r
.36008 .37894 m
.36008 .37894 L
s
1 .04 0 r
.42505 .22193 m
.42673 .22152 L
s
1 .825 0 r
.56603 .52937 m
.56918 .53117 L
s
.56603 .52937 m
.56008 .53122 L
s
1 .525 0 r
.65014 .56918 m
.64701 .56731 L
s
.64701 .56731 m
.64796 .56406 L
s
1 .417 0 r
.35505 .59867 m
.35649 .59905 L
s
.35672 .5946 m
.35505 .59867 L
s
.35505 .59867 m
.35417 .59613 L
s
.35904 .59752 m
.35505 .59867 L
s
.36287 .58942 m
.35505 .59867 L
s
1 .04 0 r
.42648 .22177 m
.42639 .2218 L
s
.4264 .22142 m
.42648 .22177 L
s
.42673 .22152 m
.42648 .22177 L
s
1 .024 0 r
.60992 .44163 m
.60985 .44159 L
s
.60985 .44159 m
.60992 .44139 L
s
.60985 .44159 m
.60974 .44145 L
s
1 .04 0 r
.4263 .22144 m
.4264 .22142 L
s
.4264 .22142 m
.42673 .22152 L
s
1 .024 0 r
.60992 .44139 m
.61 .44143 L
s
.60992 .44139 m
.60974 .44145 L
s
1 .013 0 r
.86112 .50424 m
.8612 .50429 L
s
.86104 .50432 m
.86112 .50424 L
s
.86112 .50424 m
.8611 .50424 L
s
.86113 .50437 m
.86104 .50432 L
s
.86104 .50432 m
.8611 .50424 L
s
.8612 .50429 m
.86113 .50437 L
s
.8611 .50424 m
.8612 .50429 L
s
.8611 .50424 m
.86113 .50437 L
s
1 .024 0 r
.60974 .44145 m
.60992 .44163 L
s
.60974 .44145 m
.61 .44143 L
s
.61 .44143 m
.60992 .44163 L
s
1 .04 0 r
.42673 .22152 m
.42639 .2218 L
s
.4263 .22144 m
.42673 .22152 L
s
.42639 .2218 m
.4263 .22144 L
s
1 .018 0 r
.22601 .50391 m
.22605 .50392 L
s
.22607 .50373 m
.22601 .50391 L
s
.22601 .50391 m
.22594 .5038 L
s
.22617 .50385 m
.22601 .50391 L
s
.22625 .50346 m
.22601 .50391 L
s
.22607 .50373 m
.22594 .5038 L
s
.22617 .50385 m
.22607 .50373 L
s
1 .825 0 r
.49191 .53654 m
.49219 .53528 L
s
.49219 .53528 m
.492 .52792 L
s
.49219 .53528 m
.48456 .53236 L
s
1 .018 0 r
.22605 .50392 m
.22617 .50385 L
s
.22594 .5038 m
.22605 .50392 L
s
1 .029 0 r
.60793 .2524 m
.60799 .25242 L
s
.60799 .25214 m
.60793 .2524 L
s
.60824 .25233 m
.60793 .2524 L
s
.60805 .25216 m
.60799 .25214 L
s
.60799 .25214 m
.60824 .25233 L
s
.60824 .25233 m
.60799 .25242 L
s
.60805 .25216 m
.60824 .25233 L
s
.607 .25208 m
.60824 .25233 L
s
1 .417 0 r
.35672 .5946 m
.35417 .59613 L
s
.35904 .59752 m
.35672 .5946 L
s
0 1 .511 r
.61987 .61378 m
.60423 .59783 L
s
.60423 .59783 m
.62663 .58832 L
s
1 .029 0 r
.60799 .25242 m
.60805 .25216 L
s
1 .003 0 r
.54188 .4092 m
.54188 .4092 L
s
.54188 .4092 m
.54188 .40917 L
s
.54188 .4092 m
.54185 .40919 L
s
.54188 .40917 m
.54188 .40918 L
s
.54188 .40917 m
.54185 .40919 L
s
1 .011 0 r
.79273 .47204 m
.79254 .47179 L
s
1 .003 0 r
.54199 .40919 m
.54185 .40919 L
s
1 0 0 r
.29126 .34635 m
.29127 .34634 L
s
1 .039 0 r
.35626 .18923 m
.35775 .18865 L
s
1 0 0 r
.29127 .34634 m
.29127 .34634 L
s
.29126 .34634 m
.29127 .34634 L
s
.29127 .34634 m
.29127 .34634 L
s
.29127 .34634 m
.29127 .34634 L
s
.29127 .34634 m
.29127 .34634 L
s
.29127 .34634 m
.29126 .34634 L
s
.29126 .34634 m
.29127 .34634 L
s
.29127 .34634 m
.29127 .34634 L
s
1 .003 0 r
.54185 .40919 m
.54188 .4092 L
s
.54185 .40919 m
.54188 .40918 L
s
.54188 .40918 m
.54188 .4092 L
s
1 .011 0 r
.79257 .47179 m
.79264 .47182 L
s
.79251 .47186 m
.79257 .47179 L
s
.79257 .47179 m
.79254 .47179 L
s
.79258 .47189 m
.79251 .47186 L
s
.79251 .47186 m
.79254 .47179 L
s
.79264 .47182 m
.79258 .47189 L
s
.79254 .47179 m
.79264 .47182 L
s
1 .417 0 r
.35649 .59905 m
.35904 .59752 L
s
1 .011 0 r
.79254 .47179 m
.79258 .47189 L
s
1 .039 0 r
.35758 .18892 m
.35744 .18895 L
s
.35746 .18859 m
.35758 .18892 L
s
.35775 .18865 m
.35758 .18892 L
s
.35732 .18862 m
.35746 .18859 L
s
.35746 .18859 m
.35775 .18865 L
s
.542 1 0 r
.42653 .59668 m
.43102 .60901 L
s
1 .825 0 r
.492 .52792 m
.49172 .52916 L
s
.492 .52792 m
.48456 .53236 L
s
1 .039 0 r
.35775 .18865 m
.35744 .18895 L
s
.35732 .18862 m
.35775 .18865 L
s
.35744 .18895 m
.35732 .18862 L
s
1 .068 0 r
.33773 .50274 m
.33802 .5028 L
s
.33806 .5021 m
.33773 .50274 L
s
.33773 .50274 m
.33767 .5023 L
s
.33842 .5026 m
.33773 .50274 L
s
.33931 .50127 m
.33773 .50274 L
s
.33806 .5021 m
.33767 .5023 L
s
.33842 .5026 m
.33806 .5021 L
s
1 .525 0 r
.65305 .5655 m
.65014 .56918 L
s
.64796 .56406 m
.65305 .5655 L
s
1 .068 0 r
.33802 .5028 m
.33842 .5026 L
s
1 .047 0 r
.53995 .21964 m
.53996 .21965 L
s
.53996 .21921 m
.53995 .21964 L
s
.54038 .21944 m
.53995 .21964 L
s
.53997 .21923 m
.53996 .21921 L
s
.53996 .21921 m
.54038 .21944 L
s
1 .253 0 r
.44474 .50295 m
.44558 .50248 L
s
.44558 .50248 m
.4448 .50032 L
s
.44558 .50248 m
.4428 .50227 L
s
1 .005 0 r
.78932 .28237 m
.78929 .28238 L
s
.78929 .28233 m
.78932 .28237 L
s
.78932 .28237 m
.78927 .28237 L
s
.78932 .28234 m
.78932 .28237 L
s
.78918 .28227 m
.78932 .28237 L
s
1 .004 0 r
.15726 .47102 m
.15726 .47102 L
s
.15727 .47098 m
.15726 .47102 L
s
.15726 .47102 m
.15724 .471 L
s
.15729 .47101 m
.15726 .47102 L
s
.1573 .47093 m
.15726 .47102 L
s
1 .005 0 r
.78929 .28233 m
.78927 .28237 L
s
.78932 .28234 m
.78929 .28233 L
s
.78927 .28237 m
.78929 .28238 L
s
1 .004 0 r
.15727 .47098 m
.15724 .471 L
s
.15729 .47101 m
.15727 .47098 L
s
.15726 .47102 m
.15729 .47101 L
s
.15724 .471 m
.15726 .47102 L
s
1 .005 0 r
.78929 .28238 m
.78932 .28234 L
s
1 .047 0 r
.54038 .21944 m
.53996 .21965 L
s
.53997 .21923 m
.54038 .21944 L
s
.53829 .21938 m
.54038 .21944 L
s
1 .65 0 r
.65909 .5967 m
.64626 .58231 L
s
1 .006 0 r
.72413 .43948 m
.72397 .43935 L
s
1 0 0 r
.47324 .3766 m
.47324 .3766 L
s
1 .001 0 r
.22235 .31371 m
.22238 .31368 L
s
.22237 .31368 m
.22238 .31369 L
s
.22236 .31368 m
.22237 .31368 L
s
.22237 .31368 m
.22238 .31368 L
s
.22238 .31369 m
.22237 .31369 L
s
.22238 .31368 m
.22238 .31369 L
s
.22237 .31369 m
.22236 .31368 L
s
.22236 .31368 m
.22238 .31368 L
s
.22238 .31368 m
.22237 .31369 L
s
1 .253 0 r
.4448 .50032 m
.44396 .50079 L
s
.4448 .50032 m
.4428 .50227 L
s
1 .068 0 r
.33767 .5023 m
.33802 .5028 L
s
1 .006 0 r
.724 .43935 m
.72403 .43936 L
s
.72397 .43939 m
.724 .43935 L
s
.724 .43935 m
.72397 .43935 L
s
1 .047 0 r
.53996 .21965 m
.53997 .21923 L
s
1 .006 0 r
.724 .43941 m
.72397 .43939 L
s
.72397 .43939 m
.72397 .43935 L
s
1 .253 0 r
.4428 .50227 m
.44474 .50295 L
s
.4428 .50227 m
.44396 .50079 L
s
.45266 .49908 m
.4428 .50227 L
s
1 .006 0 r
.72403 .43936 m
.724 .43941 L
s
.72397 .43935 m
.72403 .43936 L
s
.72397 .43935 m
.724 .43941 L
s
1 .525 0 r
.64796 .56406 m
.65014 .56918 L
s
1 .417 0 r
.35417 .59613 m
.35649 .59905 L
s
1 .015 0 r
.72091 .24984 m
.72098 .24986 L
s
.72097 .24971 m
.72091 .24984 L
s
.72108 .24984 m
.72091 .24984 L
s
.72108 .24984 m
.72098 .24986 L
s
.72097 .24971 m
.72108 .24984 L
s
.72103 .24973 m
.72108 .24984 L
s
.72054 .24957 m
.72108 .24984 L
s
.72103 .24973 m
.72097 .24971 L
s
.72098 .24986 m
.72103 .24973 L
s
.717 1 0 r
.59983 .56433 m
.59265 .57333 L
s
.58725 .5608 m
.59983 .56433 L
s
1 .001 0 r
.08825 .43836 m
.08825 .43836 L
s
.08826 .43836 m
.08825 .43836 L
s
.08825 .43836 m
.08825 .43836 L
s
.08826 .43836 m
.08825 .43836 L
s
.08826 .43835 m
.08825 .43836 L
s
.08826 .43836 m
.08825 .43836 L
s
.08826 .43836 m
.08826 .43836 L
s
.08825 .43836 m
.08826 .43836 L
s
.08825 .43836 m
.08825 .43836 L
s
1 .055 0 r
.47151 .18665 m
.47144 .18666 L
s
.47144 .18614 m
.47151 .18665 L
s
.47193 .18634 m
.47151 .18665 L
s
.973 1 0 r
.59036 .5642 m
.55287 .54906 L
s
1 .001 0 r
.65545 .40689 m
.6554 .40686 L
s
1 .055 0 r
.46949 .18664 m
.47193 .18634 L
s
1 .001 0 r
.4044 .34396 m
.40443 .34395 L
s
.40443 .34395 m
.40443 .34395 L
s
.40443 .34395 m
.40443 .34395 L
s
.40443 .34395 m
.40443 .34395 L
s
.40442 .34395 m
.40443 .34395 L
s
.40443 .34395 m
.40443 .34395 L
s
.40443 .34395 m
.40443 .34395 L
s
.40442 .34395 m
.40443 .34395 L
s
.40443 .34395 m
.40442 .34395 L
s
.65541 .40687 m
.65541 .40687 L
s
.65541 .40687 m
.65541 .40686 L
s
.65541 .40687 m
.6554 .40686 L
s
.65541 .40686 m
.65542 .40686 L
s
.65541 .40686 m
.6554 .40686 L
s
.65542 .40686 m
.65541 .40687 L
s
.6554 .40686 m
.65541 .40687 L
s
.6554 .40686 m
.65542 .40686 L
s
1 .055 0 r
.47137 .18616 m
.47144 .18614 L
s
.47144 .18614 m
.47193 .18634 L
s
.47193 .18634 m
.47144 .18666 L
s
.47137 .18616 m
.47193 .18634 L
s
1 .253 0 r
.44396 .50079 m
.44474 .50295 L
s
1 .055 0 r
.47144 .18666 m
.47137 .18616 L
s
1 .825 0 r
.48456 .53236 m
.49191 .53654 L
s
.48456 .53236 m
.49172 .52916 L
s
.52155 .53166 m
.48456 .53236 L
s
1 .033 0 r
.65281 .21729 m
.65291 .21731 L
s
.65289 .21699 m
.65281 .21729 L
s
.65317 .21723 m
.65281 .21729 L
s
.65299 .21702 m
.65289 .21699 L
s
.65289 .21699 m
.65317 .21723 L
s
.65317 .21723 m
.65291 .21731 L
s
.65299 .21702 m
.65317 .21723 L
s
.65181 .21683 m
.65317 .21723 L
s
1 .012 0 r
.27011 .46897 m
.27015 .46897 L
s
.27016 .46885 m
.27011 .46897 L
s
.27011 .46897 m
.27009 .46889 L
s
.27023 .46894 m
.27011 .46897 L
s
.27034 .4687 m
.27011 .46897 L
s
.27016 .46885 m
.27009 .46889 L
s
.27023 .46894 m
.27016 .46885 L
s
.27015 .46897 m
.27023 .46894 L
s
.27009 .46889 m
.27015 .46897 L
s
1 .033 0 r
.65291 .21731 m
.65299 .21702 L
s
1 .459 0 r
.39396 .56324 m
.39655 .56395 L
s
.39674 .5591 m
.39396 .56324 L
s
.39396 .56324 m
.3944 .56038 L
s
.39888 .56267 m
.39396 .56324 L
s
.40745 .55464 m
.39396 .56324 L
s
1 .002 0 r
.83789 .43721 m
.83786 .43717 L
s
1 .158 0 r
.77277 .59463 m
.77124 .59083 L
s
1 0 0 r
.58668 .37425 m
.58668 .37425 L
s
1 .003 0 r
.33547 .31128 m
.33558 .31122 L
s
1 .055 0 r
.4006 .15386 m
.40288 .15326 L
s
.717 1 0 r
.58725 .5608 m
.59265 .57333 L
s
1 .002 0 r
.83787 .43717 m
.83788 .43717 L
s
.83786 .43718 m
.83787 .43717 L
s
.83787 .43717 m
.83786 .43717 L
s
.83787 .43719 m
.83786 .43718 L
s
.83786 .43718 m
.83786 .43717 L
s
1 .003 0 r
.33557 .31124 m
.33556 .31125 L
s
.33556 .31122 m
.33557 .31124 L
s
.33558 .31122 m
.33557 .31124 L
s
.33554 .31122 m
.33556 .31122 L
s
.33556 .31122 m
.33558 .31122 L
s
1 .002 0 r
.83788 .43717 m
.83787 .43719 L
s
.83786 .43717 m
.83788 .43717 L
s
.83786 .43717 m
.83787 .43719 L
s
1 .003 0 r
.33556 .31125 m
.33554 .31122 L
s
.33558 .31122 m
.33556 .31125 L
s
.33554 .31122 m
.33558 .31122 L
s
1 .039 0 r
.136 .59455 m
.136 .59456 L
s
.13605 .59415 m
.136 .59455 L
s
.136 .59455 m
.13577 .59433 L
s
.13628 .59438 m
.136 .59455 L
s
.13612 .59359 m
.136 .59455 L
s
.13605 .59415 m
.13577 .59433 L
s
.13628 .59438 m
.13605 .59415 L
s
1 .055 0 r
.40256 .15361 m
.40241 .15363 L
s
.40244 .15312 m
.40256 .15361 L
s
.40288 .15326 m
.40256 .15361 L
s
1 .825 0 r
.56918 .53117 m
.56614 .53799 L
s
.56008 .53122 m
.56614 .53799 L
s
1 .055 0 r
.40229 .15314 m
.40244 .15312 L
s
.40244 .15312 m
.40288 .15326 L
s
1 .039 0 r
.136 .59456 m
.13628 .59438 L
s
.13577 .59433 m
.136 .59456 L
s
1 .115 0 r
.24835 .59427 m
.2485 .59433 L
s
.2486 .5931 m
.24835 .59427 L
s
.24835 .59427 m
.24782 .5936 L
s
.24927 .59383 m
.24835 .59427 L
s
.24935 .59151 m
.24835 .59427 L
s
1 .459 0 r
.39674 .5591 m
.3944 .56038 L
s
.39888 .56267 m
.39674 .5591 L
s
1 .825 0 r
.56008 .53122 m
.56918 .53117 L
s
1 .459 0 r
.39655 .56395 m
.39888 .56267 L
s
1 .055 0 r
.40288 .15326 m
.40241 .15363 L
s
.40229 .15314 m
.40288 .15326 L
s
.40241 .15363 m
.40229 .15314 L
s
1 .115 0 r
.2486 .5931 m
.24782 .5936 L
s
.24927 .59383 m
.2486 .5931 L
s
1 .053 0 r
.5848 .18452 m
.58488 .18453 L
s
.58486 .18404 m
.5848 .18452 L
s
.58534 .18434 m
.5848 .18452 L
s
.58494 .18405 m
.58486 .18404 L
s
.58486 .18404 m
.58534 .18434 L
s
1 .115 0 r
.2485 .59433 m
.24927 .59383 L
s
1 .053 0 r
.58534 .18434 m
.58488 .18453 L
s
.58494 .18405 m
.58534 .18434 L
s
.583 .18405 m
.58534 .18434 L
s
0 1 .511 r
.62663 .58832 m
.61987 .61378 L
s
1 .053 0 r
.58488 .18453 m
.58494 .18405 L
s
1 .002 0 r
.20126 .43611 m
.20127 .43611 L
s
.20127 .4361 m
.20126 .43611 L
s
.20126 .43611 m
.20126 .4361 L
s
.20128 .43611 m
.20126 .43611 L
s
.20129 .43607 m
.20126 .43611 L
s
.20127 .4361 m
.20126 .4361 L
s
.20128 .43611 m
.20127 .4361 L
s
.20127 .43611 m
.20128 .43611 L
s
.20126 .4361 m
.20127 .43611 L
s
1 .115 0 r
.24782 .5936 m
.2485 .59433 L
s
1 .001 0 r
.51788 .34157 m
.51788 .34157 L
s
.51788 .34156 m
.51788 .34157 L
s
.51789 .34156 m
.51788 .34157 L
s
.51788 .34156 m
.51788 .34156 L
s
.51788 .34156 m
.51789 .34156 L
s
1 0 0 r
.7692 .40457 m
.76919 .40456 L
s
1 .241 0 r
.70403 .56209 m
.69945 .55667 L
s
1 .001 0 r
.51783 .34156 m
.51789 .34156 L
s
1 .005 0 r
.26646 .27856 m
.2666 .27845 L
s
1 .001 0 r
.51789 .34156 m
.51788 .34157 L
s
.51788 .34156 m
.51789 .34156 L
s
.51788 .34157 m
.51788 .34156 L
s
1 0 0 r
.76919 .40456 m
.76919 .40456 L
s
.76919 .40456 m
.76919 .40456 L
s
.76919 .40456 m
.76919 .40456 L
s
.76919 .40457 m
.76919 .40456 L
s
.76919 .40456 m
.76919 .40456 L
s
.76919 .40456 m
.76919 .40457 L
s
.76919 .40456 m
.76919 .40456 L
s
.76919 .40456 m
.76919 .40457 L
s
1 .005 0 r
.26658 .27845 m
.2666 .27849 L
s
.26655 .27846 m
.26658 .27845 L
s
.26658 .27845 m
.2666 .27845 L
s
.2666 .27849 m
.26657 .2785 L
s
.2666 .27845 m
.2666 .27849 L
s
.26657 .2785 m
.26655 .27846 L
s
.26655 .27846 m
.2666 .27845 L
s
.2666 .27845 m
.26657 .2785 L
s
1 .043 0 r
.38231 .46725 m
.38257 .46731 L
s
.38259 .46687 m
.38231 .46725 L
s
.38231 .46725 m
.38238 .46696 L
s
.38278 .46721 m
.38231 .46725 L
s
.38367 .46646 m
.38231 .46725 L
s
0 .813 1 r
.5334 .49873 m
.51539 .52103 L
s
.50164 .48956 m
.5334 .49873 L
s
1 .043 0 r
.38257 .46731 m
.38278 .46721 L
s
.38278 .46721 m
.38259 .46687 L
s
.38259 .46687 m
.38238 .46696 L
s
0 1 .511 r
.45864 .59787 m
.45466 .59306 L
s
.45466 .59306 m
.45918 .57102 L
s
.45466 .59306 m
.43697 .58075 L
s
1 .043 0 r
.38238 .46696 m
.38257 .46731 L
s
1 .825 0 r
.49172 .52916 m
.49191 .53654 L
s
1 .014 0 r
.0669 .56138 m
.06689 .56139 L
s
.06691 .56124 m
.0669 .56138 L
s
.0669 .56138 m
.06681 .5613 L
s
.067 .56132 m
.0669 .56138 L
s
.06693 .56103 m
.0669 .56138 L
s
.06691 .56124 m
.06681 .5613 L
s
.067 .56132 m
.06691 .56124 L
s
.06689 .56139 m
.067 .56132 L
s
1 .018 0 r
.76621 .21461 m
.7661 .21463 L
s
.76609 .21446 m
.76621 .21461 L
s
.76621 .21461 m
.76602 .21461 L
s
.76617 .21448 m
.76621 .21461 L
s
.76563 .21427 m
.76621 .21461 L
s
.76602 .21461 m
.7661 .21463 L
s
.76609 .21446 m
.76602 .21461 L
s
1 .014 0 r
.06681 .5613 m
.06689 .56139 L
s
1 .018 0 r
.76617 .21448 m
.76609 .21446 L
s
1 .066 0 r
.51647 .15147 m
.51646 .15148 L
s
.51646 .15087 m
.51647 .15147 L
s
.51705 .15116 m
.51647 .15147 L
s
1 .018 0 r
.7661 .21463 m
.76617 .21448 L
s
1 .066 0 r
.51644 .15087 m
.51646 .15087 L
s
.51646 .15087 m
.51705 .15116 L
s
1 0 0 r
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
.13214 .40341 m
.13214 .40341 L
s
1 .05 0 r
.88673 .59255 m
.88652 .59133 L
s
1 .336 0 r
.6352 .5295 m
.62453 .5235 L
s
1 0 0 r
.70042 .37189 m
.70042 .37189 L
s
1 .066 0 r
.5141 .15123 m
.51705 .15116 L
s
1 .006 0 r
.44889 .30884 m
.44915 .30879 L
s
.44911 .30882 m
.4491 .30883 L
s
.4491 .30877 m
.44911 .30882 L
s
.44915 .30879 m
.44911 .30882 L
s
.44908 .30877 m
.4491 .30877 L
s
.4491 .30877 m
.44915 .30879 L
s
0 1 .331 r
.44533 .561 m
.46532 .57674 L
s
.44533 .561 m
.46953 .55622 L
s
1 .006 0 r
.44915 .30879 m
.4491 .30883 L
s
.44908 .30877 m
.44915 .30879 L
s
.4491 .30883 m
.44908 .30877 L
s
1 .066 0 r
.51705 .15116 m
.51646 .15148 L
s
.51644 .15087 m
.51705 .15116 L
s
.51646 .15148 m
.51644 .15087 L
s
1 .158 0 r
.77148 .59075 m
.77254 .59142 L
s
.77055 .59176 m
.77148 .59075 L
s
.77148 .59075 m
.77124 .59083 L
s
1 .035 0 r
.69776 .182 m
.69789 .18202 L
s
.69787 .1817 m
.69776 .182 L
s
.69815 .18196 m
.69776 .182 L
s
.69799 .18172 m
.69787 .1817 L
s
.69787 .1817 m
.69815 .18196 L
s
.69815 .18196 m
.69789 .18202 L
s
.69799 .18172 m
.69815 .18196 L
s
.6968 .18145 m
.69815 .18196 L
s
1 .459 0 r
.3944 .56038 m
.39655 .56395 L
s
1 .158 0 r
.77161 .59244 m
.77055 .59176 L
s
.77055 .59176 m
.77124 .59083 L
s
1 .035 0 r
.69789 .18202 m
.69799 .18172 L
s
1 .05 0 r
.88653 .59131 m
.88688 .59154 L
s
.88624 .59161 m
.88653 .59131 L
s
.88653 .59131 m
.88652 .59133 L
s
.88659 .59184 m
.88624 .59161 L
s
.88624 .59161 m
.88652 .59133 L
s
1 .005 0 r
.31447 .4339 m
.31449 .4339 L
s
.3145 .43385 m
.31447 .4339 L
s
.31447 .4339 m
.31447 .43387 L
s
.31452 .43389 m
.31447 .4339 L
s
.3146 .43379 m
.31447 .4339 L
s
.3145 .43385 m
.31447 .43387 L
s
.31452 .43389 m
.3145 .43385 L
s
.31449 .4339 m
.31452 .43389 L
s
.31447 .43387 m
.31449 .4339 L
s
1 .05 0 r
.88688 .59154 m
.88659 .59184 L
s
.88652 .59133 m
.88688 .59154 L
s
1 .001 0 r
.63157 .33918 m
.63157 .33918 L
s
.63157 .33917 m
.63157 .33918 L
s
.63158 .33917 m
.63157 .33918 L
s
.63158 .33917 m
.63157 .33917 L
s
.63157 .33917 m
.63158 .33917 L
s
.63158 .33917 m
.63157 .33918 L
s
.63158 .33917 m
.63158 .33917 L
s
.63154 .33916 m
.63158 .33917 L
s
.63157 .33918 m
.63158 .33917 L
s
1 .063 0 r
.81798 .55997 m
.81732 .55843 L
s
1 .303 0 r
.56629 .49688 m
.55326 .49458 L
s
1 .011 0 r
.37986 .27608 m
.38026 .27593 L
s
1 .05 0 r
.88652 .59133 m
.88659 .59184 L
s
1 .011 0 r
.38022 .276 m
.38018 .27601 L
s
.38018 .27591 m
.38022 .276 L
s
.38026 .27593 m
.38022 .276 L
s
.38015 .27592 m
.38018 .27591 L
s
.38018 .27591 m
.38026 .27593 L
s
1 .158 0 r
.77254 .59142 m
.77161 .59244 L
s
.77124 .59083 m
.77254 .59142 L
s
1 .011 0 r
.38026 .27593 m
.38018 .27601 L
s
.38015 .27592 m
.38026 .27593 L
s
.38018 .27601 m
.38015 .27592 L
s
1 .038 0 r
.17986 .55983 m
.17989 .55984 L
s
.17994 .55944 m
.17986 .55983 L
s
.17986 .55983 m
.17968 .5596 L
s
.18015 .55968 m
.17986 .55983 L
s
.18015 .5589 m
.17986 .55983 L
s
.17994 .55944 m
.17968 .5596 L
s
.18015 .55968 m
.17994 .55944 L
s
1 .111 0 r
.49336 .4652 m
.4935 .46505 L
s
.4935 .46505 m
.49337 .46406 L
s
.4935 .46505 m
.49239 .46474 L
s
1 .038 0 r
.17989 .55984 m
.18015 .55968 L
s
1 .158 0 r
.77124 .59083 m
.77161 .59244 L
s
1 .121 0 r
.29176 .5596 m
.2921 .55968 L
s
.29219 .5584 m
.29176 .5596 L
s
.29176 .5596 m
.29141 .55885 L
s
.29288 .55922 m
.29176 .5596 L
s
.29365 .55678 m
.29176 .5596 L
s
1 .038 0 r
.17968 .5596 m
.17989 .55984 L
s
1 .111 0 r
.49337 .46406 m
.49324 .46421 L
s
.49337 .46406 m
.49239 .46474 L
s
0 1 .511 r
.45918 .57102 m
.4632 .57563 L
s
.45918 .57102 m
.43697 .58075 L
s
0 .434 1 r
.50891 .49947 m
.5291 .51165 L
s
.48869 .52446 m
.50891 .49947 L
s
.50891 .49947 m
.49314 .50136 L
s
1 .055 0 r
.62965 .14922 m
.62977 .14924 L
s
.62975 .14873 m
.62965 .14922 L
s
.63023 .14908 m
.62965 .14922 L
s
1 .111 0 r
.49239 .46474 m
.49336 .4652 L
s
.49239 .46474 m
.49324 .46421 L
s
.49729 .46421 m
.49239 .46474 L
s
1 .055 0 r
.62987 .14874 m
.62975 .14873 L
s
.62975 .14873 m
.63023 .14908 L
s
1 .121 0 r
.29219 .5584 m
.29141 .55885 L
s
.29288 .55922 m
.29219 .5584 L
s
1 .055 0 r
.63023 .14908 m
.62977 .14924 L
s
.62987 .14874 m
.63023 .14908 L
s
.62788 .14858 m
.63023 .14908 L
s
1 .303 0 r
.55589 .49661 m
.5553 .49615 L
s
.5553 .49615 m
.55586 .49347 L
s
.5553 .49615 m
.55326 .49458 L
s
1 .121 0 r
.2921 .55968 m
.29288 .55922 L
s
1 .055 0 r
.62977 .14924 m
.62987 .14874 L
s
1 .303 0 r
.55586 .49347 m
.55645 .49394 L
s
.55586 .49347 m
.55326 .49458 L
s
1 .111 0 r
.49324 .46421 m
.49336 .4652 L
s
1 .007 0 r
.56282 .30645 m
.56283 .30645 L
s
.56283 .30639 m
.56282 .30645 L
s
.56289 .30643 m
.56282 .30645 L
s
.56283 .30639 m
.56283 .30639 L
s
.56283 .30639 m
.56289 .30643 L
s
.56289 .30643 m
.56283 .30645 L
s
.56283 .30639 m
.56289 .30643 L
s
.56259 .3064 m
.56289 .30643 L
s
1 0 0 r
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
.24544 .40109 m
.24544 .40109 L
s
1 .063 0 r
.81743 .5584 m
.81785 .55866 L
s
.81706 .55881 m
.81743 .5584 L
s
.81743 .5584 m
.81732 .55843 L
s
1 .007 0 r
.56283 .30645 m
.56283 .30639 L
s
1 .08 0 r
.74914 .52734 m
.74767 .52551 L
s
1 0 0 r
.81444 .36952 m
.81444 .36952 L
s
1 .013 0 r
.31074 .24327 m
.31117 .24304 L
s
1 .121 0 r
.29141 .55885 m
.2921 .55968 L
s
1 .063 0 r
.81748 .55907 m
.81706 .55881 L
s
.81706 .55881 m
.81732 .55843 L
s
1 .013 0 r
.31114 .24313 m
.31108 .24315 L
s
.31109 .24303 m
.31114 .24313 L
s
.31117 .24304 m
.31114 .24313 L
s
.31103 .24304 m
.31109 .24303 L
s
.31109 .24303 m
.31117 .24304 L
s
0 .813 1 r
.50164 .48956 m
.51539 .52103 L
s
1 .013 0 r
.31108 .24315 m
.31103 .24304 L
s
.31117 .24304 m
.31108 .24315 L
s
.31103 .24304 m
.31117 .24304 L
s
1 .063 0 r
.81785 .55866 m
.81748 .55907 L
s
.81732 .55843 m
.81785 .55866 L
s
.81732 .55843 m
.81748 .55907 L
s
1 .241 0 r
.7003 .55648 m
.70177 .55733 L
s
.69896 .55817 m
.7003 .55648 L
s
.7003 .55648 m
.69945 .55667 L
s
.70043 .55903 m
.69896 .55817 L
s
.69896 .55817 m
.69945 .55667 L
s
0 1 .331 r
.46953 .55622 m
.46532 .57674 L
s
1 .012 0 r
.11078 .52655 m
.11079 .52656 L
s
.1108 .52643 m
.11078 .52655 L
s
.11078 .52655 m
.11072 .52648 L
s
.11087 .52651 m
.11078 .52655 L
s
.11086 .52626 m
.11078 .52655 L
s
.1108 .52643 m
.11072 .52648 L
s
.11087 .52651 m
.1108 .52643 L
s
.11079 .52656 m
.11087 .52651 L
s
.11072 .52648 m
.11079 .52656 L
s
1 .016 0 r
.42771 .43176 m
.42776 .43173 L
s
.42776 .43173 m
.42771 .43159 L
s
.42776 .43173 m
.42759 .43172 L
s
.42771 .43159 m
.42766 .43162 L
s
.42771 .43159 m
.42759 .43172 L
s
.42759 .43172 m
.42771 .43176 L
s
.42759 .43172 m
.42766 .43162 L
s
.42821 .43151 m
.42759 .43172 L
s
.42766 .43162 m
.42771 .43176 L
s
.49413 .27361 m
.49411 .27362 L
s
.49411 .27347 m
.49413 .27361 L
s
.49426 .27354 m
.49413 .27361 L
s
1 0 0 r
.74556 .33676 m
.74556 .33676 L
s
.74556 .33676 m
.74556 .33676 L
s
.74556 .33676 m
.74556 .33676 L
s
.74556 .33676 m
.74556 .33676 L
s
.74555 .33676 m
.74556 .33676 L
s
.74556 .33676 m
.74556 .33676 L
s
.74556 .33676 m
.74556 .33676 L
s
.74556 .33676 m
.74556 .33676 L
s
1 .016 0 r
.4941 .27348 m
.49411 .27347 L
s
.49411 .27347 m
.49426 .27354 L
s
1 0 0 r
.74556 .33676 m
.74556 .33676 L
s
1 .09 0 r
.68022 .49467 m
.67764 .49291 L
s
1 .016 0 r
.49354 .27359 m
.49426 .27354 L
s
1 0 0 r
.17619 .36834 m
.17619 .36834 L
s
1 .016 0 r
.49426 .27354 m
.49411 .27362 L
s
.4941 .27348 m
.49426 .27354 L
s
.49411 .27362 m
.4941 .27348 L
s
1 .303 0 r
.55326 .49458 m
.55589 .49661 L
s
.55326 .49458 m
.55645 .49394 L
s
1 .08 0 r
.74794 .52546 m
.74844 .52573 L
s
.7475 .52602 m
.74794 .52546 L
s
.74794 .52546 m
.74767 .52551 L
s
.748 .52629 m
.7475 .52602 L
s
.7475 .52602 m
.74767 .52551 L
s
1 .303 0 r
.55645 .49394 m
.55589 .49661 L
s
1 .241 0 r
.70177 .55733 m
.70043 .55903 L
s
.69945 .55667 m
.70177 .55733 L
s
1 .08 0 r
.74844 .52573 m
.748 .52629 L
s
.74767 .52551 m
.74844 .52573 L
s
1 .035 0 r
.74284 .14654 m
.74299 .14656 L
s
.74296 .14624 m
.74284 .14654 L
s
.74323 .14652 m
.74284 .14654 L
s
1 .08 0 r
.74767 .52551 m
.748 .52629 L
s
1 .035 0 r
.74323 .14652 m
.74299 .14656 L
s
.74296 .14624 m
.74323 .14652 L
s
.74311 .14627 m
.74323 .14652 L
s
.74196 .14593 m
.74323 .14652 L
s
.74311 .14627 m
.74296 .14624 L
s
1 .336 0 r
.62662 .52294 m
.6282 .52378 L
s
.62514 .52562 m
.62662 .52294 L
s
.62662 .52294 m
.62453 .5235 L
s
.62673 .52646 m
.62514 .52562 L
s
.62514 .52562 m
.62453 .5235 L
s
1 .241 0 r
.69945 .55667 m
.70043 .55903 L
s
1 .035 0 r
.74299 .14656 m
.74311 .14627 L
s
.973 1 0 r
.48439 .55864 m
.48476 .55697 L
s
.48476 .55697 m
.48452 .54777 L
s
.48476 .55697 m
.47519 .55337 L
s
1 .003 0 r
.04146 .49366 m
.04146 .49366 L
s
.04147 .49362 m
.04146 .49366 L
s
.04146 .49366 m
.04144 .49364 L
s
.04149 .49364 m
.04146 .49366 L
s
.04148 .49357 m
.04146 .49366 L
s
.04147 .49362 m
.04144 .49364 L
s
.04149 .49364 m
.04147 .49362 L
s
.04146 .49366 m
.04149 .49364 L
s
.04144 .49364 m
.04146 .49366 L
s
1 .004 0 r
.67668 .30401 m
.67669 .30401 L
s
.67669 .30397 m
.67668 .30401 L
s
.67672 .304 m
.67668 .30401 L
s
.6767 .30398 m
.67669 .30397 L
s
.67669 .30397 m
.67672 .304 L
s
.67672 .304 m
.67669 .30401 L
s
.6767 .30398 m
.67672 .304 L
s
.67658 .30395 m
.67672 .304 L
s
.67669 .30401 m
.6767 .30398 L
s
1 .001 0 r
.359 .39877 m
.35901 .39877 L
s
.35901 .39877 m
.359 .39877 L
s
.359 .39877 m
.359 .39877 L
s
.35901 .39877 m
.359 .39877 L
s
.35903 .39876 m
.359 .39877 L
s
.35901 .39877 m
.35901 .39877 L
s
.35901 .39877 m
.35901 .39877 L
s
.35901 .39877 m
.359 .39877 L
s
.359 .39877 m
.35901 .39877 L
s
1 .023 0 r
.86337 .52517 m
.86312 .5246 L
s
1 .07 0 r
.6112 .46197 m
.60845 .46108 L
s
1 .022 0 r
.42441 .24074 m
.42535 .24052 L
s
1 .09 0 r
.67813 .49279 m
.6786 .49303 L
s
.67771 .49349 m
.67813 .49279 L
s
.67813 .49279 m
.67764 .49291 L
s
.542 1 0 r
.58991 .57668 m
.59844 .58194 L
s
.5817 .58697 m
.58991 .57668 L
s
.58991 .57668 m
.58402 .57794 L
s
1 .022 0 r
.42521 .24066 m
.42516 .24067 L
s
.42516 .24046 m
.42521 .24066 L
s
.42535 .24052 m
.42521 .24066 L
s
1 .09 0 r
.67818 .49373 m
.67771 .49349 L
s
.67771 .49349 m
.67764 .49291 L
s
1 .022 0 r
.42511 .24047 m
.42516 .24046 L
s
.42516 .24046 m
.42535 .24052 L
s
.42535 .24052 m
.42516 .24067 L
s
.42511 .24047 m
.42535 .24052 L
s
.42516 .24067 m
.42511 .24047 L
s
1 .39 0 r
.43995 .52567 m
.44126 .52491 L
s
.44126 .52491 m
.44005 .52159 L
s
.44126 .52491 m
.43696 .5246 L
s
1 .033 0 r
.2239 .52489 m
.22398 .52491 L
s
.22401 .52456 m
.2239 .52489 L
s
.2239 .52489 m
.22378 .52468 L
s
.2242 .52478 m
.2239 .52489 L
s
.22435 .52409 m
.2239 .52489 L
s
.22401 .52456 m
.22378 .52468 L
s
.2242 .52478 m
.22401 .52456 L
s
.22398 .52491 m
.2242 .52478 L
s
1 .023 0 r
.86316 .52459 m
.86332 .52468 L
s
.86302 .52474 m
.86316 .52459 L
s
.86316 .52459 m
.86312 .5246 L
s
.86318 .52484 m
.86302 .52474 L
s
.86302 .52474 m
.86312 .5246 L
s
1 .07 0 r
.60901 .46161 m
.60878 .46149 L
s
.60878 .46149 m
.60899 .46089 L
s
.60878 .46149 m
.60845 .46108 L
s
1 .39 0 r
.44005 .52159 m
.43874 .52235 L
s
.44005 .52159 m
.43696 .5246 L
s
1 .033 0 r
.22378 .52468 m
.22398 .52491 L
s
1 .023 0 r
.86332 .52468 m
.86318 .52484 L
s
.86312 .5246 m
.86332 .52468 L
s
1 .07 0 r
.60899 .46089 m
.60923 .46101 L
s
.60899 .46089 m
.60845 .46108 L
s
1 .023 0 r
.86312 .5246 m
.86318 .52484 L
s
1 .09 0 r
.6786 .49303 m
.67818 .49373 L
s
.67764 .49291 m
.6786 .49303 L
s
.67764 .49291 m
.67818 .49373 L
s
1 .39 0 r
.43696 .5246 m
.43995 .52567 L
s
.43696 .5246 m
.43874 .52235 L
s
.45219 .51973 m
.43696 .5246 L
s
0 .434 1 r
.50872 .5369 m
.48869 .52446 L
s
.48869 .52446 m
.49314 .50136 L
s
1 .116 0 r
.33541 .5244 m
.33591 .52451 L
s
.33598 .52329 m
.33541 .5244 L
s
.33541 .5244 m
.33531 .52365 L
s
.33659 .52415 m
.33541 .5244 L
s
.33813 .52191 m
.33541 .5244 L
s
.973 1 0 r
.48452 .54777 m
.48415 .5494 L
s
.48452 .54777 m
.47519 .55337 L
s
1 .07 0 r
.60845 .46108 m
.60901 .46161 L
s
.60845 .46108 m
.60923 .46101 L
s
.60923 .46101 m
.60901 .46161 L
s
1 .116 0 r
.33598 .52329 m
.33531 .52365 L
s
.33659 .52415 m
.33598 .52329 L
s
1 .013 0 r
.60795 .27124 m
.60797 .27125 L
s
.60797 .27112 m
.60795 .27124 L
s
.60809 .27121 m
.60795 .27124 L
s
.608 .27113 m
.60797 .27112 L
s
.60797 .27112 m
.60809 .27121 L
s
.60809 .27121 m
.60797 .27125 L
s
.608 .27113 m
.60809 .27121 L
s
.60752 .2711 m
.60809 .27121 L
s
1 .116 0 r
.33591 .52451 m
.33659 .52415 L
s
1 .013 0 r
.60797 .27125 m
.608 .27113 L
s
1 .024 0 r
.54125 .42929 m
.54124 .42926 L
s
.54124 .42926 m
.54125 .42905 L
s
.54124 .42926 m
.54104 .42916 L
s
.54125 .42905 m
.54127 .42907 L
s
.54125 .42905 m
.54104 .42916 L
s
1 .023 0 r
.79443 .49246 m
.79401 .49191 L
s
1 .024 0 r
.5421 .42921 m
.54104 .42916 L
s
1 0 0 r
.28977 .36597 m
.28977 .36597 L
s
1 .024 0 r
.35519 .20785 m
.35612 .20749 L
s
.54104 .42916 m
.54125 .42929 L
s
.54104 .42916 m
.54127 .42907 L
s
.54127 .42907 m
.54125 .42929 L
s
.35601 .20766 m
.35592 .20768 L
s
.35594 .20745 m
.35601 .20766 L
s
.35612 .20749 m
.35601 .20766 L
s
.35585 .20747 m
.35594 .20745 L
s
.35594 .20745 m
.35612 .20749 L
s
1 .336 0 r
.6282 .52378 m
.62673 .52646 L
s
.62453 .5235 m
.6282 .52378 L
s
1 .024 0 r
.35612 .20749 m
.35592 .20768 L
s
.35585 .20747 m
.35612 .20749 L
s
1 .336 0 r
.62453 .5235 m
.62673 .52646 L
s
1 .024 0 r
.35592 .20768 m
.35585 .20747 L
s
1 .023 0 r
.79408 .4919 m
.79423 .49198 L
s
.79395 .49206 m
.79408 .4919 L
s
.79408 .4919 m
.79401 .49191 L
s
.542 1 0 r
.59021 .59227 m
.5817 .58697 L
s
.5817 .58697 m
.58402 .57794 L
s
1 .023 0 r
.7941 .49214 m
.79395 .49206 L
s
.79395 .49206 m
.79401 .49191 L
s
1 .65 0 r
.64872 .58174 m
.65262 .58409 L
s
.64508 .58632 m
.64872 .58174 L
s
.64872 .58174 m
.64626 .58231 L
s
1 .116 0 r
.33531 .52365 m
.33591 .52451 L
s
1 .023 0 r
.79423 .49198 m
.7941 .49214 L
s
.79401 .49191 m
.79423 .49198 L
s
.79401 .49191 m
.7941 .49214 L
s
.973 1 0 r
.56048 .55756 m
.55657 .55521 L
s
.55657 .55521 m
.56037 .54668 L
s
.55657 .55521 m
.55287 .54906 L
s
.56037 .54668 m
.5643 .549 L
s
.56037 .54668 m
.55287 .54906 L
s
1 .009 0 r
.15485 .49157 m
.15487 .49157 L
s
.15488 .49148 m
.15485 .49157 L
s
.15485 .49157 m
.15482 .49151 L
s
.15493 .49154 m
.15485 .49157 L
s
.15495 .49135 m
.15485 .49157 L
s
.15488 .49148 m
.15482 .49151 L
s
.15493 .49154 m
.15488 .49148 L
s
.15487 .49157 m
.15493 .49154 L
s
.15482 .49151 m
.15487 .49157 L
s
1 .575 0 r
.38971 .58642 m
.39296 .58738 L
s
.39321 .58122 m
.38971 .58642 L
s
.38971 .58642 m
.39026 .58287 L
s
.39591 .58572 m
.38971 .58642 L
s
.40669 .57574 m
.38971 .58642 L
s
1 .026 0 r
.5393 .23835 m
.53931 .23836 L
s
.53931 .23811 m
.5393 .23835 L
s
.53954 .23824 m
.5393 .23835 L
s
.53932 .23812 m
.53931 .23811 L
s
.53931 .23811 m
.53954 .23824 L
s
1 .65 0 r
.64898 .58868 m
.64508 .58632 L
s
.64508 .58632 m
.64626 .58231 L
s
1 .026 0 r
.53954 .23824 m
.53931 .23836 L
s
.53932 .23812 m
.53954 .23824 L
s
.53837 .2382 m
.53954 .23824 L
s
1 .002 0 r
.7909 .30152 m
.7909 .30153 L
s
.7909 .30151 m
.7909 .30152 L
s
.7909 .30152 m
.79089 .30152 L
s
.7909 .30151 m
.7909 .30152 L
s
.79086 .30149 m
.7909 .30152 L
s
.7909 .30151 m
.79089 .30152 L
s
.7909 .30151 m
.7909 .30151 L
s
.79089 .30152 m
.7909 .30153 L
s
.7909 .30153 m
.7909 .30151 L
s
.47284 .39644 m
.47284 .39644 L
s
.47284 .39644 m
.47284 .39642 L
s
.47284 .39644 m
.47283 .39644 L
s
.47284 .39642 m
.47284 .39643 L
s
.47284 .39642 m
.47283 .39644 L
s
.47283 .39644 m
.47284 .39644 L
s
.47283 .39644 m
.47284 .39643 L
s
.47291 .39642 m
.47283 .39644 L
s
.47284 .39643 m
.47284 .39644 L
s
1 .02 0 r
.7254 .45971 m
.72488 .4593 L
s
1 0 0 r
.22041 .33314 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
.22042 .33313 m
.22042 .33313 L
s
1 .026 0 r
.53931 .23836 m
.53932 .23812 L
s
1 .02 0 r
.72498 .45928 m
.72509 .45933 L
s
.72488 .45943 m
.72498 .45928 L
s
.72498 .45928 m
.72488 .4593 L
s
.72499 .45948 m
.72488 .45943 L
s
.72488 .45943 m
.72488 .4593 L
s
.72509 .45933 m
.72499 .45948 L
s
.72488 .4593 m
.72509 .45933 L
s
.72488 .4593 m
.72499 .45948 L
s
1 .39 0 r
.43874 .52235 m
.43995 .52567 L
s
1 .575 0 r
.39321 .58122 m
.39026 .58287 L
s
.39591 .58572 m
.39321 .58122 L
s
.39296 .58738 m
.39591 .58572 L
s
1 .007 0 r
.72195 .26872 m
.72198 .26873 L
s
.72198 .26866 m
.72195 .26872 L
s
.72203 .26872 m
.72195 .26872 L
s
.72203 .26872 m
.72198 .26873 L
s
.72198 .26866 m
.72203 .26872 L
s
.72201 .26867 m
.72203 .26872 L
s
.72178 .2686 m
.72203 .26872 L
s
.72201 .26867 m
.72198 .26866 L
s
.72198 .26873 m
.72201 .26867 L
s
1 .002 0 r
.08545 .45863 m
.08545 .45863 L
s
.08546 .45861 m
.08545 .45863 L
s
.08545 .45863 m
.08544 .45862 L
s
.08547 .45862 m
.08545 .45863 L
s
.08547 .45858 m
.08545 .45863 L
s
.08546 .45861 m
.08544 .45862 L
s
.08547 .45862 m
.08546 .45861 L
s
.08545 .45863 m
.08547 .45862 L
s
.08544 .45862 m
.08545 .45863 L
s
1 .035 0 r
.47041 .20527 m
.47037 .20528 L
s
.47037 .20495 m
.47041 .20527 L
s
.47068 .20508 m
.47041 .20527 L
s
.808 1 0 r
.59078 .58524 m
.54691 .56774 L
s
1 .01 0 r
.65628 .42692 m
.65591 .42675 L
s
1 .035 0 r
.46913 .20527 m
.47068 .20508 L
s
1 0 0 r
.40363 .36359 m
.40363 .36359 L
s
1 .035 0 r
.47033 .20496 m
.47037 .20495 L
s
.47037 .20495 m
.47068 .20508 L
s
1 .01 0 r
.65599 .42684 m
.65594 .42682 L
s
.65594 .42682 m
.65598 .42673 L
s
.65594 .42682 m
.65591 .42675 L
s
.65598 .42673 m
.65603 .42675 L
s
.65598 .42673 m
.65591 .42675 L
s
.65603 .42675 m
.65599 .42684 L
s
.65591 .42675 m
.65599 .42684 L
s
.65591 .42675 m
.65603 .42675 L
s
1 .035 0 r
.47068 .20508 m
.47037 .20528 L
s
.47033 .20496 m
.47068 .20508 L
s
.973 1 0 r
.47519 .55337 m
.48439 .55864 L
s
.47519 .55337 m
.48415 .5494 L
s
.52153 .5525 m
.47519 .55337 L
s
1 .035 0 r
.47037 .20528 m
.47033 .20496 L
s
1 .026 0 r
.2682 .48974 m
.2683 .48975 L
s
.26832 .48948 m
.2682 .48974 L
s
.2682 .48974 m
.26815 .48956 L
s
.26846 .48967 m
.2682 .48974 L
s
.26872 .48913 m
.2682 .48974 L
s
.26832 .48948 m
.26815 .48956 L
s
.26846 .48967 m
.26832 .48948 L
s
.2683 .48975 m
.26846 .48967 L
s
.26815 .48956 m
.2683 .48975 L
s
1 .018 0 r
.65317 .23591 m
.65323 .23593 L
s
.65322 .23575 m
.65317 .23591 L
s
.65337 .23588 m
.65317 .23591 L
s
.65327 .23576 m
.65322 .23575 L
s
.65322 .23575 m
.65337 .23588 L
s
.65337 .23588 m
.65323 .23593 L
s
.65327 .23576 m
.65337 .23588 L
s
.65262 .23566 m
.65337 .23588 L
s
.65323 .23593 m
.65327 .23576 L
s
1 .006 0 r
.83989 .45745 m
.83979 .45731 L
s
1 .002 0 r
.58708 .39408 m
.587 .39407 L
s
1 0 0 r
.33426 .33071 m
.33427 .33071 L
s
1 .038 0 r
.3998 .17229 m
.40137 .17188 L
s
1 0 0 r
.33427 .33071 m
.33427 .33071 L
s
.33427 .33071 m
.33427 .33071 L
s
.33427 .33071 m
.33427 .33071 L
s
1 .002 0 r
.58702 .39408 m
.58701 .39408 L
s
.58701 .39408 m
.58702 .39406 L
s
.58701 .39408 m
.587 .39407 L
s
1 0 0 r
.33427 .33071 m
.33427 .33071 L
s
.33427 .33071 m
.33427 .33071 L
s
1 .002 0 r
.58702 .39406 m
.58702 .39406 L
s
.58702 .39406 m
.587 .39407 L
s
1 0 0 r
.33427 .33071 m
.33427 .33071 L
s
.33427 .33071 m
.33427 .33071 L
s
.33427 .33071 m
.33427 .33071 L
s
1 .002 0 r
.587 .39407 m
.58702 .39408 L
s
.587 .39407 m
.58702 .39406 L
s
.58702 .39406 m
.58702 .39408 L
s
1 .006 0 r
.83981 .45731 m
.83984 .45733 L
s
.83977 .45735 m
.83981 .45731 L
s
.83981 .45731 m
.83979 .45731 L
s
.83981 .45737 m
.83977 .45735 L
s
.83977 .45735 m
.83979 .45731 L
s
1 .65 0 r
.65262 .58409 m
.64898 .58868 L
s
.64626 .58231 m
.65262 .58409 L
s
1 .006 0 r
.83984 .45733 m
.83981 .45737 L
s
.83979 .45731 m
.83984 .45733 L
s
.83979 .45731 m
.83981 .45737 L
s
1 .038 0 r
.40115 .17212 m
.40105 .17214 L
s
.40106 .17179 m
.40115 .17212 L
s
.40137 .17188 m
.40115 .17212 L
s
.40096 .1718 m
.40106 .17179 L
s
.40106 .17179 m
.40137 .17188 L
s
.40137 .17188 m
.40105 .17214 L
s
.40096 .1718 m
.40137 .17188 L
s
.40105 .17214 m
.40096 .1718 L
s
1 .09 0 r
.37991 .48854 m
.38046 .48868 L
s
.3805 .48775 m
.37991 .48854 L
s
.37991 .48854 m
.38007 .48796 L
s
.38089 .48847 m
.37991 .48854 L
s
.38277 .48691 m
.37991 .48854 L
s
.38046 .48868 m
.38089 .48847 L
s
.38089 .48847 m
.3805 .48775 L
s
.3805 .48775 m
.38007 .48796 L
s
1 .65 0 r
.64626 .58231 m
.64898 .58868 L
s
1 .033 0 r
.58451 .20298 m
.58456 .20299 L
s
.58455 .20267 m
.58451 .20298 L
s
.58485 .20287 m
.58451 .20298 L
s
.5846 .20268 m
.58455 .20267 L
s
.58455 .20267 m
.58485 .20287 L
s
.58485 .20287 m
.58456 .20299 L
s
.5846 .20268 m
.58485 .20287 L
s
.58337 .20268 m
.58485 .20287 L
s
1 .005 0 r
.19913 .45644 m
.19915 .45645 L
s
.19915 .45639 m
.19913 .45644 L
s
.19913 .45644 m
.19912 .45641 L
s
.19918 .45643 m
.19913 .45644 L
s
.19922 .45632 m
.19913 .45644 L
s
.19915 .45639 m
.19912 .45641 L
s
.19918 .45643 m
.19915 .45639 L
s
.19915 .45645 m
.19918 .45643 L
s
.19912 .45641 m
.19915 .45645 L
s
1 .033 0 r
.58456 .20299 m
.5846 .20268 L
s
1 .318 0 r
.70517 .58313 m
.69907 .57601 L
s
1 .003 0 r
.77076 .42461 m
.77068 .42454 L
s
1 0 0 r
.51778 .3612 m
.51778 .3612 L
s
1 .002 0 r
.2648 .2978 m
.26485 .29776 L
s
.26484 .29776 m
.26485 .29777 L
s
.26483 .29777 m
.26484 .29776 L
s
.26484 .29776 m
.26485 .29776 L
s
.26485 .29777 m
.26484 .29778 L
s
.26485 .29776 m
.26485 .29777 L
s
.26484 .29778 m
.26483 .29777 L
s
.26483 .29777 m
.26485 .29776 L
s
.26485 .29776 m
.26484 .29778 L
s
1 .003 0 r
.77069 .42454 m
.77071 .42455 L
s
.77068 .42457 m
.77069 .42454 L
s
.77069 .42454 m
.77068 .42454 L
s
.7707 .42457 m
.77068 .42457 L
s
.77068 .42457 m
.77068 .42454 L
s
.77071 .42455 m
.7707 .42457 L
s
.77068 .42454 m
.77071 .42455 L
s
.77068 .42454 m
.7707 .42457 L
s
1 .09 0 r
.38007 .48796 m
.38046 .48868 L
s
1 .575 0 r
.39026 .58287 m
.39296 .58738 L
s
1 .022 0 r
.06395 .58262 m
.06394 .58263 L
s
.06397 .5824 m
.06395 .58262 L
s
.06395 .58262 m
.06382 .58249 L
s
.0641 .58253 m
.06395 .58262 L
s
.064 .58208 m
.06395 .58262 L
s
.06397 .5824 m
.06382 .58249 L
s
.0641 .58253 m
.06397 .5824 L
s
.06394 .58263 m
.0641 .58253 L
s
.06382 .58249 m
.06394 .58263 L
s
1 .01 0 r
.76748 .23329 m
.76742 .2333 L
s
.76741 .23321 m
.76748 .23329 L
s
.76748 .23329 m
.76738 .23329 L
s
.76746 .23322 m
.76748 .23329 L
s
.76716 .23311 m
.76748 .23329 L
s
.76738 .23329 m
.76742 .2333 L
s
.76741 .23321 m
.76738 .23329 L
s
.76746 .23322 m
.76741 .23321 L
s
1 .045 0 r
.51567 .16983 m
.51566 .16984 L
s
.51566 .16941 m
.51567 .16983 L
s
.51607 .16961 m
.51567 .16983 L
s
1 .01 0 r
.76742 .2333 m
.76746 .23322 L
s
1 .045 0 r
.51565 .16942 m
.51566 .16941 L
s
.51566 .16941 m
.51607 .16961 L
s
.973 1 0 r
.48415 .5494 m
.48439 .55864 L
s
1 .001 0 r
.12962 .42348 m
.12962 .42348 L
s
.12962 .42347 m
.12962 .42348 L
s
.12962 .42348 m
.12962 .42347 L
s
.12963 .42348 m
.12962 .42348 L
s
.12963 .42346 m
.12962 .42348 L
s
.12962 .42347 m
.12962 .42347 L
s
.12963 .42348 m
.12962 .42347 L
s
.12962 .42348 m
.12963 .42348 L
s
.12962 .42347 m
.12962 .42348 L
s
1 .459 0 r
.63591 .55036 m
.62121 .54219 L
s
1 .001 0 r
.70153 .39173 m
.70151 .39172 L
s
1 .045 0 r
.51403 .16966 m
.51607 .16961 L
s
1 .001 0 r
.4484 .32829 m
.44843 .32828 L
s
.44843 .32828 m
.44842 .32828 L
s
.44842 .32828 m
.44843 .32828 L
s
.44843 .32828 m
.44843 .32828 L
s
.44842 .32828 m
.44842 .32828 L
s
.44842 .32828 m
.44843 .32828 L
s
.44843 .32828 m
.44842 .32828 L
s
.44842 .32828 m
.44843 .32828 L
s
.70152 .39173 m
.70151 .39173 L
s
.70151 .39173 m
.70152 .39172 L
s
.70151 .39173 m
.70151 .39172 L
s
.70152 .39172 m
.70152 .39172 L
s
.70152 .39172 m
.70151 .39172 L
s
.44842 .32828 m
.44842 .32828 L
s
.70152 .39172 m
.70152 .39173 L
s
.70151 .39172 m
.70152 .39173 L
s
.70151 .39172 m
.70152 .39172 L
s
1 .045 0 r
.51607 .16961 m
.51566 .16984 L
s
.51565 .16942 m
.51607 .16961 L
s
.542 1 0 r
.59844 .58194 m
.59021 .59227 L
s
.58402 .57794 m
.59844 .58194 L
s
1 .045 0 r
.51566 .16984 m
.51565 .16942 L
s
1 .168 0 r
.28954 .58175 m
.29 .58187 L
s
.29013 .58007 m
.28954 .58175 L
s
.28954 .58175 m
.28904 .58072 L
s
.29109 .58123 m
.28954 .58175 L
s
.29217 .57786 m
.28954 .58175 L
s
1 .215 0 r
.48944 .4866 m
.48971 .4863 L
s
.48971 .4863 m
.48947 .48436 L
s
.48971 .4863 m
.48754 .48568 L
s
1 .168 0 r
.29013 .58007 m
.28904 .58072 L
s
.29109 .58123 m
.29013 .58007 L
s
1 .016 0 r
.31283 .45438 m
.31291 .4544 L
s
.31292 .45424 m
.31283 .45438 L
s
.31283 .45438 m
.31283 .45428 L
s
.313 .45436 m
.31283 .45438 L
s
.31325 .45405 m
.31283 .45438 L
s
.31292 .45424 m
.31283 .45428 L
s
.313 .45436 m
.31292 .45424 L
s
.31291 .4544 m
.313 .45436 L
s
1 .055 0 r
.17751 .58131 m
.17757 .58134 L
s
.17763 .58075 m
.17751 .58131 L
s
.17751 .58131 m
.17724 .58099 L
s
.17795 .5811 m
.17751 .58131 L
s
.17794 .57997 m
.17751 .58131 L
s
1 .215 0 r
.48947 .48436 m
.48919 .48467 L
s
.48947 .48436 m
.48754 .48568 L
s
1 .022 0 r
.6985 .20043 m
.69857 .20045 L
s
.69856 .20024 m
.6985 .20043 L
s
.69874 .20041 m
.6985 .20043 L
s
.69864 .20026 m
.69856 .20024 L
s
.69856 .20024 m
.69874 .20041 L
s
.69874 .20041 m
.69857 .20045 L
s
.69864 .20026 m
.69874 .20041 L
s
.6979 .20009 m
.69874 .20041 L
s
1 .016 0 r
.31283 .45428 m
.31291 .4544 L
s
1 .168 0 r
.29 .58187 m
.29109 .58123 L
s
1 .055 0 r
.17763 .58075 m
.17724 .58099 L
s
.17795 .5811 m
.17763 .58075 L
s
1 .022 0 r
.69857 .20045 m
.69864 .20026 L
s
1 .055 0 r
.17757 .58134 m
.17795 .5811 L
s
.973 1 0 r
.5643 .549 m
.56048 .55756 L
s
.55287 .54906 m
.56048 .55756 L
s
1 .091 0 r
.81985 .58103 m
.81891 .57884 L
s
1 .457 0 r
.56655 .51754 m
.54675 .51409 L
s
1 0 0 r
.63222 .35881 m
.63222 .35881 L
s
1 .003 0 r
.37892 .29532 m
.37905 .29528 L
s
1 .05 0 r
.4446 .1366 m
.44678 .13625 L
s
1 .003 0 r
.37904 .2953 m
.37903 .2953 L
s
.37903 .29527 m
.37904 .2953 L
s
.37905 .29528 m
.37904 .2953 L
s
.37902 .29527 m
.37903 .29527 L
s
.37903 .29527 m
.37905 .29528 L
s
1 .055 0 r
.17724 .58099 m
.17757 .58134 L
s
1 .003 0 r
.37905 .29528 m
.37903 .2953 L
s
.37902 .29527 m
.37905 .29528 L
s
.37903 .2953 m
.37902 .29527 L
s
1 .05 0 r
.44642 .13655 m
.44634 .13655 L
s
.44635 .13609 m
.44642 .13655 L
s
.44678 .13625 m
.44642 .13655 L
s
.44627 .1361 m
.44635 .13609 L
s
.44635 .13609 m
.44678 .13625 L
s
1 .215 0 r
.48754 .48568 m
.48944 .4866 L
s
.48754 .48568 m
.48919 .48467 L
s
.49711 .48468 m
.48754 .48568 L
s
.973 1 0 r
.55287 .54906 m
.5643 .549 L
s
0 1 .511 r
.43697 .58075 m
.45864 .59787 L
s
.43697 .58075 m
.4632 .57563 L
s
1 .05 0 r
.44678 .13625 m
.44634 .13655 L
s
.44627 .1361 m
.44678 .13625 L
s
1 .168 0 r
.28904 .58072 m
.29 .58187 L
s
1 .05 0 r
.44634 .13655 m
.44627 .1361 L
s
.542 1 0 r
.58402 .57794 m
.59021 .59227 L
s
1 .038 0 r
.62975 .16746 m
.62983 .16747 L
s
.62982 .16712 m
.62975 .16746 L
s
.63015 .16737 m
.62975 .16746 L
s
.62991 .16713 m
.62982 .16712 L
s
.62982 .16712 m
.63015 .16737 L
s
.63015 .16737 m
.62983 .16747 L
s
.62991 .16713 m
.63015 .16737 L
s
.62854 .16702 m
.63015 .16737 L
s
1 .215 0 r
.48919 .48467 m
.48944 .4866 L
s
1 .038 0 r
.62983 .16747 m
.62991 .16713 L
s
1 .002 0 r
.2436 .4212 m
.24361 .4212 L
s
.24361 .42117 m
.2436 .4212 L
s
.2436 .4212 m
.2436 .42118 L
s
.24363 .42119 m
.2436 .4212 L
s
.24365 .42115 m
.2436 .4212 L
s
.24361 .42117 m
.2436 .42118 L
s
.24363 .42119 m
.24361 .42117 L
s
.24361 .4212 m
.24363 .42119 L
s
.2436 .42118 m
.24361 .4212 L
s
1 .001 0 r
.56286 .32586 m
.56286 .32586 L
s
.56286 .32585 m
.56286 .32586 L
s
.56287 .32585 m
.56286 .32586 L
s
.56286 .32585 m
.56286 .32585 L
s
.56286 .32585 m
.56287 .32585 L
s
.56287 .32585 m
.56286 .32586 L
s
.56286 .32585 m
.56287 .32585 L
s
.56283 .32585 m
.56287 .32585 L
s
.56286 .32586 m
.56286 .32585 L
s
1 0 0 r
.81629 .38938 m
.81628 .38938 L
s
1 .121 0 r
.75058 .54821 m
.74833 .54543 L
s
1 .006 0 r
.30936 .26232 m
.30956 .26222 L
s
1 0 0 r
.81628 .38938 m
.81629 .38938 L
s
.81628 .38938 m
.81628 .38938 L
s
.81628 .38938 m
.81628 .38938 L
s
.81628 .38938 m
.81628 .38938 L
s
.81628 .38938 m
.81628 .38938 L
s
.81629 .38938 m
.81628 .38938 L
s
.81628 .38938 m
.81629 .38938 L
s
.81628 .38938 m
.81628 .38938 L
s
1 .457 0 r
.55074 .51718 m
.54985 .51644 L
s
.54985 .51644 m
.5507 .51238 L
s
.54985 .51644 m
.54675 .51409 L
s
1 .006 0 r
.30954 .26226 m
.30952 .26227 L
s
.30952 .26221 m
.30954 .26226 L
s
.30956 .26222 m
.30954 .26226 L
s
.30949 .26222 m
.30952 .26221 L
s
.30952 .26221 m
.30956 .26222 L
s
.30952 .26227 m
.30949 .26222 L
s
.30956 .26222 m
.30952 .26227 L
s
.30949 .26222 m
.30956 .26222 L
s
1 .457 0 r
.5507 .51238 m
.55159 .51312 L
s
.5507 .51238 m
.54675 .51409 L
s
1 .048 0 r
.42607 .45253 m
.42623 .45244 L
s
.42623 .45244 m
.42608 .45203 L
s
.42623 .45244 m
.4257 .4524 L
s
1 .091 0 r
.81905 .57879 m
.81967 .57917 L
s
.81852 .57938 m
.81905 .57879 L
s
.81905 .57879 m
.81891 .57884 L
s
1 .048 0 r
.42608 .45203 m
.42592 .45211 L
s
.42608 .45203 m
.4257 .4524 L
s
.4257 .4524 m
.42607 .45253 L
s
.4257 .4524 m
.42592 .45211 L
s
.42758 .45177 m
.4257 .4524 L
s
1 .019 0 r
.10807 .54761 m
.10809 .54762 L
s
.10811 .54741 m
.10807 .54761 L
s
.10807 .54761 m
.10797 .5475 L
s
.10823 .54754 m
.10807 .54761 L
s
.1082 .54713 m
.10807 .54761 L
s
1 .091 0 r
.81914 .57976 m
.81852 .57938 L
s
.81852 .57938 m
.81891 .57884 L
s
1 .525 0 r
.43513 .54865 m
.43691 .54758 L
s
.43691 .54758 m
.43528 .54308 L
s
.43691 .54758 m
.43109 .54716 L
s
1 .019 0 r
.10811 .54741 m
.10797 .5475 L
s
.10823 .54754 m
.10811 .54741 L
s
.10809 .54762 m
.10823 .54754 L
s
.10797 .5475 m
.10809 .54762 L
s
1 .048 0 r
.42592 .45211 m
.42607 .45253 L
s
1 .051 0 r
.56091 .13428 m
.56095 .13428 L
s
.56094 .1338 m
.56091 .13428 L
s
.56141 .13407 m
.56091 .13428 L
s
1 .091 0 r
.81967 .57917 m
.81914 .57976 L
s
.81891 .57884 m
.81967 .57917 L
s
1 .051 0 r
.56098 .1338 m
.56094 .1338 L
s
.56094 .1338 m
.56141 .13407 L
s
1 .525 0 r
.43528 .54308 m
.43349 .54414 L
s
.43528 .54308 m
.43109 .54716 L
s
1 .051 0 r
.56141 .13407 m
.56095 .13428 L
s
.56098 .1338 m
.56141 .13407 L
s
.55909 .13392 m
.56141 .13407 L
s
1 .091 0 r
.81891 .57884 m
.81914 .57976 L
s
1 .525 0 r
.43109 .54716 m
.43513 .54865 L
s
.43109 .54716 m
.43349 .54414 L
s
.45172 .54064 m
.43109 .54716 L
s
1 .005 0 r
.49352 .29285 m
.49352 .29286 L
s
.49352 .29281 m
.49352 .29285 L
s
.49356 .29283 m
.49352 .29285 L
s
1 0 0 r
.17396 .38821 m
.17396 .38821 L
s
.17396 .3882 m
.17396 .38821 L
s
.17396 .38821 m
.17396 .3882 L
s
.17396 .3882 m
.17396 .38821 L
s
.17396 .3882 m
.17396 .38821 L
s
.17396 .3882 m
.17396 .3882 L
s
.17396 .3882 m
.17396 .3882 L
s
.17396 .38821 m
.17396 .3882 L
s
.17396 .3882 m
.17396 .38821 L
s
1 .005 0 r
.49351 .29281 m
.49352 .29281 L
s
.49352 .29281 m
.49356 .29283 L
s
1 .151 0 r
.68121 .51534 m
.67686 .5124 L
s
1 0 0 r
.74696 .35642 m
.74696 .35642 L
s
1 .005 0 r
.49334 .29285 m
.49356 .29283 L
s
.49356 .29283 m
.49352 .29286 L
s
.49351 .29281 m
.49356 .29283 L
s
.49352 .29286 m
.49351 .29281 L
s
1 .051 0 r
.56095 .13428 m
.56098 .1338 L
s
.808 1 0 r
.4781 .58082 m
.47856 .57877 L
s
.47856 .57877 m
.47828 .56803 L
s
.47856 .57877 m
.46736 .57461 L
s
1 .318 0 r
.70021 .57573 m
.70217 .57688 L
s
.69843 .57799 m
.70021 .57573 L
s
.70021 .57573 m
.69907 .57601 L
s
1 .172 0 r
.33286 .54649 m
.33361 .54667 L
s
.33372 .54484 m
.33286 .54649 L
s
.33286 .54649 m
.33271 .54538 L
s
.33462 .54612 m
.33286 .54649 L
s
.33692 .54281 m
.33286 .54649 L
s
1 .023 0 r
.74394 .16479 m
.74404 .16481 L
s
.74403 .16459 m
.74394 .16479 L
s
.74421 .16477 m
.74394 .16479 L
s
.74421 .16477 m
.74404 .16481 L
s
.74403 .16459 m
.74421 .16477 L
s
.74412 .1646 m
.74421 .16477 L
s
.74334 .16438 m
.74421 .16477 L
s
.74412 .1646 m
.74403 .16459 L
s
1 .121 0 r
.74873 .54534 m
.7495 .54577 L
s
.74806 .5462 m
.74873 .54534 L
s
.74873 .54534 m
.74833 .54543 L
s
1 .053 0 r
.22171 .54625 m
.22182 .54627 L
s
.22188 .54571 m
.22171 .54625 L
s
.22171 .54625 m
.22152 .54591 L
s
.22218 .54607 m
.22171 .54625 L
s
.22242 .54497 m
.22171 .54625 L
s
1 .023 0 r
.74404 .16481 m
.74412 .1646 L
s
1 .172 0 r
.33372 .54484 m
.33271 .54538 L
s
.33462 .54612 m
.33372 .54484 L
s
1 .007 0 r
.03834 .51441 m
.03835 .51441 L
s
.03836 .51435 m
.03834 .51441 L
s
.03834 .51441 m
.03831 .51437 L
s
.03839 .51439 m
.03834 .51441 L
s
.03838 .51425 m
.03834 .51441 L
s
1 .121 0 r
.74882 .54663 m
.74806 .5462 L
s
.74806 .5462 m
.74833 .54543 L
s
1 .007 0 r
.03836 .51435 m
.03831 .51437 L
s
.03839 .51439 m
.03836 .51435 L
s
.03835 .51441 m
.03839 .51439 L
s
1 .318 0 r
.70039 .57914 m
.69843 .57799 L
s
.69843 .57799 m
.69907 .57601 L
s
1 .007 0 r
.03831 .51437 m
.03835 .51441 L
s
1 .006 0 r
.35776 .41894 m
.3578 .41895 L
s
.3578 .41889 m
.35776 .41894 L
s
.35776 .41894 m
.35777 .4189 L
s
.35783 .41894 m
.35776 .41894 L
s
.35796 .41883 m
.35776 .41894 L
s
.3578 .41895 m
.35783 .41894 L
s
.35783 .41894 m
.3578 .41889 L
s
.3578 .41889 m
.35777 .4189 L
s
1 .053 0 r
.22188 .54571 m
.22152 .54591 L
s
.22218 .54607 m
.22188 .54571 L
s
1 .172 0 r
.33361 .54667 m
.33462 .54612 L
s
1 .006 0 r
.35777 .4189 m
.3578 .41895 L
s
1 .053 0 r
.22182 .54627 m
.22218 .54607 L
s
1 0 0 r
.67756 .32342 m
.67756 .32342 L
s
.67756 .32341 m
.67756 .32342 L
s
.67757 .32342 m
.67756 .32342 L
s
.67756 .32341 m
.67756 .32341 L
s
.67756 .32341 m
.67757 .32342 L
s
.67757 .32342 m
.67756 .32342 L
s
.67756 .32341 m
.67757 .32342 L
s
.67755 .32341 m
.67757 .32342 L
s
.67756 .32342 m
.67756 .32341 L
s
1 .038 0 r
.86554 .54605 m
.86513 .54513 L
s
1 .141 0 r
.61175 .48244 m
.60618 .48066 L
s
1 .01 0 r
.42376 .2598 m
.42419 .2597 L
s
.42413 .25976 m
.4241 .25977 L
s
.4241 .25967 m
.42413 .25976 L
s
.42419 .2597 m
.42413 .25976 L
s
.42408 .25968 m
.4241 .25967 L
s
.4241 .25967 m
.42419 .2597 L
s
.42419 .2597 m
.4241 .25977 L
s
.42408 .25968 m
.42419 .2597 L
s
.4241 .25977 m
.42408 .25968 L
s
1 .053 0 r
.22152 .54591 m
.22182 .54627 L
s
1 .457 0 r
.54675 .51409 m
.55074 .51718 L
s
.54675 .51409 m
.55159 .51312 L
s
0 1 .511 r
.4632 .57563 m
.45864 .59787 L
s
.808 1 0 r
.47828 .56803 m
.47781 .57004 L
s
.47828 .56803 m
.46736 .57461 L
s
1 .121 0 r
.7495 .54577 m
.74882 .54663 L
s
.74833 .54543 m
.7495 .54577 L
s
.74833 .54543 m
.74882 .54663 L
s
1 .038 0 r
.86519 .54512 m
.86545 .54527 L
s
.86498 .54537 m
.86519 .54512 L
s
.86519 .54512 m
.86513 .54513 L
s
1 .039 0 r
.67507 .13177 m
.67518 .13179 L
s
.67516 .13142 m
.67507 .13177 L
s
.67549 .1317 m
.67507 .13177 L
s
1 .172 0 r
.33271 .54538 m
.33361 .54667 L
s
1 .039 0 r
.67528 .13144 m
.67516 .13142 L
s
.67516 .13142 m
.67549 .1317 L
s
1 .038 0 r
.86523 .54552 m
.86498 .54537 L
s
.86498 .54537 m
.86513 .54513 L
s
1 .039 0 r
.67549 .1317 m
.67518 .13179 L
s
.67528 .13144 m
.67549 .1317 L
s
.67388 .13123 m
.67549 .1317 L
s
1 .457 0 r
.55159 .51312 m
.55074 .51718 L
s
1 .038 0 r
.86545 .54527 m
.86523 .54552 L
s
.86513 .54513 m
.86545 .54527 L
s
1 .151 0 r
.67769 .5122 m
.67848 .5126 L
s
.67698 .51337 m
.67769 .5122 L
s
.67769 .5122 m
.67686 .5124 L
s
1 .038 0 r
.86513 .54513 m
.86523 .54552 L
s
1 .151 0 r
.67777 .51378 m
.67698 .51337 L
s
.67698 .51337 m
.67686 .5124 L
s
1 .039 0 r
.67518 .13179 m
.67528 .13144 L
s
1 .141 0 r
.60731 .48175 m
.60685 .4815 L
s
.60685 .4815 m
.60728 .48028 L
s
.60685 .4815 m
.60618 .48066 L
s
1 .07 0 r
.53968 .44971 m
.53963 .44963 L
s
.53963 .44963 m
.53967 .44899 L
s
.53963 .44963 m
.53904 .44932 L
s
1 .459 0 r
.62409 .54139 m
.62627 .54258 L
s
.62205 .54508 m
.62409 .54139 L
s
.62409 .54139 m
.62121 .54219 L
s
.62423 .54627 m
.62205 .54508 L
s
.62205 .54508 m
.62121 .54219 L
s
1 .141 0 r
.60728 .48028 m
.60775 .48053 L
s
.60728 .48028 m
.60618 .48066 L
s
1 .318 0 r
.70217 .57688 m
.70039 .57914 L
s
.69907 .57601 m
.70217 .57688 L
s
0 .197 1 r
.50466 .51447 m
.52635 .52774 L
s
.48289 .5414 m
.50466 .51447 L
s
.50466 .51447 m
.48759 .51676 L
s
1 .07 0 r
.53967 .44899 m
.53972 .44908 L
s
.53967 .44899 m
.53904 .44932 L
s
1 .004 0 r
.60818 .29041 m
.60819 .29041 L
s
.60819 .29037 m
.60818 .29041 L
s
.60822 .2904 m
.60818 .29041 L
s
.6082 .29037 m
.60819 .29037 L
s
.60819 .29037 m
.60822 .2904 L
s
.60822 .2904 m
.60819 .29041 L
s
.6082 .29037 m
.60822 .2904 L
s
.60804 .29036 m
.60822 .2904 L
s
.60819 .29041 m
.6082 .29037 L
s
1 0 0 r
.28825 .38585 m
.28825 .38585 L
s
.28825 .38584 m
.28825 .38585 L
s
.28825 .38585 m
.28825 .38584 L
s
.28825 .38585 m
.28825 .38585 L
s
.28826 .38584 m
.28825 .38585 L
s
.28825 .38584 m
.28825 .38584 L
s
.28825 .38585 m
.28825 .38584 L
s
.28825 .38585 m
.28825 .38585 L
s
.28825 .38584 m
.28825 .38585 L
s
1 .042 0 r
.79616 .51315 m
.7954 .51216 L
s
1 .07 0 r
.54221 .44949 m
.53904 .44932 L
s
1 .013 0 r
.35409 .22671 m
.3546 .22651 L
s
.35455 .2266 m
.3545 .22662 L
s
.35451 .22649 m
.35455 .2266 L
s
.3546 .22651 m
.35455 .2266 L
s
.35446 .2265 m
.35451 .22649 L
s
.35451 .22649 m
.3546 .22651 L
s
.3546 .22651 m
.3545 .22662 L
s
.35446 .2265 m
.3546 .22651 L
s
1 .07 0 r
.53904 .44932 m
.53968 .44971 L
s
.53904 .44932 m
.53972 .44908 L
s
1 .013 0 r
.3545 .22662 m
.35446 .2265 L
s
1 .318 0 r
.69907 .57601 m
.70039 .57914 L
s
1 .07 0 r
.53972 .44908 m
.53968 .44971 L
s
1 .151 0 r
.67848 .5126 m
.67777 .51378 L
s
.67686 .5124 m
.67848 .5126 L
s
1 .525 0 r
.43349 .54414 m
.43513 .54865 L
s
1 .151 0 r
.67686 .5124 m
.67777 .51378 L
s
1 .141 0 r
.60618 .48066 m
.60731 .48175 L
s
.60618 .48066 m
.60775 .48053 L
s
1 .042 0 r
.79553 .51213 m
.7958 .51228 L
s
.7953 .51243 m
.79553 .51213 L
s
.79553 .51213 m
.7954 .51216 L
s
1 .141 0 r
.60775 .48053 m
.60731 .48175 L
s
1 .016 0 r
.15239 .51244 m
.15242 .51245 L
s
.15244 .51228 m
.15239 .51244 L
s
.15239 .51244 m
.15233 .51234 L
s
.15253 .51239 m
.15239 .51244 L
s
.15258 .51204 m
.15239 .51244 L
s
1 .042 0 r
.79557 .51258 m
.7953 .51243 L
s
.7953 .51243 m
.7954 .51216 L
s
1 .016 0 r
.15244 .51228 m
.15233 .51234 L
s
.15253 .51239 m
.15244 .51228 L
s
.15242 .51245 m
.15253 .51239 L
s
.15233 .51234 m
.15242 .51245 L
s
1 .042 0 r
.7958 .51228 m
.79557 .51258 L
s
.7954 .51216 m
.7958 .51228 L
s
.7954 .51216 m
.79557 .51258 L
s
1 .014 0 r
.47207 .41665 m
.4721 .41664 L
s
.4721 .41664 m
.47208 .41651 L
s
.4721 .41664 m
.47195 .4166 L
s
.47208 .41651 m
.47205 .41653 L
s
.47208 .41651 m
.47195 .4166 L
s
.47195 .4166 m
.47207 .41665 L
s
.47195 .4166 m
.47205 .41653 L
s
.47257 .4165 m
.47195 .4166 L
s
1 .012 0 r
.53888 .25733 m
.53888 .25734 L
s
.53888 .25722 m
.53888 .25733 L
s
.53899 .25729 m
.53888 .25733 L
s
.53888 .25723 m
.53888 .25722 L
s
.53888 .25722 m
.53899 .25729 L
s
1 .014 0 r
.47205 .41653 m
.47207 .41665 L
s
1 .012 0 r
.53899 .25729 m
.53888 .25734 L
s
.53888 .25723 m
.53899 .25729 L
s
.53845 .25727 m
.53899 .25729 L
s
1 0 0 r
.79257 .32097 m
.79257 .32097 L
s
.79257 .32097 m
.79257 .32097 L
s
.79257 .32097 m
.79257 .32097 L
s
.79257 .32097 m
.79257 .32097 L
s
.79256 .32096 m
.79257 .32097 L
s
.79257 .32097 m
.79257 .32097 L
s
.79257 .32097 m
.79257 .32097 L
s
.79257 .32097 m
.79257 .32097 L
s
.79257 .32097 m
.79257 .32097 L
s
1 .043 0 r
.72668 .4802 m
.72555 .47931 L
s
1 0 0 r
.21846 .35281 m
.21846 .35281 L
s
1 .012 0 r
.53888 .25734 m
.53888 .25723 L
s
0 .434 1 r
.5291 .51165 m
.50872 .5369 L
s
.49314 .50136 m
.5291 .51165 L
s
1 .043 0 r
.72576 .47927 m
.726 .47938 L
s
.72555 .47959 m
.72576 .47927 L
s
.72576 .47927 m
.72555 .47931 L
s
.72579 .47971 m
.72555 .47959 L
s
.72555 .47959 m
.72555 .47931 L
s
.726 .47938 m
.72579 .47971 L
s
.72555 .47931 m
.726 .47938 L
s
.72555 .47931 m
.72579 .47971 L
s
.808 1 0 r
.55582 .57768 m
.55126 .57486 L
s
.55126 .57486 m
.5557 .56488 L
s
.55126 .57486 m
.54691 .56774 L
s
1 .005 0 r
.0826 .47919 m
.08261 .47919 L
s
.08261 .47914 m
.0826 .47919 L
s
.0826 .47919 m
.08258 .47916 L
s
.08264 .47917 m
.0826 .47919 L
s
.08265 .47907 m
.0826 .47919 L
s
.08261 .47914 m
.08258 .47916 L
s
.08264 .47917 m
.08261 .47914 L
s
.08261 .47919 m
.08264 .47917 L
s
.08258 .47916 m
.08261 .47919 L
s
1 .002 0 r
.7231 .28791 m
.72311 .28791 L
s
.72311 .28789 m
.7231 .28791 L
s
.72312 .28791 m
.7231 .28791 L
s
.72312 .28791 m
.72311 .28791 L
s
.72311 .28789 m
.72312 .28791 L
s
.72312 .28789 m
.72312 .28791 L
s
.72305 .28787 m
.72312 .28791 L
s
.72312 .28789 m
.72311 .28789 L
s
.72311 .28791 m
.72312 .28789 L
s
1 .001 0 r
.40282 .38349 m
.40282 .38348 L
s
.40282 .38348 m
.40282 .38348 L
s
.40282 .38348 m
.40281 .38348 L
s
.40282 .38348 m
.40282 .38348 L
s
.40282 .38348 m
.40281 .38348 L
s
.40281 .38348 m
.40282 .38349 L
s
.40281 .38348 m
.40282 .38348 L
s
.40285 .38347 m
.40281 .38348 L
s
.40282 .38348 m
.40282 .38349 L
s
1 .019 0 r
.46948 .22414 m
.46946 .22414 L
s
.46946 .22396 m
.46948 .22414 L
s
.46963 .22403 m
.46948 .22414 L
s
1 .032 0 r
.65712 .44721 m
.65597 .4467 L
s
1 .019 0 r
.46877 .22414 m
.46963 .22403 L
s
.46943 .22397 m
.46946 .22396 L
s
.46946 .22396 m
.46963 .22403 L
s
1 .047 0 r
.26615 .51091 m
.26631 .51094 L
s
.26635 .51045 m
.26615 .51091 L
s
.26615 .51091 m
.26606 .5106 L
s
.26661 .51078 m
.26615 .51091 L
s
.26707 .50984 m
.26615 .51091 L
s
.808 1 0 r
.46736 .57461 m
.4781 .58082 L
s
.46736 .57461 m
.47781 .57004 L
s
.52151 .57361 m
.46736 .57461 L
s
1 .019 0 r
.46963 .22403 m
.46946 .22414 L
s
.46943 .22397 m
.46963 .22403 L
s
1 .047 0 r
.26635 .51045 m
.26606 .5106 L
s
.26661 .51078 m
.26635 .51045 L
s
1 .019 0 r
.46946 .22414 m
.46943 .22397 L
s
1 .047 0 r
.26631 .51094 m
.26661 .51078 L
s
.808 1 0 r
.5557 .56488 m
.56028 .56767 L
s
.5557 .56488 m
.54691 .56774 L
s
1 .459 0 r
.62627 .54258 m
.62423 .54627 L
s
.62121 .54219 m
.62627 .54258 L
s
.62121 .54219 m
.62423 .54627 L
s
1 .032 0 r
.65621 .44697 m
.65607 .4469 L
s
.65607 .4469 m
.65619 .44663 L
s
.65607 .4469 m
.65597 .4467 L
s
.65619 .44663 m
.65633 .4467 L
s
.65619 .44663 m
.65597 .4467 L
s
1 .047 0 r
.26606 .5106 m
.26631 .51094 L
s
1 .032 0 r
.65633 .4467 m
.65621 .44697 L
s
.65597 .4467 m
.65621 .44697 L
s
.65597 .4467 m
.65633 .4467 L
s
1 .151 0 r
.37703 .51034 m
.37796 .51059 L
s
.37803 .509 m
.37703 .51034 L
s
.37703 .51034 m
.3773 .50937 L
s
.37869 .51022 m
.37703 .51034 L
s
.38185 .50762 m
.37703 .51034 L
s
.37796 .51059 m
.37869 .51022 L
s
.37869 .51022 m
.37803 .509 L
s
.37803 .509 m
.3773 .50937 L
s
1 .008 0 r
.65369 .25485 m
.65371 .25485 L
s
.65371 .25477 m
.65369 .25485 L
s
.65378 .25483 m
.65369 .25485 L
s
.65373 .25478 m
.65371 .25477 L
s
.65371 .25477 m
.65378 .25483 L
s
.65378 .25483 m
.65371 .25485 L
s
.65373 .25478 m
.65378 .25483 L
s
.65344 .25473 m
.65378 .25483 L
s
.65371 .25485 m
.65373 .25478 L
s
1 .013 0 r
.84191 .47795 m
.84168 .47763 L
s
.58747 .41417 m
.58692 .41407 L
s
1 0 0 r
.33303 .3504 m
.33303 .3504 L
s
1 .023 0 r
.399 .19096 m
.39998 .1907 L
s
1 .013 0 r
.58703 .41416 m
.58701 .41414 L
s
.58701 .41414 m
.58703 .41403 L
s
.58701 .41414 m
.58692 .41407 L
s
.58703 .41403 m
.58706 .41404 L
s
.58703 .41403 m
.58692 .41407 L
s
1 .023 0 r
.39984 .19085 m
.39978 .19086 L
s
.39979 .19064 m
.39984 .19085 L
s
.39998 .1907 m
.39984 .19085 L
s
1 .013 0 r
.58692 .41407 m
.58703 .41416 L
s
.58692 .41407 m
.58706 .41404 L
s
1 .023 0 r
.39972 .19065 m
.39979 .19064 L
s
.39979 .19064 m
.39998 .1907 L
s
1 .013 0 r
.58706 .41404 m
.58703 .41416 L
s
.84172 .47763 m
.84181 .47767 L
s
.84165 .47772 m
.84172 .47763 L
s
.84172 .47763 m
.84168 .47763 L
s
1 .023 0 r
.39998 .1907 m
.39978 .19086 L
s
.39972 .19065 m
.39998 .1907 L
s
1 .013 0 r
.84174 .47776 m
.84165 .47772 L
s
.84165 .47772 m
.84168 .47763 L
s
1 .023 0 r
.39978 .19086 m
.39972 .19065 L
s
1 .013 0 r
.84181 .47767 m
.84174 .47776 L
s
.84168 .47763 m
.84181 .47767 L
s
.84168 .47763 m
.84174 .47776 L
s
0 .197 1 r
.5044 .55497 m
.48289 .5414 L
s
.48289 .5414 m
.48759 .51676 L
s
1 .151 0 r
.3773 .50937 m
.37796 .51059 L
s
1 .012 0 r
.19692 .4771 m
.19696 .47711 L
s
.19697 .47699 m
.19692 .4771 L
s
.19692 .4771 m
.19689 .47703 L
s
.19703 .47707 m
.19692 .4771 L
s
.19712 .47682 m
.19692 .4771 L
s
.19697 .47699 m
.19689 .47703 L
s
.19703 .47707 m
.19697 .47699 L
s
.19696 .47711 m
.19703 .47707 L
s
.19689 .47703 m
.19696 .47711 L
s
1 .018 0 r
.58437 .22172 m
.5844 .22173 L
s
.5844 .22155 m
.58437 .22172 L
s
.58456 .22166 m
.58437 .22172 L
s
.58442 .22156 m
.5844 .22155 L
s
.5844 .22155 m
.58456 .22166 L
s
.58456 .22166 m
.5844 .22173 L
s
.58442 .22156 m
.58456 .22166 L
s
.58374 .22156 m
.58456 .22166 L
s
.5844 .22173 m
.58442 .22156 L
s
1 .001 0 r
.51768 .3811 m
.51768 .3811 L
s
.51768 .3811 m
.51768 .38109 L
s
.51768 .3811 m
.51767 .3811 L
s
.51768 .38109 m
.51768 .38109 L
s
.51768 .38109 m
.51767 .3811 L
s
.51767 .3811 m
.51768 .3811 L
s
.51767 .3811 m
.51768 .38109 L
s
.51773 .3811 m
.51767 .3811 L
s
1 .01 0 r
.77234 .44491 m
.77208 .44469 L
s
1 0 0 r
.26313 .31728 m
.26313 .31728 L
s
.26313 .31728 m
.26313 .31728 L
s
.26313 .31728 m
.26313 .31728 L
s
.26313 .31728 m
.26313 .31728 L
s
.26313 .31728 m
.26313 .31728 L
s
.26313 .31728 m
.26313 .31728 L
s
1 .001 0 r
.51768 .38109 m
.51768 .3811 L
s
1 0 0 r
.26313 .31728 m
.26313 .31728 L
s
.26313 .31728 m
.26313 .31728 L
s
.26313 .31728 m
.26313 .31728 L
s
1 .01 0 r
.77213 .44469 m
.77219 .44471 L
s
.77208 .44476 m
.77213 .44469 L
s
.77213 .44469 m
.77208 .44469 L
s
.77214 .44479 m
.77208 .44476 L
s
.77208 .44476 m
.77208 .44469 L
s
.77219 .44471 m
.77214 .44479 L
s
.77208 .44469 m
.77219 .44471 L
s
.77208 .44469 m
.77214 .44479 L
s
0 .434 1 r
.49314 .50136 m
.50872 .5369 L
s
1 .336 0 r
.48487 .50842 m
.4853 .50792 L
s
.4853 .50792 m
.48492 .50489 L
s
.4853 .50792 m
.48189 .50697 L
s
1 .028 0 r
.51499 .18844 m
.51498 .18845 L
s
.51498 .18818 m
.51499 .18844 L
s
.51524 .18831 m
.51499 .18844 L
s
1 .004 0 r
.76886 .25227 m
.76883 .25228 L
s
.76883 .25224 m
.76886 .25227 L
s
.76886 .25227 m
.76881 .25227 L
s
.76885 .25224 m
.76886 .25227 L
s
.76872 .25219 m
.76886 .25227 L
s
.76881 .25227 m
.76883 .25228 L
s
.76883 .25224 m
.76881 .25227 L
s
.76885 .25224 m
.76883 .25224 L
s
1 .003 0 r
.12705 .44383 m
.12705 .44383 L
s
.12706 .4438 m
.12705 .44383 L
s
.12705 .44383 m
.12704 .44381 L
s
.12707 .44382 m
.12705 .44383 L
s
.12708 .44376 m
.12705 .44383 L
s
1 .028 0 r
.51498 .18818 m
.51498 .18818 L
s
.51498 .18818 m
.51524 .18831 L
s
1 .003 0 r
.12706 .4438 m
.12704 .44381 L
s
.12707 .44382 m
.12706 .4438 L
s
.12705 .44383 m
.12707 .44382 L
s
.12704 .44381 m
.12705 .44383 L
s
1 .004 0 r
.76883 .25228 m
.76885 .25224 L
s
1 .575 0 r
.63662 .57148 m
.61806 .56129 L
s
1 .005 0 r
.70267 .41184 m
.7025 .41175 L
s
1 .028 0 r
.51395 .18833 m
.51524 .18831 L
s
1 0 0 r
.4479 .34798 m
.4479 .34798 L
s
1 .028 0 r
.51524 .18831 m
.51498 .18845 L
s
.51498 .18818 m
.51524 .18831 L
s
1 .336 0 r
.48492 .50489 m
.48448 .50539 L
s
.48492 .50489 m
.48189 .50697 L
s
1 .005 0 r
.70254 .41179 m
.70251 .41178 L
s
.70251 .41178 m
.70253 .41174 L
s
.70251 .41178 m
.7025 .41175 L
s
.70253 .41174 m
.70256 .41175 L
s
.70253 .41174 m
.7025 .41175 L
s
.70256 .41175 m
.70254 .41179 L
s
.7025 .41175 m
.70254 .41179 L
s
.7025 .41175 m
.70256 .41175 L
s
1 .028 0 r
.51498 .18845 m
.51498 .18818 L
s
.808 1 0 r
.47781 .57004 m
.4781 .58082 L
s
1 .035 0 r
.31096 .4753 m
.31113 .47533 L
s
.31116 .47497 m
.31096 .4753 L
s
.31096 .4753 m
.31096 .47506 L
s
.31133 .47524 m
.31096 .4753 L
s
.31189 .47456 m
.31096 .4753 L
s
.31116 .47497 m
.31096 .47506 L
s
.31133 .47524 m
.31116 .47497 L
s
.31113 .47533 m
.31133 .47524 L
s
.31096 .47506 m
.31113 .47533 L
s
1 .336 0 r
.48189 .50697 m
.48487 .50842 L
s
.48189 .50697 m
.48448 .50539 L
s
.49693 .5054 m
.48189 .50697 L
s
1 .012 0 r
.69933 .21915 m
.69938 .21916 L
s
.69937 .21905 m
.69933 .21915 L
s
.69947 .21914 m
.69933 .21915 L
s
.69941 .21906 m
.69937 .21905 L
s
.69937 .21905 m
.69947 .21914 L
s
.69947 .21914 m
.69938 .21916 L
s
.69941 .21906 m
.69947 .21914 L
s
.69901 .21897 m
.69947 .21914 L
s
.69938 .21916 m
.69941 .21906 L
s
1 .001 0 r
.63291 .37872 m
.63288 .37871 L
s
1 .607 0 r
.56682 .53846 m
.54037 .53391 L
s
1 0 0 r
.37798 .31482 m
.378 .31481 L
s
1 .034 0 r
.44408 .15507 m
.44557 .15484 L
s
1 0 0 r
.378 .31481 m
.378 .31481 L
s
.378 .31481 m
.378 .31481 L
s
.378 .31481 m
.378 .31481 L
s
.37799 .31481 m
.378 .31481 L
s
.378 .31481 m
.378 .31481 L
s
1 .001 0 r
.63288 .37871 m
.63288 .37871 L
s
.63288 .37871 m
.63288 .3787 L
s
.63288 .37871 m
.63288 .37871 L
s
.63288 .3787 m
.63289 .3787 L
s
.63288 .3787 m
.63288 .37871 L
s
1 0 0 r
.378 .31481 m
.378 .31481 L
s
.37799 .31481 m
.378 .31481 L
s
.378 .31481 m
.37799 .31481 L
s
1 .001 0 r
.63288 .37871 m
.63288 .37871 L
s
.63288 .37871 m
.63289 .3787 L
s
.63289 .3787 m
.63288 .37871 L
s
1 .034 0 r
.44533 .15503 m
.44527 .15504 L
s
.44528 .15472 m
.44533 .15503 L
s
.44557 .15484 m
.44533 .15503 L
s
.44522 .15473 m
.44528 .15472 L
s
.44528 .15472 m
.44557 .15484 L
s
1 .65 0 r
.43058 .57174 m
.43281 .57035 L
s
.43281 .57035 m
.43078 .56476 L
s
.43281 .57035 m
.42556 .56984 L
s
1 .034 0 r
.44557 .15484 m
.44527 .15504 L
s
.44522 .15473 m
.44557 .15484 L
s
.44527 .15504 m
.44522 .15473 L
s
1 .65 0 r
.43078 .56476 m
.42854 .56613 L
s
.43078 .56476 m
.42556 .56984 L
s
.42556 .56984 m
.43058 .57174 L
s
.42556 .56984 m
.42854 .56613 L
s
.45125 .56182 m
.42556 .56984 L
s
1 .336 0 r
.48448 .50539 m
.48487 .50842 L
s
1 .1 0 r
.4238 .47386 m
.42415 .47368 L
s
.42415 .47368 m
.42383 .47282 L
s
.42415 .47368 m
.42303 .4736 L
s
1 .023 0 r
.62996 .18597 m
.63001 .18598 L
s
.63001 .18576 m
.62996 .18597 L
s
.63021 .18592 m
.62996 .18597 L
s
.63006 .18577 m
.63001 .18576 L
s
.63001 .18576 m
.63021 .18592 L
s
1 .1 0 r
.42383 .47282 m
.42349 .473 L
s
.42383 .47282 m
.42303 .4736 L
s
1 .023 0 r
.63021 .18592 m
.63001 .18598 L
s
.63006 .18577 m
.63021 .18592 L
s
.6292 .1857 m
.63021 .18592 L
s
1 .1 0 r
.42303 .4736 m
.4238 .47386 L
s
.42303 .4736 m
.42349 .473 L
s
.42695 .4723 m
.42303 .4736 L
s
1 .007 0 r
.24168 .44162 m
.24171 .44162 L
s
.24172 .44155 m
.24168 .44162 L
s
.24168 .44162 m
.24167 .44157 L
s
.24175 .4416 m
.24168 .44162 L
s
.24184 .44146 m
.24168 .44162 L
s
.24172 .44155 m
.24167 .44157 L
s
.24175 .4416 m
.24172 .44155 L
s
.24171 .44162 m
.24175 .4416 L
s
.24167 .44157 m
.24171 .44162 L
s
1 .023 0 r
.63001 .18598 m
.63006 .18577 L
s
1 .168 0 r
.75203 .56934 m
.74889 .56552 L
s
1 .002 0 r
.81816 .40949 m
.81812 .40945 L
s
1 0 0 r
.56307 .34555 m
.56307 .34555 L
s
1 .002 0 r
.30797 .28161 m
.30803 .28158 L
s
.30803 .28159 m
.30802 .2816 L
s
.30802 .28158 m
.30803 .28159 L
s
.30803 .28158 m
.30803 .28159 L
s
.30801 .28158 m
.30802 .28158 L
s
.30802 .28158 m
.30803 .28158 L
s
.81813 .40945 m
.81814 .40946 L
s
.81812 .40947 m
.81813 .40945 L
s
.81813 .40945 m
.81812 .40945 L
s
.81813 .40947 m
.81812 .40947 L
s
.81812 .40947 m
.81812 .40945 L
s
.30802 .2816 m
.30801 .28158 L
s
.30803 .28158 m
.30802 .2816 L
s
.30801 .28158 m
.30803 .28158 L
s
.81814 .40946 m
.81813 .40947 L
s
.81812 .40945 m
.81814 .40946 L
s
.81812 .40945 m
.81813 .40947 L
s
1 .029 0 r
.10532 .56899 m
.10534 .56901 L
s
.10538 .56869 m
.10532 .56899 L
s
.10532 .56899 m
.10517 .56882 L
s
.10555 .56888 m
.10532 .56899 L
s
.10552 .56827 m
.10532 .56899 L
s
1 .607 0 r
.54569 .53805 m
.54452 .53701 L
s
.54452 .53701 m
.54565 .53159 L
s
.54452 .53701 m
.54037 .53391 L
s
1 .1 0 r
.42349 .473 m
.4238 .47386 L
s
1 .029 0 r
.10538 .56869 m
.10517 .56882 L
s
.10555 .56888 m
.10538 .56869 L
s
1 .233 0 r
.33017 .56892 m
.3312 .56919 L
s
.33135 .56668 m
.33017 .56892 L
s
.33017 .56892 m
.32997 .56744 L
s
.33258 .56843 m
.33017 .56892 L
s
.33571 .56398 m
.33017 .56892 L
s
1 .029 0 r
.10534 .56901 m
.10555 .56888 L
s
.10517 .56882 m
.10534 .56901 L
s
1 .233 0 r
.33135 .56668 m
.32997 .56744 L
s
.33258 .56843 m
.33135 .56668 L
s
1 .607 0 r
.54565 .53159 m
.54683 .53263 L
s
.54565 .53159 m
.54037 .53391 L
s
1 .035 0 r
.56056 .15264 m
.56058 .15264 L
s
.56058 .15231 m
.56056 .15264 L
s
.5609 .1525 m
.56056 .15264 L
s
.5606 .15232 m
.56058 .15231 L
s
.56058 .15231 m
.5609 .1525 L
s
1 .233 0 r
.3312 .56919 m
.33258 .56843 L
s
1 .035 0 r
.5609 .1525 m
.56058 .15264 L
s
.5606 .15232 m
.5609 .1525 L
s
.55931 .1524 m
.5609 .1525 L
s
1 .001 0 r
.17167 .40834 m
.17168 .40834 L
s
.17168 .40833 m
.17167 .40834 L
s
.17167 .40834 m
.17167 .40834 L
s
.17168 .40834 m
.17167 .40834 L
s
.17169 .40832 m
.17167 .40834 L
s
.17168 .40833 m
.17167 .40834 L
s
.17168 .40834 m
.17168 .40833 L
s
.17168 .40834 m
.17168 .40834 L
s
.17167 .40834 m
.17168 .40834 L
s
.49316 .31235 m
.49316 .31235 L
s
.49316 .31234 m
.49316 .31235 L
s
.49316 .31235 m
.49316 .31235 L
s
.49316 .31234 m
.49316 .31234 L
s
.49316 .31234 m
.49316 .31235 L
s
1 .22 0 r
.68221 .53628 m
.67582 .532 L
s
1 0 0 r
.74839 .37633 m
.74838 .37632 L
s
1 .001 0 r
.49313 .31235 m
.49316 .31235 L
s
.49316 .31235 m
.49316 .31235 L
s
.49316 .31234 m
.49316 .31235 L
s
.49316 .31235 m
.49316 .31234 L
s
1 0 0 r
.74838 .37632 m
.74838 .37632 L
s
.74838 .37632 m
.74838 .37632 L
s
.74838 .37632 m
.74838 .37632 L
s
.74838 .37633 m
.74838 .37632 L
s
.74838 .37632 m
.74838 .37632 L
s
.74838 .37632 m
.74838 .37633 L
s
.74838 .37632 m
.74838 .37632 L
s
.74838 .37632 m
.74838 .37633 L
s
1 .035 0 r
.56058 .15264 m
.5606 .15232 L
s
.808 1 0 r
.56028 .56767 m
.55582 .57768 L
s
.54691 .56774 m
.55582 .57768 L
s
1 .077 0 r
.21943 .56796 m
.2196 .568 L
s
.21968 .56718 m
.21943 .56796 L
s
.21943 .56796 m
.21916 .56748 L
s
.22012 .5677 m
.21943 .56796 L
s
.22046 .56613 m
.21943 .56796 L
s
.21968 .56718 m
.21916 .56748 L
s
.22012 .5677 m
.21968 .56718 L
s
.808 1 0 r
.54691 .56774 m
.56028 .56767 L
s
1 .077 0 r
.2196 .568 m
.22012 .5677 L
s
1 .02 0 r
.35623 .43951 m
.35635 .43954 L
s
.35637 .43933 m
.35623 .43951 L
s
.35623 .43951 m
.35627 .43938 L
s
.35645 .4395 m
.35623 .43951 L
s
.35689 .43916 m
.35623 .43951 L
s
.35635 .43954 m
.35645 .4395 L
s
.35645 .4395 m
.35637 .43933 L
s
.35637 .43933 m
.35627 .43938 L
s
1 .077 0 r
.21916 .56748 m
.2196 .568 L
s
1 .011 0 r
.03518 .53547 m
.03518 .53547 L
s
.0352 .53535 m
.03518 .53547 L
s
.03518 .53547 m
.03512 .5354 L
s
.03526 .53542 m
.03518 .53547 L
s
.03524 .53519 m
.03518 .53547 L
s
.0352 .53535 m
.03512 .5354 L
s
.03526 .53542 m
.0352 .53535 L
s
1 .233 0 r
.32997 .56744 m
.3312 .56919 L
s
1 .011 0 r
.03518 .53547 m
.03526 .53542 L
s
1 .02 0 r
.35627 .43938 m
.35635 .43954 L
s
1 .011 0 r
.03512 .5354 m
.03518 .53547 L
s
1 .014 0 r
.74512 .18332 m
.74518 .18333 L
s
.74517 .18319 m
.74512 .18332 L
s
.74528 .18331 m
.74512 .18332 L
s
.74528 .18331 m
.74518 .18333 L
s
.74517 .18319 m
.74528 .18331 L
s
.74523 .1832 m
.74528 .18331 L
s
.74475 .18307 m
.74528 .18331 L
s
.74523 .1832 m
.74517 .18319 L
s
.74518 .18333 m
.74523 .1832 L
s
1 .043 0 r
.4909 .11914 m
.49087 .11914 L
s
.49088 .11874 m
.4909 .11914 L
s
.49126 .11892 m
.4909 .11914 L
s
.49085 .11874 m
.49088 .11874 L
s
.49088 .11874 m
.49126 .11892 L
s
1 .055 0 r
.86773 .5672 m
.86714 .56586 L
s
1 .229 0 r
.61231 .50318 m
.60322 .5003 L
s
1 0 0 r
.67853 .34312 m
.67853 .34312 L
s
1 .003 0 r
.42311 .2791 m
.42324 .27907 L
s
1 .043 0 r
.48933 .11904 m
.49126 .11892 L
s
1 .003 0 r
.42322 .27909 m
.42321 .27909 L
s
.42321 .27906 m
.42322 .27909 L
s
.42324 .27907 m
.42322 .27909 L
s
.42321 .27906 m
.42321 .27906 L
s
.42321 .27906 m
.42324 .27907 L
s
.42324 .27907 m
.42321 .27909 L
s
.42321 .27906 m
.42324 .27907 L
s
.42321 .27909 m
.42321 .27906 L
s
1 .043 0 r
.49126 .11892 m
.49087 .11914 L
s
.49085 .11874 m
.49126 .11892 L
s
.49087 .11914 m
.49085 .11874 L
s
1 .168 0 r
.74946 .56538 m
.75052 .56599 L
s
.74852 .56658 m
.74946 .56538 L
s
.74946 .56538 m
.74889 .56552 L
s
.74958 .56719 m
.74852 .56658 L
s
.74852 .56658 m
.74889 .56552 L
s
1 .65 0 r
.42854 .56613 m
.43058 .57174 L
s
1 .026 0 r
.67565 .15008 m
.67572 .15009 L
s
.67571 .14984 m
.67565 .15008 L
s
.67594 .15003 m
.67565 .15008 L
s
.67579 .14985 m
.67571 .14984 L
s
.67571 .14984 m
.67594 .15003 L
s
.67594 .15003 m
.67572 .15009 L
s
.67579 .14985 m
.67594 .15003 L
s
.67484 .14971 m
.67594 .15003 L
s
1 .141 0 r
.53719 .47049 m
.5371 .4703 L
s
.5371 .4703 m
.53718 .46901 L
s
.5371 .4703 m
.5359 .46968 L
s
1 .055 0 r
.86723 .56584 m
.86761 .56606 L
s
.8669 .5662 m
.86723 .56584 L
s
.86723 .56584 m
.86714 .56586 L
s
1 .026 0 r
.67572 .15009 m
.67579 .14985 L
s
1 .141 0 r
.53718 .46901 m
.53727 .4692 L
s
.53718 .46901 m
.5359 .46968 L
s
1 .055 0 r
.86729 .56643 m
.8669 .5662 L
s
.8669 .5662 m
.86714 .56586 L
s
1 .003 0 r
.28665 .40602 m
.28666 .40603 L
s
.28667 .406 m
.28665 .40602 L
s
.28665 .40602 m
.28665 .40601 L
s
.28668 .40602 m
.28665 .40602 L
s
.28673 .40597 m
.28665 .40602 L
s
.28667 .406 m
.28665 .40601 L
s
.28668 .40602 m
.28667 .406 L
s
.28666 .40603 m
.28668 .40602 L
s
.28665 .40601 m
.28666 .40603 L
s
1 .001 0 r
.6086 .30988 m
.6086 .30988 L
s
.6086 .30987 m
.6086 .30988 L
s
.6086 .30988 m
.6086 .30988 L
s
.6086 .30987 m
.6086 .30987 L
s
.6086 .30987 m
.6086 .30988 L
s
.6086 .30988 m
.6086 .30988 L
s
.6086 .30987 m
.6086 .30988 L
s
.60858 .30987 m
.6086 .30988 L
s
.6086 .30988 m
.6086 .30987 L
s
1 .066 0 r
.7979 .5341 m
.79671 .53255 L
s
1 .141 0 r
.54232 .47003 m
.5359 .46968 L
s
1 .006 0 r
.35299 .24581 m
.35322 .24572 L
s
.35319 .24576 m
.35317 .24577 L
s
.35317 .24571 m
.35319 .24576 L
s
.35322 .24572 m
.35319 .24576 L
s
.35315 .24572 m
.35317 .24571 L
s
.35317 .24571 m
.35322 .24572 L
s
1 .055 0 r
.86761 .56606 m
.86729 .56643 L
s
.86714 .56586 m
.86761 .56606 L
s
1 .006 0 r
.35322 .24572 m
.35317 .24577 L
s
.35315 .24572 m
.35322 .24572 L
s
.35317 .24577 m
.35315 .24572 L
s
1 .168 0 r
.75052 .56599 m
.74958 .56719 L
s
.74889 .56552 m
.75052 .56599 L
s
1 .055 0 r
.86714 .56586 m
.86729 .56643 L
s
1 .607 0 r
.54037 .53391 m
.54569 .53805 L
s
.54037 .53391 m
.54683 .53263 L
s
1 .168 0 r
.74889 .56552 m
.74958 .56719 L
s
1 .141 0 r
.5359 .46968 m
.53719 .47049 L
s
.5359 .46968 m
.53727 .4692 L
s
1 .229 0 r
.60507 .50208 m
.6043 .50166 L
s
.6043 .50166 m
.60501 .49967 L
s
.6043 .50166 m
.60322 .5003 L
s
1 .026 0 r
.14987 .53365 m
.14991 .53366 L
s
.14994 .53338 m
.14987 .53365 L
s
.14987 .53365 m
.14976 .53348 L
s
.1501 .53355 m
.14987 .53365 L
s
.15017 .533 m
.14987 .53365 L
s
.14994 .53338 m
.14976 .53348 L
s
.1501 .53355 m
.14994 .53338 L
s
1 .229 0 r
.60501 .49967 m
.60577 .5001 L
s
.60501 .49967 m
.60322 .5003 L
s
1 .026 0 r
.14991 .53366 m
.1501 .53355 L
s
.14976 .53348 m
.14991 .53366 L
s
1 .22 0 r
.67704 .53168 m
.67821 .53229 L
s
.67599 .53342 m
.67704 .53168 L
s
.67704 .53168 m
.67582 .532 L
s
1 .141 0 r
.53727 .4692 m
.53719 .47049 L
s
1 .22 0 r
.67715 .53403 m
.67599 .53342 L
s
.67599 .53342 m
.67582 .532 L
s
1 .043 0 r
.47071 .43731 m
.47078 .43725 L
s
.47078 .43725 m
.47071 .43686 L
s
.47078 .43725 m
.47033 .43714 L
s
.47071 .43686 m
.47063 .43692 L
s
.47071 .43686 m
.47033 .43714 L
s
1 .039 0 r
.60618 .1167 m
.60624 .1167 L
s
.60623 .11634 m
.60618 .1167 L
s
.60658 .11657 m
.60618 .1167 L
s
1 .043 0 r
.47033 .43714 m
.47071 .43731 L
s
.47033 .43714 m
.47063 .43692 L
s
.47223 .43684 m
.47033 .43714 L
s
1 .039 0 r
.60629 .11634 m
.60623 .11634 L
s
.60623 .11634 m
.60658 .11657 L
s
.60658 .11657 m
.60624 .1167 L
s
.60629 .11634 m
.60658 .11657 L
s
.60484 .11632 m
.60658 .11657 L
s
1 .607 0 r
.54683 .53263 m
.54569 .53805 L
s
1 .043 0 r
.47063 .43692 m
.47071 .43731 L
s
1 .039 0 r
.60624 .1167 m
.60629 .11634 L
s
1 .066 0 r
.79692 .53251 m
.79735 .53274 L
s
.79655 .53298 m
.79692 .53251 L
s
.79692 .53251 m
.79671 .53255 L
s
1 .004 0 r
.53867 .2766 m
.53867 .2766 L
s
.53867 .27657 m
.53867 .2766 L
s
.53871 .27659 m
.53867 .2766 L
s
.53867 .27657 m
.53867 .27657 L
s
.53867 .27657 m
.53871 .27659 L
s
.53871 .27659 m
.53867 .2766 L
s
.53867 .27657 m
.53871 .27659 L
s
.53854 .27658 m
.53871 .27659 L
s
1 0 0 r
.21647 .37274 m
.21647 .37274 L
s
.21647 .37274 m
.21647 .37274 L
s
.21647 .37274 m
.21647 .37274 L
s
.21647 .37274 m
.21647 .37274 L
s
.21648 .37274 m
.21647 .37274 L
s
.21647 .37274 m
.21647 .37274 L
s
.21647 .37274 m
.21647 .37274 L
s
.21647 .37274 m
.21647 .37274 L
s
.21647 .37274 m
.21647 .37274 L
s
1 .075 0 r
.72798 .50095 m
.72599 .4994 L
s
1 0 0 r
.79429 .34069 m
.79429 .34069 L
s
1 .004 0 r
.53867 .2766 m
.53867 .27657 L
s
1 .066 0 r
.79698 .53321 m
.79655 .53298 L
s
.79655 .53298 m
.79671 .53255 L
s
1 .575 0 r
.6217 .56025 m
.62446 .56178 L
s
.61913 .5649 m
.6217 .56025 L
s
.6217 .56025 m
.61806 .56129 L
s
.62188 .56644 m
.61913 .5649 L
s
.61913 .5649 m
.61806 .56129 L
s
1 .066 0 r
.79735 .53274 m
.79698 .53321 L
s
.79671 .53255 m
.79735 .53274 L
s
.79671 .53255 m
.79698 .53321 L
s
1 .22 0 r
.37384 .53254 m
.3752 .53293 L
s
.37531 .53059 m
.37384 .53254 L
s
.37384 .53254 m
.37423 .53114 L
s
.37628 .53237 m
.37384 .53254 L
s
.38092 .5286 m
.37384 .53254 L
s
1 .073 0 r
.26395 .53247 m
.26421 .53253 L
s
.26427 .53175 m
.26395 .53247 L
s
.26395 .53247 m
.26381 .532 L
s
.26467 .53228 m
.26395 .53247 L
s
.2654 .53081 m
.26395 .53247 L
s
1 .22 0 r
.3752 .53293 m
.37628 .53237 L
s
.37628 .53237 m
.37531 .53059 L
s
.37531 .53059 m
.37423 .53114 L
s
1 .229 0 r
.60322 .5003 m
.60507 .50208 L
s
.60322 .5003 m
.60577 .5001 L
s
1 .073 0 r
.26427 .53175 m
.26381 .532 L
s
.26467 .53228 m
.26427 .53175 L
s
1 .229 0 r
.60577 .5001 m
.60507 .50208 L
s
1 .22 0 r
.67821 .53229 m
.67715 .53403 L
s
.67582 .532 m
.67821 .53229 L
s
1 .073 0 r
.26421 .53253 m
.26467 .53228 L
s
1 .22 0 r
.67582 .532 m
.67715 .53403 L
s
1 .009 0 r
.0797 .50005 m
.07971 .50005 L
s
.07972 .49996 m
.0797 .50005 L
s
.0797 .50005 m
.07966 .49999 L
s
.07977 .50002 m
.0797 .50005 L
s
.07979 .49983 m
.0797 .50005 L
s
.07972 .49996 m
.07966 .49999 L
s
.07977 .50002 m
.07972 .49996 L
s
.07971 .50005 m
.07977 .50002 L
s
.07966 .49999 m
.07971 .50005 L
s
1 .073 0 r
.26381 .532 m
.26421 .53253 L
s
1 .075 0 r
.72636 .49932 m
.72678 .49953 L
s
.72599 .4999 m
.72636 .49932 L
s
.72636 .49932 m
.72599 .4994 L
s
1 .007 0 r
.40184 .40372 m
.40187 .40371 L
s
.40187 .40371 m
.40185 .40365 L
s
.40187 .40371 m
.40179 .4037 L
s
.40185 .40365 m
.40182 .40366 L
s
.40185 .40365 m
.40179 .4037 L
s
.40179 .4037 m
.40184 .40372 L
s
.40179 .4037 m
.40182 .40366 L
s
.40206 .40361 m
.40179 .4037 L
s
1 .075 0 r
.72641 .5001 m
.72599 .4999 L
s
.72599 .4999 m
.72599 .4994 L
s
1 .007 0 r
.40182 .40366 m
.40184 .40372 L
s
1 0 0 r
.72433 .3074 m
.72433 .3074 L
s
.72433 .30739 m
.72433 .3074 L
s
.72433 .3074 m
.72433 .3074 L
s
.72433 .3074 m
.72433 .3074 L
s
.72433 .30739 m
.72433 .3074 L
s
.72433 .30739 m
.72433 .3074 L
s
.72432 .30739 m
.72433 .3074 L
s
.72433 .30739 m
.72433 .30739 L
s
.72433 .3074 m
.72433 .30739 L
s
1 .009 0 r
.46873 .24324 m
.46871 .24325 L
s
.46872 .24317 m
.46873 .24324 L
s
.46879 .2432 m
.46873 .24324 L
s
1 .068 0 r
.65797 .46776 m
.65551 .46669 L
s
1 .009 0 r
.4684 .24324 m
.46879 .2432 L
s
.4687 .24317 m
.46872 .24317 L
s
.46872 .24317 m
.46879 .2432 L
s
.46879 .2432 m
.46871 .24325 L
s
.4687 .24317 m
.46879 .2432 L
s
.46871 .24325 m
.4687 .24317 L
s
0 .04 1 r
.50177 .53168 m
.52451 .5458 L
s
.47891 .55998 m
.50177 .53168 L
s
.50177 .53168 m
.48379 .53439 L
s
1 .075 0 r
.72678 .49953 m
.72641 .5001 L
s
.72599 .4994 m
.72678 .49953 L
s
.72599 .4994 m
.72641 .5001 L
s
1 .068 0 r
.65602 .46726 m
.65574 .46712 L
s
.65574 .46712 m
.65599 .46655 L
s
.65574 .46712 m
.65551 .46669 L
s
.65599 .46655 m
.65628 .46668 L
s
.65599 .46655 m
.65551 .46669 L
s
1 .028 0 r
.72145 .11402 m
.72155 .11403 L
s
.72153 .11378 m
.72145 .11402 L
s
.72176 .11399 m
.72145 .11402 L
s
1 .22 0 r
.37423 .53114 m
.3752 .53293 L
s
1 .028 0 r
.72163 .11379 m
.72153 .11378 L
s
.72153 .11378 m
.72176 .11399 L
s
.72176 .11399 m
.72155 .11403 L
s
.72163 .11379 m
.72176 .11399 L
s
.72066 .11358 m
.72176 .11399 L
s
.72155 .11403 m
.72163 .11379 L
s
1 .068 0 r
.65628 .46668 m
.65602 .46726 L
s
.65551 .46669 m
.65602 .46726 L
s
.65551 .46669 m
.65628 .46668 L
s
1 .003 0 r
.65434 .27409 m
.65435 .27409 L
s
.65435 .27407 m
.65434 .27409 L
s
.65437 .27408 m
.65434 .27409 L
s
.65436 .27407 m
.65435 .27407 L
s
.65435 .27407 m
.65437 .27408 L
s
.65437 .27408 m
.65435 .27409 L
s
.65436 .27407 m
.65437 .27408 L
s
.65427 .27405 m
.65437 .27408 L
s
.65435 .27409 m
.65436 .27407 L
s
1 0 0 r
.33178 .37034 m
.33178 .37034 L
s
.33178 .37034 m
.33178 .37034 L
s
.33178 .37034 m
.33178 .37034 L
s
.33178 .37034 m
.33178 .37034 L
s
.33179 .37034 m
.33178 .37034 L
s
.33178 .37034 m
.33178 .37034 L
s
.33178 .37034 m
.33178 .37034 L
s
.33178 .37034 m
.33178 .37034 L
s
.33178 .37034 m
.33178 .37034 L
s
1 .024 0 r
.84396 .49871 m
.84354 .49814 L
s
1 .039 0 r
.58787 .43452 m
.58618 .43421 L
s
1 .013 0 r
.39818 .20987 m
.39872 .20973 L
s
.39864 .20981 m
.39861 .20982 L
s
.39861 .20969 m
.39864 .20981 L
s
.39872 .20973 m
.39864 .20981 L
s
.39858 .2097 m
.39861 .20969 L
s
.39861 .20969 m
.39872 .20973 L
s
1 .039 0 r
.58652 .43448 m
.58644 .43442 L
s
.58644 .43442 m
.58651 .43407 L
s
.58644 .43442 m
.58618 .43421 L
s
1 .013 0 r
.39872 .20973 m
.39861 .20982 L
s
.39858 .2097 m
.39872 .20973 L
s
1 .039 0 r
.58651 .43407 m
.5866 .43413 L
s
.58651 .43407 m
.58618 .43421 L
s
1 .013 0 r
.39861 .20982 m
.39858 .2097 L
s
1 .039 0 r
.58618 .43421 m
.58652 .43448 L
s
.58618 .43421 m
.5866 .43413 L
s
.5866 .43413 m
.58652 .43448 L
s
1 .024 0 r
.84361 .49812 m
.84377 .49821 L
s
.84347 .4983 m
.84361 .49812 L
s
.84361 .49812 m
.84354 .49814 L
s
.84363 .49838 m
.84347 .4983 L
s
.84347 .4983 m
.84354 .49814 L
s
.84377 .49821 m
.84363 .49838 L
s
.84354 .49814 m
.84377 .49821 L
s
.84354 .49814 m
.84363 .49838 L
s
1 .022 0 r
.19463 .49811 m
.19469 .49812 L
s
.19472 .49789 m
.19463 .49811 L
s
.19463 .49811 m
.19457 .49797 L
s
.19484 .49805 m
.19463 .49811 L
s
.195 .49759 m
.19463 .49811 L
s
.19472 .49789 m
.19457 .49797 L
s
.19484 .49805 m
.19472 .49789 L
s
.19469 .49812 m
.19484 .49805 L
s
.19457 .49797 m
.19469 .49812 L
s
1 .459 0 r
.48016 .53055 m
.48076 .52981 L
s
.48076 .52981 m
.48023 .52565 L
s
.48076 .52981 m
.47606 .52852 L
s
1 .008 0 r
.5844 .24075 m
.58442 .24075 L
s
.58441 .24067 m
.5844 .24075 L
s
.58449 .24072 m
.5844 .24075 L
s
.58443 .24067 m
.58441 .24067 L
s
.58441 .24067 m
.58449 .24072 L
s
1 .01 0 r
.5173 .40131 m
.51731 .4013 L
s
.51731 .4013 m
.5173 .4012 L
s
.51731 .4013 m
.51721 .40126 L
s
1 .008 0 r
.58449 .24072 m
.58442 .24075 L
s
.58443 .24067 m
.58449 .24072 L
s
.58412 .24067 m
.58449 .24072 L
s
1 .01 0 r
.5173 .4012 m
.5173 .40121 L
s
.5173 .4012 m
.51721 .40126 L
s
.51721 .40126 m
.5173 .40131 L
s
.51721 .40126 m
.5173 .40121 L
s
.51768 .40125 m
.51721 .40126 L
s
1 .008 0 r
.58442 .24075 m
.58443 .24067 L
s
1 .022 0 r
.77393 .46548 m
.77337 .46499 L
s
1 0 0 r
.26143 .33702 m
.26143 .33702 L
s
1 .01 0 r
.5173 .40121 m
.5173 .40131 L
s
1 .575 0 r
.62446 .56178 m
.62188 .56644 L
s
.61806 .56129 m
.62446 .56178 L
s
.61806 .56129 m
.62188 .56644 L
s
1 .022 0 r
.77348 .46497 m
.77361 .46503 L
s
.77336 .46514 m
.77348 .46497 L
s
.77348 .46497 m
.77337 .46499 L
s
.7735 .4652 m
.77336 .46514 L
s
.77336 .46514 m
.77337 .46499 L
s
1 .459 0 r
.48023 .52565 m
.47962 .52638 L
s
.48023 .52565 m
.47606 .52852 L
s
1 .022 0 r
.77361 .46503 m
.7735 .4652 L
s
.77337 .46499 m
.77361 .46503 L
s
.77337 .46499 m
.7735 .4652 L
s
1 .062 0 r
.30886 .49663 m
.30916 .4967 L
s
.30921 .49605 m
.30886 .49663 L
s
.30886 .49663 m
.30886 .49622 L
s
.30952 .49653 m
.30886 .49663 L
s
.31051 .49535 m
.30886 .49663 L
s
1 .006 0 r
.12442 .46448 m
.12443 .46448 L
s
.12444 .46442 m
.12442 .46448 L
s
.12442 .46448 m
.1244 .46444 L
s
.12447 .46446 m
.12442 .46448 L
s
.12451 .46433 m
.12442 .46448 L
s
.12444 .46442 m
.1244 .46444 L
s
.12447 .46446 m
.12444 .46442 L
s
.12443 .46448 m
.12447 .46446 L
s
.1244 .46444 m
.12443 .46448 L
s
1 .062 0 r
.30921 .49605 m
.30886 .49622 L
s
.30952 .49653 m
.30921 .49605 L
s
.30916 .4967 m
.30952 .49653 L
s
1 .015 0 r
.51445 .20731 m
.51445 .20731 L
s
.51445 .20716 m
.51445 .20731 L
s
.51459 .20723 m
.51445 .20731 L
s
.51444 .20717 m
.51445 .20716 L
s
.51445 .20716 m
.51459 .20723 L
s
1 .001 0 r
.77034 .27154 m
.77033 .27155 L
s
.77033 .27153 m
.77034 .27154 L
s
.77034 .27154 m
.77033 .27154 L
s
.77034 .27154 m
.77034 .27154 L
s
.7703 .27152 m
.77034 .27154 L
s
.77033 .27154 m
.77033 .27155 L
s
.77033 .27153 m
.77033 .27154 L
s
.77034 .27154 m
.77033 .27153 L
s
.77033 .27155 m
.77034 .27154 L
s
.44737 .36794 m
.44737 .36794 L
s
.44737 .36794 m
.44737 .36793 L
s
.44737 .36794 m
.44737 .36793 L
s
.44737 .36793 m
.44737 .36793 L
s
.44737 .36793 m
.44737 .36793 L
s
.44737 .36793 m
.44737 .36794 L
s
.44737 .36793 m
.44737 .36793 L
s
.4474 .36793 m
.44737 .36793 L
s
.44737 .36793 m
.44737 .36794 L
s
1 .016 0 r
.70382 .4322 m
.70328 .43191 L
s
1 .015 0 r
.51388 .20725 m
.51459 .20723 L
s
.51459 .20723 m
.51445 .20731 L
s
.51444 .20717 m
.51459 .20723 L
s
.51445 .20731 m
.51444 .20717 L
s
1 .459 0 r
.47606 .52852 m
.48016 .53055 L
s
.47606 .52852 m
.47962 .52638 L
s
.49675 .5264 m
.47606 .52852 L
s
1 .016 0 r
.70339 .43205 m
.70332 .43202 L
s
.70332 .43202 m
.70339 .43189 L
s
.70332 .43202 m
.70328 .43191 L
s
.70339 .43189 m
.70346 .43192 L
s
.70339 .43189 m
.70328 .43191 L
s
1 .062 0 r
.30886 .49622 m
.30916 .4967 L
s
1 .016 0 r
.70346 .43192 m
.70339 .43205 L
s
.70328 .43191 m
.70339 .43205 L
s
.70328 .43191 m
.70346 .43192 L
s
0 .04 1 r
.50146 .57444 m
.47891 .55998 L
s
.47891 .55998 m
.48379 .53439 L
s
0 .197 1 r
.52635 .52774 m
.5044 .55497 L
s
.48759 .51676 m
.52635 .52774 L
s
1 .005 0 r
.70028 .23818 m
.7003 .23818 L
s
.70029 .23813 m
.70028 .23818 L
s
.70034 .23817 m
.70028 .23818 L
s
.70031 .23814 m
.70029 .23813 L
s
.70029 .23813 m
.70034 .23817 L
s
.70034 .23817 m
.7003 .23818 L
s
.70031 .23814 m
.70034 .23817 L
s
.70013 .2381 m
.70034 .23817 L
s
.7003 .23818 m
.70031 .23814 L
s
1 .166 0 r
.42104 .49569 m
.42162 .49538 L
s
.42162 .49538 m
.42109 .49393 L
s
.42162 .49538 m
.41975 .49524 L
s
1 .741 0 r
.56709 .55966 m
.53455 .55413 L
s
1 .007 0 r
.63361 .39888 m
.63334 .3988 L
s
1 0 0 r
.37703 .33456 m
.37703 .33456 L
s
1 .021 0 r
.44355 .17378 m
.44448 .17364 L
s
.44433 .17376 m
.44429 .17377 L
s
.4443 .17357 m
.44433 .17376 L
s
.44448 .17364 m
.44433 .17376 L
s
1 .007 0 r
.63339 .39885 m
.63337 .39884 L
s
.63337 .39884 m
.63339 .39878 L
s
.63337 .39884 m
.63334 .3988 L
s
1 .021 0 r
.44426 .17357 m
.4443 .17357 L
s
.4443 .17357 m
.44448 .17364 L
s
1 .007 0 r
.63339 .39878 m
.63341 .39879 L
s
.63339 .39878 m
.63334 .3988 L
s
1 .166 0 r
.42109 .49393 m
.42051 .49425 L
s
.42109 .49393 m
.41975 .49524 L
s
1 .007 0 r
.63334 .3988 m
.63339 .39885 L
s
.63334 .3988 m
.63341 .39879 L
s
.63341 .39879 m
.63339 .39885 L
s
1 .166 0 r
.41975 .49524 m
.42104 .49569 L
s
.41975 .49524 m
.42051 .49425 L
s
.42632 .49309 m
.41975 .49524 L
s
1 .021 0 r
.44448 .17364 m
.44429 .17377 L
s
.44426 .17357 m
.44448 .17364 L
s
.44429 .17377 m
.44426 .17357 L
s
1 .459 0 r
.47962 .52638 m
.48016 .53055 L
s
1 .015 0 r
.23965 .46239 m
.23971 .46241 L
s
.23973 .46224 m
.23965 .46239 L
s
.23965 .46239 m
.23963 .46229 L
s
.23981 .46236 m
.23965 .46239 L
s
.24 .46204 m
.23965 .46239 L
s
.23973 .46224 m
.23963 .46229 L
s
.23981 .46236 m
.23973 .46224 L
s
.23971 .46241 m
.23981 .46236 L
s
.23963 .46229 m
.23971 .46241 L
s
1 .013 0 r
.63029 .20477 m
.63032 .20478 L
s
.63032 .20466 m
.63029 .20477 L
s
.63043 .20474 m
.63029 .20477 L
s
1 .166 0 r
.42051 .49425 m
.42104 .49569 L
s
1 .013 0 r
.63035 .20466 m
.63032 .20466 L
s
.63032 .20466 m
.63043 .20474 L
s
.63043 .20474 m
.63032 .20478 L
s
.63035 .20466 m
.63043 .20474 L
s
.62988 .20463 m
.63043 .20474 L
s
.63032 .20478 m
.63035 .20466 L
s
1 .001 0 r
.56328 .36551 m
.56328 .36551 L
s
.56328 .36551 m
.56328 .3655 L
s
.56328 .36551 m
.56327 .36551 L
s
1 .006 0 r
.82006 .42987 m
.81993 .42974 L
s
1 .001 0 r
.56331 .36551 m
.56327 .36551 L
s
1 0 0 r
.30656 .30116 m
.30657 .30115 L
s
1 .001 0 r
.56328 .3655 m
.56328 .36551 L
s
.56328 .3655 m
.56327 .36551 L
s
1 0 0 r
.30657 .30116 m
.30657 .30116 L
s
.30657 .30115 m
.30657 .30116 L
s
.30657 .30115 m
.30657 .30116 L
s
.30657 .30115 m
.30657 .30115 L
s
.30657 .30115 m
.30657 .30115 L
s
.30657 .30116 m
.30657 .30115 L
s
.30657 .30115 m
.30657 .30116 L
s
1 .001 0 r
.56327 .36551 m
.56328 .36551 L
s
.56327 .36551 m
.56328 .36551 L
s
1 0 0 r
.30657 .30115 m
.30657 .30115 L
s
1 .001 0 r
.56328 .36551 m
.56328 .36551 L
s
1 .006 0 r
.81995 .42974 m
.81999 .42975 L
s
.81992 .42978 m
.81995 .42974 L
s
.81995 .42974 m
.81993 .42974 L
s
.81996 .42979 m
.81992 .42978 L
s
.81992 .42978 m
.81993 .42974 L
s
.81999 .42975 m
.81996 .42979 L
s
.81993 .42974 m
.81999 .42975 L
s
.81993 .42974 m
.81996 .42979 L
s
1 .741 0 r
.5411 .55924 m
.53967 .55789 L
s
.53967 .55789 m
.54106 .55124 L
s
.53967 .55789 m
.53455 .55413 L
s
1 .022 0 r
.56031 .17126 m
.56033 .17127 L
s
.56032 .17106 m
.56031 .17126 L
s
.56052 .17118 m
.56031 .17126 L
s
.56034 .17107 m
.56032 .17106 L
s
.56032 .17106 m
.56052 .17118 L
s
1 .003 0 r
.16933 .42878 m
.16935 .42878 L
s
.16935 .42875 m
.16933 .42878 L
s
.16933 .42878 m
.16933 .42876 L
s
.16937 .42877 m
.16933 .42878 L
s
.1694 .4287 m
.16933 .42878 L
s
.16935 .42875 m
.16933 .42876 L
s
.16937 .42877 m
.16935 .42875 L
s
.16935 .42878 m
.16937 .42877 L
s
.16933 .42876 m
.16935 .42878 L
s
1 .022 0 r
.56052 .17118 m
.56033 .17127 L
s
.56034 .17107 m
.56052 .17118 L
s
.55953 .17111 m
.56052 .17118 L
s
1 .293 0 r
.68323 .55749 m
.67466 .55182 L
s
1 .003 0 r
.74984 .3965 m
.74976 .39645 L
s
1 0 0 r
.49292 .3321 m
.49292 .3321 L
s
1 .022 0 r
.56033 .17127 m
.56034 .17107 L
s
1 .003 0 r
.74977 .39644 m
.74979 .39645 L
s
.74976 .39647 m
.74977 .39644 L
s
.74977 .39644 m
.74976 .39645 L
s
.74977 .39647 m
.74976 .39647 L
s
.74976 .39647 m
.74976 .39645 L
s
.74979 .39645 m
.74977 .39647 L
s
.74976 .39645 m
.74979 .39645 L
s
.74976 .39645 m
.74977 .39647 L
s
1 .741 0 r
.54106 .55124 m
.54249 .55257 L
s
.54106 .55124 m
.53455 .55413 L
s
1 .043 0 r
.35436 .4605 m
.35464 .46057 L
s
.35466 .46013 m
.35436 .4605 L
s
.35436 .4605 m
.35446 .46022 L
s
.35484 .46048 m
.35436 .4605 L
s
.35579 .45975 m
.35436 .4605 L
s
.35464 .46057 m
.35484 .46048 L
s
.35484 .46048 m
.35466 .46013 L
s
.35466 .46013 m
.35446 .46022 L
s
.35446 .46022 m
.35464 .46057 L
s
1 .017 0 r
.03196 .55682 m
.03197 .55683 L
s
.032 .55665 m
.03196 .55682 L
s
.03196 .55682 m
.03187 .55672 L
s
.03209 .55676 m
.03196 .55682 L
s
.03206 .55641 m
.03196 .55682 L
s
.032 .55665 m
.03187 .55672 L
s
.03209 .55676 m
.032 .55665 L
s
.03197 .55683 m
.03209 .55676 L
s
.03187 .55672 m
.03197 .55683 L
s
1 .008 0 r
.74638 .20213 m
.74641 .20214 L
s
.7464 .20206 m
.74638 .20213 L
s
.74646 .20213 m
.74638 .20213 L
s
.74646 .20213 m
.74641 .20214 L
s
.7464 .20206 m
.74646 .20213 L
s
.74644 .20207 m
.74646 .20213 L
s
.74618 .202 m
.74646 .20213 L
s
.74644 .20207 m
.7464 .20206 L
s
.74641 .20214 m
.74644 .20207 L
s
1 .029 0 r
.49017 .13762 m
.49014 .13762 L
s
.49015 .13735 m
.49017 .13762 L
s
.49041 .13747 m
.49017 .13762 L
s
.49013 .13736 m
.49015 .13735 L
s
.49015 .13735 m
.49041 .13747 L
s
1 .323 0 r
.61287 .52419 m
.59992 .52014 L
s
1 0 0 r
.67953 .36309 m
.67951 .36308 L
s
.42244 .29865 m
.42246 .29865 L
s
1 .029 0 r
.48909 .13756 m
.49041 .13747 L
s
1 0 0 r
.42246 .29865 m
.42246 .29865 L
s
.42246 .29865 m
.42246 .29865 L
s
.42246 .29865 m
.42246 .29865 L
s
.42246 .29865 m
.42246 .29865 L
s
.42246 .29865 m
.42246 .29865 L
s
.42246 .29865 m
.42246 .29865 L
s
.42246 .29865 m
.42246 .29865 L
s
.67951 .36309 m
.67951 .36309 L
s
.67951 .36309 m
.67951 .36308 L
s
.67951 .36309 m
.67951 .36308 L
s
.67951 .36308 m
.67951 .36308 L
s
.67951 .36308 m
.67951 .36308 L
s
.42246 .29865 m
.42246 .29865 L
s
.67951 .36308 m
.67951 .36309 L
s
.67951 .36308 m
.67951 .36308 L
s
.67951 .36308 m
.67951 .36309 L
s
1 .029 0 r
.49041 .13747 m
.49014 .13762 L
s
.49013 .13736 m
.49041 .13747 L
s
.49014 .13762 m
.49013 .13736 L
s
0 .197 1 r
.48759 .51676 m
.5044 .55497 L
s
1 .229 0 r
.53406 .49159 m
.53392 .49127 L
s
.53392 .49127 m
.53405 .48917 L
s
.53392 .49127 m
.53196 .49027 L
s
.53405 .48917 m
.5342 .48949 L
s
.53405 .48917 m
.53196 .49027 L
s
1 .016 0 r
.67631 .16866 m
.67636 .16867 L
s
.67635 .16852 m
.67631 .16866 L
s
.67649 .16863 m
.67631 .16866 L
s
.6764 .16852 m
.67635 .16852 L
s
.67635 .16852 m
.67649 .16863 L
s
1 .009 0 r
.28493 .42654 m
.28497 .42655 L
s
.28498 .42646 m
.28493 .42654 L
s
.28493 .42654 m
.28493 .42648 L
s
.28502 .42652 m
.28493 .42654 L
s
.28518 .42636 m
.28493 .42654 L
s
1 .016 0 r
.67649 .16863 m
.67636 .16867 L
s
.6764 .16852 m
.67649 .16863 L
s
.67581 .16844 m
.67649 .16863 L
s
1 .009 0 r
.28498 .42646 m
.28493 .42648 L
s
.28502 .42652 m
.28498 .42646 L
s
.28497 .42655 m
.28502 .42652 L
s
.28493 .42648 m
.28497 .42655 L
s
1 .016 0 r
.67636 .16867 m
.6764 .16852 L
s
1 .095 0 r
.79968 .55532 m
.79795 .55312 L
s
1 .229 0 r
.54243 .49084 m
.53196 .49027 L
s
1 0 0 r
.60912 .32964 m
.60912 .32964 L
s
1 .002 0 r
.35187 .26516 m
.35194 .26513 L
s
.35193 .26514 m
.35193 .26515 L
s
.35193 .26513 m
.35193 .26514 L
s
.35194 .26513 m
.35193 .26514 L
s
.35192 .26513 m
.35193 .26513 L
s
.35193 .26513 m
.35194 .26513 L
s
.35194 .26513 m
.35193 .26515 L
s
.35192 .26513 m
.35194 .26513 L
s
.35193 .26515 m
.35192 .26513 L
s
1 .039 0 r
.14728 .55518 m
.14735 .5552 L
s
.1474 .55478 m
.14728 .55518 L
s
.14728 .55518 m
.14712 .55494 L
s
.14762 .55504 m
.14728 .55518 L
s
.14773 .55423 m
.14728 .55518 L
s
.1474 .55478 m
.14712 .55494 L
s
.14762 .55504 m
.1474 .55478 L
s
1 .293 0 r
.3705 .55507 m
.37232 .55561 L
s
.37247 .55245 m
.3705 .55507 L
s
.3705 .55507 m
.37102 .55322 L
s
.37377 .55484 m
.3705 .55507 L
s
.37998 .54986 m
.3705 .55507 L
s
1 .039 0 r
.14735 .5552 m
.14762 .55504 L
s
1 .09 0 r
.46869 .45841 m
.46886 .45829 L
s
.46886 .45829 m
.46871 .45747 L
s
.46886 .45829 m
.4679 .45807 L
s
.46871 .45747 m
.46854 .4576 L
s
.46871 .45747 m
.4679 .45807 L
s
1 .039 0 r
.14712 .55494 m
.14735 .5552 L
s
1 .293 0 r
.37232 .55561 m
.37377 .55484 L
s
.37377 .55484 m
.37247 .55245 L
s
.37247 .55245 m
.37102 .55322 L
s
1 .09 0 r
.4679 .45807 m
.46869 .45841 L
s
.4679 .45807 m
.46854 .4576 L
s
.47189 .45745 m
.4679 .45807 L
s
1 .229 0 r
.53196 .49027 m
.53406 .49159 L
s
.53196 .49027 m
.5342 .48949 L
s
1 .09 0 r
.46854 .4576 m
.46869 .45841 L
s
1 .026 0 r
.60627 .1351 m
.60631 .1351 L
s
.6063 .13485 m
.60627 .1351 L
s
.60654 .13501 m
.60627 .1351 L
s
.60634 .13485 m
.6063 .13485 L
s
.6063 .13485 m
.60654 .13501 L
s
1 .104 0 r
.26164 .55441 m
.262 .5545 L
s
.26209 .55337 m
.26164 .55441 L
s
.26164 .55441 m
.26143 .55374 L
s
.26267 .55413 m
.26164 .55441 L
s
.26371 .55205 m
.26164 .55441 L
s
1 .026 0 r
.60654 .13501 m
.60631 .1351 L
s
.60634 .13485 m
.60654 .13501 L
s
.60536 .13484 m
.60654 .13501 L
s
1 .323 0 r
.60256 .52268 m
.60148 .52204 L
s
.60148 .52204 m
.60248 .51922 L
s
.60148 .52204 m
.59992 .52014 L
s
1 .026 0 r
.60631 .1351 m
.60634 .13485 L
s
1 .001 0 r
.21444 .39295 m
.21444 .39295 L
s
.21444 .39294 m
.21444 .39295 L
s
.21444 .39295 m
.21444 .39294 L
s
.21445 .39295 m
.21444 .39295 L
s
.21447 .39292 m
.21444 .39295 L
s
.21444 .39294 m
.21444 .39294 L
s
.21445 .39295 m
.21444 .39294 L
s
.21444 .39295 m
.21445 .39295 L
s
1 .229 0 r
.5342 .48949 m
.53406 .49159 L
s
1 .001 0 r
.21444 .39294 m
.21444 .39295 L
s
1 0 0 r
.53864 .29614 m
.53864 .29615 L
s
.53864 .29614 m
.53864 .29614 L
s
.53865 .29614 m
.53864 .29614 L
s
.53864 .29614 m
.53864 .29614 L
s
.53864 .29614 m
.53865 .29614 L
s
.53865 .29614 m
.53864 .29615 L
s
.53864 .29614 m
.53865 .29614 L
s
.53862 .29614 m
.53865 .29614 L
s
1 .114 0 r
.7293 .52197 m
.72623 .51962 L
s
1 0 0 r
.79604 .36066 m
.79603 .36066 L
s
.53864 .29615 m
.53864 .29614 L
s
.79604 .36066 m
.79604 .36066 L
s
.79603 .36066 m
.79604 .36066 L
s
.79604 .36066 m
.79603 .36066 L
s
.79604 .36066 m
.79603 .36066 L
s
.79603 .36066 m
.79603 .36066 L
s
.79604 .36066 m
.79604 .36066 L
s
.79603 .36066 m
.79604 .36066 L
s
.79603 .36066 m
.79604 .36066 L
s
1 .104 0 r
.26209 .55337 m
.26143 .55374 L
s
.26267 .55413 m
.26209 .55337 L
s
.262 .5545 m
.26267 .55413 L
s
1 .741 0 r
.53455 .55413 m
.5411 .55924 L
s
.53455 .55413 m
.54249 .55257 L
s
1 .323 0 r
.60248 .51922 m
.60356 .51985 L
s
.60248 .51922 m
.59992 .52014 L
s
1 .095 0 r
.79826 .55305 m
.79887 .55339 L
s
.79772 .55373 m
.79826 .55305 L
s
.79826 .55305 m
.79795 .55312 L
s
1 .293 0 r
.6763 .55138 m
.67787 .55221 L
s
.67489 .5537 m
.6763 .55138 L
s
.6763 .55138 m
.67466 .55182 L
s
1 .104 0 r
.26143 .55374 m
.262 .5545 L
s
1 .095 0 r
.79834 .55408 m
.79772 .55373 L
s
.79772 .55373 m
.79795 .55312 L
s
1 .293 0 r
.67645 .55454 m
.67489 .5537 L
s
.67489 .5537 m
.67466 .55182 L
s
1 .014 0 r
.07675 .52122 m
.07676 .52122 L
s
.07679 .52107 m
.07675 .52122 L
s
.07675 .52122 m
.07668 .52112 L
s
.07687 .52116 m
.07675 .52122 L
s
.07689 .52086 m
.07675 .52122 L
s
.07679 .52107 m
.07668 .52112 L
s
.07687 .52116 m
.07679 .52107 L
s
.07676 .52122 m
.07687 .52116 L
s
1 .021 0 r
.40058 .42435 m
.40066 .42432 L
s
.40066 .42432 m
.40059 .42413 L
s
.40066 .42432 m
.40042 .4243 L
s
.40059 .42413 m
.40051 .42416 L
s
.40059 .42413 m
.40042 .4243 L
s
.40042 .4243 m
.40058 .42435 L
s
.40042 .4243 m
.40051 .42416 L
s
.40125 .42401 m
.40042 .4243 L
s
1 .014 0 r
.07668 .52112 m
.07676 .52122 L
s
1 .095 0 r
.79887 .55339 m
.79834 .55408 L
s
.79795 .55312 m
.79887 .55339 L
s
.79795 .55312 m
.79834 .55408 L
s
1 .021 0 r
.40051 .42416 m
.40058 .42435 L
s
1 .035 0 r
.53609 .10138 m
.5361 .10138 L
s
.5361 .10105 m
.53609 .10138 L
s
.53642 .10122 m
.53609 .10138 L
s
.53611 .10105 m
.5361 .10105 L
s
.5361 .10105 m
.53642 .10122 L
s
1 .293 0 r
.37102 .55322 m
.37232 .55561 L
s
1 .741 0 r
.54249 .55257 m
.5411 .55924 L
s
1 .035 0 r
.53642 .10122 m
.5361 .10138 L
s
.53611 .10105 m
.53642 .10122 L
s
.53482 .10119 m
.53642 .10122 L
s
1 .003 0 r
.46814 .2626 m
.46813 .2626 L
s
.46813 .26258 m
.46814 .2626 L
s
.46816 .26259 m
.46814 .2626 L
s
1 0 0 r
.72562 .32717 m
.72562 .32717 L
s
1 .116 0 r
.65884 .48858 m
.65461 .48676 L
s
1 .003 0 r
.46803 .2626 m
.46816 .26259 L
s
.46813 .26258 m
.46813 .26258 L
s
.46813 .26258 m
.46816 .26259 L
s
.46816 .26259 m
.46813 .2626 L
s
.46813 .26258 m
.46816 .26259 L
s
.46813 .2626 m
.46813 .26258 L
s
1 .035 0 r
.5361 .10138 m
.53611 .10105 L
s
1 .114 0 r
.72681 .51948 m
.72745 .51981 L
s
.72623 .52037 m
.72681 .51948 L
s
.72681 .51948 m
.72623 .51962 L
s
.72688 .5207 m
.72623 .52037 L
s
.72623 .52037 m
.72623 .51962 L
s
1 .323 0 r
.59992 .52014 m
.60256 .52268 L
s
.59992 .52014 m
.60356 .51985 L
s
.60356 .51985 m
.60256 .52268 L
s
1 .018 0 r
.72246 .1324 m
.72253 .13241 L
s
.72252 .13224 m
.72246 .1324 L
s
.72267 .13238 m
.72246 .1324 L
s
.72258 .13225 m
.72252 .13224 L
s
.72252 .13224 m
.72267 .13238 L
s
.72267 .13238 m
.72253 .13241 L
s
.72258 .13225 m
.72267 .13238 L
s
.72193 .13211 m
.72267 .13238 L
s
1 .293 0 r
.67787 .55221 m
.67645 .55454 L
s
.67466 .55182 m
.67787 .55221 L
s
1 .018 0 r
.72253 .13241 m
.72258 .13225 L
s
1 .293 0 r
.67466 .55182 m
.67645 .55454 L
s
1 .114 0 r
.72745 .51981 m
.72688 .5207 L
s
.72623 .51962 m
.72745 .51981 L
s
1 .003 0 r
.33042 .39059 m
.33044 .39059 L
s
.33044 .39056 m
.33042 .39059 L
s
.33042 .39059 m
.33043 .39057 L
s
.33046 .39059 m
.33042 .39059 L
s
.33053 .39053 m
.33042 .39059 L
s
1 .116 0 r
.65548 .48774 m
.65499 .48749 L
s
.65499 .48749 m
.65543 .48651 L
s
.65499 .48749 m
.65461 .48676 L
s
1 .003 0 r
.33044 .39059 m
.33046 .39059 L
s
.33046 .39059 m
.33044 .39056 L
s
.33044 .39056 m
.33043 .39057 L
s
.33043 .39057 m
.33044 .39059 L
s
1 .114 0 r
.72623 .51962 m
.72688 .5207 L
s
1 .116 0 r
.65543 .48651 m
.65592 .48675 L
s
.65543 .48651 m
.65461 .48676 L
s
1 0 0 r
.65512 .29363 m
.65512 .29363 L
s
.65512 .29363 m
.65512 .29363 L
s
.65512 .29363 m
.65512 .29363 L
s
.65512 .29363 m
.65512 .29363 L
s
.65512 .29363 m
.65512 .29363 L
s
.65512 .29363 m
.65512 .29363 L
s
.65512 .29363 m
.65512 .29363 L
s
.65511 .29362 m
.65512 .29363 L
s
.65512 .29363 m
.65512 .29363 L
s
1 .039 0 r
.84603 .51974 m
.84535 .51883 L
s
1 .081 0 r
.58828 .45514 m
.58471 .45449 L
s
1 .006 0 r
.39735 .22902 m
.39759 .22896 L
s
.39756 .22899 m
.39754 .229 L
s
.39755 .22894 m
.39756 .22899 L
s
.39759 .22896 m
.39756 .22899 L
s
.39753 .22895 m
.39755 .22894 L
s
.39755 .22894 m
.39759 .22896 L
s
.39759 .22896 m
.39754 .229 L
s
.39753 .22895 m
.39759 .22896 L
s
.39754 .229 m
.39753 .22895 L
s
1 .575 0 r
.47564 .5529 m
.47641 .55192 L
s
.47641 .55192 m
.47573 .54668 L
s
.47641 .55192 m
.47048 .55031 L
s
1 .081 0 r
.58543 .45505 m
.58526 .45493 L
s
.58526 .45493 m
.58542 .4542 L
s
.58526 .45493 m
.58471 .45449 L
s
.58542 .4542 m
.58559 .45431 L
s
.58542 .4542 m
.58471 .45449 L
s
1 .035 0 r
.19225 .51946 m
.19235 .51948 L
s
.19239 .51911 m
.19225 .51946 L
s
.19225 .51946 m
.19216 .51923 L
s
.19259 .51936 m
.19225 .51946 L
s
.19285 .51863 m
.19225 .51946 L
s
.19239 .51911 m
.19216 .51923 L
s
.19259 .51936 m
.19239 .51911 L
s
.19235 .51948 m
.19259 .51936 L
s
.19216 .51923 m
.19235 .51948 L
s
1 .081 0 r
.58471 .45449 m
.58543 .45505 L
s
.58471 .45449 m
.58559 .45431 L
s
1 .039 0 r
.84547 .5188 m
.84573 .51894 L
s
.84525 .51908 m
.84547 .5188 L
s
.84547 .5188 m
.84535 .51883 L
s
1 .116 0 r
.65592 .48675 m
.65548 .48774 L
s
.65461 .48676 m
.65548 .48774 L
s
1 .039 0 r
.84551 .51922 m
.84525 .51908 L
s
.84525 .51908 m
.84535 .51883 L
s
1 .116 0 r
.65461 .48676 m
.65592 .48675 L
s
1 .575 0 r
.47573 .54668 m
.47496 .54764 L
s
.47573 .54668 m
.47048 .55031 L
s
1 .081 0 r
.58559 .45431 m
.58543 .45505 L
s
1 .039 0 r
.84573 .51894 m
.84551 .51922 L
s
.84535 .51883 m
.84573 .51894 L
s
1 .029 0 r
.65232 .09878 m
.65239 .09878 L
s
.65238 .09851 m
.65232 .09878 L
s
.65264 .0987 m
.65232 .09878 L
s
1 .039 0 r
.84535 .51883 m
.84551 .51922 L
s
1 .029 0 r
.65245 .09851 m
.65238 .09851 L
s
.65238 .09851 m
.65264 .0987 L
s
.65264 .0987 m
.65239 .09878 L
s
.65245 .09851 m
.65264 .0987 L
s
.65137 .09842 m
.65264 .0987 L
s
1 .032 0 r
.51645 .42185 m
.51646 .42181 L
s
.51646 .42181 m
.51645 .42152 L
s
.51646 .42181 m
.51616 .42169 L
s
.51645 .42152 m
.51645 .42155 L
s
.51645 .42152 m
.51616 .42169 L
s
1 .029 0 r
.65239 .09878 m
.65245 .09851 L
s
1 .032 0 r
.51616 .42169 m
.51645 .42185 L
s
.51616 .42169 m
.51645 .42155 L
s
.51763 .42166 m
.51616 .42169 L
s
1 .003 0 r
.58459 .26006 m
.58459 .26006 L
s
.58459 .26004 m
.58459 .26006 L
s
.58462 .26005 m
.58459 .26006 L
s
.5846 .26004 m
.58459 .26004 L
s
.58459 .26004 m
.58462 .26005 L
s
.58462 .26005 m
.58459 .26006 L
s
.5846 .26004 m
.58462 .26005 L
s
.5845 .26004 m
.58462 .26005 L
s
1 0 0 r
.25971 .35702 m
.25971 .35702 L
s
.25971 .35701 m
.25971 .35702 L
s
.25971 .35702 m
.25971 .35701 L
s
.25971 .35702 m
.25971 .35702 L
s
.25971 .35701 m
.25971 .35702 L
s
.25971 .35701 m
.25971 .35701 L
s
.25971 .35702 m
.25971 .35701 L
s
.25971 .35702 m
.25971 .35702 L
s
1 .003 0 r
.58459 .26006 m
.5846 .26004 L
s
1 0 0 r
.25971 .35701 m
.25971 .35702 L
s
1 .04 0 r
.77555 .48631 m
.77454 .48544 L
s
1 .032 0 r
.51645 .42155 m
.51645 .42185 L
s
1 .095 0 r
.30654 .51837 m
.30702 .51849 L
s
.30709 .51747 m
.30654 .51837 L
s
.30654 .51837 m
.30654 .51774 L
s
.30757 .51821 m
.30654 .51837 L
s
.30911 .5164 m
.30654 .51837 L
s
.30709 .51747 m
.30654 .51774 L
s
.30757 .51821 m
.30709 .51747 L
s
.30702 .51849 m
.30757 .51821 L
s
1 .04 0 r
.77473 .4854 m
.77496 .48551 L
s
.77452 .48571 m
.77473 .4854 L
s
.77473 .4854 m
.77454 .48544 L
s
.77476 .48582 m
.77452 .48571 L
s
.77452 .48571 m
.77454 .48544 L
s
1 .575 0 r
.47048 .55031 m
.47564 .5529 L
s
.47048 .55031 m
.47496 .54764 L
s
.49656 .54767 m
.47048 .55031 L
s
1 .04 0 r
.77496 .48551 m
.77476 .48582 L
s
.77454 .48544 m
.77496 .48551 L
s
.77454 .48544 m
.77476 .48582 L
s
1 .011 0 r
.12173 .48545 m
.12176 .48545 L
s
.12177 .48533 m
.12173 .48545 L
s
.12173 .48545 m
.12169 .48537 L
s
.12183 .48541 m
.12173 .48545 L
s
.12189 .48517 m
.12173 .48545 L
s
.12177 .48533 m
.12169 .48537 L
s
.12183 .48541 m
.12177 .48533 L
s
.12176 .48545 m
.12183 .48541 L
s
1 .095 0 r
.30654 .51774 m
.30702 .51849 L
s
1 .011 0 r
.12169 .48537 m
.12176 .48545 L
s
1 .006 0 r
.44668 .38821 m
.44669 .3882 L
s
.44669 .3882 m
.44668 .38815 L
s
.44669 .3882 m
.44662 .38819 L
s
.44668 .38815 m
.44666 .38815 L
s
.44668 .38815 m
.44662 .38819 L
s
.44662 .38819 m
.44668 .38821 L
s
.44662 .38819 m
.44666 .38815 L
s
.44689 .38814 m
.44662 .38819 L
s
.44666 .38815 m
.44668 .38821 L
s
1 .007 0 r
.51406 .22644 m
.51406 .22644 L
s
.51406 .22637 m
.51406 .22644 L
s
.51412 .2264 m
.51406 .22644 L
s
.51406 .22637 m
.51406 .22637 L
s
.51406 .22637 m
.51412 .2264 L
s
1 0 0 r
.7719 .2911 m
.7719 .2911 L
s
.7719 .2911 m
.7719 .2911 L
s
.7719 .2911 m
.7719 .2911 L
s
.7719 .2911 m
.7719 .2911 L
s
.77189 .2911 m
.7719 .2911 L
s
.7719 .2911 m
.7719 .2911 L
s
.7719 .2911 m
.7719 .2911 L
s
.7719 .2911 m
.7719 .2911 L
s
.7719 .2911 m
.7719 .2911 L
s
1 .035 0 r
.70498 .45283 m
.70381 .4522 L
s
1 .007 0 r
.51381 .22641 m
.51412 .2264 L
s
.51412 .2264 m
.51406 .22644 L
s
.51406 .22637 m
.51412 .2264 L
s
.51406 .22644 m
.51406 .22637 L
s
1 .241 0 r
.41796 .51792 m
.41881 .51745 L
s
.41881 .51745 m
.41805 .51535 L
s
.41881 .51745 m
.41609 .51725 L
s
.41805 .51535 m
.4172 .51582 L
s
.41805 .51535 m
.41609 .51725 L
s
.41609 .51725 m
.41796 .51792 L
s
.41609 .51725 m
.4172 .51582 L
s
.42567 .51416 m
.41609 .51725 L
s
1 .035 0 r
.70405 .45251 m
.70388 .45243 L
s
.70388 .45243 m
.70403 .45214 L
s
.70388 .45243 m
.70381 .4522 L
s
.70403 .45214 m
.7042 .45222 L
s
.70403 .45214 m
.70381 .4522 L
s
.7042 .45222 m
.70405 .45251 L
s
.70381 .4522 m
.70405 .45251 L
s
.70381 .4522 m
.7042 .45222 L
s
1 .002 0 r
.70132 .25749 m
.70132 .2575 L
s
.70132 .25748 m
.70132 .25749 L
s
.70134 .25749 m
.70132 .25749 L
s
.70133 .25748 m
.70132 .25748 L
s
.70132 .25748 m
.70134 .25749 L
s
.70134 .25749 m
.70132 .2575 L
s
.70133 .25748 m
.70134 .25749 L
s
.70127 .25747 m
.70134 .25749 L
s
.70132 .2575 m
.70133 .25748 L
s
1 0 0 r
.37605 .35458 m
.37605 .35457 L
s
.37605 .35457 m
.37605 .35457 L
s
.37605 .35457 m
.37604 .35457 L
s
.37605 .35457 m
.37605 .35457 L
s
.37605 .35457 m
.37604 .35457 L
s
.37604 .35457 m
.37605 .35458 L
s
.37604 .35457 m
.37605 .35457 L
s
.37606 .35457 m
.37604 .35457 L
s
.37605 .35457 m
.37605 .35458 L
s
1 .021 0 r
.63432 .4193 m
.63345 .41905 L
s
1 .011 0 r
.44302 .19274 m
.44353 .19266 L
s
.44344 .19273 m
.44342 .19273 L
s
.44343 .19262 m
.44344 .19273 L
s
.44353 .19266 m
.44344 .19273 L
s
.44341 .19262 m
.44343 .19262 L
s
.44343 .19262 m
.44353 .19266 L
s
.44353 .19266 m
.44342 .19273 L
s
.44341 .19262 m
.44353 .19266 L
s
.44342 .19273 m
.44341 .19262 L
s
1 .021 0 r
.63362 .41921 m
.63356 .41918 L
s
.63356 .41918 m
.63362 .41899 L
s
.63356 .41918 m
.63345 .41905 L
s
.63362 .41899 m
.63368 .41902 L
s
.63362 .41899 m
.63345 .41905 L
s
.63345 .41905 m
.63362 .41921 L
s
.63345 .41905 m
.63368 .41902 L
s
.63368 .41902 m
.63362 .41921 L
s
1 .241 0 r
.4172 .51582 m
.41796 .51792 L
s
1 .028 0 r
.23749 .48353 m
.23761 .48355 L
s
.23764 .48325 m
.23749 .48353 L
s
.23749 .48353 m
.23746 .48334 L
s
.23779 .48347 m
.23749 .48353 L
s
.23814 .48289 m
.23749 .48353 L
s
.23764 .48325 m
.23746 .48334 L
s
.23779 .48347 m
.23764 .48325 L
s
.23761 .48355 m
.23779 .48347 L
s
1 .575 0 r
.47496 .54764 m
.47564 .5529 L
s
1 .028 0 r
.23746 .48334 m
.23761 .48355 L
s
1 .006 0 r
.63075 .22386 m
.63076 .22386 L
s
.63076 .22381 m
.63075 .22386 L
s
.63081 .22385 m
.63075 .22386 L
s
.63077 .22381 m
.63076 .22381 L
s
.63076 .22381 m
.63081 .22385 L
s
.63081 .22385 m
.63076 .22386 L
s
.63077 .22381 m
.63081 .22385 L
s
.63056 .2238 m
.63081 .22385 L
s
.63076 .22386 m
.63077 .22381 L
s
1 .007 0 r
.56332 .38574 m
.56331 .38574 L
s
.56331 .38574 m
.56332 .38567 L
s
.56331 .38574 m
.56325 .3857 L
s
1 .013 0 r
.82199 .45051 m
.82168 .45022 L
s
1 .007 0 r
.56356 .38573 m
.56325 .3857 L
s
1 0 0 r
.30514 .32096 m
.30514 .32096 L
s
1 .007 0 r
.56332 .38567 m
.56332 .38568 L
s
.56332 .38567 m
.56325 .3857 L
s
.56325 .3857 m
.56332 .38574 L
s
.56325 .3857 m
.56332 .38568 L
s
.56332 .38568 m
.56332 .38574 L
s
1 .013 0 r
.82174 .45021 m
.82182 .45025 L
s
.82167 .45031 m
.82174 .45021 L
s
.82174 .45021 m
.82168 .45022 L
s
.82175 .45034 m
.82167 .45031 L
s
.82167 .45031 m
.82168 .45022 L
s
.82182 .45025 m
.82175 .45034 L
s
.82168 .45022 m
.82182 .45025 L
s
.82168 .45022 m
.82175 .45034 L
s
1 .008 0 r
.16692 .44953 m
.16695 .44953 L
s
.16696 .44945 m
.16692 .44953 L
s
.16692 .44953 m
.16691 .44947 L
s
.167 .44951 m
.16692 .44953 L
s
.16708 .44934 m
.16692 .44953 L
s
1 .075 0 r
.35216 .48192 m
.35265 .48206 L
s
.35269 .48127 m
.35216 .48192 L
s
.35216 .48192 m
.35233 .48143 L
s
.35301 .48189 m
.35216 .48192 L
s
.35468 .48061 m
.35216 .48192 L
s
1 .008 0 r
.16696 .44945 m
.16691 .44947 L
s
.167 .44951 m
.16696 .44945 L
s
.16695 .44953 m
.167 .44951 L
s
1 .075 0 r
.35265 .48206 m
.35301 .48189 L
s
.35301 .48189 m
.35269 .48127 L
s
1 .008 0 r
.16691 .44947 m
.16695 .44953 L
s
1 .075 0 r
.35269 .48127 m
.35233 .48143 L
s
1 .012 0 r
.56018 .19016 m
.56019 .19016 L
s
.56019 .19005 m
.56018 .19016 L
s
.5603 .19011 m
.56018 .19016 L
s
.5602 .19005 m
.56019 .19005 L
s
.56019 .19005 m
.5603 .19011 L
s
.5603 .19011 m
.56019 .19016 L
s
.5602 .19005 m
.5603 .19011 L
s
.55976 .19008 m
.5603 .19011 L
s
1 .001 0 r
.49269 .35212 m
.49269 .35212 L
s
.49269 .35212 m
.49269 .35212 L
s
.49269 .35212 m
.49268 .35212 L
s
.49269 .35212 m
.49269 .35212 L
s
.49269 .35212 m
.49268 .35212 L
s
.49268 .35212 m
.49269 .35212 L
s
.49268 .35212 m
.49269 .35212 L
s
.49271 .35212 m
.49268 .35212 L
s
1 .009 0 r
.75131 .41694 m
.75103 .41677 L
s
1 .001 0 r
.49269 .35212 m
.49269 .35212 L
s
1 .012 0 r
.56019 .19016 m
.5602 .19005 L
s
1 .009 0 r
.75109 .41676 m
.75113 .41677 L
s
.75105 .41683 m
.75109 .41676 L
s
.75109 .41676 m
.75103 .41677 L
s
.75109 .41685 m
.75105 .41683 L
s
.75105 .41683 m
.75103 .41677 L
s
.75113 .41677 m
.75109 .41685 L
s
.75103 .41677 m
.75113 .41677 L
s
.75103 .41677 m
.75109 .41685 L
s
1 .075 0 r
.35233 .48143 m
.35265 .48206 L
s
0 .04 1 r
.52451 .5458 m
.50146 .57444 L
s
.48379 .53439 m
.52451 .5458 L
s
1 .003 0 r
.74771 .22123 m
.74772 .22123 L
s
.74772 .2212 m
.74771 .22123 L
s
.74775 .22123 m
.74771 .22123 L
s
.74775 .22123 m
.74772 .22123 L
s
.74772 .2212 m
.74775 .22123 L
s
.74773 .22121 m
.74775 .22123 L
s
.74762 .22117 m
.74775 .22123 L
s
.74773 .22121 m
.74772 .2212 L
s
1 .018 0 r
.48952 .15635 m
.48951 .15636 L
s
.48951 .15619 m
.48952 .15635 L
s
.48967 .15626 m
.48952 .15635 L
s
1 .003 0 r
.74772 .22123 m
.74773 .22121 L
s
1 .018 0 r
.4895 .15619 m
.48951 .15619 L
s
.48951 .15619 m
.48967 .15626 L
s
1 .417 0 r
.61345 .54547 m
.5966 .54027 L
s
1 .004 0 r
.68053 .38332 m
.68039 .38327 L
s
1 0 0 r
.42177 .31846 m
.42177 .31846 L
s
1 .018 0 r
.48886 .15631 m
.48967 .15626 L
s
1 .004 0 r
.68042 .3833 m
.68041 .38329 L
s
.68041 .38329 m
.68042 .38326 L
s
.68041 .38329 m
.68039 .38327 L
s
.68042 .38326 m
.68043 .38326 L
s
.68042 .38326 m
.68039 .38327 L
s
1 .018 0 r
.48967 .15626 m
.48951 .15636 L
s
.4895 .15619 m
.48967 .15626 L
s
1 .004 0 r
.68039 .38327 m
.68042 .3833 L
s
.68039 .38327 m
.68043 .38326 L
s
.68043 .38326 m
.68042 .3833 L
s
1 .018 0 r
.48951 .15636 m
.4895 .15619 L
s
1 .323 0 r
.53063 .51301 m
.53042 .51252 L
s
.53042 .51252 m
.53062 .50954 L
s
.53042 .51252 m
.52764 .51111 L
s
1 .019 0 r
.28305 .44741 m
.28315 .44743 L
s
.28317 .44723 m
.28305 .44741 L
s
.28305 .44741 m
.28306 .44728 L
s
.28326 .44738 m
.28305 .44741 L
s
.28361 .44701 m
.28305 .44741 L
s
.28317 .44723 m
.28306 .44728 L
s
.28326 .44738 m
.28317 .44723 L
s
.28315 .44743 m
.28326 .44738 L
s
1 .323 0 r
.53062 .50954 m
.53082 .51003 L
s
.53062 .50954 m
.52764 .51111 L
s
1 .019 0 r
.28306 .44728 m
.28315 .44743 L
s
1 .151 0 r
.46615 .47995 m
.46643 .47972 L
s
.46643 .47972 m
.46618 .47835 L
s
.46643 .47972 m
.46482 .47936 L
s
.46618 .47835 m
.46589 .47857 L
s
.46618 .47835 m
.46482 .47936 L
s
1 .009 0 r
.67707 .18753 m
.67709 .18753 L
s
.67709 .18745 m
.67707 .18753 L
s
.67717 .18751 m
.67707 .18753 L
s
.67712 .18745 m
.67709 .18745 L
s
.67709 .18745 m
.67717 .18751 L
s
.67717 .18751 m
.67709 .18753 L
s
.67712 .18745 m
.67717 .18751 L
s
.6768 .18741 m
.67717 .18751 L
s
.67709 .18753 m
.67712 .18745 L
s
1 .323 0 r
.54254 .51192 m
.52764 .51111 L
s
1 .001 0 r
.60967 .34966 m
.60964 .34966 L
s
1 0 0 r
.35074 .28476 m
.35075 .28476 L
s
1 .001 0 r
.60965 .34966 m
.60965 .34966 L
s
.60965 .34966 m
.60965 .34966 L
s
.60965 .34966 m
.60964 .34966 L
s
1 0 0 r
.35074 .28476 m
.35074 .28476 L
s
.35074 .28476 m
.35074 .28476 L
s
.35075 .28476 m
.35074 .28476 L
s
.35074 .28476 m
.35074 .28476 L
s
.35074 .28476 m
.35075 .28476 L
s
1 .001 0 r
.60965 .34966 m
.60965 .34966 L
s
.60965 .34966 m
.60964 .34966 L
s
1 0 0 r
.35075 .28476 m
.35074 .28476 L
s
.35074 .28476 m
.35075 .28476 L
s
.35074 .28476 m
.35074 .28476 L
s
1 .001 0 r
.60964 .34966 m
.60965 .34966 L
s
.60964 .34966 m
.60965 .34966 L
s
.60965 .34966 m
.60965 .34966 L
s
1 .151 0 r
.46482 .47936 m
.46615 .47995 L
s
.46482 .47936 m
.46589 .47857 L
s
.47154 .47832 m
.46482 .47936 L
s
.46589 .47857 m
.46615 .47995 L
s
1 .323 0 r
.52764 .51111 m
.53063 .51301 L
s
.52764 .51111 m
.53082 .51003 L
s
1 .016 0 r
.60644 .15376 m
.60647 .15376 L
s
.60647 .15361 m
.60644 .15376 L
s
.60661 .1537 m
.60644 .15376 L
s
.60649 .15361 m
.60647 .15361 L
s
.60647 .15361 m
.60661 .1537 L
s
1 .004 0 r
.21233 .41347 m
.21235 .41347 L
s
.21235 .41343 m
.21233 .41347 L
s
.21233 .41347 m
.21233 .41344 L
s
.21237 .41346 m
.21233 .41347 L
s
.21244 .41338 m
.21233 .41347 L
s
1 .016 0 r
.60661 .1537 m
.60647 .15376 L
s
.60649 .15361 m
.60661 .1537 L
s
.60589 .1536 m
.60661 .1537 L
s
1 .004 0 r
.21235 .41343 m
.21233 .41344 L
s
.21237 .41346 m
.21235 .41343 L
s
.21235 .41347 m
.21237 .41346 L
s
.21233 .41344 m
.21235 .41347 L
s
1 .016 0 r
.60647 .15376 m
.60649 .15361 L
s
1 .002 0 r
.79781 .3809 m
.79777 .38087 L
s
1 .158 0 r
.73064 .54326 m
.72634 .54002 L
s
1 0 0 r
.53871 .31596 m
.53871 .31596 L
s
1 .002 0 r
.79778 .38087 m
.79778 .38087 L
s
.79777 .38088 m
.79778 .38087 L
s
.79778 .38087 m
.79777 .38087 L
s
.79778 .38089 m
.79777 .38088 L
s
.79777 .38088 m
.79777 .38087 L
s
.79778 .38087 m
.79778 .38089 L
s
.79777 .38087 m
.79778 .38087 L
s
.79777 .38087 m
.79778 .38089 L
s
1 .323 0 r
.53082 .51003 m
.53063 .51301 L
s
1 .046 0 r
.39898 .44541 m
.39914 .44533 L
s
.39914 .44533 m
.399 .44493 L
s
.39914 .44533 m
.39863 .44529 L
s
.399 .44493 m
.39883 .44501 L
s
.399 .44493 m
.39863 .44529 L
s
.39863 .44529 m
.39898 .44541 L
s
.39863 .44529 m
.39883 .44501 L
s
.40044 .44468 m
.39863 .44529 L
s
1 .417 0 r
.60003 .54358 m
.59862 .54272 L
s
.59862 .54272 m
.59993 .53905 L
s
.59862 .54272 m
.5966 .54027 L
s
1 .022 0 r
.07374 .5427 m
.07376 .54271 L
s
.0738 .54247 m
.07374 .5427 L
s
.07374 .5427 m
.07364 .54256 L
s
.07392 .54262 m
.07374 .5427 L
s
.07395 .54216 m
.07374 .5427 L
s
.0738 .54247 m
.07364 .54256 L
s
.07392 .54262 m
.0738 .54247 L
s
.07376 .54271 m
.07392 .54262 L
s
.07364 .54256 m
.07376 .54271 L
s
1 .046 0 r
.39883 .44501 m
.39898 .44541 L
s
1 .417 0 r
.59993 .53905 m
.60133 .5399 L
s
.59993 .53905 m
.5966 .54027 L
s
1 .023 0 r
.53574 .11987 m
.53575 .11987 L
s
.53575 .11965 m
.53574 .11987 L
s
.53596 .11977 m
.53574 .11987 L
s
.53575 .11965 m
.53575 .11965 L
s
.53575 .11965 m
.53596 .11977 L
s
.53596 .11977 m
.53575 .11987 L
s
.53575 .11965 m
.53596 .11977 L
s
.53488 .11975 m
.53596 .11977 L
s
1 0 0 r
.46767 .28221 m
.46767 .28221 L
s
.46767 .28221 m
.46767 .28221 L
s
.46768 .28221 m
.46767 .28221 L
s
.72693 .3472 m
.72692 .3472 L
s
1 .172 0 r
.65971 .50967 m
.65338 .50698 L
s
1 0 0 r
.46766 .28221 m
.46768 .28221 L
s
.46767 .28221 m
.46767 .28221 L
s
.46767 .28221 m
.46768 .28221 L
s
.46768 .28221 m
.46767 .28221 L
s
.46767 .28221 m
.46768 .28221 L
s
.46767 .28221 m
.46767 .28221 L
s
.72692 .3472 m
.72692 .3472 L
s
.72692 .3472 m
.72692 .3472 L
s
.72692 .3472 m
.72692 .3472 L
s
.72692 .3472 m
.72692 .3472 L
s
.72692 .3472 m
.72692 .3472 L
s
.72692 .3472 m
.72692 .3472 L
s
.72692 .3472 m
.72692 .3472 L
s
.72692 .3472 m
.72692 .3472 L
s
1 .023 0 r
.53575 .11987 m
.53575 .11965 L
s
0 .04 1 r
.48379 .53439 m
.50146 .57444 L
s
1 .01 0 r
.32891 .41117 m
.32897 .41119 L
s
.32898 .41109 m
.32891 .41117 L
s
.32891 .41117 m
.32893 .41111 L
s
.32902 .41117 m
.32891 .41117 L
s
.32925 .411 m
.32891 .41117 L
s
.32897 .41119 m
.32902 .41117 L
s
.32902 .41117 m
.32898 .41109 L
s
.32898 .41109 m
.32893 .41111 L
s
1 .011 0 r
.72355 .15106 m
.72359 .15106 L
s
.72358 .15096 m
.72355 .15106 L
s
.72367 .15104 m
.72355 .15106 L
s
.72362 .15096 m
.72358 .15096 L
s
.72358 .15096 m
.72367 .15104 L
s
.72367 .15104 m
.72359 .15106 L
s
.72362 .15096 m
.72367 .15104 L
s
.72322 .15088 m
.72367 .15104 L
s
1 .051 0 r
.18979 .54116 m
.18994 .5412 L
s
.19 .54064 m
.18979 .54116 L
s
.18979 .54116 m
.18965 .54083 L
s
.19029 .54101 m
.18979 .54116 L
s
.19067 .53995 m
.18979 .54116 L
s
1 .01 0 r
.32893 .41111 m
.32897 .41119 L
s
1 .011 0 r
.72359 .15106 m
.72362 .15096 L
s
1 .158 0 r
.72714 .53981 m
.72805 .54028 L
s
.72635 .54105 m
.72714 .53981 L
s
.72714 .53981 m
.72634 .54002 L
s
1 .051 0 r
.19 .54064 m
.18965 .54083 L
s
.19029 .54101 m
.19 .54064 L
s
1 .057 0 r
.84814 .54105 m
.84713 .53972 L
s
1 .137 0 r
.58869 .47602 m
.58263 .47494 L
s
1 0 0 r
.65596 .31345 m
.65596 .31345 L
s
1 .002 0 r
.39652 .24842 m
.39659 .2484 L
s
1 .158 0 r
.72725 .54153 m
.72635 .54105 L
s
.72635 .54105 m
.72634 .54002 L
s
1 .002 0 r
.39658 .24842 m
.39658 .24842 L
s
.39658 .2484 m
.39658 .24842 L
s
.39659 .2484 m
.39658 .24842 L
s
.39657 .2484 m
.39658 .2484 L
s
.39658 .2484 m
.39659 .2484 L
s
.39659 .2484 m
.39658 .24842 L
s
.39657 .2484 m
.39659 .2484 L
s
.39658 .24842 m
.39657 .2484 L
s
1 .051 0 r
.18994 .5412 m
.19029 .54101 L
s
.18965 .54083 m
.18994 .5412 L
s
1 .137 0 r
.58385 .47589 m
.58356 .47568 L
s
.58356 .47568 m
.58383 .47443 L
s
.58356 .47568 m
.58263 .47494 L
s
.58383 .47443 m
.58412 .47463 L
s
.58383 .47443 m
.58263 .47494 L
s
1 .172 0 r
.65468 .50844 m
.65395 .50807 L
s
.65395 .50807 m
.65461 .50659 L
s
.65395 .50807 m
.65338 .50698 L
s
.65461 .50659 m
.65534 .50697 L
s
.65461 .50659 m
.65338 .50698 L
s
1 .134 0 r
.30407 .54048 m
.30474 .54066 L
s
.30484 .53921 m
.30407 .54048 L
s
.30407 .54048 m
.30407 .5396 L
s
.30552 .54026 m
.30407 .54048 L
s
.30769 .53773 m
.30407 .54048 L
s
.30484 .53921 m
.30407 .5396 L
s
.30552 .54026 m
.30484 .53921 L
s
1 .158 0 r
.72805 .54028 m
.72725 .54153 L
s
.72634 .54002 m
.72805 .54028 L
s
1 .417 0 r
.5966 .54027 m
.60003 .54358 L
s
.5966 .54027 m
.60133 .5399 L
s
1 .134 0 r
.30474 .54066 m
.30552 .54026 L
s
1 .068 0 r
.51507 .44275 m
.51509 .44266 L
s
.51509 .44266 m
.51507 .44203 L
s
.51509 .44266 m
.51444 .4424 L
s
1 .158 0 r
.72634 .54002 m
.72725 .54153 L
s
1 .068 0 r
.51507 .44203 m
.51505 .44212 L
s
.51507 .44203 m
.51444 .4424 L
s
1 .417 0 r
.60133 .5399 m
.60003 .54358 L
s
1 .057 0 r
.8473 .53968 m
.84769 .53988 L
s
.84698 .54009 m
.8473 .53968 L
s
.8473 .53968 m
.84713 .53972 L
s
1 .019 0 r
.65284 .11722 m
.65288 .11722 L
s
.65288 .11704 m
.65284 .11722 L
s
.65305 .11717 m
.65284 .11722 L
s
.65292 .11704 m
.65288 .11704 L
s
.65288 .11704 m
.65305 .11717 L
s
.65305 .11717 m
.65288 .11722 L
s
.65292 .11704 m
.65305 .11717 L
s
.6522 .11698 m
.65305 .11717 L
s
1 .057 0 r
.84736 .54029 m
.84698 .54009 L
s
.84698 .54009 m
.84713 .53972 L
s
1 .019 0 r
.65288 .11722 m
.65292 .11704 L
s
1 .137 0 r
.58263 .47494 m
.58385 .47589 L
s
.58263 .47494 m
.58412 .47463 L
s
1 .068 0 r
.51444 .4424 m
.51507 .44275 L
s
.51444 .4424 m
.51505 .44212 L
s
.51758 .44234 m
.51444 .4424 L
s
1 .002 0 r
.25793 .3773 m
.25793 .3773 L
s
.25794 .37728 m
.25793 .3773 L
s
.25793 .3773 m
.25793 .37729 L
s
.25794 .3773 m
.25793 .3773 L
s
.25797 .37727 m
.25793 .3773 L
s
.25794 .37728 m
.25793 .37729 L
s
.25794 .3773 m
.25794 .37728 L
s
.25793 .3773 m
.25794 .3773 L
s
.25793 .37729 m
.25793 .3773 L
s
1 0 0 r
.5849 .27966 m
.5849 .27966 L
s
.5849 .27966 m
.5849 .27966 L
s
.58491 .27966 m
.5849 .27966 L
s
.5849 .27966 m
.5849 .27966 L
s
.5849 .27966 m
.58491 .27966 L
s
.58491 .27966 m
.5849 .27966 L
s
.5849 .27966 m
.58491 .27966 L
s
.58489 .27966 m
.58491 .27966 L
s
.5849 .27966 m
.5849 .27966 L
s
1 .063 0 r
.77719 .50741 m
.77559 .50605 L
s
1 .057 0 r
.84769 .53988 m
.84736 .54029 L
s
.84713 .53972 m
.84769 .53988 L
s
1 .137 0 r
.58412 .47463 m
.58385 .47589 L
s
1 .057 0 r
.84713 .53972 m
.84736 .54029 L
s
1 .318 0 r
.41476 .54048 m
.4159 .53982 L
s
.4159 .53982 m
.41488 .53703 L
s
.4159 .53982 m
.41228 .53956 L
s
1 .068 0 r
.51505 .44212 m
.51507 .44275 L
s
1 .318 0 r
.41488 .53703 m
.41375 .53768 L
s
.41488 .53703 m
.41228 .53956 L
s
1 .134 0 r
.30407 .5396 m
.30474 .54066 L
s
1 .172 0 r
.65534 .50697 m
.65468 .50844 L
s
.65338 .50698 m
.65468 .50844 L
s
1 .318 0 r
.41228 .53956 m
.41476 .54048 L
s
.41228 .53956 m
.41375 .53768 L
s
.42501 .5355 m
.41228 .53956 L
s
1 .172 0 r
.65338 .50698 m
.65534 .50697 L
s
1 .018 0 r
.11898 .50673 m
.11902 .50674 L
s
.11904 .50654 m
.11898 .50673 L
s
.11898 .50673 m
.11891 .50661 L
s
.11915 .50667 m
.11898 .50673 L
s
.11925 .50628 m
.11898 .50673 L
s
.11904 .50654 m
.11891 .50661 L
s
.11915 .50667 m
.11904 .50654 L
s
.11902 .50674 m
.11915 .50667 L
s
.11891 .50661 m
.11902 .50674 L
s
1 .063 0 r
.77588 .50598 m
.77626 .50617 L
s
.77555 .50647 m
.77588 .50598 L
s
.77588 .50598 m
.77559 .50605 L
s
1 .02 0 r
.44569 .40884 m
.44573 .40882 L
s
.44573 .40882 m
.44569 .40864 L
s
.44573 .40882 m
.44552 .40878 L
s
1 .063 0 r
.77593 .50666 m
.77555 .50647 L
s
.77555 .50647 m
.77559 .50605 L
s
1 .02 0 r
.44569 .40864 m
.44565 .40867 L
s
.44569 .40864 m
.44552 .40878 L
s
1 .028 0 r
.58207 .08326 m
.5821 .08326 L
s
.5821 .083 m
.58207 .08326 L
s
.58235 .08315 m
.58207 .08326 L
s
1 .02 0 r
.44552 .40878 m
.44569 .40884 L
s
.44552 .40878 m
.44565 .40867 L
s
.44638 .40861 m
.44552 .40878 L
s
1 .028 0 r
.58213 .083 m
.5821 .083 L
s
.5821 .083 m
.58235 .08315 L
s
.58235 .08315 m
.5821 .08326 L
s
.58213 .083 m
.58235 .08315 L
s
.58108 .08304 m
.58235 .08315 L
s
1 .02 0 r
.44565 .40867 m
.44569 .40884 L
s
1 .002 0 r
.51381 .24583 m
.51381 .24583 L
s
.51381 .24581 m
.51381 .24583 L
s
.51383 .24582 m
.51381 .24583 L
s
.51381 .24581 m
.51381 .24581 L
s
.51381 .24581 m
.51383 .24582 L
s
1 0 0 r
.77351 .31094 m
.77351 .31094 L
s
1 .062 0 r
.70616 .47372 m
.70407 .47262 L
s
1 .002 0 r
.51373 .24582 m
.51383 .24582 L
s
.51383 .24582 m
.51381 .24583 L
s
.51381 .24581 m
.51383 .24582 L
s
1 .028 0 r
.5821 .08326 m
.58213 .083 L
s
1 .002 0 r
.51381 .24583 m
.51381 .24581 L
s
1 .063 0 r
.77626 .50617 m
.77593 .50666 L
s
.77559 .50605 m
.77626 .50617 L
s
.77559 .50605 m
.77593 .50666 L
s
1 .062 0 r
.70451 .47317 m
.70421 .47303 L
s
.70421 .47303 m
.70447 .47252 L
s
.70421 .47303 m
.70407 .47262 L
s
.70447 .47252 m
.70477 .47266 L
s
.70447 .47252 m
.70407 .47262 L
s
1 .318 0 r
.41375 .53768 m
.41476 .54048 L
s
1 .062 0 r
.70477 .47266 m
.70451 .47317 L
s
.70407 .47262 m
.70451 .47317 L
s
.70407 .47262 m
.70477 .47266 L
s
1 .003 0 r
.37498 .37489 m
.37499 .37488 L
s
.37499 .37488 m
.37498 .37485 L
s
.37499 .37488 m
.37495 .37488 L
s
.37498 .37485 m
.37497 .37486 L
s
.37498 .37485 m
.37495 .37488 L
s
.37495 .37488 m
.37498 .37489 L
s
.37495 .37488 m
.37497 .37486 L
s
.37508 .37483 m
.37495 .37488 L
s
.37497 .37486 m
.37498 .37489 L
s
1 0 0 r
.70243 .2771 m
.70243 .2771 L
s
.70243 .2771 m
.70243 .2771 L
s
.70244 .2771 m
.70243 .2771 L
s
.70244 .2771 m
.70243 .2771 L
s
.70243 .2771 m
.70244 .2771 L
s
.70244 .2771 m
.70243 .2771 L
s
.70244 .2771 m
.70244 .2771 L
s
.70243 .2771 m
.70244 .2771 L
s
.70243 .2771 m
.70244 .2771 L
s
1 .046 0 r
.63503 .43999 m
.63314 .43945 L
s
1 .005 0 r
.44248 .21194 m
.4427 .21191 L
s
.44267 .21194 m
.44266 .21194 L
s
.44266 .21189 m
.44267 .21194 L
s
.4427 .21191 m
.44267 .21194 L
s
.44265 .21189 m
.44266 .21189 L
s
.44266 .21189 m
.4427 .21191 L
s
.4427 .21191 m
.44266 .21194 L
s
.44265 .21189 m
.4427 .21191 L
s
.44266 .21194 m
.44265 .21189 L
s
1 .045 0 r
.23522 .50503 m
.2354 .50507 L
s
.23544 .50458 m
.23522 .50503 L
s
.23522 .50503 m
.23516 .50472 L
s
.23569 .50493 m
.23522 .50503 L
s
.23625 .50402 m
.23522 .50503 L
s
.23544 .50458 m
.23516 .50472 L
s
.23569 .50493 m
.23544 .50458 L
s
.2354 .50507 m
.23569 .50493 L
s
1 .046 0 r
.63353 .4398 m
.63338 .43973 L
s
.63338 .43973 m
.63351 .43932 L
s
.63338 .43973 m
.63314 .43945 L
s
.63351 .43932 m
.63366 .43939 L
s
.63351 .43932 m
.63314 .43945 L
s
1 .045 0 r
.23516 .50472 m
.2354 .50507 L
s
1 .046 0 r
.63314 .43945 m
.63353 .4398 L
s
.63314 .43945 m
.63366 .43939 L
s
.63366 .43939 m
.63353 .4398 L
s
1 .022 0 r
.69936 .08053 m
.69943 .08053 L
s
.69942 .08033 m
.69936 .08053 L
s
.69961 .08048 m
.69936 .08053 L
s
.69948 .08033 m
.69942 .08033 L
s
.69942 .08033 m
.69961 .08048 L
s
.69961 .08048 m
.69943 .08053 L
s
.69948 .08033 m
.69961 .08048 L
s
.69869 .08022 m
.69961 .08048 L
s
.69943 .08053 m
.69948 .08033 L
s
1 .002 0 r
.63131 .24324 m
.63131 .24324 L
s
.63131 .24322 m
.63131 .24324 L
s
.63133 .24323 m
.63131 .24324 L
s
.63132 .24322 m
.63131 .24322 L
s
.63131 .24322 m
.63133 .24323 L
s
1 .021 0 r
.56304 .40625 m
.56301 .40623 L
s
.56301 .40623 m
.56304 .40603 L
s
.56301 .40623 m
.56284 .40613 L
s
1 .002 0 r
.63133 .24323 m
.63131 .24324 L
s
.63132 .24322 m
.63133 .24323 L
s
.63125 .24322 m
.63133 .24323 L
s
.63131 .24324 m
.63132 .24322 L
s
1 0 0 r
.30368 .34102 m
.30368 .34102 L
s
.30368 .34102 m
.30368 .34102 L
s
.30368 .34102 m
.30368 .34102 L
s
.30368 .34102 m
.30368 .34102 L
s
.30369 .34102 m
.30368 .34102 L
s
.30368 .34102 m
.30368 .34102 L
s
.30368 .34102 m
.30368 .34102 L
s
.30368 .34102 m
.30368 .34102 L
s
.30368 .34102 m
.30368 .34102 L
s
1 .023 0 r
.82394 .47142 m
.82338 .47089 L
s
1 .021 0 r
.56381 .40622 m
.56284 .40613 L
s
.56304 .40603 m
.56306 .40606 L
s
.56304 .40603 m
.56284 .40613 L
s
.56284 .40613 m
.56304 .40625 L
s
.56284 .40613 m
.56306 .40606 L
s
.56306 .40606 m
.56304 .40625 L
s
1 .114 0 r
.34969 .50374 m
.35043 .50395 L
s
.3505 .50273 m
.34969 .50374 L
s
.34969 .50374 m
.34994 .503 L
s
.35098 .50368 m
.34969 .50374 L
s
.35356 .50175 m
.34969 .50374 L
s
.35043 .50395 m
.35098 .50368 L
s
.35098 .50368 m
.3505 .50273 L
s
1 .023 0 r
.82348 .47087 m
.82362 .47094 L
s
.82336 .47105 m
.82348 .47087 L
s
.82348 .47087 m
.82338 .47089 L
s
1 .114 0 r
.3505 .50273 m
.34994 .503 L
s
1 .023 0 r
.8235 .47112 m
.82336 .47105 L
s
.82336 .47105 m
.82338 .47089 L
s
.82362 .47094 m
.8235 .47112 L
s
.82338 .47089 m
.82362 .47094 L
s
.82338 .47089 m
.8235 .47112 L
s
1 .014 0 r
.16444 .4706 m
.16449 .47061 L
s
.1645 .47046 m
.16444 .4706 L
s
.16444 .4706 m
.16441 .4705 L
s
.16458 .47056 m
.16444 .4706 L
s
.16472 .47026 m
.16444 .4706 L
s
.1645 .47046 m
.16441 .4705 L
s
.16458 .47056 m
.1645 .47046 L
s
.16449 .47061 m
.16458 .47056 L
s
.16441 .4705 m
.16449 .47061 L
s
1 .114 0 r
.34994 .503 m
.35043 .50395 L
s
1 .005 0 r
.49231 .37244 m
.49232 .37243 L
s
.49232 .37243 m
.49231 .37238 L
s
.49232 .37243 m
.49227 .37241 L
s
.56017 .20932 m
.56018 .20933 L
s
.56017 .20928 m
.56017 .20932 L
s
.56022 .2093 m
.56017 .20932 L
s
.49231 .37238 m
.49231 .37239 L
s
.49231 .37238 m
.49227 .37241 L
s
.56018 .20928 m
.56017 .20928 L
s
.56017 .20928 m
.56022 .2093 L
s
.49227 .37241 m
.49231 .37244 L
s
.49227 .37241 m
.49231 .37239 L
s
.4925 .3724 m
.49227 .37241 L
s
.56022 .2093 m
.56018 .20933 L
s
.56018 .20928 m
.56022 .2093 L
s
.55998 .20929 m
.56022 .2093 L
s
1 .019 0 r
.75279 .43764 m
.75218 .43726 L
s
1 .005 0 r
.49231 .37239 m
.49231 .37244 L
s
.56018 .20933 m
.56018 .20928 L
s
1 .019 0 r
.7523 .43724 m
.7524 .43728 L
s
.75221 .4374 m
.7523 .43724 L
s
.7523 .43724 m
.75218 .43726 L
s
.75231 .43744 m
.75221 .4374 L
s
.75221 .4374 m
.75218 .43726 L
s
.7524 .43728 m
.75231 .43744 L
s
.75218 .43726 m
.7524 .43728 L
s
.75218 .43726 m
.75231 .43744 L
s
1 .01 0 r
.48898 .17534 m
.48897 .17534 L
s
.48897 .17525 m
.48898 .17534 L
s
.48906 .17529 m
.48898 .17534 L
s
1 .001 0 r
.74911 .24062 m
.74911 .24062 L
s
.74911 .24061 m
.74911 .24062 L
s
.74912 .24062 m
.74911 .24062 L
s
.74912 .24062 m
.74911 .24062 L
s
.74911 .24061 m
.74912 .24062 L
s
.74912 .24061 m
.74912 .24062 L
s
.74908 .2406 m
.74912 .24062 L
s
.74912 .24061 m
.74911 .24061 L
s
.74911 .24062 m
.74912 .24061 L
s
1 .01 0 r
.48897 .17525 m
.48897 .17525 L
s
.48897 .17525 m
.48906 .17529 L
s
1 0 0 r
.42108 .33854 m
.42108 .33854 L
s
.42108 .33854 m
.42108 .33853 L
s
.42108 .33854 m
.42107 .33854 L
s
.42108 .33853 m
.42107 .33853 L
s
.42108 .33853 m
.42107 .33854 L
s
.42107 .33854 m
.42108 .33854 L
s
.42107 .33854 m
.42107 .33853 L
s
.42109 .33853 m
.42107 .33854 L
s
.42107 .33853 m
.42108 .33854 L
s
1 .012 0 r
.68155 .40382 m
.6811 .40364 L
s
1 .01 0 r
.48862 .17532 m
.48906 .17529 L
s
.48906 .17529 m
.48897 .17534 L
s
.48897 .17525 m
.48906 .17529 L
s
.48897 .17534 m
.48897 .17525 L
s
1 .012 0 r
.68119 .40374 m
.68114 .40372 L
s
.68114 .40372 m
.68118 .40362 L
s
.68114 .40372 m
.6811 .40364 L
s
.68118 .40362 m
.68123 .40364 L
s
.68118 .40362 m
.6811 .40364 L
s
.6811 .40364 m
.68119 .40374 L
s
.6811 .40364 m
.68123 .40364 L
s
.68123 .40364 m
.68119 .40374 L
s
1 .22 0 r
.46326 .50186 m
.46367 .50151 L
s
.46367 .50151 m
.4633 .49949 L
s
.46367 .50151 m
.46131 .50097 L
s
1 .417 0 r
.52716 .53472 m
.52691 .53405 L
s
.52691 .53405 m
.52716 .53018 L
s
.52691 .53405 m
.52329 .53224 L
s
1 .035 0 r
.281 .46866 m
.28119 .4687 L
s
.28122 .46833 m
.281 .46866 L
s
.281 .46866 m
.28102 .46842 L
s
.28139 .46861 m
.281 .46866 L
s
.28202 .46794 m
.281 .46866 L
s
1 .22 0 r
.4633 .49949 m
.46289 .49984 L
s
.4633 .49949 m
.46131 .50097 L
s
1 .035 0 r
.28122 .46833 m
.28102 .46842 L
s
.28139 .46861 m
.28122 .46833 L
s
.28119 .4687 m
.28139 .46861 L
s
.28102 .46842 m
.28119 .4687 L
s
1 .22 0 r
.46131 .50097 m
.46326 .50186 L
s
.46131 .50097 m
.46289 .49984 L
s
.47118 .49947 m
.46131 .50097 L
s
1 .417 0 r
.52716 .53018 m
.52742 .53085 L
s
.52716 .53018 m
.52329 .53224 L
s
1 .004 0 r
.67792 .20668 m
.67793 .20668 L
s
.67793 .20665 m
.67792 .20668 L
s
.67796 .20667 m
.67792 .20668 L
s
.67794 .20665 m
.67793 .20665 L
s
.67793 .20665 m
.67796 .20667 L
s
.67796 .20667 m
.67793 .20668 L
s
.67794 .20665 m
.67796 .20667 L
s
.6778 .20663 m
.67796 .20667 L
s
.67793 .20668 m
.67794 .20665 L
s
.61022 .36995 m
.61004 .36992 L
s
1 .417 0 r
.54265 .53327 m
.52329 .53224 L
s
1 0 0 r
.34959 .30462 m
.34959 .30462 L
s
1 .004 0 r
.61008 .36994 m
.61007 .36994 L
s
.61007 .36994 m
.61008 .3699 L
s
.61007 .36994 m
.61004 .36992 L
s
.61008 .3699 m
.61009 .36991 L
s
.61008 .3699 m
.61004 .36992 L
s
.61004 .36992 m
.61008 .36994 L
s
.61004 .36992 m
.61009 .36991 L
s
.61009 .36991 m
.61008 .36994 L
s
1 .22 0 r
.46289 .49984 m
.46326 .50186 L
s
1 .01 0 r
.21013 .43431 m
.21018 .43432 L
s
.21019 .43422 m
.21013 .43431 L
s
.21013 .43431 m
.21013 .43424 L
s
.21024 .43429 m
.21013 .43431 L
s
.21037 .4341 m
.21013 .43431 L
s
.21019 .43422 m
.21013 .43424 L
s
.21024 .43429 m
.21019 .43422 L
s
.21018 .43432 m
.21024 .43429 L
s
.21013 .43424 m
.21018 .43432 L
s
1 .417 0 r
.52329 .53224 m
.52716 .53472 L
s
.52329 .53224 m
.52742 .53085 L
s
1 .009 0 r
.60672 .17269 m
.60673 .1727 L
s
.60673 .17261 m
.60672 .17269 L
s
.60681 .17267 m
.60672 .17269 L
s
.60675 .17262 m
.60673 .17261 L
s
.60673 .17261 m
.60681 .17267 L
s
.60681 .17267 m
.60673 .1727 L
s
.60675 .17262 m
.60681 .17267 L
s
.60642 .17261 m
.60681 .17267 L
s
.60673 .1727 m
.60675 .17262 L
s
1 0 0 r
.53878 .33604 m
.53878 .33604 L
s
.53878 .33604 m
.53878 .33604 L
s
.53878 .33604 m
.53878 .33604 L
s
.53878 .33604 m
.53878 .33604 L
s
.53878 .33604 m
.53878 .33604 L
s
1 .005 0 r
.79961 .40141 m
.79946 .40131 L
s
1 0 0 r
.5388 .33604 m
.53878 .33604 L
s
.53878 .33604 m
.53878 .33604 L
s
.53878 .33604 m
.53878 .33604 L
s
.53878 .33604 m
.53878 .33604 L
s
1 .08 0 r
.39705 .4669 m
.39734 .46675 L
s
.39734 .46675 m
.39708 .46605 L
s
.39734 .46675 m
.39643 .46668 L
s
1 .005 0 r
.79949 .4013 m
.79951 .40131 L
s
.79946 .40134 m
.79949 .4013 L
s
.79949 .4013 m
.79946 .40131 L
s
.79949 .40135 m
.79946 .40134 L
s
.79946 .40134 m
.79946 .40131 L
s
1 .08 0 r
.39708 .46605 m
.39679 .46619 L
s
.39708 .46605 m
.39643 .46668 L
s
1 .005 0 r
.79951 .40131 m
.79949 .40135 L
s
.79946 .40131 m
.79951 .40131 L
s
.79946 .40131 m
.79949 .40135 L
s
1 .08 0 r
.39643 .46668 m
.39705 .4669 L
s
.39643 .46668 m
.39679 .46619 L
s
.39962 .46562 m
.39643 .46668 L
s
.39679 .46619 m
.39705 .4669 L
s
1 .417 0 r
.52742 .53085 m
.52716 .53472 L
s
1 .014 0 r
.53547 .13862 m
.53548 .13862 L
s
.53548 .13849 m
.53547 .13862 L
s
.53561 .13856 m
.53547 .13862 L
s
.53548 .13849 m
.53548 .13849 L
s
.53548 .13849 m
.53561 .13856 L
s
.53561 .13856 m
.53548 .13862 L
s
.53548 .13849 m
.53561 .13856 L
s
.53494 .13855 m
.53561 .13856 L
s
1 .002 0 r
.72826 .3675 m
.72818 .36746 L
s
1 .233 0 r
.6606 .53104 m
.65196 .52742 L
s
1 0 0 r
.46728 .30208 m
.46728 .30208 L
s
1 .002 0 r
.7282 .36748 m
.72819 .36748 L
s
.72819 .36748 m
.7282 .36746 L
s
.72819 .36748 m
.72818 .36746 L
s
.7282 .36746 m
.72821 .36746 L
s
.7282 .36746 m
.72818 .36746 L
s
.72821 .36746 m
.7282 .36748 L
s
.72818 .36746 m
.7282 .36748 L
s
.72818 .36746 m
.72821 .36746 L
s
1 .014 0 r
.53548 .13862 m
.53548 .13849 L
s
1 .022 0 r
.32718 .43212 m
.32733 .43216 L
s
.32735 .43192 m
.32718 .43212 L
s
.32718 .43212 m
.32724 .43197 L
s
.32744 .43211 m
.32718 .43212 L
s
.32796 .43173 m
.32718 .43212 L
s
.32733 .43216 m
.32744 .43211 L
s
.32744 .43211 m
.32735 .43192 L
s
.32735 .43192 m
.32724 .43197 L
s
.32724 .43197 m
.32733 .43216 L
s
1 .006 0 r
.7247 .16999 m
.72472 .16999 L
s
.72472 .16994 m
.7247 .16999 L
s
.72477 .16998 m
.7247 .16999 L
s
.72474 .16994 m
.72472 .16994 L
s
.72472 .16994 m
.72477 .16998 L
s
.72477 .16998 m
.72472 .16999 L
s
.72474 .16994 m
.72477 .16998 L
s
.72453 .1699 m
.72477 .16998 L
s
.72472 .16999 m
.72474 .16994 L
s
1 .202 0 r
.58911 .49719 m
.58012 .4956 L
s
1 0 0 r
.65682 .33354 m
.65681 .33354 L
s
.39567 .26808 m
.39568 .26808 L
s
.39568 .26808 m
.39567 .26808 L
s
.39567 .26808 m
.39568 .26808 L
s
.39568 .26808 m
.39568 .26808 L
s
.39567 .26808 m
.39567 .26808 L
s
.39567 .26808 m
.39568 .26808 L
s
.65681 .33354 m
.65681 .33354 L
s
.65681 .33354 m
.65681 .33354 L
s
.65681 .33354 m
.65681 .33354 L
s
.65681 .33354 m
.65681 .33354 L
s
.65681 .33354 m
.65681 .33354 L
s
.39568 .26808 m
.39567 .26808 L
s
.39567 .26808 m
.39568 .26808 L
s
.39567 .26808 m
.39567 .26808 L
s
.65681 .33354 m
.65681 .33354 L
s
.65681 .33354 m
.65681 .33354 L
s
.65681 .33354 m
.65681 .33354 L
s
1 .202 0 r
.58194 .497 m
.58151 .49668 L
s
.58151 .49668 m
.5819 .49483 L
s
.58151 .49668 m
.58012 .4956 L
s
1 .116 0 r
.51321 .46399 m
.51324 .46384 L
s
.51324 .46384 m
.51321 .46276 L
s
.51324 .46384 m
.51213 .4634 L
s
1 .202 0 r
.5819 .49483 m
.58233 .49515 L
s
.5819 .49483 m
.58012 .4956 L
s
1 .116 0 r
.51321 .46276 m
.51318 .46291 L
s
.51321 .46276 m
.51213 .4634 L
s
1 .012 0 r
.65343 .13593 m
.65346 .13593 L
s
.65345 .13582 m
.65343 .13593 L
s
.65356 .1359 m
.65343 .13593 L
s
.65348 .13582 m
.65345 .13582 L
s
.65345 .13582 m
.65356 .1359 L
s
1 .116 0 r
.51213 .4634 m
.51321 .46399 L
s
.51213 .4634 m
.51318 .46291 L
s
.51753 .46329 m
.51213 .4634 L
s
1 .005 0 r
.25606 .39789 m
.25608 .3979 L
s
.25609 .39785 m
.25606 .39789 L
s
.25606 .39789 m
.25606 .39786 L
s
.25611 .39789 m
.25606 .39789 L
s
.25621 .39779 m
.25606 .39789 L
s
1 .012 0 r
.65356 .1359 m
.65346 .13593 L
s
.65348 .13582 m
.65356 .1359 L
s
.65303 .13579 m
.65356 .1359 L
s
1 .005 0 r
.25609 .39785 m
.25606 .39786 L
s
.25611 .39789 m
.25609 .39785 L
s
.25608 .3979 m
.25611 .39789 L
s
1 .233 0 r
.65374 .52941 m
.65274 .52888 L
s
.65274 .52888 m
.65364 .52687 L
s
.65274 .52888 m
.65196 .52742 L
s
1 .005 0 r
.25606 .39786 m
.25608 .3979 L
s
1 .012 0 r
.65346 .13593 m
.65348 .13582 L
s
1 .233 0 r
.65364 .52687 m
.65464 .5274 L
s
.65364 .52687 m
.65196 .52742 L
s
1 .091 0 r
.77886 .52879 m
.77654 .52685 L
s
1 0 0 r
.58528 .29954 m
.58528 .29954 L
s
1 .116 0 r
.51318 .46291 m
.51321 .46399 L
s
1 .202 0 r
.58012 .4956 m
.58194 .497 L
s
.58012 .4956 m
.58233 .49515 L
s
1 .028 0 r
.11616 .52835 m
.11622 .52836 L
s
.11626 .52806 m
.11616 .52835 L
s
.11616 .52835 m
.11606 .52816 L
s
.11642 .52826 m
.11616 .52835 L
s
.11657 .52767 m
.11616 .52835 L
s
.11626 .52806 m
.11606 .52816 L
s
.11642 .52826 m
.11626 .52806 L
s
.11622 .52836 m
.11642 .52826 L
s
.11606 .52816 m
.11622 .52836 L
s
1 .043 0 r
.44435 .42986 m
.44444 .42981 L
s
.44444 .42981 m
.44436 .42942 L
s
.44444 .42981 m
.44398 .42971 L
s
1 .202 0 r
.58233 .49515 m
.58194 .497 L
s
1 .043 0 r
.44436 .42942 m
.44426 .42947 L
s
.44436 .42942 m
.44398 .42971 L
s
.44398 .42971 m
.44435 .42986 L
s
.44398 .42971 m
.44426 .42947 L
s
.44586 .42935 m
.44398 .42971 L
s
.44426 .42947 m
.44435 .42986 L
s
1 .018 0 r
.58212 .10178 m
.58214 .10178 L
s
.58213 .10161 m
.58212 .10178 L
s
.5823 .10171 m
.58212 .10178 L
s
.58215 .1016 m
.58213 .10161 L
s
.58213 .10161 m
.5823 .10171 L
s
.5823 .10171 m
.58214 .10178 L
s
.58215 .1016 m
.5823 .10171 L
s
.58145 .10163 m
.5823 .10171 L
s
1 0 0 r
.51366 .26549 m
.51366 .26549 L
s
.51366 .26549 m
.51366 .26549 L
s
.51367 .26549 m
.51366 .26549 L
s
.51366 .26549 m
.51366 .26549 L
s
.51366 .26549 m
.51367 .26549 L
s
.77515 .33104 m
.77515 .33103 L
s
1 .095 0 r
.70736 .4949 m
.7041 .49321 L
s
1 0 0 r
.51365 .26549 m
.51367 .26549 L
s
.51367 .26549 m
.51366 .26549 L
s
.51366 .26549 m
.51367 .26549 L
s
.51366 .26549 m
.51366 .26549 L
s
.77515 .33103 m
.77515 .33103 L
s
.77515 .33103 m
.77515 .33103 L
s
.77515 .33103 m
.77515 .33103 L
s
.77515 .33103 m
.77515 .33103 L
s
.77515 .33103 m
.77515 .33103 L
s
.77515 .33103 m
.77515 .33103 L
s
.77515 .33103 m
.77515 .33103 L
s
.77515 .33103 m
.77515 .33103 L
s
1 .018 0 r
.58214 .10178 m
.58215 .1016 L
s
1 .091 0 r
.77696 .52674 m
.77751 .52702 L
s
.77649 .52745 m
.77696 .52674 L
s
.77696 .52674 m
.77654 .52685 L
s
1 .233 0 r
.65464 .5274 m
.65374 .52941 L
s
.65196 .52742 m
.65374 .52941 L
s
1 .091 0 r
.77704 .52773 m
.77649 .52745 L
s
.77649 .52745 m
.77654 .52685 L
s
1 .233 0 r
.65196 .52742 m
.65464 .5274 L
s
1 .091 0 r
.77751 .52702 m
.77704 .52773 L
s
.77654 .52685 m
.77751 .52702 L
s
.77654 .52685 m
.77704 .52773 L
s
1 .066 0 r
.23283 .52688 m
.2331 .52695 L
s
.23316 .52623 m
.23283 .52688 L
s
.23283 .52688 m
.23274 .52644 L
s
.23351 .52674 m
.23283 .52688 L
s
.23434 .52542 m
.23283 .52688 L
s
.23316 .52623 m
.23274 .52644 L
s
.23351 .52674 m
.23316 .52623 L
s
.2331 .52695 m
.23351 .52674 L
s
1 .011 0 r
.37375 .39554 m
.37379 .39553 L
s
.37379 .39553 m
.37375 .39543 L
s
.37379 .39553 m
.37367 .39552 L
s
.37375 .39543 m
.37371 .39545 L
s
.37375 .39543 m
.37367 .39552 L
s
.37367 .39552 m
.37375 .39554 L
s
.37367 .39552 m
.37371 .39545 L
s
.37409 .39537 m
.37367 .39552 L
s
1 .095 0 r
.70478 .49406 m
.70432 .49384 L
s
.70432 .49384 m
.70473 .49303 L
s
.70432 .49384 m
.7041 .49321 L
s
1 .011 0 r
.37371 .39545 m
.37375 .39554 L
s
1 .095 0 r
.70473 .49303 m
.70519 .49326 L
s
.70473 .49303 m
.7041 .49321 L
s
1 .08 0 r
.63576 .46096 m
.63243 .46002 L
s
1 0 0 r
.7036 .29699 m
.7036 .29699 L
s
1 .002 0 r
.44193 .2314 m
.442 .23139 L
s
.44199 .2314 m
.44198 .2314 L
s
.44199 .23138 m
.44199 .2314 L
s
.442 .23139 m
.44199 .2314 L
s
.44198 .23138 m
.44199 .23138 L
s
.44199 .23138 m
.442 .23139 L
s
.442 .23139 m
.44198 .2314 L
s
.44198 .23138 m
.442 .23139 L
s
.44198 .2314 m
.44198 .23138 L
s
1 .066 0 r
.23274 .52644 m
.2331 .52695 L
s
1 .08 0 r
.63311 .46063 m
.63286 .4605 L
s
.63286 .4605 m
.63308 .45978 L
s
.63286 .4605 m
.63243 .46002 L
s
1 .095 0 r
.70519 .49326 m
.70478 .49406 L
s
.7041 .49321 m
.70478 .49406 L
s
.7041 .49321 m
.70519 .49326 L
s
1 .08 0 r
.63308 .45978 m
.63334 .45991 L
s
.63308 .45978 m
.63243 .46002 L
s
1 .158 0 r
.34701 .52592 m
.34804 .52623 L
s
.34814 .52451 m
.34701 .52592 L
s
.34701 .52592 m
.34737 .52489 L
s
.34882 .52584 m
.34701 .52592 L
s
.35242 .52316 m
.34701 .52592 L
s
.34804 .52623 m
.34882 .52584 L
s
.34882 .52584 m
.34814 .52451 L
s
.34814 .52451 m
.34737 .52489 L
s
1 .08 0 r
.63243 .46002 m
.63311 .46063 L
s
.63243 .46002 m
.63334 .45991 L
s
.63334 .45991 m
.63311 .46063 L
s
1 .014 0 r
.70029 .09902 m
.70033 .09902 L
s
.70032 .09889 m
.70029 .09902 L
s
.70045 .09899 m
.70029 .09902 L
s
.70037 .09889 m
.70032 .09889 L
s
.70032 .09889 m
.70045 .09899 L
s
.70045 .09899 m
.70033 .09902 L
s
.70037 .09889 m
.70045 .09899 L
s
.69984 .09882 m
.70045 .09899 L
s
.70033 .09902 m
.70037 .09889 L
s
1 .046 0 r
.56238 .42706 m
.56233 .427 L
s
.56233 .427 m
.56238 .42658 L
s
.56233 .427 m
.56196 .42678 L
s
1 .002 0 r
.30216 .36137 m
.30217 .36137 L
s
.30218 .36136 m
.30216 .36137 L
s
.30216 .36137 m
.30217 .36136 L
s
.30218 .36137 m
.30216 .36137 L
s
.30222 .36134 m
.30216 .36137 L
s
.30217 .36137 m
.30218 .36137 L
s
.30218 .36137 m
.30218 .36136 L
s
.30218 .36136 m
.30217 .36136 L
s
.30217 .36136 m
.30217 .36137 L
s
1 0 0 r
.63196 .2629 m
.63196 .2629 L
s
.63196 .26289 m
.63196 .2629 L
s
.63196 .2629 m
.63196 .2629 L
s
.63196 .26289 m
.63196 .26289 L
s
.63196 .26289 m
.63196 .2629 L
s
.63196 .2629 m
.63196 .2629 L
s
.63196 .26289 m
.63196 .2629 L
s
.63195 .26289 m
.63196 .2629 L
s
.63196 .2629 m
.63196 .26289 L
s
1 .038 0 r
.82591 .4926 m
.82501 .49177 L
s
1 .046 0 r
.56407 .42697 m
.56196 .42678 L
s
.56238 .42658 m
.56243 .42663 L
s
.56238 .42658 m
.56196 .42678 L
s
.56196 .42678 m
.56238 .42706 L
s
.56196 .42678 m
.56243 .42663 L
s
.56243 .42663 m
.56238 .42706 L
s
1 .158 0 r
.34737 .52489 m
.34804 .52623 L
s
1 .038 0 r
.82517 .49173 m
.82541 .49185 L
s
.82497 .49202 m
.82517 .49173 L
s
.82517 .49173 m
.82501 .49177 L
s
.82521 .49214 m
.82497 .49202 L
s
.82497 .49202 m
.82501 .49177 L
s
1 .023 0 r
.16187 .49201 m
.16195 .49202 L
s
.16198 .49177 m
.16187 .49201 L
s
.16187 .49201 m
.16182 .49185 L
s
.16211 .49194 m
.16187 .49201 L
s
.16234 .49145 m
.16187 .49201 L
s
.16198 .49177 m
.16182 .49185 L
s
.16211 .49194 m
.16198 .49177 L
s
.16195 .49202 m
.16211 .49194 L
s
.16182 .49185 m
.16195 .49202 L
s
1 .038 0 r
.82541 .49185 m
.82521 .49214 L
s
.82501 .49177 m
.82541 .49185 L
s
.82501 .49177 m
.82521 .49214 L
s
1 .022 0 r
.62889 .0648 m
.62893 .0648 L
s
.62892 .06459 m
.62889 .0648 L
s
.62912 .06473 m
.62889 .0648 L
s
.62896 .06459 m
.62892 .06459 L
s
.62892 .06459 m
.62912 .06473 L
s
.62912 .06473 m
.62893 .0648 L
s
.62896 .06459 m
.62912 .06473 L
s
.62814 .06457 m
.62912 .06473 L
s
1 .016 0 r
.49169 .39307 m
.4917 .39305 L
s
.4917 .39305 m
.49169 .3929 L
s
.4917 .39305 m
.49154 .393 L
s
.49169 .3929 m
.49167 .39292 L
s
.49169 .3929 m
.49154 .393 L
s
.49154 .393 m
.49169 .39307 L
s
.49154 .393 m
.49167 .39292 L
s
.49228 .39294 m
.49154 .393 L
s
1 .022 0 r
.62893 .0648 m
.62896 .06459 L
s
1 .002 0 r
.56027 .22877 m
.56027 .22877 L
s
.56027 .22875 m
.56027 .22877 L
s
.56029 .22876 m
.56027 .22877 L
s
.56027 .22875 m
.56027 .22875 L
s
.56027 .22875 m
.56029 .22876 L
s
.56029 .22876 m
.56027 .22877 L
s
.56027 .22875 m
.56029 .22876 L
s
.56021 .22876 m
.56029 .22876 L
s
1 .035 0 r
.7543 .45862 m
.75319 .45794 L
s
1 .002 0 r
.56027 .22877 m
.56027 .22875 L
s
1 .016 0 r
.49167 .39292 m
.49169 .39307 L
s
1 .035 0 r
.7534 .45789 m
.75358 .45797 L
s
.75324 .45818 m
.7534 .45789 L
s
.7534 .45789 m
.75319 .45794 L
s
.75342 .45826 m
.75324 .45818 L
s
.75324 .45818 m
.75319 .45794 L
s
.75358 .45797 m
.75342 .45826 L
s
.75319 .45794 m
.75358 .45797 L
s
.75319 .45794 m
.75342 .45826 L
s
1 .293 0 r
.46021 .52408 m
.46077 .52359 L
s
.46077 .52359 m
.46027 .5209 L
s
.46077 .52359 m
.4576 .52289 L
s
.46027 .5209 m
.45971 .52138 L
s
.46027 .5209 m
.4576 .52289 L
s
1 .003 0 r
.42029 .35891 m
.4203 .3589 L
s
.4203 .3589 m
.42029 .35887 L
s
.4203 .3589 m
.42026 .3589 L
s
.42029 .35887 m
.42028 .35888 L
s
.42029 .35887 m
.42026 .3589 L
s
.42026 .3589 m
.42029 .35891 L
s
.42026 .3589 m
.42028 .35888 L
s
.4204 .35887 m
.42026 .3589 L
s
.42028 .35888 m
.42029 .35891 L
s
1 .004 0 r
.48854 .19458 m
.48853 .19458 L
s
.48853 .19454 m
.48854 .19458 L
s
.48857 .19456 m
.48854 .19458 L
s
.48853 .19454 m
.48853 .19454 L
s
.48853 .19454 m
.48857 .19456 L
s
1 0 0 r
.75057 .26029 m
.75057 .26029 L
s
.75057 .26029 m
.75057 .26029 L
s
.75057 .26029 m
.75057 .26029 L
s
.75057 .26029 m
.75057 .26029 L
s
.75057 .26029 m
.75057 .26029 L
s
.75057 .26029 m
.75057 .26029 L
s
.75056 .26029 m
.75057 .26029 L
s
.75057 .26029 m
.75057 .26029 L
s
.75057 .26029 m
.75057 .26029 L
s
1 .026 0 r
.68259 .42458 m
.68157 .4242 L
s
1 .004 0 r
.48838 .19457 m
.48857 .19456 L
s
.48857 .19456 m
.48853 .19458 L
s
.48853 .19454 m
.48857 .19456 L
s
.48853 .19458 m
.48853 .19454 L
s
1 .055 0 r
.27879 .49027 m
.27909 .49035 L
s
.27913 .48975 m
.27879 .49027 L
s
.27879 .49027 m
.27882 .4899 L
s
.2794 .4902 m
.27879 .49027 L
s
.2804 .48915 m
.27879 .49027 L
s
.27913 .48975 m
.27882 .4899 L
s
.2794 .4902 m
.27913 .48975 L
s
.27909 .49035 m
.2794 .4902 L
s
1 .026 0 r
.68178 .42442 m
.68168 .42437 L
s
.68168 .42437 m
.68177 .42414 L
s
.68168 .42437 m
.68157 .4242 L
s
.68177 .42414 m
.68187 .42419 L
s
.68177 .42414 m
.68157 .4242 L
s
1 .293 0 r
.4576 .52289 m
.46021 .52408 L
s
.4576 .52289 m
.45971 .52138 L
s
.47082 .5209 m
.4576 .52289 L
s
1 .026 0 r
.68157 .4242 m
.68178 .42442 L
s
.68157 .4242 m
.68187 .42419 L
s
.68187 .42419 m
.68178 .42442 L
s
1 .055 0 r
.27882 .4899 m
.27909 .49035 L
s
1 .001 0 r
.67884 .22612 m
.67885 .22612 L
s
.67885 .22611 m
.67884 .22612 L
s
.67886 .22612 m
.67884 .22612 L
s
.67885 .22611 m
.67885 .22611 L
s
.67885 .22611 m
.67886 .22612 L
s
.67886 .22612 m
.67885 .22612 L
s
.67885 .22611 m
.67886 .22612 L
s
.67881 .2261 m
.67886 .22612 L
s
.67885 .22612 m
.67885 .22611 L
s
1 0 0 r
.34842 .32475 m
.34842 .32475 L
s
.34842 .32475 m
.34842 .32475 L
s
.34842 .32475 m
.34841 .32475 L
s
.34842 .32475 m
.34842 .32475 L
s
.34842 .32475 m
.34841 .32475 L
s
.34841 .32475 m
.34842 .32475 L
s
.34841 .32475 m
.34842 .32475 L
s
.34842 .32475 m
.34841 .32475 L
s
.34842 .32475 m
.34842 .32475 L
s
1 .013 0 r
.61079 .39051 m
.6102 .3904 L
s
.61032 .39049 m
.61029 .39047 L
s
.61029 .39047 m
.61031 .39035 L
s
.61029 .39047 m
.6102 .3904 L
s
.61031 .39035 m
.61034 .39036 L
s
.61031 .39035 m
.6102 .3904 L
s
.6102 .3904 m
.61032 .39049 L
s
.6102 .3904 m
.61034 .39036 L
s
.61034 .39036 m
.61032 .39049 L
s
1 .293 0 r
.45971 .52138 m
.46021 .52408 L
s
1 .121 0 r
.39485 .48878 m
.39529 .48855 L
s
.39529 .48855 m
.3949 .48747 L
s
.39529 .48855 m
.3939 .48845 L
s
.3949 .48747 m
.39446 .4877 L
s
.3949 .48747 m
.3939 .48845 L
s
.3939 .48845 m
.39485 .48878 L
s
.3939 .48845 m
.39446 .4877 L
s
.39879 .48684 m
.3939 .48845 L
s
1 .018 0 r
.20784 .45549 m
.20792 .4555 L
s
.20794 .45531 m
.20784 .45549 L
s
.20784 .45549 m
.20783 .45536 L
s
.20803 .45545 m
.20784 .45549 L
s
.20829 .45509 m
.20784 .45549 L
s
.20794 .45531 m
.20783 .45536 L
s
.20803 .45545 m
.20794 .45531 L
s
.20792 .4555 m
.20803 .45545 L
s
.20783 .45536 m
.20792 .4555 L
s
1 .004 0 r
.60709 .19191 m
.60709 .19191 L
s
.60709 .19187 m
.60709 .19191 L
s
.60713 .1919 m
.60709 .19191 L
s
.6071 .19187 m
.60709 .19187 L
s
.60709 .19187 m
.60713 .1919 L
s
.60713 .1919 m
.60709 .19191 L
s
.6071 .19187 m
.60713 .1919 L
s
.60695 .19187 m
.60713 .1919 L
s
.53875 .3564 m
.53875 .3564 L
s
.53875 .3564 m
.53875 .35636 L
s
.53875 .3564 m
.53872 .35638 L
s
.53875 .35636 m
.53875 .35637 L
s
.53875 .35636 m
.53872 .35638 L
s
.60709 .19191 m
.6071 .19187 L
s
1 .011 0 r
.80143 .42219 m
.80109 .42196 L
s
1 .004 0 r
.53889 .35638 m
.53872 .35638 L
s
.53872 .35638 m
.53875 .3564 L
s
.53872 .35638 m
.53875 .35637 L
s
.53875 .35637 m
.53875 .3564 L
s
1 .011 0 r
.80115 .42194 m
.80122 .42197 L
s
.8011 .42203 m
.80115 .42194 L
s
.80115 .42194 m
.80109 .42196 L
s
.80116 .42206 m
.8011 .42203 L
s
.8011 .42203 m
.80109 .42196 L
s
.80122 .42197 m
.80116 .42206 L
s
.80109 .42196 m
.80122 .42197 L
s
.80109 .42196 m
.80116 .42206 L
s
1 .121 0 r
.39446 .4877 m
.39485 .48878 L
s
1 .008 0 r
.53529 .15764 m
.5353 .15764 L
s
.5353 .15756 m
.53529 .15764 L
s
.53537 .1576 m
.53529 .15764 L
s
.5353 .15756 m
.5353 .15756 L
s
.5353 .15756 m
.53537 .1576 L
s
.53537 .1576 m
.5353 .15764 L
s
.5353 .15756 m
.53537 .1576 L
s
.53501 .1576 m
.53537 .1576 L
s
1 0 0 r
.46688 .32222 m
.46688 .32222 L
s
.46688 .32222 m
.46688 .32222 L
s
.46688 .32222 m
.46688 .32222 L
s
.46688 .32222 m
.46688 .32222 L
s
.46688 .32222 m
.46688 .32222 L
s
.46688 .32222 m
.46688 .32222 L
s
.46688 .32222 m
.46688 .32222 L
s
.4669 .32222 m
.46688 .32222 L
s
.46688 .32222 m
.46688 .32222 L
s
1 .007 0 r
.72961 .38807 m
.72935 .38795 L
s
1 .008 0 r
.5353 .15764 m
.5353 .15756 L
s
1 .007 0 r
.72941 .38801 m
.72938 .388 L
s
.72938 .388 m
.7294 .38794 L
s
.72938 .388 m
.72935 .38795 L
s
.7294 .38794 m
.72943 .38795 L
s
.7294 .38794 m
.72935 .38795 L
s
.72943 .38795 m
.72941 .38801 L
s
.72935 .38795 m
.72941 .38801 L
s
.72935 .38795 m
.72943 .38795 L
s
1 .04 0 r
.32524 .45344 m
.32551 .45351 L
s
.32553 .45308 m
.32524 .45344 L
s
.32524 .45344 m
.32534 .45317 L
s
.3257 .45343 m
.32524 .45344 L
s
.32665 .45274 m
.32524 .45344 L
s
.32551 .45351 m
.3257 .45343 L
s
.3257 .45343 m
.32553 .45308 L
s
.32553 .45308 m
.32534 .45317 L
s
.32534 .45317 m
.32551 .45351 L
s
1 .003 0 r
.72592 .18921 m
.72593 .18921 L
s
.72593 .18918 m
.72592 .18921 L
s
.72596 .1892 m
.72592 .18921 L
s
.72594 .18918 m
.72593 .18918 L
s
.72593 .18918 m
.72596 .1892 L
s
.72596 .1892 m
.72593 .18921 L
s
.72594 .18918 m
.72596 .1892 L
s
.72585 .18917 m
.72596 .1892 L
s
.72593 .18921 m
.72594 .18918 L
s
1 .271 0 r
.58954 .51863 m
.57742 .51651 L
s
1 .003 0 r
.65769 .3539 m
.65758 .35387 L
s
1 0 0 r
.39481 .288 m
.39481 .288 L
s
1 .003 0 r
.65761 .35389 m
.6576 .35388 L
s
.6576 .35388 m
.65761 .35386 L
s
.6576 .35388 m
.65758 .35387 L
s
.65761 .35386 m
.65761 .35386 L
s
.65761 .35386 m
.65758 .35387 L
s
.65758 .35387 m
.65761 .35389 L
s
.65758 .35387 m
.65761 .35386 L
s
.65761 .35386 m
.65761 .35389 L
s
1 .172 0 r
.51101 .48558 m
.51105 .48534 L
s
.51105 .48534 m
.51101 .48372 L
s
.51105 .48534 m
.50939 .48468 L
s
.51101 .48372 m
.51097 .48396 L
s
.51101 .48372 m
.50939 .48468 L
s
1 .271 0 r
.57987 .51841 m
.57929 .51795 L
s
.57929 .51795 m
.57982 .51546 L
s
.57929 .51795 m
.57742 .51651 L
s
.57982 .51546 m
.58039 .51592 L
s
.57982 .51546 m
.57742 .51651 L
s
1 .011 0 r
.25407 .41882 m
.25414 .41883 L
s
.25415 .41871 m
.25407 .41882 L
s
.25407 .41882 m
.25408 .41874 L
s
.2542 .41881 m
.25407 .41882 L
s
.25442 .41859 m
.25407 .41882 L
s
.25415 .41871 m
.25408 .41874 L
s
.2542 .41881 m
.25415 .41871 L
s
.25414 .41883 m
.2542 .41881 L
s
1 .172 0 r
.50939 .48468 m
.51101 .48558 L
s
.50939 .48468 m
.51097 .48396 L
s
.51748 .48452 m
.50939 .48468 L
s
1 .011 0 r
.25408 .41874 m
.25414 .41883 L
s
1 .006 0 r
.65409 .15492 m
.65411 .15492 L
s
.65411 .15486 m
.65409 .15492 L
s
.65417 .1549 m
.65409 .15492 L
s
.65412 .15486 m
.65411 .15486 L
s
.65411 .15486 m
.65417 .1549 L
s
.65417 .1549 m
.65411 .15492 L
s
.65412 .15486 m
.65417 .1549 L
s
.65388 .15484 m
.65417 .1549 L
s
.65411 .15492 m
.65412 .15486 L
s
1 0 0 r
.58568 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
.58567 .31968 m
.58567 .31968 L
s
1 .172 0 r
.51097 .48396 m
.51101 .48558 L
s
1 .075 0 r
.44266 .45127 m
.44283 .45116 L
s
.44283 .45116 m
.44268 .45048 L
s
.44283 .45116 m
.44201 .451 L
s
.44268 .45048 m
.44251 .45058 L
s
.44268 .45048 m
.44201 .451 L
s
.44201 .451 m
.44266 .45127 L
s
.44201 .451 m
.44251 .45058 L
s
.44533 .45037 m
.44201 .451 L
s
.44251 .45058 m
.44266 .45127 L
s
1 .271 0 r
.57742 .51651 m
.57987 .51841 L
s
.57742 .51651 m
.58039 .51592 L
s
1 .011 0 r
.58223 .12056 m
.58224 .12056 L
s
.58224 .12046 m
.58223 .12056 L
s
.58235 .12052 m
.58223 .12056 L
s
.58225 .12046 m
.58224 .12046 L
s
.58224 .12046 m
.58235 .12052 L
s
.58235 .12052 m
.58224 .12056 L
s
.58225 .12046 m
.58235 .12052 L
s
.58182 .12047 m
.58235 .12052 L
s
1 .001 0 r
.77681 .3514 m
.77677 .35138 L
s
1 .134 0 r
.70857 .51635 m
.70397 .514 L
s
1 0 0 r
.51358 .28542 m
.51358 .28542 L
s
1 .011 0 r
.58224 .12056 m
.58225 .12046 L
s
1 .001 0 r
.77678 .35139 m
.77677 .35139 L
s
.77677 .35139 m
.77678 .35138 L
s
.77677 .35139 m
.77677 .35138 L
s
.77678 .35138 m
.77678 .35138 L
s
.77678 .35138 m
.77677 .35138 L
s
.77678 .35138 m
.77678 .35139 L
s
.77677 .35138 m
.77678 .35139 L
s
.77677 .35138 m
.77678 .35138 L
s
1 .271 0 r
.58039 .51592 m
.57987 .51841 L
s
1 .023 0 r
.37232 .41656 m
.37241 .41652 L
s
.37241 .41652 m
.37233 .41631 L
s
.37241 .41652 m
.37214 .4165 L
s
.37233 .41631 m
.37225 .41635 L
s
.37233 .41631 m
.37214 .4165 L
s
.37214 .4165 m
.37232 .41656 L
s
.37214 .4165 m
.37225 .41635 L
s
.37308 .41618 m
.37214 .4165 L
s
.37225 .41635 m
.37232 .41656 L
s
1 .121 0 r
.63649 .4822 m
.63139 .48078 L
s
1 0 0 r
.70479 .31714 m
.70478 .31714 L
s
.44137 .25112 m
.44138 .25112 L
s
.44138 .25112 m
.44138 .25112 L
s
.44138 .25112 m
.44138 .25112 L
s
.44138 .25112 m
.44138 .25112 L
s
.44138 .25112 m
.44138 .25112 L
s
.44138 .25112 m
.44138 .25112 L
s
.44138 .25112 m
.44138 .25112 L
s
.44138 .25112 m
.44138 .25112 L
s
.70478 .31714 m
.70478 .31714 L
s
.70478 .31714 m
.70478 .31714 L
s
.70478 .31714 m
.70478 .31714 L
s
.44138 .25112 m
.44138 .25112 L
s
.70478 .31714 m
.70478 .31714 L
s
.70478 .31714 m
.70478 .31714 L
s
.70478 .31714 m
.70478 .31714 L
s
.70478 .31714 m
.70478 .31714 L
s
.70478 .31714 m
.70478 .31714 L
s
1 .134 0 r
.70493 .5152 m
.70427 .51487 L
s
.70427 .51487 m
.70485 .51374 L
s
.70427 .51487 m
.70397 .514 L
s
.70485 .51374 m
.70551 .51406 L
s
.70485 .51374 m
.70397 .514 L
s
1 .121 0 r
.63243 .48172 m
.63204 .48151 L
s
.63204 .48151 m
.63239 .48041 L
s
.63204 .48151 m
.63139 .48078 L
s
.63239 .48041 m
.63278 .48062 L
s
.63239 .48041 m
.63139 .48078 L
s
1 .009 0 r
.70127 .11779 m
.7013 .11779 L
s
.70129 .11771 m
.70127 .11779 L
s
.70137 .11777 m
.70127 .11779 L
s
.70132 .11771 m
.70129 .11771 L
s
.70129 .11771 m
.70137 .11777 L
s
1 .006 0 r
.30054 .38204 m
.30058 .38204 L
s
.30058 .38199 m
.30054 .38204 L
s
.30054 .38204 m
.30055 .382 L
s
.3006 .38203 m
.30054 .38204 L
s
.30074 .38194 m
.30054 .38204 L
s
.30058 .38204 m
.3006 .38203 L
s
.3006 .38203 m
.30058 .38199 L
s
.30058 .38199 m
.30055 .382 L
s
1 .009 0 r
.70137 .11777 m
.7013 .11779 L
s
.70132 .11771 m
.70137 .11777 L
s
.701 .11766 m
.70137 .11777 L
s
1 .006 0 r
.30055 .382 m
.30058 .38204 L
s
1 .08 0 r
.56137 .44816 m
.56128 .44806 L
s
.56128 .44806 m
.56136 .44731 L
s
.56128 .44806 m
.56062 .44767 L
s
1 .009 0 r
.7013 .11779 m
.70132 .11771 L
s
1 .134 0 r
.70551 .51406 m
.70493 .5152 L
s
.70397 .514 m
.70493 .5152 L
s
1 .055 0 r
.82791 .51407 m
.82658 .51285 L
s
1 .08 0 r
.56433 .448 m
.56062 .44767 L
s
1 0 0 r
.63266 .28283 m
.63266 .28283 L
s
1 .134 0 r
.70397 .514 m
.70551 .51406 L
s
1 .08 0 r
.56136 .44731 m
.56145 .44741 L
s
.56136 .44731 m
.56062 .44767 L
s
1 .121 0 r
.63139 .48078 m
.63243 .48172 L
s
.63139 .48078 m
.63278 .48062 L
s
1 .08 0 r
.56062 .44767 m
.56137 .44816 L
s
.56062 .44767 m
.56145 .44741 L
s
1 .121 0 r
.63278 .48062 m
.63243 .48172 L
s
1 .035 0 r
.15922 .51375 m
.15934 .51377 L
s
.15938 .51339 m
.15922 .51375 L
s
.15922 .51375 m
.15915 .51351 L
s
.15958 .51366 m
.15922 .51375 L
s
.15992 .51293 m
.15922 .51375 L
s
.15938 .51339 m
.15915 .51351 L
s
.15958 .51366 m
.15938 .51339 L
s
.15934 .51377 m
.15958 .51366 L
s
1 .08 0 r
.56145 .44741 m
.56137 .44816 L
s
1 .035 0 r
.15915 .51351 m
.15934 .51377 L
s
1 .055 0 r
.82682 .5128 m
.82717 .51297 L
s
.82653 .51323 m
.82682 .5128 L
s
.82682 .5128 m
.82658 .51285 L
s
.82688 .5134 m
.82653 .51323 L
s
.82653 .51323 m
.82658 .51285 L
s
1 .035 0 r
.49075 .41404 m
.49079 .414 L
s
.49079 .414 m
.49076 .41367 L
s
.49079 .414 m
.49043 .41388 L
s
.49076 .41367 m
.49073 .41371 L
s
.49076 .41367 m
.49043 .41388 L
s
1 .014 0 r
.62933 .08335 m
.62935 .08335 L
s
.62935 .08322 m
.62933 .08335 L
s
.62948 .0833 m
.62933 .08335 L
s
1 .035 0 r
.49043 .41388 m
.49075 .41404 L
s
.49043 .41388 m
.49073 .41371 L
s
.49206 .41376 m
.49043 .41388 L
s
1 .014 0 r
.62937 .08322 m
.62935 .08322 L
s
.62935 .08322 m
.62948 .0833 L
s
.62948 .0833 m
.62935 .08335 L
s
.62937 .08322 m
.62948 .0833 L
s
.62883 .0832 m
.62948 .0833 L
s
1 .055 0 r
.82717 .51297 m
.82688 .5134 L
s
.82658 .51285 m
.82717 .51297 L
s
1 .014 0 r
.62935 .08335 m
.62937 .08322 L
s
1 .055 0 r
.82658 .51285 m
.82688 .5134 L
s
1 0 0 r
.56045 .24848 m
.56045 .24848 L
s
.56045 .24848 m
.56045 .24848 L
s
.56045 .24848 m
.56045 .24848 L
s
.56045 .24848 m
.56045 .24848 L
s
.56045 .24848 m
.56045 .24848 L
s
.56045 .24848 m
.56045 .24848 L
s
.56045 .24848 m
.56045 .24848 L
s
.56044 .24848 m
.56045 .24848 L
s
1 .055 0 r
.75582 .47987 m
.75405 .47881 L
s
1 0 0 r
.56045 .24848 m
.56045 .24848 L
s
1 .035 0 r
.49073 .41371 m
.49075 .41404 L
s
1 .055 0 r
.75439 .47872 m
.75469 .47886 L
s
.75413 .47918 m
.75439 .47872 L
s
.75439 .47872 m
.75405 .47881 L
s
.75443 .47932 m
.75413 .47918 L
s
.75413 .47918 m
.75405 .47881 L
s
1 .08 0 r
.27642 .51225 m
.27686 .51237 L
s
.27693 .51149 m
.27642 .51225 L
s
.27642 .51225 m
.27647 .51171 L
s
.27732 .51214 m
.27642 .51225 L
s
.27877 .51064 m
.27642 .51225 L
s
.27693 .51149 m
.27647 .51171 L
s
.27732 .51214 m
.27693 .51149 L
s
.27686 .51237 m
.27732 .51214 L
s
1 .055 0 r
.75469 .47886 m
.75443 .47932 L
s
.75405 .47881 m
.75469 .47886 L
s
.75405 .47881 m
.75443 .47932 L
s
1 .01 0 r
.41934 .3796 m
.41937 .37959 L
s
.41937 .37959 m
.41935 .3795 L
s
.41937 .37959 m
.41926 .37957 L
s
.41935 .3795 m
.41932 .37951 L
s
.41935 .3795 m
.41926 .37957 L
s
.41926 .37957 m
.41934 .3796 L
s
.41926 .37957 m
.41932 .37951 L
s
.4197 .37947 m
.41926 .37957 L
s
.41932 .37951 m
.41934 .3796 L
s
1 .001 0 r
.48818 .21408 m
.48818 .21409 L
s
.48818 .21407 m
.48818 .21408 L
s
.48819 .21408 m
.48818 .21408 L
s
.48818 .21407 m
.48818 .21407 L
s
.48818 .21407 m
.48819 .21408 L
s
1 .047 0 r
.68364 .44563 m
.6818 .44495 L
s
1 0 0 r
.75207 .28024 m
.75207 .28024 L
s
1 .001 0 r
.48813 .21408 m
.48819 .21408 L
s
.48819 .21408 m
.48818 .21409 L
s
.48818 .21407 m
.48819 .21408 L
s
.48818 .21409 m
.48818 .21407 L
s
1 .08 0 r
.27647 .51171 m
.27686 .51237 L
s
1 .047 0 r
.68218 .44533 m
.68199 .44525 L
s
.68199 .44525 m
.68216 .44483 L
s
.68199 .44525 m
.6818 .44495 L
s
.68216 .44483 m
.68234 .44492 L
s
.68216 .44483 m
.6818 .44495 L
s
.6818 .44495 m
.68218 .44533 L
s
.6818 .44495 m
.68234 .44492 L
s
.68234 .44492 m
.68218 .44533 L
s
1 .168 0 r
.39245 .51103 m
.39308 .5107 L
s
.39308 .5107 m
.39253 .5092 L
s
.39308 .5107 m
.39113 .51056 L
s
1 .002 0 r
.34719 .34517 m
.34719 .34517 L
s
.34719 .34517 m
.34719 .34515 L
s
.34719 .34517 m
.34717 .34516 L
s
.34719 .34515 m
.34718 .34515 L
s
.34719 .34515 m
.34717 .34516 L
s
.34717 .34516 m
.34719 .34517 L
s
.34717 .34516 m
.34718 .34515 L
s
.34724 .34514 m
.34717 .34516 L
s
.34718 .34515 m
.34719 .34517 L
s
1 0 0 r
.67984 .24584 m
.67984 .24584 L
s
.67984 .24584 m
.67984 .24584 L
s
.67984 .24584 m
.67984 .24584 L
s
.67984 .24584 m
.67984 .24584 L
s
.67984 .24584 m
.67984 .24584 L
s
.67984 .24584 m
.67984 .24584 L
s
.67984 .24584 m
.67984 .24584 L
s
.67983 .24584 m
.67984 .24584 L
s
.67984 .24584 m
.67984 .24584 L
s
1 .029 0 r
.61136 .41134 m
.61005 .41109 L
s
1 .168 0 r
.39253 .5092 m
.39191 .50953 L
s
.39253 .5092 m
.39113 .51056 L
s
1 .029 0 r
.61031 .4113 m
.61025 .41126 L
s
.61025 .41126 m
.61031 .41099 L
s
.61025 .41126 m
.61005 .41109 L
s
1 .168 0 r
.39113 .51056 m
.39245 .51103 L
s
.39113 .51056 m
.39191 .50953 L
s
.39794 .50834 m
.39113 .51056 L
s
1 .029 0 r
.61031 .41099 m
.61037 .41103 L
s
.61031 .41099 m
.61005 .41109 L
s
.61005 .41109 m
.61031 .4113 L
s
.61005 .41109 m
.61037 .41103 L
s
.61037 .41103 m
.61031 .4113 L
s
.20544 .47701 m
.20557 .47703 L
s
.2056 .47672 m
.20544 .47701 L
s
.20544 .47701 m
.20542 .47681 L
s
.20575 .47695 m
.20544 .47701 L
s
.20617 .47637 m
.20544 .47701 L
s
.2056 .47672 m
.20542 .47681 L
s
.20575 .47695 m
.2056 .47672 L
s
.20557 .47703 m
.20575 .47695 L
s
.20542 .47681 m
.20557 .47703 L
s
1 .017 0 r
.67658 .04599 m
.67662 .04599 L
s
.67661 .04584 m
.67658 .04599 L
s
.67676 .04595 m
.67658 .04599 L
s
.67665 .04583 m
.67661 .04584 L
s
.67661 .04584 m
.67676 .04595 L
s
1 .168 0 r
.39191 .50953 m
.39245 .51103 L
s
1 .017 0 r
.67676 .04595 m
.67662 .04599 L
s
.67665 .04583 m
.67676 .04595 L
s
.67602 .04578 m
.67676 .04595 L
s
.67662 .04599 m
.67665 .04583 L
s
1 .012 0 r
.53853 .37705 m
.53853 .37704 L
s
.53853 .37704 m
.53853 .37693 L
s
.53853 .37704 m
.53842 .37699 L
s
.53853 .37693 m
.53854 .37694 L
s
.53853 .37693 m
.53842 .37699 L
s
1 .001 0 r
.60754 .2114 m
.60754 .2114 L
s
.60754 .21139 m
.60754 .2114 L
s
.60755 .2114 m
.60754 .2114 L
s
.60754 .21139 m
.60754 .21139 L
s
.60754 .21139 m
.60755 .2114 L
s
.60755 .2114 m
.60754 .2114 L
s
.60754 .21139 m
.60755 .2114 L
s
.6075 .21139 m
.60755 .2114 L
s
.60754 .2114 m
.60754 .21139 L
s
1 .021 0 r
.80327 .44325 m
.80264 .44282 L
s
1 .012 0 r
.53898 .377 m
.53842 .37699 L
s
.53842 .37699 m
.53853 .37705 L
s
.53842 .37699 m
.53854 .37694 L
s
.53854 .37694 m
.53853 .37705 L
s
1 .021 0 r
.80276 .44279 m
.80288 .44284 L
s
.80266 .44296 m
.80276 .44279 L
s
.80276 .44279 m
.80264 .44282 L
s
.80278 .44301 m
.80266 .44296 L
s
.80266 .44296 m
.80264 .44282 L
s
.80288 .44284 m
.80278 .44301 L
s
.80264 .44282 m
.80288 .44284 L
s
.80264 .44282 m
.80278 .44301 L
s
1 .003 0 r
.46641 .34265 m
.46641 .34264 L
s
.46641 .34264 m
.46641 .34262 L
s
.46641 .34264 m
.46638 .34263 L
s
.46641 .34262 m
.4664 .34262 L
s
.46641 .34262 m
.46638 .34263 L
s
.5352 .17692 m
.5352 .17692 L
s
.5352 .17688 m
.5352 .17692 L
s
.53523 .1769 m
.5352 .17692 L
s
.46638 .34263 m
.46641 .34265 L
s
.46638 .34263 m
.4664 .34262 L
s
.46651 .34262 m
.46638 .34263 L
s
.5352 .17688 m
.5352 .17688 L
s
.5352 .17688 m
.53523 .1769 L
s
.4664 .34262 m
.46641 .34265 L
s
.53523 .1769 m
.5352 .17692 L
s
.5352 .17688 m
.53523 .1769 L
s
.53507 .1769 m
.53523 .1769 L
s
1 .015 0 r
.73097 .40891 m
.7304 .40865 L
s
1 .003 0 r
.5352 .17692 m
.5352 .17688 L
s
1 .063 0 r
.32309 .47513 m
.32351 .47525 L
s
.32355 .47456 m
.32309 .47513 L
s
.32309 .47513 m
.32325 .4747 L
s
.32382 .47511 m
.32309 .47513 L
s
.32532 .47402 m
.32309 .47513 L
s
.32351 .47525 m
.32382 .47511 L
s
.32382 .47511 m
.32355 .47456 L
s
.32355 .47456 m
.32325 .4747 L
s
1 .015 0 r
.73052 .40878 m
.73045 .40875 L
s
.73045 .40875 m
.73051 .40862 L
s
.73045 .40875 m
.7304 .40865 L
s
.73051 .40862 m
.73058 .40865 L
s
.73051 .40862 m
.7304 .40865 L
s
.73058 .40865 m
.73052 .40878 L
s
.7304 .40865 m
.73052 .40878 L
s
.7304 .40865 m
.73058 .40865 L
s
1 .063 0 r
.32325 .4747 m
.32351 .47525 L
s
1 .001 0 r
.72721 .20871 m
.72722 .20871 L
s
.72721 .2087 m
.72721 .20871 L
s
.72722 .2087 m
.72721 .20871 L
s
.72722 .2087 m
.72721 .2087 L
s
.72721 .2087 m
.72722 .2087 L
s
.72722 .2087 m
.72722 .20871 L
s
.72722 .2087 m
.72722 .2087 L
s
.72719 .20869 m
.72722 .2087 L
s
.72722 .20871 m
.72722 .2087 L
s
1 0 0 r
.39393 .3082 m
.39393 .3082 L
s
.39393 .3082 m
.39393 .30819 L
s
.39393 .3082 m
.39392 .30819 L
s
.39393 .30819 m
.39393 .30819 L
s
.39393 .30819 m
.39392 .30819 L
s
.39392 .30819 m
.39393 .3082 L
s
.39392 .30819 m
.39393 .30819 L
s
.39393 .30819 m
.39392 .30819 L
s
.39393 .30819 m
.39393 .3082 L
s
1 .008 0 r
.65858 .37453 m
.65822 .37443 L
s
.6583 .37449 m
.65827 .37448 L
s
.65827 .37448 m
.65829 .37441 L
s
.65827 .37448 m
.65822 .37443 L
s
.65829 .37441 m
.65832 .37442 L
s
.65829 .37441 m
.65822 .37443 L
s
1 .233 0 r
.5086 .50748 m
.50867 .50713 L
s
.50867 .50713 m
.50861 .50493 L
s
.50867 .50713 m
.5064 .50625 L
s
1 .008 0 r
.65822 .37443 m
.6583 .37449 L
s
.65822 .37443 m
.65832 .37442 L
s
.65832 .37442 m
.6583 .37449 L
s
1 .233 0 r
.50861 .50493 m
.50855 .50528 L
s
.50861 .50493 m
.5064 .50625 L
s
1 .021 0 r
.25197 .44009 m
.25208 .44011 L
s
.2521 .43989 m
.25197 .44009 L
s
.25197 .44009 m
.25199 .43994 L
s
.2522 .44006 m
.25197 .44009 L
s
.25261 .43966 m
.25197 .44009 L
s
.2521 .43989 m
.25199 .43994 L
s
.2522 .44006 m
.2521 .43989 L
s
.25208 .44011 m
.2522 .44006 L
s
.25199 .43994 m
.25208 .44011 L
s
1 .233 0 r
.5064 .50625 m
.5086 .50748 L
s
.5064 .50625 m
.50855 .50528 L
s
.51743 .50604 m
.5064 .50625 L
s
1 .003 0 r
.65484 .17419 m
.65484 .17419 L
s
.65484 .17416 m
.65484 .17419 L
s
.65487 .17418 m
.65484 .17419 L
s
1 .114 0 r
.44069 .47305 m
.44096 .47288 L
s
.44096 .47288 m
.44072 .47182 L
s
.44096 .47288 m
.43969 .47263 L
s
1 .003 0 r
.65485 .17416 m
.65484 .17416 L
s
.65484 .17416 m
.65487 .17418 L
s
.65487 .17418 m
.65484 .17419 L
s
.65485 .17416 m
.65487 .17418 L
s
.65474 .17415 m
.65487 .17418 L
s
.65484 .17419 m
.65485 .17416 L
s
.58609 .3401 m
.58597 .34008 L
s
.58599 .3401 m
.58599 .3401 L
s
.58599 .3401 m
.58599 .34007 L
s
.58599 .3401 m
.58597 .34008 L
s
.58599 .34007 m
.58599 .34007 L
s
.58599 .34007 m
.58597 .34008 L
s
.58597 .34008 m
.58599 .3401 L
s
.58597 .34008 m
.58599 .34007 L
s
.58599 .34007 m
.58599 .3401 L
s
1 .114 0 r
.44072 .47182 m
.44046 .47199 L
s
.44072 .47182 m
.43969 .47263 L
s
.43969 .47263 m
.44069 .47305 L
s
.43969 .47263 m
.44046 .47199 L
s
.4448 .47167 m
.43969 .47263 L
s
1 .233 0 r
.50855 .50528 m
.5086 .50748 L
s
1 .114 0 r
.44046 .47199 m
.44069 .47305 L
s
1 .006 0 r
.58242 .13961 m
.58243 .13961 L
s
.58243 .13956 m
.58242 .13961 L
s
.58248 .13959 m
.58242 .13961 L
s
.58243 .13956 m
.58243 .13956 L
s
.58243 .13956 m
.58248 .13959 L
s
.58248 .13959 m
.58243 .13961 L
s
.58243 .13956 m
.58248 .13959 L
s
.5822 .13957 m
.58248 .13959 L
s
1 0 0 r
.51349 .30562 m
.51349 .30562 L
s
.51349 .30562 m
.51349 .30562 L
s
.51349 .30562 m
.51349 .30562 L
s
.51349 .30562 m
.51349 .30562 L
s
.51349 .30562 m
.51349 .30562 L
s
.51349 .30562 m
.51349 .30562 L
s
.51349 .30562 m
.51349 .30562 L
s
.5135 .30562 m
.51349 .30562 L
s
1 .004 0 r
.7785 .37204 m
.77835 .37196 L
s
1 0 0 r
.51349 .30562 m
.51349 .30562 L
s
1 .006 0 r
.58243 .13961 m
.58243 .13956 L
s
1 .004 0 r
.77838 .372 m
.77836 .37199 L
s
.77836 .37199 m
.77838 .37196 L
s
.77836 .37199 m
.77835 .37196 L
s
.77838 .37196 m
.7784 .37196 L
s
.77838 .37196 m
.77835 .37196 L
s
.7784 .37196 m
.77838 .372 L
s
.77835 .37196 m
.77838 .372 L
s
.77835 .37196 m
.7784 .37196 L
s
1 .042 0 r
.37069 .43796 m
.37085 .43788 L
s
.37085 .43788 m
.37071 .4375 L
s
.37085 .43788 m
.37035 .43785 L
s
.37071 .4375 m
.37055 .43758 L
s
.37071 .4375 m
.37035 .43785 L
s
.37035 .43785 m
.37069 .43796 L
s
.37035 .43785 m
.37055 .43758 L
s
.37206 .43726 m
.37035 .43785 L
s
.37055 .43758 m
.37069 .43796 L
s
1 .002 0 r
.70599 .33756 m
.70592 .33754 L
s
1 .168 0 r
.63724 .50373 m
.63012 .50177 L
s
1 0 0 r
.44081 .2711 m
.44081 .2711 L
s
1 .002 0 r
.70594 .33755 m
.70593 .33755 L
s
.70593 .33755 m
.70594 .33754 L
s
.70593 .33755 m
.70592 .33754 L
s
.70594 .33754 m
.70594 .33754 L
s
.70594 .33754 m
.70592 .33754 L
s
.70592 .33754 m
.70594 .33755 L
s
.70592 .33754 m
.70594 .33754 L
s
.70594 .33754 m
.70594 .33755 L
s
1 .013 0 r
.29878 .40303 m
.29887 .40305 L
s
.29888 .40292 m
.29878 .40303 L
s
.29878 .40303 m
.29881 .40294 L
s
.29893 .40303 m
.29878 .40303 L
s
.29924 .40281 m
.29878 .40303 L
s
.29887 .40305 m
.29893 .40303 L
s
.29893 .40303 m
.29888 .40292 L
s
.29888 .40292 m
.29881 .40294 L
s
1 .168 0 r
.63158 .50308 m
.63103 .50277 L
s
.63103 .50277 m
.63152 .50124 L
s
.63103 .50277 m
.63012 .50177 L
s
1 .013 0 r
.29881 .40294 m
.29887 .40305 L
s
1 .121 0 r
.56005 .46957 m
.55991 .4694 L
s
.55991 .4694 m
.56004 .46826 L
s
.55991 .4694 m
.55891 .46881 L
s
1 .168 0 r
.63152 .50124 m
.63206 .50155 L
s
.63152 .50124 m
.63012 .50177 L
s
1 .005 0 r
.70232 .13683 m
.70234 .13683 L
s
.70234 .13679 m
.70232 .13683 L
s
.70238 .13682 m
.70232 .13683 L
s
.70235 .13679 m
.70234 .13679 L
s
.70234 .13679 m
.70238 .13682 L
s
.70238 .13682 m
.70234 .13683 L
s
.70235 .13679 m
.70238 .13682 L
s
.70218 .13676 m
.70238 .13682 L
s
.70234 .13683 m
.70235 .13679 L
s
1 .121 0 r
.56459 .46932 m
.55891 .46881 L
s
1 0 0 r
.63338 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
.63337 .30304 m
.63337 .30304 L
s
1 .121 0 r
.56004 .46826 m
.56017 .46842 L
s
.56004 .46826 m
.55891 .46881 L
s
.55891 .46881 m
.56005 .46957 L
s
.55891 .46881 m
.56017 .46842 L
s
.56017 .46842 m
.56005 .46957 L
s
1 .062 0 r
.48951 .43536 m
.48957 .43528 L
s
.48957 .43528 m
.48952 .43469 L
s
.48957 .43528 m
.48893 .43507 L
s
1 .168 0 r
.63012 .50177 m
.63158 .50308 L
s
.63012 .50177 m
.63206 .50155 L
s
1 .062 0 r
.48952 .43469 m
.48946 .43477 L
s
.48952 .43469 m
.48893 .43507 L
s
1 .168 0 r
.63206 .50155 m
.63158 .50308 L
s
1 .062 0 r
.48893 .43507 m
.48951 .43536 L
s
.48893 .43507 m
.48946 .43477 L
s
.49184 .43486 m
.48893 .43507 L
s
1 .009 0 r
.62983 .10217 m
.62984 .10217 L
s
.62984 .10209 m
.62983 .10217 L
s
.62992 .10215 m
.62983 .10217 L
s
.62985 .10209 m
.62984 .10209 L
s
.62984 .10209 m
.62992 .10215 L
s
.62992 .10215 m
.62984 .10217 L
s
.62985 .10209 m
.62992 .10215 L
s
.62952 .10208 m
.62992 .10215 L
s
.62984 .10217 m
.62985 .10209 L
s
1 .08 0 r
.75737 .50141 m
.7548 .49989 L
s
1 0 0 r
.56068 .26847 m
.56068 .26847 L
s
1 .062 0 r
.48946 .43477 m
.48951 .43536 L
s
1 .022 0 r
.4182 .40065 m
.41826 .40062 L
s
.41826 .40062 m
.41821 .40041 L
s
.41826 .40062 m
.418 .40057 L
s
.41821 .40041 m
.41815 .40044 L
s
.41821 .40041 m
.418 .40057 L
s
.418 .40057 m
.4182 .40065 L
s
.418 .40057 m
.41815 .40044 L
s
.41899 .40035 m
.418 .40057 L
s
1 .08 0 r
.75529 .49975 m
.75572 .49996 L
s
.75491 .50042 m
.75529 .49975 L
s
.75529 .49975 m
.7548 .49989 L
s
.75535 .50063 m
.75491 .50042 L
s
.75491 .50042 m
.7548 .49989 L
s
1 .022 0 r
.41815 .40044 m
.4182 .40065 L
s
1 0 0 r
.48789 .23386 m
.48789 .23386 L
s
.48789 .23385 m
.48789 .23386 L
s
.48789 .23385 m
.48789 .23386 L
s
.48789 .23385 m
.48789 .23385 L
s
.48789 .23385 m
.48789 .23385 L
s
.75359 .30045 m
.75358 .30045 L
s
1 .073 0 r
.6847 .46695 m
.68181 .46589 L
s
1 0 0 r
.48788 .23385 m
.48789 .23385 L
s
.48789 .23385 m
.48789 .23386 L
s
.48789 .23385 m
.48789 .23385 L
s
.48789 .23386 m
.48789 .23385 L
s
.75358 .30045 m
.75358 .30045 L
s
.75358 .30045 m
.75358 .30045 L
s
.75358 .30045 m
.75358 .30045 L
s
.75358 .30045 m
.75358 .30045 L
s
.75358 .30045 m
.75358 .30045 L
s
.75358 .30045 m
.75358 .30045 L
s
.75358 .30045 m
.75358 .30045 L
s
.75358 .30045 m
.75358 .30045 L
s
1 .08 0 r
.75572 .49996 m
.75535 .50063 L
s
.7548 .49989 m
.75572 .49996 L
s
.7548 .49989 m
.75535 .50063 L
s
1 .073 0 r
.6824 .4665 m
.68211 .46636 L
s
.68211 .46636 m
.68237 .46571 L
s
.68211 .46636 m
.68181 .46589 L
s
.68237 .46571 m
.68266 .46585 L
s
.68237 .46571 m
.68181 .46589 L
s
.68181 .46589 m
.6824 .4665 L
s
.68181 .46589 m
.68266 .46585 L
s
.68266 .46585 m
.6824 .4665 L
s
1 .006 0 r
.34586 .3659 m
.34588 .36589 L
s
.34588 .36589 m
.34586 .36584 L
s
.34588 .36589 m
.34581 .36589 L
s
.34586 .36584 m
.34584 .36585 L
s
.34586 .36584 m
.34581 .36589 L
s
.34581 .36589 m
.34586 .3659 L
s
.34581 .36589 m
.34584 .36585 L
s
.34605 .3658 m
.34581 .36589 L
s
.34584 .36585 m
.34586 .3659 L
s
1 0 0 r
.68087 .26584 m
.68087 .26584 L
s
1 .052 0 r
.61194 .43245 m
.60959 .43202 L
s
.61006 .43238 m
.60995 .43231 L
s
.60995 .43231 m
.61005 .43182 L
s
.60995 .43231 m
.60959 .43202 L
s
.61005 .43182 m
.61017 .4319 L
s
.61005 .43182 m
.60959 .43202 L
s
1 .043 0 r
.20294 .49887 m
.20314 .49891 L
s
.20318 .49845 m
.20294 .49887 L
s
.20294 .49887 m
.20291 .49857 L
s
.20341 .49879 m
.20294 .49887 L
s
.20403 .49793 m
.20294 .49887 L
s
.20318 .49845 m
.20291 .49857 L
s
.20341 .49879 m
.20318 .49845 L
s
.20314 .49891 m
.20341 .49879 L
s
1 .052 0 r
.60959 .43202 m
.61006 .43238 L
s
.60959 .43202 m
.61017 .4319 L
s
.61017 .4319 m
.61006 .43238 L
s
1 .043 0 r
.20291 .49857 m
.20314 .49891 L
s
1 .011 0 r
.6774 .06459 m
.67743 .06459 L
s
.67742 .06448 m
.6774 .06459 L
s
.67752 .06456 m
.6774 .06459 L
s
.67745 .06448 m
.67742 .06448 L
s
.67742 .06448 m
.67752 .06456 L
s
.67752 .06456 m
.67743 .06459 L
s
.67745 .06448 m
.67752 .06456 L
s
.67703 .06445 m
.67752 .06456 L
s
1 .026 0 r
.53808 .39801 m
.53807 .39798 L
s
.53807 .39798 m
.53808 .39773 L
s
.53807 .39798 m
.53783 .39786 L
s
.53808 .39773 m
.53809 .39776 L
s
.53808 .39773 m
.53783 .39786 L
s
1 .011 0 r
.67743 .06459 m
.67745 .06448 L
s
1 0 0 r
.60806 .23117 m
.60806 .23117 L
s
.60806 .23117 m
.60806 .23117 L
s
.60806 .23117 m
.60806 .23117 L
s
.60806 .23117 m
.60806 .23117 L
s
.60806 .23117 m
.60806 .23117 L
s
.60806 .23117 m
.60806 .23117 L
s
.60806 .23117 m
.60806 .23117 L
s
.60805 .23117 m
.60806 .23117 L
s
.60806 .23117 m
.60806 .23117 L
s
1 .034 0 r
.80514 .46459 m
.80412 .46389 L
s
1 .026 0 r
.53907 .3979 m
.53783 .39786 L
s
.53783 .39786 m
.53808 .39801 L
s
.53783 .39786 m
.53809 .39776 L
s
.53809 .39776 m
.53808 .39801 L
s
1 .034 0 r
.80431 .46385 m
.8045 .46393 L
s
.80414 .46413 m
.80431 .46385 L
s
.80431 .46385 m
.80412 .46389 L
s
.80434 .46422 m
.80414 .46413 L
s
.80414 .46413 m
.80412 .46389 L
s
.8045 .46393 m
.80434 .46422 L
s
.80412 .46389 m
.8045 .46393 L
s
.80412 .46389 m
.80434 .46422 L
s
1 .091 0 r
.32075 .49717 m
.32136 .49735 L
s
.32143 .49636 m
.32075 .49717 L
s
.32075 .49717 m
.32098 .49657 L
s
.32181 .49714 m
.32075 .49717 L
s
.32398 .4956 m
.32075 .49717 L
s
.32136 .49735 m
.32181 .49714 L
s
.32181 .49714 m
.32143 .49636 L
s
.32143 .49636 m
.32098 .49657 L
s
1 .009 0 r
.46579 .36338 m
.4658 .36337 L
s
.4658 .36337 m
.46579 .36329 L
s
.4658 .36337 m
.46571 .36334 L
s
.46579 .36329 m
.46578 .3633 L
s
.46579 .36329 m
.46571 .36334 L
s
.46571 .36334 m
.46579 .36338 L
s
.46571 .36334 m
.46578 .3633 L
s
.46611 .3633 m
.46571 .36334 L
s
.46578 .3633 m
.46579 .36338 L
s
1 .001 0 r
.53518 .19647 m
.53518 .19647 L
s
.53518 .19646 m
.53518 .19647 L
s
.53519 .19646 m
.53518 .19647 L
s
.53518 .19646 m
.53518 .19646 L
s
.53518 .19646 m
.53519 .19646 L
s
.53519 .19646 m
.53518 .19647 L
s
.53518 .19646 m
.53519 .19646 L
s
.53514 .19646 m
.53519 .19646 L
s
1 .028 0 r
.73235 .43003 m
.73131 .42956 L
s
1 .001 0 r
.53518 .19647 m
.53518 .19646 L
s
1 .091 0 r
.32098 .49657 m
.32136 .49735 L
s
1 .028 0 r
.73153 .4298 m
.7314 .42975 L
s
.7314 .42975 m
.73151 .4295 L
s
.7314 .42975 m
.73131 .42956 L
s
.73151 .4295 m
.73164 .42956 L
s
.73151 .4295 m
.73131 .42956 L
s
.73164 .42956 m
.73153 .4298 L
s
.73131 .42956 m
.73153 .4298 L
s
.73131 .42956 m
.73164 .42956 L
s
1 .002 0 r
.39299 .32868 m
.39299 .32867 L
s
.39299 .32867 m
.39299 .32866 L
s
.39299 .32867 m
.39297 .32867 L
s
.39299 .32866 m
.39299 .32866 L
s
.39299 .32866 m
.39297 .32867 L
s
.39297 .32867 m
.39299 .32868 L
s
.39297 .32867 m
.39299 .32866 L
s
.39305 .32865 m
.39297 .32867 L
s
.39299 .32866 m
.39299 .32868 L
s
1 0 0 r
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
.72855 .22848 m
.72855 .22848 L
s
1 .018 0 r
.65947 .39543 m
.65868 .39522 L
s
.65884 .39536 m
.65879 .39533 L
s
.65879 .39533 m
.65884 .39516 L
s
.65879 .39533 m
.65868 .39522 L
s
.65884 .39516 m
.65889 .39519 L
s
.65884 .39516 m
.65868 .39522 L
s
.65868 .39522 m
.65884 .39536 L
s
.65868 .39522 m
.65889 .39519 L
s
.65889 .39519 m
.65884 .39536 L
s
1 .034 0 r
.24973 .4617 m
.24992 .46175 L
s
.24995 .46138 m
.24973 .4617 L
s
.24973 .4617 m
.24976 .46146 L
s
.25011 .46166 m
.24973 .4617 L
s
.25077 .46102 m
.24973 .4617 L
s
.24995 .46138 m
.24976 .46146 L
s
.25011 .46166 m
.24995 .46138 L
s
.24992 .46175 m
.25011 .46166 L
s
1 .158 0 r
.43851 .49518 m
.43888 .49492 L
s
.43888 .49492 m
.43856 .49345 L
s
.43888 .49492 m
.43711 .49458 L
s
1 .034 0 r
.24976 .46146 m
.24992 .46175 L
s
1 .158 0 r
.43856 .49345 m
.43819 .49371 L
s
.43856 .49345 m
.43711 .49458 L
s
.43711 .49458 m
.43851 .49518 L
s
.43711 .49458 m
.43819 .49371 L
s
.44425 .49326 m
.43711 .49458 L
s
1 .001 0 r
.65564 .19373 m
.65565 .19373 L
s
.65565 .19373 m
.65564 .19373 L
s
.65565 .19373 m
.65564 .19373 L
s
.65565 .19373 m
.65565 .19373 L
s
.65565 .19373 m
.65565 .19373 L
s
.65565 .19373 m
.65565 .19373 L
s
.65565 .19373 m
.65565 .19373 L
s
.65562 .19372 m
.65565 .19373 L
s
.65565 .19373 m
.65565 .19373 L
s
1 .008 0 r
.5865 .36078 m
.58611 .36074 L
s
.58619 .36079 m
.58618 .36078 L
s
.58618 .36078 m
.58619 .3607 L
s
.58618 .36078 m
.58611 .36074 L
s
.58619 .3607 m
.5862 .36071 L
s
.58619 .3607 m
.58611 .36074 L
s
.58611 .36074 m
.58619 .36079 L
s
.58611 .36074 m
.5862 .36071 L
s
.5862 .36071 m
.58619 .36079 L
s
1 .158 0 r
.43819 .49371 m
.43851 .49518 L
s
1 .003 0 r
.58268 .15894 m
.58268 .15894 L
s
.58268 .15891 m
.58268 .15894 L
s
.58271 .15893 m
.58268 .15894 L
s
.58269 .15891 m
.58268 .15891 L
s
.58268 .15891 m
.58271 .15893 L
s
1 .002 0 r
.51334 .3261 m
.51334 .3261 L
s
.51334 .3261 m
.51334 .32608 L
s
.51334 .3261 m
.51332 .32609 L
s
1 .003 0 r
.58271 .15893 m
.58268 .15894 L
s
.58269 .15891 m
.58271 .15893 L
s
.58258 .15892 m
.58271 .15893 L
s
1 .002 0 r
.51334 .32608 m
.51334 .32608 L
s
.51334 .32608 m
.51332 .32609 L
s
.51332 .32609 m
.51334 .3261 L
s
.51332 .32609 m
.51334 .32608 L
s
.51342 .32609 m
.51332 .32609 L
s
1 .01 0 r
.7802 .39296 m
.77987 .39278 L
s
1 .003 0 r
.58268 .15894 m
.58269 .15891 L
s
1 .002 0 r
.51334 .32608 m
.51334 .3261 L
s
1 .01 0 r
.77994 .39287 m
.77989 .39285 L
s
.77989 .39285 m
.77993 .39277 L
s
.77989 .39285 m
.77987 .39278 L
s
.77993 .39277 m
.77998 .39278 L
s
.77993 .39277 m
.77987 .39278 L
s
.77998 .39278 m
.77994 .39287 L
s
.77987 .39278 m
.77994 .39287 L
s
.77987 .39278 m
.77998 .39278 L
s
1 .066 0 r
.36885 .45972 m
.3691 .4596 L
s
.3691 .4596 m
.36888 .459 L
s
.3691 .4596 m
.36833 .45955 L
s
.36888 .459 m
.36863 .45912 L
s
.36888 .459 m
.36833 .45955 L
s
.36833 .45955 m
.36885 .45972 L
s
.36833 .45955 m
.36863 .45912 L
s
.37103 .45863 m
.36833 .45955 L
s
.36863 .45912 m
.36885 .45972 L
s
1 0 0 r
.44024 .29135 m
.44024 .29135 L
s
.44024 .29135 m
.44024 .29135 L
s
.44024 .29135 m
.44023 .29135 L
s
.44024 .29135 m
.44024 .29135 L
s
.44024 .29135 m
.44023 .29135 L
s
.44023 .29135 m
.44024 .29135 L
s
.44023 .29135 m
.44024 .29135 L
s
.44024 .29135 m
.44023 .29135 L
s
.44024 .29135 m
.44024 .29135 L
s
1 .005 0 r
.70721 .35826 m
.70699 .35819 L
s
.70704 .35823 m
.70702 .35822 L
s
.70702 .35822 m
.70703 .35818 L
s
.70702 .35822 m
.70699 .35819 L
s
.70703 .35818 m
.70705 .35818 L
s
.70703 .35818 m
.70699 .35819 L
s
.70699 .35819 m
.70704 .35823 L
s
.70699 .35819 m
.70705 .35818 L
s
.70705 .35818 m
.70704 .35823 L
s
1 .023 0 r
.29687 .42437 m
.29703 .42441 L
s
.29704 .42416 m
.29687 .42437 L
s
.29687 .42437 m
.29693 .42421 L
s
.29714 .42437 m
.29687 .42437 L
s
.29771 .42396 m
.29687 .42437 L
s
.29703 .42441 m
.29714 .42437 L
s
.29714 .42437 m
.29704 .42416 L
s
.29704 .42416 m
.29693 .42421 L
s
.29693 .42421 m
.29703 .42441 L
s
1 .168 0 r
.55853 .49128 m
.55834 .49103 L
s
.55834 .49103 m
.55851 .48944 L
s
.55834 .49103 m
.55693 .49022 L
s
1 .002 0 r
.70343 .15615 m
.70344 .15615 L
s
.70344 .15613 m
.70343 .15615 L
s
.70346 .15615 m
.70343 .15615 L
s
.70345 .15613 m
.70344 .15613 L
s
.70344 .15613 m
.70346 .15615 L
s
.70346 .15615 m
.70344 .15615 L
s
.70345 .15613 m
.70346 .15615 L
s
.70337 .15612 m
.70346 .15615 L
s
.70344 .15615 m
.70345 .15613 L
s
.63411 .32352 m
.63403 .32351 L
s
1 .168 0 r
.56485 .49092 m
.55693 .49022 L
s
1 .002 0 r
.63405 .32352 m
.63405 .32352 L
s
.63405 .32352 m
.63405 .3235 L
s
.63405 .32352 m
.63403 .32351 L
s
.63405 .3235 m
.63405 .3235 L
s
.63405 .3235 m
.63403 .32351 L
s
.63403 .32351 m
.63405 .32352 L
s
.63403 .32351 m
.63405 .3235 L
s
.63405 .3235 m
.63405 .32352 L
s
1 .168 0 r
.55851 .48944 m
.5587 .48969 L
s
.55851 .48944 m
.55693 .49022 L
s
1 .095 0 r
.48799 .45702 m
.48808 .45689 L
s
.48808 .45689 m
.48801 .45598 L
s
.48808 .45689 m
.4871 .45656 L
s
.48801 .45598 m
.48792 .45611 L
s
.48801 .45598 m
.4871 .45656 L
s
1 .168 0 r
.55693 .49022 m
.55853 .49128 L
s
.55693 .49022 m
.5587 .48969 L
s
1 .095 0 r
.4871 .45656 m
.48799 .45702 L
s
.4871 .45656 m
.48792 .45611 L
s
.49161 .45624 m
.4871 .45656 L
s
1 .168 0 r
.5587 .48969 m
.55853 .49128 L
s
1 .005 0 r
.63039 .12127 m
.6304 .12127 L
s
.63039 .12122 m
.63039 .12127 L
s
.63044 .12125 m
.63039 .12127 L
s
.6304 .12122 m
.63039 .12122 L
s
.63039 .12122 m
.63044 .12125 L
s
.63044 .12125 m
.6304 .12127 L
s
.6304 .12122 m
.63044 .12125 L
s
.63022 .12122 m
.63044 .12125 L
s
.6304 .12127 m
.6304 .12122 L
s
1 0 0 r
.56091 .28873 m
.56091 .28873 L
s
.56091 .28873 m
.56091 .28873 L
s
.56091 .28873 m
.56091 .28873 L
s
.56091 .28873 m
.56091 .28873 L
s
.56091 .28873 m
.56091 .28873 L
s
.56092 .28873 m
.56091 .28873 L
s
.56091 .28873 m
.56091 .28873 L
s
.56091 .28873 m
.56091 .28873 L
s
.56091 .28873 m
.56091 .28873 L
s
1 .095 0 r
.48792 .45611 m
.48799 .45702 L
s
1 .04 0 r
.41683 .42204 m
.41694 .42199 L
s
.41694 .42199 m
.41685 .42161 L
s
.41694 .42199 m
.41648 .42191 L
s
.41685 .42161 m
.41674 .42167 L
s
.41685 .42161 m
.41648 .42191 L
s
.41648 .42191 m
.41683 .42204 L
s
.41648 .42191 m
.41674 .42167 L
s
.41827 .42152 m
.41648 .42191 L
s
.41674 .42167 m
.41683 .42204 L
s
1 .104 0 r
.68578 .48857 m
.68163 .48706 L
s
1 .001 0 r
.75513 .32094 m
.75509 .32093 L
s
1 0 0 r
.48763 .25389 m
.48763 .25389 L
s
1 .001 0 r
.7551 .32094 m
.75509 .32094 L
s
.75509 .32094 m
.7551 .32093 L
s
.75509 .32094 m
.75509 .32093 L
s
.7551 .32093 m
.7551 .32093 L
s
.7551 .32093 m
.75509 .32093 L
s
.7551 .32093 m
.7551 .32094 L
s
.75509 .32093 m
.7551 .32094 L
s
.75509 .32093 m
.7551 .32093 L
s
1 .104 0 r
.68249 .48794 m
.68206 .48773 L
s
.68206 .48773 m
.68243 .48679 L
s
.68206 .48773 m
.68163 .48706 L
s
.68243 .48679 m
.68285 .487 L
s
.68243 .48679 m
.68163 .48706 L
s
1 .013 0 r
.3444 .38697 m
.34446 .38695 L
s
.34446 .38695 m
.34441 .38683 L
s
.34446 .38695 m
.3443 .38694 L
s
.34441 .38683 m
.34436 .38685 L
s
.34441 .38683 m
.3443 .38694 L
s
.3443 .38694 m
.3444 .38697 L
s
.3443 .38694 m
.34436 .38685 L
s
.34484 .38675 m
.3443 .38694 L
s
.34436 .38685 m
.3444 .38697 L
s
1 0 0 r
.68192 .28611 m
.68191 .2861 L
s
1 .081 0 r
.61252 .45384 m
.60884 .45318 L
s
1 0 0 r
.68192 .28611 m
.68192 .28611 L
s
.68192 .28611 m
.68192 .2861 L
s
.68192 .28611 m
.68191 .2861 L
s
.68192 .2861 m
.68192 .2861 L
s
.68192 .2861 m
.68191 .2861 L
s
.68191 .2861 m
.68192 .28611 L
s
.68191 .2861 m
.68192 .2861 L
s
.68192 .2861 m
.68192 .28611 L
s
1 .081 0 r
.60959 .45375 m
.6094 .45363 L
s
.6094 .45363 m
.60956 .45287 L
s
.6094 .45363 m
.60884 .45318 L
s
.60956 .45287 m
.60975 .45299 L
s
.60956 .45287 m
.60884 .45318 L
s
1 .104 0 r
.68163 .48706 m
.68249 .48794 L
s
.68163 .48706 m
.68285 .487 L
s
.68285 .487 m
.68249 .48794 L
s
1 .081 0 r
.60884 .45318 m
.60959 .45375 L
s
.60884 .45318 m
.60975 .45299 L
s
.60975 .45299 m
.60959 .45375 L
s
1 .047 0 r
.53738 .41928 m
.53736 .41922 L
s
.53736 .41922 m
.53738 .41877 L
s
.53736 .41922 m
.53693 .41901 L
s
.53738 .41877 m
.53739 .41883 L
s
.53738 .41877 m
.53693 .41901 L
s
1 .007 0 r
.67828 .08345 m
.6783 .08345 L
s
.6783 .08339 m
.67828 .08345 L
s
.67836 .08344 m
.67828 .08345 L
s
.67831 .08339 m
.6783 .08339 L
s
.6783 .08339 m
.67836 .08344 L
s
.67836 .08344 m
.6783 .08345 L
s
.67831 .08339 m
.67836 .08344 L
s
.67806 .08337 m
.67836 .08344 L
s
.6783 .08345 m
.67831 .08339 L
s
1 .05 0 r
.80703 .48621 m
.80553 .4852 L
s
1 0 0 r
.60861 .25122 m
.60861 .25122 L
s
1 .047 0 r
.53917 .41907 m
.53693 .41901 L
s
.53693 .41901 m
.53738 .41928 L
s
.53693 .41901 m
.53739 .41883 L
s
.53739 .41883 m
.53738 .41928 L
s
1 .05 0 r
.8058 .48513 m
.80609 .48526 L
s
.80556 .48555 m
.8058 .48513 L
s
.8058 .48513 m
.80553 .4852 L
s
.80585 .48568 m
.80556 .48555 L
s
.80556 .48555 m
.80553 .4852 L
s
.80609 .48526 m
.80585 .48568 L
s
.80553 .4852 m
.80609 .48526 L
s
.80553 .4852 m
.80585 .48568 L
s
1 .019 0 r
.46498 .38444 m
.46501 .38442 L
s
.46501 .38442 m
.46499 .38423 L
s
.46501 .38442 m
.4648 .38436 L
s
.46499 .38423 m
.46496 .38425 L
s
.46499 .38423 m
.4648 .38436 L
s
.4648 .38436 m
.46498 .38444 L
s
.4648 .38436 m
.46496 .38425 L
s
.46571 .38425 m
.4648 .38436 L
s
.46496 .38425 m
.46498 .38444 L
s
1 0 0 r
.53521 .21629 m
.53521 .21629 L
s
.53521 .21629 m
.53521 .21629 L
s
.53521 .21629 m
.53521 .21629 L
s
.53521 .21629 m
.53521 .21629 L
s
.53521 .21629 m
.53521 .21629 L
s
.53521 .21629 m
.53521 .21629 L
s
.53521 .21629 m
.53521 .21629 L
s
.5352 .21629 m
.53521 .21629 L
s
1 .045 0 r
.73376 .45144 m
.73207 .45069 L
s
1 0 0 r
.53521 .21629 m
.53521 .21629 L
s
1 .045 0 r
.73242 .45108 m
.73221 .45099 L
s
.73221 .45099 m
.73239 .45059 L
s
.73221 .45099 m
.73207 .45069 L
s
.73239 .45059 m
.7326 .45068 L
s
.73239 .45059 m
.73207 .45069 L
s
.7326 .45068 m
.73242 .45108 L
s
.73207 .45069 m
.73242 .45108 L
s
.73207 .45069 m
.7326 .45068 L
s
1 .006 0 r
.39195 .34947 m
.39197 .34946 L
s
.39197 .34946 m
.39196 .34941 L
s
.39197 .34946 m
.39191 .34945 L
s
.39196 .34941 m
.39194 .34941 L
s
.39196 .34941 m
.39191 .34945 L
s
.39191 .34945 m
.39195 .34947 L
s
.39191 .34945 m
.39194 .34941 L
s
.39216 .34939 m
.39191 .34945 L
s
.39194 .34941 m
.39195 .34947 L
s
1 .033 0 r
.66038 .41662 m
.65893 .41623 L
s
1 0 0 r
.72992 .24854 m
.72992 .24854 L
s
1 .033 0 r
.65923 .41649 m
.65913 .41644 L
s
.65913 .41644 m
.65922 .41613 L
s
.65913 .41644 m
.65893 .41623 L
s
1 .05 0 r
.24736 .48366 m
.24765 .48374 L
s
.2477 .48319 m
.24736 .48366 L
s
.24736 .48366 m
.24741 .48332 L
s
.24794 .48361 m
.24736 .48366 L
s
.24891 .48267 m
.24736 .48366 L
s
1 .033 0 r
.65922 .41613 m
.65932 .41618 L
s
.65922 .41613 m
.65893 .41623 L
s
1 .05 0 r
.2477 .48319 m
.24741 .48332 L
s
.24794 .48361 m
.2477 .48319 L
s
.24765 .48374 m
.24794 .48361 L
s
1 .033 0 r
.65893 .41623 m
.65923 .41649 L
s
.65893 .41623 m
.65932 .41618 L
s
.65932 .41618 m
.65923 .41649 L
s
1 .05 0 r
.24741 .48332 m
.24765 .48374 L
s
1 0 0 r
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
.6565 .21356 m
.6565 .21356 L
s
1 .018 0 r
.58691 .38175 m
.58604 .38165 L
s
.58622 .38177 m
.58619 .38175 L
s
.58619 .38175 m
.58622 .38157 L
s
.58619 .38175 m
.58604 .38165 L
s
.58622 .38157 m
.58624 .38159 L
s
.58622 .38157 m
.58604 .38165 L
s
.58604 .38165 m
.58622 .38177 L
s
.58604 .38165 m
.58624 .38159 L
s
.58624 .38159 m
.58622 .38177 L
s
1 .095 0 r
.36684 .48185 m
.36721 .48167 L
s
.36721 .48167 m
.36689 .48081 L
s
.36721 .48167 m
.36609 .48159 L
s
.36689 .48081 m
.36653 .48099 L
s
.36689 .48081 m
.36609 .48159 L
s
.36609 .48159 m
.36684 .48185 L
s
.36609 .48159 m
.36653 .48099 L
s
.36998 .4803 m
.36609 .48159 L
s
1 .007 0 r
.51307 .34688 m
.51308 .34687 L
s
.51308 .34687 m
.51307 .34681 L
s
.51308 .34687 m
.51301 .34684 L
s
.51307 .34681 m
.51307 .34681 L
s
.51307 .34681 m
.51301 .34684 L
s
.51301 .34684 m
.51307 .34688 L
s
.51301 .34684 m
.51307 .34681 L
s
.51334 .34684 m
.51301 .34684 L
s
1 .001 0 r
.583 .17854 m
.583 .17854 L
s
.583 .17853 m
.583 .17854 L
s
.58301 .17853 m
.583 .17854 L
s
.583 .17853 m
.583 .17853 L
s
.583 .17853 m
.58301 .17853 L
s
.58301 .17853 m
.583 .17854 L
s
.583 .17853 m
.58301 .17853 L
s
.58297 .17853 m
.58301 .17853 L
s
1 .018 0 r
.78193 .41416 m
.78131 .41383 L
s
1 .001 0 r
.583 .17854 m
.583 .17853 L
s
1 .007 0 r
.51307 .34681 m
.51307 .34688 L
s
1 .018 0 r
.78144 .41399 m
.78135 .41396 L
s
.78135 .41396 m
.78143 .4138 L
s
.78135 .41396 m
.78131 .41383 L
s
.78143 .4138 m
.78152 .41384 L
s
.78143 .4138 m
.78131 .41383 L
s
.78152 .41384 m
.78144 .41399 L
s
.78131 .41383 m
.78144 .41399 L
s
.78131 .41383 m
.78152 .41384 L
s
1 .095 0 r
.36653 .48099 m
.36684 .48185 L
s
1 .002 0 r
.43961 .31189 m
.43961 .31189 L
s
.43961 .31189 m
.43961 .31187 L
s
.43961 .31189 m
.43959 .31188 L
s
.43961 .31187 m
.43961 .31188 L
s
.43961 .31187 m
.43959 .31188 L
s
.43959 .31188 m
.43961 .31189 L
s
.43959 .31188 m
.43961 .31188 L
s
.43967 .31187 m
.43959 .31188 L
s
.43961 .31188 m
.43961 .31189 L
s
1 .012 0 r
.70844 .37924 m
.70796 .37908 L
s
.70806 .37917 m
.70801 .37915 L
s
.70801 .37915 m
.70805 .37905 L
s
.70801 .37915 m
.70796 .37908 L
s
.70805 .37905 m
.7081 .37906 L
s
.70805 .37905 m
.70796 .37908 L
s
.70796 .37908 m
.70806 .37917 L
s
.70796 .37908 m
.7081 .37906 L
s
.7081 .37906 m
.70806 .37917 L
s
1 .038 0 r
.2948 .44605 m
.29506 .44613 L
s
.29509 .44572 m
.2948 .44605 L
s
.2948 .44605 m
.2949 .4458 L
s
.29524 .44605 m
.2948 .44605 L
s
.29616 .4454 m
.2948 .44605 L
s
.29506 .44613 m
.29524 .44605 L
s
.29524 .44605 m
.29509 .44572 L
s
.29509 .44572 m
.2949 .4458 L
s
.2949 .4458 m
.29506 .44613 L
s
1 .001 0 r
.7046 .17575 m
.7046 .17575 L
s
.7046 .17575 m
.7046 .17575 L
s
.70461 .17575 m
.7046 .17575 L
s
.7046 .17575 m
.7046 .17575 L
s
.7046 .17575 m
.70461 .17575 L
s
.70461 .17575 m
.7046 .17575 L
s
.7046 .17575 m
.70461 .17575 L
s
.70458 .17574 m
.70461 .17575 L
s
.7046 .17575 m
.7046 .17575 L
s
1 .006 0 r
.63485 .34428 m
.63459 .34423 L
s
.63465 .34427 m
.63463 .34426 L
s
.63463 .34426 m
.63464 .34421 L
s
.63463 .34426 m
.63459 .34423 L
s
.63464 .34421 m
.63466 .34422 L
s
.63464 .34421 m
.63459 .34423 L
s
.63459 .34423 m
.63465 .34427 L
s
.63459 .34423 m
.63466 .34422 L
s
.63466 .34422 m
.63465 .34427 L
s
1 .134 0 r
.48627 .47901 m
.48639 .47882 L
s
.48639 .47882 m
.48628 .47754 L
s
.48639 .47882 m
.485 .47836 L
s
.48628 .47754 m
.48616 .47773 L
s
.48628 .47754 m
.485 .47836 L
s
.485 .47836 m
.48627 .47901 L
s
.485 .47836 m
.48616 .47773 L
s
.49138 .47792 m
.485 .47836 L
s
1 .002 0 r
.63101 .14064 m
.63101 .14064 L
s
.63101 .14062 m
.63101 .14064 L
s
.63103 .14063 m
.63101 .14064 L
s
.63102 .14062 m
.63101 .14062 L
s
.63101 .14062 m
.63103 .14063 L
s
.63103 .14063 m
.63101 .14064 L
s
.63102 .14062 m
.63103 .14063 L
s
.63094 .14062 m
.63103 .14063 L
s
.63101 .14064 m
.63102 .14062 L
s
.5611 .30927 m
.5611 .30927 L
s
.5611 .30927 m
.5611 .30925 L
s
.5611 .30927 m
.56108 .30926 L
s
.5611 .30925 m
.5611 .30926 L
s
.5611 .30925 m
.56108 .30926 L
s
.56116 .30927 m
.56108 .30926 L
s
.56108 .30926 m
.5611 .30927 L
s
.56108 .30926 m
.5611 .30926 L
s
.5611 .30926 m
.5611 .30927 L
s
1 .134 0 r
.48616 .47773 m
.48627 .47901 L
s
1 .063 0 r
.41526 .4438 m
.41543 .44371 L
s
.41543 .44371 m
.41528 .44311 L
s
.41543 .44371 m
.4147 .44358 L
s
.41528 .44311 m
.41511 .4432 L
s
.41528 .44311 m
.4147 .44358 L
s
.4147 .44358 m
.41526 .4438 L
s
.4147 .44358 m
.41511 .4432 L
s
.41755 .44297 m
.4147 .44358 L
s
.41511 .4432 m
.41526 .4438 L
s
1 0 0 r
.48736 .27421 m
.48736 .27421 L
s
.48736 .27421 m
.48736 .27421 L
s
.48736 .27421 m
.48736 .27421 L
s
.48736 .27421 m
.48736 .27421 L
s
.48736 .27421 m
.48736 .27421 L
s
.48736 .27421 m
.48736 .27421 L
s
.48736 .27421 m
.48736 .27421 L
s
.48737 .27421 m
.48736 .27421 L
s
1 .003 0 r
.75669 .34171 m
.75656 .34166 L
s
1 0 0 r
.48736 .27421 m
.48736 .27421 L
s
1 .003 0 r
.75659 .34169 m
.75658 .34168 L
s
.75658 .34168 m
.75659 .34165 L
s
.75658 .34168 m
.75656 .34166 L
s
.75659 .34165 m
.7566 .34166 L
s
.75659 .34165 m
.75656 .34166 L
s
.7566 .34166 m
.75659 .34169 L
s
.75656 .34166 m
.75659 .34169 L
s
.75656 .34166 m
.7566 .34166 L
s
1 .024 0 r
.34281 .40839 m
.3429 .40835 L
s
.3429 .40835 m
.34282 .40813 L
s
.3429 .40835 m
.34262 .40833 L
s
.34282 .40813 m
.34273 .40817 L
s
.34282 .40813 m
.34262 .40833 L
s
.34262 .40833 m
.34281 .40839 L
s
.34262 .40833 m
.34273 .40817 L
s
.34361 .40798 m
.34262 .40833 L
s
.34273 .40817 m
.34281 .40839 L
s
1 .001 0 r
.68299 .30665 m
.68294 .30664 L
s
1 .115 0 r
.61311 .47553 m
.60786 .47459 L
s
1 .001 0 r
.68295 .30665 m
.68294 .30665 L
s
.68294 .30665 m
.68295 .30664 L
s
.68294 .30665 m
.68294 .30664 L
s
.68295 .30664 m
.68295 .30664 L
s
.68295 .30664 m
.68294 .30664 L
s
.68294 .30664 m
.68295 .30665 L
s
.68294 .30664 m
.68295 .30664 L
s
.68295 .30664 m
.68295 .30665 L
s
1 .115 0 r
.60893 .47541 m
.60867 .47523 L
s
.60867 .47523 m
.6089 .47415 L
s
.60867 .47523 m
.60786 .47459 L
s
.6089 .47415 m
.60916 .47433 L
s
.6089 .47415 m
.60786 .47459 L
s
.60786 .47459 m
.60893 .47541 L
s
.60786 .47459 m
.60916 .47433 L
s
1 .073 0 r
.53644 .44086 m
.53642 .44077 L
s
.53642 .44077 m
.53644 .44006 L
s
.53642 .44077 m
.53574 .44044 L
s
.53644 .44006 m
.53647 .44016 L
s
.53644 .44006 m
.53574 .44044 L
s
1 .115 0 r
.60916 .47433 m
.60893 .47541 L
s
1 .003 0 r
.67922 .10259 m
.67923 .10259 L
s
.67923 .10256 m
.67922 .10259 L
s
.67926 .10258 m
.67922 .10259 L
s
.67923 .10256 m
.67923 .10256 L
s
.67923 .10256 m
.67926 .10258 L
s
.67926 .10258 m
.67923 .10259 L
s
.67923 .10256 m
.67926 .10258 L
s
.6791 .10255 m
.67926 .10258 L
s
.67923 .10259 m
.67923 .10256 L
s
1 0 0 r
.60918 .27154 m
.60917 .27154 L
s
1 .073 0 r
.53926 .44054 m
.53574 .44044 L
s
1 0 0 r
.60917 .27154 m
.60917 .27154 L
s
.60917 .27154 m
.60917 .27154 L
s
.60917 .27154 m
.60917 .27154 L
s
.60917 .27154 m
.60917 .27154 L
s
.60917 .27154 m
.60917 .27154 L
s
.60917 .27154 m
.60917 .27154 L
s
.60917 .27154 m
.60917 .27154 L
s
.60917 .27154 m
.60917 .27154 L
s
1 .073 0 r
.53574 .44044 m
.53644 .44086 L
s
.53574 .44044 m
.53647 .44016 L
s
.53647 .44016 m
.53644 .44086 L
s
1 .035 0 r
.46398 .40583 m
.46403 .40579 L
s
.46403 .40579 m
.46398 .40545 L
s
.46403 .40579 m
.46365 .40568 L
s
.46398 .40545 m
.46393 .40549 L
s
.46398 .40545 m
.46365 .40568 L
s
.46365 .40568 m
.46398 .40583 L
s
.46365 .40568 m
.46393 .40549 L
s
.4653 .4055 m
.46365 .40568 L
s
.46393 .40549 m
.46398 .40583 L
s
1 .066 0 r
.73518 .47314 m
.73271 .47205 L
s
1 0 0 r
.53527 .23639 m
.53527 .23639 L
s
1 .066 0 r
.73323 .47263 m
.73292 .47249 L
s
.73292 .47249 m
.73318 .47191 L
s
.73292 .47249 m
.73271 .47205 L
s
.73318 .47191 m
.73349 .47205 L
s
.73318 .47191 m
.73271 .47205 L
s
1 .013 0 r
.39079 .37058 m
.39083 .37057 L
s
.39083 .37057 m
.3908 .37045 L
s
.39083 .37057 m
.39068 .37054 L
s
.3908 .37045 m
.39076 .37046 L
s
.3908 .37045 m
.39068 .37054 L
s
1 .066 0 r
.73349 .47205 m
.73323 .47263 L
s
.73271 .47205 m
.73323 .47263 L
s
1 .013 0 r
.39068 .37054 m
.39079 .37058 L
s
.39068 .37054 m
.39076 .37046 L
s
.39125 .37041 m
.39068 .37054 L
s
1 .066 0 r
.73271 .47205 m
.73349 .47205 L
s
1 .013 0 r
.39076 .37046 m
.39079 .37058 L
s
1 .053 0 r
.6613 .4381 m
.65899 .43749 L
s
1 0 0 r
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
.73132 .26887 m
.73132 .26887 L
s
1 .053 0 r
.65946 .4379 m
.65929 .43782 L
s
.65929 .43782 m
.65944 .43732 L
s
.65929 .43782 m
.65899 .43749 L
s
.65944 .43732 m
.65961 .4374 L
s
.65944 .43732 m
.65899 .43749 L
s
.65899 .43749 m
.65946 .4379 L
s
.65899 .43749 m
.65961 .4374 L
s
.65961 .4374 m
.65946 .4379 L
s
1 0 0 r
.65739 .23367 m
.65739 .23367 L
s
1 .033 0 r
.58733 .40301 m
.58575 .40283 L
s
.58607 .40304 m
.58602 .403 L
s
.58602 .403 m
.58606 .40268 L
s
.58602 .403 m
.58575 .40283 L
s
.58606 .40268 m
.58611 .40272 L
s
.58606 .40268 m
.58575 .40283 L
s
.58575 .40283 m
.58607 .40304 L
s
.58575 .40283 m
.58611 .40272 L
s
.58611 .40272 m
.58607 .40304 L
s
1 .015 0 r
.51266 .36796 m
.51266 .36795 L
s
.51266 .36795 m
.51266 .3678 L
s
.51266 .36795 m
.51251 .36788 L
s
.51266 .3678 m
.51265 .36781 L
s
.51266 .3678 m
.51251 .36788 L
s
.51251 .36788 m
.51266 .36796 L
s
.51251 .36788 m
.51265 .36781 L
s
.51326 .36787 m
.51251 .36788 L
s
1 0 0 r
.58337 .19841 m
.58337 .19841 L
s
.58337 .19841 m
.58337 .19841 L
s
.58337 .19841 m
.58337 .19841 L
s
.58337 .19841 m
.58337 .19841 L
s
.58337 .19841 m
.58337 .19841 L
s
.58337 .19841 m
.58337 .19841 L
s
.58337 .19841 m
.58337 .19841 L
s
.58337 .19841 m
.58337 .19841 L
s
1 .029 0 r
.78368 .43565 m
.78267 .43512 L
s
1 0 0 r
.58337 .19841 m
.58337 .19841 L
s
1 .015 0 r
.51265 .36781 m
.51266 .36796 L
s
1 .029 0 r
.78288 .43538 m
.78273 .43532 L
s
.78273 .43532 m
.78286 .43507 L
s
.78273 .43532 m
.78267 .43512 L
s
.78286 .43507 m
.78301 .43513 L
s
.78286 .43507 m
.78267 .43512 L
s
.78301 .43513 m
.78288 .43538 L
s
.78267 .43512 m
.78288 .43538 L
s
.78267 .43512 m
.78301 .43513 L
s
1 .005 0 r
.43889 .33273 m
.4389 .33273 L
s
.4389 .33273 m
.43889 .33268 L
s
.4389 .33273 m
.43885 .33271 L
s
.43889 .33268 m
.43888 .33269 L
s
.43889 .33268 m
.43885 .33271 L
s
.43885 .33271 m
.43889 .33273 L
s
.43885 .33271 m
.43888 .33269 L
s
.43908 .33268 m
.43885 .33271 L
s
.43888 .33269 m
.43889 .33273 L
s
1 .022 0 r
.70969 .40051 m
.7088 .4002 L
s
.70898 .40038 m
.7089 .40035 L
s
.7089 .40035 m
.70897 .40015 L
s
.7089 .40035 m
.7088 .4002 L
s
.70897 .40015 m
.70905 .40018 L
s
.70897 .40015 m
.7088 .4002 L
s
1 .055 0 r
.29259 .46809 m
.29297 .4682 L
s
.29301 .46759 m
.29259 .46809 L
s
.29259 .46809 m
.29274 .46771 L
s
.29324 .46808 m
.29259 .46809 L
s
.2946 .46713 m
.29259 .46809 L
s
.29297 .4682 m
.29324 .46808 L
s
.29324 .46808 m
.29301 .46759 L
s
.29301 .46759 m
.29274 .46771 L
s
1 .022 0 r
.7088 .4002 m
.70898 .40038 L
s
.7088 .4002 m
.70905 .40018 L
s
.70905 .40018 m
.70898 .40038 L
s
1 .055 0 r
.29274 .46771 m
.29297 .4682 L
s
1 0 0 r
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
.70581 .19563 m
.70581 .19563 L
s
1 .013 0 r
.6356 .36532 m
.63502 .36521 L
s
.63514 .3653 m
.63511 .36528 L
s
.63511 .36528 m
.63513 .36516 L
s
.63511 .36528 m
.63502 .36521 L
s
.63513 .36516 m
.63516 .36518 L
s
.63513 .36516 m
.63502 .36521 L
s
.63502 .36521 m
.63514 .3653 L
s
.63502 .36521 m
.63516 .36518 L
s
.63516 .36518 m
.63514 .3653 L
s
1 .005 0 r
.56121 .3301 m
.5612 .33009 L
s
.5612 .33009 m
.56121 .33004 L
s
.5612 .33009 m
.56116 .33007 L
s
1 .001 0 r
.63168 .16029 m
.63168 .16029 L
s
.63168 .16028 m
.63168 .16029 L
s
.63169 .16028 m
.63168 .16029 L
s
.63169 .16028 m
.63168 .16028 L
s
.63168 .16028 m
.63169 .16028 L
s
1 .005 0 r
.56121 .33004 m
.56121 .33005 L
s
.56121 .33004 m
.56116 .33007 L
s
1 .001 0 r
.63169 .16028 m
.63168 .16029 L
s
.63169 .16028 m
.63169 .16028 L
s
.63166 .16028 m
.63169 .16028 L
s
.63168 .16029 m
.63169 .16028 L
s
1 .005 0 r
.56141 .33008 m
.56116 .33007 L
s
.56116 .33007 m
.56121 .3301 L
s
.56116 .33007 m
.56121 .33005 L
s
.56121 .33005 m
.56121 .3301 L
s
1 .091 0 r
.4135 .46591 m
.41375 .46577 L
s
.41375 .46577 m
.41354 .46491 L
s
.41375 .46577 m
.4127 .46558 L
s
.41354 .46491 m
.4133 .46505 L
s
.41354 .46491 m
.4127 .46558 L
s
.4127 .46558 m
.4135 .46591 L
s
.4127 .46558 m
.4133 .46505 L
s
.41681 .46472 m
.4127 .46558 L
s
.4133 .46505 m
.4135 .46591 L
s
1 .001 0 r
.48706 .29481 m
.48706 .29481 L
s
.48706 .29481 m
.48706 .29479 L
s
.48706 .29481 m
.48705 .2948 L
s
.48706 .29479 m
.48706 .2948 L
s
.48706 .29479 m
.48705 .2948 L
s
.48705 .2948 m
.48706 .29481 L
s
.48705 .2948 m
.48706 .2948 L
s
.48711 .2948 m
.48705 .2948 L
s
1 .008 0 r
.75828 .36277 m
.75798 .36264 L
s
1 .001 0 r
.48706 .2948 m
.48706 .29481 L
s
1 .008 0 r
.75804 .36271 m
.75801 .36269 L
s
.75801 .36269 m
.75803 .36262 L
s
.75801 .36269 m
.75798 .36264 L
s
.75803 .36262 m
.75807 .36264 L
s
.75803 .36262 m
.75798 .36264 L
s
.75807 .36264 m
.75804 .36271 L
s
.75798 .36264 m
.75804 .36271 L
s
.75798 .36264 m
.75807 .36264 L
s
1 .039 0 r
.34107 .43016 m
.34123 .43009 L
s
.34123 .43009 m
.34109 .42973 L
s
.34123 .43009 m
.34076 .43005 L
s
.34109 .42973 m
.34094 .4298 L
s
.34109 .42973 m
.34076 .43005 L
s
.34076 .43005 m
.34107 .43016 L
s
.34076 .43005 m
.34094 .4298 L
s
.34236 .4295 m
.34076 .43005 L
s
.34094 .4298 m
.34107 .43016 L
s
1 .004 0 r
.68407 .32748 m
.6839 .32743 L
s
.68393 .32746 m
.68392 .32746 L
s
.68392 .32746 m
.68393 .32742 L
s
.68392 .32746 m
.6839 .32743 L
s
.68393 .32742 m
.68394 .32743 L
s
.68393 .32742 m
.6839 .32743 L
s
.6839 .32743 m
.68393 .32746 L
s
.6839 .32743 m
.68394 .32743 L
s
.68394 .32743 m
.68393 .32746 L
s
1 .104 0 r
.53532 .46277 m
.53528 .46263 L
s
.53528 .46263 m
.53532 .46161 L
s
.53528 .46263 m
.53431 .46216 L
s
.53532 .46161 m
.53535 .46176 L
s
.53532 .46161 m
.53431 .46216 L
s
1 .002 0 r
.68021 .12201 m
.68021 .12201 L
s
.68021 .12199 m
.68021 .12201 L
s
.68022 .12201 m
.68021 .12201 L
s
.68021 .12199 m
.68021 .12199 L
s
.68021 .12199 m
.68022 .12201 L
s
.68022 .12201 m
.68021 .12201 L
s
.68021 .12199 m
.68022 .12201 L
s
.68015 .12199 m
.68022 .12201 L
s
.68021 .12201 m
.68021 .12199 L
s
1 .001 0 r
.60975 .29214 m
.6097 .29214 L
s
1 .104 0 r
.53936 .4623 m
.53431 .46216 L
s
1 .001 0 r
.60971 .29214 m
.60971 .29214 L
s
.60971 .29214 m
.60971 .29213 L
s
.60971 .29214 m
.6097 .29214 L
s
.60971 .29213 m
.60971 .29213 L
s
.60971 .29213 m
.6097 .29214 L
s
.6097 .29214 m
.60971 .29214 L
s
.6097 .29214 m
.60971 .29213 L
s
.60971 .29213 m
.60971 .29214 L
s
1 .104 0 r
.53431 .46216 m
.53532 .46277 L
s
.53431 .46216 m
.53535 .46176 L
s
.53535 .46176 m
.53532 .46277 L
s
1 .055 0 r
.46277 .42756 m
.46285 .42749 L
s
.46285 .42749 m
.46279 .42696 L
s
.46285 .42749 m
.46225 .42732 L
s
.46279 .42696 m
.4627 .42703 L
s
.46279 .42696 m
.46225 .42732 L
s
.46225 .42732 m
.46277 .42756 L
s
.46225 .42732 m
.4627 .42703 L
s
.46489 .42703 m
.46225 .42732 L
s
.4627 .42703 m
.46277 .42756 L
s
1 0 0 r
.53533 .25676 m
.53533 .25676 L
s
.53533 .25676 m
.53533 .25676 L
s
.53533 .25676 m
.53533 .25676 L
s
.53533 .25676 m
.53533 .25676 L
s
.53533 .25676 m
.53533 .25676 L
s
.53534 .25676 m
.53533 .25676 L
s
.53533 .25676 m
.53533 .25676 L
s
.53533 .25676 m
.53533 .25676 L
s
.53533 .25676 m
.53533 .25676 L
s
1 .023 0 r
.38949 .39204 m
.38955 .39201 L
s
.38955 .39201 m
.3895 .39179 L
s
.38955 .39201 m
.38928 .39196 L
s
.3895 .39179 m
.38943 .39182 L
s
.3895 .39179 m
.38928 .39196 L
s
.38928 .39196 m
.38949 .39204 L
s
.38928 .39196 m
.38943 .39182 L
s
.39033 .39172 m
.38928 .39196 L
s
.38943 .39182 m
.38949 .39204 L
s
1 .001 0 r
.73273 .28948 m
.7327 .28947 L
s
1 .077 0 r
.66224 .45987 m
.65887 .45899 L
s
1 .001 0 r
.73271 .28948 m
.73271 .28948 L
s
.73271 .28948 m
.73271 .28947 L
s
.73271 .28948 m
.7327 .28947 L
s
.73271 .28947 m
.73271 .28947 L
s
.73271 .28947 m
.7327 .28947 L
s
.7327 .28947 m
.73271 .28948 L
s
.7327 .28947 m
.73271 .28947 L
s
.73271 .28947 m
.73271 .28948 L
s
1 .077 0 r
.65956 .45959 m
.65931 .45947 L
s
.65931 .45947 m
.65953 .45874 L
s
.65931 .45947 m
.65887 .45899 L
s
.65953 .45874 m
.65977 .45887 L
s
.65953 .45874 m
.65887 .45899 L
s
.65887 .45899 m
.65956 .45959 L
s
.65887 .45899 m
.65977 .45887 L
s
.65977 .45887 m
.65956 .45959 L
s
1 0 0 r
.6583 .25405 m
.6583 .25405 L
s
1 .053 0 r
.58776 .42455 m
.58522 .42427 L
s
1 0 0 r
.6583 .25405 m
.6583 .25405 L
s
.6583 .25405 m
.6583 .25405 L
s
.6583 .25405 m
.6583 .25405 L
s
.6583 .25405 m
.6583 .25405 L
s
.6583 .25405 m
.6583 .25405 L
s
.6583 .25405 m
.6583 .25405 L
s
.6583 .25405 m
.6583 .25405 L
s
.6583 .25405 m
.6583 .25405 L
s
1 .053 0 r
.58574 .42462 m
.58566 .42455 L
s
.58566 .42455 m
.58573 .42404 L
s
.58566 .42455 m
.58522 .42427 L
s
.58573 .42404 m
.5858 .4241 L
s
.58573 .42404 m
.58522 .42427 L
s
.58522 .42427 m
.58574 .42462 L
s
.58522 .42427 m
.5858 .4241 L
s
.5858 .4241 m
.58574 .42462 L
s
1 .028 0 r
.51207 .38936 m
.51208 .38933 L
s
.51208 .38933 m
.51207 .38906 L
s
.51208 .38933 m
.5118 .38922 L
s
.51207 .38906 m
.51207 .38909 L
s
.51207 .38906 m
.5118 .38922 L
s
.5118 .38922 m
.51207 .38936 L
s
.5118 .38922 m
.51207 .38909 L
s
.51317 .38919 m
.5118 .38922 L
s
1 .043 0 r
.78546 .45744 m
.78395 .45666 L
s
1 0 0 r
.58377 .21857 m
.58377 .21857 L
s
1 .028 0 r
.51207 .38909 m
.51207 .38936 L
s
1 .043 0 r
.78427 .45705 m
.78405 .45695 L
s
.78405 .45695 m
.78423 .45658 L
s
.78405 .45695 m
.78395 .45666 L
s
.78423 .45658 m
.78446 .45667 L
s
.78423 .45658 m
.78395 .45666 L
s
.78446 .45667 m
.78427 .45705 L
s
.78395 .45666 m
.78427 .45705 L
s
.78395 .45666 m
.78446 .45667 L
s
1 .011 0 r
.43806 .35389 m
.43808 .35388 L
s
.43808 .35388 m
.43806 .35377 L
s
.43808 .35388 m
.43795 .35385 L
s
.43806 .35377 m
.43804 .35378 L
s
.43806 .35377 m
.43795 .35385 L
s
.43795 .35385 m
.43806 .35389 L
s
.43795 .35385 m
.43804 .35378 L
s
.43849 .35377 m
.43795 .35385 L
s
.43804 .35378 m
.43806 .35389 L
s
1 .035 0 r
.71096 .42207 m
.7095 .42158 L
s
.70981 .42187 m
.70967 .42181 L
s
.70967 .42181 m
.70978 .42148 L
s
.70967 .42181 m
.7095 .42158 L
s
.70978 .42148 m
.70992 .42154 L
s
.70978 .42148 m
.7095 .42158 L
s
.7095 .42158 m
.70981 .42187 L
s
.7095 .42158 m
.70992 .42154 L
s
.70992 .42154 m
.70981 .42187 L
s
1 .023 0 r
.63636 .38665 m
.63528 .38645 L
s
1 0 0 r
.70705 .2158 m
.70705 .2158 L
s
1 .023 0 r
.6355 .38662 m
.63545 .38659 L
s
.63545 .38659 m
.63549 .38636 L
s
.63545 .38659 m
.63528 .38645 L
s
.63549 .38636 m
.63555 .38639 L
s
.63549 .38636 m
.63528 .38645 L
s
.63528 .38645 m
.6355 .38662 L
s
.63528 .38645 m
.63555 .38639 L
s
.63555 .38639 m
.6355 .38662 L
s
1 .012 0 r
.5612 .35122 m
.56119 .35121 L
s
.56119 .35121 m
.5612 .3511 L
s
.56119 .35121 m
.56108 .35115 L
s
.5612 .3511 m
.56121 .35111 L
s
.5612 .3511 m
.56108 .35115 L
s
1 0 0 r
.6324 .18021 m
.6324 .18021 L
s
.6324 .18021 m
.6324 .18021 L
s
.6324 .18021 m
.6324 .18021 L
s
.6324 .18021 m
.6324 .18021 L
s
.6324 .18021 m
.6324 .18021 L
s
.6324 .18021 m
.6324 .18021 L
s
.6324 .18021 m
.6324 .18021 L
s
.63239 .18021 m
.6324 .18021 L
s
.6324 .18021 m
.6324 .18021 L
s
1 .012 0 r
.56166 .35119 m
.56108 .35115 L
s
.56108 .35115 m
.5612 .35122 L
s
.56108 .35115 m
.56121 .35111 L
s
.56121 .35111 m
.5612 .35122 L
s
1 .004 0 r
.48668 .31571 m
.48669 .3157 L
s
.48669 .3157 m
.48668 .31566 L
s
.48669 .3157 m
.48664 .31569 L
s
.48668 .31566 m
.48668 .31566 L
s
.48668 .31566 m
.48664 .31569 L
s
.48664 .31569 m
.48668 .31571 L
s
.48664 .31569 m
.48668 .31566 L
s
.48685 .31567 m
.48664 .31569 L
s
1 .014 0 r
.75989 .38411 m
.75932 .38388 L
s
1 .004 0 r
.48668 .31566 m
.48668 .31571 L
s
1 .014 0 r
.75944 .384 m
.75937 .38398 L
s
.75937 .38398 m
.75943 .38385 L
s
.75937 .38398 m
.75932 .38388 L
s
.75943 .38385 m
.75949 .38387 L
s
.75943 .38385 m
.75932 .38388 L
s
.75949 .38387 m
.75944 .384 L
s
.75932 .38388 m
.75944 .384 L
s
.75932 .38388 m
.75949 .38387 L
s
1 .057 0 r
.3392 .45228 m
.33942 .45217 L
s
.33942 .45217 m
.33923 .45165 L
s
.33942 .45217 m
.33874 .45212 L
s
.33923 .45165 m
.339 .45175 L
s
.33923 .45165 m
.33874 .45212 L
s
.33874 .45212 m
.3392 .45228 L
s
.33874 .45212 m
.339 .45175 L
s
.3411 .45132 m
.33874 .45212 L
s
.339 .45175 m
.3392 .45228 L
s
1 .009 0 r
.68516 .34859 m
.68478 .34849 L
s
.68486 .34856 m
.68483 .34855 L
s
.68483 .34855 m
.68485 .34847 L
s
.68483 .34855 m
.68478 .34849 L
s
.68485 .34847 m
.68488 .34848 L
s
.68485 .34847 m
.68478 .34849 L
s
.68478 .34849 m
.68486 .34856 L
s
.68478 .34849 m
.68488 .34848 L
s
.68488 .34848 m
.68486 .34856 L
s
1 0 0 r
.68124 .14171 m
.68124 .14171 L
s
.68124 .1417 m
.68124 .14171 L
s
.68124 .1417 m
.68124 .14171 L
s
.68124 .1417 m
.68124 .1417 L
s
.68124 .1417 m
.68124 .1417 L
s
.68124 .1417 m
.68124 .14171 L
s
.68124 .1417 m
.68124 .1417 L
s
.68122 .1417 m
.68124 .1417 L
s
.68124 .14171 m
.68124 .1417 L
s
1 .004 0 r
.61034 .31303 m
.61016 .31301 L
s
.61019 .31303 m
.61019 .31303 L
s
.61019 .31303 m
.61019 .31299 L
s
.61019 .31303 m
.61016 .31301 L
s
.61019 .31299 m
.6102 .31299 L
s
.61019 .31299 m
.61016 .31301 L
s
.61016 .31301 m
.61019 .31303 L
s
.61016 .31301 m
.6102 .31299 L
s
.6102 .31299 m
.61019 .31303 L
s
1 .08 0 r
.4614 .44964 m
.46152 .44953 L
s
.46152 .44953 m
.46142 .44875 L
s
.46152 .44953 m
.46064 .44927 L
s
.46142 .44875 m
.4613 .44886 L
s
.46142 .44875 m
.46064 .44927 L
s
.46064 .44927 m
.4614 .44964 L
s
.46064 .44927 m
.4613 .44886 L
s
.46448 .44886 m
.46064 .44927 L
s
.4613 .44886 m
.4614 .44964 L
s
1 .001 0 r
.53537 .27742 m
.53537 .27742 L
s
.53537 .27742 m
.53537 .27741 L
s
.53537 .27742 m
.53536 .27741 L
s
.53537 .27741 m
.53537 .27741 L
s
.53537 .27741 m
.53536 .27741 L
s
.53541 .27742 m
.53536 .27741 L
s
.53536 .27741 m
.53537 .27742 L
s
.53536 .27741 m
.53537 .27741 L
s
.53537 .27741 m
.53537 .27742 L
s
1 .038 0 r
.38803 .41384 m
.38814 .41379 L
s
.38814 .41379 m
.38805 .41343 L
s
.38814 .41379 m
.3877 .41371 L
s
.38805 .41343 m
.38794 .41348 L
s
.38805 .41343 m
.3877 .41371 L
s
.3877 .41371 m
.38803 .41384 L
s
.3877 .41371 m
.38794 .41348 L
s
.38939 .41332 m
.3877 .41371 L
s
.38794 .41348 m
.38803 .41384 L
s
1 .003 0 r
.73417 .31038 m
.73406 .31034 L
s
.73408 .31036 m
.73407 .31036 L
s
.73407 .31036 m
.73408 .31033 L
s
.73407 .31036 m
.73406 .31034 L
s
.73408 .31033 m
.73409 .31034 L
s
.73408 .31033 m
.73406 .31034 L
s
.73406 .31034 m
.73408 .31036 L
s
.73406 .31034 m
.73409 .31034 L
s
.73409 .31034 m
.73408 .31036 L
s
1 .001 0 r
.65922 .27471 m
.65918 .27471 L
s
1 .077 0 r
.58819 .4464 m
.58451 .44599 L
s
1 .001 0 r
.65919 .27471 m
.65919 .27471 L
s
.65919 .27471 m
.65919 .2747 L
s
.65919 .27471 m
.65918 .27471 L
s
1 .077 0 r
.58525 .4465 m
.58514 .44639 L
s
.58514 .44639 m
.58523 .44565 L
s
.58514 .44639 m
.58451 .44599 L
s
1 .001 0 r
.65919 .2747 m
.65919 .2747 L
s
.65919 .2747 m
.65918 .27471 L
s
.65918 .27471 m
.65919 .27471 L
s
.65918 .27471 m
.65919 .2747 L
s
.65919 .2747 m
.65919 .27471 L
s
1 .077 0 r
.58523 .44565 m
.58535 .44575 L
s
.58523 .44565 m
.58451 .44599 L
s
.58451 .44599 m
.58525 .4465 L
s
.58451 .44599 m
.58535 .44575 L
s
.58535 .44575 m
.58525 .4465 L
s
1 .045 0 r
.51132 .41109 m
.51133 .41103 L
s
.51133 .41103 m
.51132 .41059 L
s
.51133 .41103 m
.51088 .41085 L
s
.51132 .41059 m
.51131 .41064 L
s
.51132 .41059 m
.51088 .41085 L
s
.51088 .41085 m
.51132 .41109 L
s
.51088 .41085 m
.51131 .41064 L
s
.51309 .4108 m
.51088 .41085 L
s
1 0 0 r
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
.58417 .239 m
.58417 .239 L
s
1 .045 0 r
.51131 .41064 m
.51132 .41109 L
s
1 .021 0 r
.43709 .37538 m
.43713 .37536 L
s
.43713 .37536 m
.43709 .37516 L
s
.43713 .37536 m
.43689 .3753 L
s
.43709 .37516 m
.43705 .37518 L
s
.43709 .37516 m
.43689 .3753 L
s
.43689 .3753 m
.43709 .37538 L
s
.43689 .3753 m
.43705 .37518 L
s
.43789 .37516 m
.43689 .3753 L
s
.43705 .37518 m
.43709 .37538 L
s
1 .051 0 r
.71225 .44393 m
.71009 .44321 L
s
.71054 .44364 m
.71034 .44355 L
s
.71034 .44355 m
.71051 .44307 L
s
.71034 .44355 m
.71009 .44321 L
s
.71051 .44307 m
.71071 .44316 L
s
.71051 .44307 m
.71009 .44321 L
s
.71009 .44321 m
.71054 .44364 L
s
.71009 .44321 m
.71071 .44316 L
s
.71071 .44316 m
.71054 .44364 L
s
1 .038 0 r
.63713 .40828 m
.63538 .40795 L
s
1 0 0 r
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
.70831 .23624 m
.70831 .23624 L
s
1 .038 0 r
.63574 .40823 m
.63565 .40818 L
s
.63565 .40818 m
.63573 .40781 L
s
.63565 .40818 m
.63538 .40795 L
s
.63573 .40781 m
.63582 .40786 L
s
.63573 .40781 m
.63538 .40795 L
s
.63538 .40795 m
.63574 .40823 L
s
.63538 .40795 m
.63582 .40786 L
s
.63582 .40786 m
.63574 .40823 L
s
1 .022 0 r
.56106 .37265 m
.56104 .37263 L
s
.56104 .37263 m
.56106 .37242 L
s
.56104 .37263 m
.56085 .37252 L
s
.56106 .37242 m
.56108 .37244 L
s
.56106 .37242 m
.56085 .37252 L
s
.56191 .37258 m
.56085 .37252 L
s
1 0 0 r
.63314 .20042 m
.63314 .20042 L
s
1 .022 0 r
.56085 .37252 m
.56106 .37265 L
s
.56085 .37252 m
.56108 .37244 L
s
.56108 .37244 m
.56106 .37265 L
s
1 .01 0 r
.48621 .33691 m
.48621 .3369 L
s
.48621 .3369 m
.48621 .33681 L
s
.48621 .3369 m
.48611 .33687 L
s
.48621 .33681 m
.4862 .33682 L
s
.48621 .33681 m
.48611 .33687 L
s
.48611 .33687 m
.48621 .33691 L
s
.48611 .33687 m
.4862 .33682 L
s
.48658 .33684 m
.48611 .33687 L
s
1 .023 0 r
.76151 .40575 m
.76059 .40537 L
s
1 .01 0 r
.4862 .33682 m
.48621 .33691 L
s
1 .023 0 r
.76078 .40558 m
.76067 .40553 L
s
.76067 .40553 m
.76076 .40532 L
s
.76067 .40553 m
.76059 .40537 L
s
.76076 .40532 m
.76087 .40536 L
s
.76076 .40532 m
.76059 .40537 L
s
.76087 .40536 m
.76078 .40558 L
s
.76059 .40537 m
.76078 .40558 L
s
.76059 .40537 m
.76087 .40536 L
s
1 .016 0 r
.68627 .37 m
.68555 .36982 L
s
.6857 .36994 m
.68565 .36992 L
s
.68565 .36992 m
.68569 .36976 L
s
.68565 .36992 m
.68555 .36982 L
s
.68569 .36976 m
.68574 .36979 L
s
.68569 .36976 m
.68555 .36982 L
s
.68555 .36982 m
.6857 .36994 L
s
.68555 .36982 m
.68574 .36979 L
s
.68574 .36979 m
.6857 .36994 L
s
1 0 0 r
.68231 .16169 m
.68231 .16169 L
s
.68231 .16169 m
.68231 .16169 L
s
.68231 .16169 m
.68231 .16169 L
s
.68231 .16169 m
.68231 .16169 L
s
.68231 .16169 m
.68231 .16169 L
s
.68231 .16169 m
.68231 .16169 L
s
.68231 .16169 m
.68231 .16169 L
s
.68231 .16168 m
.68231 .16169 L
s
.68231 .16169 m
.68231 .16169 L
s
1 .009 0 r
.61093 .3342 m
.61051 .33415 L
s
.6106 .33421 m
.61058 .3342 L
s
.61058 .3342 m
.61059 .33411 L
s
.61058 .3342 m
.61051 .33415 L
s
.61059 .33411 m
.61061 .33412 L
s
.61059 .33411 m
.61051 .33415 L
s
.61051 .33415 m
.6106 .33421 L
s
.61051 .33415 m
.61061 .33412 L
s
.61061 .33412 m
.6106 .33421 L
s
1 .003 0 r
.53535 .29837 m
.53535 .29837 L
s
.53535 .29837 m
.53535 .29834 L
s
.53535 .29837 m
.53531 .29836 L
s
.53535 .29834 m
.53535 .29834 L
s
.53535 .29834 m
.53531 .29836 L
s
.53548 .29836 m
.53531 .29836 L
s
.53531 .29836 m
.53535 .29837 L
s
.53531 .29836 m
.53535 .29834 L
s
.53535 .29834 m
.53535 .29837 L
s
1 .055 0 r
.38644 .43599 m
.3866 .4359 L
s
.3866 .4359 m
.38646 .43538 L
s
.3866 .4359 m
.38595 .4358 L
s
.38646 .43538 m
.3863 .43546 L
s
.38646 .43538 m
.38595 .4358 L
s
.38595 .4358 m
.38644 .43599 L
s
.38595 .4358 m
.3863 .43546 L
s
.38845 .43522 m
.38595 .4358 L
s
.3863 .43546 m
.38644 .43599 L
s
1 .006 0 r
.73562 .33157 m
.73537 .33148 L
s
.73542 .33153 m
.7354 .33152 L
s
.7354 .33152 m
.73542 .33147 L
s
.7354 .33152 m
.73537 .33148 L
s
.73542 .33147 m
.73544 .33147 L
s
.73542 .33147 m
.73537 .33148 L
s
.73537 .33148 m
.73542 .33153 L
s
.73537 .33148 m
.73544 .33147 L
s
.73544 .33147 m
.73542 .33153 L
s
1 .003 0 r
.66016 .29567 m
.66003 .29564 L
s
.66005 .29566 m
.66005 .29566 L
s
.66005 .29566 m
.66005 .29563 L
s
.66005 .29566 m
.66003 .29564 L
s
.66005 .29563 m
.66006 .29563 L
s
.66005 .29563 m
.66003 .29564 L
s
.66003 .29564 m
.66005 .29566 L
s
.66003 .29564 m
.66006 .29563 L
s
.66006 .29563 m
.66005 .29566 L
s
1 .066 0 r
.51041 .43314 m
.51043 .43305 L
s
.51043 .43305 m
.51041 .4324 L
s
.51043 .43305 m
.50977 .43278 L
s
.51041 .4324 m
.5104 .43249 L
s
.51041 .4324 m
.50977 .43278 L
s
.50977 .43278 m
.51041 .43314 L
s
.50977 .43278 m
.5104 .43249 L
s
.51301 .43272 m
.50977 .43278 L
s
1 .001 0 r
.58455 .25972 m
.58455 .25972 L
s
.58455 .25972 m
.58455 .25971 L
s
.58455 .25972 m
.58454 .25971 L
s
.58455 .25971 m
.58455 .25971 L
s
.58455 .25971 m
.58454 .25971 L
s
.58458 .25972 m
.58454 .25971 L
s
.58454 .25971 m
.58455 .25972 L
s
.58454 .25971 m
.58455 .25971 L
s
.58455 .25971 m
.58455 .25972 L
s
1 .066 0 r
.5104 .43249 m
.51041 .43314 L
s
1 .034 0 r
.43598 .39721 m
.43604 .39717 L
s
.43604 .39717 m
.43599 .39683 L
s
.43604 .39717 m
.43566 .39707 L
s
.43599 .39683 m
.43592 .39688 L
s
.43599 .39683 m
.43566 .39707 L
s
.43566 .39707 m
.43598 .39721 L
s
.43566 .39707 m
.43592 .39688 L
s
.43728 .39684 m
.43566 .39707 L
s
.43592 .39688 m
.43598 .39721 L
s
1 .001 0 r
.70959 .25697 m
.70956 .25696 L
s
1 .055 0 r
.63791 .43021 m
.63534 .42973 L
s
1 .001 0 r
.70957 .25696 m
.70956 .25696 L
s
.70956 .25696 m
.70957 .25696 L
s
.70956 .25696 m
.70956 .25696 L
s
.70957 .25696 m
.70957 .25696 L
s
.70957 .25696 m
.70956 .25696 L
s
.70956 .25696 m
.70957 .25696 L
s
.70956 .25696 m
.70957 .25696 L
s
.70957 .25696 m
.70957 .25696 L
s
1 .055 0 r
.63586 .43014 m
.63573 .43006 L
s
.63573 .43006 m
.63584 .42952 L
s
.63573 .43006 m
.63534 .42973 L
s
.63584 .42952 m
.63598 .4296 L
s
.63584 .42952 m
.63534 .42973 L
s
.63534 .42973 m
.63586 .43014 L
s
.63534 .42973 m
.63598 .4296 L
s
.63598 .4296 m
.63586 .43014 L
s
1 .035 0 r
.56079 .39439 m
.56076 .39435 L
s
.56076 .39435 m
.56078 .39401 L
s
.56076 .39435 m
.56044 .39418 L
s
.56078 .39401 m
.56081 .39405 L
s
.56078 .39401 m
.56044 .39418 L
s
.56216 .39428 m
.56044 .39418 L
s
1 0 0 r
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
.63389 .22091 m
.63389 .22091 L
s
1 .035 0 r
.56044 .39418 m
.56079 .39439 L
s
.56044 .39418 m
.56081 .39405 L
s
.56081 .39405 m
.56079 .39439 L
s
1 .018 0 r
.48561 .35844 m
.48563 .35842 L
s
.48563 .35842 m
.48561 .35824 L
s
.48563 .35842 m
.48544 .35835 L
s
.48561 .35824 m
.4856 .35826 L
s
.48561 .35824 m
.48544 .35835 L
s
.48544 .35835 m
.48561 .35844 L
s
.48544 .35835 m
.4856 .35826 L
s
.48631 .3583 m
.48544 .35835 L
s
1 .035 0 r
.76317 .42769 m
.76177 .42713 L
s
1 .018 0 r
.4856 .35826 m
.48561 .35844 L
s
1 .035 0 r
.76207 .42744 m
.7619 .42737 L
s
.7619 .42737 m
.76204 .42705 L
s
.7619 .42737 m
.76177 .42713 L
s
.76204 .42705 m
.7622 .42712 L
s
.76204 .42705 m
.76177 .42713 L
s
.7622 .42712 m
.76207 .42744 L
s
.76177 .42713 m
.76207 .42744 L
s
.76177 .42713 m
.7622 .42712 L
s
1 .026 0 r
.6874 .39171 m
.68622 .39141 L
s
.68646 .39161 m
.68638 .39158 L
s
.68638 .39158 m
.68645 .39132 L
s
.68638 .39158 m
.68622 .39141 L
s
.68645 .39132 m
.68653 .39136 L
s
.68645 .39132 m
.68622 .39141 L
s
.68622 .39141 m
.68646 .39161 L
s
.68622 .39141 m
.68653 .39136 L
s
.68653 .39136 m
.68646 .39161 L
s
1 .016 0 r
.61153 .35568 m
.61075 .35558 L
s
1 0 0 r
.68341 .18195 m
.68341 .18195 L
s
1 .016 0 r
.61091 .35568 m
.61088 .35567 L
s
.61088 .35567 m
.6109 .35551 L
s
.61088 .35567 m
.61075 .35558 L
s
.6109 .35551 m
.61093 .35552 L
s
.6109 .35551 m
.61075 .35558 L
s
.61075 .35558 m
.61091 .35568 L
s
.61075 .35558 m
.61093 .35552 L
s
.61093 .35552 m
.61091 .35568 L
s
1 .008 0 r
.53525 .31963 m
.53524 .31963 L
s
.53524 .31963 m
.53525 .31955 L
s
.53524 .31963 m
.53517 .31959 L
s
.53525 .31955 m
.53525 .31955 L
s
.53525 .31955 m
.53517 .31959 L
s
.53555 .31959 m
.53517 .31959 L
s
.53517 .31959 m
.53525 .31963 L
s
.53517 .31959 m
.53525 .31955 L
s
.53525 .31955 m
.53525 .31963 L
s
1 .011 0 r
.7371 .35305 m
.73661 .35289 L
s
.73672 .35299 m
.73667 .35297 L
s
.73667 .35297 m
.73671 .35286 L
s
.73667 .35297 m
.73661 .35289 L
s
.73671 .35286 m
.73675 .35288 L
s
.73671 .35286 m
.73661 .35289 L
s
.73661 .35289 m
.73672 .35299 L
s
.73661 .35289 m
.73675 .35288 L
s
.73675 .35288 m
.73672 .35299 L
s
1 .006 0 r
.6611 .31691 m
.6608 .31685 L
s
.66087 .3169 m
.66085 .31689 L
s
.66085 .31689 m
.66086 .31683 L
s
.66085 .31689 m
.6608 .31685 L
s
.66086 .31683 m
.66088 .31684 L
s
.66086 .31683 m
.6608 .31685 L
s
.6608 .31685 m
.66087 .3169 L
s
.6608 .31685 m
.66088 .31684 L
s
.66088 .31684 m
.66087 .3169 L
s
1 .003 0 r
.5849 .28073 m
.58489 .28073 L
s
.58489 .28073 m
.5849 .2807 L
s
.58489 .28073 m
.58487 .28072 L
s
.5849 .2807 m
.5849 .28071 L
s
.5849 .2807 m
.58487 .28072 L
s
.585 .28073 m
.58487 .28072 L
s
.58487 .28072 m
.5849 .28073 L
s
.58487 .28072 m
.5849 .28071 L
s
.5849 .28071 m
.5849 .28073 L
s
1 .05 0 r
.43473 .41937 m
.43483 .41931 L
s
.43483 .41931 m
.43475 .41881 L
s
.43483 .41931 m
.43426 .41916 L
s
.43475 .41881 m
.43465 .41888 L
s
.43475 .41881 m
.43426 .41916 L
s
.43426 .41916 m
.43473 .41937 L
s
.43426 .41916 m
.43465 .41888 L
s
.43666 .41883 m
.43426 .41916 L
s
.43465 .41888 m
.43473 .41937 L
s
1 .002 0 r
.71088 .27799 m
.71079 .27796 L
s
.71081 .27798 m
.71081 .27798 L
s
.71081 .27798 m
.71081 .27796 L
s
.71081 .27798 m
.71079 .27796 L
s
.71081 .27796 m
.71082 .27796 L
s
.71081 .27796 m
.71079 .27796 L
s
.71079 .27796 m
.71081 .27798 L
s
.71079 .27796 m
.71082 .27796 L
s
.71082 .27796 m
.71081 .27798 L
s
1 .051 0 r
.56039 .41645 m
.56035 .41639 L
s
.56035 .41639 m
.56038 .41588 L
s
.56035 .41639 m
.55988 .41613 L
s
.56038 .41588 m
.56042 .41594 L
s
.56038 .41588 m
.55988 .41613 L
s
1 .001 0 r
.63466 .2417 m
.63463 .24169 L
s
1 .051 0 r
.56242 .41628 m
.55988 .41613 L
s
1 .001 0 r
.63463 .2417 m
.63463 .2417 L
s
.63463 .2417 m
.63463 .24169 L
s
.63463 .2417 m
.63463 .24169 L
s
.63463 .24169 m
.63463 .24169 L
s
.63463 .24169 m
.63463 .24169 L
s
.63463 .24169 m
.63463 .2417 L
s
.63463 .24169 m
.63463 .24169 L
s
.63463 .24169 m
.63463 .2417 L
s
1 .051 0 r
.55988 .41613 m
.56039 .41645 L
s
.55988 .41613 m
.56042 .41594 L
s
.56042 .41594 m
.56039 .41645 L
s
1 .029 0 r
.48489 .38029 m
.48492 .38026 L
s
.48492 .38026 m
.4849 .37997 L
s
.48492 .38026 m
.48461 .38014 L
s
.4849 .37997 m
.48487 .38 L
s
.4849 .37997 m
.48461 .38014 L
s
.48461 .38014 m
.48489 .38029 L
s
.48461 .38014 m
.48487 .38 L
s
.48604 .38006 m
.48461 .38014 L
s
.48487 .38 m
.48489 .38029 L
s
1 .039 0 r
.68854 .41372 m
.68678 .41328 L
s
.68714 .41358 m
.68701 .41353 L
s
.68701 .41353 m
.68712 .41315 L
s
.68701 .41353 m
.68678 .41328 L
s
.68712 .41315 m
.68725 .41321 L
s
.68712 .41315 m
.68678 .41328 L
s
.68678 .41328 m
.68714 .41358 L
s
.68678 .41328 m
.68725 .41321 L
s
.68725 .41321 m
.68714 .41358 L
s
1 .026 0 r
.61214 .37745 m
.61086 .37729 L
s
1 0 0 r
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
.68452 .2025 m
.68452 .2025 L
s
1 .026 0 r
.61112 .37747 m
.61107 .37744 L
s
.61107 .37744 m
.61111 .37718 L
s
.61107 .37744 m
.61086 .37729 L
s
.61111 .37718 m
.61116 .37721 L
s
.61111 .37718 m
.61086 .37729 L
s
.61086 .37729 m
.61112 .37747 L
s
.61086 .37729 m
.61116 .37721 L
s
.61116 .37721 m
.61112 .37747 L
s
1 .014 0 r
.53505 .3412 m
.53505 .34119 L
s
.53505 .34119 m
.53505 .34104 L
s
.53505 .34119 m
.53491 .34112 L
s
.53505 .34104 m
.53505 .34106 L
s
.53505 .34104 m
.53491 .34112 L
s
.53562 .34113 m
.53491 .34112 L
s
.53491 .34112 m
.53505 .3412 L
s
.53491 .34112 m
.53505 .34106 L
s
.53505 .34106 m
.53505 .3412 L
s
1 .018 0 r
.73859 .37484 m
.73779 .37458 L
s
.73796 .37473 m
.73789 .37471 L
s
.73789 .37471 m
.73795 .37453 L
s
.73789 .37471 m
.73779 .37458 L
s
.73795 .37453 m
.73802 .37456 L
s
.73795 .37453 m
.73779 .37458 L
s
.73779 .37458 m
.73796 .37473 L
s
.73779 .37458 m
.73802 .37456 L
s
.73802 .37456 m
.73796 .37473 L
s
1 .012 0 r
.66206 .33846 m
.6615 .33835 L
s
.66162 .33844 m
.66159 .33843 L
s
.66159 .33843 m
.66161 .33831 L
s
.66159 .33843 m
.6615 .33835 L
s
.66161 .33831 m
.66164 .33832 L
s
.66161 .33831 m
.6615 .33835 L
s
.6615 .33835 m
.66162 .33844 L
s
.6615 .33835 m
.66164 .33832 L
s
.66164 .33832 m
.66162 .33844 L
s
1 .006 0 r
.58518 .30205 m
.58518 .30204 L
s
.58518 .30204 m
.58518 .30198 L
s
.58518 .30204 m
.58512 .30201 L
s
.58518 .30198 m
.58519 .30199 L
s
.58518 .30198 m
.58512 .30201 L
s
.58542 .30203 m
.58512 .30201 L
s
.58512 .30201 m
.58518 .30205 L
s
.58512 .30201 m
.58519 .30199 L
s
.58519 .30199 m
.58518 .30205 L
s
1 .005 0 r
.7122 .2993 m
.71199 .29925 L
s
.71203 .29928 m
.71202 .29928 L
s
.71202 .29928 m
.71203 .29923 L
s
.71202 .29928 m
.71199 .29925 L
s
.71203 .29923 m
.71204 .29924 L
s
.71203 .29923 m
.71199 .29925 L
s
.71199 .29925 m
.71203 .29928 L
s
.71199 .29925 m
.71204 .29924 L
s
.71204 .29924 m
.71203 .29928 L
s
1 .002 0 r
.63543 .26277 m
.63533 .26276 L
s
.63535 .26277 m
.63535 .26277 L
s
.63535 .26277 m
.63535 .26275 L
s
.63535 .26277 m
.63533 .26276 L
s
.63535 .26275 m
.63536 .26275 L
s
.63535 .26275 m
.63533 .26276 L
s
.63533 .26276 m
.63535 .26277 L
s
.63533 .26276 m
.63536 .26275 L
s
.63536 .26275 m
.63535 .26277 L
s
1 .043 0 r
.48405 .40247 m
.48409 .40242 L
s
.48409 .40242 m
.48406 .40199 L
s
.48409 .40242 m
.48363 .40225 L
s
.48406 .40199 m
.48403 .40204 L
s
.48406 .40199 m
.48363 .40225 L
s
.48363 .40225 m
.48405 .40247 L
s
.48363 .40225 m
.48403 .40204 L
s
.48576 .40213 m
.48363 .40225 L
s
.48403 .40204 m
.48405 .40247 L
s
1 0 0 r
.68565 .22334 m
.68563 .22334 L
s
1 .039 0 r
.61275 .39954 m
.61084 .3993 L
s
1 0 0 r
.68564 .22334 m
.68563 .22334 L
s
.68563 .22334 m
.68564 .22334 L
s
.68563 .22334 m
.68563 .22334 L
s
.68564 .22334 m
.68564 .22334 L
s
.68564 .22334 m
.68563 .22334 L
s
.68563 .22334 m
.68564 .22334 L
s
.68563 .22334 m
.68564 .22334 L
s
.68564 .22334 m
.68564 .22334 L
s
1 .039 0 r
.61123 .39956 m
.61116 .39952 L
s
.61116 .39952 m
.61122 .39912 L
s
.61116 .39952 m
.61084 .3993 L
s
.61122 .39912 m
.61129 .39917 L
s
.61122 .39912 m
.61084 .3993 L
s
.61084 .3993 m
.61123 .39956 L
s
.61084 .3993 m
.61129 .39917 L
s
.61129 .39917 m
.61123 .39956 L
s
1 .023 0 r
.53476 .36309 m
.53475 .36307 L
s
.53475 .36307 m
.53475 .36283 L
s
.53475 .36307 m
.53452 .36295 L
s
.53475 .36283 m
.53476 .36285 L
s
.53475 .36283 m
.53452 .36295 L
s
.5357 .36297 m
.53452 .36295 L
s
.53452 .36295 m
.53476 .36309 L
s
.53452 .36295 m
.53476 .36285 L
s
.53476 .36285 m
.53476 .36309 L
s
1 .028 0 r
.74011 .39693 m
.7389 .39655 L
s
.73916 .39678 m
.73904 .39674 L
s
.73904 .39674 m
.73913 .39647 L
s
.73904 .39674 m
.7389 .39655 L
s
.73913 .39647 m
.73925 .39652 L
s
.73913 .39647 m
.7389 .39655 L
s
.7389 .39655 m
.73916 .39678 L
s
.7389 .39655 m
.73925 .39652 L
s
.73925 .39652 m
.73916 .39678 L
s
1 .019 0 r
.66304 .36031 m
.66211 .36014 L
s
.6623 .36028 m
.66225 .36026 L
s
.66225 .36026 m
.66229 .36006 L
s
.66225 .36026 m
.66211 .36014 L
s
.66229 .36006 m
.66234 .36009 L
s
.66229 .36006 m
.66211 .36014 L
s
.66211 .36014 m
.6623 .36028 L
s
.66211 .36014 m
.66234 .36009 L
s
.66234 .36009 m
.6623 .36028 L
s
1 .011 0 r
.5854 .32367 m
.58539 .32366 L
s
.58539 .32366 m
.5854 .32355 L
s
.58539 .32366 m
.58529 .3236 L
s
.5854 .32355 m
.58541 .32355 L
s
.5854 .32355 m
.58529 .3236 L
s
.58585 .32364 m
.58529 .3236 L
s
.58529 .3236 m
.5854 .32367 L
s
.58529 .3236 m
.58541 .32355 L
s
.58541 .32355 m
.5854 .32367 L
s
1 .009 0 r
.71353 .32092 m
.71313 .32082 L
s
.71322 .32089 m
.71319 .32088 L
s
.71319 .32088 m
.71321 .3208 L
s
.71319 .32088 m
.71313 .32082 L
s
.71321 .3208 m
.71324 .32081 L
s
.71321 .3208 m
.71313 .32082 L
s
.71313 .32082 m
.71322 .32089 L
s
.71313 .32082 m
.71324 .32081 L
s
.71324 .32081 m
.71322 .32089 L
s
1 .005 0 r
.63622 .28415 m
.63599 .28411 L
s
.63604 .28415 m
.63603 .28414 L
s
.63603 .28414 m
.63604 .2841 L
s
.63603 .28414 m
.63599 .28411 L
s
.63604 .2841 m
.63604 .2841 L
s
.63604 .2841 m
.63599 .28411 L
s
.63599 .28411 m
.63604 .28415 L
s
.63599 .28411 m
.63604 .2841 L
s
.63604 .2841 m
.63604 .28415 L
s
1 .002 0 r
.6868 .24448 m
.68673 .24447 L
s
.68674 .24448 m
.68674 .24448 L
s
.68674 .24448 m
.68674 .24446 L
s
.68674 .24448 m
.68673 .24447 L
s
.68674 .24446 m
.68675 .24446 L
s
.68674 .24446 m
.68673 .24447 L
s
.68673 .24447 m
.68674 .24448 L
s
.68673 .24447 m
.68675 .24446 L
s
.68675 .24446 m
.68674 .24448 L
s
1 .035 0 r
.53436 .3853 m
.53435 .38526 L
s
.53435 .38526 m
.53436 .38491 L
s
.53435 .38526 m
.53401 .3851 L
s
.53436 .38491 m
.53437 .38495 L
s
.53436 .38491 m
.53401 .3851 L
s
.53577 .38513 m
.53401 .3851 L
s
.53401 .3851 m
.53436 .3853 L
s
.53401 .3851 m
.53437 .38495 L
s
.53437 .38495 m
.53436 .3853 L
s
1 .029 0 r
.66402 .38248 m
.66263 .38222 L
s
.66291 .38243 m
.66284 .3824 L
s
.66284 .3824 m
.6629 .38211 L
s
.66284 .3824 m
.66263 .38222 L
s
.6629 .38211 m
.66298 .38214 L
s
.6629 .38211 m
.66263 .38222 L
s
.66263 .38222 m
.66291 .38243 L
s
.66263 .38222 m
.66298 .38214 L
s
.66298 .38214 m
.66291 .38243 L
s
1 .018 0 r
.58554 .34561 m
.58552 .34559 L
s
.58552 .34559 m
.58554 .3454 L
s
.58552 .34559 m
.58536 .34549 L
s
.58554 .3454 m
.58556 .34542 L
s
.58554 .3454 m
.58536 .34549 L
s
.58628 .34556 m
.58536 .34549 L
s
.58536 .34549 m
.58554 .34561 L
s
.58536 .34549 m
.58556 .34542 L
s
.58556 .34542 m
.58554 .34561 L
s
1 .014 0 r
.71488 .34286 m
.71422 .34269 L
s
.71436 .3428 m
.71431 .34279 L
s
.71431 .34279 m
.71435 .34264 L
s
.71431 .34279 m
.71422 .34269 L
s
.71435 .34264 m
.7144 .34266 L
s
.71435 .34264 m
.71422 .34269 L
s
.71422 .34269 m
.71436 .3428 L
s
.71422 .34269 m
.7144 .34266 L
s
.7144 .34266 m
.71436 .3428 L
s
1 .009 0 r
.63701 .30583 m
.63659 .30577 L
s
.63667 .30583 m
.63666 .30582 L
s
.63666 .30582 m
.63667 .30573 L
s
.63666 .30582 m
.63659 .30577 L
s
.63667 .30573 m
.63669 .30574 L
s
.63667 .30573 m
.63659 .30577 L
s
.63659 .30577 m
.63667 .30583 L
s
.63659 .30577 m
.63669 .30574 L
s
.63669 .30574 m
.63667 .30583 L
s
1 .003 0 r
.68796 .26593 m
.6878 .26589 L
s
.68783 .26592 m
.68782 .26591 L
s
.68782 .26591 m
.68783 .26588 L
s
.68782 .26591 m
.6878 .26589 L
s
.68783 .26588 m
.68784 .26588 L
s
.68783 .26588 m
.6878 .26589 L
s
.6878 .26589 m
.68783 .26592 L
s
.6878 .26589 m
.68784 .26588 L
s
.68784 .26588 m
.68783 .26592 L
s
1 .028 0 r
.58561 .36787 m
.58557 .36784 L
s
.58557 .36784 m
.5856 .36755 L
s
.58557 .36784 m
.58532 .36769 L
s
.5856 .36755 m
.58563 .36758 L
s
.5856 .36755 m
.58532 .36769 L
s
.58672 .3678 m
.58532 .36769 L
s
.58532 .36769 m
.58561 .36787 L
s
.58532 .36769 m
.58563 .36758 L
s
.58563 .36758 m
.58561 .36787 L
s
1 .022 0 r
.71626 .36511 m
.71525 .36485 L
s
.71546 .36503 m
.71538 .365 L
s
.71538 .365 m
.71544 .36478 L
s
.71538 .365 m
.71525 .36485 L
s
.71544 .36478 m
.71552 .36481 L
s
.71544 .36478 m
.71525 .36485 L
s
.71525 .36485 m
.71546 .36503 L
s
.71525 .36485 m
.71552 .36481 L
s
.71552 .36481 m
.71546 .36503 L
s
1 .014 0 r
.63782 .32783 m
.63711 .32773 L
s
.63726 .32783 m
.63723 .32781 L
s
.63723 .32781 m
.63725 .32767 L
s
.63723 .32781 m
.63711 .32773 L
s
.63725 .32767 m
.63728 .32768 L
s
.63725 .32767 m
.63711 .32773 L
s
.63711 .32773 m
.63726 .32783 L
s
.63711 .32773 m
.63728 .32768 L
s
.63728 .32768 m
.63726 .32783 L
s
1 .007 0 r
.68914 .28768 m
.68882 .28762 L
s
.68889 .28767 m
.68887 .28766 L
s
.68887 .28766 m
.68889 .28759 L
s
.68887 .28766 m
.68882 .28762 L
s
.68889 .28759 m
.6889 .2876 L
s
.68889 .28759 m
.68882 .28762 L
s
.68882 .28762 m
.68889 .28767 L
s
.68882 .28762 m
.6889 .2876 L
s
.6889 .2876 m
.68889 .28767 L
s
1 .022 0 r
.63864 .35015 m
.63756 .35 L
s
.63778 .35015 m
.63774 .35013 L
s
.63774 .35013 m
.63778 .3499 L
s
.63774 .35013 m
.63756 .35 L
s
.63778 .3499 m
.63782 .34993 L
s
.63778 .3499 m
.63756 .35 L
s
.63756 .35 m
.63778 .35015 L
s
.63756 .35 m
.63782 .34993 L
s
.63782 .34993 m
.63778 .35015 L
s
1 .011 0 r
.69034 .30976 m
.68981 .30965 L
s
.68992 .30973 m
.68989 .30972 L
s
.68989 .30972 m
.68991 .30961 L
s
.68989 .30972 m
.68981 .30965 L
s
.68991 .30961 m
.68994 .30962 L
s
.68991 .30961 m
.68981 .30965 L
s
.68981 .30965 m
.68992 .30973 L
s
.68981 .30965 m
.68994 .30962 L
s
.68994 .30962 m
.68992 .30973 L
s
1 .017 0 r
.69156 .33215 m
.69074 .33199 L
s
.69091 .33212 m
.69086 .3321 L
s
.69086 .3321 m
.6909 .33193 L
s
.69086 .3321 m
.69074 .33199 L
s
.6909 .33193 m
.69094 .33195 L
s
.6909 .33193 m
.69074 .33199 L
s
.69074 .33199 m
.69091 .33212 L
s
.69074 .33199 m
.69094 .33195 L
s
.69094 .33195 m
.69091 .33212 L
s
0 g
.25 Mabswid
.68389 0 m
.95694 .42575 L
s
.95694 .42575 m
1 .74078 L
s
1 .74078 m
.70392 .345 L
s
.70392 .345 m
.68389 0 L
s
.05221 .25273 m
0 .58221 L
s
0 .58221 m
.70392 .345 L
s
.70392 .345 m
.68389 0 L
s
.68389 0 m
.05221 .25273 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 514.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009000020R000`400?l00000o`00003ooooonfZ9
oookJP;o0000]_oonfX00?oooo]ZQ_oonfX3o`000003oookJ_l0003ooo]Z0;Gooo]Z003ooookJXCo
oo]Z0_l00004oookJP;o0000]OoonfX00?oooo]ZPOoonfX3o`0000Kooo]Z00?o0000oookJ_l00000
]?oonfX00?oooo]ZOooonfX2o`0000Wooo]Z00?o0000oookJ_l00000]?oonfX00?oooo]ZO?oonfX3
o`0000_ooo]Z00Co0000oookJ_oonf[o0000/ooonfX00?oooo]ZN_oonfX2o`0000kooo]Z00Go0000
oookJ_oonf[ooo]Zo`00002boookJP00oooonfYgoookJP?o00004?oonfX01Ol0003ooo]ZoookJ_oo
nf[o00000;;ooo]Z003ooookJWGooo]Z0_l0000CoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX0[ooonfX00?oooo]ZL_oonfX3o`0001Gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP2_oookJP00oooonfY`oookJP;o00006OoonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z0:kooo]Z003ooookJVgooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z00?ooo]Z
00?o0000oookJ_oonfX0[OoonfX00?oooo]ZJooonfX2o`0001kooo]Z00?o0000oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP2]oookJP00oooonfYXoookJP?o00008?oonfX00ol0003ooo]ZoookJP04
oookJP03o`000?oonf[ooo]Z0:cooo]Z003ooookJVKooo]Z0_l0000SoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX0ZooonfX00?oooo]ZHooonfX3o`0002Gooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP2[oookJP00oooonfYQoookJP;o0000:?oonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z0:[ooo]Z003ooookJUkooo]Z0ol0000ZoookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0ZOoonfX00?oooo]ZG?oonfX2o`0002gooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP2YoookJP00oooonfYJoookJP;o0000;ooonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0:Sooo]Z003ooookJUOooo]Z0ol0000aoookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0Z?oonfX00?oooo]ZEOoonfX2o`0003Cooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP2WoookJP00oooonfYBoookJP?o0000=_oo
nfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0:Kooo]Z003ooookJU3ooo]Z0_l0000i
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0Y_oonfX00?oooo]ZCOoonfX3o`00
03_ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP2UoookJP00oooonfY;oookJP;o
0000?_oonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z0:Cooo]Z003ooookJTSooo]Z
0ol0000koookJP03ool40?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Z
oookJP2ToookJP00oooonfY6oookJP;o0000?OoonfX2ool400Cooo]Z00?o0000oookJ_oonfX03Ooo
nfX00ol0003ooo]ZoookJP2SoookJP00oooonfY3oookJP?o0000A_oonfX00ol0003ooo]ZoookJP0=
oookJP03o`000?oonf[ooo]Z0:;ooo]Z003ooookJT7ooo]Z0_l00019oookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX0X_oonfX00?oooo]Z?_oonfX3o`0004_ooo]Z00?o0000oookJ_oo
nfX03_oonfX00ol0003ooo]ZoookJP2QoookJP00oooonfXloookJP;o0000C_oonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z0:3ooo]Z003ooookJSWooo]Z0ol0001@oookJP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0X?oonfX00?oooo]Z=ooonfX2o`0005?ooo]Z00?o0000
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2OoookJP00oooonfXdoookJP?o0000EOoonfX00ol0
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z09oooo]Z003ooookJS;ooo]Z0_l0001HoookJP03
o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0W_oonfX00?oooo]Z;ooonfX3o`0005[ooo]Z
00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2MoookJP00oooonfX]oookJP;o0000>ooo
nfX00ooo1@3ooo]ZoookJP0IoookJP03ool20?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX04_oo
nfX00ol0003ooo]ZoookJP2MoookJP00oooonfXZoookJP?o0000?OoonfX00ooo1@3ooo]ZoookJP0O
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0W?oonfX00?oooo]Z:?oonfX2o`00
06;ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2KoookJP00oooonfXUoookJP?o
0000I?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z09_ooo]Z003ooookJR?ooo]Z
0_l0001WoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0V_oonfX00?oooo]Z8?oo
nfX3o`0006Wooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP2IoookJP00oooonfXN
oookJP;o0000K?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z09Wooo]Z003ooook
JQ_ooo]Z0ol0001^oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0V?oonfX00?oo
oo]Z6OoonfX2o`00077ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP2GoookJP00
oooonfXFoookJP?o0000M?oonfX00ol0003ooo]ZoookJP02oookJP;oo`D04ooonfX00ol0003ooo]Z
oookJP2GoookJP00oooonfXDoookJP;o0000MooonfX00ol0003ooo]ZoookJP03oookJP03ool50?oo
nf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0U_oonfX00?oooo]Z4OoonfX3o`0003_ooo]Z00?oo`L0
oookJ_oonfX06?oonfX2ool301[ooo]Z0_oo0@05oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000
oookJ_oonfX0U_oonfX00?oooo]Z3ooonfX2o`0007cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0
003ooo]ZoookJP2EoookJP00oooonfX<oookJP?o0000O_oonfX00ol0003ooo]ZoookJP0JoookJP03
o`000?oonf[ooo]Z09Cooo]Z003ooookJP[ooo]Z0_l00021oookJP03o`000?oonf[ooo]Z01[ooo]Z
00?o0000oookJ_oonfX0U?oonfX00?oooo]Z1ooonfX3o`0008?ooo]Z00?o0000oookJ_oonfX06ooo
nfX00ol0003ooo]ZoookJP2CoookJP00oooonfX5oookJP;o0000Q_oonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z09;ooo]Z003ooookJP;ooo]Z0ol00028oookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX0T_oonfX00?oooo]Z0_l0002;oookJP03o`000?oonf[ooo]Z01go
oo]Z00?o0000oookJ_oonfX0TOoonfX00?gooo]Z0_l0002=oookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX0T?oonfX00?[ooo]Z0ol0001ioookJP;oo`L05?oonfX00ol0003ooo]Zoook
JP03oookJP03ool30?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0T?oonfX00?Sooo]Z0_l0000i
oookJP;oo`P06OoonfX00ooo103ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX0SooonfX00?Gooo]Z0ol0000loookJP03ool80?oonf[ooo]Z01Oooo]Z00?oo`@0oook
J_oonfX06?oonfX2ool201_ooo]Z00?oo`00oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0Ooook
JP03o`000?oonf[ooo]Z08oooo]Z003coookJP;o0000UooonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z08kooo]Z003`oookJP?o0000VOoonfX00ol0003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z08gooo]Z003^oookJP;o0000W?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z08gooo]Z003[oookJP?o0000W_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o
oo]Z08cooo]Z003YoookJP;o0000X_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
08_ooo]Z003VoookJP?o0000Y?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z08_o
oo]Z003ToookJP;o0000YooonfX00ol0003ooo]ZoookJP0>oookJP03ool70?oonf[ooo]Z01;ooo]Z
00?o0000oookJ_oonfX0R_oonfX00>7ooo]Z0ol0001goookJP;oo`T06OoonfX2ool401Gooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP29oookJP00gooonfX2o`0003Wooo]Z00?oo`/0
oookJ_oonfX0F_oonfX00ooo103ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00?ooo]Z00?oo`80
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP29oookJP00g?oonfX3o`0003[ooo]Z0_oo2`0Hoook
JP;oo`D06OoonfX2ool203gooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP28oook
JP00f_oonfX2o`0007;ooo]Z00?oo`80oookJ_oonfX06OoonfX00ooo0@3ooo]ZoookJP0JoookJP03
ool00?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP27oookJP00
eooonfX3o`000;?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP27oookJP00eOoo
nfX2o`000;Kooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP26oookJP00d_oonfX3
o`000;Sooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP26oookJP00d?oonfX2o`00
0;_ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP25oookJP00cOoonfX3o`000;go
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP24oookJP00booonfX2o`000;Kooo]Z
0_oo2@08oookJP03o`000?oonf[ooo]Z00oooo]Z00?oo`@0oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP24oookJP00b?oonfX3o`0007Kooo]Z0_oo3@1:oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX0PooonfX00<Kooo]Z0_l0000hoookJP03ool<0?oonf[ooo]Z05Wooo]Z00?oo`H0
oookJ_oonfX06?oonfX00ooo0`3ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000
oookJ_oonfX0P_oonfX00<?ooo]Z0ol0000ioookJP;oo``06?oonfX2ool707;ooo]Z00?o0000oook
J_oonfX00ooonfX2ool102Kooo]Z00?o0000oookJ_oonfX0P_oonfX00<7ooo]Z0_l0001`oookJP;o
o`<06OoonfX2ool103gooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP21oookJP00
__oonfX3o`0008gooo]Z00?oo`40oookJ_oonfX06OoonfX2ool001_ooo]Z00?oo`00oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z083ooo]Z002loookJP;o0000d?oo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z083ooo]Z002ioookJP?o0000d_oonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z07oooo]Z002goookJP;o0000eOoonfX00ol0
003ooo]ZoookJP0IoookJP;oo`P04ooonfX00ol0003ooo]ZoookJP1noookJP00]?oonfX3o`000=Oo
oo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP1noookJP00/_oonfX2o`000;Gooo]Z
0_oo3P0IoookJP03ool60?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Z
oookJP1moookJP00[ooonfX3o`0007Gooo]Z0ooo401JoookJP03ool60?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX03_oonfX2ool201oooo]Z00?o0000oookJ_oonfX0OOoonfX00:gooo]Z0_l0000h
oookJP03ool>0?oonf[ooo]Z05Oooo]Z0_oo200IoookJP03ool40?oonf[ooo]Z02oooo]Z00?o0000
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP1loookJP00Z_oonfX3o`0003Wooo]Z0_oo3P0Goook
JP;oo`P0FooonfX00ooo103ooo]ZoookJP0HoookJP;oo`405OoonfX00ol0003ooo]ZoookJP0aoook
JP03o`000?oonf[ooo]Z07_ooo]Z002XoookJP;o0000KooonfX00ooo103ooo]ZoookJP1boookJP03
o`000?oonf[ooo]Z00?ooo]Z00?oo`00oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1koookJP00
Y_oonfX2o`0008_ooo]Z0_oo0P0JoookJP03ool00?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol0003ooo]ZoookJP1joookJP00XooonfX3o`000:Sooo]Z0_oo000KoookJP03ool00?oo
nf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1ioookJP00XOoonfX2
o`000>Gooo]Z00?oo`00oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[o
oo]Z07Wooo]Z002NoookJP?o0000kOoonfX01?l0003ooo]Zool=0?oo3@0coookJP03o`000?oonf[o
oo]Z07Sooo]Z002LoookJP;o0000/OoonfX2oolC03gooo]Z00?o0000oookJ_oonfX06_oonfX00ooo
1@3ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z07Oooo]Z002IoookJP?o0000]?oonfX00ooo4`3o
oo]ZoookJP0FoookJP;oo`T08ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z07Oo
oo]Z002GoookJP;o0000MOoonfX3oolD05Wooo]Z00?oo`T0oookJ_oonfX05ooonfX00ooo103ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0M_oonfX009Cooo]Z0ol0
000foookJP;oo`h0F?oonfX2ool;01Wooo]Z00?oo`D0oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0?oookJP03ool10?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0M_oonfX009;ooo]Z0_l0001A
oookJP;oo`T0F_oonfX2ool501Wooo]Z0_oo0P0`oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000
oookJ_oonfX0MOoonfX008oooo]Z0ol0001]oookJP03ool50?oonf[ooo]Z05[ooo]Z00?oo`80oook
J_oonfX06OoonfX00ooo003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oook
J_oonfX0M?oonfX008gooo]Z0_l00029oookJP;oo`80MOoonfX00ol0003ooo]ZoookJP03oookJP03
ool00?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0M?oonfX008[ooo]Z0ol0002VoookJP03ool0
0?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX09?oonfX2ool;01;ooo]Z00?o0000oookJ_oonfX0
LooonfX008Sooo]Z0_l00035oookJP03ool00?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX09?oo
nfX2ool;01?ooo]Z00?o0000oookJ_oonfX0L_oonfX008Gooo]Z0ol0003SoookJP03ool00?oonf[o
oo]Z00Oooo]Z0ooo4`0GoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0L_oonfX0
08?ooo]Z0_l0002`oookJPCooaX0D?oonfX00ooo003ooo]ZoookJP03oookJP03o`000?oo203oo`P0
01[ooo]Z00?oo`<0oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP1aoookJP00P?oonfX3o`0007?o
oo]Z0_oo5`1GoookJP;oo`d0?_oonfX00ol0003ooo]ZoookJP0JoookJP03ool30?oonf[ooo]Z01ko
oo]Z00?o0000oookJ_oonfX0L?oonfX007kooo]Z0_l0000eoookJP;oo`h0?_oonfX00ooo5`3ooo]Z
oookJP0FoookJP;oo`h0FOoonfX2ool502Cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Z
oookJP1`oookJP00NooonfX3o`0003Oooo]Z00?oo`h0oookJ_oonfX0EOoonfX00ooo3P3ooo]Zool>
000HoookJP03ool70?oonf[ooo]Z05[ooo]Z00?oo`80oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP0loookJP03o`000?oonf[ooo]Z06oooo]Z001ioookJP;o0000DOoonfX2ool905Wooo]Z0_oo1`0I
oookJP03ool30?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX03ooonfX00ooo003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z06kooo]Z001foookJP?o0000K?oonfX2ool505[ooo]Z0_oo0`0Joook
JP03ool10?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1^oook
JP00M?oonfX2o`0008Sooo]Z0_oo0P1LoookJP;oo`406ooonfX00ooo003ooo]ZoookJP0CoookJP03
o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0KOoonfX0077ooo]Z0ol0002ToookJP;oo`40
MOoonfX00ol0003ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z00?ooo]Z0_oo400boookJP03o`00
0?oonf[ooo]Z06gooo]Z001_oookJP;o0000`_oonfX00ooo003ooo]ZoookJP0VoookJP?ooad0<?oo
nfX00ol0003ooo]ZoookJP0UoookJP03ool70?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0K?oo
nfX006cooo]Z0ol0002_oookJP;oob80;ooonfX00ooo003ooo]ZoookJP0<oookJP03oolM0?oonf[o
oo]Z01Gooo]Z0_oo3@0GoookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0JooonfX0
06[ooo]Z0_l0001aoookJP;ooaP0?OoonfX3oolR01Sooo]Z00?ooa80oookJ_oonfX0<_oonfX00ooo
003ooo]ZoookJP08oookJP03ool=0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo1@00@?oonfX00ol0
003ooo]ZoookJP1[oookJP00IooonfX3o`0007;ooo]Z00?ooaP0oookJ_oo6000E_oonfX3oolB057o
oo]Z00?oo`00oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0KoookJP03ool20?oonf[ooo]Z02?o
oo]Z00?o0000oookJ_oonfX0J_oonfX006Gooo]Z0_l0000foookJP03ool<0?oonf[ooo]Z05Cooo]Z
0ooo401HoookJP;oo`P0?_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z06Wooo]Z
001RoookJP?o0000=ooonfX00ooo303ooo]ZoookJP0EoookJP03ool90?oonf[ooo]Z05Kooo]Z0_oo
201KoookJP03ool30?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Zoook
JP1YoookJP00H?oonfX2o`0005;ooo]Z00?oo`T0oookJ_oonfX0L?oonfX2ool305cooo]Z0_oo0@09
oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0J?oonfX005gooo]Z0ol0001/oook
JP03ool60?oonf[ooo]Z07?ooo]Z00?oo`40oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0?oook
JP03ool00?oonf[ooo]Z01cooo]Z0_oo300CoookJP03o`000?oonf[ooo]Z06Oooo]Z001KoookJP;o
0000QooonfX2ool305_ooo]Z0_oo0@0ooookJP;ooaX03?oonfX00ol0003ooo]ZoookJP13oookJP03
o`000?oonf[ooo]Z06Oooo]Z001HoookJP?o0000XooonfX00ooo0@3ooo]ZoookJP15oookJP03ool[
0?oonf[ooo]Z01Cooo]Z00?oo`00oookJ_oonfX08ooonfX2oolJ00_ooo]Z00?o0000oookJ_oonfX0
2OoonfX2ool;03Wooo]Z00?o0000oookJ_oonfX0I_oonfX005Kooo]Z0_l0002]oookJP?oobP04?oo
nfX00ooo003ooo]ZoookJP0WoookJPGoob/0<_oonfX00ooo003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?oo`/0oookJ_oonfX06?oonfX00ooo103ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z06Gooo]Z001CoookJP?o0000KooonfX00ooo5`3ooo]ZoookJP0koookJP;oobP000?ooo]Z
oolX0?oonfX0:ooonfX00ooo003ooo]ZoookJP0VoookJP?ooa@0<OoonfX00ol0003ooo]ZoookJP03
oookJP03ool00?oonf[ooo]Z01oooo]Z00?oo`@0oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP1U
oookJP00DOoonfX2o`00077ooo]Z0_oo5`1FoookJP?ooaP0EooonfX2ool801Sooo]Z00?o0000oook
J_oonfX0A_oonfX00ol0003ooo]ZoookJP1ToookJP00C_oonfX3o`0003Cooo]Z00?oo`/0oookJ_oo
nfX0EOoonfX00ooo403ooo]ZoookJP1EoookJP;oo``06?oonfX00ooo003ooo]ZoookJP0noookJP03
o`000?oo0`3oo`<004Kooo]Z00?o0000oookJ_oonfX0I?oonfX004cooo]Z0_l0000goookJP03ool;
0?oonf[ooo]Z05Cooo]Z00?ooa00oookJ_oonfX05_oonfX00ooo2P3ooo]ZoookJP0noookJP03ool<
0?oonf[ooo]Z01Oooo]Z00?oo`@0oookJ_oonfX06OoonfX00ooo003ooo]ZoookJP0QoookJP03o`00
0?oonf[ooo]Z01[ooo]Z0_oo000[oookJP03o`000?oonf[ooo]Z06?ooo]Z001:oookJP;o0000D?oo
nfX00ooo203ooo]ZoookJP1EoookJP;oo`X0FOoonfX2ool403Wooo]Z00?oo`00oookJ_oonfX00ooo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z06;ooo]Z0017oookJP?o0000JOoonfX0
0ooo1@3ooo]ZoookJP1GoookJP;oo`@0FooonfX00ooo0@3ooo]ZoookJP0SoookJP03o`000?oonf[o
oo]Z01Cooo]Z0ooo500aoookJP03o`000?oonf[ooo]Z06;ooo]Z0015oookJP;o0000Q?oonfX2ool3
05[ooo]Z00?oo`40oookJ_oonfX0?_oonfX2ool[01cooo]Z00?oo`00oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP0EoookJP;ooa@06?oonfX2ool801Sooo]Z00?o0000oookJ_oonfX0HOoonfX004;o
oo]Z0ol00026oookJP03ool30?oonf[ooo]Z063ooo]Z00?ooc/0oookJ_oonfX04OoonfX00ooo003o
oo]ZoookJP0UoookJP?oob/08ooonfX00ol0003ooo]ZoookJP0@oookJP03ool00?oonf[ooo]Z01go
oo]Z00?oo`P0oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP1PoookJP00@?oonfX2o`000:;ooo]Z
00?oo`40oookJ_oonfX01_oonfX2ool[03[ooo]Z1ooo>`0BoookJP03ool00?oonf[ooo]Z02Kooo]Z
0_oo:`0EoookJP?ooa802ooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z063ooo]Z
000moookJP?o0000ZooonfX3ool[013ooo]Z00?oo`00oookJ_oonfX0@OoonfX4oolN01Oooo]Z00?o
o`00oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0:oookJP;oo`L0?ooonfX00ol0003ooo]Zoook
JP1OoookJP00>ooonfX2o`00073ooo]Z00?ooa@0oookJ_oonfX0DooonfX3oolM01;ooo]Z00?oo`00
oookJ_oonfX0:_oonfX00ooo7P3ooo]ZoookJP0DoookJP;oo`d07?oonfX00ooo003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z02Kooo]Z00?oo`80oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP1N
oookJP00>?oonfX3o`0003?ooo]Z00?oo`P0oookJ_oonfX0>ooonfX00ooo503ooo]ZoookJP0Eoook
JP03ool@0?oonf[ooo]Z09Kooo]Z00?oo`d0oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP1<oook
JP03o`000?oonf[ooo]Z05kooo]Z000foookJP;o0000=OoonfX2ool805Cooo]Z0_oo401GoookJP;o
o`l05_oonfX00ooo003ooo]ZoookJP10oookJP03ool40?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oo
nfX01?oonfX00ooo003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z05gooo]Z000coookJP?o0000
C_oonfX00ooo1`3ooo]ZoookJP1DoookJP;oo`X0F?oonfX2ool601Wooo]Z00?oo`00oookJ_oonfX0
?_oonfX00ol0003oo`40oookJP0ioookJP03ool>0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0
GOoonfX0037ooo]Z0_l0001XoookJP03ool50?oonf[ooo]Z05Kooo]Z00?oo`D0oookJ_oonfX0FOoo
nfX00ooo0P3ooo]ZoookJP0koookJP;oob8000?ooo]Zo`000?oonfX06ooonfX00ooo003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z05cooo]Z000^oookJP?o0000J_oonfX00ooo1@3ooo]ZoookJP1F
oookJP03ool50?oonf[ooo]Z01oooo]Z0_ooB`0goookJP;oo`8000?oodD0oookJ_oonfX06?oonfX2
ool002;ooo]Z00?oob80o`000?oonfX05OoonfX00ooo3P3ooo]ZoookJP03oookJP03ool00?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX0FooonfX002cooo]Z0_l00024oookJP03ool30?oonf[ooo]Z
023ooo]Z00?oobP0oookJ_oonfX0=OoonfX00ooo0P3ooo]ZoookJP05oookJPCood/0>OoonfX4oom5
01Gooo]Z00?oo`00oookJ_oonfX08_oonfX00ooo8P3o0000oookJP0FoookJP03ool>0?oonf[ooo]Z
03Kooo]Z00?o0000oookJ_oonfX0FooonfX002Wooo]Z0ol0002OoookJP03ool10?oonf[ooo]Z00Ko
oo]Z0_oo:00koookJPCood/000?ooo]Zoom;0?ooB`003ooonfX00ooo003ooo]ZoookJP0ZoookJP?o
odD04_oonfX3oolN01_ooo]Z00?oo`00oookJ_oonfX00_oo0005oookJP03o`000?oonf[ooo]Z02oo
oo]Z0_oo1@0NoookJP03o`000?oonf[ooo]Z05[ooo]Z000WoookJP;o0000XOoonfX2ool100Oooo]Z
00?oobP0oookJ_oonfX0DOoonfX00ooo003ooo]Zool/0005ool/03cooo]Z00?ooah0oookJ_oonfX0
5OoonfX2ool<00cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1IoookJP009?oo
nfX3o`0006kooo]Z00?ooa00oookJ_oonfX0C?oonfX00ooo003ooo]ZoookJP05oookJP;ooah0?ooo
nfX00ooo;03ooo]ZoookJP0BoookJP03ool00?oonf[ooo]Z03oooo]Z00?oo``0oookJ_oonfX02_oo
nfX00ol0003ooo]ZoookJP0?oookJP03ool00?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0FOoo
nfX002;ooo]Z0_l0001`oookJP03ool@0?oonf[ooo]Z01Gooo]Z00?oo`h0oookJ_oonfX0>ooonfX2
oolN01;ooo]Z00?oo`00oookJ_oonfX0@_oonfX3oolD01Sooo]Z00?oo`00oookJ_oonfX0<?oonfX0
0ol0003ooo]ZoookJP0:oookJP03ool30?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0F?oonfX0
01oooo]Z0ol0000doookJP;oo`L0DooonfX2ool>05Gooo]Z0ooo4`1HoookJP03ool70?oonf[ooo]Z
037ooo]Z00?o0000oookJ_oonfX09OoonfX2ool102_ooo]Z00?o0000oookJ_oonfX0EooonfX001ko
oo]Z0_l0001<oookJP;oo`D0EOoonfX00ooo2P3ooo]ZoookJP1BoookJP05ool00?oonf[ooo]Zoook
J_oo2000FooonfX00ooo0P3ooo]Zool0000FoookJP03o`000?oonf[ooo]Z01oooo]Z0_oo5`0aoook
JP03o`000?oonf[ooo]Z05Oooo]Z000NoookJP03o`000?oonf[o00000:7ooo]Z00?oo`X0oookJ_oo
nfX0>OoonfX3oomA01[ooo]Z0_oo201HoookJP;ooc/000?oo`80oookJ_oonfX05ooonfX00ol0003o
oo]ZoookJP0PoookJP03oolG0?oonf[ooo]Z01Oooo]Z00?oo`T0oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP1FoookJP007_oonfX01?l0003ooo]ZoookJ_l0001QoookJP03ool40?oonf[ooo]Z05Co
oo]Z0_oo1@0PoookJPCooe40<ooonfX2ool000;oo`<01_ooJP02oookJP;oofX0=_oonfX3oolk01Oo
oo]Z00?o0000oookJ_oo00001?oonfX00ooo003ooo]ZoookJP0coookJP03ool90?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX0EOoonfX001kooo]Z00Go0000oookJ_oonf[ooo]Zo`00001goookJP03
ool20?oonf[ooo]Z023ooo]Z00?oob80oookJ_oonfX0=?oonfX00ooo0P3ooo]ZoookJP03oookJP;o
oe400_oonfX00oooD@3ooo]ZoookJP0loookJPGoofX03_oonfX00ooo003ooo]ZoookJP0UoookJP;o
oc/05OoonfX2oolH0003o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0EOoonfX001gooo]Z
00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP2FoookJP;oob80=OoonfX00ooo0P3ooo]Z
oookJP03oookJP03oomA0?oonf[ooo]Z01Sooo]Z0ooo>00XoookJP03oomZ0?oonf[ooo]Z00kooo]Z
00?oo`00oolc0?oo<`000_oo<`0koookJP03oolH0?l0003ooo]Z01Kooo]Z0_oo2004oookJP03ool0
0?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0E?oonfX001gooo]Z00?o0000oookJ_oonfX01?oo
nfX00ol0003ooo]ZoookJP2:oookJP;oo`402?oonfX00ooo8P3ooo]ZoookJP0EoookJP;ooad0>?oo
nfX01?oo003ooo]ZoookJ_oonfX3oolh0003oookJ_oo>03ooo]Z03cooo]Z0_oo<`0DoookJP;ooa@0
00?oo`00oookJ_oo00008ooonfX00ol0003ooo]ZoookJP0aoookJP03ool20?oonf[ooo]Z027ooo]Z
00?o0000oookJ_oonfX0E?oonfX001gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP1EoookJP;oo`d0BooonfX00ooo003ooo]ZoookJP06oookJP;ooad0EooonfX00ooo7@3ooo]Zoook
JP0koookJP;ooa@09OoonfX00ol0003ooo]ZoookJP0`oookJP03ool20?oonf[ooo]Z02?ooo]Z00?o
0000oookJ_oonfX0DooonfX001gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0G
oookJP03ool50?oonf[ooo]Z057ooo]Z00?oo`/0oookJ_oonfX0<ooonfX00ooo003ooo]ZoookJP05
oookJP03oolM0?oonf[ooo]Z05;ooo]Z00?oo`00oookJ_oo7@000ooo7@1FoookJP;oo`H00_oonfX0
1Ooo003ooo]ZoookJ_oonf[oo`0000Gooo]Z00?o0000oookJ_oonfX0A?oonfX00ooo3P3ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z05;ooo]Z000MoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX05_oonfX00ooo1@3ooo]ZoookJP1AoookJP03ool;0?oonf[ooo]Z04cooo]Z00?oo`00
oookJ_oonfX01?oonfX2oolD03gooo]Z0_ooT`0GoookJP03ool00?oo2`3oo`/004cooo]Z00?o0000
oookJ_oonfX02ooonfX00ooo0@3ooo]ZoookJP0foookJP03ool>0?oonf[ooo]Z013ooo]Z00?o0000
oookJ_oonfX0D_oonfX001gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0Zoook
JP03ool40?oonf[ooo]Z05?ooo]Z00?oo`P0oookJ_oonfX0=_oonfX3oom;01cooo]Z00?oo`/0oook
J_oonfX08ooonfX3oonC01Sooo]Z00?oo`/0oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP05oook
JP;oobP00_oonfX2ool100Cooo]Z00?oo`00oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1Aoook
JP007?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z07kooo]Z00?oo`P0oookJ_oo
nfX0=ooonfX00oooB`3ooo]Zoom;000FoookJP03ool00?oonf[ooo]Z00;ooo]Z0_oo2`0QoookJPSo
oi<0;ooonfX00oooJP3oo`<0ool0000coookJP03o`000?oonf[ooo]Z00Kooo]Z0_oo:00GoookJP03
ool@0?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1@oookJP00
7?oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z03kooo]Z00?oo`<0oookJ_oonfX0
E?oonfX00ooo1@3ooo]ZoookJP0NoookJP03oom;0?oonf[ood/003Kooo]Z00?oo`@0oookJ_ooT`00
1_ooT`04oookJP;ooi<0=?oonfX3oomZ0003oookJ_ooJP3ooo]Z013ooo]Z0_oo;00KoookJP03o`00
0?oonf[ooo]Z00Oooo]Z00?oobP0oookJ_oonfX05OoonfX2ool@03Oooo]Z00?o0000oookJ_oonfX0
D?oonfX001cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP1DoookJP03ool20?oo
nf[ooo]Z023ooo]Z00?ooaX0oookJ_oonfX0>_oonfX00oooB`3ooo]ZoookJP0GoookJP?oocd06Ooo
nfX00ooo003ooo]ZoookJP02ool4023ooo]Z0_ooDP0SoookJP?oofX04_oonfX01Ooo;03oo`00oook
J_oonf[oo`0001Kooo]Z00?o0000oookJ_oonfX0>_oonfX00ooo1@3ooo]ZoookJP0LoookJP03o`00
0?oonf[ooo]Z04oooo]Z000LoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0Dooo
nfX00ooo0P3ooo]ZoookJP0OoookJP;ooaX0=?oonfX00ooo0P3ooo]ZoookJP04oookJP03oom;0?oo
nf[ooo]Z01Kooo]Z1?oo?@0foookJP03ool00?oo0@3ooo]Z00Wooe808_oonfX4oomZ01;ooo]Z0_oo
;00EoookJP;oo`l000Cooo]Zo`000?oonf[oo`00F_oonfX00ol0003ooo]ZoookJP1>oookJP007?oo
nfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z03Oooo]Z00?oo`T0oookJ_oonfX0;ooo
nfX00ooo0@3ooo]ZoookJP08oookJP03oolJ0?oonf[ooo]Z01Cooo]Z0_oo600foookJP03ool00?oo
nf[ooo]Z00;ooo]Z0_oo?@0GoookJP?oojH0:OoonfX00oooDP3ooo]ZoookJP0@oookJP?oob<0?Ooo
nfX00ooo3`3ooo]Zo`000005oookJP03ool00?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0C_oo
nfX001cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0foookJP03ool90?oonf[o
oo]Z057ooo]Z0_oo600foookJP03ool00?oonf[ooo]Z01[ooo]Z0oooYP02oolV03_ooo]Z00Coo`00
oookJ_oo8`3oob<0?_oonfX00ol0003ooo]ZoookJP0EoookJP03ool40?oonf[ooo]Z00?ooo]Z00?o
o`00oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP1=oookJP007?oonfX00ol0003ooo]ZoookJP0;
oookJP03ool40?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0B_oonfX2ool803?ooo]Z00?oo`00
oookJ_oonfX01_oonfX00ooo603ooo]ZoookJP0EoookJP;ooa<0>OoonfX01?oo003ooo]ZoookJ_oo
YP04oolV03_ooo]Z00?oo`00oookJ_oonfX05_oonfX3ool;02Kooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ooo603ooo]ZoookJP05oookJP03ool10?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0COoo
nfX001_ooo]Z00?o0000oookJ_oonfX03?oonfX00ooo103ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z04Wooo]Z0_oo201CoookJP03oolC0?oonf[ooa<003Wooo]Z0oooYP001?oonf[oojH0oonV0?oo
YP0GoookJP03oolA0?oonf[ooo]Z03Cooo]Z1?l02_l4oookJP04ool;0?oonf[oo`00ool101?ooo]Z
00?ood/0oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0ZoookJP03oolH0?oonf[ooo]Z00?ooo]Z
00?oo`40oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1<oookJP006ooonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z00[ooo]Z0_oo0`1CoookJP03ool70?oonf[ooo]Z03?ooo]Z00?o
o`00oookJ_oo>`000_oo>`0moookJP;oojH01?oonfX00oooYP3ooo]ZoookJP0CoookJP03ool00?oo
nf[ooa4000;ooa40=?oonfX2o`0:o`04oookJ_l02_oooo]ZoookJP?o00[o1?oonfX00ooo0@3ooo]Z
oookJP0BoookJP03oom;0?oonf[oo`<000?ooo]Z00?oo`00oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP14oookJP03ool90?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0BooonfX001_ooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP1NoookJP03ool70?oonf[ooo]Z03Kooo]Z0_oo
>`0KoookJP;oo`/07OoonfX3oonV01cooo]Z0_ooM@0JoookJP;oo`D00ooo_@09oookJP;ookd02ooo
nfX2o`0:o`Cooo]Z00?o00[ooookJ_oonfX00_oonfX4o`0:oaKooo]Z0_ooB`07oookJP03ool10?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01OoonfX2oolM00Cooo]Z00?oo`00oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP1;oookJP006ooonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[o
oo]Z01kooo]Z00?oo`80oookJ_oonfX0DooonfX00ooo103ooo]ZoookJP0NoookJP03oolk0?oonf[o
oo]Z01Gooo]Z00?oo`00oolh0?oonfX07OoonfX01Ooo1@3ooo]ZoookJ_oonf[oojH001kooo]Z1?oo
M@0HoookJP03ool00?oonf[ooo]Z00?ooo]Z1_oo_@03oookJP?ookd02?oonfX2oomB00Oo00[o2?oo
nfX3o`0:oaCooo]Z0_ooB`06oookJP03ool10?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01_oo
nfX2oolM00;ooo]Z0_oo0004oookJP03ool00?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0B_oo
nfX001_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0coookJP03ool20?oonf[o
oo]Z023ooo]Z00?ooa<0oookJ_oonfX0>_oonfX00ooo>`3ooo]ZoookJP0FoookJP;oocP00ooonfX<
o`0:o`Wooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo1@3ooo]ZoookJP0LoookJPGoogD000?ooo]Z
oome0?ooM@009OoonfX5oonm0003oookJ_oo_@3ooo]Z00Oooo]Z00Ooo`40oomB0?ooDP3ooe80oook
J_ooDP3ooo]Z00_o00[o00Cooo]Zo`0:ool02_oo00[o4OoonfX2oom;00cooo]Z00?o0000oookJ_oo
nfX08?oonfX00ooo2P3ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oo
nfX0BOoonfX001_ooo]Z00?o0000oookJ_oonfX05ooonfX2o`0003?ooo]Z00?oo`80oookJ_oonfX0
8?oonfX2oolC03;ooo]Z0_oo0P0OoookJP03oolh0?oonf[oocP000?ooo]Z00?o00[ooookJ_oonfX0
0ol02_l4oookJP03o`0:oooonf[o00[o00Cooi<08?oonfX2o`3oPP03oookJ_oo0@3ooo]Z00?oogD0
1_oonfX00oooM@3ooo]ZoookJP0VoookJP;ookd000Cooo]Zoonm0?oo_@3ookd02?oonfX00ooo003o
oo]ZoookJP02oomB00;ooo]Z00?o00[ooookJ_oonfX01ooonfX6o`0:o`03oookJ_oo7@3ooad001[o
oo]Z00?o0000oookJ_oonfX0>ooonfX00ooo0`3ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z04Wo
oo]Z000JoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX05_oonfX2ool702oooo]Z
00?oo`40oookJ_oonfX02OoonfX00ooo4`3ooo]ZoookJP0CoookJP;ooa80??oonfX00ooo>03ooo]Z
oookJP04oookJP;o00[o1?oonfX4o`0:o`?ooo]Z1?ooT`02oookJP;oobX06OoonfX2o`3oPP04ool0
0?oonf[o0?n2ool100oooo]Z1?n:o`08oookJPGoocX05?oonfX3oonm00_ooo]Z00?o00[ooookJ_oo
nfX00oooDP000ooonf[o00[ooookJP09oookJPGo00[o0_oonfX00ooo7@3oo`00oookJP0HoookJP03
o`000?oonf[ooo]Z03_ooo]Z00?oo`<0oookJ_oonfX03ooonfX00ooo3P3ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z04Sooo]Z000JoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0
5OoonfX00ooo1`3ooo]ZoookJP0]oookJP;oo`408OoonfX2oolB03Cooo]Z0_oo000=oookJP?o00[o
1OoonfX00ol02_oooo]Zo`0:o`02o`0:o`Cooi<00ooo:P0HoookJP?o0?n200?ooo]Zool00?l0oh80
0_l0oh8>oookJPSoR_l00ooonfX00ooo003ooo]ZoookJP03oookJP;oocX01OoonfX2olko01[ooo]Z
00?o00[ooookJ_oonfX01?oonfX00ol02_oooo]ZoookJP05oookJP?o00[o0_oonfX2o`0:o`Oooo]Z
00?oo`00oookJ_oonfX04_oonfX00ooo203ooo]Zo`00001?oookJP;oo`h04_oonfX00ol0003ooo]Z
oookJP17oookJP006_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z02Wooo]Z0_oo
1P0aoookJP03ool00?oonf[ooo]Z01oooo]Z00?oo`l0oookJ_oonfX0:ooonfX01?l02_oooo]Zo`0:
ool02_l3oookJP0:o`0:oooonf[ooo]ZoookJ_ooT`3ooo]Zo`0:ooooT`3o00[ooolZ00;o00[o5ooo
nfX3o`3oPPCooo]Z00?o0?n2oookJ_l0oh803_oonfX01On:o`3ooo]ZoookJ_n:o`3ooo]Z00CoR_l0
00?ooo]Zool00?oonfX03?oonfX01?o>o`3ooo]Zolko0?o>o`0:oookJP?ooa@03?oonfX00ol02_oo
oo]ZoookJP04oookJP04o`0:oooonf[ooo]ZoookJP?o00[o1?oonfX2o`0:oaoooo]Z00?o0000oook
J_oo00004?oonfX00ooo:`3ooo]ZoookJP03oookJP03ool20?oonf[ooo]Z04Sooo]Z00?o0000oook
J_oonfX0AooonfX001[ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0XoookJP03
ool60?oonf[ooo]Z05;ooo]Z00?oo`l0oookJ_oonfX0:_oonfX02?l02_oooo]ZoookJ_l02_oooo]Z
o`0:oooonf[o00[o0_oonfX2oonC0003ool00?oonf[ooo]Z00?ooo]Z1?l02_lAoookJPCoohH00_oo
5`04oookJP?o0?n200?ooo]Zo`3oP_oonfX03?oonfX00on:o`3ooo]ZoookJP06oh[o00;oo`003Ooo
nfX01?o>o`3ooo]ZoookJ_oonfX2olko00Sooo]Z00?oo`00oolD0?oo50003?oonfX00ol02_oooo]Z
oookJP04oookJP;o00[o0_ooT`06oookJP;o00[o8?oonfX00ol0003ooo]ZoookJP04oookJP03ool1
0?oonf[ooo]Z00[ooo]Z0_oo:`03oookJP03ool20?oonf[ooo]Z017ooo]Z00?ooa00oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP16oookJP006_oonfX00ol0003ooo]ZoookJP0;oookJP03ool20?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0?OoonfX2ool503?ooo]Z00Goo`00oookJ_oonf[ooo]Z
ool[000LoookJP;oo`/05?oonfX01?l02_oooo]ZoookJ_l02_l2oookJP;o00[o00?ooo]ZoonC0?oo
nfX02_oonfX2o`0:o`oooo]Z0oooQP03oolG00Gooo]Z0_l0oh801?oonf[o0?n2oookJ_l0oh8=oook
JP03oh[o0?o>o`3oc_l000;oc_l000?oR_l0olko0?o>o`005_o>o`0GoookJP04o`0:oooonf[ooo]Z
oookJP?o00[o0ooonfX00ooo1@3ooi<0oookJP02oookJP;o00[o8_oonfX00ol0003ooo]ZoookJP0@
oookJP;oob/02OoonfX00ooo003ooo]ZoookJP0;oookJP;ooa001OoonfX00ooo003ooo]ZoookJP0_
oookJP03o`000?oonf[ooo]Z04Gooo]Z000JoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000ool2
0?oonfX0M?oonfX2ool[01cooo]Z0_oo2`0DoookJP06o`0:oooonf[ooo]ZoookJ_l02_oooo]Z0_l0
2_l00oooT`3ooo]ZoookJP0;oookJP03o`0:oooonf[ooo]Z00[ooo]Z0_ooQP000ooo003ooo]Zo`3o
PP02oon600Oooo]Z00Co0?n2oookJ_oonf[ooo]Z0_l0oh8:oookJP04oh[o0?oo203oo`P0oh[o00;o
oo]Z0on:o`0AoookJP03olko0?oonf[oc_l000;oc_l02OoonfX00ooo0@3ooo]ZoookJP0=oookJPCo
00[o0ooonfX00ol02_oooo]ZoookJP02oookJP04ool00?oonf[o00[oo`0:oa7ooo]Z0_oo>00@oook
JP03o`000?oonf[ooo]Z033ooo]Z00?oo`00oookJ_oonfX04OoonfX00ooo1P3ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z04Gooo]Z000IoookJP03o`000?oonf[ooo]Z027ooo]Z00?oo`80oookJ_oo
nfX0D_oonfX00ooo0`3ooo]ZoookJP0NoookJP03ool[0?oonf[ooo]Z01?ooo]Z00?oo`00oookJ_oo
;0006ooonfX01?l02_oooo]ZoookJ_oonfX2o`0:o`;ooo]Z00?o00[ooookJ_oonfX02_oonfX00ol0
2_oooo]ZoookJP08oookJP?oohH00oo>o`02oookJP03o`3oP_oonf[ooo]Z00Gooo]Z0_l0oh84oook
JP;o0?n21ooonfX2oh[o00;ooo]Z00Ooo`P0oh[o0?oonf[ooo]Zoh[o0?oonf[oR_l0017ooo]Z0_o>
o`03oonK01Sooo]Z0_l02_l3o`0bo`?ooo]Z00?o00[ooookJ_oonfX00ooonfX01?l02_oooi<0oook
J_ooT`0BoookJP;oocP000?oo`40oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP05oookJP03oolC
0?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0A?oonfX001Wooo]Z00?o0000oookJ_oonfX08_oo
nfX00ol0003ooo]ZoookJP0BoookJP03ool10?oonf[ooo]Z023ooo]Z0_oo3P0koookJP03ool[0?oo
nf[ooo]Z01Cooo]Z0_oo;00KoookJP04o`0:oooonf[oo`D0oookJP;o00[o0ooonfX00ol02_oooo]Z
oookJP08oookJP03o`0:oooonf[ooo]Z00Sooo]Z00GoohH0olko0?o>o`3oc_l0oookJP02olko00?o
oo]Z00?o0?n2oookJ_oonfX01?oonfX2o`3oPPGooo]Z00?o0?n2oookJ_oonfX00_oonfX2oh[o0003
oomF0?oonf[oo`0000Cooo]Z1?n:o`0BoookJP03olko0?oo0@3ooo]Z00;ooo]Z1OooV`03oookJP;o
oi/02ooonfX01_l02_oo03;oo`0bool0<_oooo]Zo`0:o`;ooo]Z1?l0<_l4oookJP03o`0:oooonf[o
o`8000?ooi<04OoonfX3oolh00;ooo]Z00?oo`00oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP06
oookJP03oolC0?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0A?oonfX001Wooo]Z00?o0000oook
J_oonfX08ooonfX00ol0003ooo]ZoookJP0AoookJP03ool10?oonf[ooo]Z023ooo]Z00?oo`h0oook
J_oonfX0<?oonfX00ooo0P3ooo]ZoookJP0NoookJP03ool/0?oonf[ooo]Z00kooo]Z0_ooJP05oook
JP03ool00?oonf[ooo]Z00;ooo]Z00Ko00[ooookJ_oonf[o00[ooookJ_l02_l4oookJP03o`0:oooo
nf[ooo]Z00Kooo]Z00?o00[ooookJ_oonfX01OoonfX01Ooo0@3ooo]ZoookJ_oonf[oc_l000?ooo]Z
0oo>o`04oookJP03o`3oP_oonf[ooo]Z00;ooo]Z00?o0?n2oookJ_l0oh801OoonfX2o`3oPP;oR_l0
1OooEP05oookJP;oR_l07_oonfX6oonK00Oooo]Z0_l02_l2o`0bo`;oocX01?l0<_l5oookJP?o03;o
00Oo00[ooookJ_l02_oooo]ZoonC0?oonf[ooi<001Kooo]Z00?oo`00oookJ_oonfX02?oonfX00ol0
003ooo]ZoookJP0:oookJP03ool00?oonf[ooo]Z01;ooo]Z00?oo`D0oookJ_oonfX0@_oonfX00ol0
003ooo]ZoookJP13oookJP006OoonfX00ol0003ooo]ZoookJP0NoookJP03ool50?oonf[ooo]Z00?o
oo]Z00?o0000oookJ_oonfX09_oonfX00ooo003ooo]ZoookJP0PoookJP03ool=0?oonf[ooo]Z03[o
oo]Z00?oob`0oookJ_oonfX03_oonfX3oomZ00Gooo]Z0_oo9P03oookJP04o`0:oooonf[ooo]Zo`0:
o`;ooo]Z00Go00[ooookJ_oonf[ooo]Zo`0:o`07oookJP03o`0:oooonf[ooo]Z00Kooo]Z00?oo`40
oookJ_oonfX00_oonfX01?o>o`3ooo]Zolko0?oonfX2olko00Gooo]Z00Co0?n2oookJ_oonf[ooo]Z
0_l0oh84oookJP;o0?n21?ooEP03oookJP03oomF0?oonf[ooo]Z01[ooo]Z00?oo`00oookJ_oonfX0
2OoonfX5oonK00?ooo]Z0ol02_l2oookJP04o`0boooonf[ooo]Zool000?oocX03_l0<_l3oonC01Wo
oo]Z00?oo`80oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0@oookJP03ool00?oonf[ooo]Z00go
oo]Z00?oo`D0oookJ_oonfX04?oonfX00ooo5`3ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z04;o
oo]Z000IoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX09OoonfX00ooo003ooo]Z
oookJP0PoookJP03ool=0?oonf[ooo]Z037ooo]Z0_oo000IoookJP;oofX00ooonfX3oolV00?ooo]Z
00Co00[ooookJ_oonf[o00[o0ol0<_l00ol02_oo03;oo`0bo`02oookJP03o`0:oooonf[oogD000;o
ogD00_oonfX01Ol02_oooo]ZoookJ_oonf[oo`0000[ooo]Z00?oc_l0oookJ_o>o`000_o>o`06oook
JP05o`3oP_oonf[o0?n2oookJ_l0oh800_oonfX2o`3oPP;oR_l0<OoonfX2oonK00;ooo]Z0ol02_l6
oookJP04o`0boooonf[ooo]ZoookJP;oocX000?o00[ooookJ_oonfX00ooonfX2o`0:o`03oookJ_l0
2_oooo]Z00Go03;o1?oonfX2oolA01Cooo]Z00?ooe40oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP0@oookJP03ool00?oonf[ooo]Z01?ooo]Z00?oo`00oookJ_oonfX02_oonfX2oolG00Kooo]Z00?o
o`40oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP12oookJP006OoonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?oo`@0oookJ_oonfX0;_oonfX00ooo003ooo]ZoookJP0O
oookJP;oo``0=_oonfX00oooJP3ooo]ZoookJP09oookJP06o`0:oooonf[o00[ooookJ_l0<_oooo]Z
0ol0<_l01?oonf[o03;oo`0bool0<_l4oome0003oookJ_l02_oooo]Z00;ooo]Z00?oo`00oookJ_oo
nfX02?oonfX2olko0003oookJ_o>o`3ooo]Z00Sooo]Z0_l0oh801_oonf[o0?n2oh[o0?l0oh;oR_l0
ool001_ooo]Z1?oo9004oookJP;onOl03ooonfX2olko0003o`0:oooonf[ooo]Z00Oooo]Z00Co03;o
oookJ_oo0@3oo`400_oonfX00ol02_oo03;ooookJP03oookJP?o00[o0_oonfX5o`0bo`Oooo]Z00?o
o`00oookJ_oonfX04OoonfX00oooD@3ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z04gooo]Z00?o
o`T0oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP11oookJP006OoonfX00ol0003ooo]ZoookJP0W
oookJP03o`000?oonf[ooo]Z05cooo]Z00?oo``0oookJ_oonfX0=?oonfX00ooo003oofX0oookJP0:
oookJP;o00[o0_oonfX2o`0bo`;ooo]Z00Oo00[oo`0bool0<_oo03;ooookJ_ooM@3o00[o00;oogD0
00Co00[ooolI0?oo6@3ooaT02ooonfX01?o>o`3ooo]ZoookJ_o>o`0;oookJP?o0?n200?oo`40o`3o
E?oonfX03OoonfX5okOo00gooo]Z00?oob@0oookJ_oonfX00_oonfX4ooWo00[ooo]Z0ol02_l2oook
JP;oc_l02?oonfX00ol0<_oooo]ZoookJP04oookJP04o`0:oooonf[ooo]ZoookJP?o00[o0ol0<_l2
oookJP;o03;o7OoonfX01_ooD@3ooo]Zool40?oo103ooo]Zo`0001;ooo]Z00?ooah0oookJ_oonfX0
E?oonfX00ol0003ooo]ZoookJP10oookJP006?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z01gooo]Z0_oo100aoookJP03ool00?oonf[ooo]Z00;ooo]Z00?ooad0oookJ_oonfX06_oo
nfX00ooo203ooo]ZoookJP0MoookJP03oomZ0?oonf[ooo]Z00[ooo]Z0_l02_l2oookJP?o03;o00?o
oo]Zo`0:oooonfX00_oonfX00oooM@3o03;ooome0002o`0:o`;o03;o3?oonfX00oo>o`3ooo]Zoook
JP0<oookJP06oh[o0?l0oeCo0?mDool10?oonf[o0?mD3OoonfX9okOo00Kooo]Z00?oo`00oookJ_oo
nfX01_oonfX00ooio`3ooo]ZooWo0002ooWo00Kooo]Z0ol02_l3oookJP;oo`T00_oonfX2olko00Oo
oo]Z00?o03;ooookJ_oonfX00ooonfX00ol02_oooo]ZoookJP02o`0:o`03o`0booooM@3oogD000?o
oo]Z0_l0<_l;oookJP;oo`404_oonfX2oomA00;ooo]Z00?o0000oookJ_oo00004?oonfX2oolN00Co
oo]Z00?oo`00oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP10oookJP006?oonfX00ol0003ooo]Z
oookJP0;oookJP;oo`407OoonfX00ol0003ooo]ZoookJP1DoookJP;ooad06ooonfX00ooo203ooo]Z
oookJP0LoookJP03oomZ0?oonf[ooo]Z00gooo]Z0_l02_l02Ol0<_oooo]Zo`0bool0<_oooo]Zo`0:
oooonf[oogD0ool00002oookJP?o03;o00?ooo]Zo`0boooonfX02OoonfX00oo>o`3ooo]ZoookJP06
oookJP03oomS0?oonf[ooo]Z00;oo`/000Gooo]Zo`3oE?l0oeCo0?mDoookJP04o`3oE0cooo]Z00?o
]ol0oookJ_oonfX00_ngo`02ooWo0003okOo0?oio`3onOl001ConOl00ooonfX2o`0:o`cooo]Z0_o>
o`05oookJP03o`0boooonf[ooo]Z00?ooo]Z00Co00[oo`0bool02_oo03;o1?oonfX01?ooM@3ooo]Z
o`0bool0<_lOoookJP?ooe400_oonfX00ol0003ooo]ZoookJP0AoookJP05oolN0?oonf[ooo]Zoook
J_oo00005?oonfX00ooo2P3ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z03oooo]Z000HoookJP03
o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0<OoonfX00ooo0`3ooo]ZoookJP0OoookJP03
oolM0?oonf[ooo]Z01Cooo]Z00?ooah0oookJ_oonfX06ooonfX00ooo1@3ooo]ZoookJP0EoookJP08
o`0bool02_oo00[oo`0boooonf[o03;oo`0:ooooM@04oookJP03o`0:oooonf[o00[o00Co03;o1ooo
nfX00oo>o`3ooo]ZoookJP06oookJP?oof<00_oonfX2o`3oE003o`3oP_oonf[ooo]Z00;ooo]Z00?o
0?mDoookJ_l0oe@03OoonfX3okOo00;ooo]Z0_ngo`04oookJP;oo`802_oonfX4ooWo00;ooo]Z0ol0
2_l8oookJP03ool00?oonf[ooo]Z00Gooo]Z0_o>o`03oookJP04o`0boooonf[ooo]ZoookJP?o03;o
00?o00[ooookJ_oonfX00ooonfX2ool10003o`0booooM@3o03;o01?ooo]Z00?oobH0oookJ_oonfX0
3_oonfX00ol0003ooo]ZoookJP04oookJP03ool20?oonf[ooo]Z01Gooo]Z00?oo`00oookJ_oonfX0
B_oonfX00ol0003ooo]ZoookJP0noookJP006?oonfX00ol0003ooo]ZoookJP0QoookJP03ool10?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX05_oonfX00ooo2@3ooo]ZoookJP1<oookJP03ool00?oo
nf[ooo]Z00;ooah07?oonfX2ool501Oooo]Z00Co03;ooookJ_oonf[o03;o0_oonfX00oooM@3o00[o
oookJP02oookJP05o`0:oooonf[ooo]ZoookJ_l02_l00_oonfX3o`0bo`Cooo]Z00?oc_l0oookJ_oo
nfX01OoonfX2oomS0003ool00?ooH`3ooo]Z00;o0?mD0_oonfX01?l0oh;ooo]ZoookJ_oonfX3o`3o
E003oookJ_l0oeCooo]Z00Wooo]Z0ongo`02ool20003oookJ_ngo`3o]ol0017ooo]Z0_oio`000ooo
nf[o00[oo`0:o`04oomd01;ooo]Z0oo>o`001?oonf[o03;oo`0bool0<_l3oookJP03o`0boooonf[o
oo]Z00Cooo]Z00?o03;ooookJ_l0<_l00oooM@0BoookJP;oobH03_oonfX00ol0003ooo]ZoookJP04
oookJP03ool20?oonf[ooo]Z02[ooo]Z00?oo`00oookJ_oonfX04OoonfX00ooo0`3ooo]ZoookJP0>
oookJP;oo``04OoonfX00ol0003ooo]ZoookJP0noookJP006?oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z04Kooo]Z00?oo`40oookJ_oonfX07_oonfX00ooo7P3ooo]ZoookJP0doook
JP08o`0boooonf[ooo]ZoookJ_l0<_oo00[oo`0bool02_l2oookJP03o`0:oooonf[ooo]Z00?ooo]Z
00?o00[ooookJ_oonfX00_oonfX01?l0<_oooo]ZoookJ_o>o`05oookJP?oof<01?oonfX01Ol0oeCo
oo]ZoookJ_oonf[o0?n200Cooo]Z0_l0oe@00ooonf[o0?mDo`3oE007oookJP?o]ol00_oonfX00ong
o`3ooo]ZoookJP02okOo01;ooo]Z00?onOl0o`0:ool02_l01_oonfX6oomd00;ooo]Z00?oo`80oook
J_oonfX02OoonfX3o`0bo`?ooo]Z0oo>o`000ol0<_oooo]ZoookJP02oookJP03o`0boooonf[oo`00
00;ooo]Z0_ooM@0BoookJP;oobH000?oo`00oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP06oook
JP03ool;0?oonf[ooo]Z017ooo]Z00?oobP0oookJ_oonfX0>OoonfX00ooo303ooo]ZoookJP0Aoook
JP03o`000?oonf[ooo]Z03gooo]Z000HoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX01OoonfX00ooo003ooo]ZoookJP0QoookJP03ool90?oonf[ooo]Z04[ooo]Z00?oodD0oookJ_oo
nfX00ooonfX00ooo003ooad0oolM000MoookJP;oo`4000?ookd0oookJ_oonfX00_l0<_l2o`0:o`03
o`0bool02_oooo]Z00Kooo]Z00Oo00[ooookJ_oonf[ooo]Zo`0boooonf[oc_l000Gooo]Z00?oof<0
ooWo0?oio`000_oio`03oookJP05o`3oE?oonf[ooo]ZoookJ_l0oh801?oonfX01?l0oeCooo]Zoook
J_oonfX2o`3oE0?ooo]Z0ongo`04oookJP03ool00?oonf[o]ol000;o]ol04?oonfX3o`0:o`Cooo]Z
00?oo`00oookJ_oonfX01_oonfX3oomd00[ooo]Z0ol0<_l01_l0Koooob@0oolT0?oo903oc_l0oook
JP;oc_l000?ooo]Zo`0boooonfX00_oonfX00ol0<_oooo]Zo`0bo`02oookJP?oogD00ooonfX00ooo
YP3ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Kooo]Z00?oo`/0oookJ_oonfX04OoonfX00ooo
:03ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z03cooo]Z000GoookJP03o`000?oonf[ooo]Z01oo
oo]Z00?oo`<0oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP1KoookJP03ool00?oonf[ooo]Z01Ko
oo]Z0oooA@04oookJP03oolM0?oonf[ooo]Z01gooo]Z00?ookd0o`0boooo_@000_oonfX2o`0bo`;o
oo]Z00?o00[oo`0boooonfX01ooonfX01Ol02_oooo]Zo`0boooonf[oc_l000Cooo]Z1Ooio`000ooo
nf[onOl0oookJP03oookJP04o`3oE?oonf[ooo]Zo`3oPP?ooo]Z0_l0oe@4oookJP05o`3oE?ngo`3o
]ol0okOo0?oonfX00ooo=`03oookJP03ool00?oonf[o]ol000oooo]Z0ol02_l7oookJP03ool00?oo
nf[ooo]Z00Kooo]Z00?oog@0oookJ_oonfX01ooonfX3o`0bo`06oookJ_l0Kooo06oooookJ_l0Kooo
oo]Z0_oo9003o`1_o`07olko0?l0<_oooo]ZoookJ_l0<_oooo]Zo`0bo`03oookJP03ool30?oonf[o
oo]Z00?ooo]Z00?oojH0oookJ_oonfX04_oonfX00ooo0@3ooo]ZoookJP07oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?oo`00oookJ_oonfX03?oonfX2oolX00Cooo]Z0_oo0P0BoookJP03ool@0?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX0??oonfX001Oooo]Z00?o0000oookJ_oonfX07ooonfX00ooo
0`3ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01[ooo]Z00?oo`00oookJ_oonfX08?oonfX00ooo
203ooo]ZoookJP0doookJP03oom50?oonf[ooo]Z01Cooo]Z0oooDP05oookJP;oo`001?oonfX00ooo
_@3ooo]Zo`0bo`02oonm0003o`0boooonf[o03;o00?ooo]Z00?o03;ooookJ_oonfX01_oonfX01?l0
2_oo03;ooookJ_o>o`03oookJP03ool00?oonf[onOl000;ooo]Z1?oio`05oookJP03o`3oE?l0oh;o
oo]Z00?ooo]Z0_l0oe@3oookJP03okOo0?l0oeCo0?mD00?oocL000?ooo]Zoolg0?oonfX04_oonfX3
o`0:o`?o0?n25ooonfX3o`0bo`?ooo]Z00?o06oooookJ_oonfX00_oonfX01_oo003oob@0oookJ_o>
o`3ooo]Zolko00?o06oo00Co03;ooookJ_oonf[o03;o0ooonfX00ooo0`3ooo]ZoookJP04oookJP03
oonV0?oonf[ooo]Z01Gooo]Z00?oocd0oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0doookJP03
ool@0?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0>ooonfX001Oooo]Z00?o0000oookJ_oonfX0
<_oonfX2o`000003ool30?oonf[ooo]Z06oooo]Z00?oo`00oom50?oonfX05ooonfX2oomB00Cooo]Z
0_oo5`06oookJP05oonm0?l0<_oookd0oonm0?l0<_l00_oonfX01Ol0<_oooo]ZoookJ_oonf[o03;o
00Oooo]Z00?o03;oo`0:ooo>o`001ooonfX2ooWo0004oookJ_oio`3onOl0ooWo00Kooo]Z00Co0?mD
oookJ_oonf[ooo]Z0_l0oe@01Ooonf[o]ol0okOo0?ngo`3o0?mD01Sooo]Z0_l02_l6oookJPKo0?n2
00?oo`40oookJ_oonfX02ooonfX3o`0bo`Gooo]Z3?l0Kol01?oonf[oc_l0o`0boooonfX4o`1_o`[o
oo]Z00?oojH0ool80?oonfX05?oonfX00ooo?@3ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z02Oo
oo]Z00?oo`00oookJ_oonfX04_oonfX00ooo003ooo]ZoookJP0?oookJP03ool50?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX0>ooonfX001Oooo]Z00?o0000oookJ_oonfX0=?oonfX00ooo0`3ooo]Z
oookJP0^oookJP03ool00?oonf[ooo]Z00?ooo]Z0_oo4`0JoookJP;oo`H07_oonfX00oooA@3ooo]Z
oookJP0EoookJP03oomB0?oonf[ooo]Z00cooo]Z00Co03;ooonm0?oonf[o03;o0ooonfX01?l0<_oo
oo]ZoookJ_oonfX2oomF00Gooo]Z00Co03;ooookJ_oo0@3o00[o1ooonfX2ooWo0004oookJ_oio`3o
nOl0ooWo00Gooo]Z00?o0?n2oookJ_l0oe@00_oonfX01?ngo`3o0?mDokOo0?oonfX2o`3oE003ool0
0?oonf[ooo]Z01?ooo]Z0ol02_l3oookJP?ooa400_oonfX2oooC00Cooo]Z1Ol0oh86oookJP?o03;o
0_oio`06oookJP03o`1_oooonf[ooo]Z00?ooo]Z00?o06oooookJ_l0<_l00oo>o`0:o`1_o`Wooo]Z
00?oojH0oookJ_oonfX04ooonfX01Ooo103oocd0oolm0?oonf[oo`4000;ooo]Z00?o0000oookJ_oo
nfX03ooonfX2ool105_ooo]Z00?o0000oookJ_oonfX0>_oonfX001Oooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP0AoookJP03ool20?oonf[ooo]Z01Sooo]Z00?oo`00oookJ_oonfX0
1OoonfX00ooo4`3ooo]ZoookJP1?oookJP03oomB0?oo003ooo]Z00gooo]Z00?o03;ooookJ_l0<_l0
1?oonfX00ol0<_oooo]ZoookJP03oomF000:o`0boooonf[oo``0ool<0?oonf[o03;ooookJ_oo0@3o
oo]Zo`0:o`Gooo]Z00?onOl0oookJ_oonfX00_oio`07oookJP06o`3oP_oonf[ooo]Zo`3oE?ngo`3o
oo]Z0ol0oe@EoookJP?o00[o2_oonfX2oooC0003oookJ_ood`3ooo]Z00Oooo]Z0ol0oh83o`0bo`Go
oo]Z0_oio`04oookJP03o`1_oooonf[ooo]Z00Cooo]Z00?oo`80o`0boooonfX00_o>o`001Ol0<_oo
0?n2o`0bool0<_oo0?n200?o06oo00?ooo]Zo`1_oooonfX02OoonfX00oooYP3oo`00oookJP0Coook
JP?oocd000Coo`40oookJ_oonf[o00004_oonfX00ooo503ooo]ZoookJP1JoookJP03o`000?oonf[o
oo]Z03Wooo]Z000GoookJP03o`000?oonf[ooo]Z033ooo]Z00?oo`L0oookJ_oonfX00ooonfX00ol0
003ooo]ZoookJP0@oookJP03ool20?oonf[ooo]Z03Gooo]Z00?ooa@0oookJ_oonfX06_oonfX00ooo
103ooo]ZoookJP0LoookJP03oomB0?oonf[ooo]Z00kooo]Z0_l0<_l2oookJPCo06oo1?ooEP03o`1_
o`;ooo]Z00?o03;ooookJ_oonfX00ooonfX01Ol02_oooo]ZoookJ_oonf[onOl000_ooo]Z00?o0?n2
oookJ_oonfX00_oonfX3o`3oE0kooo]Z1?o`o`02oookJP?o00[o2?oonfX00ooo003ooo]ZoookJP02
oookJPGoom<02?oonfX2o`0bo`?ooo]Z0ol0oh82ool30003o`3oP_oonf[onOl000;onOl00_oonfX0
0ol0Kooooo]ZoookJP03oookJP04o`1_ool0<_oooo]ZoookJP?o03;o0ol0Kol01?ooEP3o06oooook
J_l0Kol;oookJPCoojH04ooonfX00ooo?@3ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z02[ooo]Z
00?oo`D0oookJ_oonfX03ooonfX00ooo503ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03Wooo]Z
000FoookJP03o`000?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX08_oonfX00ooo1`3ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z04;ooo]Z00?oo`00oookJ_oonfX00_oonfX2oolD01_ooo]Z00?o
o`@0oookJ_oonfX0;OoonfX2o`0bo`;ooo]Z00Co06oooookJ_oonf[ooeH00_l0Kol3oookJP04o`1_
oooonf[o06ooo`0bo`Oooo]Z00?o00[ooookJ_oio`003?oonfX02Ol0oh;oo`<0ool30?oonf[o0?mD
oookJ_l0oeCooo]Zool2000<oookJPOol?l000?ooo]ZoooC0?ood`004oood`04oookJP?o03;o2ooo
nfX4o`3oPP;onOl000?o06oooookJ_oonfX00ooonfX00ol0Kooooo]Zo`0bo`02o`0bo`;o06oo0_oo
nfX00ol0oh;o06ooo`3oPP02oomF00cooo]Z00CoojH0oookJ_oonf[oo`<05ooonfX01Ol0003oo`00
ool00?oonf[ood/001?ooo]Z00?oo`00oookJ_oonfX04_oonfX00ooo1@3ooo]ZoookJP0?oookJP;o
oa@0<?oonfX00ol0003ooo]ZoookJP0hoookJP005_oonfX00ol0003ooo]ZoookJP0ioookJP03o`00
0?oonf[ooo]Z00[ooo]Z00?oo`H0oookJ_oonfX05ooonfX00ooo0@3ooo]ZoookJP0foookJP03oolD
0?oonf[ooo]Z01_ooo]Z00?oo`40oookJ_oonfX05?oonfX00ooo_@3ooo]ZoookJP02o`0bo`;o06oo
00GooeH0oookJ_oonf[o03;oool00002o`1_o`;ooo]Z0_l0<_l2o`1_o`Kooo]Z00?onOl0oookJ_oo
nfX01_oonfX2oom000?ooo]Z00Go0?n2oookJ_oonf[ooo]Zo`3oE002oookJP;o0?lC3?oonfX00oo`
o`3o00[ooo3o0004oo3o017ooo]Z0oood`03oookJP?o03;o3?oonfX00ooo003ooo]ZoookJP04oook
JP03o`3oP_l0KooonOl000?o0?n20_oonfX01Ol0Kooo03;oo`1_oooonf[o0?n200?ooo]Z00Go06oo
oookJ_l0Koooo`00o`3oPP02oomF00Wooo]Z1?ooYP000ooo0`3ooo]ZoookJP03oookJP?ooaL03ooo
nfX01Ol0003ooo]ZoookJ_oonf[ood/004?ooo]Z00?oo`40oookJ_oonfX03_oonfX2ool801Oooo]Z
00?o0000oookJ_oonfX0=ooonfX001Kooo]Z00?o0000oookJ_oonfX08OoonfX00ooo003ooo]Zoook
JP0FoookJP03o`000?oonf[ooo]Z00Wooo]Z00?oo`H0oookJ_oonfX0C?oonfX00ooo003ooo]Zoook
JP02oolD01gooo]Z00?oo`40oookJ_oonfX05?oonfX00ooo_@3ooo]ZoookJP02oookJP?o06oo0_oo
nfX01?l0<_ooc_l0o`1_oooonfX4o`1_o`03o`0boooonf[o06oo00Cooo]Z00?onOl0oookJ_l02_l0
1?oonfX5oom000;ooo]Z00?o0?n2oookJ_oonfX00_oonfX3o`3o4`03oookJ_l0oa?ooo]Z00Wooo]Z
00Go00[ooo3o0?o`o`3ol?l0oookJP03oo3o0003ool00?oonf[ooo]Z00Kooo]Z00?oo`<0oookJ_oo
nfX01_oonfX00oood`3ooo]ZoookJP03o`0bo`;ooo]Z1OooC@000ooonf[oodd0oookJP04oookJP;o
o`002?oonfX00ol0KooonOl0ooWo0004o`1_o`04o`3oP_oio`3o0?n2o`3oPP;ooo]Z00Co06oooook
J_oonf[o06oo0_oonfX3oomF00[ooo]Z0_ooYP07oookJP;ooaL03ooonfX01Ol0003ooo]ZoookJ_oo
nf[ood/001Sooo]Z00?ooad0oookJ_oo00005?oonfX00ooo003ooo]ZoookJP0AoookJP03ool10?oo
nf[ooo]Z00oooo]Z00?oo`P0oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0goookJP005_oonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z01gooo]Z00?oo`D0oookJ_oonfX06OoonfX0
0ooo003ooo]ZoookJP0GoookJP;oob/01OoonfX00ooo503ooo]ZoookJP0coookJP05oonm0?oonf[o
oo]ZoookJ_l0Kol00_oonfX2o`1_o`;oc_l000Go03;ooookJ_o>o`3ooo]Zo`0bo`02oookJPGo06oo
00?ooo]ZooWo0?oonfX00_oonfX01?l02_oooo]ZoookJ_oo@003oookJP05oom00?oonf[oo`00oook
J_l0oh800_oonfX3o`3o4`03oookJ_l0oa?o0?lC00;o0?lC1ooonfX3oo3o00;ooo]Z00Col?l0oook
J_o`o`3ol?l04ooonfX3o`0bo`[ooo]Z0oooC@0>oookJP?o06oo0ooio`001?l0KooonOl0ooWo0?oo
nfX2o`3oPP04o`1_ool0oh;o0?n2o`1_o`Cooo]Z0_l0oh8FoookJP03ool00?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX00_oonfX00oooB`3oo`<0ool30002ool501?ooo]Z00?ooad0ool00?oo0000
DooonfX00ol0003ooo]ZoookJP0foookJP005_oonfX00ol0003ooo]ZoookJP0goookJP03ool00?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX07?oonfX00ooo1@3ooo]ZoookJP0doookJP03ool[0?oo
nf[ooo]Z01?ooo]Z00?ooc<0oookJ_oonfX00ooonfX00ooo003ooa40oolA000LoookJP03oonm0?oo
nf[oo`0000;ooo]Z00Co06oooookJ_oonf[o06oo0_l0<_l01Ol0Kooo03;ooookJ_oonf[o03;o00Co
oo]Z00?o03;ooookJ_l0Kol00ol0Kol4oookJP03o`0:oooonf[ooo]Z00Kooo]Z00?o0?n2oookJ_oo
nfX00_l0oa<01ol0oeCooo]ZoookJ_oonf[o0?lCoookJ_l0oa<01OoonfX2oo3o00Gooo]Z0oo`o`0A
oookJP?o03;o3OoonfX2oom=00cooo]Z1?l0Kol2oookJP;ooa400_oio`002?l0KooonOl0ooWo0?l0
oh;o06oooookJ_l0oh;o06oo0ol0oh82ool10003o`3oP_oonf[o0?n200Cooo]Z00?oohH0oookJ_oo
nfX07?oonfX01?l0003ooo]ZoookJ_oonfX3oom;01Kooo]Z0_oo7@0HoookJP03ool:0?oonf[ooo]Z
03[ooo]Z00?o0000oookJ_oonfX0=OoonfX001Kooo]Z00?o0000oookJ_oonfX07_oonfX2ool201go
oo]Z00?o0000oookJ_oonfX0C_oonfX01Ooo003ooo]ZoookJ_oonf[oob/001Gooo]Z0_oo<`04oook
JP03ool00?oo4@3ooo]Z01kooo]Z0_ooV`001Ooonf[o06oooookJ_oonf[oc_l000;o06oo0_l0<_l0
1?oonf[o03;oolko0?o>o`04oookJP04o`0boooonf[onOl0oookJP;o06oo0ooonfX00ol02_oooo]Z
oookJP06oookJP05o`3oP_l0oa?o0?lCoookJ_l0oe@00ooonfX3o`3o4`03oookJ_l0oa?ooo]Z00?o
l?l00_oonfX2oolL00?ooo]Z00?ol?l0oookJ_oo0@003_oonfX3o`0bo`?o0?mD2?oonfX00ooo003o
oo]ZoookJP09oookJP;oo`@00_oonfX3o`1_o`Cooo]Z00?o06oooookJ_oonfX00_oo4@001Ooonf[o
06ooooWo0?oio`3o06oo00;ooo]Z00?o06oooookJ_oonfX01OoonfX3o`3oPP?ooo]Z00?oohH0oook
J_oonfX06ooonfX2o`0000Cooo]Z00?ood/0oookJ_oonfX06ooonfX00ooo003ooo]ZoookJP0Aoook
JP03ool:0?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0=OoonfX001Kooo]Z00?o0000oookJ_oo
nfX0?_oonfX00ol0003ooo]ZoookJP0<oookJP03ool00?oonf[ooo]Z00Kooo]Z0_oo3@0IoookJP03
ool40?oonf[ooo]Z03?ooo]Z0_oo<`0=oookJP;oofX02?oonfX00ooo>P3ooo]ZoookJP04oookJP03
ool;0?oonf[ooo]Z00Cooo]Z0oooV`000ooonf[o06oooookJP02oookJP06o`1_oooonf[oc_l0o`1_
ool0<_ooc_l01ooonfX01_oio`3ooo]ZoookJ_oonf[o06ooool000;ooo]Z1?ood`04oookJP03o`3o
P_l0oa?ooo]Z00;ooo]Z00Co0?mDoookJ_oonf[ooo]Z0_l0oa<01?oonf[ol?l0oo3o0?o`o`03oook
JP?ooa`01OoonfX2ool100cooo]Z0_l0<_l6oookJPGo0?mD4?oonfX3o`1_o`Oooo]Z00?o06oooook
J_oonfX00ooio`001ol0KooonOl0o`1_oooio`3ooo]Zo`1_ool0oh800_oonfX6o`3oPPKooo]Z00?o
ohH0ool20?oonfX04?oonfX2ool200?ooo]Z00?oobX0oookJ_l000000_l000000ooonf[o0000oook
JP0<oookJP03ool00?oonf[ooo]Z057ooo]Z0_oo2`0AoookJP03o`000?oonf[ooo]Z03Cooo]Z000E
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?oo`40oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0E
oookJP03ool=0?oonf[ooo]Z04cooo]Z00?oo`00oolc0?oonfX03?oonfX4oomZ00Kooo]Z0_oo>P05
oookJP;oo`/000?oo`40oookJ_oonfX00_oonfX00oooV`3ooo]ZoonK0002oonK0004o`1_oooonf[o
oo]ZoookJP;o06oo0_o>o`000ol0Kooooo]ZoookJP07oookJP03o`0boooonf[o06oo00;ooo]Z1_oo
d`04oookJP05o`3oP_oonf[o0?lCoookJ_l0oe@00ooonfX01Ol0oa?ol?l0o`3o4oo`o`3ooo]Z00;o
0?lC5_oonfX3o`0bo`gooo]Z1Ol0oe@8oookJP?o06oo0_ood`03oookJPCo0=3o00Kooo]Zo`1_oooo
nf[ooo]Zool00?oonfX2ooWo0005o`1_ool0oeCo0?mDo`3oP_l0Kol00ol0oh801Ooonf[o0?n2o`3o
P_l0oh;oo`D000Sooo]Z00?oo`80oookJ_oonfX03ooonfX01?oo0P3ooo]ZoookJ_oonfX3o`0000Go
oo]Z00?o0000oookJ_oonfX08ooonfX00ooo8P3ooo]ZoookJP0EoookJP03ool00?oonf[ooo]Z00oo
oo]Z0_oo0`0?oookJP03ool;0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0=?oonfX001Gooo]Z
00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0XoookJP;oo`d06_oonfX2ool302gooo]Z
00?oofX0oookJ_oonfX01_oonfX2oolj00gooo]Z1?ooV`001_l0Kooooo]ZoookJ_l0Kooooo]Zo`1_
o`;oc_l000?ooo]Zo`1_oooonfX02?oonfX00ol0Kooooo]ZoookJP02oookJP03oooC0?oonf[oom<0
00;oom<01?oonfX01Ol0oh;ooo]ZoookJ_l0oa?o0?mD00?ooo]Z00?ol?l0o`3o4ooonfX00ooonfX0
0ol0oa?oo`00oookJP0AoookJP?o03;o1_oonfX2ool600Wooo]Z00Coo`<0oookJ_oonf[ooo]Z1Ol0
oe@3o`1_o`Gooo]Z0ol0d?l01?oonf[o0=3ooookJ_oonfX2o`3@o`05o`1_oooonf[ooo]ZoookJ_n:
o`000_l0Kol01?l0oh;o0?mDo`1_ool0oe@2oookJP;o0?n20ooonfX2ool500Sooo]Z0oooQP05oook
JP03oonC0?oonf[ooo]Z00Oooo]Z0ol000000ooonf[oobX0oolZ0006oookJP03o`000?oonf[ooo]Z
00kooo]Z0_oo2`0BoookJP04oolR0?oonf[ooo]Zool004_ooo]Z00?o0000oookJ_oonfX0<ooonfX0
01Gooo]Z00?o0000oookJ_oonfX0<OoonfX00ooo103ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z
00Gooo]Z00?oo`40oookJ_oonfX06?oonfX00ooo003ooo]ZoookJP05oookJP03ool=0?oonf[ooo]Z
04Oooo]Z00?oofX0oookJ_oonfX01_oonfX00ooo>P3ooo]ZoookJP0<oookJP;ooi/00_oonfX00ol0
Kooooo]Zo`1_o`03oookJP04oolg0?o>o`3ooo]Zo`1_o`;ooo]Z0_oo1003oookJP04ool20?l0Kooo
oo]Zo`0bo`Cooo]Z00Goom<0oookJ_ood`3oom<0o`0:o`02oookJP03o`3oP_oonf[ooo]Z00;ooo]Z
00Ko0?lCoookJ_oonf[o0?lCoookJ_l0oa<4oookJP;o0?lC3ooonfX3o`0bo`Wooo]Z0oooU`0>oook
JP?o06oo00?ooo]Zo`3oE?l0oe@00ol0oe@00ooonf[o0=3oo`3@o`05o`3@o`?ooo]Z00go06ooo`3@
ool0d?oo0=3oo`1_oon:o`3o06oooookJ_l0Kooo0?mDo`3oP_l0oeCo0?n200;oocL03OoonfX2oon6
0003ool00?ooQP3ooo]Z00?ooo]Z00?ooi<0oookJ_oonfX01?oonfX3o`0000Sooo]Z00?oo`00oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP0=oookJP03ool20?oo2`3ooo]Z017ooo]Z0_oo8P0Goook
JP03ool>0?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<_oonfX001Gooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ooo103ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Cooo]Z00?oo`40oookJ_oo
nfX0=OoonfX2ool=01_ooo]Z0_oo0@0FoookJP03oomZ0?oonf[ooo]Z00Gooo]Z00?oocX0ool00?oo
nfX03OoonfX01_ooV`3ooo]ZoookJ_l0Kooooo]Zo`1_o`?ooo]Z0_oo=`001?o>o`3ooo]ZoookJ_l0
Kol5oookJP;oo`800ooonfX01_l0<_oooo]ZoookJ_ood`3ooo]ZoooC00?ooo]Z00?o00[ooookJ_l0
oh800ooonfX01ol0oeCooo]Zo`3o4ooonf[o0?lCoookJ_l0oa<00_oonfX2o`3o4`kooo]Z0ol0<_l8
oookJPSooiL02_oonfX00ol02_oo06ooo`1_o`09oookJP03ool00?l0d?oo0?mD00;o0?mD00?ooo]Z
oooC0?l0d?l01_l0d?l00ooo103o0=3oo`3@o`02o`3@o`03oookJ_l0oeCo0?n200;o0?mD0_oonfX2
oolg00[ooo]Z0oooQP000ooo003oohH0oookJP03oookJP04oonC0?oonf[ooo]ZoookJP?o00004?oo
nfX00ol0003ooo]ZoookJP0XoookJP03ool20?oonf[ooo]Z00oooo]Z0_oo3P0eoookJP03o`000?oo
nf[ooo]Z03;ooo]Z000EoookJP03o`000?oonf[ooo]Z00_ooo]Z0_oo000goookJP03o`000?oonf[o
oo]Z03Kooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo3@3ooo]ZoookJP0boookJP03oomZ0?oonf[o
oo]Z01Gooo]Z00?ooi/0oookJ_oonfX00_l0Kol3oookJP04oolg0?oonf[o06ooolko00?ooo]Z00?o
06oooookJ_oonfX00_oonfX00ol0Kooooo]ZoookJP03oookJP03o`0booood`3ooo]Z00Kooo]Z00?o
0?n2oookJ_oonfX00_oonfX00ol0oeCoo`00oookJP02o`3o4`04oookJ_l0oa?ooo]Zo`3o4`gooo]Z
0ol0<_l4oookJPOooiL00_oonfX2ool100;ooiL02_oonfX3o`1_o`gooo]Z00?o0=3ooookJ_oonfX0
0_l0oe@01Ol0d?oo0?mDoooC0?ood`3ooo]Z00;o06oo00?oo`@0o`1_ool0d?l01?l0d?l2oookJP;o
0?mD0_oonfX2oolg00_ooo]Z0_ooQP05oookJP04oonC0?l0003o0000o`0001Cooo]Z00?o0000oook
J_oonfX04_oonfX00ooo003ooo]ZoookJP0ooookJP03ool50?oonf[ooo]Z01[ooo]Z00?o0000oook
J_oonfX0<OoonfX001Gooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003oo`@0oookJP0HoookJP03
ool00?oonf[ooo]Z01Wooo]Z0_oo6P0KoookJP03ool;0?oonf[ooo]Z01_ooo]Z00?oofX0oookJ_oo
nfX05?oonfX01?ooV`3ooo]ZoookJ_oonfX2o`1_o`;ooo]Z00GoocL0oookJ_oonf[oo`00o`1_o`04
oookJP04o`1_oooonf[ooo]Zo`1_o`Kooo]Z00?oom<0oookJ_oonfX01ooonfX01?l02_oooo]Zoook
J_l0oe@3oookJPGo0?lC00?oo`@0oookJ_oonfX01_oonfX4ooo90003o`0boooonf[ooo]Z013ooo]Z
00?ooiL0oookJ_oonfX01_oonfX3o`1_o`?ooo]Z00?o00[ooookJ_oonfX02_oonfX00ol0d?oooo]Z
oookJP03oookJP04o`3@oooonf[o0?mDoooC00;o06oo00?oom<0o`3oE?l0d?l00_l0d?l00ol0oeCo
0=3ooookJP02oookJP;o0?mD00?oo`00oolg0?oo=`004?oonfX3o`0000;ooo]Z00?oo`/0oookJ_oo
nfX04?oonfX01?oo0@3ooo]Zoolh0?l00013oookJP03ool00?oonf[ooo]Z00oooo]Z00?oo`D0oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0`oookJP005?oonfX00ol0003ooo]ZoookJP0RoookJP03
ool00?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0<ooonfX00ooo6P3ooo]ZoookJP0IoookJP;o
o`/07OoonfX00ooo003ooo]ZoookJP0DoookJP03oonK0?oonf[ooo]Z00?ooo]Z0_l0Kol3oookJP03
ool00?l0Kooooo]Z00Cooo]Z00?o06oooookJ_l0Kol01OoonfX00oood`3ooo]Zo`0bo`04oookJP;o
ob800ooonfX00ol02_oooo]Zo`3oE003oookJP03o`3o4ooonf[o0?lC00[ooo]Z1_oob@0HoookJP?o
06oo1?oonfX4oolY00Wooo]Z00?oo`80oookJ_l0d?l01OoonfX01Ol0d?oooo]ZoookJ_ood`3o]ol0
00?oom<000Go0?mDo`3@ool0oeCo0=3oo`3oE002oookJP;oR_l000?ooo]Zo`3oE?oonfX03_oonfX3
o`0000?ooo]Z00?ooi<0oookJ_oonfX05?oonfX2oolh0003o`000?oonf[ooo]Z01Gooo]Z00?ooa<0
oookJ_oonfX05?oonfX00ooo003ooo]ZoookJP0AoookJP03ool00?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX0<?oonfX001Cooo]Z00?o0000oookJ_oonfX0@ooonfX00ooo203ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z017ooo]Z00?oo`<0oookJ_oonfX06OoonfX00ooo003ooo]ZoookJP0Goook
JP;ooah00ooonfX00ooo003ooo]ZoookJP0doookJP03oonK0?oonf[ooo]Z00Kooo]Z0_l0Kol01?oo
nf[onOl0ooWo0?l0Kol5oookJP03o`1_oooonf[ooo]Z00?ooo]Z00Goom<0oookJ_oonf[ooo]Zo`0b
o`02oookJP03oolR0?oonf[oob8000Cooo]Z00Go0?mDoookJ_oonf[ooo]Zo`3o4`0=oookJPKoolT0
1?oonfX00ooo003ooo]ZoookJP0>oookJP?o06oo2_oonfX2oolY00Sooo]Z00Coo`80oookJ_oonf[o
0=3o1?oonfX00ol0d?oooo]Zo`3@o`05oooC0005o`3@oooonf[o0=3oo`3oE?n:o`001Ol0oe@00on:
o`3o0?mDoookJP07oookJP03oomS0?oonf[ooo]Z00?o00001OoonfX3oonC01Kooo]Z00GoocP0o`00
0?oonf[ooo]Zool1000DoookJP03oolC0?oonf[oo`8002Wooo]Z00?ooa00oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP0_oookJP005?oonfX00ol0003ooo]ZoookJP0OoookJP03ool10?oonf[ooo]Z
01Kooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo203ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z
04Oooo]Z00?ooah0oookJ_oonfX06_oonfX2ool801oooo]Z00?oo`00oookJ_oonfX01?oonfX01On:
o`3o0=3oo`3@ool0d?oo06oo00Co0=3o00?o06ooo`3@ool0Kol00ooonfX00oood`3ooo]ZoookJP03
oookJP03o`0boooonf[ooo]Z00Cooo]Z0_oo0P001Ol0oeCo00[ooookJ_oonf[o0?lC00_ooo]Z1?oo
b@000ooonf[oolT0ooo9000?oookJP;oo`D00_oonfX3o`1_o`;o0?lC3OoonfX00ol02_oooo]Zoook
JP08oookJP04o`3@oooonf[ooo]ZoookJP?o0=3o0_oonfX2ool60007okOo0?l0d?oo0?mDo`3@oooo
nf[o0?mDoookJP02oh[o0003oookJ_n:o`3ooo]Z00?o0?mD1ooonfX3o`0000Oooo]Z00Gooi<0oook
J_ooT`3ooo]ZoonC0002oookJP03ool00?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX01OoonfX0
0ooo>`3ooo]ZoookJP0=oookJP03ool20?oonf[ooo]Z01Kooo]Z00?oo`D0oookJ_oonfX03_oonfX2
ool@033ooo]Z00?o0000oookJ_oonfX0;_oonfX001Cooo]Z00?o0000oookJ_oonfX07ooonfX00ooo
0@3ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00[ooo]Z0_oo200IoookJP03ool20?oonf[ooo]Z
01[ooo]Z00Goo`00oookJ_oonf[ooo]ZoolN000EoookJP;oob<01OoonfX00ooo0@3ooo]ZoookJP0U
oookJP0;ooWo0?l0d?oo06ooo`1_ool0d?oo06ooo`3@oon:o`3o06ooo`3@oooonfX00_l0d?l00ooo
nf[oom<0oookJP06oookJP03o`0boooonf[ooo]Z00Cooo]Z00Go0?mDoookJ_l02_oooo]Zo`3o4`09
oookJP?oolT000Cooo]Zool90?oo2@3ooo]Z0_oob@09oookJP?oo`001OoonfX3o`1_o`Gooo]Z1Ol0
oa<2oookJP;oo`001OoonfX00ol02_oooo]ZoookJP07oookJPCo0=3o0_oonfX00ol0d?oooo]Zoook
JP02oookJP03o`3@ool0oeCo0=3o00;ooo]Z00?o0?mDoookJ_l0oe@01Ol0oe@00ooonf[oo`<0oook
JP03oookJP?o000000?ooo]ZoomS0?oonfX02?oonfX3oonC00_ooo]Z00?ooaT0oookJ_oonfX02_oo
nfX00ooo1@3o0000oookJP05oookJP03oolk0?oonf[ooo]Z01;ooo]Z00?oo`00oookJ_oonfX0??oo
nfX2ool701Kooo]Z00?o0000oookJ_oonfX0;_oonfX001Cooo]Z00?o0000oookJ_oonfX0BooonfX2
o`0000[ooo]Z00?oo`P0oookJ_oonfX06?oonfX00ooo0P3ooo]ZoookJP0/oookJP;ooc/01_oonfX0
0ooo8`3ooo]ZoookJP03oookJP;oo`409_oonfX01Ooio`3oR_l0o`3@ool0d?ooR_l000;o06oo00?o
nOl0o`3@ool0d?l00_l0d?l2oookJP;o0=3o2?oonfX00ol0<_oooo]ZoookJP03oookJP05o`3oE?oo
nf[ooo]Zo`0:ool0oa<00_oonfX2odSo00;ooo]Z0ooob@0=oookJP04ool30?oonf[ooo]ZoookJPGo
o`0000Cooo]Zo`1_ool0Kooo06oo3OoonfX5o`3o4`Cooo]Z00?o00[ooookJ_oonfX00ooonfX00ooo
1`3ooo]Zo`3@o`03o`3@o`Cooo]Z00So0=3ooookJ_oonf[ooo]Zo`3@ool0oa?o0=3ooookJPCo0?mD
00Cooo]Zo`3oE?l0oeCoR_l00_oonfX00on:o`3ooo]ZoookJP03o`0000Gooo]Z00?oof<0ool00?oo
nfX01ooonfX00oooT`3ooo]ZoookJP0:oookJP;ooaT03OoonfX00ol0003ooo]ZoookJP02oookJP03
ool00?oo>`3ooo]Z01Oooo]Z00?ooaP0oookJ_oonfX09ooonfX2ool100oooo]Z0_oo1`0GoookJP03
o`000?oonf[ooo]Z02gooo]Z000DoookJP03o`000?oonf[ooo]Z03Cooo]Z00?oo`00oookJ_oonfX0
5_oonfX00ol0003oo`00oookJP1AoookJP03oolk0?oonf[ooo]Z00Gooo]Z00?oob<0oookJ_oonfX0
2ooonfX2oomB00Oooo]Z0_oo90000ooonf[ooi<0oookJP03oookJP03ool30?oonf[ooo]Z00Cooo]Z
0_ooM007oookJP09ooWo0?l0d?oo0=3oo`3@oooio`3ooo]Zo`1_ool0d?ooR_l000;ooo]Z1_l0d?l0
0ooonf[oo`00oookJP04oookJP03o`0boooonf[ooo]Z00;ooo]Z00Go0?mDoookJ_oonf[o0?lCo`0:
o`03odSo00?oolT03ooonfX2ool300?ooo]Z0ooo0003o`1_oaGooo]Z1_l0oa<3oookJP04o`3@oooo
1`3oo`L0oonG00;ooo]Z00?o0=3ooookJ_oonfX00ooonfX01ol0d?oooo]Zo`3@ool0oa?ooo]Zo`3@
ool0oa<01Ol0oe@00ooonf[oR_l0oookJP02oh[o00?o00002?oonfX00ooo003oof<0oomS000Eoook
JP03oolI0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX00_oonfX00ooo003ooc/0oookJP0Goook
JP03oolH0?oonf[ooo]Z01Gooo]Z00?oo`00oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0/oook
JP004ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01cooo]Z00?oo`P0oookJ_oo
nfX06?oonfX2ool101Sooo]Z00?ooc/0oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP0=oookJP;o
oe801_oonfX2oolT00?ooi<01?oonfX00ooo0`3ooo]ZoookJP02oookJP03oomd0?oonf[oog@000Oo
oo]Z00?oR_l0o`3@oooio`000_l0d?l00ooonf[o0=3ooh[o0006oookJP03o`1_ool0d?oo0=3o00;o
0=3o1_oonfX01?l0<_oooo]ZoookJ_l0oe@3oookJP;oB?l000?o00[ooookJ_oob@000_m8o`0Eoook
JP?o06oo0_oo0007oookJP03ool00?oonf[ooo]Z01;ooo]Z0ol0d?l2o`3o4`;ooo]Z0_ooU`000ol0
d?oooo]ZoookJP03oookJP;o0=3o00?ooo]Zool10?oo0@000ol0oa<00ol0oeCooo]ZoookJP03oh[o
00?o000000?oR_l0oookJ_oonfX02?oonfX3oomS00Kooo]Z00?oogD0oookJ_oonfX01ooonfX00ooo
103ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00;ooo]Z00?ooc/0oookJ_oonfX00_oonfX00ooo
1@3ooo]ZoookJP0AoookJP03oolH0?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0;?oonfX001?o
oo]Z00?o0000oookJ_oonfX0<_oonfX00ooo0P3ooo]ZoookJP0FoookJP03ool00?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX04ooonfX01?oo003ooo]Zool@0?oo400ioookJP03oolk0?oonf[ooo]Z
01?ooo]Z00?ooe80oookJ_oonfX01?oonfX01?oo903ooo]ZoonC0?oonfX3oonC00Wooo]Z0oooM006
oookJP05oh[o0?l0d?oonOl0o`3@oon:o`000_l0d?l00ooonf[oo`00oookJP05oookJP03o`1_oooo
nf[ooiL000;o0=3o0_ooU`03oookJP05o`0boooonf[ooo]Zo`3oE?oonfX00_m8o`03oookJP03o`0:
oom8o`3ooo]Z00;oB?l01?oonfX00ooo0@3ooo]ZoookJP0:oookJP?o06oo00Cooo]Zool00?oo003o
o`000ooonfX2oomH00kooo]Z0_oo1@000ooonf[o03;ooookJP02oookJP?o0=3o00?ooo]Zo`0:oooo
nfX00_oonfX4o`3o4`03oonG0?l0d?oooiL000;ooo]Z00OooiL0o`3@oooonf[o0?lCo`3@oooonf[o
0?lC00;ooo]Z00?o0?lCoookJ_oonfX00ol000000on:o`3ooa`0oolL000DoookJP03oome0?oonf[o
oo]Z00oooo]Z00?oo`00oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0MoookJP03ool10?oonf[o
oo]Z01?ooo]Z0_oo200koookJP03o`000?oonf[ooo]Z02_ooo]Z000CoookJP03o`000?oonf[ooo]Z
00cooo]Z00?oo`00oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0DoookJP;ooa006OoonfX2ool7
01cooo]Z00?oo`00oookJ_oonfX05?oonfX00oooDP3ooo]ZoookJP06oookJP03ool00?oonf[ooi<0
00;ooi<02_oonfX2oomd00Oooo]Z00Cooa`0o`3@oon:o`3onOl00ol0d?l9oookJP04o`1_ooooU`3o
oo]Zo`3@o`;ooiL01?oonfX01_l0<_oo0?mDoookJ_m8o`3ooo]Zo`3o4`?ooo]Z0_m8o`02oookJP03
odSo0?oonf[ooo]Z00cooo]Z0ol0Kol3oookJP[ooeP04?oonfX01?l0<_oo0=3oo`3@ool0d?l5oook
JP04o`0:oooonf[ooo]Zool000Cooo]Z00Ko0=3oo`3o4oooU`3ooiL0o`3@ooooU`02o`3@o`03oook
J_l0oa?ooo]Z00;ooo]Z0ol00002oookJP03olko0?n:o`3oR_l000;ooa`03OoonfX00ooo0P3ooo]Z
oookJP04oookJP03oome0?oonf[ooo]Z01Gooo]Z00?oobH0oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP05oookJP03ool40?oonf[ooo]Z01Sooo]Z00?oo`00oookJ_oonfX0>_oonfX00ooo203ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z02_ooo]Z000CoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o
o`80oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0XoookJP03oolB0?oonf[ooo]Z03Sooo]Z00?o
oe80oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP02oonC00[ooo]Z00?oog@0oookJ_oonfX01Ooo
nfX2oolL00;ooo]Z00GonOl0o`3@oooonf[oR_l0o`3@o`04oookJP03ool50?oonf[ooo]Z00;ooo]Z
00?o06ooo`3@oooonfX00_ooU`05oookJP04o`0boooonf[ooo]ZodSo00;ooo]Z00Goo`00oookJ_m8
o`3oB?l0o`0:o`02oookJP03odSo0?oonf[ooo]Z00Sooo]Z0ol0Kol=oookJP03oomH0?oonf[ooo]Z
00kooo]Z0ol0d?l00ol0<_oooo]ZoookJP06oookJP03o`0:oooonf[ooo]Z00Cooo]Z00Co0=3ooook
J_oonf[o0=3o0_ooU`001?l0d?oo0?lCo`3o4ol0oa<3o`000004oookJ_ngo`3o0?lCo`3o4`;o]ol0
4OoonfX00ooo0P3ooo]ZoookJP04oookJP04oome0?oonf[oo`<0ool301Cooo]Z0_oo9P05oookJP03
o`000?oonf[ooo]Z00Gooo]Z00?oo`@0oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP0DoookJP03
oolJ0?oonf[ooo]Z02Sooo]Z00?oo`80oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0ZoookJP00
4ooonfX00ol0003ooo]ZoookJP16oookJP03ool20?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0
2ooonfX00ooo003ooo]ZoookJP0IoookJP03oolB0?oo003ooo]Z01[ooo]Z00?oo`D0oookJ_oonfX0
:OoonfX00oooT`3ooo]ZoookJP07oookJP03oomd0?oonf[ooo]Z00Cooo]Z00?ooa`0oookJ_l0d?l0
0_oonfX01_l0d?oooo]Zo`3@oooonf[oR_l0o`3@o`Sooo]Z00?o0=3oo`1_ooooU`002?oonfX01?l0
<_oooo]Zo`3o4om8o`03oookJP;oB?l000?ooo]Zo`0:oooonfX00_m8o`08oookJP03o`1_oooonf[o
oo]Z017ooo]Z00?oo`<0oookJ_oonfX02?oonfX3o`3@o`Cooo]Z00Co03;ooookJ_oonf[ooo]Z1?l0
oi000ol02_oooo]ZoookJP05oookJP?o0=3o0oooU`03o`000003oookJ_l0oa?o0?lC00?o0?lC00?o
oo]Zo`3o4oo>o`000_ngo`0FoookJP;oogD00_oo0`06oookJP03oomZ0?oonf[ooo]Z00_ooo]Z0_oo
9P06oookJP03o`000?oonf[ooo]Z00oooo]Z00?oo`/0oookJ_oonfX03ooonfX2oolJ01Oooo]Z00?o
o`00oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0YoookJP004ooonfX00ol0003ooo]ZoookJP0Q
oookJP03ool00?oonf[ooo]Z01oooo]Z00?oo`D0oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0V
oookJP03oolB0?oonf[ooo]Z01[ooo]Z00?oo`D0oookJ_oonfX07?oonfX00ooo003ooo]ZoookJP0:
oookJP03oonC0?oonf[ooo]Z00Kooo]Z00?oog@0oookJ_oonfX01ooonfX01_l0d?oooo]Zool20?l0
d?oooo]Zo`3@o`;ooo]Z00?oR_l0o`3@oooonfX01OoonfX01?l0d?oooo]ZoookJ_l0Kol9oookJP08
o`3o4ooonf[ooo]ZodSo0?oonf[oB?l0oookJ_m8o`02oookJP03odSo0?oonf[ooo]Z02Cooo]Z0ol0
d?l4oookJP?oo`h000Kooo]Zo`0bool0oi3o0?n@oookJ_l0oi02oookJPCo0?n@1?oonfX00ol0d?oo
oo]ZoookJP03o`000003o`3o4oo`o`3o0?lC00Kooo]Z0ol0oa<2oookJP03okOo0?oo003ooo]Z01;o
oo]Z1?ooM@07oookJP03oomZ0?oonf[ooo]Z00Wooo]Z00?oo`<0oookJ_oonfX02?oonfX00ol0003o
oo]ZoookJP0>oookJP03ool;0?oonf[ooo]Z02Wooo]Z00?oo`/0oookJ_oonfX0<_oonfX00ol0003o
oo]ZoookJP0YoookJP004_oonfX00ol0003ooo]ZoookJP14oookJP03ool50?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX01?oonfX00ooo0@3ooo]ZoookJP0IoookJP03ool00?oonf[ooo]Z01Sooo]Z
00?ooa@0oookJ_oonfX0<?oonfX00oooT`3ooo]ZoookJP06oookJP03oomd0?oonf[ooo]Z00Oooo]Z
00Oo0=3ooookJ_l0d?oonOl0oookJ_l0d?oooo]Z00;o0?n200?oR_l0o`3@oooonfX00ooonfX00ol0
d?oooo]ZoookJP02oookJP04o`1_oooonf[oo``0ool<00Gooo]Z00Co0?lCo`0boooonf[ooo]Z0om8
o`000ooonf[oB?l0odSo0002ool700?ooo]Z0oooN`0;oookJP03ool00?oonf[ooo]Z00kooo]Z0ol0
d?l;oookJPWo0?n@00?oo`@0oookJ_l0oi000ol0oi03o`0000;ooo]Z00Co0?lCoookJ_oonf[o0?lC
0_oonfX5o`3o4`;o]ol00_oonfX00ongo`3ooo]ZoookJP07oookJP03oom00?oonf[ooo]Z00Wooo]Z
0_ooM@08oookJP03oomZ0?oonf[ooo]Z013ooo]Z00?oo`00oookJ_oonfX00_oonfX00ol0003oob`0
oookJP0ToookJP03ool00?oonf[ooo]Z01;ooo]Z00?oo`/0oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP0XoookJP004_oonfX00ol0003ooo]ZoookJP0OoookJP;oo`00=_oonfX00ol0003ooo]Zoook
JP0coookJP;oob801OoonfX00ooo503ooo]ZoookJP02ool101Wooo]Z00?oo`80oookJ_oonfX04ooo
nfX00oooT`3ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z00Gooo]Z0_l0d?l2oookJP04ooWo0?l0
oh;o0=3ooookJP;o0?n200GoR_l0o`3@oooonf[ooo]Zo`3@o`06oookJP03o`1_oooonf[ooo]Z00Go
oo]Z00Co0?lCoookJ_l0<_oooo]Z1?m8o`07oookJPCoog/03OoonfX3ool000Sooo]Z0_l0d?l4odSo
00_ooo]Z00?o0?n@oookJ_l0<_l00_oonfX00ol0oi3ooo]ZoookJP02ool400;o0?n@0ol00002o`3o
T0?ooo]Z00?o0?lCoookJ_oo00001Ol0oa<01Ooonf[o]ol0oookJ_ngo`3oc_l000?o]ol02_oonfX0
0ooo@03ooo]ZoookJP03oookJP;oo`L02OoonfX01Ooo0@3ooo]ZoookJ_oonf[oofX001Oooo]Z00?o
0000ool/0?oonfX09ooonfX00ooo0P3ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Oooo]Z000B
oookJP03o`000?oonf[ooo]Z03Sooo]Z00?oo`00oookJ_oonfX07OoonfX00ooo1@3ooo]ZoookJP0H
oookJP03ool00?oonf[ooo]Z01Oooo]Z00?oob80oookJ_oonfX06_oonfX2oolD01cooo]Z00?ooi<0
oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP05oookJP;o0=3o00Koom<0okOo0?oio`3o]ol0o`3@
oooonfX3o`3oPP04oh[o0?l0d?oooiL0o`3@o`Oooo]Z00?o06oooookJ_oonfX00ooonfX02?oo103o
oo]ZoookJ_oonf[o03;oodSo0?oonf[oB?l01ooonfX4oomk0003ool10?oonf[ooo]Z00[ooo]Z1Ooo
0003oookJP04ool80?l0d?oo0=3oo`3@o`Kooo]Z1Om8o`07oookJP05o`3oT?l0<_oooo]ZoookJ_l0
oi000_oonfX01?l0oh;o0000o`000?l00003o`3oT003oookJ_l0oi3oB?l000;ooo]Z1_l0oa<2oook
JP?o]ol000Coc_l0okOo0?ngo`3o]ol03?oonfX2oom000kooo]Z00Coo`40oookJ_oonf[oofX01?oo
nfX00ooo303ooo]ZoookJP0AoookJP03ool/0?l0003ooo]Z00kooo]Z00?oo`<0oookJ_oonfX00_oo
nfX00ooo003ooo]ZoookJP0moookJP03ool40?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX09ooo
nfX001;ooo]Z00?o0000oookJ_oonfX0E?oonfX00ooo2`3ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z01Oooo]Z00?oo`00oookJ_oonfX06?oonfX01?oo8P3ooo]ZoookJ_oo000@oookJP;oob`01_oo
nfX00ooo503ooo]ZoookJP0]oookJP;o0?n20_l0d?l02_oio`3o]ol0okOo0?l0d?oo]ol0oookJ_l0
oh;ooo]Zoh[o0?l0d?l8oookJP03o`1_oooonf[ooo]Z00?ooo]Z00Ko0?lCoookJ_oonf[ooo]ZodSo
0?l0<_l6oookJP?oog/000Gooo]Zoomk0?ooN`3ooo]Zool1000<oookJPGoo`0000?ooo]Zo`3@ool0
d?l00_oo200=oookJP03odSo0?oo0@3oo`4000?oB?l000Cooo]Zo`3oT?oonf[o03;o0_oonfX3o`00
00;ooeP000Oo0?n@o`0:ool0oi3ooo]Zo`3oT?m8o`3ooo]Z00;oB?l00_oonfX01?l0oa?ooo]Zoook
J_o`o`04oookJPGo]ol00_oonfX00ooo1@3ooo]ZoookJP07oookJP;ood004?oonfX3oomZ00?ooo]Z
00?oo``0oookJ_oonfX04OoonfX00ooo;03ooo]Zo`00000GoookJP03ool?0?oonf[ooo]Z02Sooo]Z
00?oo`00oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0VoookJP004_oonfX00ol0003ooo]Zoook
JP0eoookJP03ool00?oonf[ooo]Z01Oooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo2`3ooo]Zoook
JP03oookJP03o`000?oonf[ooo]Z017ooo]Z00?oo`@0oookJ_oonfX0<_oonfX00ooo;03ooo]Zoook
JP0:oookJP;oo`<01ooonfX00ooo>P3ooo]ZoookJP0=oookJP03ool00?oonf[ooo]Z00cooo]Z0ol0
oh82oooC0005okOo0?l0d?oo0=3ooookJ_l0d?l00_ngo`001Ol0oh;ooo]Zo`3@oon:o`3o0=3o00;o
oo]Z0_oo0@04oookJP05o`1_oooonf[ooo]ZoookJ_l0oa<01?oonfX00om8o`3o03;ooookJP02oook
JP?oog/05?oonfX3ool000?o0=3o5ooonfX00om8o`3o0?n@odSo0003o`0000?o0?n@0_oonfX01ooo
F03o0?n@oomH0?l0oi3ooo]ZodSo0?oonfX00om8o`05oookJP05oo3o0?oonf[ooo]Zolko0?oonfX0
1?ngo`000oo>o`3ooo]Zool5000:oookJP03ool00?oonf[ooo]Z00Kooo]Z00?ooeH0oookJ_oonfX0
1_oonfX00oooJP3ooo]ZoookJP0FoookJP04ool10?oonf[ooo]Zo`0000;ooo]Z00?oo`40oookJ_oo
nfX04?oonfX2ool?02Wooo]Z0_oo3@0_oookJP03o`000?oonf[ooo]Z02Gooo]Z000BoookJP03o`00
0?oonf[ooo]Z037ooo]Z00?oo`40oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0@oookJP03ool4
0?oonf[ooo]Z01Wooo]Z00?oo`00oookJ_oonfX05_oonfX00ooo;03ooo]ZoookJP0:oookJP03oom;
0?oonf[ooo]Z00Gooo]Z0ooo>P06oookJP;ooa400_oonfX2oome013ooo]Z0ol0oh801?ood`3o]ol0
oooC0?ngo`02oooC0006o`3@ool0oh;o0=3ookOo0?l0oh;o0=3o0_oonfX00ol0d?oooo]ZoookJP07
oookJP04o`1_oooonf[ooo]Zo`3o4`?ooo]Z00KoB?l0oookJ_oonf[o03;ooookJ_ooN`0BoookJP;o
o`L00ooonfX3o`3@o`03ool00?oonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX02ooonfX00ol0Kooo
oo]ZoookJP03o`0000Co0?n@1?m8o`000ol0oi3ooo]Zo`3oT002oomH00;ooo]Z00KoB?l0oookJ_m8
o`3oB?l0oookJ_oo0`03oookJP03oo3o0?o>o`3oc_l000;ooo]Z00?onOl0oookJ_oonfX00_o>o`0D
oookJP03oomF0?oonf[ooo]Z02;ooo]Z00Co0000oookJ_oonf[oo`401?oonfX00ooo:`3ooo]Zoook
JP0ToookJP03ool00?oo103oo`@0043ooo]Z00?o0000oookJ_oonfX09OoonfX001;ooo]Z00?o0000
oookJ_oonfX0<OoonfX00ooo0@3ooo]ZoookJP0FoookJP03ool00?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX02OoonfX2ool;03oooo]Z00?oo`00oookJ_oonfX00ooonfX3oom;00Oooo]Z00?oocX0
oookJ_oonfX01OoonfX01ooo4@3ooo]ZoookJ_oonf[oogD0oookJ_ooM@000_oonfX2ool500Gooo]Z
00?oodd0oookJ_oonfX01OoonfX00ol0oh;ooo]ZoooC0002oooC00;o]ol000Gooo]Zo`3@oooo003o
0?n2o`3@o`04oookJP03o`3@oooonf[ooo]Z00Oooo]Z00?o06ooo`3o4ooonfX00ooonfX01Om8o`3o
oo]ZoookJ_oonf[o03;o01Gooo]Z0ol0d?lJoookJP?o00000ol0oi03oookJP08o`0bool0oi3ooo]Z
oookJ_l0oi3oB?l0o`3oT?m8o`03oomH0003odSo0?oonf[ooo]Z00;ooo]Z0_oo0`04oookJP03oo3o
0?o>o`3ol?l000;ol?l000?ooo]Zool90?oo2@002?oonfX00ooo_@3ooo]ZoookJP0:oookJP03oomF
0?oonf[ooo]Z00Kooo]Z0_oo1P07oookJP03ool00?oonf[ooo]Z00Cooo]Z00?ooaL0oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP03oookJP;oob/0D_oonfX00ooo1@3ooo]ZoookJP0EoookJP03o`00
0?oonf[ooo]Z02Cooo]Z000AoookJP03o`000?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX0Cooo
nfX00ol0003ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z01[ooo]Z0_oo0`0[oookJP;ood/01ooo
nfX00ooo>P3ooo]ZoookJP08oookJP?oogD00ooonfX2ool500Cooo]Z0oooC@07oookJP06o`3oP_ng
o`3oom<0oookJ_ngo`3ooo]Z0_ngo`001?l0oh;o0=3oo`3oP_l0oh84oookJP03o`3@oooonf[ooo]Z
00Oooo]Z00?o06oooookJ_oonfX00_oonfX00om8o`3ooo]ZoookJP02oookJP03o`0boooonf[ooo]Z
00Cooo]Z0_oo1009oookJP?o0=3o0ooonfX5oolR00Wooo]Z0_l02_l7oookJP?o00000ol0oi02oook
JP0:o`3oT?oonf[ooo]Zo`3oP_oonf[o0?n@oookJ_l0oi3ooo]Zo`3oT0;ooo]Z00?ooeP0odSo0?oo
nfX01Om8o`000ooonf[oB?l0oookJP03oookJP?ol?l000Coc_l0ooWo0?o`o`3oc_l02OoonfX00ooo
_@3ooo]ZoookJP0:oookJP;ooeH05ooonfX00ooo5`3ooo]ZoookJP0;oookJP04o`000?oonf[ooo]Z
oookJP;oob/04_oonfX01ooo0P3ooo]ZoookJ_oonf[oo`00oookJ_oo4P00DooonfX00ol0003ooo]Z
oookJP0SoookJP004OoonfX00ol0003ooo]ZoookJP17oookJP03ool10?oonf[ooo]Z01Gooo]Z00?o
0000oookJ_oonfX07?oonfX2ool<02;ooo]Z00?oo`00oookJ_oonfX03OoonfX00oooB`3ooo]Zoook
JP05oookJP03oolj0?oonf[ooo]Z00Kooo]Z00?oo`80oookJ_oonfX00_ooM@06oookJP?oojH00_oo
C@06oookJP;oo`T000?ooo]Zo`3oP_ood`000_ngo`001Ooonf[o]ol0okOo0?oonf[o0?n200;ooo]Z
1?l0oh82oomH00Wooo]Z00Co06oooookJ_oonf[oB?l01_oonfX00ol0<_oooo]ZoookJP0;oookJP?o
0=3o4OoonfX3o`0:o`Kooo]Z0ol00002ool80004o`3oT?oonf[ooo]Zo`1_o`?ooo]Z00Co0?n@oook
J_l0oh;ooo]Z0_l0oi000ooo003o0?n@oookJP03oookJP03odSo0?l02_ooB?l000?ooo]Z00CoolT0
odSo0?m8o`3oB?l00ooonfX2oo3o0004oookJ_o`o`3onOl0oo3o00Wooo]Z00?ookd0oookJ_oonfX0
1?oonfX2ool400Cooo]Z1?ooEP000ooo003ooo]ZoookJP05oookJP03oomB0?oonf[ooo]Z00_ooo]Z
00?ooaL0oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0JoookJP03oolB0?oonf[ooo]Z02Sooo]Z
00?oo`40oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0SoookJP004OoonfX00ol0003ooo]Zoook
JP1PoookJP03o`000?oonf[oo`0001Kooo]Z00?ooa@0oookJ_oonfX00ooonfX00ooo303ooo]Zoook
JP0IoookJP03ool10?oonf[ooo]Z01Gooo]Z00?ood/0oookJ_oonfX03?oonfX2ool200?ooo]Z00?o
ogD0oookJ_oonfX01?oonfX2oonV0003oookJ_ooC@3oojH000_ooo]Z00Koom<0o`3oP_ngo`3o0?n2
oookJ_ngo`02o`3oT0;oo`P00_l0oi03oomH0003o`3@ool0oh;o0?n200;o0?n21OoonfX00ol0Kooo
oo]ZodSo0002oookJP03ool00?oonf[ooo]Z00;ooo]Z00?o03;ooookJ_oonfX02OoonfX00ol0d?oo
oo]ZoookJP0?oookJP?o00[o1_oonfX3o`0000?o0?n@0ooonfX01?oo0P3ooo]ZoookJ_l0Kol2oook
JP04o`3oT?l0oh;ooo]ZoookJP?o0?n@1?oonfX00om8o`3ooo]ZoookJP06odSo00Cooo]Z0_o`o`00
0ooonf[ol?l0oo3o0002oo3o00Sooo]Z00?ookd0oookJ_oonfX01OoonfX2ool400Kooo]Z00?ooeH0
oookJ_oonfX01ooonfX00oooDP3ooo]ZoookJP0IoookJP03ool70?l0003ooo]Z00Cooo]Z00Coo`00
oookJ_oonf[ooo]Z0_oo1@0ZoookJP03ool00?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX08_oo
nfX0017ooo]Z00?o0000oookJ_oonfX08_oonfX00ooo003ooo]ZoookJP0NoookJP;oo`<07?oonfX0
0ol0003ooo]ZoookJP0EoookJP03oolD0?oonf[ooo]Z00?ooo]Z00?oo`40oookJ_oonfX04ooonfX0
0ooo2`3ooo]ZoookJP03oookJP03ool10?oonf[ooo]Z01cooo]Z00?oo`00oookJ_oonfX02_oonfX0
0oooM@3ooo]ZoookJP04oookJP;oojH000?oodd0oonV0?oonfX02ooonfX01?ood`3o0?n2o`3oP_l0
oh82oookJP03o`3oT?oonf[oo`P000?o0?n@0oooF0000ol0oi3o0=3ooookJP02oookJPGo0?n200?o
oo]ZodSo0?oonfX01?o9o`04oookJP03o`0boooonf[ooo]Z01Oooo]Z0ol02_l2oookJP04ool60?oo
nf[ooo]ZoookJP?o00000ol0oi05oookJP;oo`800ooonfX01Ol0Kooooo]Zo`3oT?l0oh;ooo]Z00?o
0?n@00?o0?mDoookJ_oonfX00_oonfX6odSo00;ooo]Z00?oolT0oookJ_oonfX01?oonfX4oo3o00?o
oo]Z00?oo`40oookJ_oonfX00ooonfX01Ooo_@3ooo]ZoookJ_oonf[oob8001Gooo]Z00?ooe80oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP0coookJP03ool70?oonf[ooo]Z02Kooo]Z00?oo`L0oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP0RoookJP004OoonfX00ol0003ooo]ZoookJP1MoookJP03
ool00?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX05?oonfX00ooo503ooo]ZoookJP0HoookJP03
ool;0?oonf[ooo]Z037ooo]Z00?oogD0oookJ_oonfX01OoonfX2oonV00[ooo]Z00?oo`D0oookJ_oo
d`000_oonfX00ol0oh;ooo]Zo`3oPP02o`3oT004o`3oE?oonf[ooo]ZoomH00Ko0?n@00?ooo]Zool1
0?oonfX01?oonfX00ol0oh;oB?l0olWo0004olWo00Gooo]Z00?o03;ooookJ_oonfX04ooonfX3o`0:
o`Kooo]Z0ol00003olWo00kooo]Z00?o06ooo`3oP_l0oi000_l0oi001?oonf[o0?mDoookJ_l0<_l5
oookJP03odSo0?oonf[o00[o00Cooo]Z0_oo2@05oookJP?ol?l000ConOl0oookJ_oonf[oo`401?oo
nfX00ooo_@3ooo]ZoookJP02oookJP;oob804ooonfX00oooDP3ooo]ZoookJP09oookJP;oo`D01_oo
nfX00ooo003ooo]ZoookJP02oookJP03oolM0?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX08?oo
nfX00ooo003ooo]ZoolC001;oookJP03o`000?oonf[ooo]Z027ooo]Z000AoookJP03o`000?oonf[o
oo]Z01oooo]Z00?oo`00oookJ_oonfX0=_oonfX00ooo0`3ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z01?ooo]Z00?oo`00oookJ_oonfX04OoonfX2oolH02?ooo]Z00?oo`00oookJ_oonfX04ooonfX0
0oooM@3ooo]ZoookJP07oookJP03oonV0?oonf[ooo]Z00Oooo]Z00?oo`D0oookJ_ood`000ooonfX0
0ol0oh;o0?n@o`3oE002o`3oT003o`3oE?ooF03ooo]Z00Cooo]Z1?l0oi05oookJP05odSo0?o9o`3o
bOl0o`1_oooonfX00oo9o`03o`3oPP;oo`/04OoonfX00ooo0P3o00[oo`0:o`03ool000Cooo]Z0ol0
00001?oonf[o0?n@o`3oT?l0oi02oookJPGobOl02OoonfX00ol0Kooo0?n2o`3oT002oookJP;obOl0
0_oonfX00ol0<_oooo]ZoookJP05oookJP06o`0:oooonf[ooo]Zool00?oonf[oolT01_oonfX2ooWo
0003oooC0?oio`3onOl000?ooo]Z0ooo_@05oookJP03oolR0?oonf[ooo]Z013ooo]Z0oooDP09oook
JP03oom50?oonf[ooo]Z00_ooo]Z0_oo7@06oookJP03o`000?oonf[ooo]Z01cooo]Z00Coo`40oook
J_oonf[oo`000_oo4`0YoookJP03ool20?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX08?oonfX0
013ooo]Z00?o0000oookJ_oonfX0>OoonfX00ooo003ooo]ZoookJP0MoookJP03ool30?oonf[ooo]Z
00Wooo]Z00?o0000oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP0HoookJP03oolH0?oonf[ooo]Z
00Kooo]Z0_oo0`0BoookJP03ool90?oonf[ooo]Z02Gooo]Z00?oo`40oookJ_oonfX02?oonfX03?oo
d`3ooo]Zo`3oE?l0oeCoc_l0o`3oT?o>o`3o0?mDo`3oT?ooF03o0?mDolko00Oooo]Z0_l0oi04oook
JP08olWo0?oonf[ooo]Zo`1_oooonf[obOl0oookJ_o9o`03oookJP03ool;0?l0oh;o0?n200?o0?n2
0_oonfX00ooo003ooo]ZoookJP06oookJP?o00[o00?ooo]Zool00?oo00000ooo0003o`000004oook
J_l0oi3o0?n@o`3oT0[ooo]Z1Oo9o`04oookJP03o`3oP_l0Kooooo]Z00;ooo]Z00?obOl0ool80?oo
20000_oonfX00ol0<_oooo]ZoookJP05oookJP03o`0:oooonf[ooo]Z00;ooo]Z00?oolT0oookJ_oo
nfX00_oonfX01Ooio`3ooo]ZooWo0?ood`3ooo]Z00;onOl000?ooo]Zoonm0?oo_@000_oo_@0Eoook
JP05ool30?oonf[ooo]ZoookJ_ooDP000ooonfX2ool400Gooo]Z00?oodD0oookJ_oonfX04ooonfX0
0ol0003ooo]ZoookJP0>oookJP03ool80?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX08?oonfX0
013ooo]Z00?o0000oookJ_oonfX0EOoonfX00ooo1`3ooo]ZoookJP0>oookJP;o0000:_oonfX00ooo
003ooo]ZoookJP0?oookJP;ooad01OoonfX2ool902Sooo]Z00?oojH0oookJ_oonfX01_oonfX00ol0
oeCoom<0o`3oE003o`3oE007o`3oT?l0oeCoc_l0o`3oT?oonf[o0?n@olko0008oookJP04o`3oT?oo
nf[ooo]ZoookJP;oo`P000?obOl0oookJ_oonfX00_o9o`001?oonf[obOl0olWo0?oonfX3oolb00Co
oo]Z1Ol0oh83oookJP?o00[o1?oonfX3ool000;o000000Cooo]Zo`3oT?l0oi3o0?n@4_oonfX4olWo
0003o`3oP_oonf[o06oo00;ooo]Z0_o9o`03oolR0003o`0boooonf[ooo]Z00Gooo]Z0_o>o`04oook
JP08ooo90?oonf[oolT0ooo90?oio`3ooo]ZooWo0?ood`02ooWo0005oookJ_oo_@3ooo]Zoonm0?oo
nfX00_oo_@0>oookJP03oolg0?oonf[ooo]Z017ooo]Z00?oodD0oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP05oookJP03ool50?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX00_oo200YoookJP03
ool80?oo003ooo]Z03?ooo]Z00?o0000oookJ_oonfX07ooonfX0013ooo]Z00?o0000oookJ_oonfX0
=OoonfX00ooo003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00Cooo]Z00?oo`80oookJ_oonfX0
7ooonfX00ooo003ooo]ZoookJP08oookJP;oobP01_oonfX00ooo7@3ooo]ZoookJP0ToookJP03ool0
0?oonf[ooo]Z00Sooo]Z00?oojH0oookJ_oonfX01?oonfX3o`3oE0Col?l000Oo0?n@olko0?l0oi3o
c_l0o`3oT?l0oeCo0?n@00Oooo]Z00?o0?n@oookJ_l0d?l00_oonfX01Ooo203ooo]ZoookJ_o9o`3o
oo]Z00?obOl000?ooo]Zoolb0?oo<P000_oonfX00ooo<P3ooo]ZoookJP07oookJP?o0?n21ooonfX3
o`0000?o0?n@4_oonfX2ool500Cooo]Z00?o0?n2olWo0?o9o`001Oo9o`02oookJP;oob8000?o03;o
oookJ_oonfX00ooonfX01?o>o`3ooo]ZoookJ_l02_l4oookJP;oolT000Ko00[oooo90?oio`3onOl0
oooC0?oio`02oookJPCookd02?oonfX00ooo003ooo]ZoookJP05oookJP03oolg0?oonf[ooo]Z013o
oo]Z0_ooA@0DoookJP05ool00?oonf[ooo]ZoookJ_l00000L?oonfX00ol0003ooo]ZoookJP0Noook
JP004?oonfX00ol0003ooo]ZoookJP0boookJP03ool00?oonf[ooo]Z01_ooo]Z00?oo`00oookJ_oo
nfX05_oonfX2ool7023ooo]Z00?oo`00oookJ_oonfX03ooonfX00ooo:03ooo]ZoookJP04oookJP03
oolM0?oonf[ooo]Z00_ooo]Z00?oo`H0oookJ_oonfX01OoonfX2oolT00Kooo]Z0_oo1P0CoookJP03
oonV0?oonf[ooo]Z00Cooo]Z00?ooiL0o`3oE?o`o`000_l0oe@01_o`o`3o0?n@o`3oT?l0oeCoc_l0
o`3oT0;oc_l000?o0?n@olko0?oo1@000ooonfX01ol0oi3ooo]ZoookJ_oonf[o0=3ooookJ_m8o`00
0ooonfX3olWo0003o`1_oooonf[ooo]Z00[ooo]Z0ol02_l7oookJP?o00000ol0oi000ooo003ooo]Z
oookJP06oookJP03ool00?oonf[ooo]Z00_ooo]Z00Go0=3ooookJ_oonf[ooo]Zo`3oPP04oookJPOo
bOl000?ooo]Zo`0boooonfX00_oonfX00oo>o`3ooo]ZoookJP02oookJP05o`0:oooonf[ooo]Zooo9
0?oonfX00ooob@000ol02_oonOl0oooC0003oookJP;oo`T000?ookd0oookJ_oonfX00_oonfX00ooo
V`3ooo]ZoookJP0:oookJP;oocL04OoonfX00oooA@3ooo]ZoookJP0<oookJP;oo`<02?oonfX2oolN
0003o`000?oonf[ooo]Z02Cooo]Z00?oo`00ool20?oo0P00:OoonfX2ool301_ooo]Z00?o0000oook
J_oonfX07_oonfX0013ooo]Z00?o0000oookJ_oonfX0BooonfX00ooo003ooo]ZoookJP0LoookJP03
ool70?oonf[ooo]Z037ooo]Z00?oobP0oookJ_oonfX02OoonfX00ooo0P3ooo]ZoookJP04oookJP;o
ocP01ooonfX2oolT00Kooo]Z00?oo`H0oookJ_oonfX00_oonfX00oooEP3ooo]ZoookJP0CoookJP?o
oiL00oo`o`02o`3oT004oookJ_o`o`3o0?mDo`3oT0;o0?mD00?ooo]Zo`3oT?o>o`000_o>o`000ol0
oi3ooo]ZoookJP03oookJP03odSo0?oonf[ooo]Z00;ooo]Z0_o9o`02oookJP03o`1_oooonf[ooo]Z
00Kooo]Z0ol02_l7oookJP?o00000ol0oi0>oookJP03o`0boom/o`3oK?l000;oK?l01ooonfX01?l0
d?oooo]ZoookJ_l0oh84oookJP03o`3oE?o9o`3obOl000;ooo]Z1?o9o`001?oonf[o03;ooookJ_o>
o`05oookJP03ool70?oonf[oolT000GoolT00_oonfX00oood`3oo`40ool10008oookJP03oonK0?oo
nf[ooo]Z00[ooo]Z0_oo=`0GoookJP03ool;0?oonf[ooo]Z017ooo]Z00?ooah0o`000?oonfX05_oo
nfX00ooo303ooo]ZoookJP0<oookJP03ool00?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX07Ooo
nfX0013ooo]Z00?o0000oookJ_oonfX0I?oonfX2ool<00Gooo]Z00?o0000oookJ_oonfX05ooonfX0
0ooo0@3ooo]ZoookJP0RoookJP03ool20?oonf[ooo]Z00Cooo]Z0_oo>007oookJP03oolT0?oonf[o
oo]Z00Wooo]Z0oooEP09oookJP03oolY0?oonf[ooo]Z00Oooo]Z1OooU`02oo3o0008ool00?l0oi3o
oo]Zoo3o0?oonf[o0?mDo`3oT?oonfX2o`3oE003o`3oT?l0oeCo0?n@00;oc_l01?oonfX00ol0d?oo
oo]ZoookJP02oookJP03olWo0?oonf[ooo]Z00;ooo]Z00?o06oooookJ_oonfX00_oonfX3o`0:o`Oo
oo]Z0ol000000ol0oi3oo`/0o`3oT003oookJP;oo`D02OoonfX3o`0bo`SoK?l01OoonfX00ol0d?oo
oo]Zo`3oPP04oookJP03o`3oE?o9o`3obOl000CobOl00ooonfX00oo>o`3o03;ooookJP03oookJP04
oomk0?oo1`3oo`L0o`0:o`;ooo]Z00Co00[oooo90?oob@3oolT00_oonfX01?ood`3ooo]Zo`0:ool0
2_l6oookJP03oonK0?oonf[ooo]Z00cooo]Z00?oocL0oookJ_oonfX03_oonfX2ool100Gooo]Z0_oo
2`0DoookJP03o`000?oonf[ooo]Z01;ooo]Z00?oo`00oookJ_oo3000:OoonfX00ooo2@3oo`00oook
JP0]oookJP03o`000?oonf[ooo]Z01cooo]Z000?oookJP03o`000?oonf[ooo]Z00gooo]Z00?oo`00
oookJ_oonfX0>?oonfX00ooo003ooo]ZoookJP0MoookJP03ool10?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX04?oonfX00ooo1P3ooo]ZoookJP0PoookJP03ool00?oonf[ooo]Z00gooo]Z00?oocP0
oookJ_oonfX02?oonfX2oomA00Sooo]Z0_ooEP02oookJP;oo`T00ooonfX00oooQP3oobT0oolY0007
oookJP06ool10?oonf[ooo]ZoookJ_ooU`3ooo]Z1?o`o`001_oonf[o0?n@o`3oT?l02_oo0?mDo`3o
T0Cooo]Z00?o0?n@oookJ_l0oe@01?l0oe@2oookJP04o`3@oooonf[ooo]ZolWo00Kooo]Z00Co06oo
o`0:ool02_oo00[o0_oonfX00ooo203ooo]ZoookJP02oookJP?o00000ol0oi0>oookJP?o03;o0ooo
nfX01?m/o`3ooo]ZoookJ_m/o`02oookJPCoK?l01?oonfX00ol0d?oooo]ZoookJP02oookJP03o`3o
E?oonf[ooo]Z00;obOl000?oo`<0oookJ_oonfX00_oonfX01?o>o`3ooo]ZoookJ_l0<_l3oookJP04
oomk0?oonf[ooo]ZoookJP;o00[o1?oonfX01?l02_oooo]ZoooC0?ood`02oookJP;o00[o1?oonfX0
0oooV`3ooo]ZoookJP0?oookJP03ool00?oonf[ooo]Z00;ooo]Z0_oo2@000ooo>P3ooo]ZoookJP0R
oookJP03o`000?oonf[ooo]Z00Cooo]Z00?ooad0oookJ_oonfX01_oonfX00ooo103ooo]ZoookJP1M
oookJP03o`000?oonf[ooo]Z01cooo]Z000?oookJP03o`000?oonf[ooo]Z04Cooo]Z00?oo`80oook
J_oonfX07?oonfX00ooo003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Wooo]Z00?oo`h0oook
J_oonfX07ooonfX00ooo003ooo]ZoookJP0EoookJP03oolh0?oonf[ooo]Z00Oooo]Z0oooD@03oook
JP03ool50?oonf[ooo]Z00;ooo]Z00?ooeH0oookJ_oonfX01OoonfX01?ooQP3oobT0oookJ_ooQP0:
oookJP09oonG0?oonf[ooo]ZoookJ_o`o`3o0?mDoo3o0?l0oeCo00[o00;o0?n@00Oooo]Zo`3oT?oo
nf[ooo]Zo`3oT?oonf[o0?n@00Gooo]Z0ol0oe@01Ol0d?oo0?mDolWo0?oonf[oo`<000;ooo]Z0ol0
2_l00ol0Kooooo]ZoookJP04oookJP?o00000_oonfX00ol0oi3ooo]ZoookJP0<oookJP?o03;o1_oo
nfX01Om/o`3ooo]ZoookJ_m/o`3ooo]Z00?oK?l00_oo3@001_l0oh;ooo]ZoookJ_oonf[o0?n2o`3@
o`?ooo]Z00?o0?mDoookJ_oonfX00_oonfX01Ol0oa?ooo]ZoookJ_oonf[oc_l000?ooo]Z00?o03;o
oookJ_oonfX00_oonfX00oooN`3ooo]ZoookJP02o`0:o`Cooo]Z00Go00[ooooC0?ood`3ooo]ZoooC
0003oookJP;o00[o00?ooo]ZoonK0?oonfX01ooonfX01Ooo203ooo]ZoookJ_oonf[oofX000cooo]Z
00?oocX0oookJ_oonfX08ooonfX00ol0003ooo]Zool10002oookJP;ooad0:?oonfX00ooo0`3ooo]Z
oookJP0WoookJP03ool40?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX06ooonfX000oooo]Z00?o
0000oookJ_oonfX08_oonfX00ooo003ooo]ZoookJP0OoookJP03ool20?oonf[ooo]Z02Sooo]Z00?o
0000oookJ_oonfX02?oonfX00ooo3P3ooo]ZoookJP0IoookJP03ool50?oonf[ooo]Z02Gooo]Z0ooo
D@03oookJP03ool50?oonf[ooo]Z00;ooo]Z00?ooeH0oookJ_oonfX01OoonfX01?ooQP3oobT0oon6
0?ooQP0;oookJP0:oonG0?oonf[ooo]Zo`0:ooo`o`3o0?mDoo3o0?oonf[o0?mDoookJP;o0?n@00Go
oo]Zo`3oT?oonf[ooo]Zo`3oT007oookJP;oc_l000CobOl0o`3oE?l0oeCoo`<00_l0oe@4oookJP03
o`1_oooonf[ooo]Z00?o00004OoonfX3o`0bo`[ooo]Z1?m/o`02oookJP;oK?l00_oo3@000ol0oh;o
o`00oh[o0002oookJP03o`3@oooonf[o0?mD00?ooo]Z0_o>o`001?l0oa?o06oooookJ_o>o`05oook
JP03o`0boooonf[ooo]Z00;ooo]Z00Goog/0o`0:oooonf[ooo]Zo`0:o`03oookJP03oooC0?l02_oo
om<000;ooo]Z00Ooom<0oookJ_oonf[ooo]ZoonK0?l02_oooi/000?ooo]Z0_oo3002oookJP;oo`P0
0_oonfX00oooJP3ooo]ZoookJP0:oookJP;oocX06?oonfX00ooo4@3ooo]ZoookJP07oookJP;oo`80
00?ooo]Zo`000?oonfX07OoonfX00ooo3@3ooo]ZoookJP0<oookJP03ool00?oonf[ooo]Z03oooo]Z
00?o0000oookJ_oonfX06ooonfX000oooo]Z00?o0000oookJ_oonfX0G_oonfX00ooo003ooo]Zoook
JP0?oookJP03o`000?oonf[ooo]Z00gooo]Z00?oo`80oookJ_oonfX03?oonfX00ooo3`3ooo]Zoook
JP03oookJP;oo`D09?oonfX2ool100Cooo]Z00?ooe40oookJ_oonfX01_oonfX00oooEP3ooo]Zoook
JP06oookJP;oohH02ooonfX01oooU`3ooo]ZoookJ_l02_oooo]Zo`0:ool0oe@00ooo3002oolR0003
o`3oT?oonf[ooo]Z00;ooo]Z00?o0?n@oookJ_oo00001_oonfX00oo9o`3o0=3oo`0:o`03oookJPCo
0?mD0ol0000AoookJP;o03;o0ooo0005oookJP?oo``000Sooo]Zofco0?ooV`3oK?l0oonK0?oonf[o
K?l0oookJP;oK?l000Cooo]Zoh[o0?n:o`3oR_l00_l0oh83oookJP07o`3@ool0oeCooo]ZoookJ_o>
o`3ooo]Zo`3o4`02oookJP03o`1_oooonf[ooo]Z00Gooo]Z00_o03;ooookJ_oonf[ooo]Zo`0:oooo
N`3ooo]Zoomk0?oonf[o00[ooookJP02oooC0005o`0:ooooU`3ooo]ZoooC0?oo1@000_oonfX3oonK
00Gooo]Z00?oo``0oookJ_oonfX00ooonfX00oooJP3ooo]ZoookJP0;oookJP;oocX02_oonfX00ooo
<`3ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z00?ooo]Z00?ooa40oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP0IoookJP03ool00?oo3@3oo`d002Wooo]Z00?oo`40oookJ_oonfX09OoonfX00ol0
003ooo]ZoookJP0JoookJP003ooonfX00ol0003ooo]ZoookJP0PoookJP03ool00?oonf[ooo]Z03Ko
oo]Z00?oo`40oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z00co
oo]Z00?ooaL0oookJ_oonfX00ooonfX00ooo3`3ooo]ZoookJP0RoookJP03ool00?oonf[ooo]Z00_o
oo]Z00?ooe40oookJ_oonfX04?oonfX00oooQP3ooo]ZoookJP08oookJP05oonG0?oonf[o00[ooook
J_l02_l00ooonfX01?o`o`3onOl0oolR0?oo8P02o`3o4`Cooo]Z00?o0?n@oookJ_oonfX00_oonfX2
o`0:o`04olWo0?oonf[ooo]Zo`3@o`Cooo]Z0ol000000ooonf[o0?mDo`3oE003o`3oE0_ooo]Z0_l0
<_l00ooo203ooo]Zool00004ool000Gooo]Z0om/o`02oookJP03ofco0?oonf[ooi/000?oK?l000Co
oi/0oh[o0?l0oh;ooo]Z0_ooV`002ol0oh;ooo]ZoookJ_oonf[o0?mDo`3@oooonf[oc_l0oookJ_o>
o`3o0?lC00;oc_l000?o06oooookJ_oonfX01_oonfX01Ol0<_oooo]Zool00?l02_oooo]Z00?oog/0
00Oo00[ooookJ_oonf[ooo]ZoooC0?ooU`3oom<000Cooo]Z1?ooV`08oookJP;oofX06_oonfX00ooo
<`3ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z01Sooo]Z00?oo`00oookJ_oonfX0:OoonfX00ooo
0@3ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01Wooo]Z000?oookJP03o`000?oonf[ooo]Z03So
oo]Z00?oo`00oookJ_oonfX06_oonfX00ooo103ooo]ZoookJP0JoookJP03o`000?oonf[oo`0001?o
oo]Z0_oo5`0RoookJP03ool30?oonf[ooo]Z02Oooo]Z00?oohH0oookJ_oonfX00_oonfX2oonC00;o
o`X000Cooo]ZoonG0?l02_oooo]Z0_l02_l2oookJP;onOl000?oob80o`3o4ooio`000ol0oa<4oook
JP04o`3oT?l02_oo00[oo`0:o`;ooo]Z00GobOl0oookJ_oonf[ooo]Zo`3@o`03o`0000Wooo]Z1Ol0
oe@3oookJP?o03;o00Cooo]Zool80?oo203ooo]Z1Ooo0002oookJP?oK?l01OoonfX00om/o`3ooo]Z
o`3oPP02ofco00;ooo]Z1_ooV`003_l0oh;ooo]ZoookJ_l0oeCooo]Zo`3@ooo>o`3ooo]Zo`3o4oo>
o`3ooo]Zolko0?oonf[o06oo1ooonfX2ooWo0003ool00?oonf[oog/000?oog/000?ooo]Zo`0bool0
<_l00_oonfX00oooU`3ooo]ZoookJP03oookJP03o`0:ooooV`3ooi/000Sooo]Z0oooJP0CoookJP03
ool00?oonf[ooo]Z00;ooo]Z0_oo<`02ool801cooo]Z00?o0000oookJ_oonfX01_oonfX2ool400co
oo]Z00?oo`80oookJ_oonfX06ooonfX00ooo1@3ooo]ZoookJP0UoookJP;oo`D04?oonfX00ol0003o
oo]ZoookJP0IoookJP003ooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z01?ooo]Z
00?ooaL0oookJ_oonfX03?oonfX2ool500[ooo]Z0_oo4@06oookJP03ool30?oonf[ooo]Z02Gooo]Z
00Coo`D0oookJ_oonf[oohH00ooonfX02oooT`3ooo]ZoonC0?ooT`3ooo]ZoonG0?oonf[o00[ooook
J_l02_oooo]Z00Oo0?lC00ConOl0o`3o4ooonf[ooo]Z0ol02_l00ol0oi3ooo]ZoookJP02oookJP03
olWo0?oonf[o000000;o000000?o0=3ooookJ_oonfX02ooonfX00ooo0@3ooo]ZoookJP03o`3oE0Oo
oo]Z1?oo0003ofco00Oooo]Z0_n:o`02ofco00Gooo]Z00?o0?n2oonK0?ooV`000oooV`001Ol0oh;o
0?mDoookJ_oonf[o0=3o00;oc_l000Co0?lCool=0?oo3@3oo`D00_oonfX00ol0Kooooo]ZoookJP03
oookJP03ooWo0?oonf[o03;o00Cooo]Z0_ooN`000ooonf[o03;oo`0:o`02o`0bo`03oonG0?l02_oo
oo]Z00;ooo]Z00?o00[ooookJ_l02_l02OoonfX2oomZ00Kooo]Z00?ooa`0oookJ_oonfX00_oonfX2
ool600cooo]Z0_oo<`0HoookJP03oolD0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX00ooonfX0
0ooo003ooo]ZoookJP0LoookJP03ool>0?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP0HoookJP003_oonfX00ol0003ooo]ZoookJP0foookJP03ool00?oonf[ooo]Z
03Oooo]Z00?oo`00oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0JoookJP;oo`802_oonfX2oolM
00Kooo]Z00?ooa40oookJ_oonfX08ooonfX00ooo003ooo]ZoookJP0:oookJP06oon60?oonf[ooo]Z
oookJ_ooT`3ooo]Z0_ooT`02o`0:o`;ooo]Z1?l0oa<3ooWo0004oo3o0?l0oa?onOl0o`3o4`;o00[o
1?oonfX00ol0oi3ooo]ZoookJP03o`0000Cooo]Z00Co0=3ooookJ_oo203oo`P01?oonfX2olko00?o
oo]Z0ol0<_l;oookJP?oK?l000?oR_l0oookJ_oonfX01?oonfX3oh[o00;ooo]Z00?oK?l0o`3oP_oo
nfX01?oonfX01?l0oh;oo`/0oonK0?ooV`03oookJP06o`3oE?oonf[ooo]ZoookJ_l0d?oo0?lC1Oo>
o`02oookJP09o`1_oooonf[ooo]ZoookJ_oio`3ooo]Zo`0:oooonf[o03;o00Gooo]Z00Oo03;ooook
J_l0<_oo00[ooookJ_ooU`3o03;o00;ooo]Z00Co00[ooookJ_oonf[o00[o0ooonfX00oooM03ooo]Z
oookJP02oookJP03ool20?oonf[ooo]Z00Kooo]Z00?ooa`0oookJ_oonfX07?oonfX00ooo:`3ooo]Z
oookJP07oookJP03ool00?oonf[ooo]Z00;ooa@01_oonfX00ol0003ooo]ZoookJP0PoookJP03ool0
0?oonf[ooo]Z02Sooo]Z00?oo`80oookJ_oonfX07OoonfX3o`0001Wooo]Z000>oookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?oo`00oookJ_oonfX06_oonfX00ooo003ooo]ZoookJP0GoookJP;oo`<02_oo
nfX00ol0003ooo]ZoookJP0CoookJP03ool00?oonf[ooo]Z013ooo]Z00?ooad0oookJ_oonfX06_oo
nfX00ooo4@3ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z01Oooo]Z00?ooi<0oookJ_l02_l00_oo
T`000ooonf[o0?lCo`3o4`02o`3o4`;ooo]Z0_oio`000ol02_ool?l0o`3o4`03ooWo00Cooo]Z0ol0
0002ool>00Kooo]Z00?o0=3ooookJ_oonfX00_oonfX4olko00?o03;o2ooonfX3ofco00;oR_l00_oo
nfX00on:o`3ooo]ZoookJP03oh[o00?ooo]Z0_l0Kol00ooonf[o0?n2o`3oPP03oookJP05o`3oP_oo
nf[oo`/0ool;0?l0oi000_oonfX00ol0oeCooo]Zo`3oPP02oookJP03olko0?l0d?ooc_l000;oc_l0
1OoonfX01Ol0Kooooo]ZooWo0?oonf[o00[o00?ooo]Z00Go03;ooookJ_oonf[ooo]Zo`0bo`02oook
JP08o`0booooT`3ooi<0oonG0?l02_oo03;ooookJ_l02_l2oookJP05o`0:oooonf[ooo]ZoookJ_oo
M0001?oonfX00ooo0P3ooo]ZoookJP06oookJP03oolL0?oonf[ooo]Z01_ooo]Z00?oob/0oookJ_oo
nfX04_oonfX2ool80003o`000?oonf[ooo]Z01kooo]Z00?oo`00oookJ_oonfX0:OoonfX00ooo0P3o
oo]ZoookJP0JoookJP?o00000_oonfX00ol0003ooo]ZoookJP0GoookJP003_oonfX00ol0003ooo]Z
oookJP1@oookJP03ool00?oonf[ooo]Z01?ooo]Z00?oo`P0oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP0BoookJP03ool00?oonf[ooo]Z02?ooo]Z0_oo2@000ooo9P3ooo]ZoookJP05oookJP03oolA
0?oonf[ooo]Z023ooo]Z0_l02_l2oookJP;ooi<000?ooo]Zo`3o4ooonfX01_l0oa<2ool;00;ooo]Z
00ConOl0o`000?l0003o00000_oonfX00oo9o`3ooo]ZoookJP07oookJP03o`3@oooonf[ooo]Z00;o
c_l00ol0<_l;oookJP?oK?l00_oonfX3oh[o00;ooo]Z0on:o`03oookJP03o`1_oooo1P3o06oo00Co
oo]Z0_l0oh82oookJP03o`3oP_oonf[o0?n200;ooo]Z00Co0?n@oookJ_l0oeCooo]Z0_l0oh801?oo
nf[o0?lCoookJ_l0d?l7oookJP03ooWo0?l0Kooooo]Z00?o00[o0ooonfX00ol0<_oooo]Zo`0bo`03
oookJP03o`0boooonf[ooiL000;ooiL000Goo`00o`0:oooo3P3ooo]Zo`0:o`03oookJP03oomd0?oo
nf[ooo]Z02Gooo]Z00Coo`<0oookJ_oonf[ooo]Z0_oo:`03oookJP;oo`L04_oonfX00ol0003ooo]Z
oookJP0=oookJP03ool60?oonf[ooo]Z00cooo]Z00?oo`40oookJ_oonfX06?oonfX00ooo1P3ooo]Z
oookJP0YoookJP?o00001OoonfX00ol0003ooo]ZoookJP0GoookJP003_oonfX00ol0003ooo]Zoook
JP1<oookJP03ool00?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX02ooonfX00ooo003ooo]Zoook
JP0RoookJP03ool50?oo:`3ooo]Z00Gooo]Z00?oo`T0oolV0?oonfX01_oonfX00ooo4@3ooo]Zoook
JP0:oookJP03oolg0?oonf[ooo]Z01;ooo]Z0_l02_l4oookJP;oo`@00ooob@03o`0bo`04o`3o4ol0
<_oo0?lCoo3o00?o000000Cooo]ZooWo0?oio`3onOl00_oonfX00ol0oi3ooo]ZoookJP07oookJP04
o`3@ool0<_oo03;oo`0bo`_oc_l00om/o`06olko0005ool00?n:o`3oc_l0olko0?n:o`000_oonfX3
o`1_o`Oooo]Z00Co0?n2oookJ_l0oh;ooo]Z0_l0oh82o`3oE0;ooo]Z00?o0?n@o`3oP_l0oh800ooo
nfX01?l0oa?ooo]ZoookJ_l0d?l5oookJP03ooWo0?oonf[o06oo00?ooo]Z0_l02_l01?oo3@3o00[o
oookJ_l0<_l2oookJP;ooi<000Oooo]ZoonG0?oonf[ooiL0oookJ_ooU`3ooo]Z00;oo`h000Go03;o
oookJ_oonf[ooo]Zoomd000IoookJP03oolT0?oonf[ooo]Z00Cooo]Z00?oo`@0oookJ_oonfX08Ooo
nfX00ol0003ooa@0oookJP0;oookJP03ool00?oonf[ooo]Z02_ooo]Z00?oo`00oookJ_oonfX09?oo
nfX3o`0000Sooo]Z00?o0000oookJ_oonfX05ooonfX000kooo]Z00?o0000oookJ_oonfX03?oonfX0
0ooo003ooo]ZoookJP0ioookJP03ool00?oonf[ooo]Z02kooo]Z00?o0000ool80?oonfX01?oonfX0
0ooo0`3ooo]ZoookJP0QoookJP03ool10?oonf[ooo]Z00Cooo]Z00?oo`D0ool[0?oonfX01_oonfX0
0ooo9P3ooo]ZoookJP0BoookJP;oocL04OoonfX01Ooo003ooo]Zo`0:oooonf[ooeP000;ooo]Z0_l0
2_l00ooob@3ooi<0ooo90002ooo90003o`3o4ooonf[o0?lC00?o00000ooonfX6o`3o4`04oookJ_oo
V`3ooi/0oonK00Cooo]Z0ol0<_l00ol0d?oooo]Zolko0003olko00Kooo]Z0_m/o`02oookJP;ooa00
0ooonfX3oh[o0003oookJ_n:o`3ooo]Z00?o06oo2ooonfX00ol0oh;ooo]Zo`3oPP02o`3oE006oook
J_l0oeCo0?mDo`3oP_l0oeCo0?n@0ooonfX00ol0oa?ooo]ZoookJP02oookJP05odSo0?oio`3ooo]Z
oookJ_oio`000ooonfX00ol0Kooooo]ZoookJP02oookJP;oo`d000Co03;oo`0:ool0<_oooi<00ooo
nfX01_l0<_oooiL0oonG0?ooU`3ooo]Zo`0:o`;ooo]Z00Co00[oo`0booooM03oog@03?oonfX00ooo
DP3ooo]ZoookJP0:oookJP;oob@01_oonfX00ooo103ooo]ZoookJP0NoookJP05ool00?oonf[ooo]Z
oolD0?l00000:?oonfX00ooo0@3ooo]ZoookJP0WoookJP03ool20?oonf[ooo]Z00Sooo]Z1?l0000;
oookJP03o`000?oonf[ooo]Z01Oooo]Z000>oookJP03o`000?oonf[ooo]Z04Cooo]Z00?oo`00oook
J_oonfX08?oonfX2ool200cooo]Z00?oo`h0oookJ_oonfX00_oonfX00ooo203ooo]ZoookJP0Poook
JP03ool00?oonf[ooo]Z00?ooo]Z00?oo`40oookJ_oonfX01ooonfX00ooo:`3ooo]ZoookJP0@oook
JP;oocd01ooonfX01?oo=`3ooo]ZoookJ_oonfX2ool>00Cooo]Z00?oo`h0oomS0?ooH`001ooonfX0
0ol02_oooo]ZoomH0002oomH0003o`0:oooonf[ooo]Z00;oolT000?o00[ooookJ_oob@000ol00000
0ooonf[o0?lCo`0:o`09oookJP;ooi/000Co0?n@oonK0?l0oa?o0?lC0_l0<_l4oookJP03o`3@oooo
nf[ooo]Z00;oo`l03_oonfX4oh[o00?o06oo0_n:o`0<oookJP09o`3oP_oonf[o0?mDo`3oP_oonf[o
0?n2o`3oE?ngo`3o0?mD00;ooo]Z00Co0?n@oookJ_oonf[o0?lC0ooonfX00ooio`3oo`T0ool90002
ooWo00Gooo]Z00?o06oooookJ_oonfX00_oonfX2oolb0003oonC0?l0<_oo00[o00?o00[o00?ooo]Z
o`0booooU`000ol02_l2oookJP03o`0:ooooM03oog@000;oog@02ooonfX00oooDP3ooo]ZoookJP03
oookJP03ool00?oonf[ooo]Z00Cooo]Z0_oo900WoookJP03ool00?oonf[ooo]Z00;ooo]Z00?o0000
oookJ_oonfX01?oonfX2ool701oooo]Z00?oo`40oookJ_oonfX05_oonfX00ooo1`3ooo]ZoookJP0>
oookJP03ool20?oonf[ooo]Z00Gooo]Z0ol0000@oookJP03o`000?oonf[ooo]Z01Kooo]Z000=oook
JP03o`000?oonf[ooo]Z06?ooo]Z0_oo000AoookJP03ool>0?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX06?oonfX00ooo0@3ooo]ZoookJP0WoookJP03oolm0?oonf[oocd000Oooo]Z00CoocL0oook
J_oo3P3oo`h01?oonfX00ooo3P3ooo]ZoomS0002oomS00Gooo]Z1?l02_l00oooF03ooo]ZoookJP02
oookJP;oolT00ol000002?oonf[o0?lCo`3o4ol0oa?o03;ooookJ_l02_oooo]Z1_m/o`02oookJP?o
oi/00_oo2`06o`3o4`?ooo]Z00?oo`l0olko0?oonfX03_oonfX3o`1_o`?oR_l03_oonfX2o`3oE0;o
0?n20_ngo`02ool200;o0?mD0_oonfX00ol0oi3o0?lCoookJP02oookJP05ooWo0?m8o`3onOl0ooWo
0?l0d?l01ooonfX01?l0Kooooo]ZoookJ_oonfX2oolb00;o00[o0_l0Kol2oookJP03o`0:ool0<_oo
00[o00;ooo]Z0_l02_l00ooonf[o03;ooookJP02oomd00Cooo]Z00?oo`40oookJ_oonfX00_oonfX0
0oooDP3ooo]ZoomB000VoookJP;oo`P05?oonfX00ol0003ooo]ZoookJP04oookJP03ool70?oonf[o
oo]Z00cooo]Z0_oo200>oookJP03ool00?oonf[ooo]Z01Oooo]Z00?oo`L0oookJ_oonfX04ooonfX3
o`0001?ooo]Z00?o0000oookJ_oonfX05_oonfX000gooo]Z00?o0000oookJ_oonfX08_oonfX2ool0
03_ooo]Z00?oo`00oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0@oookJP03ool80?oonf[ooo]Z
00Cooo]Z00?oo`40oookJ_oonfX0:_oonfX2ool:00Gooo]Z00?oocL0oookJ_oonfX01_oonfX3oomS
00Gooo]Z1_l02_l00oooF03ooo]ZoookJP03o`0000;oolT00ooonfX2o`3o4`05oookJ_l0<_oo00[o
oookJ_m/o`000_oo0@05ofco0004o`0booooV`3o0?n@ool;00Oooo]Z1Ol0oa<<oookJP?o06oo0_oo
nfX3ool000[ooo]Z0ooo7@000ooonf[o0?mDoookJP03okOo0004o`3oP_l0oeCooo]Zo`3oE0;ooo]Z
00Co0?mDoookJ_oonf[o0?n@0ooonfX01Ooio`3oB?l0ooWo0?oonf[o0=3o00Sooo]Z00?o06oooook
J_l0<_l01?ooT`001ol0Kooo03;oo`1_ool0Kooooo]Zo`0:ooooF0001?l02_l2o`0bo`[ooo]Z0ooo
3@000oooDP3ooo]ZoookJP0GoookJP03oolS0?oonf[ooo]Z01Kooo]Z00?oo`@0oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP03oookJP;ooa<03OoonfX00ooo003ooo]ZoookJP0>oookJP03ool00?oo
nf[ooo]Z01Wooo]Z00?oo`00oookJ_oonfX03_oonfX3o`0001Kooo]Z00?o0000oookJ_oonfX05_oo
nfX000gooo]Z00?o0000oookJ_oonfX08?oonfX00ooo003ooo]ZoookJP0goookJP03ool00?oonf[o
oo]Z027ooo]Z00Co0000oookJ_oo1@3oo`D02?oonfX00ooo403ooo]ZoookJP03oookJP03ool80?oo
nf[ooo]Z02;ooo]Z00?oo`00oookJ_oonfX01?oonfX2ool500oooo]Z0_ooB`08oookJP03oomS0?oo
nf[ooo]Z00Gooo]Z0ol02_l3o`000007o`0bool02_oo03;oo`0bool02_ooolT0ool50002o`0:o`05
o`3o4ooonf[o03;oo`0:oooonfX00_m/o`001?oonf[oK?l0o`0bool0<_l3ofco00;ookd000Co0?n@
oonm0?oo_@3ookd02OoonfX6o`3o4`?ooo]Z0ol0Kol4oookJPGoo`001?oonfX3oolB00Cooo]Z00Co
oad0okOo0?l0oeCo]ol01?oonfX00ol0oeCooo]Zo`3oE003oookJP04o`3oE?l0oa?ooo]Zo`3oT0;o
oo]Z00?oB?l0ooWo0?oonfX00_oio`000ol0d?oooo]ZoookJP05oookJP;oom<01?oonfX01Ol0Kooo
oo]Zo`1_ool0<_oooo]Z00;o06oo00?ooeP0o`0:ool02_l00_oo2`000ol02_oo03;ooookJP0;oook
JP03oomB0?oonf[ooo]Z00[ooo]Z0_oo>`0;oookJP;oob<02?oonfX00ooo0@3ooo]ZoookJP0Ioook
JP04o`000?oonf[ooo]Zool102_ooo]Z00?oo`<0oookJ_oonfX07?oonfX4o`0000Kooo]Z00?oo`<0
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0FoookJP003OoonfX00ol0003ooo]ZoookJP1Foook
JP03ool20?oonf[ooo]Z02;ooo]Z00Goo`40oookJ_oonf[ooo]Zo`00000;oookJP03ool@0?oonf[o
oo]Z01oooo]Z00?oo`00oookJ_oonfX01OoonfX00ooo003ooo]ZoookJP0EoookJP03oom;0?oonf[o
od/000Sooo]Z00?oof<0oookJ_oonfX01?oonfX3o`00000:oomH0?l02_oo03;ooookJ_l0<_oooo]Z
o`0boooonf[o00[oooo900;ooo]Z00?o00[ooooC0?ood`000_l02_l3ofco00Gooo]Z00Gooi/0ofco
0?oo_@3ooo]Zo`3oT002oookJPGookd02_oonfX3o`3o4`Cooo]Z00?ooa40oookJ_oonfX01Ooo0000
1Ooonf[o]ol0oookJ_oonf[ooa8000Cooo]Z0ongo`02oookJP03o`3oE?oonf[ooo]Z00;ooo]Z0_l0
oe@5oookJP03o`3o4ooonf[o0?n@00;ooo]Z00OoB?l0ooWo0?oio`3ooo]ZooWo0?oonf[o0=3o00Go
oo]Z00?oom<0o`0bool0Kol00_oo1P001_oonf[o06oooookJ_oonf[o06oooookJP?o00[o00KooeP0
oookJ_oonf[o03;ooookJ_l0<_lHoookJP;ooc/02?oonfX00ooo003ooo]ZoookJP02oookJP03oolS
0?oonf[ooo]Z01Oooo]Z00?oo`/0oookJ_oonfX02_oonfX00ol0003ooo]Zool1000JoookJP;oo`T0
:ooonfX3o`0001gooo]Z00?o0000oookJ_oonfX05_oonfX000gooo]Z00?o0000oookJ_oonfX0>Ooo
nfX00ooo003ooo]ZoookJP0ioookJP03ool00?oonf[ooo]Z00Sooo]Z0_l0000MoookJP03oolC0?oo
nf[ooo]Z00Cooo]Z00?oo`P0oookJ_oonfX01?oonfX00ooo003ooo]ZoookJP0PoookJP03oom;0?oo
nf[ooo]Z00Kooo]Z00?oof<0oookJ_oonfX00ol00002ool@0003oome0?oonf[ooo]Z00;o03;o0_l0
2_l01Ooonf[o03;oo`0:oooonf[oolT000Goom<000?oB?l0ofco0?oonfX00_m/o`03oookJP03oonK
0?oonf[oK?l000?ooo]Z00?o0?n@oookJ_oonfX01?oonfX3oonm00;ooo]Z00?onOl0ool90?oo2@00
0_l0Kol6oookJP?ooa4000?ooo]Zool00?oo00000ooo0002okOo00Cooo]Z0ongo`05oookJP;o0?mD
0_oonfX00ol0oeCooo]Zo`3oE002oookJP03oonV0?oonf[o0?lC00;o0?mD00Cooo]Zo`3oT?m8o`3o
ojH00_oonfX01Ooo003ooo]ZoookJ_oonf[o0=3o00?ooo]Z00Ooom<0o`0boooonf[ooo]Zo`1_oooo
nf[o06oo00?ooo]Z00Go06oooookJ_oonf[o03;ooookJP02oomH0004o`0boooonf[ooo]Zo`0boa?o
oo]Z0_oo2@03oookJP;ooc/03ooonfX2ool=00Oooo]Z00?ooah0oookJ_oonfX02ooonfX2ool;00go
oo]Z00?o0000oookJ_oonfX03?oonfX00ooo1@3ooo]ZoookJP0:oookJP03ool90?oonf[ooo]Z00ko
oo]Z00?oo`00oookJ_oonfX05_oonfX3o`00023ooo]Z00?o0000oookJ_oonfX05_oonfX000gooo]Z
00?o0000oookJ_oonfX0=OoonfX00ooo003ooo]ZoookJP0coookJP03ool10?oonf[ooo]Z00;ooo]Z
00?oo`00oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0CoookJP03oolH0?oo2@3oo`T000Cooo]Z
00?ooa<0oookJ_oonfX01?oonfX00ooo203ooo]ZoookJP0XoookJP04oom;0?oonf[ooo]ZoookJP;o
o`/00_oonfX3o`0000?ooo]Z0_ooM@001?oonf[oogD0oome0?l0<_l3oookJP06o`0:ool0<_oo00[o
oookJ_l02_ooolT00_ood`02odSo0006oookJ_m/o`3oK?l0ofco0?m8o`3oK?l00_oonfX00oooV`3o
K?l0oookJP04oookJP03o`3oT?oonf[oo`0000Kooo]Z00ConOl0o`1_ool0Koooo`T03_oonfX3ool0
00;o]ol000?ooo]ZokOo0?ngo`000_ngo`09oookJP;o0?mD00Wooo]Zo`3oE?l0oeCooo]Zofco0?l0
oa?oojH0o`3oE?l0oa<00oooYP001?oonf[o0?n@oookJ_oo4`06oookJP03o`3@oooonf[oom<000?o
03;o0_oonfX00ol0Kooooo]ZoookJP03oookJP03o`1_oooonf[oogD000CooeP00_l0Kol00ol0<_oo
oo]ZoookJP04oookJP03oom=0?oonf[ooo]Z013ooo]Z0_oo300FoookJP;ooah06OoonfX2ool20003
oookJ_l0003ooo]Z01Wooo]Z0_oo000VoookJP?o000000?ooo]Zool00?oonfX08?oonfX00ol0003o
oo]ZoookJP0FoookJP003?oonfX00ol0003ooo]ZoookJP0coookJP03ool00?oonf[ooo]Z037ooo]Z
00Goo`D0oookJ_oonf[ooo]Zool1000HoookJP03o`000?oonf[ooo]Z00cooo]Z0_oo1005oookJP03
ool90?oonf[ooo]Z02Sooo]Z00?oo`00oookJ_oonfX01OoonfX2ool300Sooo]Z0ol00009oookJP;o
03;o0_ooM@03oookJP;o03;o00Co00[oo`0boooonf[oolT01?m8o`03ofco0005odSo0?oonf[oK?l0
oonK0?m/o`001ooonfX00ol0oi3ooo]ZoookJP03oookJP?o06oo00?onOl0oookJ_oio`002OoonfX3
oomU00Cooo]Z00?o]ol0oookJ_ngo`000_ngo`05oookJP?o0=3o1?oonfX01?l0oeCooo]Zo`3oE?oo
5002o`3o4`05ofco0?l0oa?o0?lCo`3o4oooYP000ooonfX00om8o`3ooo]Zo`3oT003oolC00Cooo]Z
00?oom<0o`3@oooonfX00_oonfX2o`0bo`03o`1_ool0<_oo06oo00Cooo]Z00Co06oooome0?oonf[o
03;o0_ooF002oookJP03o`0bool0Kooooo]Z00Gooo]Z00Goodd0oookJ_oonf[ooo]Zool8000Roook
JP04ool00?oonf[ooo]ZoookJP;ooah02OoonfX00ooo003ooo]ZoookJP0AoookJP03o`000?oonf[o
oo]Z00Oooo]Z00?oo`<0oookJ_oonfX03OoonfX00ooo003ooo]ZoookJP0GoookJP;oo`@02?oonfX4
o`0001[ooo]Z0_oo100;oookJP03o`000?oonf[ooo]Z01Gooo]Z000<oookJP03o`000?oonf[ooo]Z
057ooo]Z00?oo`80oookJ_oonfX04ooonfX00ooo1@3ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?oo`40oookJ_oonfX07OoonfX2oolN00Kooo]Z0_oo5`06oookJP;oo`H05OoonfX3o`00
00cooo]Z00Go03;ooookJ_oonf[ooo]Zoome0004o`0bo`0:oookJ_l0KoooB?l0odSo0?oob@3oB?l0
oookJ_l0Kooooo]ZodSo00;oK?l00_oonfX3oolD00Oooo]Z00?o0?n@oookJ_l0Kol00_l0Kol=ooWo
00GoofD01_oio`000ooonf[o]ol0okOo0002oookJP03o`3@oooo4@3o0=3o00Sooo]Z00?o0?mDoook
J_oo50000_oo50001?l0oeCoK?l0oonV0?l0oa<4oookJP04odSo0?oonf[ooo]Zo`3oT0;ooo]Z0_oo
d`001Ooonf[oom<0oookJ_oonf[o0=3o00Cooo]Z00Co06ooo`0bool0d?oo0=3o0_l0<_l2oome0009
o`1_oooonf[ooo]Zo`0boooonf[oo`40oookJ_l0<_oo06oo00Cooo]Z0_ooC@0HoookJP03oolA0?oo
nf[ooo]Z02Wooo]Z0_oo3@05oookJP03o`000?oonf[ooo]Z023ooo]Z00?oo`T0oookJ_oonfX05?oo
nfX3o`0002_ooo]Z00?o0000oookJ_oonfX05OoonfX000cooo]Z00?o0000oookJ_oonfX0C?oonfX2
ool000?ooo]Z00?oo`80oookJ_oonfX0;OoonfX00ooo0@3ooo]ZoookJP02oookJP03o`000?oo003o
oo]Z02Cooo]Z0_oo7P07oookJP03oolG0?oonf[ooo]Z01Sooo]Z0ol0000>oookJP03o`0boooonf[o
oo]Z00?o03;o00GoogD0oookJ_oonf[o03;oo`1_o`02oomZ00?ooa<01Om8o`001Om/o`3oB?l0oolD
0?oo503oK?l000Oooo]Z0_l0Kol00ol0oi3ooo]ZoookJP03oookJPConOl01?oonfX3oomU00;ooo]Z
0_ooI@02oookJP03ool50?ngo`3o]ol000Co]ol00ol0d?l3oolA00Sooo]Z0_l0oa<2o`3oE006oook
J_l0oa?ooo]Zofco0?oonf[o0?lC0_oonfX00om8o`3ooo]ZoookJP02oookJP03o`3oT?ood`3ooo]Z
00;oom<00ooonfX02Ol0d?oooo]ZoookJ_oonf[o06ooool80?oonf[o0=3oo`1_o`02o`3@o`;o03;o
00Co06ooo`0bool0<_oooo]Z0_l0<_l00ooonf[o06oooookJP03oookJP?oodd02ooonfX00ooo>P3o
oo]ZoookJP0:oookJP03oolA0?oonf[ooo]Z01Cooo]Z0_oo2`04oookJP;ooaX03OoonfX00ooo3@3o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Cooo]Z00?oo`<0oookJ_oonfX06_oonfX00ooo003o
oo]Zo`000002o`0002kooo]Z00?o0000oookJ_oonfX05OoonfX000cooo]Z00?o0000oookJ_oonfX0
3?oonfX00ooo003ooo]ZoookJP0joookJP03ool00?oonf[ooo]Z02oooo]Z00?oo`@0oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP0UoookJP04oolN0?oonf[ooo]ZoookJP?oo`h05OoonfX00ooo703o
oo]ZoookJP03o`00013ooo]Z1?l0<_l2ool<00Gooo]Z00Go06oooomZ0?l0Kooooa<0oookJP02odSo
0006o`1_ool0<_ooB?l0odSo0?oonf[oK?l00om8o`001?m/o`3oB?l0odSo0?oonfX3o`1_o`?ooo]Z
00?o0?n@oookJ_oonfX01?oonfX2ooWo00;ooo]Z0_ooI@0=oookJP?o0=3o3OoonfX00ol0oa?ooo]Z
o`3oE003o`3oE008o`3o4oo`o`3o0?lCofco0?oonf[o0?lCoookJ_m8o`05oookJP04olWo0?ood`3o
om<0oooC00Cooo]Z00?o0=3ooookJ_l0Kol00_oonfX02?l0d?oooo]Zo`3@ool0KoooogD0o`3@oooo
nf[o06oo1Ol0<_l2o`1_o`Cooo]Z00?ood/0oom=0?oonfX02_oonfX00ooo>P3ooo]ZoookJP0Boook
JP03ool80?oonf[ooo]Z00kooo]Z00?oo`/0oookJ_oonfX00_oonfX00ooo6P3ooo]ZoookJP09oook
JP03ool00?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00_oonfX2ool001_ooo]Z00?oo`00oook
J_oonfX03_oonfX3o`0000Gooo]Z00?oo`@0oookJ_oonfX03_oonfX00ooo0@3ooo]ZoookJP0Hoook
JP03o`000?oonf[ooo]Z01Gooo]Z000<oookJP03o`000?oonf[ooo]Z04Gooo]Z00?oo`00oookJ_oo
nfX0;_oonfX00ooo2@3ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01Wooo]Z0_oo1006oookJP03
ool:0?oonf[ooo]Z01?ooo]Z0_oo:P07oookJP?o00001_oonfX00ooo0P3ooo]ZoookJP06oookJP03
ool10?oonf[ooo]Z00Ko03;o1OoonfX00ol0Kooo03;oo`1_o`05oomZ00;oB?l000?ooo]ZodSo0?oo
nfX01?oonfX00oood`3oK?l0o`1_o`06odSo00;ooo]Z00?o0?n@oookJ_oonfX01?oonfX00ooio`3o
oo]ZoookJP0<oookJP?o0=3o00?ooo]ZoonC0?ooT`000ooonfX7oonC00?ooo]Z0_l0oa<01?oonf[o
l?l0oo3o0?o`o`02o`3o4`;ooo]Z00?oK?l0oookJ_m8o`001?oonfX01?oo503ooo]ZolWo0?l0oi03
oooC00Cooo]Z00?o0=3ooookJ_oonfX00ooo50001?l0d?ooogD0o`1_ool0<_l2o`3@o`08o`1_oooo
nf[o03;oo`0bool0Kooo03;oo`1_oooonfX3oom;00_ooo]Z0_oo>P06oookJP03ool30?oonf[ooo]Z
00gooo]Z00?oo`P0oookJ_oonfX03_oonfX2ool201[ooo]Z00?o0000oookJ_oonfX03OoonfX00ooo
103ooo]ZoookJP0KoookJPCo00002?oonfX00ooo103ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
01Gooo]Z000<oookJP03o`000?oonf[ooo]Z06?ooo]Z00?oo`40oookJ_oonfX00_oonfX00ooo103o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z00_ooo]Z00?oo`00oookJ_oonfX01?oonfX00ooo003o
oo]ZoookJP0IoookJP?oobP01_oonfX00ooo:P3ooo]ZoookJP02oookJP?o000000?ooo]ZoolL0?oo
nfX02OoonfX00ooo@03ooo]ZoookJP08oookJP?o03;o00?ooo]Zo`0bool0<_l00_l0<_l01?l0Kooo
og/0oomk0?l0Kol3o`0bo`;ooo]Z00?oofX0odSo0?m8o`001?oonfX3o`1_o`04oookJ_m/o`3ooi/0
oonK00Cooo]Z1?m8o`000ooo603oB?l0odSo000>oookJP?o0=3o0ooo0006oonC00[ooo]Z00Col?l0
o`3o4ol0oa?ooo]Z0_oo3P000ooonf[o0?lCoookJP02oookJP03ofco0?l0oa?o0?lC00?ooo]Z0ooo
50000ol0oi3ooo]ZoooC0004oookJP04o`1_oooonf[o0=3oo`3@o`Cooo]Z00?o0=3ooookJ_l0Kol0
0_l0<_l2o`3@o`04oookJ_l0Kooooo]Zo`1_o`;ooo]Z0_ooB`06oookJP03ool00?oonf[ooo]Z00?o
oo]Z0_oo>P0IoookJP03oolD0?oonf[ooo]Z00_ooo]Z00?oo`80oookJ_oonfX06OoonfX00ooo3@3o
0000oookJP0XoookJP?o0000>?oonfX00ol0003ooo]ZoookJP0EoookJP003?oonfX00ol0003ooo]Z
oookJP1OoookJP05ool00?oonf[ooo]ZoookJ_oo0@009_oonfX2ool:00Cooo]Z0_oo100[oookJP03
oolX0?oonf[ooo]Z00Cooo]Z00CoobX0o`000?l0003o00003ooonfX2oom000Wooo]Z0_oo8P001_oo
nf[o03;oo`0bool0<_oooo]Zo`1_o`Coog/00ooonfX4o`0bo`03odSo0?oonf[o06oo00;o06oo0ooo
nfX01?ooV`3ooaL0oolG0?oo5`08oookJP?ooaP01_m8o`05oookJP?o0=3o0_oonfX5ool000?ooi<0
00?ooo]Zoo3o0?o`o`000ooonfX00ooo003ooo]ZoookJP03oo3o0005oookJ_l0oa?ooo]Zo`3o4ooo
nfX00_oo3P001_oonf[oB?l0odSo0?l0oa?oB?l0ofco00Gooo]Z00CobOl0oookJ_oonf[o0?n@1?oo
nfX2o`1_o`03oookJ_ooU`3ooiL000Cooo]Z00co0=3ooookJ_oonf[o06oooookJ_l0Kooooo]Zo`3@
oooo8P3ooo]Zo`1_oooonfX2oom;01[ooo]Z00?oob`0oookJ_oonfX02_oonfX2oolD01Sooo]Z00?o
o`P0oookJ_oonfX03_oonfX2ool;0003o`000?oonf[ooo]Z01_ooo]Z0_oo0@06oookJP?o00004Ooo
nfX00ooo003ooo]ZoookJP0DoookJP03ool20?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX05Ooo
nfX000_ooo]Z00?o0000oookJ_oonfX08?oonfX01?oo003ooo]ZoookJ_oo000boookJP;oo`400ooo
nfX00ooo003ooo]ZoookJP0XoookJP03ool>0?oonf[ooo]Z00?ooo]Z00?oo`X0oookJ_oonfX0=?oo
nfX3o`0000;ooa001ooonfX2oolh00Oooo]Z0_oo@009oookJP03oolR0?oonf[ooo]Z00?ooo]Z00Oo
03;oo`1_ooooN`3oog/0ool00?ooN`3o06oo00;ooo]Z0ol0<_l2ool<0003o`1_oooonf[ooo]Z00Go
oo]Z00?ooaL0ofco0?ooV`001oooV`0:oookJP?oB?l00_l0d?l5oookJPGoo`0000?ooo]ZoonC0?oo
nfX00oo`o`03oookJP?ol?l01OoonfX00ol0oa?ooo]Zo`3o4`02o`3o4`04odSo0?l0oa?oB?l0odSo
00;ooo]Z00GoK?l0oookJ_oonf[ooo]ZolWo0002oon600;ooo]Z00?o0?n@oookJ_oonfX00ooonfX2
o`3oT003o`1_ool0d?oooo]Z00;ooo]Z00Co0=3ooookJ_oonf[o06oo0_oonfX01Ol0Koooob80oolR
0?oonf[o06oo00gooo]Z0_oo4`0<oookJP;oob`05_oonfX00ooo1@3ooo]ZoookJP0>oookJP03ool8
0?oonf[ooo]Z00cooo]Z00Goo`00oookJ_oonf[ooo]Zo`00000<oookJP03ool00?oonf[ooo]Z00So
oo]Z00?oo`D0oookJ_oonfX02?oonfX3o`0000;ooo]Z00?oo`40oookJ_oonfX05OoonfX00ooo1@3o
oo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01Gooo]Z000;oookJP03o`000?oonf[ooo]Z087ooo]Z
0_oo200:oookJP03o`000?oonf[ooo]Z01oooo]Z00?oo`00oookJ_oonfX01?oonfX00ooo0P3ooo]Z
oookJP04oookJP;oo`/000Cooo]Zo`000?l0003o00000ooonfX00ooo403ooo]ZoookJP06oookJPCo
ocP01ooonfX00ooo@03ooo]ZoookJP06oookJP03oolR0?oonf[ooo]Z00?ooo]Z0_l0Kol01Ooonf[o
03;ooomk0?ooN`3o06oo00;o03;o0ol0Kol00ooonf[o06oooookJP02o`3@o`Oooo]Z00?oK?l0oook
J_oonfX01OoonfX3oonK00Kooo]Z0ol0d?l8oookJPGoo`000ooonfX00oo`o`3ooo]ZoookJP03oo3o
00Wooo]Z00So0?lCoookJ_m8o`3oB?l0o`3o4om8o`3o0?lCodSo00;ooo]Z00CoohH0ofco0?ooQP3o
bOl01_oonfX01ol0oi3ooo]ZoookJ_oonf[ooiL0o`3oT?oonfX00_oo4@001Ol0d?oo06oooookJ_oo
nf[o0=3o00;ooo]Z0ol0Kol00ooonf[oob80oolD0002oolD00kooo]Z00?ooa<0oookJ_oonfX01?oo
nfX00ooo0@3ooo]ZoookJP02oookJP03ool/0?oonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX03Ooo
nfX00ooo1@3ooa@0oookJP0<oookJP;oo`D04ooonfX00ol0003ooo]ZoookJP04oookJP03ool=0?oo
nf[ooo]Z00cooo]Z00?oo`D0oookJ_oonfX01OoonfX4o`0004;ooo]Z00?o0000oookJ_oonfX05?oo
nfX000_ooo]Z00?o0000oookJ_oonfX0M_oonfX00ooo003ooo]ZoookJP02oookJP;oo`<01?oonfX0
0ooo203ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00Wooo]Z00?ooa00oookJ_oonfX00ooonfX2
ool;00Gooo]Z0_oo0P0DoookJP?o00004ooonfX00ooo>03ooo]ZoookJP05oookJP03oom00?oonf[o
oo]Z00Gooo]Z0_ooEP03oookJP;o06oo1OoonfX00oooN`3o06ooo`1_o`04oookJPCo0=3o00?ooo]Z
oolM0?oonfX01OoonfX00om/o`3ooo]ZoookJP0:oookJP?o0=3o0_ood`05oookJP03oolM0?oonf[o
oo]Z00;ooo]Z0ooo0003oookJP03oo3o0?oo6P3ooaX000;ooaX02ooonfX01Ol0oa?oB?l0o`3o4ol0
oa?ooo]Z00;oB?l000?oohH0odSo0?ooQP000_oonfX00om/o`3obOl0oookJP02ool500Cooo]Z00Oo
0?n@oookJ_ooU`3o0?n@oookJ_l0oi3ooo]Z00;ooa4000Co0=3oo`1_ool0Kooo0=3o0_oonfX2o`1_
o`04oookJ_l0d?oo0=3oo`1_o`Wooo]Z00?oobT0oookJ_oonfX02ooonfX00ooo0@3ooo]ZoookJP0=
oookJP;oob803?oonfX2oolD02?ooo]Z00?o0000oookJ_oonfX05ooonfX3o`0003[ooo]Z00?oo`80
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0DoookJP002ooonfX00ol0003ooo]ZoookJP0foook
JP04ool00?oonf[ooo]Zool102gooo]Z00Coo`80oookJ_oonf[ooo]Z0_oo0004oookJP03ool00?oo
nf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX02?oonfX2ool@00Gooo]Z00?oo`/0oookJ_oonfX05ooo
nfX2o`0001oooo]Z0_oo>`001Ooonf[ooaL0oolG0?oo5`3ooo]Z00CooeH000?ooo]Zo`1_oooonfX0
0_oonfX3o`1_o`04oookJ_ooN`3ooo]ZoookJPCooiL000Co0=3ooookJ_oonf[o0=3o0_oo7@06oook
JP03ofco0?oonf[ooo]Z00Kooo]Z00Co0=3ooolL0?oo703ooa`01?ood`04oookJPCooad01ooonfX4
oo3o0003oookJ_o`o`3ooo]Z00?o0?n@1ooonfX2odSo00;o0?lC00?oofD0odSo0?m8o`000_ooQP00
1?m8o`3ooo]ZoookJ_m/o`07oookJP;ooiL00_l0oi001?l0d?oooo]Zo`3oT?ooD@02oookJP;o0?n@
0_oonfX01?l0d?oo06ooo`1_oooonfX2o`3@o`03oookJ_l0Kooooo]Z00Oooo]Z0_oo:@0LoookJP;o
ob80<ooonfX00ol0003ooo]ZoookJP04oookJP03ool80?oonf[ooo]Z00[ooo]Z00?oo`00oookJ_l0
00000_l0000<oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oo`80oookJ_oonfX03_oonfX00ooo003o
oo]ZoookJP0DoookJP03ool20?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX05?oonfX000_ooo]Z
00?o0000oookJ_oonfX0<ooonfX00ooo003ooo]ZoookJP0aoookJP03ool20?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX09OoonfX3o`0001?ooo]Z00?oo`/0oookJ_oonfX01OoonfX2oolD00Cooo]Z
0ooo>`000ooo5`3ooo]ZoookJP05oookJP03oomF0?oonf[o06oo00;o06oo1?oonfX01Ol0Koooog/0
oookJ_ooU`3ooo]Z00;ooiL000Gooo]Zo`1_oooonf[o0=3ooolM0002oookJP;obOl01?oonfX2ool8
00?ooo]Z0ol0d?l00ooonf[ooa`0oomZ000CoooC00?ooo]Z0_o`o`03o`3oT0[ooo]Z00SoB?l0oook
J_m8o`3ooo]ZoomU0?m8o`3ooo]Zoon600;ooo]Z00CoB?l0oookJ_o9o`3oK?l00ooonfX2ofco0005
oonG0?oonf[ooiL0oomA0?l0oi000_ooD@000ooonf[o0?n@oookJP02oookJP0:o`3@ool0oi3ooo]Z
o`1_oooonf[ooeH0o`3@ool0Kooo0=3oo`1_o`Wooo]Z0_oo:@03oookJP03oolA0?oonf[ooo]Z00co
oo]Z00?ooa80oookJ_oonfX04_oonfX00ooo003ooo]ZoookJP0<oookJP03ool10?oonf[ooo]Z00_o
oo]Z00?oo`L0oookJ_oo1@002_oonfX01?l0003ooo]ZoookJ_oo0@0?oookJP?o00001ooonfX00ooo
1P3ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z01Cooo]Z000;oookJP03o`000?oonf[ooo]Z097o
oo]Z00Co0000oookJ_oo203oo`P01OoonfX2ool>00_ooo]Z0_oo5`05oookJP;ooa@01OoonfX3o`00
00Kooo]Z00?oo`00oookJ_oonfX01OoonfX00ooo003ooo]ZoookJP04oookJP;oo`/01_oonfX2oolD
00Wooo]Z00?ooc/0oookJ_oonfX00ooonfX2o`1_o`03oomF0?oonf[ooo]Z00Kooo]Z00?o06oooook
J_l0d?l00_ooU`001Ooonf[ooiL0oonG0?ooU`3o0=3o00KobOl01?oonfX01?m/o`3o0=3oo`3@ool0
d?l7oookJP04oomZ0?ood`3oom<0oooC013ooo]Z0ol0oi000oo`o`3ooo]ZoookJP0:oookJP03oolN
0?m8o`3ooo]Z00;oB?l000?oofD0oookJ_oonfX00_oonfX01Om8o`3obOl0oookJ_oonf[oK?l000;o
oo]Z00?oK?l0oookJ_m/o`000_m/o`000ol0oi3ooo]Zo`3oT002oookJP03o`3oT?oonf[ooo]Z00;o
oo]Z00?o0=3oo`3oT?l0Kol00_l0d?l2o`1_o`03o`3@ool0Koooo`T000cooo]Z0ooo4@0>oookJP03
oolB0?oonf[ooo]Z00;ooo]Z00?oo`H0oookJ_oonfX06_oonfX2oolB00gooo]Z00?oo`L0oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0;oookJPCo0000CooonfX00ol0003ooo]ZoookJP0DoookJP00
2_oonfX00ol0003ooo]ZoookJP1moookJP03ool20?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX0
0ooonfX00ooo003ooo]ZoookJP03oookJP03ool30?oonf[ooo]Z00;ooo]Z00?o0000ool80?oonfX0
4_oonfX3oolG00Gooo]Z00?ooa@0oookJ_oonfX00ol000000ooonf[oo`/0oookJP0]oookJP_o06oo
00Kooe80o`1_ool0d?oooo]Zo`3@ooooU`02oookJP03o`1_oooonf[obOl000?obOl000?ooo]ZolWo
0?o9o`000_oonfX3o`3@o`03ofco0?oonf[ooo]Z00Wooo]Z0_ood`07oookJP03oolR0?oonf[ooo]Z
00?ooo]Z0ol0oi02oookJPCoob@02OoonfX4oolN0003oookJ_m8o`3ooo]Z00;oofD01?o9o`03oook
JP;oK?l000Sooo]Zofco0?ooU`3ooiL0o`3oT?m/o`3o0=3oo`3oT0?ooo]Z00?oo`00oookJ_oonfX0
0_oonfX00ol0oi3ooeH0o`3@o`02oookJP05o`3@oooonf[ooo]ZoookJ_oo2@001_oonfX2oolh00_o
oo]Z00?oob@0oookJ_oonfX0:?oonfX00ooo4P3ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Oo
oo]Z0ol0000PoookJP03ool00?oonf[ooo]Z00Cooo]Z00?oo`<0oookJ_oonfX03_oonfX2ool001Wo
oo]Z00?o0000oookJ_oonfX05?oonfX000[ooo]Z00?o0000oookJ_oonfX0A_oonfX01?oo003ooo]Z
oookJ_oo0003oookJP05ool10?oonf[ooo]ZoookJ_oo0`009OoonfX00ooo1@3ooo]ZoookJP02oook
JP03ool20?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX06OoonfX3o`0003Gooo]Z0ol0Kol5oook
JP?ooad000?o06ooo`3@ool0d?l01Ol0Kol01?oonf[o0=3oolWo0?ooU`05olWo00Cooo]Z00?oK?l0
oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP04oookJPCoob800ol0oi03oookJP;oogD000?oob@0
oookJ_ooM@001OooM@08oookJPCoB?l00oooI@03olWo00?ooo]Z0_m/o`001_oonf[oK?l0oookJ_l0
oi3ooo]Zofco00;o0=3o00Co0?n@o`3@ool0d?oo0?n@0ooonfX2o`3oT0;o0=3o0_oonfX00ol0d?oo
oo]ZoookJP05oookJP?oocP03?oonfX00ooo903ooo]ZoookJP15oookJP04ool20?oonf[ooo]Zo`00
00Gooo]Z0ol00002ool200Cooo]Z00?oo`D0oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP05oook
JP;oo`L03ooonfX00ooo0`3ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Cooo]Z000:oookJP03
o`000?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX0Q_oonfX00ol0003ooo]ZoookJP0EoookJP?o
00003OoonfX00ooo7@3ooo]ZoookJP04oookJP;ooaT01ooonfX00ooo2@3ooo]ZoookJP06oookJP03
ool00?oonf[ooo]Z00Gooo]Z00?oo`T0oookJ_oonfX01OoonfX3oolI00;ooo]Z0ol0Kol02ooonf[o
oad0oolM0?oonf[o0=3oo`1_oooonf[o0=3ooomB0?oonf[o06oo00?ooo]Z00?o0=3ooookJ_o9o`00
0_o9o`02oookJP03oomd0?o9o`3obOl000?obOl000?oK?l0oookJ_oonfX04?oonfX3o`3oT0Gooo]Z
1OooM@0;oookJP?oolT000Gooo]ZodSo0?m8o`3obOl0odSo0002oomU000<oookJ_o9o`3ooo]ZolWo
0?oonf[oK?l0oonK0?oonf[oK?l0oookJ_m/o`3o0?n@0_m/o`02oookJP04o`3@ool0oi3ooo]Zo`3o
T0;o0=3o0_l0oi001_oonf[o0=3oo`3@ool0d?oooo]Zo`3@o`Oooo]Z0_oo>00CoookJP;oo`/03Ooo
nfX2ool?00oooo]Z0_oo40000ooo003ooo]ZoookJP0:oookJP;ooa0000?ooo]Zool00?oonfX02ooo
nfX01?oo203ooo]ZoookJ_oo0P02oookJP03o`000?oonf[ooo]Z00?o0000F_oonfX00ol0003ooo]Z
oookJP0CoookJP002_oonfX00ol0003ooo]ZoookJP2FoookJP03o`000?oonf[oo`0000Kooo]Z00?o
o`40oookJ_oonfX00ooonfX2ool800?ooo]Z0ol00002ool@00kooo]Z0_oo7@07oookJP03oolI0?oo
nf[ooo]Z00Cooo]Z00?oo`T0oookJ_oonfX03_oonfX00ooo2@3ooo]ZoookJP05oookJP03oolI0?oo
nf[ooo]Z00Gooo]Z0ol0Kol2o`3@o`05o`1_oooonf[ooo]Zo`3@ool0Kol00ooonfX3o`3@o`04oook
J_o9o`3obOl0oookJPCoog@01?oonfX5olWo00[ooo]Z0ol0oi03oookJP?oo`001?oonfX2oome00?o
oo]Z0_oob@04oookJP?oolT00ooo:@03oookJP;obOl000?ooo]ZolWo0?o9o`000_oonfX01?o9o`3o
ob<0oolS0?oo8`02oookJP?oK?l000?ooo]Zofco0?oonfX00ooonfX3oolM0003o`3oT?oonf[o0?n@
00Go0=3o0_oonfX00ooo1@3ooo]ZoookJP0;oookJP03ool10?oonf[ooo]Z00;ooo]Z0_oo:006oook
JP;oo`/00ooonfX2oolM00[ooo]Z00?oo`l0oookJ_oo2@006ooonfX2ool@01?ooo]Z1?l0001:oook
JP03ool10?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX04ooonfX000[ooo]Z00?o0000oookJ_oo
nfX0GooonfX00ooo003ooo]ZoookJP02oookJP03ool30?oonf[ooo]Z00;ooo]Z00?oo`L0oookJ_oo
nfX06_oonfX00ooo2@3ooo]ZoookJP03oookJP03ool50?oonf[ooo]Z00?ooo]Z00?oo`40oookJ_oo
nfX00_oonfX00ol0003ooo]ZoookJP0=oookJP?o0000<?oonfX00ooo8P3ooo]ZoookJP0CoookJP;o
0=3o0_l0Kol01?oonf[o06ooo`3@oooonfX3o`3@o`;ooo]Z00Go0=3ooom50?ooA@3obOl0oookJP02
o`3oT0Ooog@01?oonfX5olWo00;ooo]Z0ol0oi05oookJPGoo`001_oonfX4oolM0004oookJ_oob@3o
olT0ooo900Cooo]Z00CoobT0oookJ_oo:@3oobT00_ooB`03olWo000:oookJ_o9o`3obOl0oookJ_oo
8`3ooi/0ofco0?oo8`3oK?l0o`3oT0?oK?l01OoonfX01oooF03ooad0o`3oT?oo7@3ooo]Zo`3oT?oo
nfX01?l0d?l2oookJP03ool50?oonf[ooo]Z00kooo]Z0_oo:00<oookJP;ooad0>ooonfX3o`0000?o
oo]Z00?o0000oookJ_oonfX07_oonfX00ooo003ooo]ZoookJP0?oookJP03ool00?oonf[ooo]Z00?o
oo]Z00?oo`<0oookJ_oonfX03_oonfX2ool101;ooo]Z00?o0000oookJ_oonfX04ooonfX000[ooo]Z
00?o0000oookJ_oonfX08_oonfX00ooo0@3ooo]ZoookJP0boookJP05ool00?oonf[ooo]ZoookJ_oo
00002?oonfX00ooo0`3ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z00Wooo]Z0ol0000RoookJP?o
ob801OoonfX2oolV00Oooo]Z0_oo8P08oookJP03ool50?oonf[ooo]Z00Sooo]Z0_l0d?l3oookJP04
o`1_ool0d?ooob80oolR00Gooo]Z00?o0=3ooolV0?oo9P000ooo9P000ol0oi3oog@0oookJP03oook
JPGoob801OoonfX01?l0oi3obOl0olWo0?o9o`07oookJPGoo`001ooonfX4ooo900Kooo]Z0oooB`04
oookJPGobOl000?oof<0oonK0?ooV`000_oonfX00om/o`3ooo]Zofco0003ofco00Co0?n@00?ooeP0
oookJ_oonfX00_l0oi000ol0d?oo0?n@o`3@o`0HoookJP03oolX0?oonf[ooo]Z03;ooo]Z00?oo`h0
ool10?oonfX03OoonfX00ooo003ooo]Zo`000002o`0000Oooo]Z00?o0000oookJ_oonfX00_oonfX0
0ooo003ooo]ZoookJP07oookJP;oo`<01OoonfX2ool304Gooo]Z00?o0000oookJ_oonfX04ooonfX0
00Wooo]Z00?o0000oookJ_oonfX08OoonfX00ooo003ooo]Zool1001foookJP03o`000?oonf[ooo]Z
00Gooo]Z0ol0000RoookJP;ooaP00_oonfX00ooo8P3ooo]ZoolR0006oookJP03oolV0?oonf[ooo]Z
00Gooo]Z00?oob80oookJ_oonfX01_oonfX00ooo1@3ooo]ZoookJP06oookJP03ool50?oonf[o0=3o
00;ooo]Z0_l0d?l2oolR0003oookJ_l0d?oooo]Z00Gooo]Z0_oo9P001Ooonf[o0?n@oookJ_oonf[o
0?n@00Gooo]Z00?oob80oookJ_oonfX00ooonfX3o`3oT0_ooo]Z1Ooo0006oookJPKoolT01_oonfX0
0oooB`3ooo]ZoookJP04oookJP?obOl000Goof<0oonK0?ooV`3ooi/0oolR0002oookJPGoK?l00_l0
oi02oomH0003o`3oT?oo903o0?n@00?o0?n@2OoonfX00ooo7P3ooo]ZoookJP0EoookJP03ool00?oo
nf[ooo]Z00cooo]Z00Coo`@0oookJ_oo603ooaP02ooonfX3ool;00gooo]Z0_oo3P0=oookJP?o0000
2_oonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z01?ooo]Z0009oookJP03o`000?oo
nf[ooo]Z09Gooo]Z0_oo3P04oookJP;oo`X00_oonfX3o`000003ool50?oonf[ooo]Z00Cooo]Z00?o
o`00oookJ_oonfX01?oonfX00ooo003ooo]ZoookJP04oookJP03ool80?oonf[ooo]Z00Cooo]Z0_oo
4`06oookJP;ooaP07_oonfX2oolg00Oooo]Z00Co0=3ooolb0?oo<P3ooc800ooonfX00ooo8P3ooo]Z
o`3@o`06oookJP03o`3@ool0oi3o0?n@00?ooo]Z0_ooI@07oookJP?o0?n@0_oonfX2oomB00?ooo]Z
0_ooU`06oookJP?oo`002_oonfX00ooob@3ooo]ZoookJP0@oookJP03oonK0?oonf[ooi/000?oob80
1ooonfX00oooF03o0?n@o`3oT003oolT00?o0?n@1_oonfX2oolg0004oookJ_oo7P3ooah0oolN00Oo
oo]Z0_oo3P0MoookJP03oolH0?oonf[ooo]Z02Gooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z02Go
oo]Z00?oo`40oookJ_oonfX03ooonfX00ooo003ooo]ZoookJP0CoookJP03ool10?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX04ooonfX000Wooo]Z00?o0000oookJ_oonfX0J?oonfX01?oo0@3ooo]Z
oookJ_oonfX2ool000Cooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo0P3ooo]ZoookJP02oookJP03
ool70?oonf[ooo]Z00?ooo]Z0_oo300HoookJP?o0000?ooonfX3ool/00Kooo]Z0ooo=`04oookJP?o
0=3o0_oo<P06o`3@o`Kooo]Z0ol0oi03oookJP?oofD00ooonfX3o`3oT0Cooo]Z1?ooDP03oonG0003
ool/0?ooU`3ooiL000So0?n@2?oonfX3ofco00_ooo]Z00?oo`00oookJ_oonfX00ooonfX4oonK00;o
oo]Z00?oob80oookJ_oonfX01?oonfX2oomH0005oolm0?l0oi3o0?n@o`3oT?oo90001_oonfX2oolg
00gooo]Z00?oo`h0oookJ_oonfX0@OoonfX3o`0001?ooo]Z00?o0000oookJ_oonfX00ooonfX2ool8
00Gooo]Z00?oo`00oookJ_oonfX01_oonfX00ooo103ooo]ZoookJP06oookJP03ool10?oonf[ooo]Z
00Gooo]Z00?oo`40oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0CoookJP002OoonfX00ol0003o
oo]ZoookJP0coookJP03ool00?oonf[ooo]Z00;oo`000_oonfX00ooo0P3ooo]ZoookJP1LoookJP?o
00000_oonfX00ol0003ooo]ZoookJP0noookJP04ool/0?oonf[oob`0ool/00Oooo]Z00?oocL0oook
J_oonfX01?oonfX2o`3@o`03oolb0?oonf[ooo]Z00;ooo]Z0ol0d?l00oooF03o0=3oool00002o`3o
T004o`3@ool0oi3ooo]ZoookJP?ooc8000GoofD0o`3oT?l0oi3o0?n@oookJP06oolg00;ooo]Z00Co
oe80oookJ_oonf[ooo]Z1_oo;003o`3oT004oookJ_l0oi3ooo]Zo`3oT0Cooo]Z0om/o`0EoookJP;o
oi/02OoonfX3oolm00_ooo]Z0_oo=`0foookJP;ooa@03?oonfX2ool<00Sooo]Z0ol00002oookJP03
ool30?oonf[oo`X000gooo]Z00Koo`00oookJ_oonf[ooo]Zool<0?l0000LoookJP03ool10?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX04ooonfX000Wooo]Z00?o0000oookJ_oonfX0U_oonfX3o`00
00Kooo]Z00?o0000oookJ_oonfX01ooonfX2ool@00Gooo]Z0_oo2`05oookJP;oo`<01_oonfX00ooo
003ooo]ZoookJP05oookJP03ool60?oonf[ooo]Z00Gooo]Z0_oo5`06oookJP?ooah06OoonfX01?oo
>P3o0=3oo`3@ool0d?l2oookJP04o`3@ooooF03ooeP0oomH00;o0?n@0_oonfX01?l0oi3ooc80oolb
0?oonfX3o`3oT003oomU0?oonf[ooo]Z00;ooo]Z00?oocL0oookJ_oonfX02OoonfX00oooU`3ooo]Z
oookJP02o`3oT0?ooo]Z0ol0oi000ooonf[o0?n@o`3oT006ofco02cooo]Z00Goob/0oookJ_oo:`3o
ob/0oookJP02oolL00Oooo]Z0_oo9P03oookJP;ooad01_oonfX2oolA00Gooo]Z0ooo6P05oookJP03
ool00?oonf[ooo]Z00_ooo]Z00?oo`00oolD0?oonfX03?oonfX2ool500Gooo]Z0ol00007oookJP03
ool:0?oonf[ooo]Z00oooo]Z00?oo``0o`000?oonfX0FOoonfX00ol0003ooo]ZoookJP0BoookJP00
2OoonfX00ol0003ooo]ZoookJP1goookJP;oo`<01?oonfX00ooo003ooo]ZoookJP02oookJP03ool0
0?oonf[ooo]Z00?ooo]Z00?oo`40oookJ_oonfX00ooonfX00ooo1P3ooo]ZoookJP02oookJP?o0000
2_oonfX00ol0003ooo]ZoookJP0[oookJP;ooaL01_oonfX2oolN01?ooo]Z0ooo:`04oookJPCoocX0
00Cooo]Zo`3@ool0d?oo0=3o0_ooF0001?l0d?oooeP0oomH0?ooF002oookJP05o`3oT?oo<P3o0?n@
oookJ_l0oi000_oonfX00oooI@3ooo]ZoookJP0<oookJPKo0=3o00?o0?n@oookJ_l0oi000_oo>`00
0om/o`3o0?n@o`3oT002oolj0003o`3oT?ooEP3ooo]Z00GoK?l02OoonfX2oomk00_ooo]Z00?ooad0
oookJ_oonfX02OoonfX2ool800Gooo]Z0_oo:`03oookJP03oolL0?oonf[ooa`000Cooo]Z0_oo9P05
oookJP03oolM0?oonf[ooad000Gooo]Z00?ooa40oookJ_oonfX01OoonfX00ooo6P3ooo]ZoolJ000T
oookJPCo00007_oonfX00ol0003ooo]ZoookJP0JoookJP03ool40?oonf[ooo]Z00gooo]Z00?oo`40
oookJ_oonfX03ooonfX00ooo003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z01;ooo]Z0008oook
JP03o`000?oonf[ooo]Z04Kooo]Z00Goo`00oookJ_oonf[ooo]Zool00014oookJP03ool60?oonf[o
000000;o000000?ooo]Zool>0?oonfX02ooonfX00ol0003ooo]ZoookJP0CoookJP03oolD0?oonf[o
oo]Z03;ooo]Z00?oob/0oookJ_oo:`001?oonfX00ooo>P3ooo]ZoookJP02oolj00;ooo]Z00?o0=3o
oookJ_l0oi000_oonfX01?l0oi3ooeP0o`3oT?l0oi04oookJP04o`3oT?oonf[ooo]ZoomU00?ooi/0
1OoonfX00oooI@3o0=3oo`3@o`02o`3@o`06oomH0?oonf[ooo]ZoomH0?l0d?oo0?n@0_l0d?l3oonK
00;ooo]Z1ooo>P03oookJP;oK?l00_oonfX00oooN`3oob/0ool[0003ool[00cooo]Z0_oo7@1Ioook
JP?o00001_oonfX2ool;00kooo]Z00?oo`@0oookJ_oonfX02_oonfX01?l0003ooo]Zool00?oo000?
oookJP03ool00?oonf[ooo]Z00oooo]Z00?oo`00oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0B
oookJP002?oonfX00ol0003ooo]ZoookJP1>oookJP05ool20?oonf[ooo]ZoookJ_oo1@00>ooonfX3
o`0001;ooo]Z00?o0000oookJ_oonfX04_oonfX2oolD00Gooo]Z0_oo4`05oookJP;oo``01ooonfX0
0ooo0@3ooo]ZoookJP05oookJP03ool20?oonf[ooo]Z02;ooo]Z1?l0oi03oookJP03o`3oT?oonf[o
oo]Z00;ooo]Z00?o0?n@oookJ_ooV`000oooV`000oooI@3ooo]ZoookJP03oomU0004ofco0?l0d?oo
oo]ZoookJP?o0=3o00OooeP0o`3@oom/o`3oK?l0o`3oT?ooV`3o0=3o00;ooi/01?oonfX01?oo>P3o
oo]Zofco0?l0oi05oookJP03ofco0?oonf[oog/000;oog/000?oob/0oookJ_oonfX03OoonfX00ooo
7@3ooo]ZoookJP0YoookJP;ooad03?oonfX00ooo4@3ooo]ZoookJP0;oookJP03ool30?oonf[ooo]Z
00cooo]Z00Coo`00o`000?l0003o00002ooonfX2ool100oooo]Z00?oo`D0oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP04oookJP03ool90?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX04_oonfX0
00Sooo]Z00?o0000oookJ_oonfX03?oonfX2ool007Wooo]Z0_oo1P02oookJP?o00001OoonfX00ooo
003ooo]ZoookJP03oookJP03ool00?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0<?oonfX00ooo
0P3ooo]ZoookJP04oookJP?ooa`01OoonfX5oolZ00Gooo]Z1Ooo:006oookJPSo0?n@00Kooc<0o`3o
T?oonf[ooo]Zoom=0?l0oi02oom=00?ooi/00oooI@02oonK0004ofco0?ooV`3o0=3oo`3@o`;ooo]Z
00?ooeP0ofco0?l0d?l00ol0d?l00ol0oi3ooo]ZoonK0002o`3@o`Cooi/00om/o`000ol0oi3oK?l0
oookJP02oookJP06ofco0?oonf[oog/0oomk0?ooC@3ooo]Z0oooI@001?oonf[oocP0oolh0?oo>009
oookJP;ood002ooonfX00ooo8P3ooo]ZoookJP0:oookJP03ool00?oonf[ooo]Z00[ooo]Z00Coo``0
oookJ_oonf[ooo]Z0_oo7@07oookJP;ooaL00ooonfX2oolA00Sooo]Z0_oo600@oookJP?o0000:_oo
nfX00ol0003ooo]ZoookJP0`oookJP;oo`804?oonfX00ooo003ooo]ZoookJP0@oookJP03o`000?oo
nf[ooo]Z01;ooo]Z0008oookJP03o`000?oonf[ooo]Z08Sooo]Z0ol00002oookJP03ool20?oonf[o
oo]Z00Wooo]Z00?oo`00oookJ_oonfX01?oonfX00ooo1@3ooo]ZoookJP02oookJP03o`000?oo3`3o
o`l000Kooo]Z0_oo5`0LoookJP03oolH0?oonf[ooo]Z00Gooo]Z00?ooaL0oookJ_oonfX01ooonfX2
oolL00Kooo]Z0_oo:P08oookJP;oobP02ooonfX3o`3oT003oookJ_oo<`3ooo]Z00Oo0?n@0_oonfX0
1?ooV`3oofD0oomU0?ooI@02oookJP;oK?l000_ooo]Zo`3@ool0d?oo0=3ooonK0?m/o`3o0=3ooook
J_l0oi3ooo]Zo`3oT004o`3@o`05o`3oT?l0d?oo0=3ooookJ_m/o`000_ooV`001_l0oi3oK?l0oonK
0?m/o`3ooo]Zofco00?ooo]Z1OooC@000oooI@3oocP0oookJP07oookJPCooc<02ooonfX2oolR02Wo
oo]Z00?ooaL0oookJ_oonfX03?oonfX00ooo603ooo]ZoookJP09oookJPCo00006OoonfX00ooo2`3o
oo]ZoookJP0<oookJP03ool50?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01_oonfX2ool100oo
oo]Z00?oo`00oookJ_oonfX03ooonfX00ooo003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z01;o
oo]Z0008oookJP03o`000?oonf[ooo]Z05Oooo]Z00Coo`00oookJ_oonf[ooo]Z0_oo0003oookJP03
ool10?oonf[ooo]Z00;ooo]Z00?oo`D0oookJ_oonfX00_oonfX00ooo2`3ooo]ZoookJP0HoookJP?o
00007_oonfX2ool?00Gooo]Z0_oo5`0MoookJP;ooaP01OoonfX3oolG00Kooo]Z0_oo3008oookJP03
ool00?oonf[ooo]Z01Oooo]Z0_l0oi02oookJP04o`3oT?oonf[ooo]Zo`3oT0Kooo]Z00CoofD0oook
J_oonf[oK?l00_oonfX00ol0d?ooK?l0ofco0002o`3@o`05oookJ_l0d?oo0?n@oookJ_l0oi000_oo
nfX00ol0oi3oo`00ool00004o`3@o`;oK?l000Ko0?n@oookJ_m/o`3ooo]ZoonK0?m/o`05oookJP04
oom=0?oonf[ooo]ZoomU00?oodd01OoonfX3oomH0003oolc0?oonf[ooo]Z00;ooc<02OoonfX2oolR
02Wooo]Z0ooo5`0;oookJP;oo`l02?oonfX3o`000003oookJ_oo1@3ooo]Z00gooo]Z00?oo`00oook
J_oonfX03OoonfX00ooo003ooo]ZoookJP0>oookJP03ool20?oonf[o000005Gooo]Z00?o0000oook
J_oonfX04_oonfX000Sooo]Z00?o0000oookJ_oonfX08?oonfX01?oo003ooo]ZoookJ_oo0P10oook
JP;oo`D00ooonfX2ool;01Oooo]Z0ol0000AoookJP03ool90?oonf[ooo]Z00?ooo]Z00?oo`D0oook
J_oonfX00ooonfX00ooo0@3ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03?ooo]Z00?oo``0oook
J_oonfX03ooonfX00ooo8P3ooo]ZoookJP06oookJP;ood001OoonfX00ooo>03ooo]Zoolh0002oolh
00?o0?n@1ooonfX00ooo:`3ooo]Zofco0003ofco0004o`3@ool0Kooo06ooo`3@o`?o06oo0_l0oi03
oookJP03o`3oT?oo003oo`0000;oo`0000Co0?n@o`3@ool0d?oo0?n@0om/o`02oookJP;oK?l02Ooo
nfX00oooI@3ooo]ZoookJP05oookJPCooeP000?ooo]ZoolX0?oo:0002?oonfX00ooo>P3oobX0oolZ
000;oookJP03oolL0?oonf[ooo]Z00[ooo]Z00?oo`80oookJ_oonfX02ooonfX01?oo0@3ooo]Zoook
J_oo5`0:oookJP04ool<0?oonf[ooo]Zool?00Kooo]Z0ol00002oookJP03oolC0?oonf[ooo]Z02oo
oo]Z00Coo`80oookJ_oonf[o00003OoonfX2ool603[ooo]Z00?oo`00oookJ_oonfX02OoonfX00ol0
003ooo]ZoookJP0AoookJP002?oonfX00ol0003ooo]ZoookJP0RoookJP03ool20?oonf[ooo]Z05[o
oo]Z0ol0000PoookJP03ool10?oonf[ooo]Z00?ooo]Z00?o0000ool00?oonfX01OoonfX00ooo0`3o
oo]ZoookJP05oookJP03oolA0?oonf[ooo]Z01gooo]Z0_oo6P06oookJP;ooad01ooonfX01?oo703o
oo]ZoookJ_oonfX2oolR00Gooo]Z1?oo@006oookJP?oocP01?oonfX00ol0oi3ooo]ZoookJP05oook
JP;oob/000?oK?l0o`1_ool0Kol00ol0Kol2oolj00;o0=3o00Ko06ooo`3@ool0Kooo06oooookJ_oo
F002oookJP07o`3oT?oo003oo`00oomH0?l0oi3ooo]Zo`3@o`03oookJP?oK?l00_oonfX00om/o`3o
oo]ZoookJP07oookJP03oomU0?oonf[ooo]Z00Gooo]Z00?ooeP0oookJ_oo:0000_ooF008oookJPCo
ocX02_oonfX01?oo703ooo]ZoookJ_oo:`0:oookJP03ool20?oonf[ooo]Z00_ooo]Z00?oo`40oook
J_oonfX02ooonfX00ooo303ooo]ZoookJP04oookJP?o00001OoonfX2oolC00kooo]Z0ooo500Roook
JP03o`000?oo1@3ooo]Z00gooo]Z0_oo0P0?oookJP03ool00?oonf[ooo]Z00oooo]Z00?oo`00oook
J_oonfX08?oonfX00ol0003ooo]ZoookJP0AoookJP001ooonfX00ol0003ooo]ZoookJP1YoookJP03
ool00?oonf[ooo]Z00;ooo]Z00Coo`00oookJ_oonf[ooo]Z0_oo0009oookJP?o0000:_oonfX00ol0
003ooo]ZoookJP0;oookJP03oolA0?oonf[ooo]Z00Cooo]Z0ooo7@0HoookJP;ooaX01OoonfX3oolM
00Kooo]Z0_oo7002oookJP03oolR0?oonf[ooo]Z00?ooo]Z0ooo@009oookJP03oolh0?oonf[ooo]Z
00kooo]Z00?o06oooookJ_m/o`000ol0Kol00om/o`3o0=3oo`3@o`02oookJP03o`3@oooonf[o06oo
00?ooeP000?o0?n@oookJ_oonfX00_oonfX00ol0d?oo0?n@oookJP03oookJP06ofco0?ooI@3oofD0
oomU0?oonf[oK?l02OoonfX00oooI@3ooo]ZoookJP09oookJP03oomH0?oonf[ooo]Z00Kooo]Z00?o
ocX0oookJ_oonfX00ooo>P09oookJP?oob/0:?oonfX4o`0000Kooo]Z00?oo`h0oookJ_oonfX02ooo
nfX00ooo1P3ooo]ZoookJP0<oookJP03ool10?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z017ooo]Z0007oookJP03o`000?oonf[o
oo]Z03Cooo]Z00?oo`00oookJ_oonfX0@?oonfX2ool40005oookJ_l0003o0000o`000?oo2`009_oo
nfX2ool<00Gooo]Z00?oo`X0oookJ_oonfX01?oonfX00ooo1@3ooo]ZoookJP0:oookJP03oolM0?oo
nf[ooo]Z02[ooo]Z00?ooa`0oookJ_oonfX01OoonfX2ool800Sooo]Z00?ooad0oookJ_oonfX01_oo
nfX2oomk00?ooo]Z00?ooeH0oookJ_oonfX00_oonfX2o`1_o`;ooo]Z00?o0=3oofco0?l0Kol00ol0
Kol2oookJP04o`3@oooonf[o06ooo`1_o`;ooo]Z00Co0?n@oookJ_oonf[o0=3o0_l0oi05oomU00Go
oo]Z00?oK?l0oookJ_oonfX07OoonfX2oolb00Oooo]Z0ooo7P001?oo=`3ooo]ZoookJ_oonfX2ool[
00Gooo]Z00?ooaL0oookJ_oonfX06ooonfX3o`0004?ooo]Z00?o0000oookJ_oonfX00_oonfX00ooo
003ooo]ZoookJP0?oookJP03ool30?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX04OoonfX000Oo
oo]Z00?o0000oookJ_oonfX0=ooonfX01?oo0@3ooo]ZoookJ_oo100loookJP?o00000ooonfX00ooo
2`3ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00?ooo]Z00?oo`D0oookJ_oonfX01?oonfX00ooo
003ooo]ZoookJP04oookJP;oo`00;?oonfX2oolN00Oooo]Z00?oob@0oookJ_oonfX00ooonfX2oolM
00Gooo]Z0oooN`05oookJP03oomF0?oonf[ooo]Z00GooeH000GobOl0o`3@ooo9o`3o06ooolWo0007
oolk000;oookJ_l0Kooo06ooo`3oT?oo;03o0=3oo`3oT?oo;03oofD0o`3oT?ooI@000ooonfX4oolg
0003oookJ_m/o`3ooo]Z01gooo]Z0ooo<P07oookJP;ooah00ooo=`08oookJP03oolG0?oonf[ooo]Z
00;ooo]Z00?oob`0oookJ_oonfX01_oonfX00ooo1P3ooo]ZoookJP0;oookJP03ool00?l0003o0000
00cooo]Z00?oo`<0oookJ_oonfX03?oonfX00ooo2`3ooo]ZoookJP0=oookJP;ooa006_oonfX00ol0
003ooo]ZoookJP0CoookJP03ool20?oonf[ooo]Z00gooo]Z0_oo000@oookJP03ool00?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX04OoonfX000Oooo]Z00?o0000oookJ_oonfX0>_oonfX00ooo103o
oo]ZoookJP0goookJP?o000000?ooo]Zool10?oonfX01?oonfX00ooo003ooo]ZoookJP02oookJP03
ool00?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX06?oonfX00ooo4@3ooo]ZoookJP05oookJP;o
obH01ooonfX2ool[01?ooo]Z00?ooah0oookJ_oo7P001OoonfX4oolT00?ooo]Z00Gooad0oookJ_oo
N`3oog/0oolR0002oomk00Oooo]Z1?ooEP003?oonf[o06oooookJ_o9o`3o06ooo`3@ooo9o`3o0=3o
o`1_oooonf[obOl0oolk00?ooo]Z1?l0Kol01?oonf[o06ooool/0?l0d?l4oookJP03o`3oT?oonf[o
oo]Z00;oocL01OoonfX00om/o`3ooo]ZoookJP02oookJP03oolb0?oonf[ooc8000;ooc802ooonfX0
0ooo003ooo]ZoookJP09oookJP03oolb0?oonf[ooo]Z00Oooo]Z0ooo=`0;oookJP?oob`04_oonfX3
o`0001Wooo]Z0_oo3003oookJP03ool;0?oonf[ooo]Z00Kooo]Z0_oo1`06oookJP03ool@0?oonf[o
oo]Z00Cooo]Z0_oo0P0?oookJP04ool00?oonf[ooo]Zo`0005;ooo]Z00?o0000oookJ_oonfX04Ooo
nfX000Oooo]Z00?o0000oookJ_oonfX0A_oonfX00ooo003ooo]ZoookJP0XoookJP?o00003ooonfX0
0ooo003ooo]ZoookJP03oookJP03ool30?oonf[ooo]Z00?ooo]Z00?oo``0oookJ_oonfX07?oonfX0
0ol0003ooo]ZoookJP07oookJP;oo`h01_oonfX00ooo2`3ooo]ZoookJP05oookJP03oolA0?oonf[o
oo]Z00?ooo]Z0_oo9P07oookJP;oob/09_oonfX3oomk0003oolR0?oonf[ooo]Z00Oooo]Z00GooeH0
oookJ_oonf[ooo]Zo`1_o`02oookJP04o`1_ool0d?oooiL0o`1_o`CobOl000?o0=3ooookJ_oonfX0
0_oonfX00ol0d?oooo]Zo`1_o`03o`1_o`;ooe800ooonfX00ol0oi3ooo]ZoookJP07oookJP03ofco
0?oonf[ooo]Z00?ooc809ooonfX00ooo=`3ooo]ZoookJP02oookJP?ooaP01?oonfX01?oo;03ooo]Z
ool/0?oo;002oookJP;ooa<02?oonfX4o`000003ool80?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oo
nfX02OoonfX00ooo003ooo]ZoookJP0?oookJP03ool10?oonf[ooo]Z037ooo]Z00?o0000oookJ_oo
nfX04OoonfX000Oooo]Z00?o0000oookJ_oonfX0BOoonfX2ool102?ooo]Z0ol0000GoookJP03ool3
0?oonf[ooo]Z00Cooo]Z00?oo``0oookJ_oonfX00ooonfX2oolD01Sooo]Z00?o0000oookJ_oonfX0
3_oonfX00ooo2`3ooo]ZoookJP04oookJP;oo`@01OoonfX2oolV0003ool00?oonf[ooo]Z00?ooo]Z
0ooo:`0QoookJP?ooad000?ooo]Zoomk0?ooN`000_ooN`000ooonf[oob<0oookJP0;oookJP06o`1_
oooonf[ooiL0o`1_ool0d?oo06oo1OooU`000ol0d?oooiL0oonG0004oonG0003oookJ_l0d?oooo]Z
00Gooe800_oonfX01?l0oi3ooo]ZoookJ_oonfX4oolR00;ooo]Z00CoK?l0oookJ_oonf[ooo]Z1?oo
9P0_oookJP;oob801OoonfX00ooo4`3ooo]ZoookJP04oookJP?o00000ooonfX2ool800gooo]Z00?o
o`00oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP0<oookJP03ool50?oonf[ooo]Z023ooo]Z00?o
0000oookJ_oonfX06_oonfX00ooo0@3ooo]ZoookJP0=oookJP03ool10?oonf[ooo]Z00kooo]Z00?o
o`00oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0AoookJP001_oonfX00ol0003ooo]ZoookJP1>
oookJP04ool40?oonf[ooo]ZoookJP;oo`P06?oonfX3o`0001[ooo]Z00?oo`<0oookJ_oonfX00_oo
nfX00ooo003ooo]ZoookJP03oookJP03ool00?oo503ooa@001[ooo]Z00?o0000oookJ_oonfX04ooo
nfX00ooo403ooo]ZoookJP0>oookJP;oo`h01ooonfX2oolg01Wooo]Z00?ooad0oookJ_oo7@000_oo
nfX00oooN`3ooo]ZoookJP03oolS00Gooo]Z0ooo:@02oookJP06o`1_oom/o`3oK?l0ofco0?l0Kooo
oiL00_l0d?l01Oo9o`3ooo]ZoookJ_oonf[o0=3o00Gooo]Z00Co0=3oolWo0?o9o`3obOl00_ooDP02
oookJPCooe800ooonfX3oomd00?ooo]Z00?oK?l0oookJ_oonfX00_oo9P02oookJP;ooiL01_oonfX3
oolR00_ooo]Z00?oo`D0oookJ_oonfX02_oonfX00ooo1@3ooo]ZoookJP09oookJP;oob802OoonfX3
o`0000;oobH0<OoonfX00ooo1@3ooo]ZoookJP05oookJP03ool70?oonf[ooo]Z00Kooo]Z00?oo`X0
oookJ_oonfX00ooonfX00ooo0`3ooo]ZoookJP09oookJP05ool>0?l0003ooo]ZoookJ_oo0000COoo
nfX00ol0003ooo]ZoookJP0@oookJP001_oonfX00ol0003ooo]ZoookJP0=oookJP03ool10?oonf[o
oo]Z04;ooo]Z00?oo`P0oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP0>oookJP?o0000;_oonfX2
ool101Kooo]Z00?o0000oookJ_oonfX04_oonfX2ool@00Gooo]Z0_oo3`06oookJP03ool;0?oonf[o
o`h000Oooo]Z00?oocL0oookJ_oonfX01?oonfX00ooo?@3ooo]ZoookJP02oolm027ooo]Z00GoobT0
ofco0?m/o`3oK?l0o`1_o`02oookJP03o`0bool0Kooo03;o00Co03;o0_oonfX00ol0d?oooo]Zoook
JP02oookJP06o`3@oooo003o0=3oool00?l0Kooooo]Z1_o9o`000ol0oi3ooo]ZoookJP04oomd00Co
oo]Z00CoK?l0oookJ_oonf[ooo]Z1OooU`05oookJP03oolR0?oonf[ooo]Z02Kooo]Z00?oob80oook
J_oonfX00ooonfX3o`0000?ooo]Z00?oobH0oookJ_oo9P000_oo400:oookJP?oob80A?oonfX00ooo
3P3o0000oookJP0BoookJP03ool00?oonf[ooo]Z00oooo]Z00?oo`00oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP0@oookJP001_oonfX00ol0003ooo]ZoookJP1LoookJP03ool00?oonf[ooo]Z00Oo
oo]Z0ol0000^oookJP03ool50?oonf[ooo]Z00?ooo]Z00Goo`80oookJ_oonf[ooo]Zool;0006oook
JP03oolH0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX08?oonfX00ooo2`3ooo]ZoookJP05oook
JP;oocL01_oonfX4oolm027ooo]Z0om/o`000ooonf[o03;oo`0bo`03o`0bo`03o`1_oooonf[o06oo
00;ooo]Z00Go03;oo`3@ool0<_oooo]Zo`3@o`04oookJP05o`3@oooo003o0=3oo`1_oooo00001ooo
nfX3olWo0004oookJ_ooM03oog@0oookJPGoog@000?oK?l0oookJ_oonfX01OooU`000ooonf[oodD0
oom50002oom500?ooad02?oonfX01?ooN`3ooo]ZoolI0?oo6@0MoookJP?o00005ooonfX00ooo203o
ob80oookJP0;oookJP03ool10?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX03OoonfX00ooo0@3o
oo]ZoookJP0GoookJP03o`000?oonf[ooo]Z047ooo]Z00?oo`00oookJ_oonfX02OoonfX00ol0003o
oo]ZoookJP0@oookJP001_oonfX00ol0003ooo]ZoookJP1QoookJP03ool30?oonf[o000000;o0000
=ooonfX00ooo0P3ooo]ZoookJP04oookJP04ool00?oonf[ooo]ZoolH00cooo]Z0_l0000UoookJP03
oolB0?oonf[ooo]Z00;oocL01_oonfX2oolm00Sooo]Z0_ooF009oookJP;oK?l02ooonfX3ofco00?o
oo]Z00CoB?l0o`0boooo7P3o06oo0ol0<_l01?oonf[o06oooookJ_l0<_l2oolT0004o`1_ool0<_oo
03;oo`3@o`;ooo]Z00Ko0=3oool00?oo003o06ooo`3@oooo0009oookJP04o`3oT?oonf[ooo]Zoomd
00Kooo]Z0oooM0001Ooonf[ooiL0oonG0?ooU`3ooo]Z00;ooiL000?oodD0oookJ_oonfX00oooA@07
oookJP?oog/03?oonfX2ool900cooo]Z00?oo`00o`000?l000000_l00008oookJP03ool90?oonf[o
oo]Z00_ooo]Z00?ooaT0ool>0?oonfX0;_oonfX00ooo0@3ooo]ZoookJP0=oookJP;oo`D00_oonfX2
ool300Gooo]Z00?o0000oookJ_oonfX01OoonfX00ooo2@3oo`40ool10014oookJP03o`000?oonf[o
oo]Z013ooo]Z0006oookJP03o`000?oonf[ooo]Z023ooo]Z0_oo0@0noookJP?o00000_oonfX01Ooo
203ooo]ZoookJ_oonf[oo`00043ooo]Z00?oo`00oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0R
oookJP;ooa801_oonfX2oolA00[ooo]Z00?ooeP0oookJ_oonfX01ooonfX01?m/o`3oof<0oomS0?m/
o`07oookJPCoK?l01?oonfX2odSo0003oookJ_l0<_oo03;o00;ooo]Z00?o06oooookJ_l0<_l00_l0
<_l2oookJP07oolT0?oonf[o06oooookJ_l0<_oooo]Zo`3@o`02oookJP04o`1_oooo003oo`00o`3@
o`[ooo]Z00?o0?n@ool00?oonfX02?oonfX01Om/o`3ooo]ZoookJ_oonf[ooiL000?ooo]Z0_ooU`09
oookJPCooe8000?oog/0oolG0?oonfX05_oonfX3o`0000cooo]Z00?oo`T0oookJ_oonfX02ooonfX0
0ooo6@3ooo]ZoookJP0:oookJP;oo`P00_oo7@0;oookJP03ool30?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX00ooonfX2ool9017ooo]Z00?oo`00oookJ_oonfX03ooonfX00ooo003ooo]ZoookJP0P
oookJP03o`000?oonf[ooo]Z013ooo]Z0006oookJP03o`000?oonf[ooo]Z02?ooo]Z00?oo`<0oook
J_oonfX0=ooonfX3o`0000gooo]Z00?oo`00oookJ_oonfX0=OoonfX2ool800Cooo]Z0_oo1@04oook
JP03ool90?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo7@00<_oonfX00ooo2@3ooo]ZoomH0005oook
JP03oomS0?oonf[oo`0000?oof<00ooonfX01Om/o`3ooo]Zoom;0?oonf[oK?l000Cood/00ooonfX3
odSo00;ooo]Z00Go03;oodSo0?l0<_oo03;oo`1_o`03oookJP03o`0bool0Kooo03;o00;o03;o00Co
oo]ZoolJ0?l0KooooaX00_l0<_l2oookJP05o`1_oooonf[ooo]ZoookJ_l0d?l02_oonfX00ol0oi3o
oo]ZoookJP08oookJP03ofco0?oonf[ooo]Z00Kooo]Z0oooU`07oookJPCooe802_oonfX3oolD00So
oo]Z0ol0000NoookJP03oolI0?oonf[ooo]Z00_ooo]Z00?ooad0oookJ_oo7@002_oonfX00ooo0`3o
oo]ZoookJP0<oookJP03ool00?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP1;oookJP03o`000?oonf[ooo]Z013ooo]Z0005oookJP03o`000?oonf[ooo]Z05cooo]Z
0_l0000EoookJP03ool20?oonf[ooo]Z03Oooo]Z00?oo`D0oookJ_oonfX00ooonfX2ool100?ooo]Z
0_oo7@07oookJP;oobP09OoonfX3oolC00;ooo]Z0_ooF005oookJPCoof<000Cooo]Zofco0?oonf[o
K?l00_oonfX00om/o`3ood/0oom;0002oom;00Gooo]Z1om8o`000ol0<_oooo]Zo`1_o`02o`0bo`;o
oo]Z00?o03;ooookJ_l0Kol00ooonfX3o`0bo`?ooo]Z00?o03;oo`1_oooonfX00_oonfX2oolM0003
o`3@oooonf[ooo]Z00Sooo]Z00?o0?n@oookJ_oonfX04ooonfX00oooU`3ooad0oookJP05oookJP03
oomB0?oonf[oog/000?ooe801ooonfX3oomF00Gooo]Z0ol00002oookJP;oo`/03?oonfX00ooo003o
oo]ZoookJP1IoookJP03ool20?oonf[o000000oooo]Z00?oo`40oookJ_oonfX03_oonfX00ooo003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z013ooo]Z0005oookJP03o`000?oonf[ooo]Z03Gooo]Z
00?oo`00oookJ_oonfX08OoonfX3o`0001cooo]Z0_oo20001Ooo003ooo]ZoookJ_oonf[ooa0003Go
oo]Z00Coo`/0oookJ_oonf[ooo]Z0_oo7@000ol0003oo`00oookJP02oookJP;oobP0;?oonfX3oomH
00?ooa@00oooH`02oookJP03ofco0?oo4@3ooa4000?oK?l000?ooo]Zofco0?ooB`001_oonfX3odSo
0003ooo90?ooM@3oogD000;ooo]Z00Go03;ooookJ_l0Kooo03;ooookJP02o`0bo`?ooo]Z00?o06oo
oookJ_oonfX00ooonfX3o`0bo`03o`1_ool0<_oo03;o00Gooo]Z00?o0=3ooookJ_oonfX01?oonfX4
oolL0003o`3oT?oonf[ooo]Z00Kooo]Z0_oo200;oookJP;ooad02?oonfX01?ooN`3ooo]ZoookJ_oo
DP06oookJP04oomF0?oonf[ooeH0oookJPCo00008OoonfX00ooo003ooo]ZoookJP0;oookJP03ool;
0?oonf[ooo]Z00Sooo]Z0_oo2002oookJP;ooa@02?oonfX2ool302Sooo]Z00?o0000oookJ_oonfX0
3?oonfX00ooo1@3ooo]ZoookJP0PoookJP03ool00?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
4?oonfX000Gooo]Z00?o0000oookJ_oonfX0=ooonfX00ooo0`3ooo]ZoookJP0LoookJP?o00009?oo
nfX2ool@0003ool00?oonf[ooo]Z03Sooo]Z0_oo2003oookJP;oobP000?ooo]Zool60?oonfX01_oo
nfX00ooo903ooo]ZoookJP0QoookJP03oomH0?oonf[ooo]Z00Kooo]Z1Om/o`03oookJP04ofco0?oo
nf[ooo]ZoookJP;oo`D000Gooo]Zooo90?oob@3oolT0odSo0003oome00;oB?l01?ooM@000ol0<_oo
ogD0oome0003oookJP03o`1_oooonf[ooo]Z00Cooo]Z0_l0Kol4o`0bo`Gooo]Z00?o0=3ooookJ_oo
nfX01OoonfX01?oo603ooo]ZoookJ_l0oi07oookJP03ool80?oonf[ooo]Z00Wooo]Z00?ooad0oook
J_oonfX02OoonfX00oooN`3ooo]ZoookJP07oookJP04oomF0?l0003ooeH0oomF00Kooo]Z0_oo4002
oookJP?ooc/01_oonfX00ooo2`3ooo]ZoookJP0LoookJP03ool;0?oonf[ooo]Z00cooo]Z0_oo500?
oookJP;ooaL01_oonfX2ool000oooo]Z00?oo`00oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP19
oookJP03o`000?oonf[ooo]Z00oooo]Z0005oookJP03o`000?oonf[ooo]Z03[ooo]Z0_oo1`0Goook
JP?o0000;_oonfX00ooo0@3ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z00;ooo]Z0_oo1@06oook
JP03oolT0?oonf[ooo]Z00Kooo]Z0_oo>00RoookJPKoK?l000CoolT0oolD0?oonf[oK?l00ooonfX3
ooo900?ooo]Z1_ooM@001Ol0<_oooo]ZoooC0?ood`3o03;o00;o06oo00GoB?l0oookJ_oonf[ooo]Z
o`1_o`05oookJP;o06oo0ooonfX2o`0bo`Gooo]Z00?o0=3ooookJ_oonfX01?oonfX3oolH0003oook
J_l0oi3ooo]Z00Gooo]Z0_oo5`0GoookJP03oomk0?oonf[ooo]Z00?ooo]Z0ol00004oookJP03oomF
0?oonf[ooo]Z00Oooo]Z1?oo>`05oookJP03ool;0?oonf[ooo]Z00[ooo]Z0_oo0P0=oookJP03ool0
0?oonf[ooo]Z023ooo]Z0_oo5`0RoookJP03o`000?oonf[ooo]Z00?ooo]Z00?oo`00oookJ_oonfX0
7_oonfX00ooo003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00oooo]Z0005oookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?oo`00oookJ_oonfX01_oonfX3o`0003Kooo]Z00?oo`40ool70?oonfX00ooo
nfX00ooo003ooa80oookJP0[oookJP03o`000?oonf[ooo]Z00Oooo]Z00?oo`/0oolT0?oo90001Ooo
nfX3oolh02Kooo]Z0om/o`02ooo900?oK?l00ooob@03oookJP;ooa@01?oonfX00oooM@3oB?l0o`0b
o`02oooC0003oookJ_ood`3o03;o00;ooo]Z0_l0Kol2odSo0003o`1_oom8o`3oB?l000?ooo]Z00?o
06oooookJ_l0Kol00ooonfX2oomZ00Gooo]Z00?o0=3ooookJ_oonfX01ooonfX00ol0oi3ooo]Zoook
JP02oookJP?oom<02ooonfX01?oo303ooo]ZoookJ_oonfX4ooo900Sooo]Z0ol00006oookJP;oob80
00?ooeH0oookJ_oonfX01_oonfX01_oo@03ooc/0oom00?oonf[ooc/0oookJP;oo`h0:ooonfX00ooo
0P3ooo]ZoookJP0EoookJP03ool40?oonf[ooo]Z00cooo]Z00?oo`40oookJ_oonfX04?oonfX00ol0
003ooo]ZoookJP0CoookJP;oo`808?oonfX00ooo003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z
00oooo]Z0005oookJP03o`000?oonf[ooo]Z04[ooo]Z00?oo`80oookJ_oonfX00ol0000noookJP03
ool00?oo4P3ooa8000?ooo]Z00?oo`00oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP07oookJP03
ool;0?oonf[ooo]Z00?ooo]Z0ooo>008oookJP03oolY0?oonf[ooo]Z01oooo]Z00?oolT0ofco0?oo
b@000_oob@0=oookJP03odSo0?l0<_ooom<000;oom<000?o03;oo`0:ool0<_l01Ol02_l00oood`3o
06oooooC0002oooC0003o`1_ooood`3oom<000;oom<01oooJP03oookJP03o`3@oooonf[ooi/000;o
oi/01OoonfX00ol0oi3ooo]ZoooC0005oooC0003oolD0?oonf[ooo]Z00[ooo]Z00?ooi/0ooo90?oo
V`000ooob@03oookJP04o`000?oo003o0000o`0000Wooo]Z00?oob80oookJ_oonfX02OoonfX01Ooo
@03ooo]ZoookJ_oonf[ooc/000Sooo]Z0_oo>003oookJP;oo`X0;_oonfX00ooo2`3ooo]ZoookJP0>
oookJP03ool@0?oonf[ooo]Z00?ooo]Z00?oo`40oookJ_oonfX03OoonfX01Ooo003ooo]ZoookJ_oo
nf[o000004Wooo]Z00?o0000oookJ_oonfX03ooonfX000Gooo]Z00?o0000oookJ_oonfX0B_oonfX3
o`000003oookJ_oo1P3ooo]Z00Sooo]Z00?oo`00oookJ_oonfX0??oonfX2ool300;ooo]Z00?oo`D0
oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0=oookJP03oolh0?oonf[ooo]Z00Gooo]Z00?oo`<0
oookJ_oo:@001ooonfX2oomF01Oooo]Z1?oob@000oooV`3ooo]ZoookJP07oookJP;o0?lC00Cooa<0
oookJ_oonf[ooo]Z1Ol02_l00oood`3o03;ooookJP02oookJP04o`0:ool0Kooo00[oo`1_o`;ooo]Z
00?o06oooookJ_oonfX00_oonfX00om8o`3o03;oodSo0002oomZ0003odSo0?oonf[ooo]Z00KoofX0
0_ooV`06oookJP03o`3oT?ood`3ooo]Z00Coom<02OoonfX2oolC0003oookJ_ooV`3ooi/000;oolT0
0ooonfX00ooob@3o0000o`00000=oookJP03oolR0?oonf[ooo]Z00[ooo]Z00?ood00oookJ_oonfX0
2OoonfX3oolh00oooo]Z0_oo100=oookJP03ool00?oonf[ooo]Z027ooo]Z0_oo400JoookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0?oookJP001?oo
nfX00ol0003ooo]ZoookJP0=oookJP03ool20?oonf[ooo]Z03Sooo]Z0ol0000BoookJP03ool10?oo
nf[ooo]Z03_ooo]Z0_oo1@000ooonf[oo`00ool00002oookJP03oolD0?oonf[ooo]Z01cooo]Z00?o
0000oookJ_oonfX04OoonfX2ool=00;ooo]Z0_oo:@05oookJP03ool00?ooEP3ooo]Z00Sooo]Z0ooo
D@0<oookJPKoolT000?ooi/0oookJ_oonfX01?oonfX2o`3o4`03oookJ_l0oa?ooo]Z00;ooo]Z00Co
0?n@o`0:ool0oi3o03;o0ol02_l01?oo503o03;ooookJ_l02_l2oookJP04o`0bool02_oo00[oo`1_
o`Gooo]Z00Ko03;oool00?l0Koooo`00oomZ0?oonfX6odSo00Sooi/00_oonfX00oooI@3o0?n@oooC
0002oookJP?oom<03?oonfX01_ooV`3oolT0ooo90?oob@3o0000ooo900;ooo]Z0_oo300;oookJP03
ool10?oonf[ooo]Z00cooo]Z00?ood00oookJ_oonfX02ooonfX00ooo>03ooo]ZoookJP09oookJP03
ool90?oonf[ooo]Z01kooo]Z00?oo`00oookJ_oonfX08OoonfX2ool200_ooo]Z00?o0000oookJ_oo
nfX06ooonfX00ooo0@3ooo]ZoookJP0MoookJP03ool00?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX03ooonfX000Cooo]Z00?o0000oookJ_oonfX0AOoonfX3o`0001Gooo]Z00?oo`40oookJ_oonfX0
@OoonfX2oolD00;ooo]Z00Goo`00oookJ_oonf[ooo]ZoolR000HoookJP03o`000?oonf[ooo]Z01So
oo]Z0_oo3002oomF00Cooo]Z00?oo`P0oomA0?ooD@000oooD@0AoookJP04oonK0?oob@3ooi/0oonK
00Cooo]Z0ol0oa<2oookJP?o0?lC0_l0oi001ooonf[o00[oo`0:oooonf[oofD0oooC0?oonfX00ol0
2_l4oookJP04o`0bool0Kooo00[oo`0:o`?ooo]Z00Ko03;oool00?oo003oo`00o`1_oooo0007oook
JP03odSo0?ooV`3ooi/000Gooo]Z1OooV`000oood`3ooo]ZoooC0002oookJP?oom<02OoonfX01Om/
o`3ooi/0ooo90?oonf[oolT000?obOl000?ooa00oookJ_oonfX02_oonfX00ooo0@3ooo]ZoookJP0:
oookJP03ool20?oonf[ooo]Z00[ooo]Z0_oo7002oookJP03oolh0?oonf[ooo]Z00Oooo]Z00?oobX0
ool90?oonfX02ooonfX2ool402;ooo]Z00?oo`@0oookJ_oonfX07ooonfX01?l0003ooo]ZoookJ_oo
0014oookJP03o`000?oonf[ooo]Z00oooo]Z0004oookJP03o`000?oonf[ooo]Z04;ooo]Z0ol0000L
oookJP;oo`D01ooonfX00ooo003ooo]ZoookJP0joookJP;oob800_oonfX3ool201Gooo]Z00?o0000
oookJ_oonfX06?oonfX2oomF00Gooo]Z00Goo`P0oomA0?ooD@3ooo]ZoolR0004oookJP03ool10?oo
nf[ooo]Z00;ooiL02_oonfX2oonK00?ooo]Z0_l0oa<00ooonf[o0?lCo`3o4`03o`3o4`06oookJ_l0
oa?ooo]ZoookJ_l02_oo03;o0_l02_l4oookJP03o`0:ool0<_oo00[o00?o00[o00Gooo]Zo`0boooo
nf[ooa80o`0:o`02oookJP03o`0boooonf[oo`0000;oo`0000?o06oooookJ_oonfX01ooonfX00ooo
V`3ooo]ZoookJP03oomU00;ooo]Z00?oofD0oookJ_oonfX00_ooV`06oookJP;oom<00ooonfX3o`00
0007ofco0?ooV`3ooo]ZoookJ_ooJP3obOl0ooo90002olWo00_ooo]Z0_oo2`0KoookJP03oolL0?oo
nf[ooo]Z00[ooo]Z0_oo:P0KoookJP03ool10?oonf[ooo]Z02;ooo]Z0_oo2P0AoookJP03o`000?oo
nf[ooo]Z013ooo]Z00?oo`00oookJ_oonfX03ooonfX00ooo003ooo]ZoookJP0PoookJP03o`000?oo
nf[ooo]Z00kooo]Z0004oookJP03o`000?oonf[ooo]Z027ooo]Z00?oo`80oookJ_oonfX06ooonfX3
o`0002Cooo]Z00?oo`d0oookJ_oonfX01OoonfX00ooo003ooo]ZoookJP0foookJP;oob801?oonfX0
0ooo0P3ooo]ZoookJP03oookJP03oolD0?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX05ooonfX3
oomF00Kooo]Z0_ooD@02oolR00?ooo]Z00?oo`40oookJ_ooU`002_oonfX2oon600?ooo]Z1Ol0oa<2
o`3oT0;ooo]Z00?o0?lCoookJ_l0oa<00_oonfX00ol02_oo03;ooookJP02o`0:o`;ooo]Z00?o00[o
oookJ_l0<_l01?oonfX3o`0:o`;ooo]Z00?o00[oo`0boooonfX01OoonfX00ol0Kooooa40oookJP07
oookJP03o`3@ooooI@3ooo]Z00Sooo]Z00?o0?n@oookJ_oonfX01_oonfX2oooC0003o`000?oonf[o
oo]Z00CoK?l00oooJP001?m/o`3oolT0olWo0?o9o`08oookJP;oogD03OoonfX00ooo0`3ooo]Zoook
JP0LoookJP03oolZ0?oonf[ooo]Z00[ooo]Z0_oo:007oookJP03ool50?oonf[ooo]Z017ooo]Z00?o
o`00oookJ_oonfX09OoonfX2ool>0003o`000?oonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX0>ooo
nfX00ol0003ooo]ZoookJP0>oookJP001?oonfX00ol0003ooo]ZoookJP0SoookJP03ool50?oonf[o
oo]Z01Kooo]Z0ol0000doookJP03ool40?oonf[ooo]Z03cooo]Z0_oo50000ooo003oo`L0oookJP03
oookJP03ool/0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX09?oonfX2o`3oT006oookJ_ooU`3o
oo]ZoookJ_oo2`3oohH00ooonfX01?oo203oohH0oon60?ooQP04oookJPCo0?lC00?o0?n@oookJ_oo
nfX00ooonfX00ol0oa?ooo]Zo`3o4`02oookJP08o`0:oooonf[o03;oo`0:oooonf[o00[ooookJ_l0
2_l2oookJP03o`0boooonf[ooo]Z00Cooo]Z0ol02_l00ooonf[o00[oo`0:o`05oookJP03o`1_oooo
403ooo]Z00Oooo]Z00?o0=3oool90?oonfX02?oonfX00ol0oi3ooo]ZoookJP02oookJP?o00000_oo
nfX3oooC0005ofco0?ooV`3ooo]ZolWo0?m/o`001OooJP000oo9o`3ooo]ZoookJP05oookJPCoogD0
6OoonfX00ooo003ooo]ZoookJP0MoookJP;oobP01_oonfX00ooo1@3ooo]ZoookJP0;oookJP03ool1
0?oonf[ooo]Z01?ooo]Z00?oo`40oookJ_oonfX03_oonfX00ooo103ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?oo`00oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0>oookJP001?oo
nfX00ol0003ooo]ZoookJP0doookJP03ool10?oonf[ooo]Z00;ooo]Z0ol0000goookJP03ool40?oo
nf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX0>ooonfX2ool/0003oookJ_oo003ooo]Z00Wooo]Z00?o
0000oookJ_oonfX08?oonfX3o`3oT003oookJ_l0oi3ooiL000?ooo]Z0_ooQP001?oonf[oohH0oon6
0?ooQP03oookJP03ool60?oonf[o0?n@00?o0?n@00?o0?lCoookJ_l0oa<01Ol0oa<00ooonf[o0?lC
oookJP02oookJP07o`0:oooonf[ooo]Zo`0:ool0<_oooo]Zo`0:o`03oookJP03o`0boooonf[ooo]Z
00Gooo]Z00?o03;ooookJ_l02_l00ol02_l4oookJP03o`1_oooo403ooa0000Sooo]Z00?o0=3ooook
J_oonfX02?oonfX01?oo003o0000o`000?l00008oookJP03oooC0?m/o`3ol?l000;ol?l000Gooo]Z
oomZ0?o9o`3obOl0oookJP03oomZ00Gooo]Z00CoogD0oookJ_ooM@3ooo]Z0_l0oi02oomH00Kooo]Z
00?oo`X0oookJ_oonfX02_oonfX00ooo1@3ooo]ZoookJP0=oookJP03ool60?oonf[ooo]Z00_ooo]Z
0_oo5`04oookJP03oolX0?oonf[ooo]Z017ooo]Z00?oo`40oookJ_oonfX03?oonfX2ool001Kooo]Z
00?oo`@0oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP05oookJP03ool90?oonf[ooo]Z023ooo]Z
00?oo`00oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0>oookJP000ooonfX00ol0003ooo]Zoook
JP0eoookJP03ool10?oonf[o000000;o0000?ooonfX00ooo3@3ooo]ZoookJP04oookJP03ool00?oo
nf[ooo]Z03Kooo]Z0_oo;007oookJP03ool80?oo4@3ooo]Z00?ooo]Z00?o0000oookJ_oonfX07_oo
nfX00ol0oi3ooo]Zo`3oT003oonG0003o`3oT?oonf[ooo]Z00CoohH000?ooo]Zool>0?oo3P000_oo
nfX3o`3oT006oookJ_oo3@3oo`d0oookJ_o9o`3o0?lC0_oonfX00ooo003ooo]ZoookJP06o`3o4`04
o`0:oooonf[ooo]ZoookJP;o00[o00?o03;oo`0:oooonfX00_oonfX00ol0<_oooo]ZoookJP03oook
JP03o`0boooonf[o03;o00?ooo]Z0_l02_l4oookJP03o`1_oooonf[ooo]Z00Kooo]Z0_oo3`000ol0
d?oooo]ZoookJP04oookJPCo00002OoonfX2ofco0003oonK0?o`o`3ol?l000?ol?l000Sooo]ZolWo
0?o9o`3oB?l0oookJ_oob@3oB?l0oomZ00?ooo]Z00Co0?n@oome0?ooM@3ooo]Z0_ooM@04oomH0003
o`3oT?oonf[ooo]Z00Cooo]Z0_ooH`08oookJP;oo`D03?oonfX00ooo003ooo]ZoookJP0?oookJP03
oolG0?oonf[ooo]Z00cooo]Z00?ooah0oookJ_oonfX09ooonfX00ooo003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z00Cooo]Z00?oo`T0oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0>oookJP00
0ooonfX00ol0003ooo]ZoookJP0doookJP?o000000?ooo]Zool40?oonfX0BooonfX00ooo0`3ooo]Z
oookJP02oookJP03ool00?oonf[ooo]Z03Kooo]Z00?ooa40oookJ_oonfX00ooonfX00ooo1`3ooo]Z
oolj000MoookJP;o0?n@00KooiL0oookJ_ooU`3ooiL0o`3oT?oonfX5oon600;ooo]Z0ol0oi04oook
JP;oo`d000?obOl0oookJ_oonfX00_l0oa<01?oonf[ol?l0oo3o0?l0oa<2oonC00;ooo]Z00?o00[o
ooWo0?oio`000_l0oa<00ol02_oooi<0oonC0002oonC00;ooo]Z00?o03;ooookJ_oonfX00ooonfX0
0ol0<_oooo]Zo`0bo`04oookJP03o`0:oooonf[ooo]Z00?ooo]Z00?o06oooookJ_oonfX02?oonfX0
0ol0d?oooo]ZooWo0003ooWo00;ooo]Z0_oo2`06oookJP?oK?l00_oonfX01Ooo0@3ol?l0oo3o0?oo
nf[oK?l000;ol?l000?obOl0odSo0?oonfX00_m8o`001?oob@3oB?l0oookJ_oonfX7o`3oT0;oogD0
00?ooeP0oookJ_oonfX00ol0oi03oookJP?oof<01OoonfX2ool900kooo]Z00?oo`00oookJ_oonfX0
2ooonfX00ooo003ooo]ZoookJP0AoookJP03oolN0?oonf[ooo]Z00oooo]Z0_oo0P0VoookJP03ool1
0?l0003ooo]Z01kooo]Z00?oo`00oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0>oookJP000ooo
nfX00ol0003ooo]ZoookJP0aoookJP?o00004ooonfX00ooo003ooo]ZoookJP11oookJP03ool=0?oo
nf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX0=_oonfX2ool70003oolj0?oonf[ooo]Z00?ooo]Z00Co
o`@0oookJ_ooB`3ood/04ooonfX3o`3oT0GooiL000Go0?n@oookJ_oonf[ooo]Zoon60003o`3oT0Wo
oo]Z00CobOl0oookJ_o`o`3ol?l00_l0oa<01?oonf[oo`T0oonC0?oonfX8oonC0004ool20?l02_oo
0?lCo`3o4`;o03;o00?o0?lCo`0boooonfX00ooonfX01Ol0<_oooo]ZoookJ_oonf[o03;o00;ooo]Z
00?o00[ooookJ_oonfX01OoonfX00ol0Kooooo]ZoookJP06oookJPSonOl00_oonfX2ool>00;ooo]Z
0om/o`05oookJP?ol?l00_oonfX00om/o`3ol?l0odSo0002odSo00;ooo]Z0om8o`000ooonf[o0?n@
oookJP03oookJP05o`3oT?oonf[ooo]ZoookJ_ooM@001_l0oi02oookJP;oof<04ooonfX00ooo1@3o
oo]ZoookJP0>oookJP03ool00?oonf[ooo]Z00cooo]Z00?oo`P0oookJ_oonfX09?oonfX00ooo003o
oo]ZoookJP0DoookJP04ool10?oonf[ooo]Zo`0000oooo]Z00?oo`D0oookJ_oonfX07_oonfX00ooo
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00kooo]Z0003oookJP03o`000?oonf[ooo]Z02ko
oo]Z0ol0000JoookJP03ool40?oonf[ooo]Z03gooo]Z00?oo`d0oookJ_oonfX02?oonfX01?oo0@3o
oo]ZoookJ_oo0@0_oookJP;oocX000?o0000oookJ_oonfX00ooonfX2oom;0003ool90?oonf[ooo]Z
017ooo]Z0_l0oi000ooonf[o0?n@oonG0002oonG00;ooo]Z00?o0?n@oookJ_l0oi000_l0oi03oook
JP;ol?l01_oonfX3oo3o00Cooo]Z00?o0?lCoonC0?ooT`000_ooT`02ooWo0004o`0:oooonf[onOl0
o`0:o`;oo`8000Go00[ooookJ_oonf[ooo]Zo`3@o`03o`0bo`;o0?lC00?o03;oo`3o4ooonfX00ooo
nfX00ol0<_oo00[ooookJP08oookJP03o`1_oooo_@3ookd000?ooo]Z0ol00004ooWo00;ooo]Z00Co
nOl0oookJ_oonf[ooo]Z0om/o`07oookJP03ool;0?o`o`3ol?l000;ol?l000CoK?l0oo3o0?m8o`3o
B?l01?oonfX00om8o`3ooo]ZodSo0002oookJP03o`3oT?oonf[ooo]Z00;ooo]Z00Go0?n@oookJ_oo
nf[ooeP0oome0002o`3oT003oookJ_l0oi3o0?n@00Cooo]Z00?oof<0oookJ_oonfX02OoonfX2oom;
01;ooo]Z00?oo`40oookJ_oonfX04?oonfX00ooo203ooo]ZoookJP0<oookJP;ooa<09_oonfX00ooo
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00cooo]Z00?oo`D0oookJ_oonfX0<OoonfX00ol0
003ooo]ZoookJP0>oookJP000ooonfX00ol0003ooo]ZoookJP0[oookJP?o00007OoonfX00ooo103o
oo]ZoookJP12oookJP;ooaX00ooonfX01Ooo0@3ooo]ZoookJ_oonf[oo`4002oooo]Z0_oo>P001?oo
nf[o0000oookJ_oonfX2oom;00Gooo]Z0_oo20001?oonf[oo`00oookJ_ooC@0:oookJP;o0?n@0_oo
nfX01?l0oi3ooo]ZoookJ_oonfX4o`3oT0Gooo]Z00?ol?l0oookJ_o`o`000ooonfX3oo3o0004olWo
0?oonf[ooo]ZoookJP;o0?mD0_oonfX01?l0oa?ooo]Zo`3o4oooT`02ooWo0004o`0:oooio`3onOl0
o`0:o`?onOl000?o00[oooWo0?oio`000ooio`000ol0<_oonOl0o`0bo`06ooWo0003o`0:oooio`3o
o`0000;oo`001OoonfX4oonm00?o00001?oonfX00ooio`3ooo]ZooWo0002ooWo0004oookJ_m/o`3o
K?l0ofco00[ooo]Z0_oo30001Ooonf[ol?l0ofco0?o`o`3oB?l000Gooo]Z0_m8o`001Ooonf[oB?l0
odSo0?oonf[o0?n@00Cooo]Z0ol0oi001OooF03ooo]ZoookJ_oonf[o0?n@00Co0=3o0ooonfX00ooo
H`3ooo]ZoookJP08oookJP?ood/03_oonfX00ooo1@3ooo]ZoookJP0?oookJP03ool00?oonf[ooo]Z
017ooo]Z00?ooa<0oookJ_oonfX03OoonfX2oolH00gooo]Z0_oo000BoookJP03o`000?oonf[ooo]Z
00;ooo]Z00?oo`00oookJ_oonfX0;ooonfX00ooo003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z
00gooo]Z0003oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000SoookJP;oo`T02OoonfX00ooo003o
oo]ZoookJP0doookJP;ooaX02OoonfX2ool;00;ooo]Z00?oo`00oookJ_oonfX0:ooonfX01?l0003o
oo]Zoom;0?ooB`0:oookJP04oom=0?oonf[ooo]Zool600;ooo]Z00Koo`40oookJ_ooM@3oogD0oook
J_l0oi04oookJP?o0?n@0ooonfX00ol0oi3ooo]ZoookJP02oookJP;ol?l000?ooo]Zoo3o0?o`o`00
0_o`o`02oookJP03olWo0?oonf[ooo]Z00;o0?mD00?ooo]Zo`3oE?l0oe@00_oonfX2o`3o4`;ooo]Z
00GonOl0o`0:oooio`3o00[ooookJP03o`3@o`04o`0:oooonf[oo`d0ool=00;ooo]Z00Go00[oo`0b
oooonf[ooo]ZoolM0003oookJP03o`0:oooonf[oo`0000Ko0?lC00?ooo]Zoonm0?oo_@000ooo_@08
oookJP03ooWo0?oonf[o0=3o00ConOl03ooonfX01?o`o`3obOl0oo3o0?m8o`03oookJP03odSo0?oo
2P3oB?l000;ooo]Z00?oB?l0oookJ_l0oi000_oonfX3o`3oT003oookJ_oo003ooo]Z00;ooo]Z00Co
0?n@o`3@oooonf[o0=3o0_oonfX3o`3@o`03oookJ_ooH`3ooo]Z00Wooo]Z00?ood/0oolg0?ooB`00
6_oonfX00ooo0P3ooo]ZoookJP0@oookJP;oo`405?oonfX2oolH01kooo]Z00Coo`00oookJ_oonf[o
00005_oonfX00ooo0P3ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z00gooo]Z0002oookJP03o`00
0?oonf[ooo]Z00gooo]Z00?oo`@0oookJ_oonfX05_oonfX3o`0003Gooo]Z00?oo`<0oookJ_oonfX0
??oonfX00ooo2`3ooo]ZoookJP03oookJP06oolN0?oonf[ooo]Zool00?oonf[oo`809_oonfX2o`00
0003oom;0?oonf[ooo]Z00Kooo]Z0_ooC@07oookJP06oome0?oo2@3ooo]Zo`3oT?oo0P3ooo]Z1?l0
oi05oookJP04o`3oT?oonf[ooo]ZoookJPCol?l000?ooo]Zoo3o0?oonfX00ooonfX3o`3oE0?ooo]Z
0ol0oe@2oookJP08o`3o4ooonf[ooo]Zo`0:oooonf[o00[oooWo0?l0d?l2oookJP03ofco0?l02_oo
oo]Z00Gooo]Z00Co00[ooookJ_oonf[ooo]Z0_oo30000ooonf[o00[ooookJP02ool00005o`0boooo
003oo`00ool00?l000000ol0oa<9oonm0006oookJ_m/o`3oK?l0ooWo0?oonf[onOl00ooonfX2ooWo
00gooo]Z00GobOl0oookJ_oonf[ol?l0odSo0002oookJP03odSo0?oonf[o0?lC00Go0?lC0_l0oi02
oookJP03ool50?l0oi3ooo]Z00;ooo]Z00?o0?n@o`3@oooonfX00_oonfX00ol0d?oooo]ZoookJP02
oookJP?o0=3o2OoonfX2oolg0003oookJ_ooB`3ooo]Z00Wooo]Z00?oocd0oookJ_oonfX06ooonfX0
0ooo003ooo]ZoookJP0AoookJP;oo`P0:?oonfX00ol0003ooo]ZoookJP0:oookJP03ool00?oonf[o
oo]Z00Kooo]Z00?oo`80oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0=oookJP000_oonfX00ol0
003ooo]ZoookJP0SoookJP?o0000AOoonfX00ooo003ooo]ZoookJP0doookJP;ooah02OoonfX00ooo
203oo`00ool0000QoookJP03o`000?oonf[ooo]Z00Gooo]Z0oooC@05oookJP;oogD00_oonfX4o`3o
T0;ooo]Z00?ooeP0ool80?l0oi000_oonfX01Ooo003ooo]ZoookJ_l0oi3ooo]Z00Gol?l000Cooo]Z
oo3o0?oonf[ooo]Z0_l0oe@00ooonf[o0?mDo`3oE004o`3oE003oookJ_l0oeCooo]Z00;ooo]Z0_l0
d?l2o`0:o`03oookJ_oio`3ooo]Z00?ooo]Z00?oK?l0o`0:oooonfX01OoonfX00ol02_oooo]Zoook
JP02oookJP03o`0:oooonf[ooo]Z00?oo`0000Co03;oool00?oo203oo`P01?oonfX2oonm00;o0?lC
0_oonfX2ofco00Kookd000?o0=3ooookJ_oonfX00_oonfX2ooWo00_ooo]Z00GobOl0oookJ_oonf[o
oo]Zoo3o0002odSo0004oookJ_l0oa?oB?l0o`3oT0;o0?lC00Cooo]Zo`3o4ol0oi3ooo]Z0_oo2@00
1_oonf[o0?n@oookJ_ooU`3o0?n@o`3@o`Cooo]Z00Go0=3ooookJ_oonf[oo`00ool>0003oookJP?o
0=3o1ooonfX01?oo=`3ooo]ZoookJ_ooB`08oookJP?oocd05ooonfX00ooo0P3ooo]ZoookJP0Goook
JP03ool80?oonf[ooo]Z00gooo]Z0_oo400HoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oook
J_oonfX03OoonfX000;ooo]Z00?o0000oookJ_oonfX08?oonfX3o`0003oooo]Z00?oo`T0oookJ_oo
nfX02_oonfX00ooo0@3ooo]ZoookJP0`oookJP;ooah02OoonfX00ooo203ooo]ZoookJP05oookJP03
ool00?oo103ooo]Z01[ooo]Z00?o0000oookJ_oonfX01OoonfX00oooC@3ooo]ZoookJP04oome00?o
oo]Z2_l0oi05oookJP;oom<00_oonfX5oo3o00Go0?mD1?oonfX01?l0oeCooo]ZoookJ_l0oe@3o`3@
o`;ooo]Z0_l02_l7oookJP03o`0:oooonf[ooo]Z00Gooo]Z00Co00[ooookJ_oonf[o00[o0_oonfX2
o`0000?oo`0000?o03;ooookJ_oonfX00_oo2`03oookJP06oonm0?oonf[ooo]Zo`1_oom/o`3oo`40
1ooonfX3oonm00Cooo]Z0ooio`05oookJP?o]ol01OoonfX00oo`o`3o0?lCo`3o4`03o`3o4`03oook
J_l0oa?o0?lC00?ooi<00_oo2@000ooonf[o0?n@oonG0002oonG00[o0=3o1_oonfX3o`3@o`Cooo]Z
00?oocL0oookJ_oonfX02_oonfX2oolm01Oooo]Z00?oo`80oookJ_oonfX04OoonfX00ooo003ooo]Z
oookJP0DoookJP03ool@0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo00006_oonfX00ooo003ooo]Z
oookJP0PoookJP03o`000?oonf[ooo]Z00gooo]Z0002oookJP03o`000?oonf[ooo]Z01gooo]Z0ol0
00000ooonf[oo`<0oookJP1<oookJP03ool10?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX0=_oo
nfX00ooo8`3ooo]ZoookJP05oookJP;oo`805OoonfX00ol0003ooo]ZoookJP07oookJP?oogD01_oo
nfX3o`3oT0;ooo]Z00?ooeP0oookJ_l0oi001?l0oi000oood`3o0?n@o`3oT003oookJP03ool90?oo
<P3ol?l000;o0?mD0_ooYP06oookJP04o`3oE?l0d?oo0=3oo`3oE0Oooo]Z00?o00[ooookJ_oonfX0
1OoonfX00ol02_oooo]ZoookJP05oookJP;o00[o0ol00006oookJP03o`0boooonf[ooo]Z00Sooo]Z
00?o06ooool10?oonfX02?oonfX00ol0d?oooo]ZoookJP05oookJP;onOl000?ooo]ZokOo0?ngo`00
0_ngo`000oo9o`3o]ol0oookJP02oookJP04o`3oT?l0oa?o0?lCo`3o4`;oB?l00ooonfX5oonC00;o
oo]Z00GooiL0o`3oT?ooU`3o0=3ooonG0004oookJP03ool50?l0d?oooo]Z00;ooo]Z2_l0d?l00ooo
nf[oo`00oookJP0<oookJP04oolA0?oonf[ooo]Zoolm02Cooo]Z00?oo`00oookJ_oonfX04ooonfX0
0ooo0`3ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z013ooo]Z00?oo`00oookJ_oonfX0:_oonfX0
0ol0003ooo]ZoookJP0=oookJP000_oonfX00ol0003ooo]ZoookJP0JoookJP?o0000EooonfX00ooo
203ooo]ZoookJP0loookJP;oob<01_oonfX2oolk00Kooo]Z00?oo`D0oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP06oookJPCoogD00_oonfX2o`3@o`Cooo]Z0ol0oi000oooF03ooo]Zo`3oT002oook
JP03oooC0?l0oi3ooo]Z00Gooo]Z00KobOl0oonV0?ooYP3oojH0o`3oE?o9o`07o`3oE003oookJ_l0
oeCooo]Z00Sooo]Z0_l02_l5oookJP03o`0:oom/o`3ooo]Z00Cooo]Z00?o0000o`0:ool02_l02_oo
nfX00ol0<_oooo]ZoookJP07oookJP04o`1_oooo203oo`P0ool;00Sooo]Z0_oo2007oookJP03ooWo
0?ngo`3onOl000Go]ol00_l0oi02o`3o4`03oookJ_o`o`3oB?l000?ooo]Z00?o0?lCoonC0?ooT`00
0oooT`02oookJP05o`3oT?ooU`3ooiL0oonG0?l0d?l01OoonfX3oon600Gooo]Z0ol0d?l00ooonf[o
0=3ooookJP0?oookJP03oolA0?oonf[ooo]Z00_ooo]Z0_oo9P0WoookJP03ool00?oonf[ooo]Z01Go
oo]Z00?oo`P0oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0QoookJP03ool00?oonf[ooo]Z01So
oo]Z00?o0000oookJ_oonfX03OoonfX000;ooo]Z00?o0000oookJ_oonfX05ooonfX3o`0001[ooo]Z
0_oo0P0noookJP03ool80?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX0<?oonfX2oolS00Gooo]Z
00?ooc/0oookJ_oonfX01ooonfX00ooo903ooo]ZoookJP03oookJP03ool30?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0d?oooo]Zo`3@o`06oookJP08oomH0?l0oi3o0?n@o`3oT?oo
nf[oom<0oookJ_ooYP04oookJP?oojH00_oo<P02olWo00;o0?mD0ol0d?l00ooonf[oo`T0o`3oE006
o`3oE0Oooo]Z0_l02_l4oookJP03o`0:oom/o`3ooo]Z00?o000000Co00[ooookJ_oonf[o00[o2_oo
nfX00ol0<_oooo]ZoookJP07oookJP03o`1_oooo2`3oc_l000;oc_l01_oonfX2ool300Sooo]Z0_ng
o`001?oio`3obOl0o`3oT?oonfX2okOo0003o`3o4om8o`3ooo]Z00;ooo]Z00?ol?l0oookJ_oonfX0
0_l0oa<2oonC0005o`3o4oooT`3ooi<0oonC0?l0oi000_oonfX00oooU`3ooo]Zo`3@o`05oookJP;o
ohH000?ooo]Zoon60?oonfX00ol0d?l2oookJP03ool60?l0d?oooo]Z00gooo]Z00?oo`00oookJ_oo
nfX03_oonfX00ooo9P3ooo]ZoookJP0<oookJP03ool[0?oonf[ooo]Z017ooo]Z0_oo0@0EoookJP03
ool00?oonf[ooo]Z00Cooo]Z00?oo`P0oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0FoookJP03
ool00?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX03?oonfX000;ooo]Z00?o0000oookJ_oonfX0
5?oonfX3o`0006;ooo]Z00?ooa<0oookJ_oonfX03_oonfX00ooo003ooo]ZoookJP0[oookJP;ooc/0
2_oonfX00ooo903ooo]ZoookJP03oookJP03ool30?oo003ooo]Z00?ooo]Z00?oo`L0oookJ_oonfX0
0ooonfX00ol0003ooo]ZoookJP07oookJP;o0=3o00Cooo]Zo`3@oooonf[o0=3o2?oonfX2oooC0004
oookJ_ooYP3oojH0oookJP?oojH000Gooo]ZolWo0?o9o`3ooo]ZolWo0003o`3@o`;o0?mD00OoB?l0
oookJ_oonf[ooo]Zo`3oE?oonf[o0?mD00;ooo]Z00?oo`<0okOo0?l0oe@01Ol0oe@3oookJP07o`0:
oooonf[ooo]Zo`000?l02_oo0000ofco0003oookJP05o`0:oom/o`3ooo]ZoookJ_l02_l02_oonfX0
0ol0<_oooo]ZoookJP05oookJP?oc_l000Cooo]Zolko0?oonf[oc_l01OoonfX2ool800Oooo]Z1?ng
o`04oookJP03okOo0?m8o`3o0?lC00Cooo]Z00Col?l0oookJ_l0oa?o0?lC0_oonfX01OooT`3o0?lC
o`3oT?l0oi3ooi<000;ooo]Z00?ooiL0oookJ_l0d?l01OoonfX3oon600;o0=3o1OoonfX00ol0d?oo
oo]ZoookJP09oookJP;oo`804?oonfX01Ooo0`3ooo]ZoookJ_oonf[oobH000gooo]Z0_oo:`0Roook
JP03ool00?oonf[ooo]Z00?ooo]Z00?oo`00oookJ_oonfX05ooonfX00ooo3P3o0000oookJP0loook
JP03o`000?oonf[ooo]Z00cooo]Z00000ooonf[o0000oookJP0CoookJP?o00008ooonfX00ooo1`3o
oo]ZoookJP0ooookJP03oolC0?oonf[ooo]Z00Wooo]Z00?oo`H0oookJ_oonfX02?oonfX00ooo003o
oo]ZoookJP0UoookJP?ooc/02?oonfX2oolT00Oooo]Z00?ooe80oookJ_oonfX00_oonfX2ool100Co
oo]Z00?oo`D0oookJ_oonfX01OoonfX01?l0d?oooo]ZoookJ_l0d?l2oookJP03o`3@oooonf[ooo]Z
00;ooo]Z0_ood`001?oonf[oom<0oookJ_oonfX4oonV00Gooo]Z0ol0d?l3olWo0006oookJ_l0oeCo
0?mDo`3oE?oonf[o0?mD0_oonfX01_l0oeCo]ol0okOo0?ngo`3ooo]Zool800;oc_l000?ooo]Zo`3o
T?oonfX01?l0oe@2o`0:o`09o`3oE?l02_oooo]ZoookJ_m/o`3ooo]Zo`0:oom/o`3ooo]Z00;oK?l0
00?ooo]Zo`0:oooonfX02OoonfX00ol0<_oooo]ZoookJP03oookJPWoc_l02_oonfX3o`3oT0;o]ol0
00?oo`D0okOo0?ngo`000_oonfX01Ongo`3ooo]ZodSo0?oonf[o0?lC00Cooo]Z00?ol?l0oolR0?l0
oa<00ooonfX2o`3o4`;ooo]Z0_ooT`001?ooU`3ooo]ZoookJ_l0d?l2oookJP?o0=3o0_ooQP000ooo
nf[o06ooo`1_o`02o`1_o`03oookJ_l0d?oooo]Z01Wooo]Z00Goo`00oookJ_oonf[ooo]Zool3000>
oookJP05oolA0?oonf[ooo]ZoookJ_oo:`00>_oonfX00ooo0`3ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?oo`00oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0<oookJP0000?ooo]Z
o`000?oonfX04?oonfX3o`0003Kooo]Z00?oo`80oookJ_oonfX0@OoonfX00ooo503ooo]ZoookJP0;
oookJP03ool00?oonf[ooo]Z02oooo]Z00?ooe80oookJ_oonfX01OoonfX01ooo703ooo]ZoookJ_oo
nf[oo`D0o`000?oo00001?oonfX01?l0d?oooo]ZoookJ_l0d?l3oookJP06o`3@oooonf[ooo]Zoook
J_ood`3ooo]Z0_ood`02oookJPGoojH00_oonfX3o`3@o`03oookJ_o9o`3obOl000;obOl00_oonfX0
1Om8o`3ooo]Zo`3oP_l0oh;o0?mD00;o]ol000Co0?mDoookJ_oonf[ooo]Z1?o>o`02oookJP07o`3o
T?l0003o0000o`000?oonf[oo`D0oookJP03o`0:o`;o0?mD00Co00[oo`3oE?oonf[oK?l00_oonfX0
0om/o`3ooo]Zo`0:o`0:oookJP03o`0boooonf[ooo]Z00;ooo]Z1Oo>o`001?l0Kooooo]ZoookJ_o>
o`07oookJP?o0?n@1OoonfX2okOo0005oookJ_ngo`3o]ol0oookJ_m8o`000ooonfX01Ol0oa?ooo]Z
oookJ_oo8P3o0?lC00Co0?mD00?o0?lCoookJ_oonfX01?oonfX2oonC0004oookJ_l0d?oo0=3oo`3@
o`?ooo]Z00Go0=3ooookJ_ooQP3ooo]Zo`1_o`02oookJP03o`3@ool0Kooo06oo01Gooo]Z0_oo0`02
oookJP03ool00?oonf[ooo]Z013ooo]Z00?ooa40oookJ_oonfX00_oonfX00ooo:`3ooo]ZoookJP07
oookJP03oolM0?oonf[ooo]Z01kooo]Z00?oo`00oookJ_oonfX01?oonfX00ooo003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z00Gooo]Z00?oo`P0oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0<
oookJP0000?ooo]Zo`000?oonfX03OoonfX3o`0003cooo]Z00?oo`H0oookJ_oonfX0?OoonfX2oolD
00[ooo]Z00?oo`@0oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP0WoookJP;ooe802?oonfX2oolL
00Cooo]Z00?o0000oookJ_ooM0000_oonfX00ol0d?ooo`<0o`3@o`03oookJP06ool60?oonf[o0=3o
oookJ_ood`3ooo]Z0oood`05oookJP05oonV0?l0d?oo0=3oo`3@oongo`001?oonfX2olWo00?ooo]Z
0_l0oh800ongo`3o0?n2o`3oE002oookJP03o`3oE?oonf[ooo]Z00;oc_l000?ooo]Zolko0?o>o`00
0ol000001?l0oi3ooo]ZoookJ_oonfX3o`1_o`06ool80?l02_oooo]Zo`0:oom/o`3ooi/01_l0oe@0
0ooonf[o00[oool00002ool00003oonK0?oonf[ooo]Z00Cooo]Z00?o03;ooookJ_oonfX00_oonfX3
olko0004oookJ_o>o`3oc_l0olko00Cooo]Z1?l0oi09oookJP06okOo0?oonf[o]ol0okOo0?oonf[o
B?l01?oonfX01_l0oa?oo`00o`3o4ol0oeCo0?lCo`3oE0;o0?lC0_l0oe@4oookJP06o`3@ooood`3o
0=3ooonC0?oonf[o0=3o1OoonfX01_l0Kooooo]Zoon60?oonf[o06ooo`3@o`?ooo]Z1?l0Kol2oook
JP03oomF0?oonf[ooo]Z01[ooo]Z00Goo`00oookJ_oonf[ooo]Zool0000CoookJP;ooad0=ooonfX0
0ooo0@3ooo]Zo`000006oookJP03ool80?oonf[ooo]Z02Kooo]Z00?oo`00oookJ_oonfX02OoonfX0
0ol0003ooo]ZoookJP0<oookJP0000?ooo]Zo`000?oonfX02_oonfX3o`0003oooo]Z00?oo`H0oook
J_oonfX02ooonfX2ool104gooo]Z0_oo0@0OoookJP;ooe804?oonfX01ol0003oog@0oookJ_l0d?oo
oo]Zo`3@oooonfX00_oo30001Ooonf[oo`H0oookJ_l0d?ooo`0000Koom<000?ooo]Zo`3@ool0d?l0
0_l0d?l2oookJP;o]ol01ooonfX2o`3oPP;o]ol000Kooo]Zo`3oP_l0oh;ooo]Zo`3oE?oonfX2olko
0003oookJ_l0003o000000;oc_l01?oonfX3o`1_o`03oookJ_o>o`3oc_l000;oc_l000?o00[oolko
0?o>o`002Oo>o`05o`3oE0Kooo]Z00Oo03;ooookJ_oonf[ooo]Zolko0?oonf[oc_l000;ooo]Z1?o>
o`02o`3oT0kooo]Z00Co]ol0oookJ_oonf[o]ol01_oonfX01?l0oa?o0?mDoookJ_l0oa<3o`3oE003
oookJ_l0oeCooo]Z00?o0=3o00?oo`40oooC0?ood`000_oonfX00ol0d?oooo]ZoookJP02oookJP06
o`1_ool0d?oooo]ZoolY0?ooQP3o0=3o2?oonfX01?l0KooooeH0oomF0?ooEP0^oookJP;oo`D01?oo
nfX00ooo7@3ooo]ZoookJP0]oookJP03ool00?oonf[ooo]Z00Gooo]Z00Coo`40oookJ_oonf[o0000
>_oonfX00ol0003ooo]ZoookJP0<oookJP0000?ooo]Zo`000?oonfX01ooonfX3o`0009?ooo]Z0_oo
5008oookJP;oo`401ooonfX00ooo003ooo]ZoookJP0GoookJP?ooe804?oonfX00oooM03o0=3ooook
JP02o`3@o`;ooo]Z00?oo``0oonC0?ooT`000_oonfX01_l0d?oooo]ZoooC0?ood`3oo`@0oooC00;o
0=3o00?ooo]Zool70?oonfX00_oonfX01?ngo`3ooo]ZoookJ_ngo`03oookJP?o0?n200Cooo]ZodSo
0?oonf[ooo]Z1?l0oh800ol0oeCoc_l0olko000>olko00Cooo]Z00?oK?l0oookJ_oonfX00_oonfX2
ofco0004oookJ_m/o`3oK?l0oookJP;oo`0000Co00[oool00?oo003ooi/01_l0oe@00ol0<_oooo]Z
oookJP02oookJP?oc_l000Gooo]Zolko0?l0oi3o06oooookJP02olko017ooo]Z00?oB?l0okOo0?oo
nfX00ooonfX2o`3oE003o`3o4ol0oeCo0?mD00;ooo]Z1?l0oe@01Ooo1@3oo`40ool10?ood`3ooo]Z
00;oom<000?ooo]Zo`3@oooonfX00_oonfX6o`1_o`03oon60?l0Kooo06oo00?o06oo1OoonfX01?oo
EP3o06ooo`1_ool0Kol8oookJP;ooe406OoonfX01Ooo0@3ooo]ZoookJ_oonf[oo`0000Cooo]Z00?o
o`D0oookJ_oonfX03_oonfX00ooo3`3ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o
o`00oookJ_oonfX01_oonfX00ooo103ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z00cooo]Z0000
0ooonf[o0000oookJP04oookJP?o0000EooonfX2ool500cooo]Z00?oo`00oookJ_oonfX0;ooonfX0
0ooo503ooo]ZoookJP04oookJP03ool[0?oonf[ooo]Z00oooo]Z0_oo0P0SoookJP06oomd0?oonf[o
0=3oo`3@oooonf[o0=3o0_oonfX00oooT`3ooo]ZoookJP02oookJP05o`3@oooonf[o0=3oo`3@oooo
d`000ooonfX2ool100;ooo]Z0_ngo`02oookJP;o]ol00_l0oh83oookJPGo0?n20_oonfX01?l0oh;o
0?mDo`000?oonfX6olko0003o`1_oooonf[ooo]Z00?ooo]Z00?o0?n@oookJ_oonfX00_oonfX3ofco
00Cooo]Z0om/o`02oookJP?oo`0000Co00[oool00?oonf[oo`800_oo1`03oookJP?o0?mD0ooonfX2
o`3oT005olko0?oonf[ooo]ZoookJ_l0Kol00_oonfX3olko00Kooo]Z1_n:o`001Ooonf[oB?l0oook
J_oonf[o]ol000;ooo]Z00Go0?mDo`3o4ol0oeCo0?mDo`3o4`04o`3@o`03o`3oE?oonf[o0?mD00;o
oo]Z0_ood`001_oonf[oom<0oookJ_ood`3ooo]Zo`3@o`;ooo]Z00?o06oooookJ_oo00000_l0d?l2
oookJP03o`1_oooonf[ooo]Z00;ooo]Z2ol0Kol6oookJP?ooe405ooonfX2ool101Sooo]Z0_oo3`0/
oookJP05ool00?oonf[ooo]ZoookJ_l000001?oonfX00ooo003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z00cooo]Z00001?l0003ooo]ZoookJ_oonfX3o`000:7ooo]Z00?oob/0oookJ_oonfX01_oo
nfX00ooo4@3ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z023ooo]Z0oooM002o`3@o`03o`000?oo
nf[ooo]Z00;ooi<01?oonfX3o`3@o`03oookJ_ooU`3ooo]Z00Kooo]Z00?o]ol0oookJ_oo0@000_ng
o`07o`3oPP05odSo0?oonf[ooo]ZoookJ_l0oh800_l000001?l0oh;ooo]ZoookJ_oonfX2o`1_o`Co
c_l01ooonfX00ol0oi3ooo]ZoookJP03oookJPSoK?l00ooonfX3ool00003o`0:oooonf[ooo]Z00Oo
oo]Z00Co03;ooookJ_l0oi3o0?n@1ooonfX00ol0Kooooo]ZoookJP02oookJP;oc_l01?oonfX00on:
o`3ooo]ZoookJP05oh[o00?ooo]Z00Co]ol0o`3oE?l0oeCo0?mD0ol0d?l3oookJP?o0?mD00?ooo]Z
o`3oE?oonfX00_oonfX3oooC00;ooo]Z00Oo0=3ooookJ_oonf[oo`80o`1_oooonf[o0=3o00?ooo]Z
00?o06oooookJ_oonfX01ooonfX01Ol0KooooeH0o`1_oooonf[o06oo00Oooo]Z0oooD@0VoookJP03
ool00?oonf[ooo]Z00;ooo]Z0_oo0@0EoookJP;ooaL08?oonfX00ol0003ooo]ZoookJP0CoookJP03
ool20?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX02ooonfX000Co0000HOoonfX2ool>00cooo]Z
00?oo`<0oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP0ToookJP;oob/02OoonfX00ooo4@3ooo]Z
oookJP0=oookJP03ool00?oonf[ooo]Z00Cooo]Z00?oo`<0oookJ_oonfX04OoonfX01OooM03ooo]Z
oomd0?ooM03o0=3o00;ooi<000Co0000oonC0?l0d?oooo]Z1?l0d?l2oookJP03o`3@oooonf[ooiL0
00Kooo]Z1Ongo`04o`3oPP?ooo]Z00WoB?l0o`000?l0003o0000ool30?l0oh;ooo]Zo`3oP_oonfX0
0ol0Kol4oookJP03olko0?oonf[ooo]Z00Oooo]Z00?o0?n@oookJ_oonfX01?oonfX00om/o`3ooo]Z
ofco0003ofco00Kooo]Z00?o00[ooookJ_oonfX02?oonfX01Ol0<_oooo]ZoookJ_oo103oo`L000Ko
oo]Z00Co06oooookJ_oonf[ooo]Z0_oo<P03olko0005oookJ_n:o`3oR_l0oookJ_n:o`000_oonfX3
oh[o00;ooo]Z00Co0?mDokOo0?l0oa?o0=3o1OoonfX01?l0oeCooo]Zo`3oE?oonfX2o`3oE0Cooo]Z
00?oom<0oookJ_oonfX00_oonfX01Ol0d?oooo]ZoookJ_l0Kooo0=3o00Cooo]Z00?o06oooookJ_oo
nfX00ooonfX02?oo003o06ooo`1_ool0Kooooo]ZoomF0?oonf[o06oo2?oonfX2oolT0003oookJ_oo
D@3ooo]Z03[ooo]Z00?oo`H0oookJ_oonfX00ooonfX2oolG027ooo]Z00?o0000oookJ_oonfX02?oo
nfX00ooo003ooo]ZoookJP07oookJP03ool20?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX02ooo
nfX000;o00008_oonfX2ool5083ooo]Z00?oob/0oookJ_oonfX03ooonfX00ooo<`3ooo]ZoookJP05
oookJP;oo`/01_oonfX00ooo003ooo]ZoookJP04oookJP03ool10?oonf[ooo]Z00_ooo]Z0oooM000
1?ooT`3ooo]ZoonC0?ooT`03o`3@o`Kooo]Z00?o0=3ooookJ_ooU`001OoonfX8okOo0003o`3oP_oo
N`3o0?n200Go0?n200Koo`<0o`3oP_oonf[o06ooo`3oP_l0KolBoookJP03o`3oT?oonf[ooo]Z00Co
oo]Z0_m/o`0:oookJP03o`0:oooonf[ooo]Z00Sooo]Z00?o03;ooookJ_oonfX02?oonfX01Ol0Kooo
oc80oolb0?oonf[ooc8000?ooo]Z0_o>o`02oh[o00;ooo]Z00GoB?l0oookJ_oonf[o0=3ooh[o0002
o`3@o`03o`3oE?ngo`3ooo]Z00Gooo]Z0_l0oe@3oookJP;o0?mD0ooonfX00oood`3ooo]ZoookJP02
oookJP03o`3@ooooYP3oojH000;oojH01OoonfX00ol0Kooooo]Zo`1_o`03o`1_o`Gooo]Z00?o06oo
oookJ_oonfX02?oonfX01?oo903ooo]ZoookJ_ooD@09oookJP;oocP08_oonfX00ooo003ooo]Zoook
JP03oookJP03ool00?oonf[ooo]Z00Cooo]Z00?oo`H0oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP0KoookJP03ool00?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX02ooonfX000;ooo]Z00?o0000
oookJ_oonfX0LooonfX00ooo3@3ooo]ZoookJP09oookJP03ool20?oonf[ooo]Z00Oooo]Z00?oo`00
oookJ_oonfX09_oonfX2oolc00Sooo]Z00?oo`/0oookJ_oonfX02ooonfX00ooo0@3ooo]ZoookJP02
oookJP;oo`@02?oonfX02OooM03ooo]ZoonC0?ooT`3o0=3ooonC0?oonf[o0000o`3@o`07oookJP03
o`3@ooooU`3ooo]Z00Gooo]Z00?onOl0oookJ_ngo`001?ngo`001Ol0003o0?n2o`3oP_oonf[oB?l0
00?ooo]Z1ol0oh82oolR0005oookJ_oo003ooo]ZoookJ_oo10002ooonfX00ol0oi3ooo]ZoookJP0@
oookJP03o`0:oooonf[ooo]Z00Sooo]Z00?o03;ooookJ_oonfX02OoonfX00ooo103ooo]ZoookJP03
oookJP07oh[o0?oonf[oc_l0oh[o0?o>o`3ooo]ZodSo0002o`3@o`07oookJ_n:o`3ooo]ZoookJ_l0
oa?o0?mDokOo0004oookJP03o`3oE?oonf[o0?mD00Cooo]Z00Co0?mDoookJ_oonf[oom<01OoonfX0
1?l0d?ooojH0o`3@oooonfX2oonV00?ooo]Z0_l0Kol3o`0bo`Kooo]Z00?o06oooookJ_oonfX00_oo
nfX01?oo003ooo]ZoookJ_oo0002oookJP03oolT0?oonf[ooo]Z00_ooo]Z0_oo>00ioookJP03ool2
0?oonf[ooo]Z00Cooo]Z00?oo`h0oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP03ool0
0?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0;oookJP000ooo
nfX00ol0003ooo]ZoookJP0boookJP03ool40?oonf[ooo]Z03gooo]Z00?oo`d0oookJ_oonfX0??oo
nfX2oolc00oooo]Z00?oocX0oookJ_oonfX01?oonfX2ool400Gooo]Z00?oo`00oookJ_oonfX00ooo
nfX01?oo0`3o0=3oo`3@ool0d?l4oonC00;ooo]Z00?o0=3ooookJ_oonfX01OoonfX01?l0d?oooiL0
oonG0?ooU`03oookJP03ooWo0?oonf[ooo]Z00;ooo]Z00Go0000okOo0?l0003ooo]ZodSo0002o`3o
PP09odSo0?l0Kooo06ooo`1_oooonf[o0?n2o`3o4ooonf[o0?n200;ooo]Z1_l0oh801?oo103ooo]Z
ool70?oo1`09oookJP03o`3oT?oonf[ooo]Z013ooo]Z00?o00[ooookJ_oonfX02?oonfX00ol0<_oo
oo]ZoookJP0>oookJP;oR_l000Cooo]Zoh[o0?l0d?ooc_l00ooonfX01?n:o`3ooo]ZoookJ_l0oa<2
oookJP08o`3oE?ngo`3ooo]ZoookJ_ooF03o0?mDoomH0?l0oe@4oookJP;o0?mD00?ooo]ZoooC0?oo
nfX01?oonfX3oonV0003oookJ_l0KoooojH000?o06oo00Gooo]Zo`0bool0Kooo03;ooookJP03o`0b
o`;ooo]Z00?o06oooookJ_oonfX05OoonfX01?oo2@3ooo]ZoookJ_oo>00boookJP03ool00?oonf[o
oo]Z00?ooo]Z00?oo`80oookJ_oonfX01OoonfX00ooo3P3ooo]ZoookJP0GoookJP03o`000?oonf[o
oo]Z03Cooo]Z00?o0000oookJ_oonfX02ooonfX000Cooo]Z0_l00023oookJP03ool<0?oonf[ooo]Z
00Sooo]Z00?oo`00oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP0FoookJP03oolc0?oonf[ooo]Z
00kooo]Z00?oocX0oookJ_oonfX04OoonfX4o`3@o`04o`1_ooooT`3o0=3oo`1_o`Co0=3o1_oonfX0
1OooU`3ooo]ZoonG0?oonf[ooiL000;onOl000?ooo]Zo`000?l000000_l00003oookJP03odSo0?l0
Kooo06oo00;o0?n200Ooog/0oookJ_ooN`3ooo]Zo`3oP_oonf[o0?n200Oooo]Z0_n:o`06o`3oPP;o
o`8000Oooo]Zool10?oonf[ooo]Zool50?oonf[o0?n@01;ooo]Z00?o00[ooookJ_oonfX02?oonfX0
0ol0<_oooo]ZoookJP0<oookJP0:o`3@oon:o`3oR_l0o`3@oon:o`3ooo]Zool50?n:o`3ooo]Zoh[o
00?ooo]Z00So0?lCoookJ_oonf[ooo]Zo`3oE?ngo`3ooeP0o`3oE0Oo0?n20ooonfX3ooWo00Gooo]Z
0oooYP002Ol0Kooooo]ZoookJ_oonf[o03;ooookJ_l0Kooooo]Zo`0bo`03oookJP03o`0bool0Kooo
oo]Z00oooo]Z00Goo`40oookJ_oonf[ooo]Zool00002oookJP;oo`T00_oonfX00ooo>03ooo]Zoook
JP09oookJP03oolM0?oonf[ooo]Z03cooo]Z00?oo`L0oookJ_oonfX03_oonfX00ol0003ooo]Zoook
JP0PoookJP03ool00?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX02ooonfX000Kooo]Z00?o0000
oookJ_oonfX0@OoonfX2ool303gooo]Z00?oo``0oookJ_oonfX0??oonfX00ooo>P3ooo]ZoookJP05
oookJP03oomZ0?oonf[ooo]Z00Cooo]Z00?oocL0oookJ_oonfX01?oonfX00ol0d?oo06ooo`1_o`02
oookJP04ool10?l0Kooooo]ZoookJPSo0=3o0oooU`001?oio`3o0000o`000?l00005oookJP?o06oo
00?ooo]ZodSo0?m8o`000ol0oh801OooN`3ooo]Zo`3oP_oonf[o0?n200Cooo]Z0on:o`06oookJP03
o`3@oooonf[o0?n200Go0?n200Coo`D0oookJ_oonf[o0?n@4_oonfX00ol02_oooo]ZoookJP08oook
JP03o`0boooonf[ooo]Z00Sooo]Z0ol0d?l3oookJP?oR_l00_oonfX01On:o`3ooo]ZoookJ_oonf[o
0?lC00Cooo]Z00Koo`80o`3oE?ngo`3o0?n2oookJ_l0oe@3o`3oPP0:o`3oE?l0oh;ooo]ZoookJ_oi
o`3oom<0ooWo0?oonf[onOl0oookJPCo06oo0_ooYP002Ol0Kooooo]ZoookJ_l0<_ooodd0oookJ_l0
Kooooo]Zo`0bo`03oookJP05o`1_oooonf[oogD0oome0?l0<_l08ooonfX2oolM02oooo]Z00?oo`00
oookJ_oonfX01?oonfX00ooo003ooo]ZoookJP05oookJP03ool70?oonf[ooo]Z00kooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0;oookJP001ooonfX00ol0003ooo]ZoookJP10oook
JP03ool30?oonf[ooo]Z04;ooo]Z00?ooad0oookJ_oonfX02?oonfX00ooo203ooo]ZoookJP06oook
JP03ool00?oonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX06?oonfX3oolj00Kooo]Z00?oofX0oook
J_oonfX01?oonfX00ooo=`3ooo]ZoookJP03oookJP?o06oo00Gooo]Zo`3@ool0d?oo0=3oo`1_o`03
oookJP04o`3@oooo103ooo]ZoookJP;onOl00_oonfX00oooU`3onOl0o`000005oookJP?o06oo0ooo
nfX01Om8o`3ooo]ZodSo0?m8o`3oog/000?o0?n20_oonfX00ol0oh;ooo]Zoh[o0002oh[o00[ooo]Z
00?o0=3ooookJ_oonfX01?oonfX6o`3oPP?obOl000?oo`<0oookJ_oo1@002ooonfX01Ol02_oooo]Z
oookJ_oonf[obOl000Kooo]Z00?o03;ooookJ_oonfX01?oonfX3o`3@o`Sooo]Z00GoR_l0oookJ_n:
o`3ooo]Zoh[o0002oookJP03o`3o4ooonf[ooo]Z00Cooo]Z00?o0?n2oookJ_oonfX00ol0oh802?oo
nf[o0?n2o`3oP_l0oh;onOl0oookJ_ood`3onOl00_l0Kol00ooio`3ooo]ZoookJP04oookJP05oonV
0?oonf[o03;ooookJ_ooC@000_oonfX01_l0Kooo03;ooookJ_oonf[o06oooookJP;oogD000?ooo]Z
oome0?l0<_l00_l0<_lHoookJP05ool00?oonf[ooo]ZoookJ_oo0@000ooonfX00ooo7@3ooo]Zoook
JP0=oookJP;oobP0@?oonfX00ol0003ooo]ZoookJP0WoookJP03ool00?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX02_oonfX000Sooo]Z00?o0000oookJ_oonfX0@ooonfX00ooo2@3ooo]ZoookJP0;
oookJP03ool20?oonf[ooo]Z02oooo]Z0_oo7@0:oookJP03ool80?oonf[ooo]Z03;ooo]Z00?oofX0
oookJ_oonfX01_oonfX2oolg00;ooo]Z00Go06oooookJ_l0Kooooo]ZoonK0003oookJP0:o`1_ool0
d?ooob80oookJ_l0d?oooo]Zo`000?oio`3o0=3oooWo00;o000000?onOl0ool20?oonfX00_oonfX2
o`1_o`;oR_l000?oB?l0oookJ_oonfX00_oonfX2odSo00;ooo]Z00CoB?l0oookJ_l0oh;o0?n20_n:
o`000ol0oh;oR_l0oookJP0=oookJP03o`3@oooonf[ooo]Z00?o03;o1OoonfX00ol0oi3o0?n2o`3o
PP05o`3oPP04olWo0?oo003oo`00ool000Oooo]Z00?o00[ooookJ_oonfX00_o9o`06oookJP03o`0b
oooonf[o0=3o00?o0=3o3?oonfX01_n:o`3ooo]ZoookJ_oonf[oR_l0o`3o4`Gooo]Z1Ol0oh800ol0
oeCooo]ZoookJP02o`3oPP06ool30?l0oh;onOl0o`1_ooood`3onOl00_oonfX2ooWo00Gooo]Z00?o
06oooonV0?l0<_l01Ol0<_l00ooonf[o03;oo`1_o`02oookJP?oogD01?oonfX2o`0bobWooo]Z00?o
o`/0oookJ_oonfX00_oonfX00ooo:03ooo]ZoookJP0^oookJP03ool00?oonf[ooo]Z00Gooo]Z00?o
o`<0oookJ_oonfX01_oonfX00ooo303o0000oookJP0coookJP03o`000?oonf[ooo]Z00[ooo]Z0009
oookJP;o0000@ooonfX00ooo2@3ooo]ZoookJP0;oookJP03ool20?oonf[ooo]Z02oooo]Z0_oo7@0@
oookJP03oolN0?oonf[ooo]Z00Kooo]Z00?oo`D0oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP05
oookJP03ool10?oonf[ooo]Z00oooo]Z0oooJP09oookJP04oolg0?oonf[ooo]ZoookJP;o06oo0_oo
nfX00oooV`3ooo]ZoookJP02oookJP09o`1_ool0d?oo0=3oo`3@oooonf[onOl0o`000?oio`3ooo]Z
00;onOl000?ooo]Zo`1_ool0Kol00_l0Kol01Ooonf[oR_l0oh[o0?n:o`3oB?l000Cooo]Z0_m8o`03
oookJP;oR_l000Co0?n2oookJ_oonf[o0?n23ooonfX3o`0bo`Wooo]Z00?o0?n@oookJ_oonfX01?oo
nfX6o`3oPP03olWo0?oo8P3oob8000?ooo]Z00?o00[ooookJ_o9o`000_o9o`04oookJP;o0=3o00?o
03;ooookJ_oonfX02_oonfX2oomk00Kooo]Z00?o0?lCoh[o0?oonfX00ooonfX3o`3oPP;ooo]Z00Co
0?mDoookJ_oonf[ooo]Z0_l0oh82o`1_o`06o`3oP_oio`3ooo]ZooWo0?oonf[onOl02?oonfX00ol0
<_ooojH0oookJP03oookJP03o`1_ool0<_oo03;o00Co03;o00?oogD0o`0bool0<_l00ol0<_l2oook
JP?o03;o7?oonfX00ooo003ooo]ZoookJP02oookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`/0oook
J_oonfX00ooonfX00ooo:03ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oook
J_oonfX02_oonfX000_ooo]Z00?o0000oookJ_oonfX0GooonfX00ooo0@3ooo]ZoookJP0`oookJP03
oolN0?oonf[ooo]Z00Oooo]Z00?oo`D0oookJ_oonfX07_oonfX00oooJP3ooo]ZoomZ000=oookJP?o
06oo00?ooo]ZoonK0?oonfX01?oonfX01ol0Kooooo]ZoolR0?oo8P3o0=3oooWo0?l000000_oio`00
0ol0KooonOl0o`1_o`03oookJP07ool90?n:o`3oR_l0oookJ_n:o`3oo`00odSo0002oookJP;oB?l0
00Cooo]Zoh[o0?n:o`3oR_l00_m8o`000ooonf[o0?n2o`3oPP0=oookJP?o03;o0_oonfX00ol0d?oo
oo]ZoookJP08oookJP03o`3oT?oonf[ooo]Z00?ooo]Z1Ooo00000ooonf[o0?n2o`3oPP04o`3oPP06
oookJ_l02_oobOl0olWo0?oonf[obOl00ol0d?l3oookJP03o`0boooonf[ooo]Z00Wooo]Z0oooN`05
oookJP03o`3o4on:o`3ooo]Z00;ooo]Z0_l0oh800ol0oeCooo]ZoookJP03oookJP03o`1_ool0oh;o
06oo00;o0?n200?ooo]Zo`3oP_oonfX00ooio`06oookJP06ool00?oonf[oo`00o`1_ool0<_ooojH0
1?oonfX00ol0Kooo03;ooookJP04oookJP03oome0?oonf[ooo]Z00;ooo]Z1_l0<_leoookJP;ooaP0
;?oonfX00ooo003ooo]ZoookJP06oookJP03ool10?oonf[o000000Kooo]Z0_oo1`0[oookJP03o`00
0?oonf[ooo]Z00[ooo]Z000<oookJP03o`000?oonf[ooo]Z057ooo]Z00?oo`P0oookJ_oonfX02_oo
nfX00ooo0@3ooo]ZoookJP0_oookJP;ooah06?oonfX00ooo0@3ooo]ZoookJP04oookJP;oo`001Ooo
nfX00ooo0P3ooo]ZoookJP02oookJP?oofX02ooonfX2o`1_o`04oookJ_l0Kooooo]ZoonK00Gooo]Z
00?o06oooookJ_oonfX00_oonfX3ooWo0004o`1_oooonf[onOl0ooWo00?ooo]Z00?oo`T0oh[o0?oo
nfX00_oonfX01?n:o`3oB?l0odSo0?oonfX3oh[o0004oookJ_m8o`3oB?l0o`3o4`?ooo]Z00?o0?n2
oookJ_oonfX01ooonfX4o`0bo`Kooo]Z00?o0=3ooookJ_oonfX02?oonfX00ol0oi3ooo]ZoookJP02
oookJPGoo`001ooonfX3o`3oPP05olWo0?l0d?oo0=3oolWo0?oo10001OoonfX00ol0<_oooo]Zoook
JP05oookJPKoog/01?oonfX01_l0oa?ooo]ZoookJ_n:o`3ooo]Zo`3oPP;ooo]Z00?o0?mDoookJ_oo
nfX00ol0Kol01Ooonf[o0?n2oonG0?l0oh;ooiL000;o0?n20_oonfX00ooio`3ooo]ZoookJP08oook
JP03o`1_ool0<_oooo]Z00?ooo]Z00Co06oooookJ_oonf[o03;o0_oonfX2oolA0003oome0?oonf[o
oo]Z00;ooo]Z1?l0<_l4oookJP03oolj0?oonf[ooo]Z02Gooo]Z00?oo`00oookJ_oonfX00_oonfX2
ool300Cooo]Z00?ooaP0oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[o
oo]Z00[ooo]Z000=oookJP;o0000KooonfX00ooo003ooo]ZoookJP0_oookJP03oolM0?oonf[ooo]Z
01[ooo]Z00?oofX0oookJ_oonfX02OoonfX2o`1_o`;ooo]Z00?o06oooonK0?oonfX01_oonfX01?l0
Kooooo]Zo`1_ool0Kol5ooWo0003oooC0?oonf[ooo]Z00;ooo]Z0_n:o`03oookJPCoR_l000?oB?l0
oookJ_m8o`000_m8o`000ooo003o0?lCoookJP02ool100;ooo]Z00?oo`@0oookJ_oonfX00_oonfX3
o`0bo`_ooo]Z00?o0=3ooookJ_oonfX02?oonfX00ol0oi3ooo]ZoookJP02oookJP?oo`0000?o0?n@
oookJ_oonfX01_oonfX2olWo0003o`0:ooo9o`3obOl000;obOl01_oonfX01?l0<_oooo]ZoookJ_oo
nfX3oomk00?ooo]Z0_ooN`05oookJP08o`3o4ooonf[ooo]ZoookJ_n:o`3ooo]Zo`3oP_l0oe@3o`1_
o`?ooo]Z00?o0?n2oonG0?l0oh800_ooU`001Ooonf[o0?n2o`3oP_oonf[onOl000_ooo]Z00Wo03;o
oookJ_oonf[ooo]Zo`1_oooonf[oo`40oookJ_l0<_l00_oonfX2oolA0003oome0?l0<_oo03;o00;o
03;o0_oonfX00ol0<_oooo]ZoookJP02oookJP;oocX0?OoonfX00ooo303ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX01_oonfX2ool302;ooo]Z00?o0000oookJ_oo
nfX02_oonfX000oooo]Z00?o0000oookJ_oonfX0H?oonfX00ooo1`3ooo]ZoookJP0koookJP;ooad0
5_oonfX00ooo003ooo]ZoookJP03oookJP03ool00?oonf[ooo]Z00?ooo]Z00Coo`80oookJ_oonf[o
oo]Z0_l0Kol2oookJP?ooi/01_oonfX3o`1_o`;ooo]Z1?oio`000ooonf[oom<0oookJP02oookJP03
oh[o0?oonf[ooo]Z00CoR_l000?ooo]ZodSo0?m8o`000om8o`02oookJP03o`3o4ooonf[ooo]Z00Ko
oo]Z0ol0<_l7oookJP03ool40?oonf[ooo]Z00Gooo]Z00?o0=3ooookJ_oonfX02?oonfX02?l0oi3o
oo]ZoookJ_oonf[o0?n@oookJ_l0oi3ooo]Z0_l0oi06oookJP?obOl000?o00[oolWo0?oonfX02?oo
nfX00ol0<_ooog/0oomk000<oookJP03o`3o4ooonf[ooo]Z00;ooo]Z00Co06oooh[o0?l0oeCo0?n2
1_oonfX00ol0oh;ooiL0o`3oPP02oonG00;ooo]Z00?o0?n2oookJ_oio`002ooonfX01?l0Kooo03;o
oookJ_l0Kol4oookJP03o`0boooonf[ooo]Z00?o03;o1OoonfX00ol0<_oooo]ZoookJP03oookJP;o
ocX03?oonfX2oom;02;ooo]Z00?oo`00oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP04oookJP03
ool<0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0:oookJP00
4?oonfX00ol0003ooo]ZoookJP1koookJP03ool00?oonf[ooo]Z02Kooo]Z00?oodD0oookJ_oonfX0
1_oonfX2oolG01Gooo]Z0_l0Kol2oookJP04oonK0?oonf[ooi/0oonK00;ooo]Z1?l0Kol2oookJP05
o`1_oooonf[ooo]ZoookJ_l000000ooonfX00oood`3ooo]ZoookJP05oh[o00?ooo]Z00?oR_l0oook
J_m8o`000_m8o`001?oob@3ooo]ZoookJ_l0oa<4oookJPCo03;o0_ooF002oookJP05ool00?oonf[o
oo]Zool20?oonfX00_oo1008oookJP03o`3@oooonf[ooo]Z00Sooo]Z00?o0?n@oookJ_l0oi000_oo
nfX01?l0oi3ooo]ZoookJ_oonfX2o`3oT0Gooo]Z00CobOl0oookJ_oonf[o00[o2_oonfX00ol0<_oo
oo]ZoookJP09oookJP04ool20?l0oa?ooo]ZoookJP?o06oo0_oonfX00on:o`3ooo]Zo`3oPP04oook
JP05o`3oP_ooU`3ooo]Zo`3oP_ooU`000ooonfX2o`3oPP03ooWo0?oonf[ooo]Z00Wooo]Z00?o06oo
o`0bool0Kol01?oonfX01?l0<_oo00[oo`0:ool0<_l7oookJP05o`0boooo003ooo]ZoookJ_oo0P00
0_oonfX00ooo>P3ooo]ZoookJP0:oookJP;ood/0@OoonfX00ooo503ooo]ZoookJP0MoookJP03o`00
0?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX01ooonfX00ooo0@3ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z00[ooo]Z000AoookJP03o`000?oonf[ooo]Z06?ooo]Z00?ooa<0oookJ_oonfX02Ooo
nfX00ooo103ooo]ZoookJP0aoookJP03oom50?oonf[ooo]Z00Kooo]Z0_oo5`0=oookJP03ool<0?oo
nf[ooo]Z00Cooo]Z00?oo`00o`1_oooonfX00_oonfX5oonK0003o`1_oooo0`3ooo]Z00Cooo]Z00Go
06oooookJ_oonf[ooo]Zo`000003oookJP03oooC0?oonf[oR_l000WoR_l01OoonfX01?oob@3o0?lC
oookJ_oonfX3o`0bo`03o`3oE?oonf[ooo]Z00?ooo]Z1?ooF00=oookJP03ool30?l0d?oooo]Z00Wo
oo]Z00?o0?n@oookJ_oonfX00_oonfX00ol0oi3ooo]ZoookJP02oookJP03o`3oT?oonf[ooo]Z00Ko
oo]Z00?o00[ooookJ_oonfX04ooonfX01?oo303o0?lCo`1_ool0Kol4oookJP05o`3oE?oonf[oR_l0
oookJ_l0oh800_oonfX01?l0oh;ooo]ZoookJ_l0oh84oookJP03o`3oP_oonf[ooo]Z00;oc_l02ooo
nfX00ol0Kooo03;ooookJP03o`0bo`;o00[o00Co03;oo`0:ool02_oo00[o1?oonfX00ol0<_oooo]Z
oookJP09oookJP03ool00?oonf[ooo]Z00Cooo]Z0_oo50000ooonf[ood/0oookJP0boookJP03ool0
0?oonf[ooo]Z00?ooo]Z00?oo`@0oookJ_oonfX01OoonfX00ooo503ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX02OoonfX001;ooo]Z0_l0000RoookJP03ool70?oo
nf[ooo]Z03gooo]Z0_oo4`0KoookJP03ool20?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX05_oo
nfX00oooA@3ooo]ZoookJP0>oookJP03oomB0?oonf[ooo]Z00Gooo]Z00?oo``0oookJ_oonfX01?oo
nfX00ol0Kooooo]ZoookJP02oookJP05o`1_ooooV`3ooi/0oonK0?l0Kol01ooonfX02Ol0Koooo`80
oookJ_oonf[o0000oookJ_oo103ooo]ZoooC0004oookJPGoR_l02?oonfX3o`0bo`?ooo]Z00?o0?mD
oookJ_oonfX01_oonfX2oomH00Kooo]Z0ooo3P001_oo003ooo]ZoookJ_oo0`3ooo]Zo`3@o`Sooo]Z
00?o0?n@oookJ_l0oi000ooonfX00ol0oi3ooo]ZoookJP03oookJP03o`3oT?oonf[ooo]Z00Kooo]Z
00?o00[ooookJ_oonfX03ooonfX3o`1_o`03o`3o4ooonf[ooo]Z00Gooo]Z00So0?mDoookJ_oonf[o
R_l0ool00?l0oh;ooiL0o`3oPP;ooo]Z00Go0?n2oookJ_oonf[ooo]Zo`3oPP02oookJP;oc_l000?o
oo]Zolko0?o>o`002?oonfX3o`0bo`04oomd0?oonf[ooo]Zo`0:o`;ooo]Z00?o00[ooookJ_oonfX0
0_ooT`02o`0:o`03o`0boooonf[ooo]Z00[ooo]Z00Coo`00oookJ_oonf[oo`000ooonfX2oolD00;o
oo]Z00?ood/0oookJ_oonfX02?oonfX00ooo;03ooo]ZoookJP0^oookJP03ool00?oonf[ooo]Z00;o
oo]Z00?ooa@0oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0IoookJP03ool00?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX02OoonfX001Cooo]Z00?o0000oookJ_oonfX07ooonfX00ooo1`3ooo]Z
oookJP1?oookJP03oolB0?oonf[ooo]Z00Sooo]Z00?oo`80oookJ_oonfX07ooonfX3oom500oooo]Z
00?ooe80oookJ_oonfX02ooonfX00ol0Kooooo]ZoookJP03o`1_o`05oookJ_l0<_oooi/0o`0bool0
Kol00ooonfX00ooo003ooo]ZoookJP02oookJP04o`1_oooonf[ooo]Zo`0000?ooo]Z0oood`02olko
00?ooo]Z00?oR_l0oookJ_oonfX01?oonfX3o`0bo`03oookJ_oob@3ooo]Z00;ooo]Z00?o0?mDoook
J_oonfX01ooonfX3oomH00;ooo]Z00Go06oooookJ_oonf[ooo]Zool>0007oookJP03o`3@oooonf[o
oo]Z00?ooo]Z00?oo`40o`3oT?oo0`000_oonfX01Ol0oi3ooo]ZoookJ_oonf[o0?n@00Cooo]Z00?o
0?n@oookJ_oonfX01ooonfX00ol02_oooo]ZoookJP0;oookJP?o06oo2_oonfX02?l0oeCooo]Zoook
J_oonf[oo`00oh[o0?ooU`3o0?n20ooonfX01?l0oh;ooo]Zo`3oP_l0oh82oookJP03olko0?oonf[o
c_l000?ooo]Z00Coc_l0oookJ_oonf[ooo]Z1?l0<_l00ooonf[oog@0o`0bo`02oomd0006o`0:oooo
nf[ooo]ZoookJ_l02_oo03;o0_ooT`000ooonf[ooi<0o`0bo`03o`0:oaGooo]Z00?ood/0oookJ_oo
00002?oonfX2ool/03Kooo]Z00?oo`40oookJ_oonfX01OoonfX00ooo2`3ooo]ZoookJP0FoookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX02OoonfX001Gooo]Z00?o0000oookJ_oonfX0
<OoonfX00ooo1@3ooo]ZoookJP0loookJP03oolB0?oonf[ooo]Z01Oooo]Z0_oo0007oookJP03ool0
0?oonf[ooo]Z00Sooo]Z00?oodD0oookJ_oonfX03_oonfX00oooDP3ooo]ZoookJP0:oookJPCo06oo
0_oonfX3o`0bo`;ooo]Z00?o06oooookJ_oonfX01_oonfX01?l0Kooooo]ZoookJ_l00002oookJP06
oooC0?oonf[oom<0olko0?ood`3ooo]Z0_oo0`04oookJPCo03;o0_oonfX01ol0oa?ooo]ZoookJ_oo
b@3ooo]Zooo90?l0oe@03ooonfX00ol0Kooooo]ZoookJP09oookJP06o`3@oooonf[ooo]Zool00?oo
nf[o0?n@1OoonfX01?l0oi3ooo]ZoookJ_l0oi03oookJP;o0?n@2_oonfX00ol02_oooo]ZoookJP07
oookJP?o06oo2?oonfX2ooo900?ooo]Z00?o0?mDoookJ_oonfX00ooonfX00on:o`3o0?n2o`3oPP02
oookJP;o0?n20_oonfX01Ooo0@3oc_l0oookJ_oo703oc_l000?ooo]Z0_o>o`02o`0bo`Kooo]Z00?o
og@0o`0bool02_l01?oonfX01ol02_oooi<0oonC0?ooT`3ooo]Zo`0booooT`000ooonfX2o`0:oaWo
oo]Z0_oo1@03oookJP03ool/0?oonf[ooo]Z03gooo]Z00?oo`/0oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0PoookJP03ool00?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX02OoonfX001Kooo]Z
0_l00021oookJP03ool?0?oonf[ooo]Z01gooo]Z00?oo`00oookJ_oonfX02_oonfX3oomB00[ooo]Z
1_l0Kol00ol0<_oo06ooo`0bo`03o`1_o`03o`0bool0Kooooo]Z00Kooo]Z00Ko06oooookJ_oonf[o
o`00oookJ_ood`02oookJP04olko0?oonf[ooo]ZoooC00?ooo]Z0ol0<_l2oookJP;o0?lC0_oonfX0
2?l0oa?ooo]ZoookJ_oonf[oolT0o`3oE?oonf[oolT03ooonfX00ol0Kooooo]ZoookJP04oookJP?o
00[o0_oonfX4odSo00Gooo]Z0ooo00001?oonf[o0?n@oookJ_oonfX2o`3oT003oookJ_ooF03ooeP0
00Wooo]Z00?o00[oodSo0?m8o`000ooonfX3o`1_o`[ooo]Z1?oob@000ooonf[o0?mDoookJP05oook
JP03o`3oP_oonf[ooo]Z00?o0?n20ooonfX2olko0003oooC0?oonf[oc_l000;o03;o00?oc_l0o`0b
oooonfX02?oonfX00oooM03o00[oo`0:o`06o`0:o`04oookJ_ooT`3ooi<0oonC00Kooo]Z0ol02_lK
oookJP03ool/0?oo003ooo]Z03kooo]Z00?oo`00oookJ_oonfX01OoonfX2ool500oooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP09oookJP006?oonfX00ol0003ooo]ZoookJP10oook
JP03ool40?oonf[ooo]Z03_ooo]Z00?oo`l0oookJ_oonfX05OoonfX2ool000Kooo]Z00?oo`00oook
J_oonfX02ooonfX00oooDP3ooo]ZoookJP0;oookJP?o06oo00?o03;ooookJ_l0<_l01?oonfX00ooo
_@3o06ooo`1_o`08o`1_o`;oc_l00_oonfX01_ood`3oc_l0oooC0?oonf[oom<0oookJP?o03;o1?oo
nfX01Ol0oa?ooo]Zo`3o4ooonf[o0?lC00;oo`<000Cooo]Zooo90?oonf[o0?mD0_oob@0@oookJP03
o`1_oooonf[ooo]Z00?o00[o1_oonfX00ol0d?oo0?n@o`3oT004odSo00Goo`000_ooF0000ol0oi3o
oeP0oomH0004oomH00Wooo]Z00?o00[oo`1_ool0Kol00_l0Kol=oookJPCoolT000?o0?mDoookJ_oo
nfX01?oonfX00ol0oh;ooo]ZoookJP02oookJP0<o`3oP_oonf[ooo]ZoookJ_ood`3ooo]ZoooC0?o>
o`3o03;oolko0?oonf[oc_l01OoonfX00ooo003ooo]ZoookJP02oookJP03oomd0?oonf[o00[o00Ko
oo]Z0ol02_l00oooT`3o00[oo`0:o`06o`0:o`;ooo]Z0ol02_lNoookJP03ool10?oonf[ooo]Z00;o
oo]Z0_oo500moookJP03ool00?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003o
oo]ZoookJP09oookJP006OoonfX00ol0003ooo]ZoookJP23oookJP03ool[0?oonf[ooo]Z00Oooo]Z
00?oo`/0oookJ_oonfX06ooonfX00ooo003ooo]ZoookJP0=oookJP03o`0bool0Kooo03;o00Gooo]Z
00?ookd0o`1_oooonfX01OoonfX01Ol0Koooc_l0olko0?oonf[oc_l000;ooo]Z00?oc_l0oooC0?l0
<_l00ol0<_l2oolL00?ooo]Z0_l0oa<2oookJP?o0?lC0_oonfX2ooo90004o`3oE?oob@3oolT0ooo9
013ooo]Z0ol02_l:oookJP03o`3@oooonf[o0?n@00?o0?n@1Ooo0004odSo0003o`3oT?oonf[ooeP0
00Kooo]Z00?oo`00ool20?oonfX00ol0Kol00ol02_ooB?l0odSo000=oookJPGoolT000?o0?mDoook
J_oonfX01?oonfX00ol0oh;ooo]ZoookJP05oookJPCo03;o00Coom<0olko0?o>o`3oc_l02?oonfX0
1ooo0`3ooo]ZoookJ_ooM03ooo]Zo`0:ool0<_l01OoonfX01?l02_oo03;ooookJ_ooT`08oookJPKo
00[o8_oonfX00ooo503ooo]ZoookJP02oookJP03ool00?oonf[ooo]Z00Sooo]Z0_oo8P0eoookJP03
ool20?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP09oookJP00
6_oonfX00ol0003ooo]ZoookJP1?oookJP03ool20?oonf[ooo]Z033ooo]Z00?oob/0oookJ_oonfX0
7_oonfX00ooo003ooo]ZoookJP0AoookJP03ool10?oonf[ooo]Z00;o03;o00WooeH0o`1_ool0Kooo
06oooookJ_oo_@3ooo]Zo`0bool0Kol00ooonfX2o`1_o`05olko0?oo@03ood00olko0?l000000_o>
o`02o`0bo`03oooC0?oonf[ooo]Z00;ooo]Z0_oo7002o`3o4`?ooo]Z00Co0?lCoookJ_l0oa?o0?lC
1?oonfX01_l0oeCoolT0ooo90?oob@3ooo]Zool200[ooo]Z1?l02_l2oookJP03o`1_oooonf[ooo]Z
00Wooo]Z00Go0=3ooookJ_l0oi3o0?n@oookJP05ool000?o0?n@00?ooo]ZodSo0?m8o`001Om8o`00
0ooonf[oo`T0o`1_o`02o`1_o`06oookJ_m8o`3ooo]ZoookJ_l02_oooo]Z0_m8o`07oookJPCoolT0
0_oonfX2ooo90003o`3oE?oonf[ooo]Z00Cooo]Z00?o0?n2oookJ_oonfX00ooonfX3o`0bo`04oook
J_ood`3oom<0oookJP;oom<000?oc_l0oookJ_oonfX02OoonfX01OooM03ooo]ZoookJ_oonf[o00[o
00;ooo]Z00Ooo`00oookJ_oo003o03;oo`0:oooo903ooi<000Sooo]Z1Ol02_l00oooDP3ooo]Zoook
JP0ZoookJP03ool70?oonf[ooo]Z00?ooo]Z0_oo8P0ooookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX02?oonfX001_ooo]Z0_l00012oookJP03ool=0?oonf[ooo]Z01_ooo]Z00?oo`40
oookJ_oonfX07_oonfX2ool[00oooo]Z00?oob`0oookJ_oonfX01_oonfX00ooo1@3ooo]ZoookJP0C
oookJP03ool00?oonf[ooo]Z00?ooo]Z00?oo`40oookJ_l0<_l00_l0<_l4oookJP05o`1_oooo_@3o
oo]ZoookJ_l0Kol00_oonfX01?l0Kooooo]ZoookJ_o>o`02oom000;oc_l000?o03;oolko0?oio`00
1_oonfX00ooo703o0?lCoookJP04oookJP05o`3o4ooonf[o0?lCoookJ_l0oa<00_oo1P000ol0oeCo
oo]ZoookJP0;oookJP?o00[o0_oo0P05oookJP03o`1_oooonf[ooo]Z00Wooo]Z00?o0=3ooookJ_oo
nfX00_l0oi03ool000Go0?n@1ooonfX2o`1_o`GoB?l00_oonfX00om8o`3o00[ooookJP02odSo0003
ool00?oonf[ooo]Z00?oolT01_oonfX00ooob@3ooo]Zo`3oE006oookJP03o`3oP_oonf[o03;o00?o
03;o0ooonfX3oooC0004oookJ_ood`3oom<0olko00oooo]Z00?o00[oo`0boooonfX00_oonfX01_l0
<_oooo]Zo`0:oooonf[oob@0oonC00?ooo]Z1?l02_l2oookJP;o00[o0oooDP0_oookJP03ool00?oo
nf[oob8003oooo]Z00?oo`00oookJ_l00000:ooonfX00ol0003ooo]ZoookJP08oookJP007OoonfX0
0ol0003ooo]ZoookJP1AoookJP03ool;0?oonf[ooo]Z00Wooo]Z00?oo`40oookJ_oonfX07ooonfX0
0ooo:`3ooo]ZoookJP0=oookJP03ool/0?oonf[ooo]Z01Gooo]Z00?oo`40oookJ_oonfX02ooonfX2
o`0bo`03oookJ_l0<_oooo]Z00Cooo]Z00Kookd0o`1_ool0Kooo06oooookJ_l0Kol3oookJPCoc_l0
0ooonfX00oo>o`3ooo]ZoookJP04oookJP03o`3o4ooonf[ooo]Z00Cooo]Z0_l0oa<01_o`o`3ooo]Z
oookJ_l0oa?ooo]Zo`3oE0[ooo]Z0ol02_l00ooonf[oo`00oookJP08oookJP03o`1_oooonf[ooo]Z
00Wooo]Z00So0=3ooookJ_oonf[ooo]Zo`3oT?oonf[o0?n@oookJPCo0?n@3OoonfX5odSo0003o`0:
oom8o`3oo`0000?oolT02?oonfX00ooo0@3ooo]Zo`3oE006oookJP03o`3oP_l0<_oo03;o00Kooo]Z
00Goom<0oookJ_oonf[ooo]ZoooC0002oookJP03olko0?oonf[ooo]Z00gooo]Z00Go00[oo`0boooo
nf[ooo]Zo`0bo`03oookJP03o`0:oooonf[ooi<000?o00[o00?ooo]Zool00?oonfX00_oonfX2o`0:
o`;ooo]Z00?ooe80oookJ_oonfX0=?oonfX00ooo0P3ooo]ZoookJP04oookJP03oolB0?oonf[ooo]Z
03Gooo]Z00?o0000oookJ_oonfX00_oonfX00ooo003ooo]Zool5000SoookJP03o`000?oonf[ooo]Z
00Sooo]Z000NoookJP03o`000?oonf[ooo]Z053ooo]Z00?oo`/0oookJ_oonfX06?oonfX2ool0027o
oo]Z0_oo;00>oookJP03oolV0?oonf[ooo]Z01;ooo]Z0_l0<_l2oookJP06o`0boooonf[ooo]Zool0
0?oonf[ookd00ooonfX00ol0<_oo06ooo`0bo`03o`0bo`05oookJ_o>o`3oc_l0o`000?oonfX01?o>
o`05oookJP;o0?lC1?oonfX01Ol0oa?ooo]Zo`3o4ooonf[ol?l000;ooo]Z00?o0?lCoookJ_oonfX0
1OoonfX4o`0:o`;oo`003OoonfX00ol0Koooo`40oookJP09oookJP04o`3@oooonf[ooo]ZoookJP?o
0?n@4OoonfX00om8o`3ooo]ZodSo0003oookJP04o`0:oooob@3oB?l0odSo00Sooo]Z00Coo`40ool0
0?l0oeCoob800_oonfX4o`0bo`03o`3oP_oonf[ooo]Z00Gooo]Z00?oom<0oookJ_oonfX01OoonfX0
0oo>o`3ooo]ZoookJP0=oookJP04oonK0?l02_oooo]Zo`0bo`?ooo]Z1?l02_l7oookJP;o00[o0_oo
nfX00oooDP3ooo]ZoookJP0loookJP03oolB0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX02ooo
nfX2ool201[ooo]Z00?o0000oookJ_oonfX02?oonfX001oooo]Z0_l0001QoookJP03ool80?oonf[o
oo]Z02_ooo]Z00?oob`0oookJ_oonfX03?oonfX2oolV01;ooo]Z0_l0<_l01_oo003ooo]ZoookJ_oo
nf[o03;ooookJP?ookd00_oonfX3o`0bo`Gooo]Z1_o>o`000ooonf[onOl0oookJP05oookJP;o0?lC
0ooonfX2o`3o4`?ooo]Z00Col?l0oookJ_l0oa?o0?lC0ooonfX3o`0:o`03oookJ_ooU`3ooiL000ko
oo]Z00Coo`00oookJ_oonf[o06oo2ooonfX00ol0d?oooo]ZoookJP06oookJP;o0=3o2ooonfX00om8
o`3ooo]ZoookJP06odSo00_ooo]Z00?oob80o`3oE?l0<_l00_l0<_l3oookJP03o`3oP_oonf[ooo]Z
00Cooo]Z0_ood`08oookJP03olko0?oonf[ooo]Z00cooo]Z0_ooV`000ol02_oo03;oo`0:o`03o`0:
o`03oookJ_l02_oooo]Z00Oooo]Z0_l02_l3oookJP04oomB0?oonf[ooo]Zool000Oooo]Z0_oo8`0e
oookJP03ool00?oonf[ooo]Z00?ooo]Z0_oo200^oookJP03o`000?oonf[ooo]Z00_ooo]Z00?oo`80
oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP08oookJP008OoonfX00ol0003ooo]ZoookJP1Noook
JP03ool80?oonf[ooo]Z01Oooo]Z00?oo`00oookJ_oonfX08OoonfX2oolV00cooo]Z0_oo6@02oook
JP;o03;o1OoonfX01?l0<_oookd0oookJ_oo_@03o`0bo`;ooo]Z00?o03;oool00?oonfX00ooonfX0
1?oo0@3ooo]Zo`000?o>o`03oookJP03ooWo0?oonf[ooo]Z00Gooo]Z0_l0oa<2oookJP;o0?lC0ooo
nfX2o`3o4`;ooo]Z0ol02_l00ol0oh;ooo]ZoookJP03oookJP?ooiL02?oonfX4oolY00?ooo]Z00?o
06oooookJ_oonfX01ooonfX00ooo0P3ooo]Zo`3@o`07oookJP03o`3@oooonf[o0=3o00[ooo]Z1?m8
o`000ooonf[oB?l0odSo000;oookJP;o03;o00?o0?mDo`0boooonfX01?oonfX01Ol0oh;ooo]Zoook
J_oonf[oo`0000;ooo]Z00?oom<0oookJ_oonfX02?oonfX00oo>o`3ooo]ZoookJP0;oookJP;ooi/0
0_l02_l00oooV`3ooo]ZoookJP04oookJP03o`0:oooonf[ooo]Z00Cooo]Z0_l02_l;oookJP03ool1
0?oonf[ooo]Z00;ooo]Z00?oob<0oookJ_oonfX02ooonfX00ooo>`3ooo]ZoookJP0[oookJP04ool8
0?oonf[oo`00ool002gooo]Z00?o0000oookJ_oonfX04_oonfX2ool101;ooo]Z00?o0000oookJ_oo
nfX02?oonfX002;ooo]Z00?o0000oookJ_oonfX0KOoonfX00ooo1@3ooo]ZoookJP0FoookJP03ool0
0?oonf[ooo]Z01Wooo]Z00?oofX0oookJ_oonfX01OoonfX2oolI0003oookJ_l0<_oooo]Z00Gooo]Z
0_oo_@000ol02_oookd0oonm0004oookJP03o`0boooonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
0_oonfX00ooio`3ooo]ZoookJP02oookJP;oo`400_oonfX2o`3o4`03oookJ_l0oa?ooo]Z00Co0?lC
0ol02_l3oookJP03o`3oP_oonf[ooo]Z00Kooo]Z0oooU`000ooonf[ooiL0oonG0005oookJP;oobT0
0ooonfX00ol0Kooooo]ZoookJP04oookJP03ool00?oonf[ooo]Z00;ooo]Z00?o0=3ooookJ_oonfX0
0ooonfX01?l0d?oooo]Zo`3@oooonfX2o`3@o`Wooo]Z1?m8o`09oookJPCo03;o1ooonfX2oo3o0004
o`3oP_o`o`3ooo]ZoookJP;oo`@000?oom<0oookJ_oonfX01_oonfX01_oo003ooo]ZoookJ_o>o`3o
oo]Zoolg00Wooo]Z0ol02_l3oonK0003o`0:oooonf[ooo]Z00Cooo]Z00?o00[ooookJ_oonfX00ooo
nfX2o`0:oa3ooo]Z00?oob<0oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP05oookJP?ooc/0=_oo
nfX00ooo0`3ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX02?oo
nfX002?ooo]Z00?o0000oookJ_oonfX0HOoonfX00ooo6P3ooo]ZoookJP0HoookJP03ool20?oonf[o
oo]Z02;ooo]Z00?oofX0oookJ_oonfX01ooonfX00ol0<_oooo]ZoookJP02oookJP?o03;o00?o00[o
oonm0?oo_@000ooo_@04oookJP03o`0boooonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00_oonfX0
0ooio`3oo`00oookJP07oookJPCo0?lC1?l02_l00ooo0P3ooo]Zoo3o0002oookJP03o`3oP_oonf[o
oo]Z00[ooo]Z0oooU`000ol0<_oooo]ZoookJP08oookJP05o`1_oooonf[ooo]ZoookJ_oo1P001ooo
nfX02?l0d?oooo]ZoookJ_oonf[o0=3ooookJ_oo003o0=3o0ooonfX00ol0d?oooo]ZoookJP07oook
JP03odSo0?oonf[ooo]Z00Kooo]Z0ol0<_l:oookJP;ol?l000?o0?n2oo3o0?o`o`000_o`o`000ooo
nf[oom<0oookJP09oookJP;onOl000?oc_l0ooWo0?oio`001_oonfX3o`0:o`?ooo]Z0_ooV`000ooo
nf[o00[ooookJP05oookJP03o`0:oooonf[ooo]Z00;ooo]Z0_l02_lKoookJP;oo`/00ooonfX00ooo
>`3ooo]ZoookJP0moookJP03ool@0?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX06OoonfX00ooo
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Sooo]Z000ToookJP;o00008OoonfX2ool803ko
oo]Z0_oo6P0IoookJP03ool20?oonf[ooo]Z01Cooo]Z00?oo`00oookJ_oonfX02ooonfX00oooJP3o
oo]ZoookJP06oookJP03o`0boooonf[ooo]Z00?o03;o00GoogD0o`0:ool02_oo00[oo`0bo`02oonm
00Kooo]Z00?o03;ooookJ_oonfX01?oonfX00ol0003oo`80oookJP02oookJP;onOl02OoonfX3o`0:
o`04o`3o4ooonf[ooo]Zo`3oE0?ooo]Z00?ol?l0oookJ_l0oh803?oonfX4oonG0003o`0boooonf[o
oo]Z00Sooo]Z1?l0oa<8oookJP05o`3@oooonf[o0=3ooookJ_oo00000_oonfX01?l0d?oooo]Zoook
J_oonfX2o`3@o`?ooiL02OoonfX4o`0bo`gooo]Z0_o`o`000ol0oh;ol?l0oookJP02oo3o00[ooo]Z
1?oio`000oo>o`3ooo]ZooWo0002oookJPCo00[o1OoonfX01OooV`3ooo]ZoookJ_oonf[o00[o00Oo
oo]Z00?o00[ooookJ_oonfX00_l02_lQoookJP03oolk0?oo003ooo]Z03kooo]Z00?oo`40oookJ_oo
nfX07OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z00Oooo]Z000VoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?oo`P0oookJ_oonfX0COoonfX00ooo603ooo]ZoookJP0FoookJP03ool0
0?oonf[ooo]Z01;ooo]Z0_ooJP07oookJPCo03;o0_oonfX2o`0:o`06oome0?l02_oooo]Zo`0boooo
nf[o00[o1ooonfX00ol0<_ooof<0oookJP03oookJP04o`000?oonf[ooo]ZoookJPConOl01OoonfX3
o`0:o`;ooo]Z00Co0?lCoookJ_oonf[o0?mD1OoonfX01?l0oh;ooo]Zoo3o0?o`o`0;oookJP05oonG
0?oonf[ooo]ZoookJ_l0<_l02_oonfX00ol0Kooooo]ZoookJP06o`3o4`?oo`0000?o0=3ooookJ_oo
nfX00ooonfX00ol0d?oooo]ZoonG0007oonG00Gooo]Z0ol0<_l2oookJP03o`3o4ooonf[o0?lC00[o
oo]Z0oo`o`000ol0oh;ooo]Zoo3o0002oo3o00_ooo]Z00KonOl0oookJ_oonf[onOl0olko0?oio`03
o`0:o`Cooo]Z00?oo`00oookJ_oonfX00_oonfX00oooV`3ooo]ZoookJP02oookJP03o`0:oooonf[o
oo]Z00Cooo]Z00Co00[ooookJ_l02_oo00[o8_oonfX00ooo>`3ooo]ZoookJP02oookJP;oo`<01?oo
nfX2oolN03cooo]Z0_oo200GoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX01ooo
nfX002Oooo]Z00?o0000oookJ_oonfX0<?oonfX00ooo1`3ooo]ZoookJP0koookJP;ooaP03_oonfX0
0ooo4`3ooo]ZoookJP0DoookJP03ool00?oonf[ooo]Z00?ooo]Z1?ooJP05oookJPKo03;o00Co00[o
oookJ_oonf[o00[o0ooonfX00ol0<_oo00[ooookJP06oookJP03o`0boooonf[oof<000?ooo]Z00Go
0000oookJ_oonf[onOl0oookJP02ooWo0003oookJ_oio`3o00[o00?o00[o0ooonfX2o`3oE0?ooo]Z
00?o0?mDoookJ_oonfX00ooonfX01Ol0oh;ol?l0oo3o0?oonf[ol?l000oooo]Z00?o03;ooookJ_oo
nfX02?oonfX00ol0Kooooo]ZoookJP04oookJPGoo`000_l0oa<5oonG00Cooo]Z0_ooU`000ooo003o
oo]ZoookJP04o`0bo`Gooo]Z0_l0oa<00ooonf[o0?lCoookJP05oookJP?ol?l00_oonfX00ol0oh;o
l?l0oookJP02oo3o00gooo]Z00KonOl0o`0:ool02_ooc_l0o`0:oooio`07oookJP;oo`/000?ooo]Z
oonK0?oonfX01?oonfX00ol02_oooo]ZoookJP04oookJP?o00[o2_oonfX2oomZ02;ooo]Z00?ooah0
oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP0foookJP;oo`006?oonfX00ol0003ooo]ZoookJP0S
oookJP03o`000?oonf[ooo]Z00Oooo]Z000XoookJP;o0000@OoonfX00ooo1@3ooo]ZoookJP0joook
JP;ooa<06ooonfX3oomZ00Sooo]Z0_l0<_l01Ooonf[o00[ooookJ_l0<_oo00[o00Ko03;o00?o00[o
o`0bool0<_l01?oonfX01?l0<_oooo]ZoookJ_ooH`02oookJP04o`000?oonf[onOl0ooWo00;ooo]Z
0ol02_l00ooio`3oocL0oookJP03oookJP06o`3oE?oonf[o0?mDo`3oE?oonf[o0?mD1OoonfX00ol0
oh;oo`00oo3o0002oo3o0003oookJ_o`o`3ooo]Z00Sooo]Z0_oo0@04oookJP03o`0boooonf[ooo]Z
00Sooo]Z00?o06oooookJ_oonfX00ooonfX5ool00003oookJ_l0d?oo0?lC00Go0?lC0ooonfX00ooo
U`3o0=3oo`0bo`02o`0bo`Sooo]Z00?o0?lCool00?oonfX00ol0oa<2oookJP?ol?l01OoonfX01?l0
oh;ol?l0oookJ_o`o`0;oookJPCo00[o00?onOl0oookJ_oio`000_oio`09oookJP03oonK0?oonf[o
oo]Z00Cooo]Z00?o00[ooookJ_oo0@000ooonfX00ooo>P3o00[oo`0:o`0:oookJP03oomZ0?oonf[o
ofX002Kooo]Z00?oo`00oookJ_oonfX00ooonfX00ooo3@3ooo]ZoookJP0joookJP;oo`@04?oonfX0
0ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00Oooo]Z000ZoookJP03o`000?oonf[ooo]Z
03kooo]Z00?oo`D0oookJ_oonfX0BOoonfX2ool;00gooo]Z00?oofX0oookJ_oonfX01?oonfX00ooo
003ooo]ZoookJP02oookJP05o`0bool02_oooo]Zo`0:oooonfX00_ooM@001Ooonf[oogD0o`0boooo
nf[o00[o00;ooo]Z1_l0<_l2oookJP?oof<00_oonfX3o`0:o`03ooWo0?oonf[onOl000;ooo]Z0ooo
=`001Ol0oeCooo]ZoookJ_l0oeCooo]Z00;o0?mD0_oonfX2oolA0003oookJ_l0oh;ol?l000;ooo]Z
0oo`o`07oookJP03ool00?oonf[ooo]Z00Kooo]Z00?o03;ooookJ_oonfX02?oonfX00ol0Kooooo]Z
oookJP02oookJPGoo`000_oonfX01_l0d?oooo]ZoookJ_oonf[o0=3ooookJP?o0?lC0_l0<_l2o`3o
4`Wooo]Z00Go0?lCool30?oonf[o0?lCoookJP03oo3o00Cooo]Z00Coo`00oookJ_oonf[o0?n20_oo
nfX00oo`o`3ooo]ZoookJP07oookJP?o00[o00Oooo]ZooWo0?oonf[ooo]ZooWo0?oonf[onOl001?o
oo]Z00?o00[oool10?oonfX00_oonfX00ol02_oooo]ZoookJP0:oookJPCoofX0:ooonfX01Ooo3@3o
oo]ZoookJ_oonf[oo`00047ooo]Z00?oo`40oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0Roook
JP03o`000?oonf[ooo]Z00Oooo]Z000[oookJP03o`000?oonf[ooo]Z04kooo]Z00?oo`<0oookJ_oo
nfX0<?oonfX00ooo>`3ooo]ZoookJP0DoookJP;oo`D02_oonfX00ol02_oooo]Zo`0:o`02o`0bo`Co
ogD000?oo`00o`0bool02_l01OoonfX00ol0<_oooo]ZoookJP02oookJP03oomS0?l02_oo00[o00;o
00[o00?oo`40olko0?oio`000_oio`04oookJP;o0?mD0_oonfX00ol0oeCooo]ZoookJP02o`3oE0?o
oo]Z00?ooa40o`3oP_o`o`000oo`o`000ooonf[ol?l0oo3o0004oookJP03ool30?oonf[ooo]Z00[o
oo]Z00?o03;ooookJ_oo00002?oonfX00ol0Kooooo]ZoookJP02oookJP?oo`001?oonfX01Ol0d?oo
oo]ZoookJ_oonf[o0=3o00;ooo]Z0_l0d?l3oookJPKo0?lC0ooonfX01_l0oa?ooo]Zoo3o0?l0oa?o
l?l0oookJP?o0?lC1_oonfX00ol0oh;ooo]ZoookJP06oookJPCo00[o0ooonfX00ooio`3ooo]Zoook
JP02oookJP03ooWo0?oonf[ooo]Z00oooo]Z0_oo_@000ooonf[o00[ooookJP02oookJP03o`0:oooo
nf[ooo]Z00Gooo]Z00?oo`00oookJ_oonfX01?oonfX00oooJP3ooo]ZoookJP0eoookJP03ool40?oo
nf[ooo]Z00Cooo]Z00?ooaX0oookJ_oonfX0>ooonfX00ooo003o0000oookJP0RoookJP03o`000?oo
nf[ooo]Z00Oooo]Z000/oookJP03o`000?oonf[ooo]Z043ooo]Z00?ooa00oookJ_oonfX06_oonfX0
0ooo0@3ooo]ZoookJP0PoookJP03oolk0?oonf[ooo]Z01oooo]Z00Ko00[ooookJ_l02_oo00[oool1
0?oonfX2o`0bo`06oome0?oonf[ooo]Zo`0boooonf[o00[o0_oonfX2o`0bo`?ooo]Z0ol02_l2oomS
00?ooo]Z00?oc_l0oookJ_oio`001?oonfX00ol0oeCooo]ZoookJP02oookJP06o`3oE?oonf[ooo]Z
o`3oE?ngo`3o0?mD0ooonfX01Ol0oh;ooo]ZoookJ_o`o`3ooo]Z00?ol?l00ooonfX2ool300gooo]Z
00?o03;oool00?oonfX02?oonfX01?l0Kooooo]ZoookJ_l0d?l8oookJP08o`3@oooonf[ooo]Zo`3@
oooonf[o0=3ooookJ_l0d?l9oookJP?o0?lC0_o`o`000ol0oa?ooo]ZoookJP03oookJP;o0?lC0_oo
nfX00ooo003ooo]Zo`3oPP03oom000?ooo]Z0ol02_l6oookJP03ooWo0?oonf[ooo]Z01Cooo]Z1?oo
_@001?l02_oooo]ZoookJ_l02_l;oookJP;ooa400_oonfX01?ooJP3ooo]ZoookJ_oo000koookJP04
oolJ0?oonf[ooo]Zool103Wooo]Z00Coo`00oookJ_oo203o00008_oonfX00ol0003ooo]ZoookJP07
oookJP00;OoonfX2o`00043ooo]Z0_oo400ZoookJP03ool00?oonf[ooo]Z017ooo]Z00?ooc/0oook
J_oonfX03OoonfX00ooo>03ooo]ZoookJP0>oookJP06o`0:oooonf[o00[ooookJ_l02_ooo`400ooo
nfX2o`0bo`04oookJ_l0<_oooo]Zo`0:o`;o03;o0_oonfX3o`0:o`Cooo]Z00Go0000oookJ_oonf[o
oo]Zolko0005oookJP03o`3oE?oonf[ooo]Z00?ooo]Z00?o0?mDoookJ_l0oe@00_oonfX01?ngo`3o
0?mDoookJ_l0oh84oookJP;ol?l00_oonfX2oooC00kooo]Z00Coo`00oookJ_oonf[o03;o2_oonfX0
0ol0Kooo0=3ooookJP09oookJP03o`3@oooonf[ooo]Z00;o0=3o00?ooo]Zo`3@oooonfX02ooonfX0
0ol0oa?ooo]Zo`3o4`06o`3o4`08oookJ_l0oa?ooo]Zoom00?l0oh;ood00oookJ_oo@004o`0:o`03
oookJ_ngo`3o]ol000Cooo]Z0_oio`0FoookJP;ookd00_oonfX01?oo_@3ooo]Zo`0:ool02_l?oook
JP03oomZ0?oonf[ooo]Z00Gooo]Z00Coo`@0oookJ_oonf[ooo]Z0_oo<`0boookJP04oolJ0?oonf[o
o`40ool103gooo]Z00?o0000oookJ_oonfX01?oonfX00ooo103ooo]ZoookJP0IoookJP03o`000?oo
nf[ooo]Z00Kooo]Z000_oookJP03o`000?oonf[ooo]Z04oooo]Z00?oo`h0oookJ_oonfX0:_oonfX3
oolk00kooo]Z0_oo>00=oookJP04oolZ0?oonf[o00[oo`0:o`?ooo]Z00?o00[ooookJ_oonfX00ooo
nfX4o`0bo`Co00[o00?oo`00oookJ_oonfX01?oonfX01Ol0003ooo]ZoookJ_oonf[oc_l000Cooo]Z
00?o0?mDool00?oonfX01?oonfX00ol0oeCooo]Zo`3oE003oookJP03okOo0?l0oeCo0?n200[ooo]Z
0oood`0?oookJP03o`0boooonf[ooo]Z00Gooo]Z00?oo`00oookJ_l0d?l00_l0d?l:oookJP03o`3@
oooonf[o0=3o00;ooo]Z00?o0=3ooookJ_oonfX02OoonfX01?l0oa?ooo]ZoookJ_l0oa<5oookJPCo
0?lC00?ooo]Zo`3oP_l02_l00_l02_l4oookJP;o]ol000Gooo]ZokOo0?ngo`3ooo]ZooWo0006oook
JP04ool00?oonf[ooo]ZoookJPCoc_l02ooonfX00ooo_@3ooo]Zoonm0002oonm0003o`0:oooonf[o
oo]Z00kooo]Z00?oofX0oookJ_oonfX01?oonfX2ool400?ooo]Z0_oo<`0koookJP;oo`d000?ooo]Z
ool00?oonfX0<ooonfX00ol0003ooo]ZoookJP0<oookJP03ool20?oonf[ooo]Z017ooo]Z00?o0000
oookJ_oonfX01_oonfX0033ooo]Z00?o0000oookJ_oonfX0C_oonfX00ooo3P3ooo]ZoookJP0=oook
JP03ool:0?oonf[ooo]Z01Kooo]Z00?oo`00oookJ_oonfX04_oonfX3oolh00gooo]Z0_l02_l4oook
JP03o`0:oooonf[ooo]Z00Cooo]Z00Co00[oo`0bool02_oo00[o2_oonfX00ol0003ooo]ZoookJP02
oookJP04olko0?oo003ooo]ZoookJP;o0?mD1?oonfX00ol0oeCooo]Zo`3oE004oookJP03ool10?l0
oh;o0?mD00gooo]Z0oood`05oookJPOoodd000?ooo]Zo`0boooonfX02OoonfX5o`3@o`?ooo]Z00Co
o`00oookJ_oonf[o06oo0_l0d?l2oookJP03o`3@oooonf[ooo]Z00Wooo]Z00?o0?lCoookJ_oonfX0
2?l0oa<2o`0:o`03o`3oP_l02_oooo]Z00Gooo]Z1Ongo`000ooo303onOl0okOo0009oookJP03olko
0?oonf[oc_l000?oc_l02ooonfX3oonm01gooo]Z00?ooc<0oookJ_oonfX01?oonfX00ooo003ooo]Z
oookJP0noookJP03ool50?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX02ooonfX00ooo0P3ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z00Kooo]Z000aoookJP;o0000G_oonfX00ooo2P3ooo]Zoook
JP0ToookJP03ool00?oonf[ooo]Z00Gooo]Z00?oocP0oookJ_oonfX02ooonfX2o`0:o`03oolZ0?oo
nf[ooo]Z00;ooo]Z00Co00[ooookJ_oonf[ooo]Z0ol02_l3oolG0003o`0:oooonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX00_oonfX00oo>o`3ooo]ZoookJP02oookJP;o0?mD0ooonfX01Ol0oeCooo]Z
o`3oE?oonf[oo`0000?ooo]Z00?o0?n2o`3oE?l0oe@03ooonfX2oooC00;o00[o00?ooo]ZoooC0?oo
nfX00ooonfX3oom=0003oookJ_l0<_oooo]Z00;ooo]Z0ooo4@04oookJP04o`1_ool0d?oooo]Zoook
JPGo0=3o00Cooo]Zo`3@oooonf[o06oo0_l0d?l4oookJP;oom<01_oonfX4o`3o4`;ooo]Z0_l0oa<3
o`0:o`[ooo]Z00Go]ol0oookJ_oonf[o]ol0oookJP04okOo00Kooo]Z00?oo`40olko0?o>o`000oo>
o`000oooEP3oc_l0oookJP0:oookJP;ookd0:OoonfX2oolD00Cooo]Z00?oo`00oookJ_oonfX0=?oo
nfX00ooo1@3ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01;ooo]Z00?oo`00oookJ_oonfX02Ooo
nfX00ol0003ooo]ZoookJP06oookJP00<ooonfX00ol0003ooo]ZoookJP1[oookJP03ool50?oonf[o
oo]Z02;ooo]Z00?oo`00oookJ_oonfX01?oonfX2o`0:o`Oooo]Z0ol02_l5oookJP03oolG0?oonf[o
00[o00Wooo]Z0_oo2003oookJP03olko0?oonf[ooo]Z00?ooo]Z0_l0oe@2oookJP;o0?mD1OoonfX0
1?l0oh;o0?mDoookJ_ngo`0AoookJPGoom<02?oonfX00ol0<_oooo]ZoookJP08oookJP04o`1_ool0
d?oo0=3ooookJP;oo`800_oonfX01_l0Kooo0=3oo`1_ool0d?oo06ooo`3@o`?ooo]Z00Coo`00oooC
0?ood`3oom<01_oonfX3o`3o4`Co00[o3_oonfX01?ngo`3ooo]ZokOo0?oio`02okOo00Sooo]Z0_o>
o`02oomF0004olko0?oonf[oc_l0olko00?ooo]Z00?oo`00oookJ_oonfX01?oonfX00ooo_@3ooo]Z
oookJP0YoookJP03oolD0?oonf[ooo]Z04?ooo]Z00?oo`80oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z00Kooo]Z000doookJP03o`000?oonf[ooo]Z063ooo]Z00?o
ob80oookJ_oonfX05_oonfX00ooo0P3ooo]ZoookJP0JoookJP03o`0:oooonf[ooo]Z00;ooo]Z1Ol0
2_l9oookJP03o`0:oooonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX00_oonfX00oo>o`3ooo]Zoook
JP04oookJP;o0?mD00?oo`40o`3oE?l0oe@00_oonfX4o`3oE0?ooo]Z00?o]ol0oookJ_oonfX00_oo
nfX00ooo003ooo]ZoookJP0;oookJPCoom<01ooonfX4o`3oE0Sooo]Z00Co06oooookJ_l0d?oo0=3o
0_oonfX01?l0Kooo0=3ooookJ_l0Kol2o`3@o`;o06oo0_oonfX00ooo003oom<0oookJP02oooC00Co
oo]Z1?l02_l3oookJP;o0?mD2ooonfX4okOo0003oookJ_ngo`3o]ol000Wooo]Z00Coc_l0oomF0?o>
o`3oc_l00_oonfX2olko00?ooo]Z00Coo`00oookJ_oonf[ooaL00_oonfX00ooo_@3ooo]ZoookJP0d
oookJP;oo`H01?oonfX2ool[03gooo]Z00?oo`d0oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z00Kooo]Z000eoookJP03o`000?oonf[ooo]Z05oooo]Z00?oob80oook
J_oonfX09OoonfX00ooo003ooo]ZoookJP0:oookJP03o`0:oooonf[ooo]Z00?o00[o00?ooo]Zool0
0?oonfX00_oonfX00ol02_oooo]ZoookJP06oookJP03o`0:oooonf[ooo]Z00;ooo]Z00?oohH0oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP;oc_l01OoonfX01Ol0oeCooo]Zo`3oE?l0oeCo
oo]Z00;o0?mD00?ooo]Zo`3oE?l0oe@01OoonfX00ongo`3ooo]ZoookJP0<oookJP;oo`001_ood`08
oookJP03o`0boooonf[o0?mD00Ko0?mD0_oonfX00ol0Koooom<0oooC000BoooC00?o00[o1ooonfX3
o`3oE0Oooo]Z0ongo`02oookJP04okOo0?oonf[ooo]ZokOo00_ooo]Z00Ooc_l0oookJ_oonf[ooo]Z
olko0?oonf[oc_l000Gooo]Z0_oo5`02oookJP05oonm0?oonf[ooo]ZoookJ_oo00001_oonfX3oomB
02oooo]Z0_oo:`02oookJP03ool10?oonf[ooo]Z03Sooo]Z00?oo`d0oookJ_oonfX07OoonfX00ol0
003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Kooo]Z000foookJP;o00008?oonfX2ool;03go
oo]Z0_oo8P0>oookJP03oolM0?oonf[ooo]Z027ooo]Z1?l02_l8oookJP03o`0:oooonf[ooo]Z00Ko
oo]Z00?oo`00o`0:oooonfX00ooonfX01OooQP3ooo]ZoookJ_oonf[o000000?ooo]Z1?o>o`000ooo
nf[ooeH0oomF0002oookJPCo0?mD0_oonfX00ol0oeCooo]Zo`3oPP06oookJP03okOo0?oonf[ooo]Z
00;o]ol03OoonfX2oooC0003o`0:oooonf[ooo]Z00Sooo]Z00?o03;ooookJ_oonfX01OoonfX7o`3o
E005o`3@oooonf[ooo]ZoookJ_l0Kol00ooonfX01?oo=`3o06ooo`1_ooood`04o`0:o`Gooo]Z00?o
o`00oookJ_oonfX00_oonfX01?l0oeCooo]Zo`3oE?l0oe@2oookJPCo]ol01_oonfX2okOo00_ooo]Z
00?oc_l0oookJ_o>o`000_oonfX2olko00Wooo]Z00?ookd0oookJ_oonfX01OoonfX00ooo1@3ooo]Z
oookJP02oookJP;ooe80;ooonfX01Ooo:`3ooo]ZoookJ_oonf[oo`4000Gooo]Z0_oo500loookJP03
ool60?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP06oookJP00
>?oonfX00ol0003ooo]ZoookJP0_oookJP03ool80?oonf[ooo]Z03_ooo]Z00?ooad0oookJ_oonfX0
3?oonfX00ooo503ooo]ZoookJP0@oookJPOo00[o1_oonfX01?l02_oooo]ZoookJ_oo0006oookJP03
o`0:oooonf[ooo]Z00?ooo]Z00SoohH0oookJ_oonf[o0000oookJ_oo003oc_l0oookJP;oc_l000Co
oo]Zolko0?oonf[ooo]Z0_ooEP002?oonf[o0?mDo`3oP_l0oeCooo]Zo`3oE?oonf[o0?n20_oonfX3
oolT00?ooo]Z00Co]ol0oookJ_ngo`3ooo]Z0_ngo`05oookJP03ool00?oonf[ooo]Z00Kooo]Z00?o
00[ooookJ_oonfX02?oonfX00ol0<_oooo]ZoookJP08oookJP;o06oo00?ooo]Zo`3oE?l0oe@01Ol0
oe@2oookJP?o00[o00?oocL0oookJ_oonfX01_oonfX01Ooo2`3ooo]ZoookJ_oonf[o0?mD00;ooo]Z
00Go0?mDokOo0?ngo`3o]ol0ool00009oookJP03okOo0?oonf[ooo]Z00Sooo]Z0_o>o`03oookJP03
olko0?oonf[oc_l000Wooo]Z00?ookd0oookJ_oonfX01_oonfX01Ooo1@3ooo]ZoookJ_oonf[ooe80
03_ooo]Z0_oo5002oookJP03ool00?oonf[ooo]Z043ooo]Z00?oo`<0oookJ_oonfX03OoonfX00ol0
003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Gooo]Z000ioookJP03o`000?oonf[ooo]Z03ko
oo]Z0_oo1@0koookJP;ooa@03OoonfX00ooo2`3ooo]ZoookJP03oookJP;o00[o0ooonfX<o`0:o`Co
oo]Z00?o00[ooookJ_oonfX01?oonfX01OooQP3ooo]Zoon60?oonf[oc_l000;ooo]Z0_o>o`02oook
JP09olko0?oonf[ooo]ZoookJ_ooEP3o0?n2oomF0?l0oh;o0?mD00;ooo]Z00?o0?n2oookJ_oonfX0
0_oonfX2oolT00?ooo]Z00?o]ol0oookJ_ngo`000_oonfX00ongo`3ooo]ZoookJP0<oookJP03o`0:
oooo003oo`0000Sooo]Z00?o03;ooookJ_oonfX01ooonfX2o`1_o`Kooo]Z00Co06oooookJ_l02_oo
00[o1Ol0oe@6oookJP;oo`/00ooonfX3okOo0003o`3oE?oonf[ooo]Z00;o0?mD1OoonfX3oomS00_o
oo]Z00?oc_l0oookJ_oonfX01?oonfX00oo>o`3ooo]ZoookJP0DoookJP03oomB0?oonf[ooo]Z00Co
oo]Z00?oo`00oookJ_oonfX00_oonfX00ooo7@3ooo]ZoookJP0hoookJP03ool80?oonf[ooo]Z03Wo
oo]Z00?oo`<0oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00Go
oo]Z000joookJP;o0000CooonfX00ooo0`3ooo]ZoookJP0hoookJP03ool;0?oonf[ooo]Z00Gooo]Z
0ol02_l6oookJP04oonC0?l02_oooo]ZoonC00;ooo]Z1_l02_l4oookJP04ool00?oonf[oohH0oon6
00;oc_l00ooonfX00oo>o`3ooo]ZoookJP02olko0003oookJ_l0oh;o0?n200;ooeH00_l0oh800on:
o`3o0?n2oookJP08oookJP04okOo0?oonf[o]ol0okOo00;ooo]Z00?o]ol0ool90?oo2@003OoonfX0
0ol02_oooo]ZoookJP08oookJP03o`0boooo003ooo]Z00Kooo]Z00?o06oooookJ_l0Kol01OoonfX0
0ol0Kooooo]ZoookJP05oookJP03o`1_ool0oeCo0?mD00Go0?mD00Gooo]ZokOo0?ngo`3o]ol0o`3o
E002oookJP05o`3oE?oonf[ooo]ZoookJ_oo0@000_l0oe@00ooonf[oof<0oomS0003oomS00[ooo]Z
00?oc_l0oookJ_oonfX06ooonfX00oooDP3ooo]ZoookJP09oookJP;ooad01OoonfX00ooo003ooo]Z
oookJP0boookJP03ool80?oonf[ooo]Z04;ooo]Z00?oo`40oookJ_oonfX01_oonfX00ol0003ooo]Z
oookJP0JoookJP03o`000?oonf[ooo]Z00Gooo]Z000loookJP03o`000?oonf[ooo]Z04cooo]Z00?o
o`<0oookJ_oonfX03?oonfX00ooo0@3ooo]ZoookJP0QoookJP03oom;0?oonf[ooo]Z013ooo]Z0_l0
2_l00ooonf[oo`@0oookJP02oonC0003o`0:ooooT`3ooi<000Gooo]Z00?o00[ooookJ_oonfX01Ooo
nfX4oon6000:oookJ_o>o`3oc_l0oookJ_o>o`3ooo]Zolko0?oonf[oo`00o`3oPP?ooo]Z00?o0?n2
oookJ_oonfX00_l0oh800on:o`3ooo]ZoookJP05oookJP04okOo0?oonf[ooo]ZoookJPCo]ol03Ooo
nfX01?oo0@3ooo]ZoookJ_l02_l:oookJP03o`0boooonf[ooo]Z00Cooo]Z00Go06oooookJ_oonf[o
oo]Zo`1_o`05oookJP03o`1_oooonf[ooo]Z00Cooo]Z00?o06oooookJ_oonfX01?oonfX2okOo00Ko
0?mD1OoonfX00oooH`3o0?mDo`3oE003oookJP06oomS0?oonf[ooo]ZoookJ_oo003ooo]Z0on:o`02
oookJP03olko0?oonf[ooo]Z02Oooo]Z00?ooad0oookJ_oonfX03OoonfX2oom503Cooo]Z0_oo0`14
oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX01OoonfX003gooo]Z00?o0000oook
J_oonfX0F_oonfX00ooo0@3ooo]ZoookJP0QoookJP03oom;0?oonf[ooo]Z01;ooo]Z0_l02_l3oook
JP03oonC0?l02_oooo]Z00?ooo]Z0_l02_l2oookJP03ool10?oonf[ooo]Z00Gooo]Z0_ooQP03oook
JP?oc_l000?ooo]Zo`3oP_l0oh801?oonfX00ol0oh;ooo]ZoookJP02o`3oPP03oookJ_n:o`3oo`00
00Cooo]Z1Ongo`000ooio`3o]ol0okOo000BoookJP03o`0:oooonf[ooo]Z00Gooo]Z00Coo`00oook
J_oonf[o03;o1?oonfX00ol0Kooooo]ZoookJP03oookJP03o`1_oooonf[ooo]Z00;ooo]Z00?o06oo
oookJ_oonfX00ooonfX2o`1_o`[ooo]Z00?o0?mDoookJ_oonfX02?l0oe@00ooonf[o0?mDoookJP06
oookJP;oR_l000GooaT0oookJ_o>o`3oc_l0oh[o0003oookJP03ool00?oonf[ooo]Z00Gooo]Z0ooo
M@0VoookJP;oo`P01?oonfX2oom503_ooo]Z00?ooa<0ool00?oo0000>ooonfX00ooo1`3o0000oook
JP0IoookJP03o`000?oonf[ooo]Z00Gooo]Z000noookJP03o`000?oonf[ooo]Z03oooo]Z00?ooa@0
oookJ_oonfX09_oonfX00ooo003ooo]ZoookJP0CoookJP03oom;0?oonf[ooo]Z00_ooo]Z0_oo?@06
oookJP?o00[o00Cooo]Zo`0:oooonf[ooo]Z0_l02_l<oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co
o`00olko0?oonf[o0?n21_oonfX02?l0oh;ooo]ZoookJ_l0oh;ooo]Zo`3oP_oonf[oR_l01_oonfX2
okOo0004oookJ_ngo`3o]ol0okOo00?onOl02?oonfX4oomd00Cooo]Z00?o00[ooomd0?oonfX02?oo
nfX01?l0<_oooo]ZoookJ_l0Kol4oookJP04ool00?oonf[ooo]Zo`1_o`?ooo]Z00?o06oooookJ_oo
nfX00_oonfX2o`1_o`_ooo]Z00Co0?mDoookJ_oonf[o0?mD1ooonfX3o`3oE0Gooo]Z2_n:o`08oook
JPCoogD0:ooonfX00oooA@3ooo]ZoookJP02oookJP;oo`80=_oonfX2oolC03kooo]Z00?o0000oook
J_oonfX01?oonfX2ool301;ooo]Z00?o0000oookJ_oonfX01OoonfX003oooo]Z0_l0000ooookJP03
oolD0?oonf[ooo]Z00gooo]Z0_oo400VoookJP03ool00?oonf[ooo]Z00Cooo]Z0oooB`0=oookJP;o
ocd01ooonfX2o`0:o`04oookJ_l02_ooobH0oolV00cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
oh;ooo]ZoookJP05oookJP04o`3oP_oonf[o0?n2ool000;ooo]Z00?o0?n2oookJ_n:o`001ooonfX2
okOo00Gooo]Z0ooio`09oookJPKoog@00ooonfX4oolT00?ooo]Z00?o03;ooookJ_l0Kol02?oonfX0
1Ol0Kooooo]ZoookJ_oonf[o06oo00;ooo]Z00?o06ooool00?l0Kol00_oonfX2ooWo00Oooo]Z00Co
0?mDoookJ_oonf[o0?mD0_oonfX6o`3oE0Oooo]Z00CoR_l0oookJ_oonf[oc_l01On:o`03oookJP;o
o`D00ooonfX00oooM@3ooo]ZoookJP02oome02[ooo]Z00?oodD0oookJ_oonfX02?oonfX2oolN00?o
oo]Z00?oo`00oookJ_oonfX0=OoonfX00ooo2@3ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z00_o
oo]Z0_oo0@0:oookJP03o`000?oonf[ooo]Z00Gooo]Z0011oookJP03o`000?oonf[ooo]Z04gooo]Z
00?ooa00oookJ_oonfX03?oonfX2ool:01gooo]Z0_ooB`04oookJP03ool00?oonf[ooo]Z00Oooo]Z
0_oo?@09oookJP05o`0:oooonf[ooo]ZoookJ_oo9P002ooonfX2oolA00Gooo]Z00?o0?n2oookJ_oo
nfX01OoonfX00ol0oh;ooo]Zo`3oPP04oookJP03o`3oP_oonf[oR_l000Kooo]Z00?oo`00oookJ_oo
nfX01ooonfX3ooWo00Gooo]Z0_oio`03oookJP;oog@000?o00[ooookJ_oonfX00_oonfX00ooo903o
oo]ZoookJP03oookJP04o`1_oooonf[ooo]ZoookJP;oo`P01OoonfX2o`0bo`04oookJ_l0Kooooo]Z
o`1_o`;ooo]Z00?o06oooookJ_oonfX01?oio`04oookJP03o`3oE?oonf[o0?mD00Co0?mD00Cooo]Z
o`3oE?l0oeCo0?mD2OoonfX2oh[o0004olko0?n:o`3oR_l0oookJP;oR_l01ooonfX2oome00Kooo]Z
00?oo`00oookJ_oonfX0<OoonfX2oolN04Cooo]Z00?oo`@0oookJ_oonfX0;?oonfX00ol0003ooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z00Gooo]Z0012oookJP03o`000?oonf[ooo]Z06[ooo]Z0_oo
1@0OoookJP04oolm0?oonf[ooo]Zool001Gooo]Z00?o0000oookJ_oo4@001_oonfX00ol0oh;ooo]Z
oookJP03oookJP03o`3oP_oonf[o0?n200Kooo]Z00?o0?n2oookJ_n:o`004OoonfX01?oo003onOl0
ooWo0?oio`02oookJP?onOl00_oonfX00oooM03ooo]Zo`3oPP03o`3oPPKooo]Z0_l0Kol00ol0<_oo
oo]ZoookJP07oookJP05o`0bool0Kooo03;ooookJ_l0Kol00_oo0@001_l0Kooooo]ZoookJ_oonf[o
nOl0oookJP?onOl00ooonfX2o`3oE004oookJ_l0oeCooo]ZoookJP;o0?n22OoonfX3oh[o0004oook
J_n:o`3ooo]ZoookJP?oR_l01ooonfX00oooM@3ooo]ZoookJP0:oookJP;oobH01OoonfX00ooo003o
oo]ZoookJP06oookJP;oofX0:?oonfX2ool<03[ooo]Z00?oo`@0oookJ_oonfX01_oonfX00ooo0@3o
oo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX01?oonfX004?ooo]Z
0_l0001ioookJP03ool20?oonf[ooo]Z01oooo]Z00Goo`00oookJ_oonf[ooo]ZoonV0004oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0?n2oookJ_oonfX00_oonfX00ol0oh;ooo]Zo`3oPP06oookJP;o
0?n200?ooo]Zoh[o0?oo0@004ooonfX3ooWo0003oookJ_oio`3ooo]Z00Gooo]Z00?o00[ooookJ_l0
oh801Ol0oh82oookJP04o`1_ool0<_oo06ooo`1_o`Gooo]Z00?o03;ooookJ_l0<_l00_l0Kol=ooWo
0004ool00?oonf[ooo]ZoookJPCo0?mD0ol0oh84oookJPCoR_l01?oonfX00on:o`3ooo]ZoookJP02
oh[o01Cooo]Z0ooo9P0=oookJP?oofX0:?oonfX00ooo303ooo]ZoookJP07oookJP03ool30?oonf[o
oo]Z03Sooo]Z00?oo`40oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z00Cooo]Z0015oookJP03o`000?oonf[ooo]Z08Cooo]Z00?oo`00oookJ_oonfX05_oonfX01Ooo
YP3ooo]ZoookJ_oonf[o000000;ooo]Z00?oo`00oookJ_oonfX01OoonfX01?l0oh;ooo]ZoookJ_oo
nfX2o`3oPPGooo]Z0_l0oh84oookJP03oh[o0?oonf[ooo]Z00[ooo]Z00?oo`00oookJ_oonfX01Ooo
nfX00ooio`3ooo]ZooWo0002ooWo00Kooo]Z00?o00[ooookJ_oonfX01?oonfX6o`3oPP[onOl000Co
oo]Zo`0boooonf[o06oo0oooEP04ooWo00Oooo]Z00Ko0?mDoookJ_oonf[o0?n2oookJ_l0oh84oh[o
00Wooo]Z0_n:o`0EoookJP03oolV0?oonf[ooo]Z00Wooo]Z00?oo`/0oookJ_oonfX00_oonfX3oomZ
03;ooo]Z00?oo`<0oookJ_oonfX01ooonfX00ooo0@3ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z
01Gooo]Z00?o0000oookJ_oonfX01?oonfX004Kooo]Z00?o0000oookJ_oonfX0GOoonfX00ooo:03o
oo]ZoookJP0aoookJP03ool00?oonf[ooo]Z00Wooo]Z00CoojH0oookJ_oonf[o00002OoonfX00ooo
M@3o0?n2o`3oPP02oookJP;o0?n20_oonfX4o`3oPPKooo]Z00?oR_l0oookJ_oonfX00_oonfX2oh[o
00cooo]Z1ooio`06oookJP03o`0:oooonf[ooo]Z00Sooo]Z00?o06ooo`3oP_l0oh801?l0oh83o`1_
o`03oookJ_ooEP3ooeH000;o03;o0_oonfX00oooEP3onOl0ooWo0004oookJP;ooaL01_oonfX3oh[o
00;o0?n21ooonfX2oon600;ooo]Z00?oR_l0oookJ_oonfX07ooonfX2ool;00?ooo]Z00?oofX0oook
J_ooJP000ooonfX00ooo0P3ooo]ZoookJP0coookJP;ooad000?ooo]Zool10?oonfX0>OoonfX00ooo
2@3ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX01?oonfX004Oo
oo]Z00?o0000oookJ_oonfX07ooonfX00ooo303ooo]ZoookJP0koookJP;oobP03OoonfX2oolN02oo
oo]Z00?oojH0oookJ_l000002ooonfX2o`3oPP03oookJ_l0oh;oogD000;o0?n200?ooo]Zo`3oP_oo
nfX00_oonfX5oolj0003oookJ_n:o`3ooo]Z00;ooo]Z00?oR_l0oookJ_n:o`003?oonfX01?oio`3o
oo]ZooWo0?oio`09oookJP03o`0:oooonf[oo`0000Sooo]Z00?o06oooookJ_l0<_l00ooonfX6o`3o
PP03o`1_oooonf[o03;o00;ooo]Z00?onOl0oookJ_oonfX00_oonfX00ooo5`3ooo]ZoolG0002oook
JPCoR_l00ooonfX00ol0oh;oo`D0o`3oPP05oookJPCoohH09ooonfX00oooJP3ooo]ZoookJP04oook
JP03ool20?oonf[ooo]Z00;ooo]Z00?oob`0oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP0Yoook
JP03oolM0?oonf[ooo]Z04Cooo]Z00?oo`@0oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z00Cooo]Z0018oookJP;o0000;ooonfX2ool902cooo]Z0_oo:00>oookJP;o
oah03?oonfX2oolC027ooo]Z00CoojH0o`000?oonf[oojH02?oonfX00ooo003ooo]Zo`3oPP03o`3o
PP03oome0?l0oh;o0?n200Oooo]Z0_oo>P02oookJP07oh[o0?oonf[oR_l0oookJ_n:o`3ooo]Zoh[o
0002oolD00[ooo]Z00?onOl0oookJ_oonfX02_oonfX00ol02_oooo]ZoookJP08oookJP03o`1_ool0
<_oooo]Z00;ooo]Z00Co06oooookJ_l0<_oooo]Z0_l0Kol5o`3oPPOooo]Z0on:o`03oookJP07o`3o
P_oonf[ooo]ZoookJ_l0oh;oo`D0oookJP02o`3oPPCoohH000Cooo]Zoon60?ooQP3oo`009OoonfX0
0oooJP3ooo]ZoookJP09oookJP;oob`01?oonfX00ooo003ooo]ZoookJP0coookJP03ool=0?oonf[o
oo]Z04;ooo]Z00?oo`80oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z00Cooo]Z001:oookJP03o`000?oonf[ooo]Z03gooo]Z00?oo`H0oookJ_oonfX0A_oonfX2ool8
00gooo]Z00?oo`<0oookJ_oonfX01?oonfX01?ooYP3ooo]ZoonV0?ooYP0:oookJP;o0?n200?oogD0
o`3oP_oonfX01?oonfX00ooo003ooo]ZoookJP06oookJP04oh[o0?oonf[ooo]Zoh[o00;ooo]Z00?o
R_l0oookJ_oonfX02OoonfX00ooo1@3ooo]ZoookJP09oookJP03ool10?oonf[o00[o00Wooo]Z0_l0
<_l00ol0Kooooo]Zo`1_o`03o`1_o`03o`0boooonf[ooo]Z00Gooo]Z1Ol0oh82oh[o00Kooo]Z00Co
0?n2oookJ_oonf[o0?n20_oonfX2oon600;o0?n20ooonfX2oon600;oo`002_oonfX00ooo003ooo]Z
oookJP06oookJP?ooi<06_oonfX00ooo;03ooo]ZoookJP13oookJP03ool50?oonf[ooo]Z04[ooo]Z
00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP04oookJP00BooonfX00ol0003ooo]Zoook
JP1;oookJP;oo`<03_oonfX00ooo0@3ooo]ZoookJP0eoookJP;oo`<01_oonfX01ol0003oojH0oonV
0?oonf[oojH0oookJ_oo00002OoonfX00ol0oh;oogD0oome000<oookJP05oh[o0?oonf[oR_l0olko
0?n:o`000_oonfX00on:o`3ooo]ZoookJP0EoookJP04ool10?oonf[ooo]Zo`0:o`Oooo]Z00Co03;o
ool00?oonf[o03;o0_l0Kol3oookJP03o`0boooonf[ooo]Z00Kooo]Z00?o03;ooookJ_oonfX00_oo
nfX6o`3oPP05oookJ_l0oh;ooo]ZoookJ_l0oh800_ooQP04oookJP03o`3oP_oonf[ooo]Z00Gooo]Z
0ooo:P0>oookJPGooi<09?oonfX2ool?04;ooo]Z0_oo0P13oookJP03o`000?oonf[ooo]Z01;ooo]Z
00?o0000oookJ_oonfX00ooonfX004cooo]Z0_l0001JoookJP03ool10?oonf[ooo]Z00cooo]Z00?o
o`00oookJ_oonfX04ooonfX00oooD@3ooo]ZoookJP0IoookJPGoojH000?ooo]Zool00?oonfX02ooo
nfX00ooo003ooo]ZoookJP08oookJP06oh[o0?oonf[ooo]ZoookJ_n:o`3oc_l00on:o`08oookJP?o
oi/02?oonfX00oooV`3ooo]ZoookJP05oookJP03o`0:oooonf[ooo]Z00?ooo]Z00?o03;ooookJ_oo
nfX00_oonfX00ol0<_oooo]ZoookJP03oookJP04o`0boooonf[ooo]Zool000Cooo]Z00?o03;ooook
J_oonfX02?oonfX6o`3oPPKooo]Z00?o0?n2oookJ_oonfX00_oonfX2oolZ0003oookJ_oo:P3ooo]Z
00kooo]Z1OooT`0^oookJP03ool40?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP03oookJP00C_oonfX00ol0003ooo]ZoookJP1doookJP03ool00?oonf[ooo]Z00Ko
oo]Z00?ooe40oookJ_oonfX02_oonfX2oolh00cooo]Z00Co0000oookJ_ooYP3oojH06OoonfX3oh[o
00?ooo]Z0on:o`03olko00Wooo]Z1OooV`03oookJP;ooi/01Ooo>P02oookJP03o`0:oooonf[ooo]Z
00;ooo]Z00?o03;ooookJ_oonfX00ooonfX00ol0<_oooo]ZoookJP02oookJP03o`0boooonf[ooo]Z
00Cooo]Z0_l0<_l2oookJP;oc_l01ooonfX01Ol0oh;ooo]ZoookJ_l0oh;ooo]Z00Ko0?n200?ooo]Z
o`3oP_oonfX03_oonfX00ooo2`3ooo]ZoookJP03oookJP?ooi<000?ooo]ZoonC0?oonfX0<ooonfX2
ool[00?ooo]Z00?oo`40oookJ_oonfX0=OoonfX2ool>03cooo]Z00?o0000oookJ_oonfX04OoonfX0
0ol0003ooo]ZoookJP03oookJP00CooonfX00ol0003ooo]ZoookJP0moookJP;ooaL03_oonfX00ooo
403ooo]ZoookJP0]oookJP;ooe4000?ooo]Zool00?oonfX02OoonfX2oolh00[ooo]Z00?o0000oolM
0?oo7@007?oonfX7oh[o00?ooo]Z0_o>o`000ooo003ooo]ZoookJP09oookJPKooi/00ooonfX2oolj
00;ooo]Z00Co00[ooookJ_oonf[o03;o0ooo4@04oookJP03o`0boooonf[ooo]Z00;ooo]Z00?o03;o
oookJ_oonfX00_oonfX2o`0bo`?ooo]Z00?oc_l0oookJ_o>o`001OoonfX01?l0oh;ooo]ZoookJ_l0
oh87oookJPCo0?n24_oonfX2oonC00?ooo]Z00?ooi<0oookJ_oo0P00<ooonfX3ool[03[ooo]Z0_oo
3P0moookJP03o`000?oonf[ooo]Z00Cooo]Z00?oo`80oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP03oookJP00D?oonfX00ol0003ooo]ZoookJP0moookJP03oolG0?oonf[ooo]Z00gooo]Z00?ooa00
oookJ_oonfX03?oonfX00ooo2P3ooo]ZoookJP0NoookJP;ooe403?oonfX2oolh00Wooo]Z00Co0000
oookJ_oo7@3ooad02_oonfX2ool;013ooo]Z00?oR_l0oookJ_n:o`000on:o`05oookJP?oc_l01_oo
nfX2olko00?ooo]Z1OooV`07oookJP03o`0:ool0<_oooo]Z00Sooo]Z00Ko03;ooookJ_oonf[ooo]Z
o`0boooo1002oookJP03o`0boooonf[o03;o00?ooo]Z0_o>o`000ooonf[oc_l0oookJP03oookJP03
o`3oP_oonf[ooo]Z00[o0?n24_oonfX2oonC00_ooo]Z0_oo>004oookJP03ool00?oonf[ooo]Z02Ko
oo]Z00?oob/0oookJ_oonfX02?oonfX2oolB03[ooo]Z0_oo1P07oookJP03ool20?oonf[ooo]Z02_o
oo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP03oookJP00DOoonfX2o`0005cooo]Z
00?oo`X0oookJ_oonfX02ooonfX2ool4013ooo]Z0oooD@0<oookJP03oolh0?oonf[ooo]Z00Sooo]Z
00Co0000oookJ_oo003oo`002ooonfX00ooo2`3ooo]ZoookJP09oookJP;oo`<01?oonfX2oh[o00_o
oo]Z0oo>o`03oookJP?oc_l00ooonfX2oonK00Wooo]Z00?o03;oo`0:oooonfX02OoonfX2o`0:o`;o
oo]Z00?o03;ooookJ_l0<_l00_oonfX01_l0<_oooo]Zoome0?ooM@3oc_l0oookJP?oc_l00ooonfX4
o`3oPPCooo]Z0_l0oh8DoookJP03oonC0?oonf[ooo]Z00Wooo]Z0_oo>0000ooonf[oocP0oookJP0g
oookJP;ooa80@ooonfX00ooo0P3ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000
oookJ_oonfX00ooonfX005?ooo]Z00?o0000oookJ_oonfX0M_oonfX00ooo0@3ooo]ZoookJP0Joook
JP03o`000?oonf[ooo]Z02Gooo]Z00?oo`00oookJ_oonfX01_oonfX3olko0004oookJ_oo003oc_l0
olko00cooo]Z0ol0<_lMolko00;ooo]Z00Co0?n2oookJ_oonf[o0?n20_oonfX2o`3oPR7ooo]Z00?o
ocP0oookJ_oonfX02_oonfX00ooo4`3ooo]ZoookJP0goookJP03ool70?oonf[ooo]Z00Oooo]Z00?o
o`80oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00?ooo]Z001D
oookJP03o`000?oonf[ooo]Z08;ooo]Z0_oo000<oookJP03ool00?oonf[o000000Sooo]Z0_ooT`0X
oookJP?oc_l000?ooo]Zolko0?oonfX01ooonfX00ooo003ooo]ZoookJP03oookJP;o03;o00?o00[o
o`0boooonfX01OoonfX01_l02_oooo]Zo`0:ooooM@3o00[oo`0bo`?oogD000?o03;ooookJ_oonfX0
0_ooM@04olko00;oobH00ooonfX5o`3oPP_ooo]Z0_ooYP0RoookJP;ooa<02OoonfX00ooo1@3ooo]Z
oookJP0foookJP03ool20?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP03oookJP00EOoonfX2o`0005kooo]Z00?oob/0oookJ_oonfX0<OoonfX00ol0003ooo]Zoook
JP07oookJP03ool00?ooT`3ooi<000[ooo]Z0oooDP0IoookJP03olko0?oonf[ooo]Z00?oc_l03_oo
nfX00ol0<_oooo]Zo`0:o`03o`0bo`;ooo]Z00Go00[ooookJ_oonf[o00[ooookJP02o`0bo`04o`0:
oooonf[ooo]Zo`0bo`;ooo]Z00CoogD0oookJ_o>o`3oc_l00ooo9P05oookJP05o`3oP_oonf[ooo]Z
oookJ_oo2`002OoonfX4oonV02_ooo]Z0_oo1@04oookJP03oolk0?oonf[ooo]Z00;ooo]Z00?oo`40
oookJ_oonfX0L?oonfX00ooo1`3ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000
oookJ_oonfX00_oonfX005Oooo]Z00?o0000oookJ_oonfX07_oonfX00ooo3P3ooo]ZoookJP0koook
JP;oob/03?oonfX2oolM02?ooo]Z00?o0000oookJ_oonfX02_oonfX3oonC00Oooo]Z00?oo`00oook
J_oonfX01?ooDP07oookJPCoob<02OoonfX8olko00kooo]Z0_l0<_l01Ol02_oooo]ZoookJ_l0<_oo
00[o00;o03;o0_oonfX01?l02_oo03;oo`0bool0<_l2o`0:o`03o`0boooonf[ooo]Z00;ooo]Z00?o
c_l0oookJ_oonfX02_oonfX2ool;00Oooo]Z0oooYP000ooo0P3oojH0oonV000aoookJP;ooc/00ooo
nfX00ooo0@3ooo]ZoookJP0coookJP;ooa<0>ooonfX00ooo1`3ooo]ZoookJP05oookJP;oo`<05_oo
nfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00;ooo]Z001HoookJP03o`000?oonf[o
oo]Z01kooo]Z00?oo`h0oookJ_oonfX03OoonfX00ooo2@3ooo]ZoookJP0[oookJP03ool[0?oonf[o
oo]Z00cooo]Z00?ooad0oookJ_oonfX02_oonfX2ool?01Cooo]Z00?o0000oookJ_oonfX03OoonfX4
oonC00Sooo]Z0oooDP08oookJP03oolS0?oonf[ooo]Z00Sooo]Z00?oo`/0olko0?oonfX00oo>o`06
oookJP03ool30?oonf[ooo]Z00Wooo]Z00Co03;oo`0:oooonf[o00[o0ooonfX3o`0bo`;ooo]Z0_l0
<_l00ooonf[o00[ooookJP0EoookJPCoojH00ooonfX2oonV00Wooo]Z00?oo`00oookJ_oonfX09?oo
nfX3oolk03[ooo]Z00?ooa<0oookJ_oonfX01_oonfX2ool803[ooo]Z00?oo`<0oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00;ooo]Z001IoookJP03o`000?oonf[o
oo]Z02gooo]Z00?oo`T0oookJ_oonfX03?oonfX2ool500kooo]Z00?oo`80oookJ_oonfX0=_oonfX2
ool600Kooo]Z00?o0000oookJ_oonfX00_oonfX2ool200[ooo]Z0oooT`09oookJP03oomB0?oonf[o
oo]Z01Cooo]Z00?oc_l0oookJ_oonfX04ooonfX01?oo003o03;oo`0bool02_l4oookJP03o`0bool0
2_oo03;o00Co03;o00?ooo]Zo`0:ool02_l04OoonfX3oonV00Oooo]Z00CoojH0oookJ_oonf[ooo]Z
0_oo?@0[oookJP03oolk0?oonf[ooo]Z00Wooo]Z0_oo600ioookJP03ool80?oonf[ooo]Z00Kooo]Z
0_oo0`1:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX00_oonfX005[ooo]Z0_l0
001;oookJP;oo`803OoonfX00ooo0@3ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00gooo]Z1Ooo
T`0goookJP03o`0:ool0<_oooo]Z00;ooo]Z00Go03;ooookJ_oonf[o00[ooookJP03o`0bo`?ooo]Z
00?o00[ooookJ_oonfX03?oonfX2oonV00_ooo]Z1Ooo?@0foookJP03oolH0?oonf[ooo]Z00Sooo]Z
00?oo`P0oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00;ooo]Z
001LoookJP03o`000?oonf[ooo]Z06Gooo]Z00?oo`00oookJ_oonfX02ooonfX00ooo003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z00oooo]Z00?ooi<0oookJ_oonfX02_oonfX00ooo003ooo]Zoook
JP09oookJP04ool00?oonf[ooo]ZoookJPCookd02OoonfX2oonm00Cooo]Z00?ooe80oookJ_oonfX0
1_oonfX01Ol02_oooo]ZoookJ_l0<_oooo]Z00Co03;o00?o00[oo`0boooonfX01_oonfX00ol02_oo
oo]ZoookJP0GoookJP03oolm0?oonf[ooo]Z00Wooo]Z0ooo5012oookJP03ool20?oonf[ooo]Z07_o
oo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP02oookJP00GOoonfX00ol0003ooo]Z
oookJP1koookJP;ood/00_oonfX00ooo003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z033ooo]Z
1_oo_@03oookJP?ookd01OooDP04oookJP;ooad000?o00[ooolM0?oonfX00_oonfX2o`0bo`Cooo]Z
00?o00[ooookJ_oonfX01OoonfX00ol02_oooo]ZoookJP0^oookJP03ool50?oonf[ooo]Z0;Gooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP02oookJP00G_oonfX2o`0003kooo]Z0_oo
600moookJP?ood/02OoonfX4ool/00[ooo]Z0_oo500YoookJPGookd000Gooo]Zoonm0?oonf[ooo]Z
oomB0006oookJP03o`0:oooonf[ooad000Cooo]Z00?o00[ooookJ_oonfX00_oonfX00ol02_oooo]Z
oookJP04oookJP;o00[o0ooonfX00ooo0P3ooo]ZoookJP0`oookJP;ood/00ooonfX00ooo0@3ooo]Z
oookJP0boookJP03oolJ0?oonf[ooo]Z03Wooo]Z00?oo`T0oookJ_oonfX0>OoonfX00ooo103o0000
oookJP0:oookJP03o`000?oonf[ooo]Z007ooo]Z001PoookJP03o`000?oonf[ooo]Z03cooo]Z0_oo
600=oookJP;ooa003OoonfX00ooo203ooo]ZoookJP0OoookJP;ood/02?oonfX00ol0003ooo]Zoook
JP02ool/00[ooo]Z0_oo500:oookJP;oo`L02ooonfX00ooo0P3ooo]ZoookJP0AoookJPGookd02?oo
nfX00ol02_oooo]ZoookJP05oookJP03o`0:oooonf[ooo]Z00;ooo]Z00?o00[ooookJ_oonfX00_oo
nfX2o`0:o`04oookJ_ooT`3ooi<0oonC00[ooo]Z0_oo000UoookJPCood/0=ooonfX2oolJ03[ooo]Z
00?oo`T0oookJ_oonfX01_oonfX00ooo103ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z00Sooo]Z
00?o0000oookJ_oonfX00OoonfX0067ooo]Z00?o0000oookJ_oonfX0FOoonfX00ooo203ooo]Zoook
JP0;oookJP;oo`<03?oonfX00ooo0@3ooo]ZoookJP02oookJP?ood/02?oonfX00ol0003ooo]Zoook
JP0UoookJP03ool20?oonf[ooo]Z00Wooo]Z0_oo0006oookJP;ookd02_oonfX00ol02_oooo]Zoook
JP07oookJP05o`0:oooonf[ooo]ZoookJ_l02_l00ooonfX01?l02_oooo]Zo`0:oooonfX4oonC02oo
oo]Z00Cood/0oookJ_oonf[ood/01ooonfX2oolM02oooo]Z00?ooaX0oookJ_oonfX01ooonfX00ooo
2`3ooo]ZoookJP07oookJP03ool40?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP01oookJP00H_oonfX00ol0003ooo]ZoookJP1doookJP03ool10?oonf[ooo]Z00[o
oo]Z00Coo`00oookJ_oonf[o0000?ooonfX00ooo003ooo]ZoookJP04oookJP03o`0:oooonf[ooo]Z
00Wooo]Z00Co00[ooookJ_oonf[ooo]Z0_ooT`000ol02_oooi<0oonC0005oonC00?ooo]Z00?oocP0
oookJ_oonfX0:OoonfX00oooB`3ooo]ZoookJP08oookJP03oolM0?oonf[ooad004;ooo]Z00?oo`@0
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z007ooo]Z001Soook
JP;o0000Q?oonfX00ol0003ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z00[ooo]Z00?oo`00oook
J_oonfX0;?oonfX00ol02_oooo]ZoookJP0:oookJPCooi<000?o00[ooookJ_l02_l00_oonfX01?l0
2_oooo]ZoonC0?ooT`06oolh00Oooo]Z00?ooa<0oookJ_oonfX0=_oonfX2ool:00Sooo]Z0_oo0`2H
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX00OoonfX006Gooo]Z00?o0000oook
J_oonfX0POoonfX00ol0003ooo]ZoookJP0DoookJP?oofX01?oonfX00oooJP3ooo]ZoookJP04oook
JPCooc<07?oonfX3o`0:o`gooo]Z00Co00[ooookJ_oonf[o00[o0_oonfX00ol02_oooo]ZoookJP0>
oookJP;ooa<02OoonfX2ool50=;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP01
oookJP00I_oonfX00ol0003ooo]ZoookJP1KoookJP?oobP02ooonfX2oolH01Cooo]Z00?o0000oook
J_oonfX06?oonfX6oomZ00Sooo]Z0_oo<`08oookJP;ooa@02_oonfX2ool600Oooo]Z1Ol02_l:oook
JP?o00[o0_oonfX00ol02_oooo]ZoookJP0ToookJP03ool10?oonf[ooo]Z0:Sooo]Z00?oo`D0oook
J_oonfX07?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z007ooo]Z001WoookJP;o
00007ooonfX00ooo3P3ooo]ZoookJP0=oookJP03ool90?oonf[ooo]Z02[ooo]Z0_oo:00=oookJP03
oolH0?oonf[ooo]Z00[ooo]Z0_oo3005oookJP03o`000?oonf[ooo]Z00?ooo]Z0_oo100GoookJP?o
ofX09ooonfX2o`0:o`03ool10?oonf[o00[o00Co00[o1OoonfX3o`0:o`;ooo]Z00?o00[ooookJ_oo
nfX07ooonfX2oomA03Kooo]Z0_oo8P0ioookJP;oo`d02?oonfX00ooo1@3ooo]ZoookJP1?oookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX00OoonfX006Wooo]Z00?o0000oookJ_oonfX0
;?oonfX00ooo2@3ooo]ZoookJP0<oookJP03ool50?oonf[ooo]Z00_ooo]Z0_oo0P0aoookJP03o`00
0?oonf[ooo]Z013ooo]Z0_oo0@0:oookJP03oomZ0?oo003ooo]Z02Wooo]Z00?o00[ooookJ_oonfX0
1?oonfX5o`0:o`;ooo]Z0_l02_l00ooonf[o00[ooookJP0MoookJPGooe40=OoonfX00ooo8P3ooo]Z
oolR0008oookJP03ool>0?oonf[ooo]Z03Oooo]Z0_oo1@1BoookJP03o`000?oonf[ooo]Z00Cooo]Z
0Ol00001oookJP7ooo]Z001ZoookJP03o`000?oonf[ooo]Z05Kooo]Z0_oo000<oookJP03ool00?oo
nf[ooo]Z00[ooo]Z00?oo`00oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0YoookJP03ool00?oo
nf[ooo]Z01Kooo]Z00?oofX0oookJ_oonfX01?oonfX2o`0:o`Sooo]Z1_l02_lMoookJP;ooe400ooo
nfX00oooD@3ooo]ZoookJP05oookJP;ooah0=ooonfX2ool>00Sooo]Z0_oo1@24oookJP03o`000?oo
nf[ooo]Z00?ooo]Z0Ol00001oookJP7ooo]Z001[oookJP03o`000?oonf[ooo]Z07[ooo]Z00Co0000
oookJ_oonf[oo`00>OoonfX6oomZ00;ooo]Z0_ooJP06oookJP03ool/0?l02_oooo]Z00Gooo]Z00?o
00[ooookJ_oonfX00_oonfX2o`0:obSooo]Z0ooo7P08oookJP;oo`X02_oonfX00ooo0`3ooo]Zoook
JP2boookJP03o`000?oonf[ooo]Z00;ooo]Z0Ol00001oookJP7ooo]Z001/oookJP;o0000N_oonfX0
0ol0003ooc/0oolk0010oookJPGoofX000?ooo]Zool/0?oo;0000ooo;0000ooonf[o00[oo`0:o`03
oookJP03o`0:oooonf[oo`l000?o00[o2?oonfX00ooo103ooo]ZoookJP0eoookJP03ool30?oonf[o
oo]Z0;?ooo]Z00?o0000oookJ_oonfX00_oonfX1o`00007ooo]Z0OoonfX006kooo]Z00?o0000oook
J_oonfX0??oonfX2oolG03Wooo]Z00?o0000oookJ_oonfX00ooo>`09oookJP?ooah02_oonfX2ool=
00_ooo]Z00?oo`@0oookJ_oonfX06OoonfX00oooJP3ooo]ZoookJP09oookJP03o`0:oooonf[o00[o
00?o00[o2_oonfX2ool400[ooo]Z00?oo`40oookJ_oonfX0YOoonfX00ooo1`3ooo]ZoookJP0ioook
JP05o`000?oonf[ooo]ZoookJ_l000000_oonfX006oooo]Z00?o0000oookJ_oonfX0??oonfX2oolG
00cooo]Z0_oo3P0<oookJP;oo`L03OoonfX00ooo0`3ooo]ZoookJP0<oookJP04o`000?oonf[ooo]Z
oookJP;ooc/02ooonfX00ooo7P3ooo]ZoookJP0EoookJP03ool40?oonf[ooo]Z00Wooo]Z00?oo`40
oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP0>oookJP;o00[oBooonfX00ooo:03ooo]ZoookJP0g
oookJP03ool@0?oonf[ooo]Z03Sooo]Z0_oo1`0loookJP04o`000?oonf[ooo]Zo`0000;ooo]Z001`
oookJP;o0000I_oonfX2ool300cooo]Z00?oo`40oookJ_l000002_oonfX00ooo003ooo]ZoookJP09
oookJP03ool00?oonf[ooo]Z04cooo]Z0_ooB`0goookJP;oobP0=ooonfX00ooo403ooo]ZoookJP07
oookJP03ool70?oonf[ooo]Z06kooo]Z00?o0000oookJ_l000000_oonfX007;ooo]Z00?o0000oook
J_oonfX0LooonfX00ol0003ooo]ZoookJP1RoookJPCood/01_oonfX00ooo7@3ooo]ZoookJP0[oook
JP;oobP02?oonfX3ool@00Sooo]Z00?oo`D0oookJ_oonfX0W_oonfX01?l0003ooo]ZoookJ_l00001
oookJP00LooonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z05kooo]Z1?ooB`000ooo
nf[ood/0oookJP05oookJP?ooad02?oonfX2ool:03Sooo]Z00?oo`D0oookJ_oonfX0WooonfX00ol0
003ooo]Zo`000001oookJP00M?oonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[ooo]Z02;o
oo]Z1?ooA@000ooonf[oodD0oookJP06oookJPCooah02OoonfX2ool<00_ooo]Z00?oo`<0oookJ_oo
nfX0=?oonfX2ool30=3ooo]Z0_l00001oookJP00MOoonfX2o`0005_ooo]Z0ooo8P0;oookJP;ooa80
1_oonfX00ol0003ooo]ZoookJP03oookJP03ool80?oonf[ooo]Z00[ooo]Z00?oo`<0oookJ_oonfX0
4ooonfX3oom500Wooo]Z00?ooah0oookJ_oonfX02?oonfX00ooo303ooo]ZoookJP08oookJP;oo`<0
2_oonfX00ooo0@3ooo]ZoookJP3joookJP?o00000OoonfX007Oooo]Z00?o0000oookJ_oonfX07Ooo
nfX2ool>00gooo]Z0_oo200=oookJP03ool40?oonf[ooo]Z00_ooo]Z00?oo`80oookJ_oonfX03_oo
nfX00ooo8P3ooo]ZoookJP0:oookJP;ooa801OoonfX00ol0003ooo]ZoookJP03oookJP03ool80?oo
nf[ooo]Z00[ooo]Z00?oo`<0oookJ_oonfX02_oonfX00ooo0@3ooo]ZoookJP09oookJP03ool00?oo
nf[ooo]Z09;ooo]Z00?ooa@0oookJ_oonfX0=ooonfX2ool805?ooo]Z1?l00004oookJP00N?oonfX0
0ol0003ooo]ZoookJP18oookJP03ool20?oonf[ooo]Z00_ooo]Z00?oo`00oookJ_oonfX02_oonfX0
0ooo003ooo]ZoookJP07oookJP04o`000?oonf[ooo]Zool008?ooo]Z0_oo:`0goookJP;ooa@02?oo
nfX2ool8083ooo]Z1?l00008oookJP00NOoonfX2o`0006gooo]Z00?o0000oookJ_oonfX0BooonfX0
0ooo>`3ooo]ZoookJP0doookJPCoob/01ooonfX2ool@0;Kooo]Z1?l0000<oookJP00NooonfX00ol0
003ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z04Kooo]Z1ooo>`06oookJP?ooaP02OoonfX00ooo
203ooo]ZoookJP0foookJP03ool60?oonf[ooo]Z0:Kooo]Z1?l0000@oookJP00O?oonfX00ol0003o
oo]ZoookJP1YoookJP03o`000?oonf[ooo]Z00_ooo]Z1?oo:`0:oookJP;ooa@02ooonfX00ooo203o
oo]ZoookJP0RoookJP03oolk0?oonf[ooo]Z00Kooo]Z00?ooaP0oookJ_oonfX02?oonfX00ooo203o
oo]ZoookJP08oookJP03ool20?oonf[ooo]Z0=3ooo]Z1?l0000DoookJP00OOoonfX00ol0003ooo]Z
oookJP0koookJP?ooa@03?oonfX2ool;00cooo]Z00?oo`D0oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0>oookJP;oob/02_oonfX2oolD00[ooo]Z00?oo`P0oookJ_oonfX02OoonfX2ool300[ooo]Z
00?oo`00oookJ_oonfX0n?oonfX4o`0001Sooo]Z001noookJP;o0000??oonfX2oolD00gooo]Z00?o
o`/0oookJ_oonfX02_oonfX00ooo1@3ooo]ZoookJP0:oookJP;oo`8000?ooo]Zo`000?oonfX02?oo
nfX2ool000_ooo]Z00?oo`00oookJ_oonfX0bOoonfX2ool;05?ooo]Z1?l0000LoookJP00P?oonfX0
0ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z0:Kooo]Z0_oo5`08oookJP03ool90?oonf[o
oo]Z02gooo]Z00?oo`/0oookJ_oonfX0C_oonfX4o`00023ooo]Z0021oookJP03o`000?oonf[ooo]Z
06Cooo]Z00?o0000oookJ_oonfX0K?oonfX3oolX00Sooo]Z00?ooa00oookJ_oonfX0:ooonfX00ooo
5`3ooo]ZoookJP07oookJP;oo`T0O?oonfX4o`0002Cooo]Z0022oookJP;o0000I?oonfX00ol0003o
oo]ZoookJP0_oookJPCoob/02_oonfX00ooo4P3ooo]ZoookJP09oookJP03ool70?oonf[ooo]Z01ko
oo]Z0_oo:0000ooonf[oobP0oookJP07oookJP;ooa002OoonfX00ooo1@3ooo]ZoookJP2UoookJPCo
0000:?oonfX008Cooo]Z00?o0000oookJ_oonfX0FOoonfX2oolJ00Kooo]Z00?o0000oookJ_oonfX0
<_oonfX2ool[00Sooo]Z0ooo4P09oookJP;oo`L02_oonfX00ooo0P3ooo]ZoookJP3>oookJPCo0000
;?oonfX008Gooo]Z00?o0000oookJ_oonfX07OoonfX00ooo303ooo]ZoookJP0KoookJP03ool30?oo
nf[ooo]Z00[ooo]Z00?oo`40oookJ_oonfX03_oonfX2oolJ00Gooo]Z00?o0000oookJ_oonfX00_oo
nfX3ool=00_ooo]Z00?oo`D0oookJ_oonfX02OoonfX2ool200_ooo]Z00?oo`00oookJ_oonfX0mOoo
nfX4o`00033ooo]Z0026oookJP03o`000?oonf[ooo]Z01gooo]Z00?oo``0oookJ_oonfX02ooonfX2
ool700cooo]Z0_oo0`0<oookJP03ool10?oonf[ooo]Z00[ooo]Z0_oo0009oookJP03o`000?oonf[o
o`000<Sooo]Z0_oo301CoookJPCo0000=?oonfX008Oooo]Z0_l0001OoookJP03o`000?oonf[ooo]Z
08kooo]Z0_oo600hoookJP;oo``0CooonfX4o`0003Sooo]Z0029oookJP03o`000?oonf[ooo]Z05co
oo]Z00?o0000oookJ_oonfX0EOoonfX00ooo8P3ooo]ZoookJP0CoookJP03ool50?oonf[ooo]Z01oo
oo]Z00?ooaP0oookJ_oo60002?oonfX2ool907cooo]Z0ol0000loookJP00R_oonfX00ol0003ooo]Z
oookJP1KoookJP03o`000?oonf[ooo]Z03kooo]Z00?oo`80oookJ_oonfX04_oonfX4oolR00Sooo]Z
0_oo3P09oookJP;oo`D0Y_oonfX4o`0003oooo]Z002;oookJP;o0000F?oonfX00ooo103ooo]Zo`00
000:oookJP03ool10?oonf[ooo]Z00[ooo]Z00?oo`00oookJ_oonfX00_oonfX3oolM00Wooo]Z0ooo
3@0:oookJP;oo`D02_oonfX00ooo0P3ooo]ZoookJP3=oookJPCo0000@ooonfX008gooo]Z00?o0000
oookJ_oonfX0>OoonfX3ool@00_ooo]Z0_oo200<oookJP03ool40?oonf[o000000[ooo]Z00?oo`40
oookJ_oonfX02_oonfX00ooo003ooo]ZoookJP3coookJPCo0000AooonfX008kooo]Z00?o0000oook
J_oonfX0E_oonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z1?l0001;oookJP00SooonfX00ol0003o
oo]ZoookJP1EoookJP03o`000?oonf[ooo]Z07Sooo]Z00?ooaL0oookJ_oonfX0=_oonfX2ool>053o
oo]Z1?l0001?oookJP00T?oonfX2o`0005Gooo]Z00?o0000oookJ_oonfX0MooonfX3oolG00Sooo]Z
0_oo2@1koookJPCo0000DooonfX009;ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]Zoook
JP0NoookJP03ool40?oonf[ooo]Z00Wooo]Z00?oo`40oookJ_oonfX04?oonfX3oolJ00Wooo]Z0_oo
2`0:oookJP03ool40?oonf[ooo]Z0:?ooo]Z1?l0001GoookJP00TooonfX00ol0003ooo]ZoookJP0j
oookJP03ool20?oonf[ooo]Z00[ooo]Z00?oo`40oookJ_oonfX01ooonfX01?l0003ooo]ZoookJ_oo
0002oookJP?ooa<02_oonfX2ool900_ooo]Z0_oo100;oookJP03ool10?oonf[ooo]Z0<[ooo]Z1?l0
001KoookJP00U?oonfX2o`0001gooo]Z0_oo2`0=oookJP03ool50?oonf[ooo]Z00_ooo]Z00?oo`80
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP3coookJPCo0000GooonfX009Kooo]Z00?o0000oook
J_oonfX0C_oonfX00ol0003ooo]ZoookJP3_oookJPCo0000HooonfX009Oooo]Z00?o0000oookJ_oo
nfX0COoonfX00ol0003ooo]ZoookJP1/oookJP03ool80?oonf[ooo]Z02[ooo]Z0ooo3P1?oookJPCo
0000IooonfX009Sooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0doookJP03ool8
0?oonf[ooo]Z00Sooo]Z00?oo`<0oookJ_oonfX07_oonfX3oolD00Sooo]Z0_oo201joookJPCo0000
JooonfX009Wooo]Z0_l0001:oookJP03ool60?oonf[o000000[ooo]Z00?oo`<0oookJ_oonfX02Ooo
nfX2ool1013ooo]Z0ooo4`0:oookJP;oo`P02_oonfX00ooo0`3ooo]ZoookJP2QoookJPCo0000Kooo
nfX009_ooo]Z00?o0000oookJ_oonfX0>OoonfX2ool=00cooo]Z00?oo`H0oookJ_l000002_oonfX0
0ooo0`3ooo]ZoookJP3DoookJPCo0000LooonfX009cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0
003ooo]ZoookJP3KoookJPCo0000MooonfX009gooo]Z0_l00018oookJP03o`000?oonf[ooo]Z0=Oo
oo]Z1?l0001koookJP00WooonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z08;ooo]Z
0ooo3P1>oookJPCo0000OooonfX00:3ooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Zoook
JP0YoookJP;oo`807_oonfX3ool@00Wooo]Z0_oo1`1hoookJPCo0000PooonfX00:7ooo]Z00?o0000
oookJ_oonfX0;?oonfX00ooo103ooo]ZoookJP09oookJP;oo`802OoonfX01?l0003ooo]Zool00?oo
000?oookJP;oo`h02ooonfX2ool60:cooo]Z1?l00027oookJP00X_oonfX2o`0001gooo]Z0_oo200<
oookJP03ool40?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0aooonfX4o`0008_ooo]Z002Toook
JP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0`ooonfX4o`0008oooo]Z002UoookJP03
o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0_ooonfX4o`0009?ooo]Z002VoookJP;o0000
?ooonfX00ol0003ooo]ZoookJP0ooookJP;oo`D0:ooonfX2ool<04gooo]Z1?l0002GoookJP00Z?oo
nfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z00Oooo]Z0_oo100;oookJP03ool20?oo
nf[ooo]Z01cooo]Z0_oo3@0:oookJP03ool50?oonf[ooo]Z07Gooo]Z1?l0002KoookJP00ZOoonfX0
0ol0003ooo]ZoookJP0hoookJP;oo`T000?ooo]Zo`000?oonfX02OoonfX00ooo103ooo]ZoookJP2X
oookJPCo0000WooonfX00:[ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP2_oook
JPCo0000XooonfX00:_ooo]Z0_l0000joookJP03o`000?oonf[ooo]Z0:_ooo]Z1?l0002WoookJP00
[OoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z0:Oooo]Z1?l0002[oookJP00[_oo
nfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[oo`4002Wooo]Z0_oo100ZoookJP;oo`/0COoo
nfX3o`000:oooo]Z002_oookJP;o0000:ooonfX00ooo0`3ooo]ZoookJP07oookJP04o`000?oonf[o
oo]Zool101gooo]Z0_oo2@21oookJPCo0000/_oonfX00;7ooo]Z00?o0000oookJ_oonfX06ooonfX0
0ooo1`3ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z09gooo]Z1?l0002foookJP00/_oonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z09Wooo]Z1?l0002joookJP00/ooonfX00ol0003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z09Gooo]Z1?l0002noookJP00]?oonfX2o`00033ooo]Z
00?o0000oookJ_oonfX0@OoonfX00ooo203ooo]ZoookJP1=oookJPCo0000`_oonfX00;Kooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP08oookJP;oo`L02ooonfX00ooo0`3ooo]Zoook
JP0XoookJP;oo`P0BooonfX4o`000<Kooo]Z002goookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000
oookJ_oonfX02OoonfX00ooo1`3ooo]ZoookJP1moookJPCo0000b_oonfX00;Sooo]Z0_l0000/oook
JP03o`000?oonf[ooo]Z08Gooo]Z1?l0003>oookJP00^_oonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z087ooo]Z1?l0003BoookJP00^ooonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z07gooo]Z1?l0003FoookJP00_?oonfX00ol0003ooo]ZoookJP0WoookJP04o`000?oo
nf[ooo]Zool202Wooo]Z0_oo1`1=oookJPCo0000f_oonfX00;gooo]Z0_l0000MoookJP03ool50?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0MOoonfX4o`000=kooo]Z002ooookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX0LOoonfX4o`000>;ooo]Z0030oookJP03o`000?oonf[ooo]Z
02?ooo]Z00?o0000oookJ_oonfX0KOoonfX4o`000>Kooo]Z0031oookJP;o00008ooonfX00ol0003o
oo]ZoookJP1YoookJPCo0000j_oonfX00<?ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Z
oookJP1UoookJPCo0000k_oonfX00<Cooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0EoookJP03ool50?oonf[ooo]Z04Wooo]Z1?l0003boookJP00aOoonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[ooo]Z05gooo]Z1?l0003foookJP00a_oonfX2o`0001kooo]Z00?o0000oook
J_oonfX0FOoonfX4o`000?[ooo]Z0038oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0EOoonfX4o`000?kooo]Z0039oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
DOoonfX4o`000?oooo]Z0ooonfX00<[ooo]Z0_l0000JoookJP04o`000?oonf[oo`@0ool404cooo]Z
1?l0003ooookJPOooo]Z003<oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0BOoo
nfX4o`000?oooo]Z2ooonfX00<gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP15
oookJPCo0000oooonfX?oookJP00c_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z
047ooo]Z1?l0003ooookJQ?ooo]Z003?oookJP;o00005OoonfX00ol0003ooo]ZoookJP0moookJPCo
0000oooonfXGoookJP00dOoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z03Wooo]Z
1?l0003ooookJQ_ooo]Z003BoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0=Ooo
nfX4o`000?oooo]Z7ooonfX00=?ooo]Z0_l0000AoookJP03o`000?oonf[ooo]Z03;ooo]Z0ol0003o
oookJR?ooo]Z003EoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0;ooonfX4o`00
0?oooo]Z9_oonfX00=Kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0[oookJPCo
0000oooonfXZoookJP00eooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02Oooo]Z
1?l0003ooookJRkooo]Z003HoookJP;o00002ooonfX00ol0003ooo]ZoookJP0SoookJPCo0000oooo
nfXboookJP00f_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01oooo]Z1?l0003o
oookJSKooo]Z003KoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX06ooonfX4o`00
0?oooo]Z>_oonfX00=cooo]Z0_l00007oookJP03o`000?oonf[ooo]Z01Oooo]Z1?l0003ooookJSko
oo]Z003NoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04ooonfX4o`000?oooo]Z
@_oonfX00=oooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0?oookJPCo0000oooo
nfY6oookJP00h?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00_ooo]Z1?l0003o
oookJT[ooo]Z003QoookJP;o00000_oonfX00ol0003ooo]ZoookJP07oookJPCo0000oooonfY>oook
JP00hooonfX00ol0003ooo]Zo`000005oookJPCo0000oooonfYBoookJP00i?oonfX2o`000003oook
J_l0003o000000;o0000oooonfYFoookJP00iOoonfX2o`000?oooo]ZF_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {513.25, 0}} -> {-0.000133425, 0.0275501, \
0.00165591, 0.00165591}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Or simply by avoiding the axis altogether and using the symmetry of \
the field\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlotVectorField3D[
      LeavingKansas[x, y, z, 3], {x,  .01, 1}, {y,  .01, 1}, {z,  .01,  .5}, 
      VectorHeads \[Rule] True, \ 
      ColorFunction \[Rule] \((\((Hue[#* .66])\) &)\), PlotPoints \[Rule] 15, 
      ScaleFactor \[Rule] 0.5]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92779 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.9748e-17 1.06503 -0.0181428 1.06503 [
[ 0 0 0 0 ]
[ 1 .92779 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04176 .22644 m
0 .5347 L
s
0 .5347 m
.46444 .92779 L
s
.46444 .92779 m
.46883 .64868 L
s
.46883 .64868 m
.04176 .22644 L
s
.61722 0 m
.96751 .49777 L
s
.96751 .49777 m
1 .78865 L
s
1 .78865 m
.62517 .31897 L
s
.62517 .31897 m
.61722 0 L
s
.04176 .22644 m
0 .5347 L
s
0 .5347 m
.62517 .31897 L
s
.62517 .31897 m
.61722 0 L
s
.61722 0 m
.04176 .22644 L
s
.46883 .64868 m
.96751 .49777 L
s
.96751 .49777 m
1 .78865 L
s
1 .78865 m
.46444 .92779 L
s
.46444 .92779 m
.46883 .64868 L
s
0 0 m
1 0 L
1 .92779 L
0 .92779 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.47567 .65343 m
.47567 .65343 L
s
.47567 .65343 m
.47567 .65343 L
s
.47567 .65343 m
.47567 .65343 L
s
.47567 .65343 m
.47567 .65343 L
s
.47567 .65343 m
.47567 .65343 L
s
.47567 .65343 m
.47567 .65343 L
s
.47567 .65343 m
.47567 .65343 L
s
.47567 .65343 m
.47567 .65343 L
s
.47567 .65343 m
.47567 .65343 L
s
.47546 .66845 m
.47546 .66845 L
s
.47546 .66845 m
.47546 .66845 L
s
.47546 .66845 m
.47546 .66845 L
s
.47546 .66845 m
.47546 .66845 L
s
.47546 .66845 m
.47546 .66845 L
s
.47546 .66845 m
.47546 .66845 L
s
.47546 .66845 m
.47546 .66845 L
s
.47546 .66845 m
.47546 .66845 L
s
.47546 .66845 m
.47546 .66845 L
s
.50739 .64386 m
.50739 .64386 L
s
.50739 .64386 m
.50739 .64386 L
s
.50739 .64386 m
.50739 .64386 L
s
.50739 .64386 m
.50739 .64386 L
s
.50739 .64386 m
.50739 .64386 L
s
.50739 .64386 m
.50739 .64386 L
s
.50739 .64386 m
.50739 .64386 L
s
.50739 .64386 m
.50739 .64386 L
s
.50739 .64386 m
.50739 .64386 L
s
.47525 .68359 m
.47525 .68359 L
s
.47525 .68359 m
.47525 .68359 L
s
.47525 .68359 m
.47525 .68359 L
s
.47525 .68359 m
.47525 .68359 L
s
.47525 .68359 m
.47525 .68359 L
s
.47525 .68359 m
.47525 .68359 L
s
.47525 .68359 m
.47525 .68359 L
s
.47525 .68359 m
.47525 .68359 L
s
.47525 .68359 m
.47525 .68359 L
s
.5073 .65893 m
.5073 .65893 L
s
.5073 .65893 m
.5073 .65893 L
s
.5073 .65893 m
.5073 .65893 L
s
.5073 .65893 m
.5073 .65893 L
s
.5073 .65893 m
.5073 .65893 L
s
.5073 .65893 m
.5073 .65893 L
s
.5073 .65893 m
.5073 .65893 L
s
.5073 .65893 m
.5073 .65893 L
s
.5073 .65893 m
.5073 .65893 L
s
.45776 .6357 m
.45776 .6357 L
s
.45776 .6357 m
.45776 .6357 L
s
.45776 .6357 m
.45776 .6357 L
s
.45776 .6357 m
.45776 .6357 L
s
.45776 .6357 m
.45776 .6357 L
s
.45776 .6357 m
.45776 .6357 L
s
.45776 .6357 m
.45776 .6357 L
s
.45776 .6357 m
.45776 .6357 L
s
.45776 .6357 m
.45776 .6357 L
s
.53942 .6342 m
.53942 .6342 L
s
.53942 .6342 m
.53942 .6342 L
s
.53942 .6342 m
.53942 .6342 L
s
.53942 .6342 m
.53942 .6342 L
s
.53942 .6342 m
.53942 .6342 L
s
.53942 .6342 m
.53942 .6342 L
s
.53942 .6342 m
.53942 .6342 L
s
.53942 .6342 m
.53942 .6342 L
s
.53942 .6342 m
.53942 .6342 L
s
.47504 .69884 m
.47504 .69884 L
s
.47504 .69884 m
.47504 .69884 L
s
.47504 .69884 m
.47504 .69884 L
s
.47504 .69884 m
.47504 .69884 L
s
.47504 .69884 m
.47504 .69884 L
s
.47504 .69884 m
.47504 .69884 L
s
.47504 .69884 m
.47504 .69884 L
s
.47504 .69884 m
.47504 .69884 L
s
.47504 .69884 m
.47504 .69884 L
s
.5072 .6741 m
.5072 .6741 L
s
.5072 .6741 m
.5072 .6741 L
s
.5072 .6741 m
.5072 .6741 L
s
.5072 .6741 m
.5072 .6741 L
s
.5072 .6741 m
.5072 .6741 L
s
.5072 .6741 m
.5072 .6741 L
s
.5072 .6741 m
.5072 .6741 L
s
.5072 .6741 m
.5072 .6741 L
s
.5072 .6741 m
.5072 .6741 L
s
.45748 .65079 m
.45748 .65079 L
s
.45748 .65079 m
.45748 .65079 L
s
.45748 .65079 m
.45748 .65079 L
s
.45748 .65079 m
.45748 .65079 L
s
.45748 .65079 m
.45748 .65079 L
s
.45748 .65079 m
.45748 .65079 L
s
.45748 .65079 m
.45748 .65079 L
s
.45748 .65079 m
.45748 .65079 L
s
.45748 .65079 m
.45748 .65079 L
s
.53944 .64931 m
.53944 .64931 L
s
.53944 .64931 m
.53944 .64931 L
s
.53944 .64931 m
.53944 .64931 L
s
.53944 .64931 m
.53944 .64931 L
s
.53944 .64931 m
.53944 .64931 L
s
.53944 .64931 m
.53944 .64931 L
s
.53944 .64931 m
.53944 .64931 L
s
.53944 .64931 m
.53944 .64931 L
s
.53944 .64931 m
.53944 .64931 L
s
.48967 .62596 m
.48967 .62596 L
s
.48967 .62596 m
.48967 .62596 L
s
.48967 .62596 m
.48967 .62596 L
s
.48967 .62596 m
.48967 .62596 L
s
.48967 .62596 m
.48967 .62596 L
s
.48967 .62596 m
.48967 .62596 L
s
.48967 .62596 m
.48967 .62596 L
s
.48967 .62596 m
.48967 .62596 L
s
.48967 .62596 m
.48967 .62596 L
s
.57176 .62445 m
.57176 .62445 L
s
.57176 .62445 m
.57176 .62445 L
s
.57176 .62445 m
.57176 .62445 L
s
.57176 .62445 m
.57176 .62445 L
s
.57176 .62445 m
.57176 .62445 L
s
.57176 .62445 m
.57176 .62445 L
s
.57176 .62445 m
.57176 .62445 L
s
.57176 .62445 m
.57176 .62445 L
s
.57176 .62445 m
.57176 .62445 L
s
.47482 .71421 m
.47483 .7142 L
s
.47483 .7142 m
.47483 .71421 L
s
.47483 .7142 m
.47483 .7142 L
s
.47483 .7142 m
.47483 .7142 L
s
.47483 .7142 m
.47483 .7142 L
s
.47483 .7142 m
.47483 .7142 L
s
.47483 .7142 m
.47483 .71421 L
s
.47483 .7142 m
.47483 .7142 L
s
.47483 .71421 m
.47483 .7142 L
s
.50711 .68939 m
.50711 .68939 L
s
.50711 .68939 m
.50711 .68939 L
s
.50711 .68939 m
.50711 .68939 L
s
.50711 .68939 m
.50711 .68939 L
s
.50711 .68939 m
.50711 .68939 L
s
.50711 .68939 m
.50711 .68939 L
s
.50711 .68939 m
.50711 .68939 L
s
.50711 .68939 m
.50711 .68939 L
s
.50711 .68939 m
.50711 .68939 L
s
.4572 .666 m
.4572 .666 L
s
.4572 .666 m
.4572 .666 L
s
.4572 .666 m
.4572 .666 L
s
.4572 .666 m
.4572 .666 L
s
.4572 .666 m
.4572 .666 L
s
.4572 .666 m
.4572 .666 L
s
.4572 .666 m
.4572 .666 L
s
.4572 .666 m
.4572 .666 L
s
.4572 .666 m
.4572 .666 L
s
.53947 .66452 m
.53947 .66452 L
s
.53947 .66452 m
.53947 .66452 L
s
.53947 .66452 m
.53947 .66452 L
s
.53947 .66452 m
.53947 .66452 L
s
.53947 .66452 m
.53947 .66452 L
s
.53947 .66452 m
.53947 .66452 L
s
.53947 .66452 m
.53947 .66452 L
s
.53947 .66452 m
.53947 .66452 L
s
.53947 .66452 m
.53947 .66452 L
s
.48951 .64109 m
.48951 .64109 L
s
.48951 .64109 m
.48951 .64109 L
s
.48951 .64109 m
.48951 .64109 L
s
.48951 .64109 m
.48951 .64109 L
s
.48951 .64109 m
.48951 .64109 L
s
.48951 .64109 m
.48951 .64109 L
s
.48951 .64109 m
.48951 .64109 L
s
.48951 .64109 m
.48951 .64109 L
s
.48951 .64109 m
.48951 .64109 L
s
.43952 .61764 m
.43952 .61764 L
s
.43952 .61764 m
.43952 .61764 L
s
.43952 .61764 m
.43952 .61764 L
s
.43952 .61764 m
.43952 .61764 L
s
.43952 .61764 m
.43952 .61764 L
s
.43952 .61764 m
.43952 .61764 L
s
.43952 .61764 m
.43952 .61764 L
s
.43952 .61764 m
.43952 .61764 L
s
.43952 .61764 m
.43952 .61764 L
s
.57191 .63959 m
.57191 .63959 L
s
.57191 .63959 m
.57191 .63959 L
s
.57191 .63959 m
.57191 .63959 L
s
.57191 .63959 m
.57191 .63959 L
s
.57191 .63959 m
.57191 .63959 L
s
.57191 .63959 m
.57191 .63959 L
s
.57191 .63959 m
.57191 .63959 L
s
.57191 .63959 m
.57191 .63959 L
s
.57191 .63959 m
.57191 .63959 L
s
.4746 .72969 m
.47462 .72968 L
s
.47462 .72968 m
.47462 .72968 L
s
.47462 .72968 m
.47462 .72968 L
s
.47462 .72968 m
.47462 .72968 L
s
.47462 .72968 m
.47462 .72968 L
s
.47462 .72968 m
.47462 .72968 L
s
.47462 .72968 m
.47462 .72968 L
s
.47462 .72968 m
.47462 .72968 L
s
.47462 .72968 m
.47462 .72968 L
s
.52191 .61612 m
.52191 .61612 L
s
.52191 .61612 m
.52191 .61612 L
s
.52191 .61612 m
.52191 .61612 L
s
.52191 .61612 m
.52191 .61612 L
s
.52191 .61612 m
.52191 .61612 L
s
.52191 .61612 m
.52191 .61612 L
s
.52191 .61612 m
.52191 .61612 L
s
.52191 .61612 m
.52191 .61612 L
s
.52191 .61612 m
.52191 .61612 L
s
.60442 .6146 m
.60442 .6146 L
s
.60442 .6146 m
.60442 .6146 L
s
.60442 .6146 m
.60442 .6146 L
s
.60442 .6146 m
.60442 .6146 L
s
.60442 .6146 m
.60442 .6146 L
s
.60442 .6146 m
.60442 .6146 L
s
.60442 .6146 m
.60442 .6146 L
s
.60442 .6146 m
.60442 .6146 L
s
.60442 .6146 m
.60442 .6146 L
s
.50701 .7048 m
.50702 .70479 L
s
.50702 .7048 m
.50702 .7048 L
s
.50702 .70479 m
.50702 .7048 L
s
.50702 .70479 m
.50702 .7048 L
s
.50702 .70479 m
.50702 .70479 L
s
.50702 .70479 m
.50702 .70479 L
s
.50702 .7048 m
.50702 .70479 L
s
.50702 .70479 m
.50702 .7048 L
s
.50702 .70479 m
.50702 .70479 L
s
.45691 .68133 m
.45692 .68132 L
s
.45692 .68132 m
.45692 .68132 L
s
.45692 .68132 m
.45692 .68132 L
s
.45692 .68132 m
.45692 .68132 L
s
.45692 .68132 m
.45692 .68132 L
s
.45692 .68132 m
.45692 .68132 L
s
.45692 .68132 m
.45692 .68132 L
s
.45692 .68132 m
.45692 .68132 L
s
.45692 .68132 m
.45692 .68132 L
s
.5395 .67985 m
.5395 .67985 L
s
.5395 .67985 m
.5395 .67985 L
s
.5395 .67985 m
.5395 .67985 L
s
.5395 .67985 m
.5395 .67985 L
s
.5395 .67985 m
.5395 .67985 L
s
.5395 .67985 m
.5395 .67985 L
s
.5395 .67985 m
.5395 .67985 L
s
.5395 .67985 m
.5395 .67985 L
s
.5395 .67985 m
.5395 .67985 L
s
.48935 .65634 m
.48935 .65634 L
s
.48935 .65634 m
.48935 .65634 L
s
.48935 .65634 m
.48935 .65634 L
s
.48935 .65634 m
.48935 .65634 L
s
.48935 .65634 m
.48935 .65634 L
s
.48935 .65634 m
.48935 .65634 L
s
.48935 .65634 m
.48935 .65634 L
s
.48935 .65634 m
.48935 .65634 L
s
.48935 .65634 m
.48935 .65634 L
s
.43917 .63281 m
.43917 .63281 L
s
.43917 .63281 m
.43917 .63281 L
s
.43917 .63281 m
.43917 .63281 L
s
.43917 .63281 m
.43917 .63281 L
s
.43917 .63281 m
.43917 .63281 L
s
.43917 .63281 m
.43917 .63281 L
s
.43917 .63281 m
.43917 .63281 L
s
.43917 .63281 m
.43917 .63281 L
s
.43917 .63281 m
.43917 .63281 L
s
.57206 .65484 m
.57206 .65484 L
s
.57206 .65484 m
.57206 .65484 L
s
.57206 .65484 m
.57206 .65484 L
s
.57206 .65484 m
.57206 .65484 L
s
.57206 .65484 m
.57206 .65484 L
s
.57206 .65484 m
.57206 .65484 L
s
.57206 .65484 m
.57206 .65484 L
s
.57206 .65484 m
.57206 .65484 L
s
.57206 .65484 m
.57206 .65484 L
s
1 .001 0 r
.47439 .74528 m
.47442 .74528 L
s
.47441 .74528 m
.47441 .74528 L
s
.47441 .74527 m
.47441 .74528 L
s
.47442 .74528 m
.47441 .74528 L
s
.47441 .74527 m
.47441 .74527 L
s
.47441 .74527 m
.47442 .74528 L
s
.47442 .74528 m
.47441 .74528 L
s
.47441 .74527 m
.47442 .74528 L
s
.47441 .74528 m
.47441 .74527 L
s
1 0 0 r
.52187 .63129 m
.52187 .63129 L
s
.52187 .63129 m
.52187 .63129 L
s
.52187 .63129 m
.52187 .63129 L
s
.52187 .63129 m
.52187 .63129 L
s
.52187 .63129 m
.52187 .63129 L
s
.52187 .63129 m
.52187 .63129 L
s
.52187 .63129 m
.52187 .63129 L
s
.52187 .63129 m
.52187 .63129 L
s
.52187 .63129 m
.52187 .63129 L
s
.47163 .60773 m
.47163 .60773 L
s
.47163 .60773 m
.47163 .60773 L
s
.47163 .60773 m
.47163 .60773 L
s
.47163 .60773 m
.47163 .60773 L
s
.47163 .60773 m
.47163 .60773 L
s
.47163 .60773 m
.47163 .60773 L
s
.47163 .60773 m
.47163 .60773 L
s
.47163 .60773 m
.47163 .60773 L
s
.47163 .60773 m
.47163 .60773 L
s
.60469 .62978 m
.60469 .62978 L
s
.60469 .62978 m
.60469 .62978 L
s
.60469 .62978 m
.60469 .62978 L
s
.60469 .62978 m
.60469 .62978 L
s
.60469 .62978 m
.60469 .62978 L
s
.60469 .62978 m
.60469 .62978 L
s
.60469 .62978 m
.60469 .62978 L
s
.60469 .62978 m
.60469 .62978 L
s
.60469 .62978 m
.60469 .62978 L
s
.50691 .72032 m
.50693 .72031 L
s
.50693 .72032 m
.50693 .72032 L
s
.50693 .72031 m
.50693 .72032 L
s
.50693 .72031 m
.50693 .72032 L
s
.50693 .72031 m
.50693 .72031 L
s
.50693 .72031 m
.50693 .72031 L
s
.50693 .72032 m
.50693 .72031 L
s
.50693 .72031 m
.50693 .72032 L
s
.50693 .72031 m
.50693 .72031 L
s
.55446 .60619 m
.55446 .60619 L
s
.55446 .60619 m
.55446 .60619 L
s
.55446 .60619 m
.55446 .60619 L
s
.55446 .60619 m
.55446 .60619 L
s
.55446 .60619 m
.55446 .60619 L
s
.55446 .60619 m
.55446 .60619 L
s
.55446 .60619 m
.55446 .60619 L
s
.55446 .60619 m
.55446 .60619 L
s
.55446 .60619 m
.55446 .60619 L
s
.45663 .69676 m
.45664 .69676 L
s
.45664 .69676 m
.45664 .69676 L
s
.45664 .69676 m
.45664 .69676 L
s
.45664 .69676 m
.45664 .69676 L
s
.45664 .69676 m
.45664 .69676 L
s
.45664 .69676 m
.45664 .69676 L
s
.45664 .69676 m
.45664 .69676 L
s
.45664 .69676 m
.45664 .69676 L
s
.45664 .69676 m
.45664 .69676 L
s
.63741 .60465 m
.63741 .60465 L
s
.63741 .60465 m
.63741 .60465 L
s
.63741 .60465 m
.63741 .60465 L
s
.63741 .60465 m
.63741 .60465 L
s
.63741 .60465 m
.63741 .60465 L
s
.63741 .60465 m
.63741 .60465 L
s
.63741 .60465 m
.63741 .60465 L
s
.63741 .60465 m
.63741 .60465 L
s
.63741 .60465 m
.63741 .60465 L
s
.53952 .6953 m
.53953 .69529 L
s
.53953 .69529 m
.53953 .6953 L
s
.53953 .69529 m
.53953 .69529 L
s
.53953 .69529 m
.53953 .69529 L
s
.53953 .69529 m
.53953 .69529 L
s
.53953 .69529 m
.53953 .69529 L
s
.53953 .6953 m
.53953 .69529 L
s
.53953 .69529 m
.53953 .6953 L
s
.53953 .69529 m
.53953 .69529 L
s
.48919 .6717 m
.48919 .6717 L
s
.48919 .6717 m
.48919 .6717 L
s
.48919 .6717 m
.48919 .6717 L
s
.48919 .6717 m
.48919 .6717 L
s
.48919 .6717 m
.48919 .6717 L
s
.48919 .6717 m
.48919 .6717 L
s
.48919 .6717 m
.48919 .6717 L
s
.48919 .6717 m
.48919 .6717 L
s
.48919 .6717 m
.48919 .6717 L
s
.43881 .64809 m
.43881 .64809 L
s
.43881 .64809 m
.43881 .64809 L
s
.43881 .64809 m
.43881 .64809 L
s
.43881 .64809 m
.43881 .64809 L
s
.43881 .64809 m
.43881 .64809 L
s
.43881 .64809 m
.43881 .64809 L
s
.43881 .64809 m
.43881 .64809 L
s
.43881 .64809 m
.43881 .64809 L
s
.43881 .64809 m
.43881 .64809 L
s
.57221 .67021 m
.57221 .67021 L
s
.57221 .67021 m
.57221 .67021 L
s
.57221 .67021 m
.57221 .67021 L
s
.57221 .67021 m
.57221 .67021 L
s
.57221 .67021 m
.57221 .67021 L
s
.57221 .67021 m
.57221 .67021 L
s
.57221 .67021 m
.57221 .67021 L
s
.57221 .67021 m
.57221 .67021 L
s
.57221 .67021 m
.57221 .67021 L
s
1 .001 0 r
.47416 .761 m
.47421 .76099 L
s
.47421 .76099 m
.4742 .761 L
s
.4742 .76098 m
.47421 .76099 L
s
.47421 .76099 m
.47421 .76099 L
s
.4742 .76099 m
.4742 .76098 L
s
.4742 .76098 m
.47421 .76099 L
s
.47421 .76099 m
.4742 .761 L
s
.4742 .76099 m
.47421 .76099 L
s
.4742 .761 m
.4742 .76099 L
s
1 0 0 r
.52183 .64658 m
.52183 .64658 L
s
.52183 .64658 m
.52183 .64658 L
s
.52183 .64658 m
.52183 .64658 L
s
.52183 .64658 m
.52183 .64658 L
s
.52183 .64658 m
.52183 .64658 L
s
.52183 .64658 m
.52183 .64658 L
s
.52183 .64658 m
.52183 .64658 L
s
.52183 .64658 m
.52183 .64658 L
s
.52183 .64658 m
.52183 .64658 L
s
.4714 .62293 m
.4714 .62293 L
s
.4714 .62293 m
.4714 .62293 L
s
.4714 .62293 m
.4714 .62293 L
s
.4714 .62293 m
.4714 .62293 L
s
.4714 .62293 m
.4714 .62293 L
s
.4714 .62293 m
.4714 .62293 L
s
.4714 .62293 m
.4714 .62293 L
s
.4714 .62293 m
.4714 .62293 L
s
.4714 .62293 m
.4714 .62293 L
s
.60497 .64507 m
.60497 .64507 L
s
.60497 .64507 m
.60497 .64507 L
s
.60497 .64507 m
.60497 .64507 L
s
.60497 .64507 m
.60497 .64507 L
s
.60497 .64507 m
.60497 .64507 L
s
.60497 .64507 m
.60497 .64507 L
s
.60497 .64507 m
.60497 .64507 L
s
.60497 .64507 m
.60497 .64507 L
s
.60497 .64507 m
.60497 .64507 L
s
.42094 .59926 m
.42094 .59926 L
s
.42094 .59926 m
.42094 .59926 L
s
.42094 .59926 m
.42094 .59926 L
s
.42094 .59926 m
.42094 .59926 L
s
.42094 .59926 m
.42094 .59926 L
s
.42094 .59926 m
.42094 .59926 L
s
.42094 .59926 m
.42094 .59926 L
s
.42094 .59926 m
.42094 .59926 L
s
.42094 .59926 m
.42094 .59926 L
s
1 .001 0 r
.50682 .73596 m
.50685 .73595 L
s
.50684 .73595 m
.50684 .73596 L
s
.50684 .73595 m
.50684 .73595 L
s
.50685 .73595 m
.50684 .73595 L
s
.50684 .73595 m
.50684 .73595 L
s
.50684 .73595 m
.50685 .73595 L
s
.50684 .73596 m
.50684 .73595 L
s
.50685 .73595 m
.50684 .73596 L
s
.50684 .73595 m
.50685 .73595 L
s
1 0 0 r
.55454 .6214 m
.55454 .6214 L
s
.55454 .6214 m
.55454 .6214 L
s
.55454 .6214 m
.55454 .6214 L
s
.55454 .6214 m
.55454 .6214 L
s
.55454 .6214 m
.55454 .6214 L
s
.55454 .6214 m
.55454 .6214 L
s
.55454 .6214 m
.55454 .6214 L
s
.55454 .6214 m
.55454 .6214 L
s
.55454 .6214 m
.55454 .6214 L
s
.45634 .71232 m
.45636 .71231 L
s
.45636 .71232 m
.45636 .71232 L
s
.45636 .71231 m
.45636 .71232 L
s
.45636 .71231 m
.45636 .71232 L
s
.45636 .71231 m
.45636 .71231 L
s
.45636 .71231 m
.45636 .71231 L
s
.45636 .71231 m
.45636 .71232 L
s
.45636 .71231 m
.45636 .71231 L
s
.45636 .71232 m
.45636 .71231 L
s
.50407 .59771 m
.50407 .59771 L
s
.50407 .59771 m
.50407 .59771 L
s
.50407 .59771 m
.50407 .59771 L
s
.50407 .59771 m
.50407 .59771 L
s
.50407 .59771 m
.50407 .59771 L
s
.50407 .59771 m
.50407 .59771 L
s
.50407 .59771 m
.50407 .59771 L
s
.50407 .59771 m
.50407 .59771 L
s
.50407 .59771 m
.50407 .59771 L
s
.63781 .61987 m
.63781 .61987 L
s
.63781 .61987 m
.63781 .61987 L
s
.63781 .61987 m
.63781 .61987 L
s
.63781 .61987 m
.63781 .61987 L
s
.63781 .61987 m
.63781 .61987 L
s
.63781 .61987 m
.63781 .61987 L
s
.63781 .61987 m
.63781 .61987 L
s
.63781 .61987 m
.63781 .61987 L
s
.63781 .61987 m
.63781 .61987 L
s
.53955 .71086 m
.53957 .71085 L
s
.53956 .71086 m
.53956 .71086 L
s
.53956 .71085 m
.53956 .71086 L
s
.53957 .71085 m
.53956 .71086 L
s
.53956 .71085 m
.53956 .71085 L
s
.53956 .71085 m
.53957 .71085 L
s
.53956 .71086 m
.53956 .71085 L
s
.53957 .71085 m
.53956 .71086 L
s
.53956 .71085 m
.53957 .71085 L
s
.58734 .59616 m
.58734 .59616 L
s
.58734 .59616 m
.58734 .59616 L
s
.58734 .59616 m
.58734 .59616 L
s
.58734 .59616 m
.58734 .59616 L
s
.58734 .59616 m
.58734 .59616 L
s
.58734 .59616 m
.58734 .59616 L
s
.58734 .59616 m
.58734 .59616 L
s
.58734 .59616 m
.58734 .59616 L
s
.58734 .59616 m
.58734 .59616 L
s
.48902 .68718 m
.48904 .68718 L
s
.48903 .68718 m
.48903 .68718 L
s
.48903 .68718 m
.48903 .68718 L
s
.48904 .68718 m
.48903 .68718 L
s
.48903 .68718 m
.48903 .68718 L
s
.48903 .68718 m
.48904 .68718 L
s
.48903 .68718 m
.48903 .68718 L
s
.48904 .68718 m
.48903 .68718 L
s
.48903 .68718 m
.48904 .68718 L
s
.43845 .66349 m
.43846 .66348 L
s
.43846 .66348 m
.43846 .66348 L
s
.43846 .66348 m
.43846 .66348 L
s
.43846 .66348 m
.43846 .66348 L
s
.43846 .66348 m
.43846 .66348 L
s
.43846 .66348 m
.43846 .66348 L
s
.43846 .66348 m
.43846 .66348 L
s
.43846 .66348 m
.43846 .66348 L
s
.43846 .66348 m
.43846 .66348 L
s
.67073 .59461 m
.67073 .59461 L
s
.67073 .59461 m
.67073 .59461 L
s
.67073 .59461 m
.67073 .59461 L
s
.67073 .59461 m
.67073 .59461 L
s
.67073 .59461 m
.67073 .59461 L
s
.67073 .59461 m
.67073 .59461 L
s
.67073 .59461 m
.67073 .59461 L
s
.67073 .59461 m
.67073 .59461 L
s
.67073 .59461 m
.67073 .59461 L
s
.57236 .6857 m
.57237 .6857 L
s
.57237 .6857 m
.57236 .6857 L
s
.57236 .6857 m
.57237 .6857 L
s
.57237 .6857 m
.57237 .6857 L
s
.57236 .6857 m
.57236 .6857 L
s
.57236 .6857 m
.57237 .6857 L
s
.57236 .6857 m
.57236 .6857 L
s
.57237 .6857 m
.57236 .6857 L
s
.57236 .6857 m
.57237 .6857 L
s
1 .001 0 r
.47394 .77684 m
.47401 .77682 L
s
.474 .77683 m
.474 .77683 L
s
.474 .77681 m
.474 .77683 L
s
.47401 .77682 m
.474 .77683 L
s
.47399 .77682 m
.474 .77681 L
s
.474 .77681 m
.47401 .77682 L
s
.47401 .77682 m
.474 .77683 L
s
.47399 .77682 m
.47401 .77682 L
s
.474 .77683 m
.47399 .77682 L
s
1 0 0 r
.52179 .66198 m
.52179 .66198 L
s
.52179 .66198 m
.52179 .66198 L
s
.52179 .66198 m
.52179 .66198 L
s
.52179 .66198 m
.52179 .66198 L
s
.52179 .66198 m
.52179 .66198 L
s
.52179 .66198 m
.52179 .66198 L
s
.52179 .66198 m
.52179 .66198 L
s
.52179 .66198 m
.52179 .66198 L
s
.52179 .66198 m
.52179 .66198 L
s
.47117 .63825 m
.47117 .63825 L
s
.47117 .63825 m
.47117 .63825 L
s
.47117 .63825 m
.47117 .63825 L
s
.47117 .63825 m
.47117 .63825 L
s
.47117 .63825 m
.47117 .63825 L
s
.47117 .63825 m
.47117 .63825 L
s
.47117 .63825 m
.47117 .63825 L
s
.47117 .63825 m
.47117 .63825 L
s
.47117 .63825 m
.47117 .63825 L
s
.60524 .66048 m
.60525 .66048 L
s
.60525 .66048 m
.60525 .66048 L
s
.60525 .66048 m
.60525 .66048 L
s
.60525 .66048 m
.60525 .66048 L
s
.60525 .66048 m
.60525 .66048 L
s
.60525 .66048 m
.60525 .66048 L
s
.60525 .66048 m
.60525 .66048 L
s
.60525 .66048 m
.60525 .66048 L
s
.60525 .66048 m
.60525 .66048 L
s
.42051 .61449 m
.42051 .61449 L
s
.42051 .61449 m
.42051 .61449 L
s
.42051 .61449 m
.42051 .61449 L
s
.42051 .61449 m
.42051 .61449 L
s
.42051 .61449 m
.42051 .61449 L
s
.42051 .61449 m
.42051 .61449 L
s
.42051 .61449 m
.42051 .61449 L
s
.42051 .61449 m
.42051 .61449 L
s
.42051 .61449 m
.42051 .61449 L
s
1 .001 0 r
.50672 .75172 m
.50677 .7517 L
s
.50676 .75171 m
.50676 .75171 L
s
.50676 .7517 m
.50676 .75171 L
s
.50677 .7517 m
.50676 .75171 L
s
.50675 .7517 m
.50676 .7517 L
s
.50676 .7517 m
.50677 .7517 L
s
.50676 .75171 m
.50675 .7517 L
s
.50677 .7517 m
.50676 .75171 L
s
.50675 .7517 m
.50677 .7517 L
s
1 0 0 r
.55463 .63673 m
.55463 .63672 L
s
.55463 .63672 m
.55463 .63672 L
s
.55463 .63672 m
.55463 .63672 L
s
.55463 .63672 m
.55463 .63672 L
s
.55463 .63672 m
.55463 .63672 L
s
.55463 .63672 m
.55463 .63672 L
s
.55463 .63672 m
.55463 .63672 L
s
.55463 .63672 m
.55463 .63672 L
s
.55463 .63672 m
.55463 .63672 L
s
1 .001 0 r
.45605 .728 m
.45609 .72799 L
s
.45609 .72799 m
.45608 .72799 L
s
.45608 .72798 m
.45609 .72799 L
s
.45609 .72799 m
.45609 .72799 L
s
.45608 .72798 m
.45608 .72798 L
s
.45608 .72798 m
.45609 .72799 L
s
.45609 .72799 m
.45608 .72799 L
s
.45608 .72798 m
.45609 .72799 L
s
.45608 .72799 m
.45608 .72798 L
s
1 0 0 r
.50396 .61295 m
.50397 .61295 L
s
.50397 .61295 m
.50397 .61295 L
s
.50397 .61295 m
.50397 .61295 L
s
.50397 .61295 m
.50397 .61295 L
s
.50396 .61295 m
.50397 .61295 L
s
.50397 .61295 m
.50397 .61295 L
s
.50397 .61295 m
.50396 .61295 L
s
.50397 .61295 m
.50397 .61295 L
s
.50396 .61295 m
.50397 .61295 L
s
.63821 .6352 m
.63821 .6352 L
s
.63821 .6352 m
.63821 .6352 L
s
.63821 .6352 m
.63821 .6352 L
s
.63821 .6352 m
.63821 .6352 L
s
.63821 .6352 m
.63821 .6352 L
s
.63821 .6352 m
.63821 .6352 L
s
.63821 .6352 m
.63821 .6352 L
s
.63821 .6352 m
.63821 .6352 L
s
.63821 .6352 m
.63821 .6352 L
s
.45326 .58915 m
.45326 .58915 L
s
.45326 .58915 m
.45326 .58915 L
s
.45326 .58915 m
.45326 .58915 L
s
.45326 .58915 m
.45326 .58915 L
s
.45326 .58915 m
.45326 .58915 L
s
.45326 .58915 m
.45326 .58915 L
s
.45326 .58915 m
.45326 .58915 L
s
.45326 .58915 m
.45326 .58915 L
s
.45326 .58915 m
.45326 .58915 L
s
1 .001 0 r
.53958 .72654 m
.5396 .72653 L
s
.5396 .72654 m
.5396 .72654 L
s
.5396 .72653 m
.5396 .72654 L
s
.5396 .72653 m
.5396 .72654 L
s
.53959 .72653 m
.5396 .72653 L
s
.5396 .72653 m
.5396 .72653 L
s
.5396 .72654 m
.53959 .72653 L
s
.5396 .72653 m
.5396 .72654 L
s
.53959 .72653 m
.5396 .72653 L
s
1 0 0 r
.58755 .61141 m
.58755 .61141 L
s
.58755 .61141 m
.58755 .61141 L
s
.58755 .61141 m
.58755 .61141 L
s
.58755 .61141 m
.58755 .61141 L
s
.58755 .61141 m
.58755 .61141 L
s
.58755 .61141 m
.58755 .61141 L
s
.58755 .61141 m
.58755 .61141 L
s
.58755 .61141 m
.58755 .61141 L
s
.58755 .61141 m
.58755 .61141 L
s
.48886 .70278 m
.48888 .70277 L
s
.48888 .70278 m
.48888 .70278 L
s
.48888 .70277 m
.48888 .70278 L
s
.48888 .70277 m
.48888 .70278 L
s
.48887 .70277 m
.48888 .70277 L
s
.48888 .70277 m
.48888 .70277 L
s
.48888 .70278 m
.48887 .70277 L
s
.48888 .70277 m
.48888 .70278 L
s
.48887 .70277 m
.48888 .70277 L
s
.53684 .58759 m
.53684 .58759 L
s
.53684 .58759 m
.53684 .58759 L
s
.53684 .58759 m
.53684 .58759 L
s
.53684 .58759 m
.53684 .58759 L
s
.53684 .58759 m
.53684 .58759 L
s
.53684 .58759 m
.53684 .58759 L
s
.53684 .58759 m
.53684 .58759 L
s
.53684 .58759 m
.53684 .58759 L
s
.53684 .58759 m
.53684 .58759 L
s
.43809 .679 m
.43811 .67899 L
s
.43811 .679 m
.43811 .679 L
s
.43811 .67899 m
.43811 .679 L
s
.43811 .67899 m
.43811 .679 L
s
.43811 .67899 m
.43811 .67899 L
s
.43811 .67899 m
.43811 .67899 L
s
.43811 .67899 m
.43811 .679 L
s
.43811 .67899 m
.43811 .67899 L
s
.43811 .679 m
.43811 .67899 L
s
.67126 .60986 m
.67126 .60986 L
s
.67126 .60986 m
.67126 .60986 L
s
.67126 .60986 m
.67126 .60986 L
s
.67126 .60986 m
.67126 .60986 L
s
.67126 .60986 m
.67126 .60986 L
s
.67126 .60986 m
.67126 .60986 L
s
.67126 .60986 m
.67126 .60986 L
s
.67126 .60986 m
.67126 .60986 L
s
.67126 .60986 m
.67126 .60986 L
s
.57251 .70131 m
.57253 .7013 L
s
.57252 .7013 m
.57252 .7013 L
s
.57252 .7013 m
.57252 .7013 L
s
.57253 .7013 m
.57252 .7013 L
s
.57252 .7013 m
.57252 .7013 L
s
.57252 .7013 m
.57253 .7013 L
s
.57252 .7013 m
.57252 .7013 L
s
.57253 .7013 m
.57252 .7013 L
s
.57252 .7013 m
.57253 .7013 L
s
.62054 .58603 m
.62054 .58603 L
s
.62054 .58603 m
.62054 .58603 L
s
.62054 .58603 m
.62054 .58603 L
s
.62054 .58603 m
.62054 .58603 L
s
.62054 .58603 m
.62054 .58603 L
s
.62054 .58603 m
.62054 .58603 L
s
.62054 .58603 m
.62054 .58603 L
s
.62054 .58603 m
.62054 .58603 L
s
.62054 .58603 m
.62054 .58603 L
s
1 .002 0 r
.47372 .79279 m
.47381 .79277 L
s
.4738 .79278 m
.47379 .79279 L
s
.4738 .79276 m
.4738 .79278 L
s
.47381 .79277 m
.4738 .79278 L
s
.47379 .79276 m
.4738 .79276 L
s
.4738 .79276 m
.47381 .79277 L
s
.47381 .79277 m
.47379 .79279 L
s
.47379 .79276 m
.47381 .79277 L
s
.47379 .79279 m
.47379 .79276 L
s
1 0 0 r
.52174 .67751 m
.52176 .6775 L
s
.52176 .6775 m
.52175 .6775 L
s
.52175 .6775 m
.52176 .6775 L
s
.52176 .6775 m
.52176 .6775 L
s
.52175 .6775 m
.52175 .6775 L
s
.52175 .6775 m
.52176 .6775 L
s
.52175 .6775 m
.52175 .6775 L
s
.52176 .6775 m
.52175 .6775 L
s
.52175 .6775 m
.52176 .6775 L
s
.47094 .65368 m
.47094 .65368 L
s
.47094 .65368 m
.47094 .65368 L
s
.47094 .65368 m
.47094 .65368 L
s
.47094 .65368 m
.47094 .65368 L
s
.47094 .65368 m
.47094 .65368 L
s
.47094 .65368 m
.47094 .65368 L
s
.47094 .65368 m
.47094 .65368 L
s
.47094 .65368 m
.47094 .65368 L
s
.47094 .65368 m
.47094 .65368 L
s
.70438 .58446 m
.70438 .58446 L
s
.70438 .58446 m
.70438 .58446 L
s
.70438 .58446 m
.70438 .58446 L
s
.70438 .58446 m
.70438 .58446 L
s
.70438 .58446 m
.70438 .58446 L
s
.70438 .58446 m
.70438 .58446 L
s
.70438 .58446 m
.70438 .58446 L
s
.70438 .58446 m
.70438 .58446 L
s
.70438 .58446 m
.70438 .58446 L
s
.60552 .67601 m
.60553 .676 L
s
.60553 .676 m
.60553 .67601 L
s
.60553 .676 m
.60553 .676 L
s
.60553 .676 m
.60553 .676 L
s
.60553 .67601 m
.60553 .67601 L
s
.60553 .676 m
.60553 .67601 L
s
.60553 .67601 m
.60553 .676 L
s
.60553 .676 m
.60553 .676 L
s
.60553 .676 m
.60553 .67601 L
s
.42008 .62984 m
.42009 .62984 L
s
.42009 .62984 m
.42009 .62984 L
s
.42009 .62984 m
.42009 .62984 L
s
.42009 .62984 m
.42009 .62984 L
s
.42009 .62984 m
.42009 .62984 L
s
.42009 .62984 m
.42009 .62984 L
s
.42009 .62984 m
.42009 .62984 L
s
.42009 .62984 m
.42009 .62984 L
s
.42009 .62984 m
.42009 .62984 L
s
1 .001 0 r
.50662 .7676 m
.50669 .76758 L
s
.50668 .76759 m
.50667 .76759 L
s
.50667 .76757 m
.50668 .76759 L
s
.50669 .76758 m
.50668 .76759 L
s
.50667 .76758 m
.50667 .76757 L
s
.50667 .76757 m
.50669 .76758 L
s
.50667 .76759 m
.50667 .76758 L
s
.50669 .76758 m
.50667 .76759 L
s
.50667 .76758 m
.50669 .76758 L
s
1 0 0 r
.55471 .65217 m
.55472 .65217 L
s
.55472 .65217 m
.55471 .65217 L
s
.55471 .65217 m
.55472 .65217 L
s
.55472 .65217 m
.55472 .65217 L
s
.55471 .65217 m
.55471 .65217 L
s
.55471 .65217 m
.55472 .65217 L
s
.55471 .65217 m
.55471 .65217 L
s
.55472 .65217 m
.55471 .65217 L
s
.55471 .65217 m
.55472 .65217 L
s
1 .001 0 r
.45575 .74379 m
.45582 .74377 L
s
.45581 .74378 m
.45581 .74379 L
s
.45581 .74377 m
.45581 .74378 L
s
.45582 .74377 m
.45581 .74378 L
s
.4558 .74377 m
.45581 .74377 L
s
.45581 .74377 m
.45582 .74377 L
s
.45582 .74377 m
.45581 .74379 L
s
.4558 .74377 m
.45582 .74377 L
s
.45581 .74379 m
.4558 .74377 L
s
1 0 0 r
.50386 .62831 m
.50386 .62831 L
s
.50386 .62831 m
.50386 .62831 L
s
.50386 .62831 m
.50386 .62831 L
s
.50386 .62831 m
.50386 .62831 L
s
.50386 .62831 m
.50386 .62831 L
s
.50386 .62831 m
.50386 .62831 L
s
.50386 .62831 m
.50386 .62831 L
s
.50386 .62831 m
.50386 .62831 L
s
.50386 .62831 m
.50386 .62831 L
s
.63862 .65065 m
.63862 .65065 L
s
.63862 .65065 m
.63862 .65065 L
s
.63862 .65065 m
.63862 .65065 L
s
.63862 .65065 m
.63862 .65065 L
s
.63862 .65065 m
.63862 .65065 L
s
.63862 .65065 m
.63862 .65065 L
s
.63862 .65065 m
.63862 .65065 L
s
.63862 .65065 m
.63862 .65065 L
s
.63862 .65065 m
.63862 .65065 L
s
.45296 .60443 m
.45296 .60443 L
s
.45296 .60443 m
.45296 .60443 L
s
.45296 .60443 m
.45296 .60443 L
s
.45296 .60443 m
.45296 .60443 L
s
.45296 .60443 m
.45296 .60443 L
s
.45296 .60443 m
.45296 .60443 L
s
.45296 .60443 m
.45296 .60443 L
s
.45296 .60443 m
.45296 .60443 L
s
.45296 .60443 m
.45296 .60443 L
s
1 .001 0 r
.5396 .74235 m
.53965 .74233 L
s
.53964 .74233 m
.53964 .74234 L
s
.53964 .74232 m
.53964 .74233 L
s
.53965 .74233 m
.53964 .74233 L
s
.53963 .74233 m
.53964 .74232 L
s
.53964 .74232 m
.53965 .74233 L
s
.53964 .74234 m
.53963 .74233 L
s
.53965 .74233 m
.53964 .74234 L
s
.53963 .74233 m
.53965 .74233 L
s
1 0 0 r
.58776 .62677 m
.58776 .62677 L
s
.58776 .62677 m
.58776 .62677 L
s
.58776 .62677 m
.58776 .62677 L
s
.58776 .62677 m
.58776 .62677 L
s
.58776 .62677 m
.58776 .62677 L
s
.58776 .62677 m
.58776 .62677 L
s
.58776 .62677 m
.58776 .62677 L
s
.58776 .62677 m
.58776 .62677 L
s
.58776 .62677 m
.58776 .62677 L
s
.40201 .58053 m
.40201 .58053 L
s
.40201 .58053 m
.40201 .58053 L
s
.40201 .58053 m
.40201 .58053 L
s
.40201 .58053 m
.40201 .58053 L
s
.40201 .58053 m
.40201 .58053 L
s
.40201 .58053 m
.40201 .58053 L
s
.40201 .58053 m
.40201 .58053 L
s
.40201 .58053 m
.40201 .58053 L
s
.40201 .58053 m
.40201 .58053 L
s
1 .001 0 r
.48869 .7185 m
.48873 .71849 L
s
.48873 .71849 m
.48872 .71849 L
s
.48872 .71848 m
.48873 .71849 L
s
.48873 .71849 m
.48873 .71849 L
s
.48872 .71849 m
.48872 .71848 L
s
.48872 .71848 m
.48873 .71849 L
s
.48872 .71849 m
.48872 .71849 L
s
.48873 .71849 m
.48872 .71849 L
s
.48872 .71849 m
.48873 .71849 L
s
1 0 0 r
.53685 .60287 m
.53685 .60287 L
s
.53685 .60287 m
.53685 .60287 L
s
.53685 .60287 m
.53685 .60287 L
s
.53685 .60287 m
.53685 .60287 L
s
.53685 .60287 m
.53685 .60287 L
s
.53685 .60287 m
.53685 .60287 L
s
.53685 .60287 m
.53685 .60287 L
s
.53685 .60287 m
.53685 .60287 L
s
.53685 .60287 m
.53685 .60287 L
s
1 .001 0 r
.43773 .69463 m
.43777 .69462 L
s
.43776 .69463 m
.43776 .69463 L
s
.43776 .69462 m
.43776 .69463 L
s
.43777 .69462 m
.43776 .69463 L
s
.43776 .69462 m
.43776 .69462 L
s
.43776 .69462 m
.43777 .69462 L
s
.43777 .69462 m
.43776 .69463 L
s
.43776 .69462 m
.43777 .69462 L
s
.43776 .69463 m
.43776 .69462 L
s
1 0 0 r
.67179 .62523 m
.67179 .62523 L
s
.67179 .62523 m
.67179 .62523 L
s
.67179 .62523 m
.67179 .62523 L
s
.67179 .62523 m
.67179 .62523 L
s
.67179 .62523 m
.67179 .62523 L
s
.67179 .62523 m
.67179 .62523 L
s
.67179 .62523 m
.67179 .62523 L
s
.67179 .62523 m
.67179 .62523 L
s
.67179 .62523 m
.67179 .62523 L
s
.48591 .57895 m
.48591 .57895 L
s
.48591 .57895 m
.48591 .57895 L
s
.48591 .57895 m
.48591 .57895 L
s
.48591 .57895 m
.48591 .57895 L
s
.48591 .57895 m
.48591 .57895 L
s
.48591 .57895 m
.48591 .57895 L
s
.48591 .57895 m
.48591 .57895 L
s
.48591 .57895 m
.48591 .57895 L
s
.48591 .57895 m
.48591 .57895 L
s
1 .001 0 r
.57266 .71703 m
.57269 .71702 L
s
.57269 .71702 m
.57268 .71702 L
s
.57268 .71702 m
.57269 .71702 L
s
.57269 .71702 m
.57269 .71702 L
s
.57268 .71702 m
.57268 .71702 L
s
.57268 .71702 m
.57269 .71702 L
s
.57268 .71702 m
.57268 .71702 L
s
.57269 .71702 m
.57268 .71702 L
s
.57268 .71702 m
.57269 .71702 L
s
1 0 0 r
.62088 .60131 m
.62088 .60131 L
s
.62088 .60131 m
.62088 .60131 L
s
.62088 .60131 m
.62088 .60131 L
s
.62088 .60131 m
.62088 .60131 L
s
.62088 .60131 m
.62088 .60131 L
s
.62088 .60131 m
.62088 .60131 L
s
.62088 .60131 m
.62088 .60131 L
s
.62088 .60131 m
.62088 .60131 L
s
.62088 .60131 m
.62088 .60131 L
s
1 .002 0 r
.47349 .80887 m
.47362 .80884 L
s
.4736 .80885 m
.47359 .80886 L
s
.47359 .80883 m
.4736 .80885 L
s
.47362 .80884 m
.4736 .80885 L
s
.47358 .80883 m
.47359 .80883 L
s
.47359 .80883 m
.47362 .80884 L
s
.47362 .80884 m
.47359 .80886 L
s
.47358 .80883 m
.47362 .80884 L
s
.47359 .80886 m
.47358 .80883 L
s
1 0 0 r
.5217 .69315 m
.52173 .69314 L
s
.52172 .69314 m
.52172 .69314 L
s
.52172 .69313 m
.52172 .69314 L
s
.52173 .69314 m
.52172 .69314 L
s
.52172 .69314 m
.52172 .69313 L
s
.52172 .69313 m
.52173 .69314 L
s
.52172 .69314 m
.52172 .69314 L
s
.52173 .69314 m
.52172 .69314 L
s
.52172 .69314 m
.52173 .69314 L
s
.56993 .57737 m
.56993 .57737 L
s
.56993 .57737 m
.56993 .57737 L
s
.56993 .57737 m
.56993 .57737 L
s
.56993 .57737 m
.56993 .57737 L
s
.56993 .57737 m
.56993 .57737 L
s
.56993 .57737 m
.56993 .57737 L
s
.56993 .57737 m
.56993 .57737 L
s
.56993 .57737 m
.56993 .57737 L
s
.56993 .57737 m
.56993 .57737 L
s
.4707 .66924 m
.47072 .66923 L
s
.47072 .66924 m
.47071 .66924 L
s
.47071 .66923 m
.47072 .66924 L
s
.47072 .66923 m
.47072 .66924 L
s
.47071 .66923 m
.47071 .66923 L
s
.47071 .66923 m
.47072 .66923 L
s
.47071 .66924 m
.47071 .66923 L
s
.47072 .66923 m
.47071 .66924 L
s
.47071 .66923 m
.47072 .66923 L
s
.70504 .59975 m
.70504 .59975 L
s
.70504 .59975 m
.70504 .59975 L
s
.70504 .59975 m
.70504 .59975 L
s
.70504 .59975 m
.70504 .59975 L
s
.70504 .59975 m
.70504 .59975 L
s
.70504 .59975 m
.70504 .59975 L
s
.70504 .59975 m
.70504 .59975 L
s
.70504 .59975 m
.70504 .59975 L
s
.70504 .59975 m
.70504 .59975 L
s
.6058 .69165 m
.60582 .69165 L
s
.60581 .69165 m
.60582 .69165 L
s
.60581 .69165 m
.60581 .69165 L
s
.60581 .69165 m
.60582 .69165 L
s
.60582 .69165 m
.60581 .69165 L
s
.60582 .69165 m
.60582 .69165 L
s
.60581 .69165 m
.60581 .69165 L
s
.60581 .69165 m
.60582 .69165 L
s
.60582 .69165 m
.60581 .69165 L
s
.41965 .64531 m
.41966 .64531 L
s
.41966 .64531 m
.41966 .64531 L
s
.41966 .64531 m
.41966 .64531 L
s
.41966 .64531 m
.41966 .64531 L
s
.41966 .64531 m
.41966 .64531 L
s
.41966 .64531 m
.41966 .64531 L
s
.41966 .64531 m
.41966 .64531 L
s
.41966 .64531 m
.41966 .64531 L
s
.41966 .64531 m
.41966 .64531 L
s
.65409 .57579 m
.65409 .57579 L
s
.65409 .57579 m
.65409 .57579 L
s
.65409 .57579 m
.65409 .57579 L
s
.65409 .57579 m
.65409 .57579 L
s
.65409 .57579 m
.65409 .57579 L
s
.65409 .57579 m
.65409 .57579 L
s
.65409 .57579 m
.65409 .57579 L
s
.65409 .57579 m
.65409 .57579 L
s
.65409 .57579 m
.65409 .57579 L
s
1 .002 0 r
.50652 .7836 m
.50661 .78357 L
s
.5066 .78358 m
.50659 .78359 L
s
.50659 .78356 m
.5066 .78358 L
s
.50661 .78357 m
.5066 .78358 L
s
.50659 .78357 m
.50659 .78356 L
s
.50659 .78356 m
.50661 .78357 L
s
.50659 .78359 m
.50659 .78357 L
s
.50661 .78357 m
.50659 .78359 L
s
.50659 .78357 m
.50661 .78357 L
s
1 0 0 r
.5548 .66773 m
.55481 .66772 L
s
.55481 .66773 m
.5548 .66773 L
s
.5548 .66772 m
.55481 .66773 L
s
.55481 .66772 m
.55481 .66773 L
s
.5548 .66772 m
.5548 .66772 L
s
.5548 .66772 m
.55481 .66772 L
s
.5548 .66773 m
.5548 .66772 L
s
.55481 .66772 m
.5548 .66773 L
s
.5548 .66772 m
.55481 .66772 L
s
1 .002 0 r
.45546 .75971 m
.45555 .75968 L
s
.45554 .7597 m
.45553 .7597 L
s
.45553 .75968 m
.45554 .7597 L
s
.45555 .75968 m
.45554 .7597 L
s
.45553 .75968 m
.45553 .75968 L
s
.45553 .75968 m
.45555 .75968 L
s
.45555 .75968 m
.45553 .7597 L
s
.45553 .75968 m
.45555 .75968 L
s
.45553 .7597 m
.45553 .75968 L
s
1 0 0 r
.50375 .64378 m
.50375 .64378 L
s
.50375 .64378 m
.50375 .64378 L
s
.50375 .64378 m
.50375 .64378 L
s
.50375 .64378 m
.50375 .64378 L
s
.50375 .64378 m
.50375 .64378 L
s
.50375 .64378 m
.50375 .64378 L
s
.50375 .64378 m
.50375 .64378 L
s
.50375 .64378 m
.50375 .64378 L
s
.50375 .64378 m
.50375 .64378 L
s
.73837 .57421 m
.73837 .57421 L
s
.73837 .57421 m
.73837 .57421 L
s
.73837 .57421 m
.73837 .57421 L
s
.73837 .57421 m
.73837 .57421 L
s
.73837 .57421 m
.73837 .57421 L
s
.73837 .57421 m
.73837 .57421 L
s
.73837 .57421 m
.73837 .57421 L
s
.73837 .57421 m
.73837 .57421 L
s
.73837 .57421 m
.73837 .57421 L
s
.63902 .66622 m
.63903 .66621 L
s
.63903 .66621 m
.63903 .66621 L
s
.63903 .66621 m
.63903 .66621 L
s
.63903 .66621 m
.63903 .66621 L
s
.63903 .66621 m
.63903 .66621 L
s
.63903 .66621 m
.63903 .66621 L
s
.63903 .66621 m
.63903 .66621 L
s
.63903 .66621 m
.63903 .66621 L
s
.63903 .66621 m
.63903 .66621 L
s
.45265 .61982 m
.45265 .61982 L
s
.45265 .61982 m
.45265 .61982 L
s
.45265 .61982 m
.45265 .61982 L
s
.45265 .61982 m
.45265 .61982 L
s
.45265 .61982 m
.45265 .61982 L
s
.45265 .61982 m
.45265 .61982 L
s
.45265 .61982 m
.45265 .61982 L
s
.45265 .61982 m
.45265 .61982 L
s
.45265 .61982 m
.45265 .61982 L
s
1 .001 0 r
.53963 .75827 m
.53969 .75824 L
s
.53969 .75825 m
.53968 .75826 L
s
.53968 .75824 m
.53969 .75825 L
s
.53969 .75824 m
.53969 .75825 L
s
.53967 .75825 m
.53968 .75824 L
s
.53968 .75824 m
.53969 .75824 L
s
.53968 .75826 m
.53967 .75825 L
s
.53969 .75824 m
.53968 .75826 L
s
.53967 .75825 m
.53969 .75824 L
s
1 0 0 r
.58797 .64225 m
.58797 .64225 L
s
.58797 .64225 m
.58797 .64225 L
s
.58797 .64225 m
.58797 .64225 L
s
.58797 .64225 m
.58797 .64225 L
s
.58797 .64225 m
.58797 .64225 L
s
.58797 .64225 m
.58797 .64225 L
s
.58797 .64225 m
.58797 .64225 L
s
.58797 .64225 m
.58797 .64225 L
s
.58797 .64225 m
.58797 .64225 L
s
.40151 .59583 m
.40151 .59583 L
s
.40151 .59583 m
.40151 .59583 L
s
.40151 .59583 m
.40151 .59583 L
s
.40151 .59583 m
.40151 .59583 L
s
.40151 .59583 m
.40151 .59583 L
s
.40151 .59583 m
.40151 .59583 L
s
.40151 .59583 m
.40151 .59583 L
s
.40151 .59583 m
.40151 .59583 L
s
.40151 .59583 m
.40151 .59583 L
s
1 .001 0 r
.48852 .73434 m
.48858 .73432 L
s
.48858 .73433 m
.48857 .73433 L
s
.48857 .73431 m
.48858 .73433 L
s
.48858 .73432 m
.48858 .73433 L
s
.48856 .73432 m
.48857 .73431 L
s
.48857 .73431 m
.48858 .73432 L
s
.48857 .73433 m
.48856 .73432 L
s
.48858 .73432 m
.48857 .73433 L
s
.48856 .73432 m
.48858 .73432 L
s
1 0 0 r
.53687 .61827 m
.53687 .61827 L
s
.53687 .61827 m
.53687 .61827 L
s
.53687 .61827 m
.53687 .61827 L
s
.53687 .61827 m
.53687 .61827 L
s
.53687 .61827 m
.53687 .61827 L
s
.53687 .61827 m
.53687 .61827 L
s
.53687 .61827 m
.53687 .61827 L
s
.53687 .61827 m
.53687 .61827 L
s
.53687 .61827 m
.53687 .61827 L
s
1 .001 0 r
.43737 .71039 m
.43743 .71037 L
s
.43742 .71038 m
.43741 .71038 L
s
.43741 .71037 m
.43742 .71038 L
s
.43743 .71037 m
.43742 .71038 L
s
.43741 .71037 m
.43741 .71037 L
s
.43741 .71037 m
.43743 .71037 L
s
.43743 .71037 m
.43741 .71038 L
s
.43741 .71037 m
.43743 .71037 L
s
.43741 .71038 m
.43741 .71037 L
s
1 0 0 r
.67232 .64072 m
.67233 .64072 L
s
.67233 .64072 m
.67233 .64072 L
s
.67233 .64072 m
.67233 .64072 L
s
.67233 .64072 m
.67233 .64072 L
s
.67233 .64072 m
.67233 .64072 L
s
.67233 .64072 m
.67233 .64072 L
s
.67233 .64072 m
.67233 .64072 L
s
.67233 .64072 m
.67233 .64072 L
s
.67233 .64072 m
.67233 .64072 L
s
.48573 .59426 m
.48573 .59426 L
s
.48573 .59426 m
.48573 .59426 L
s
.48573 .59426 m
.48573 .59426 L
s
.48573 .59426 m
.48573 .59426 L
s
.48573 .59426 m
.48573 .59426 L
s
.48573 .59426 m
.48573 .59426 L
s
.48573 .59426 m
.48573 .59426 L
s
.48573 .59426 m
.48573 .59426 L
s
.48573 .59426 m
.48573 .59426 L
s
1 .001 0 r
.57282 .73288 m
.57286 .73286 L
s
.57285 .73286 m
.57285 .73287 L
s
.57285 .73286 m
.57285 .73286 L
s
.57286 .73286 m
.57285 .73286 L
s
.57284 .73286 m
.57285 .73286 L
s
.57285 .73286 m
.57286 .73286 L
s
.57285 .73287 m
.57284 .73286 L
s
.57286 .73286 m
.57285 .73287 L
s
.57284 .73286 m
.57286 .73286 L
s
1 0 0 r
.62122 .61671 m
.62122 .61671 L
s
.62122 .61671 m
.62122 .61671 L
s
.62122 .61671 m
.62122 .61671 L
s
.62122 .61671 m
.62122 .61671 L
s
.62122 .61671 m
.62122 .61671 L
s
.62122 .61671 m
.62122 .61671 L
s
.62122 .61671 m
.62122 .61671 L
s
.62122 .61671 m
.62122 .61671 L
s
.62122 .61671 m
.62122 .61671 L
s
1 .003 0 r
.47327 .82508 m
.47343 .82503 L
s
.47341 .82505 m
.47339 .82506 L
s
.4734 .82502 m
.47341 .82505 L
s
.47343 .82503 m
.47341 .82505 L
s
.47338 .82503 m
.4734 .82502 L
s
.4734 .82502 m
.47343 .82503 L
s
.47343 .82503 m
.47339 .82506 L
s
.47338 .82503 m
.47343 .82503 L
s
.47339 .82506 m
.47338 .82503 L
s
1 0 0 r
.43454 .57024 m
.43454 .57024 L
s
.43454 .57024 m
.43454 .57024 L
s
.43454 .57024 m
.43454 .57024 L
s
.43454 .57024 m
.43454 .57024 L
s
.43454 .57024 m
.43454 .57024 L
s
.43454 .57024 m
.43454 .57024 L
s
.43454 .57024 m
.43454 .57024 L
s
.43454 .57024 m
.43454 .57024 L
s
.43454 .57024 m
.43454 .57024 L
s
1 .001 0 r
.52166 .70891 m
.5217 .70889 L
s
.5217 .7089 m
.52169 .7089 L
s
.52169 .70889 m
.5217 .7089 L
s
.5217 .70889 m
.5217 .7089 L
s
.52169 .70889 m
.52169 .70889 L
s
.52169 .70889 m
.5217 .70889 L
s
.52169 .7089 m
.52169 .70889 L
s
.5217 .70889 m
.52169 .7089 L
s
.52169 .70889 m
.5217 .70889 L
s
1 0 0 r
.57008 .59269 m
.57008 .59269 L
s
.57008 .59269 m
.57008 .59269 L
s
.57008 .59269 m
.57008 .59269 L
s
.57008 .59269 m
.57008 .59269 L
s
.57008 .59269 m
.57008 .59269 L
s
.57008 .59269 m
.57008 .59269 L
s
.57008 .59269 m
.57008 .59269 L
s
.57008 .59269 m
.57008 .59269 L
s
.57008 .59269 m
.57008 .59269 L
s
1 .001 0 r
.47046 .68492 m
.47049 .6849 L
s
.47049 .68491 m
.47049 .68491 L
s
.47049 .6849 m
.47049 .68491 L
s
.47049 .6849 m
.47049 .68491 L
s
.47048 .6849 m
.47049 .6849 L
s
.47049 .6849 m
.47049 .6849 L
s
.47049 .68491 m
.47048 .6849 L
s
.47049 .6849 m
.47049 .68491 L
s
.47048 .6849 m
.47049 .6849 L
s
1 0 0 r
.7057 .61516 m
.70571 .61516 L
s
.70571 .61516 m
.70571 .61516 L
s
.70571 .61516 m
.70571 .61516 L
s
.70571 .61516 m
.70571 .61516 L
s
.70571 .61516 m
.70571 .61516 L
s
.70571 .61516 m
.70571 .61516 L
s
.70571 .61516 m
.70571 .61516 L
s
.70571 .61516 m
.70571 .61516 L
s
.70571 .61516 m
.70571 .61516 L
s
.51889 .56864 m
.51889 .56864 L
s
.51889 .56864 m
.51889 .56864 L
s
.51889 .56864 m
.51889 .56864 L
s
.51889 .56864 m
.51889 .56864 L
s
.51889 .56864 m
.51889 .56864 L
s
.51889 .56864 m
.51889 .56864 L
s
.51889 .56864 m
.51889 .56864 L
s
.51889 .56864 m
.51889 .56864 L
s
.51889 .56864 m
.51889 .56864 L
s
.60609 .70742 m
.60611 .70741 L
s
.6061 .70741 m
.60611 .70741 L
s
.6061 .70741 m
.6061 .70741 L
s
.6061 .70741 m
.60611 .70741 L
s
.60611 .70741 m
.6061 .70742 L
s
.60611 .70741 m
.60611 .70741 L
s
.6061 .70742 m
.6061 .70741 L
s
.6061 .70741 m
.60611 .70741 L
s
.60611 .70741 m
.6061 .70742 L
s
.41922 .6609 m
.41924 .6609 L
s
.41924 .6609 m
.41924 .6609 L
s
.41924 .66089 m
.41924 .6609 L
s
.41924 .6609 m
.41924 .6609 L
s
.41924 .66089 m
.41924 .66089 L
s
.41924 .66089 m
.41924 .6609 L
s
.41924 .6609 m
.41924 .6609 L
s
.41924 .66089 m
.41924 .6609 L
s
.41924 .6609 m
.41924 .66089 L
s
.65456 .59111 m
.65456 .59111 L
s
.65456 .59111 m
.65456 .59111 L
s
.65456 .59111 m
.65456 .59111 L
s
.65456 .59111 m
.65456 .59111 L
s
.65456 .59111 m
.65456 .59111 L
s
.65456 .59111 m
.65456 .59111 L
s
.65456 .59111 m
.65456 .59111 L
s
.65456 .59111 m
.65456 .59111 L
s
.65456 .59111 m
.65456 .59111 L
s
1 .002 0 r
.50642 .79973 m
.50654 .79969 L
s
.50653 .7997 m
.50652 .79971 L
s
.50652 .79968 m
.50653 .7997 L
s
.50654 .79969 m
.50653 .7997 L
s
.50651 .79969 m
.50652 .79968 L
s
.50652 .79968 m
.50654 .79969 L
s
.50652 .79971 m
.50651 .79969 L
s
.50654 .79969 m
.50652 .79971 L
s
.50651 .79969 m
.50654 .79969 L
s
1 0 0 r
.55488 .68341 m
.5549 .6834 L
s
.5549 .6834 m
.5549 .68341 L
s
.5549 .6834 m
.5549 .6834 L
s
.5549 .6834 m
.5549 .6834 L
s
.5549 .6834 m
.5549 .6834 L
s
.5549 .6834 m
.5549 .6834 L
s
.5549 .68341 m
.5549 .6834 L
s
.5549 .6834 m
.5549 .68341 L
s
.5549 .6834 m
.5549 .6834 L
s
.60336 .56705 m
.60336 .56705 L
s
.60336 .56705 m
.60336 .56705 L
s
.60336 .56705 m
.60336 .56705 L
s
.60336 .56705 m
.60336 .56705 L
s
.60336 .56705 m
.60336 .56705 L
s
.60336 .56705 m
.60336 .56705 L
s
.60336 .56705 m
.60336 .56705 L
s
.60336 .56705 m
.60336 .56705 L
s
.60336 .56705 m
.60336 .56705 L
s
1 .002 0 r
.45516 .77575 m
.45529 .77571 L
s
.45527 .77573 m
.45526 .77574 L
s
.45526 .7757 m
.45527 .77573 L
s
.45529 .77571 m
.45527 .77573 L
s
.45525 .77571 m
.45526 .7757 L
s
.45526 .7757 m
.45529 .77571 L
s
.45529 .77571 m
.45526 .77574 L
s
.45525 .77571 m
.45529 .77571 L
s
.45526 .77574 m
.45525 .77571 L
s
1 0 0 r
.50363 .65938 m
.50365 .65937 L
s
.50365 .65938 m
.50365 .65938 L
s
.50365 .65937 m
.50365 .65938 L
s
.50365 .65937 m
.50365 .65938 L
s
.50365 .65937 m
.50365 .65937 L
s
.50365 .65937 m
.50365 .65937 L
s
.50365 .65938 m
.50365 .65937 L
s
.50365 .65937 m
.50365 .65938 L
s
.50365 .65937 m
.50365 .65937 L
s
.73917 .58954 m
.73917 .58954 L
s
.73917 .58954 m
.73917 .58954 L
s
.73917 .58954 m
.73917 .58954 L
s
.73917 .58954 m
.73917 .58954 L
s
.73917 .58954 m
.73917 .58954 L
s
.73917 .58954 m
.73917 .58954 L
s
.73917 .58954 m
.73917 .58954 L
s
.73917 .58954 m
.73917 .58954 L
s
.73917 .58954 m
.73917 .58954 L
s
.63943 .6819 m
.63945 .6819 L
s
.63944 .6819 m
.63945 .6819 L
s
.63944 .6819 m
.63944 .6819 L
s
.63944 .6819 m
.63945 .6819 L
s
.63945 .6819 m
.63944 .6819 L
s
.63945 .6819 m
.63945 .6819 L
s
.63944 .6819 m
.63944 .6819 L
s
.63944 .6819 m
.63945 .6819 L
s
.63945 .6819 m
.63944 .6819 L
s
.45234 .63533 m
.45235 .63532 L
s
.45235 .63533 m
.45235 .63533 L
s
.45235 .63532 m
.45235 .63533 L
s
.45235 .63532 m
.45235 .63533 L
s
.45235 .63532 m
.45235 .63532 L
s
.45235 .63532 m
.45235 .63532 L
s
.45235 .63533 m
.45235 .63532 L
s
.45235 .63532 m
.45235 .63533 L
s
.45235 .63532 m
.45235 .63532 L
s
.68797 .56545 m
.68797 .56545 L
s
.68797 .56545 m
.68797 .56545 L
s
.68797 .56545 m
.68797 .56545 L
s
.68797 .56545 m
.68797 .56545 L
s
.68797 .56545 m
.68797 .56545 L
s
.68797 .56545 m
.68797 .56545 L
s
.68797 .56545 m
.68797 .56545 L
s
.68797 .56545 m
.68797 .56545 L
s
.68797 .56545 m
.68797 .56545 L
s
1 .002 0 r
.53966 .77432 m
.53974 .77428 L
s
.53973 .7743 m
.53973 .7743 L
s
.53973 .77428 m
.53973 .7743 L
s
.53974 .77428 m
.53973 .7743 L
s
.53972 .77428 m
.53973 .77428 L
s
.53973 .77428 m
.53974 .77428 L
s
.53973 .7743 m
.53972 .77428 L
s
.53974 .77428 m
.53973 .7743 L
s
.53972 .77428 m
.53974 .77428 L
s
1 0 0 r
.58818 .65785 m
.58819 .65785 L
s
.58819 .65785 m
.58819 .65785 L
s
.58819 .65785 m
.58819 .65785 L
s
.58819 .65785 m
.58819 .65785 L
s
.58819 .65785 m
.58819 .65785 L
s
.58819 .65785 m
.58819 .65785 L
s
.58819 .65785 m
.58819 .65785 L
s
.58819 .65785 m
.58819 .65785 L
s
.58819 .65785 m
.58819 .65785 L
s
.40101 .61126 m
.40101 .61126 L
s
.40101 .61126 m
.40101 .61126 L
s
.40101 .61125 m
.40101 .61126 L
s
.40101 .61126 m
.40101 .61126 L
s
.40101 .61126 m
.40101 .61125 L
s
.40101 .61125 m
.40101 .61126 L
s
.40101 .61126 m
.40101 .61126 L
s
.40101 .61126 m
.40101 .61126 L
s
.40101 .61126 m
.40101 .61126 L
s
1 .002 0 r
.48835 .7503 m
.48844 .75027 L
s
.48843 .75028 m
.48842 .75029 L
s
.48842 .75026 m
.48843 .75028 L
s
.48844 .75027 m
.48843 .75028 L
s
.48841 .75027 m
.48842 .75026 L
s
.48842 .75026 m
.48844 .75027 L
s
.48842 .75029 m
.48841 .75027 L
s
.48844 .75027 m
.48842 .75029 L
s
.48841 .75027 m
.48844 .75027 L
s
1 0 0 r
.53689 .63378 m
.53689 .63378 L
s
.53689 .63378 m
.53689 .63378 L
s
.53689 .63378 m
.53689 .63378 L
s
.53689 .63378 m
.53689 .63378 L
s
.53689 .63378 m
.53689 .63378 L
s
.53689 .63378 m
.53689 .63378 L
s
.53689 .63378 m
.53689 .63378 L
s
.53689 .63378 m
.53689 .63378 L
s
.53689 .63378 m
.53689 .63378 L
s
.77271 .56385 m
.77271 .56385 L
s
.77271 .56385 m
.77271 .56385 L
s
.77271 .56385 m
.77271 .56385 L
s
.77271 .56385 m
.77271 .56385 L
s
.77271 .56385 m
.77271 .56385 L
s
.77271 .56385 m
.77271 .56385 L
s
.77271 .56385 m
.77271 .56385 L
s
.77271 .56385 m
.77271 .56385 L
s
.77271 .56385 m
.77271 .56385 L
s
1 .002 0 r
.437 .72626 m
.43709 .72624 L
s
.43708 .72625 m
.43707 .72626 L
s
.43707 .72623 m
.43708 .72625 L
s
.43709 .72624 m
.43708 .72625 L
s
.43706 .72624 m
.43707 .72623 L
s
.43707 .72623 m
.43709 .72624 L
s
.43709 .72624 m
.43707 .72626 L
s
.43706 .72624 m
.43709 .72624 L
s
.43707 .72626 m
.43706 .72624 L
s
1 0 0 r
.67286 .65633 m
.67287 .65632 L
s
.67287 .65632 m
.67287 .65632 L
s
.67287 .65632 m
.67287 .65632 L
s
.67287 .65632 m
.67287 .65632 L
s
.67287 .65632 m
.67287 .65632 L
s
.67287 .65632 m
.67287 .65632 L
s
.67287 .65632 m
.67287 .65632 L
s
.67287 .65632 m
.67287 .65632 L
s
.67287 .65632 m
.67287 .65632 L
s
.48555 .60969 m
.48555 .60969 L
s
.48555 .60969 m
.48555 .60969 L
s
.48555 .60969 m
.48555 .60969 L
s
.48555 .60969 m
.48555 .60969 L
s
.48555 .60969 m
.48555 .60969 L
s
.48555 .60969 m
.48555 .60969 L
s
.48555 .60969 m
.48555 .60969 L
s
.48555 .60969 m
.48555 .60969 L
s
.48555 .60969 m
.48555 .60969 L
s
1 .001 0 r
.57297 .74884 m
.57303 .74882 L
s
.57303 .74883 m
.57302 .74883 L
s
.57302 .74881 m
.57303 .74883 L
s
.57303 .74882 m
.57303 .74883 L
s
.57301 .74882 m
.57302 .74881 L
s
.57302 .74881 m
.57303 .74882 L
s
.57302 .74883 m
.57301 .74882 L
s
.57303 .74882 m
.57302 .74883 L
s
.57301 .74882 m
.57303 .74882 L
s
1 0 0 r
.62157 .63224 m
.62157 .63223 L
s
.62157 .63223 m
.62157 .63223 L
s
.62157 .63223 m
.62157 .63223 L
s
.62157 .63223 m
.62157 .63223 L
s
.62157 .63223 m
.62157 .63224 L
s
.62157 .63223 m
.62157 .63223 L
s
.62157 .63224 m
.62157 .63223 L
s
.62157 .63223 m
.62157 .63223 L
s
.62157 .63223 m
.62157 .63224 L
s
1 .003 0 r
.47304 .84141 m
.47324 .84135 L
s
.47321 .84137 m
.4732 .84139 L
s
.4732 .84133 m
.47321 .84137 L
s
.47324 .84135 m
.47321 .84137 L
s
.47318 .84135 m
.4732 .84133 L
s
.4732 .84133 m
.47324 .84135 L
s
.47324 .84135 m
.4732 .84139 L
s
.47318 .84135 m
.47324 .84135 L
s
.4732 .84139 m
.47318 .84135 L
s
1 0 0 r
.43416 .58558 m
.43416 .58558 L
s
.43416 .58558 m
.43416 .58558 L
s
.43416 .58558 m
.43416 .58558 L
s
.43416 .58558 m
.43416 .58558 L
s
.43416 .58558 m
.43416 .58558 L
s
.43416 .58558 m
.43416 .58558 L
s
.43416 .58558 m
.43416 .58558 L
s
.43416 .58558 m
.43416 .58558 L
s
.43416 .58558 m
.43416 .58558 L
s
1 .001 0 r
.52162 .72479 m
.52168 .72476 L
s
.52167 .72477 m
.52166 .72478 L
s
.52166 .72476 m
.52167 .72477 L
s
.52168 .72476 m
.52167 .72477 L
s
.52166 .72477 m
.52166 .72476 L
s
.52166 .72476 m
.52168 .72476 L
s
.52166 .72478 m
.52166 .72477 L
s
.52168 .72476 m
.52166 .72478 L
s
.52166 .72477 m
.52168 .72476 L
s
1 0 0 r
.57022 .60813 m
.57022 .60812 L
s
.57022 .60812 m
.57022 .60812 L
s
.57022 .60812 m
.57022 .60812 L
s
.57022 .60812 m
.57022 .60812 L
s
.57022 .60812 m
.57022 .60812 L
s
.57022 .60812 m
.57022 .60812 L
s
.57022 .60812 m
.57022 .60812 L
s
.57022 .60812 m
.57022 .60812 L
s
.57022 .60812 m
.57022 .60812 L
s
.38274 .56145 m
.38274 .56145 L
s
.38274 .56145 m
.38274 .56145 L
s
.38274 .56145 m
.38274 .56145 L
s
.38274 .56145 m
.38274 .56145 L
s
.38274 .56145 m
.38274 .56145 L
s
.38274 .56145 m
.38274 .56145 L
s
.38274 .56145 m
.38274 .56145 L
s
.38274 .56145 m
.38274 .56145 L
s
.38274 .56145 m
.38274 .56145 L
s
1 .001 0 r
.47022 .70071 m
.47028 .70069 L
s
.47027 .7007 m
.47026 .7007 L
s
.47026 .70069 m
.47027 .7007 L
s
.47028 .70069 m
.47027 .7007 L
s
.47026 .70069 m
.47026 .70069 L
s
.47026 .70069 m
.47028 .70069 L
s
.47026 .7007 m
.47026 .70069 L
s
.47028 .70069 m
.47026 .7007 L
s
.47026 .70069 m
.47028 .70069 L
s
1 0 0 r
.70638 .63069 m
.70638 .63068 L
s
.70638 .63068 m
.70638 .63069 L
s
.70638 .63068 m
.70638 .63068 L
s
.70638 .63068 m
.70638 .63068 L
s
.70638 .63069 m
.70638 .63069 L
s
.70638 .63068 m
.70638 .63069 L
s
.70638 .63069 m
.70638 .63068 L
s
.70638 .63068 m
.70638 .63068 L
s
.70638 .63068 m
.70638 .63069 L
s
.51883 .58399 m
.51883 .58399 L
s
.51883 .58399 m
.51883 .58399 L
s
.51883 .58399 m
.51883 .58399 L
s
.51883 .58399 m
.51883 .58399 L
s
.51883 .58399 m
.51883 .58399 L
s
.51883 .58399 m
.51883 .58399 L
s
.51883 .58399 m
.51883 .58399 L
s
.51883 .58399 m
.51883 .58399 L
s
.51883 .58399 m
.51883 .58399 L
s
1 .001 0 r
.60637 .72331 m
.60641 .72329 L
s
.6064 .72329 m
.6064 .7233 L
s
.60639 .72329 m
.6064 .72329 L
s
.6064 .72329 m
.60641 .72329 L
s
.6064 .7233 m
.6064 .7233 L
s
.60641 .72329 m
.6064 .7233 L
s
.6064 .7233 m
.60639 .72329 L
s
.60639 .72329 m
.60641 .72329 L
s
.60641 .72329 m
.6064 .7233 L
s
.41878 .67661 m
.41883 .6766 L
s
.41882 .67661 m
.41882 .67661 L
s
.41882 .67659 m
.41882 .67661 L
s
.41883 .6766 m
.41882 .67661 L
s
.41881 .6766 m
.41882 .67659 L
s
.41882 .67659 m
.41883 .6766 L
s
.41883 .6766 m
.41882 .67661 L
s
.41881 .6766 m
.41883 .6766 L
s
.41882 .67661 m
.41881 .6766 L
s
1 0 0 r
.65503 .60656 m
.65503 .60656 L
s
.65503 .60656 m
.65503 .60656 L
s
.65503 .60656 m
.65503 .60656 L
s
.65503 .60656 m
.65503 .60656 L
s
.65503 .60656 m
.65503 .60656 L
s
.65503 .60656 m
.65503 .60656 L
s
.65503 .60656 m
.65503 .60656 L
s
.65503 .60656 m
.65503 .60656 L
s
.65503 .60656 m
.65503 .60656 L
s
1 .003 0 r
.50632 .81598 m
.50648 .81593 L
s
.50646 .81595 m
.50644 .81596 L
s
.50644 .81591 m
.50646 .81595 L
s
.50648 .81593 m
.50646 .81595 L
s
.50643 .81593 m
.50644 .81591 L
s
.50644 .81591 m
.50648 .81593 L
s
.50644 .81596 m
.50643 .81593 L
s
.50648 .81593 m
.50644 .81596 L
s
.50643 .81593 m
.50648 .81593 L
s
1 0 0 r
.4674 .55984 m
.4674 .55984 L
s
.4674 .55984 m
.4674 .55984 L
s
.4674 .55984 m
.4674 .55984 L
s
.4674 .55984 m
.4674 .55984 L
s
.4674 .55984 m
.4674 .55984 L
s
.4674 .55984 m
.4674 .55984 L
s
.4674 .55984 m
.4674 .55984 L
s
.4674 .55984 m
.4674 .55984 L
s
.4674 .55984 m
.4674 .55984 L
s
1 .001 0 r
.55497 .69921 m
.555 .6992 L
s
.555 .6992 m
.555 .69921 L
s
.555 .6992 m
.555 .6992 L
s
.555 .6992 m
.555 .6992 L
s
.55499 .6992 m
.555 .6992 L
s
.555 .6992 m
.555 .6992 L
s
.555 .69921 m
.55499 .6992 L
s
.555 .6992 m
.555 .69921 L
s
.55499 .6992 m
.555 .6992 L
s
1 0 0 r
.60364 .5824 m
.60364 .5824 L
s
.60364 .5824 m
.60364 .5824 L
s
.60364 .5824 m
.60364 .5824 L
s
.60364 .5824 m
.60364 .5824 L
s
.60364 .5824 m
.60364 .5824 L
s
.60364 .5824 m
.60364 .5824 L
s
.60364 .5824 m
.60364 .5824 L
s
.60364 .5824 m
.60364 .5824 L
s
.60364 .5824 m
.60364 .5824 L
s
1 .003 0 r
.45486 .79192 m
.45503 .79187 L
s
.45501 .79189 m
.455 .7919 L
s
.455 .79185 m
.45501 .79189 L
s
.45503 .79187 m
.45501 .79189 L
s
.45498 .79186 m
.455 .79185 L
s
.455 .79185 m
.45503 .79187 L
s
.45503 .79187 m
.455 .7919 L
s
.45498 .79186 m
.45503 .79187 L
s
.455 .7919 m
.45498 .79186 L
s
1 .001 0 r
.50352 .6751 m
.50355 .67508 L
s
.50355 .67509 m
.50355 .67509 L
s
.50355 .67508 m
.50355 .67509 L
s
.50355 .67508 m
.50355 .67509 L
s
.50354 .67508 m
.50355 .67508 L
s
.50355 .67508 m
.50355 .67508 L
s
.50355 .67509 m
.50354 .67508 L
s
.50355 .67508 m
.50355 .67509 L
s
.50354 .67508 m
.50355 .67508 L
s
1 0 0 r
.73997 .60498 m
.73997 .60498 L
s
.73997 .60498 m
.73997 .60498 L
s
.73997 .60498 m
.73997 .60498 L
s
.73997 .60498 m
.73997 .60498 L
s
.73997 .60498 m
.73997 .60498 L
s
.73997 .60498 m
.73997 .60498 L
s
.73997 .60498 m
.73997 .60498 L
s
.73997 .60498 m
.73997 .60498 L
s
.73997 .60498 m
.73997 .60498 L
s
.5522 .55823 m
.5522 .55823 L
s
.5522 .55823 m
.5522 .55823 L
s
.5522 .55823 m
.5522 .55823 L
s
.5522 .55823 m
.5522 .55823 L
s
.5522 .55823 m
.5522 .55823 L
s
.5522 .55823 m
.5522 .55823 L
s
.5522 .55823 m
.5522 .55823 L
s
.5522 .55823 m
.5522 .55823 L
s
.5522 .55823 m
.5522 .55823 L
s
.63985 .69771 m
.63987 .6977 L
s
.63987 .6977 m
.63987 .69771 L
s
.63986 .6977 m
.63987 .6977 L
s
.63987 .6977 m
.63987 .6977 L
s
.63987 .69771 m
.63987 .69771 L
s
.63987 .6977 m
.63987 .69771 L
s
.63987 .69771 m
.63986 .6977 L
s
.63986 .6977 m
.63987 .6977 L
s
.63987 .6977 m
.63987 .69771 L
s
.45203 .65096 m
.45206 .65095 L
s
.45205 .65095 m
.45205 .65096 L
s
.45205 .65095 m
.45205 .65095 L
s
.45206 .65095 m
.45205 .65095 L
s
.45205 .65095 m
.45205 .65095 L
s
.45205 .65095 m
.45206 .65095 L
s
.45205 .65096 m
.45205 .65095 L
s
.45206 .65095 m
.45205 .65096 L
s
.45205 .65095 m
.45206 .65095 L
s
.68857 .58081 m
.68857 .58081 L
s
.68857 .58081 m
.68857 .58081 L
s
.68857 .58081 m
.68857 .58081 L
s
.68857 .58081 m
.68857 .58081 L
s
.68857 .58081 m
.68857 .58081 L
s
.68857 .58081 m
.68857 .58081 L
s
.68857 .58081 m
.68857 .58081 L
s
.68857 .58081 m
.68857 .58081 L
s
.68857 .58081 m
.68857 .58081 L
s
1 .002 0 r
.53968 .79049 m
.5398 .79044 L
s
.53979 .79046 m
.53978 .79047 L
s
.53978 .79044 m
.53979 .79046 L
s
.5398 .79044 m
.53979 .79046 L
s
.53976 .79044 m
.53978 .79044 L
s
.53978 .79044 m
.5398 .79044 L
s
.53978 .79047 m
.53976 .79044 L
s
.5398 .79044 m
.53978 .79047 L
s
.53976 .79044 m
.5398 .79044 L
s
1 0 0 r
.5884 .67358 m
.58842 .67357 L
s
.58841 .67357 m
.58842 .67357 L
s
.58841 .67357 m
.58841 .67357 L
s
.58841 .67357 m
.58842 .67357 L
s
.58842 .67357 m
.58841 .67357 L
s
.58842 .67357 m
.58842 .67357 L
s
.58841 .67357 m
.58841 .67357 L
s
.58841 .67357 m
.58842 .67357 L
s
.58842 .67357 m
.58841 .67357 L
s
.4005 .6268 m
.40051 .6268 L
s
.40051 .6268 m
.40051 .6268 L
s
.40051 .62679 m
.40051 .6268 L
s
.40051 .6268 m
.40051 .6268 L
s
.40051 .62679 m
.40051 .62679 L
s
.40051 .62679 m
.40051 .6268 L
s
.40051 .6268 m
.40051 .6268 L
s
.40051 .62679 m
.40051 .6268 L
s
.40051 .6268 m
.40051 .62679 L
s
.63713 .55662 m
.63713 .55662 L
s
.63713 .55662 m
.63713 .55662 L
s
.63713 .55662 m
.63713 .55662 L
s
.63713 .55662 m
.63713 .55662 L
s
.63713 .55662 m
.63713 .55662 L
s
.63713 .55662 m
.63713 .55662 L
s
.63713 .55662 m
.63713 .55662 L
s
.63713 .55662 m
.63713 .55662 L
s
.63713 .55662 m
.63713 .55662 L
s
1 .002 0 r
.48818 .76639 m
.4883 .76634 L
s
.48829 .76636 m
.48828 .76637 L
s
.48828 .76633 m
.48829 .76636 L
s
.4883 .76634 m
.48829 .76636 L
s
.48826 .76634 m
.48828 .76633 L
s
.48828 .76633 m
.4883 .76634 L
s
.48828 .76637 m
.48826 .76634 L
s
.4883 .76634 m
.48828 .76637 L
s
.48826 .76634 m
.4883 .76634 L
s
1 0 0 r
.5369 .64942 m
.53692 .64941 L
s
.53692 .64941 m
.53692 .64942 L
s
.53691 .64941 m
.53692 .64941 L
s
.53692 .64941 m
.53692 .64941 L
s
.53692 .64942 m
.53692 .64942 L
s
.53692 .64941 m
.53692 .64942 L
s
.53692 .64942 m
.53691 .64941 L
s
.53691 .64941 m
.53692 .64941 L
s
.53692 .64941 m
.53692 .64942 L
s
.77364 .57922 m
.77364 .57922 L
s
.77364 .57922 m
.77364 .57922 L
s
.77364 .57922 m
.77364 .57922 L
s
.77364 .57922 m
.77364 .57922 L
s
.77364 .57922 m
.77364 .57922 L
s
.77364 .57922 m
.77364 .57922 L
s
.77364 .57922 m
.77364 .57922 L
s
.77364 .57922 m
.77364 .57922 L
s
.77364 .57922 m
.77364 .57922 L
s
1 .002 0 r
.43663 .74226 m
.43675 .74223 L
s
.43674 .74224 m
.43673 .74225 L
s
.43673 .74222 m
.43674 .74224 L
s
.43675 .74223 m
.43674 .74224 L
s
.43672 .74222 m
.43673 .74222 L
s
.43673 .74222 m
.43675 .74223 L
s
.43675 .74223 m
.43673 .74225 L
s
.43672 .74222 m
.43675 .74223 L
s
.43673 .74225 m
.43672 .74222 L
s
1 0 0 r
.67341 .67206 m
.67342 .67205 L
s
.67342 .67205 m
.67342 .67205 L
s
.67342 .67205 m
.67342 .67205 L
s
.67342 .67205 m
.67342 .67205 L
s
.67342 .67205 m
.67342 .67205 L
s
.67342 .67205 m
.67342 .67205 L
s
.67342 .67205 m
.67342 .67205 L
s
.67342 .67205 m
.67342 .67205 L
s
.67342 .67205 m
.67342 .67205 L
s
.48537 .62524 m
.48538 .62524 L
s
.48537 .62524 m
.48537 .62524 L
s
.48537 .62524 m
.48537 .62524 L
s
.48538 .62524 m
.48537 .62524 L
s
.48537 .62524 m
.48537 .62524 L
s
.48537 .62524 m
.48538 .62524 L
s
.48537 .62524 m
.48537 .62524 L
s
.48538 .62524 m
.48537 .62524 L
s
.48537 .62524 m
.48538 .62524 L
s
.7222 .55501 m
.7222 .55501 L
s
.7222 .55501 m
.7222 .55501 L
s
.7222 .55501 m
.7222 .55501 L
s
.7222 .55501 m
.7222 .55501 L
s
.7222 .55501 m
.7222 .55501 L
s
.7222 .55501 m
.7222 .55501 L
s
.7222 .55501 m
.7222 .55501 L
s
.7222 .55501 m
.7222 .55501 L
s
.7222 .55501 m
.7222 .55501 L
s
1 .002 0 r
.57313 .76494 m
.57321 .7649 L
s
.5732 .76491 m
.57319 .76492 L
s
.57319 .7649 m
.5732 .76491 L
s
.57321 .7649 m
.5732 .76491 L
s
.57318 .7649 m
.57319 .7649 L
s
.57319 .7649 m
.57321 .7649 L
s
.57319 .76492 m
.57318 .7649 L
s
.57321 .7649 m
.57319 .76492 L
s
.57318 .7649 m
.57321 .7649 L
s
1 0 0 r
.62191 .64788 m
.62192 .64787 L
s
.62192 .64787 m
.62192 .64788 L
s
.62192 .64787 m
.62192 .64787 L
s
.62192 .64787 m
.62192 .64787 L
s
.62192 .64788 m
.62192 .64788 L
s
.62192 .64787 m
.62192 .64788 L
s
.62192 .64788 m
.62192 .64787 L
s
.62192 .64787 m
.62192 .64787 L
s
.62192 .64787 m
.62192 .64788 L
s
1 .004 0 r
.47281 .85786 m
.47305 .85779 L
s
.47302 .85782 m
.473 .85784 L
s
.473 .85777 m
.47302 .85782 L
s
.47305 .85779 m
.47302 .85782 L
s
.47298 .85779 m
.473 .85777 L
s
.473 .85777 m
.47305 .85779 L
s
.47305 .85779 m
.473 .85784 L
s
.47298 .85779 m
.47305 .85779 L
s
.473 .85784 m
.47298 .85779 L
s
1 0 0 r
.43378 .60104 m
.43379 .60104 L
s
.43379 .60104 m
.43379 .60104 L
s
.43379 .60104 m
.43379 .60104 L
s
.43379 .60104 m
.43379 .60104 L
s
.43379 .60104 m
.43379 .60104 L
s
.43379 .60104 m
.43379 .60104 L
s
.43379 .60104 m
.43379 .60104 L
s
.43379 .60104 m
.43379 .60104 L
s
.43379 .60104 m
.43379 .60104 L
s
1 .002 0 r
.52158 .74079 m
.52166 .74076 L
s
.52165 .74077 m
.52164 .74078 L
s
.52164 .74075 m
.52165 .74077 L
s
.52166 .74076 m
.52165 .74077 L
s
.52163 .74076 m
.52164 .74075 L
s
.52164 .74075 m
.52166 .74076 L
s
.52164 .74078 m
.52163 .74076 L
s
.52166 .74076 m
.52164 .74078 L
s
.52163 .74076 m
.52166 .74076 L
s
1 0 0 r
.57037 .62368 m
.57037 .62368 L
s
.57037 .62368 m
.57037 .62368 L
s
.57037 .62368 m
.57037 .62368 L
s
.57037 .62368 m
.57037 .62368 L
s
.57037 .62368 m
.57037 .62368 L
s
.57037 .62368 m
.57037 .62368 L
s
.57037 .62368 m
.57037 .62368 L
s
.57037 .62368 m
.57037 .62368 L
s
.57037 .62368 m
.57037 .62368 L
s
.38215 .57682 m
.38216 .57682 L
s
.38215 .57682 m
.38215 .57682 L
s
.38215 .57682 m
.38215 .57682 L
s
.38216 .57682 m
.38215 .57682 L
s
.38215 .57682 m
.38215 .57682 L
s
.38215 .57682 m
.38216 .57682 L
s
.38216 .57682 m
.38215 .57682 L
s
.38215 .57682 m
.38216 .57682 L
s
.38215 .57682 m
.38215 .57682 L
s
.8074 .55339 m
.8074 .55339 L
s
.8074 .55339 m
.8074 .55339 L
s
.8074 .55339 m
.8074 .55339 L
s
.8074 .55339 m
.8074 .55339 L
s
.8074 .55339 m
.8074 .55339 L
s
.8074 .55339 m
.8074 .55339 L
s
.8074 .55339 m
.8074 .55339 L
s
.8074 .55339 m
.8074 .55339 L
s
.8074 .55339 m
.8074 .55339 L
s
1 .001 0 r
.46998 .71663 m
.47006 .7166 L
s
.47005 .71661 m
.47004 .71662 L
s
.47005 .71659 m
.47005 .71661 L
s
.47006 .7166 m
.47005 .71661 L
s
.47004 .7166 m
.47005 .71659 L
s
.47005 .71659 m
.47006 .7166 L
s
.47004 .71662 m
.47004 .7166 L
s
.47006 .7166 m
.47004 .71662 L
s
.47004 .7166 m
.47006 .7166 L
s
1 0 0 r
.70705 .64634 m
.70706 .64633 L
s
.70705 .64633 m
.70706 .64633 L
s
.70705 .64633 m
.70705 .64633 L
s
.70705 .64633 m
.70706 .64633 L
s
.70706 .64633 m
.70705 .64633 L
s
.70706 .64633 m
.70706 .64633 L
s
.70705 .64633 m
.70705 .64633 L
s
.70705 .64633 m
.70706 .64633 L
s
.70706 .64633 m
.70705 .64633 L
s
.51878 .59946 m
.51878 .59946 L
s
.51878 .59946 m
.51878 .59946 L
s
.51878 .59946 m
.51878 .59946 L
s
.51878 .59946 m
.51878 .59946 L
s
.51878 .59946 m
.51878 .59946 L
s
.51878 .59946 m
.51878 .59946 L
s
.51878 .59946 m
.51878 .59946 L
s
.51878 .59946 m
.51878 .59946 L
s
.51878 .59946 m
.51878 .59946 L
s
1 .001 0 r
.60666 .73932 m
.60671 .7393 L
s
.6067 .73929 m
.60671 .73931 L
s
.60669 .7393 m
.6067 .73929 L
s
.6067 .73929 m
.60671 .7393 L
s
.60671 .73931 m
.6067 .73931 L
s
.60671 .7393 m
.60671 .73931 L
s
.6067 .73931 m
.60669 .7393 L
s
.60669 .7393 m
.60671 .7393 L
s
.60671 .7393 m
.6067 .73931 L
s
.41834 .69245 m
.41842 .69242 L
s
.41841 .69243 m
.4184 .69244 L
s
.4184 .69242 m
.41841 .69243 L
s
.41842 .69242 m
.41841 .69243 L
s
.41839 .69242 m
.4184 .69242 L
s
.4184 .69242 m
.41842 .69242 L
s
.41842 .69242 m
.4184 .69244 L
s
.41839 .69242 m
.41842 .69242 L
s
.4184 .69244 m
.41839 .69242 L
s
1 0 0 r
.6555 .62212 m
.65551 .62212 L
s
.65551 .62212 m
.65551 .62212 L
s
.65551 .62212 m
.65551 .62212 L
s
.65551 .62212 m
.65551 .62212 L
s
.65551 .62212 m
.65551 .62212 L
s
.65551 .62212 m
.65551 .62212 L
s
.65551 .62212 m
.65551 .62212 L
s
.65551 .62212 m
.65551 .62212 L
s
.65551 .62212 m
.65551 .62212 L
s
1 .003 0 r
.50622 .83235 m
.50641 .83229 L
s
.50639 .83232 m
.50637 .83233 L
s
.50637 .83227 m
.50639 .83232 L
s
.50641 .83229 m
.50639 .83232 L
s
.50635 .83229 m
.50637 .83227 L
s
.50637 .83227 m
.50641 .83229 L
s
.50637 .83233 m
.50635 .83229 L
s
.50641 .83229 m
.50637 .83233 L
s
.50635 .83229 m
.50641 .83229 L
s
1 0 0 r
.46715 .57522 m
.46715 .57522 L
s
.46715 .57522 m
.46715 .57522 L
s
.46715 .57522 m
.46715 .57522 L
s
.46715 .57522 m
.46715 .57522 L
s
.46715 .57522 m
.46715 .57522 L
s
.46715 .57522 m
.46715 .57522 L
s
.46715 .57522 m
.46715 .57522 L
s
.46715 .57522 m
.46715 .57522 L
s
.46715 .57522 m
.46715 .57522 L
s
1 .001 0 r
.55506 .71514 m
.55511 .71512 L
s
.5551 .71512 m
.5551 .71513 L
s
.5551 .71511 m
.5551 .71512 L
s
.55511 .71512 m
.5551 .71512 L
s
.55509 .71512 m
.5551 .71511 L
s
.5551 .71511 m
.55511 .71512 L
s
.5551 .71513 m
.55509 .71512 L
s
.55511 .71512 m
.5551 .71513 L
s
.55509 .71512 m
.55511 .71512 L
s
1 0 0 r
.60391 .59788 m
.60391 .59788 L
s
.60391 .59788 m
.60391 .59788 L
s
.60391 .59788 m
.60391 .59788 L
s
.60391 .59788 m
.60391 .59788 L
s
.60391 .59788 m
.60391 .59788 L
s
.60391 .59788 m
.60391 .59788 L
s
.60391 .59788 m
.60391 .59788 L
s
.60391 .59788 m
.60391 .59788 L
s
.60391 .59788 m
.60391 .59788 L
s
1 .004 0 r
.45456 .80821 m
.45477 .80815 L
s
.45475 .80817 m
.45473 .80819 L
s
.45473 .80813 m
.45475 .80817 L
s
.45477 .80815 m
.45475 .80817 L
s
.45471 .80814 m
.45473 .80813 L
s
.45473 .80813 m
.45477 .80815 L
s
.45477 .80815 m
.45473 .80819 L
s
.45471 .80814 m
.45477 .80815 L
s
.45473 .80819 m
.45471 .80814 L
s
1 0 0 r
.41547 .55096 m
.41547 .55096 L
s
.41547 .55096 m
.41547 .55096 L
s
.41547 .55096 m
.41547 .55096 L
s
.41547 .55096 m
.41547 .55096 L
s
.41547 .55096 m
.41547 .55096 L
s
.41547 .55096 m
.41547 .55096 L
s
.41547 .55096 m
.41547 .55096 L
s
.41547 .55096 m
.41547 .55096 L
s
.41547 .55096 m
.41547 .55096 L
s
1 .001 0 r
.50341 .69094 m
.50346 .69091 L
s
.50345 .69092 m
.50345 .69093 L
s
.50345 .69091 m
.50345 .69092 L
s
.50346 .69091 m
.50345 .69092 L
s
.50344 .69092 m
.50345 .69091 L
s
.50345 .69091 m
.50346 .69091 L
s
.50345 .69093 m
.50344 .69092 L
s
.50346 .69091 m
.50345 .69093 L
s
.50344 .69092 m
.50346 .69091 L
s
1 0 0 r
.74077 .62055 m
.74078 .62055 L
s
.74078 .62055 m
.74078 .62055 L
s
.74078 .62055 m
.74078 .62055 L
s
.74078 .62055 m
.74078 .62055 L
s
.74078 .62055 m
.74078 .62055 L
s
.74078 .62055 m
.74078 .62055 L
s
.74078 .62055 m
.74078 .62055 L
s
.74078 .62055 m
.74078 .62055 L
s
.74078 .62055 m
.74078 .62055 L
s
.55228 .57362 m
.55228 .57362 L
s
.55228 .57362 m
.55228 .57362 L
s
.55228 .57362 m
.55228 .57362 L
s
.55228 .57362 m
.55228 .57362 L
s
.55228 .57362 m
.55228 .57362 L
s
.55228 .57362 m
.55228 .57362 L
s
.55228 .57362 m
.55228 .57362 L
s
.55228 .57362 m
.55228 .57362 L
s
.55228 .57362 m
.55228 .57362 L
s
1 .001 0 r
.64027 .71365 m
.6403 .71363 L
s
.64029 .71363 m
.6403 .71363 L
s
.64029 .71363 m
.64029 .71363 L
s
.64029 .71363 m
.6403 .71363 L
s
.6403 .71363 m
.64029 .71364 L
s
.6403 .71363 m
.6403 .71363 L
s
.64029 .71364 m
.64029 .71363 L
s
.64029 .71363 m
.6403 .71363 L
s
.6403 .71363 m
.64029 .71364 L
s
.45172 .66671 m
.45176 .66669 L
s
.45176 .6667 m
.45175 .6667 L
s
.45175 .66669 m
.45176 .6667 L
s
.45176 .66669 m
.45176 .6667 L
s
.45175 .66669 m
.45175 .66669 L
s
.45175 .66669 m
.45176 .66669 L
s
.45175 .6667 m
.45175 .66669 L
s
.45176 .66669 m
.45175 .6667 L
s
.45175 .66669 m
.45176 .66669 L
s
1 0 0 r
.68918 .59629 m
.68918 .59629 L
s
.68918 .59629 m
.68918 .59629 L
s
.68918 .59629 m
.68918 .59629 L
s
.68918 .59629 m
.68918 .59629 L
s
.68918 .59629 m
.68918 .59629 L
s
.68918 .59629 m
.68918 .59629 L
s
.68918 .59629 m
.68918 .59629 L
s
.68918 .59629 m
.68918 .59629 L
s
.68918 .59629 m
.68918 .59629 L
s
1 .003 0 r
.53971 .80679 m
.53986 .80673 L
s
.53984 .80675 m
.53983 .80676 L
s
.53983 .80672 m
.53984 .80675 L
s
.53986 .80673 m
.53984 .80675 L
s
.53981 .80673 m
.53983 .80672 L
s
.53983 .80672 m
.53986 .80673 L
s
.53983 .80676 m
.53981 .80673 L
s
.53986 .80673 m
.53983 .80676 L
s
.53981 .80673 m
.53986 .80673 L
s
1 0 0 r
.5006 .54934 m
.5006 .54934 L
s
.5006 .54934 m
.5006 .54934 L
s
.5006 .54934 m
.5006 .54934 L
s
.5006 .54934 m
.5006 .54934 L
s
.5006 .54934 m
.5006 .54934 L
s
.5006 .54934 m
.5006 .54934 L
s
.5006 .54934 m
.5006 .54934 L
s
.5006 .54934 m
.5006 .54934 L
s
.5006 .54934 m
.5006 .54934 L
s
1 .001 0 r
.58862 .68942 m
.58865 .68941 L
s
.58864 .68941 m
.58864 .68941 L
s
.58864 .68941 m
.58864 .68941 L
s
.58864 .68941 m
.58865 .68941 L
s
.58864 .68941 m
.58864 .68942 L
s
.58865 .68941 m
.58864 .68941 L
s
.58864 .68942 m
.58864 .68941 L
s
.58864 .68941 m
.58865 .68941 L
s
.58865 .68941 m
.58864 .68942 L
s
.39998 .64247 m
.40002 .64245 L
s
.40002 .64246 m
.40001 .64246 L
s
.40001 .64245 m
.40002 .64246 L
s
.40002 .64245 m
.40002 .64246 L
s
.40001 .64245 m
.40001 .64245 L
s
.40001 .64245 m
.40002 .64245 L
s
.40002 .64245 m
.40001 .64246 L
s
.40001 .64245 m
.40002 .64245 L
s
.40001 .64246 m
.40001 .64245 L
s
1 0 0 r
.63754 .57201 m
.63754 .57201 L
s
.63754 .57201 m
.63754 .57201 L
s
.63754 .57201 m
.63754 .57201 L
s
.63754 .57201 m
.63754 .57201 L
s
.63754 .57201 m
.63754 .57201 L
s
.63754 .57201 m
.63754 .57201 L
s
.63754 .57201 m
.63754 .57201 L
s
.63754 .57201 m
.63754 .57201 L
s
.63754 .57201 m
.63754 .57201 L
s
1 .003 0 r
.48801 .7826 m
.48816 .78254 L
s
.48815 .78256 m
.48813 .78258 L
s
.48813 .78253 m
.48815 .78256 L
s
.48816 .78254 m
.48815 .78256 L
s
.48812 .78254 m
.48813 .78253 L
s
.48813 .78253 m
.48816 .78254 L
s
.48813 .78258 m
.48812 .78254 L
s
.48816 .78254 m
.48813 .78258 L
s
.48812 .78254 m
.48816 .78254 L
s
1 .001 0 r
.53692 .66518 m
.53695 .66517 L
s
.53694 .66516 m
.53695 .66517 L
s
.53694 .66517 m
.53694 .66516 L
s
.53694 .66516 m
.53695 .66517 L
s
.53695 .66517 m
.53694 .66517 L
s
.53695 .66517 m
.53695 .66517 L
s
.53694 .66517 m
.53694 .66517 L
s
.53694 .66517 m
.53695 .66517 L
s
.53695 .66517 m
.53694 .66517 L
s
1 0 0 r
.77458 .59471 m
.77458 .59471 L
s
.77458 .59471 m
.77458 .59471 L
s
.77458 .59471 m
.77458 .59471 L
s
.77458 .59471 m
.77458 .59471 L
s
.77458 .59471 m
.77458 .59471 L
s
.77458 .59471 m
.77458 .59471 L
s
.77458 .59471 m
.77458 .59471 L
s
.77458 .59471 m
.77458 .59471 L
s
.77458 .59471 m
.77458 .59471 L
s
.58586 .54771 m
.58586 .54771 L
s
.58586 .54771 m
.58586 .54771 L
s
.58586 .54771 m
.58586 .54771 L
s
.58586 .54771 m
.58586 .54771 L
s
.58586 .54771 m
.58586 .54771 L
s
.58586 .54771 m
.58586 .54771 L
s
.58586 .54771 m
.58586 .54771 L
s
.58586 .54771 m
.58586 .54771 L
s
.58586 .54771 m
.58586 .54771 L
s
1 .003 0 r
.43626 .75839 m
.43643 .75834 L
s
.43641 .75836 m
.43639 .75837 L
s
.43639 .75832 m
.43641 .75836 L
s
.43643 .75834 m
.43641 .75836 L
s
.43638 .75833 m
.43639 .75832 L
s
.43639 .75832 m
.43643 .75834 L
s
.43643 .75834 m
.43639 .75837 L
s
.43638 .75833 m
.43643 .75834 L
s
.43639 .75837 m
.43638 .75833 L
s
1 0 0 r
.67396 .68791 m
.67398 .6879 L
s
.67397 .6879 m
.67398 .6879 L
s
.67397 .6879 m
.67397 .6879 L
s
.67397 .6879 m
.67398 .6879 L
s
.67398 .6879 m
.67397 .6879 L
s
.67398 .6879 m
.67398 .6879 L
s
.67397 .6879 m
.67397 .6879 L
s
.67397 .6879 m
.67398 .6879 L
s
.67398 .6879 m
.67397 .6879 L
s
.48518 .64091 m
.4852 .6409 L
s
.4852 .64091 m
.4852 .64091 L
s
.4852 .6409 m
.4852 .64091 L
s
.4852 .6409 m
.4852 .64091 L
s
.4852 .6409 m
.4852 .6409 L
s
.4852 .6409 m
.4852 .6409 L
s
.4852 .64091 m
.4852 .6409 L
s
.4852 .6409 m
.4852 .64091 L
s
.4852 .6409 m
.4852 .6409 L
s
.72294 .57041 m
.72294 .57041 L
s
.72294 .57041 m
.72294 .57041 L
s
.72294 .57041 m
.72294 .57041 L
s
.72294 .57041 m
.72294 .57041 L
s
.72294 .57041 m
.72294 .57041 L
s
.72294 .57041 m
.72294 .57041 L
s
.72294 .57041 m
.72294 .57041 L
s
.72294 .57041 m
.72294 .57041 L
s
.72294 .57041 m
.72294 .57041 L
s
1 .002 0 r
.57329 .78115 m
.57339 .78111 L
s
.57338 .78113 m
.57337 .78113 L
s
.57337 .7811 m
.57338 .78113 L
s
.57339 .78111 m
.57338 .78113 L
s
.57336 .78111 m
.57337 .7811 L
s
.57337 .7811 m
.57339 .78111 L
s
.57337 .78113 m
.57336 .78111 L
s
.57339 .78111 m
.57337 .78113 L
s
.57336 .78111 m
.57339 .78111 L
s
1 0 0 r
.62226 .66364 m
.62227 .66363 L
s
.62227 .66363 m
.62227 .66364 L
s
.62227 .66363 m
.62227 .66363 L
s
.62227 .66363 m
.62227 .66363 L
s
.62227 .66364 m
.62227 .66364 L
s
.62227 .66363 m
.62227 .66364 L
s
.62227 .66364 m
.62227 .66363 L
s
.62227 .66363 m
.62227 .66363 L
s
.62227 .66363 m
.62227 .66364 L
s
1 .005 0 r
.47257 .87444 m
.47287 .87436 L
s
.47283 .8744 m
.47281 .87442 L
s
.47281 .87434 m
.47283 .8744 L
s
.47287 .87436 m
.47283 .8744 L
s
.47278 .87436 m
.47281 .87434 L
s
.47281 .87434 m
.47287 .87436 L
s
1 0 0 r
.4334 .61663 m
.43341 .61662 L
s
.43341 .61662 m
.43341 .61662 L
s
.43341 .61662 m
.43341 .61662 L
s
.43341 .61662 m
.43341 .61662 L
s
.43341 .61662 m
.43341 .61662 L
s
.43341 .61662 m
.43341 .61662 L
s
1 .005 0 r
.47287 .87436 m
.47281 .87442 L
s
.47278 .87436 m
.47287 .87436 L
s
1 0 0 r
.43341 .61662 m
.43341 .61662 L
s
.43341 .61662 m
.43341 .61662 L
s
.43341 .61662 m
.43341 .61662 L
s
1 .005 0 r
.47281 .87442 m
.47278 .87436 L
s
1 0 0 r
.67125 .54609 m
.67125 .54609 L
s
.67125 .54609 m
.67125 .54609 L
s
.67125 .54609 m
.67125 .54609 L
s
.67125 .54609 m
.67125 .54609 L
s
.67125 .54609 m
.67125 .54609 L
s
.67125 .54609 m
.67125 .54609 L
s
.67125 .54609 m
.67125 .54609 L
s
.67125 .54609 m
.67125 .54609 L
s
.67125 .54609 m
.67125 .54609 L
s
1 .002 0 r
.52153 .75692 m
.52165 .75688 L
s
.52164 .7569 m
.52162 .75691 L
s
.52162 .75687 m
.52164 .7569 L
s
.52165 .75688 m
.52164 .7569 L
s
.52161 .75688 m
.52162 .75687 L
s
.52162 .75687 m
.52165 .75688 L
s
.52162 .75691 m
.52161 .75688 L
s
.52165 .75688 m
.52162 .75691 L
s
.52161 .75688 m
.52165 .75688 L
s
1 0 0 r
.57052 .63936 m
.57053 .63935 L
s
.57053 .63935 m
.57053 .63935 L
s
.57052 .63935 m
.57053 .63935 L
s
.57053 .63935 m
.57053 .63935 L
s
.57053 .63935 m
.57053 .63935 L
s
.57053 .63935 m
.57053 .63935 L
s
.57053 .63935 m
.57052 .63935 L
s
.57052 .63935 m
.57053 .63935 L
s
.57053 .63935 m
.57053 .63935 L
s
.38157 .59232 m
.38158 .59232 L
s
.38158 .59232 m
.38157 .59232 L
s
.38157 .59232 m
.38158 .59232 L
s
.38158 .59232 m
.38158 .59232 L
s
.38157 .59232 m
.38157 .59232 L
s
.38157 .59232 m
.38158 .59232 L
s
.38158 .59232 m
.38157 .59232 L
s
.38157 .59232 m
.38158 .59232 L
s
.38157 .59232 m
.38157 .59232 L
s
.80847 .5688 m
.80847 .5688 L
s
.80847 .5688 m
.80847 .5688 L
s
.80847 .5688 m
.80847 .5688 L
s
.80847 .5688 m
.80847 .5688 L
s
.80847 .5688 m
.80847 .5688 L
s
.80847 .5688 m
.80847 .5688 L
s
.80847 .5688 m
.80847 .5688 L
s
.80847 .5688 m
.80847 .5688 L
s
.80847 .5688 m
.80847 .5688 L
s
1 .002 0 r
.46973 .73267 m
.46985 .73263 L
s
.46984 .73265 m
.46983 .73266 L
s
.46983 .73262 m
.46984 .73265 L
s
.46985 .73263 m
.46984 .73265 L
s
.46982 .73263 m
.46983 .73262 L
s
.46983 .73262 m
.46985 .73263 L
s
.46983 .73266 m
.46982 .73263 L
s
.46985 .73263 m
.46983 .73266 L
s
.46982 .73263 m
.46985 .73263 L
s
1 0 0 r
.70773 .66211 m
.70774 .6621 L
s
.70774 .6621 m
.70774 .6621 L
s
.70774 .6621 m
.70774 .6621 L
s
.70774 .6621 m
.70774 .6621 L
s
.70774 .6621 m
.70774 .6621 L
s
.70774 .6621 m
.70774 .6621 L
s
.70774 .6621 m
.70774 .6621 L
s
.70774 .6621 m
.70774 .6621 L
s
.70774 .6621 m
.70774 .6621 L
s
.51873 .61505 m
.51874 .61505 L
s
.51873 .61505 m
.51874 .61505 L
s
.51873 .61505 m
.51873 .61505 L
s
.51873 .61505 m
.51874 .61505 L
s
.51874 .61505 m
.51873 .61505 L
s
.51874 .61505 m
.51874 .61505 L
s
.51873 .61505 m
.51873 .61505 L
s
.51873 .61505 m
.51874 .61505 L
s
.51874 .61505 m
.51873 .61505 L
s
.75678 .54446 m
.75678 .54446 L
s
.75678 .54446 m
.75678 .54446 L
s
.75678 .54446 m
.75678 .54446 L
s
.75678 .54446 m
.75678 .54446 L
s
.75678 .54446 m
.75678 .54446 L
s
.75678 .54446 m
.75678 .54446 L
s
.75678 .54446 m
.75678 .54446 L
s
.75678 .54446 m
.75678 .54446 L
s
.75678 .54446 m
.75678 .54446 L
s
1 .001 0 r
.60695 .75546 m
.60702 .75542 L
s
.607 .75542 m
.60701 .75544 L
s
.60699 .75543 m
.607 .75542 L
s
.607 .75542 m
.60702 .75542 L
s
.60701 .75544 m
.607 .75544 L
s
.60702 .75542 m
.60701 .75544 L
s
.607 .75544 m
.60699 .75543 L
s
.60699 .75543 m
.60702 .75542 L
s
.60702 .75542 m
.607 .75544 L
s
1 .002 0 r
.41789 .7084 m
.41801 .70837 L
s
.418 .70838 m
.41799 .70839 L
s
.41799 .70836 m
.418 .70838 L
s
.41801 .70837 m
.418 .70838 L
s
.41798 .70836 m
.41799 .70836 L
s
.41799 .70836 m
.41801 .70837 L
s
.41801 .70837 m
.41799 .70839 L
s
.41798 .70836 m
.41801 .70837 L
s
.41799 .70839 m
.41798 .70836 L
s
1 0 0 r
.65598 .6378 m
.65599 .6378 L
s
.65599 .6378 m
.65599 .6378 L
s
.65599 .6378 m
.65599 .6378 L
s
.65599 .6378 m
.65599 .6378 L
s
.65599 .6378 m
.65599 .6378 L
s
.65599 .6378 m
.65599 .6378 L
s
.65599 .6378 m
.65599 .6378 L
s
.65599 .6378 m
.65599 .6378 L
s
.65599 .6378 m
.65599 .6378 L
s
1 .004 0 r
.50612 .84886 m
.50635 .84878 L
s
.50633 .84881 m
.5063 .84883 L
s
.50631 .84876 m
.50633 .84881 L
s
.50635 .84878 m
.50633 .84881 L
s
.50628 .84878 m
.50631 .84876 L
s
.50631 .84876 m
.50635 .84878 L
s
.5063 .84883 m
.50628 .84878 L
s
.50635 .84878 m
.5063 .84883 L
s
.50628 .84878 m
.50635 .84878 L
s
1 0 0 r
.46689 .59072 m
.4669 .59072 L
s
.4669 .59072 m
.4669 .59072 L
s
.4669 .59072 m
.4669 .59072 L
s
.4669 .59072 m
.4669 .59072 L
s
.4669 .59072 m
.4669 .59072 L
s
.4669 .59072 m
.4669 .59072 L
s
.4669 .59072 m
.4669 .59072 L
s
.4669 .59072 m
.4669 .59072 L
s
.4669 .59072 m
.4669 .59072 L
s
1 .001 0 r
.55514 .73119 m
.55522 .73116 L
s
.55521 .73117 m
.5552 .73117 L
s
.5552 .73115 m
.55521 .73117 L
s
.55522 .73116 m
.55521 .73117 L
s
.55519 .73116 m
.5552 .73115 L
s
.5552 .73115 m
.55522 .73116 L
s
.5552 .73117 m
.55519 .73116 L
s
.55522 .73116 m
.5552 .73117 L
s
.55519 .73116 m
.55522 .73116 L
s
1 0 0 r
.60419 .61348 m
.6042 .61347 L
s
.6042 .61347 m
.6042 .61347 L
s
.60419 .61347 m
.6042 .61347 L
s
.6042 .61347 m
.6042 .61347 L
s
.6042 .61347 m
.6042 .61347 L
s
.6042 .61347 m
.6042 .61347 L
s
.6042 .61347 m
.60419 .61347 L
s
.60419 .61347 m
.6042 .61347 L
s
.6042 .61347 m
.6042 .61347 L
s
1 .004 0 r
.45426 .82462 m
.45452 .82455 L
s
.45449 .82458 m
.45447 .8246 L
s
.45447 .82453 m
.45449 .82458 L
s
.45452 .82455 m
.45449 .82458 L
s
.45444 .82454 m
.45447 .82453 L
s
.45447 .82453 m
.45452 .82455 L
s
.45452 .82455 m
.45447 .8246 L
s
.45444 .82454 m
.45452 .82455 L
s
.45447 .8246 m
.45444 .82454 L
s
1 0 0 r
.41501 .56638 m
.41502 .56638 L
s
.41502 .56638 m
.41502 .56638 L
s
.41502 .56638 m
.41502 .56638 L
s
.41502 .56638 m
.41502 .56638 L
s
.41502 .56638 m
.41502 .56638 L
s
.41502 .56638 m
.41502 .56638 L
s
.41502 .56638 m
.41502 .56638 L
s
.41502 .56638 m
.41502 .56638 L
s
.41502 .56638 m
.41502 .56638 L
s
.84244 .54282 m
.84244 .54282 L
s
.84244 .54282 m
.84244 .54282 L
s
.84244 .54282 m
.84244 .54282 L
s
.84244 .54282 m
.84244 .54282 L
s
.84244 .54282 m
.84244 .54282 L
s
.84244 .54282 m
.84244 .54282 L
s
.84244 .54282 m
.84244 .54282 L
s
.84244 .54282 m
.84244 .54282 L
s
.84244 .54282 m
.84244 .54282 L
s
1 .001 0 r
.5033 .7069 m
.50337 .70687 L
s
.50336 .70688 m
.50336 .70688 L
s
.50336 .70686 m
.50336 .70688 L
s
.50337 .70687 m
.50336 .70688 L
s
.50335 .70687 m
.50336 .70686 L
s
.50336 .70686 m
.50337 .70687 L
s
.50336 .70688 m
.50335 .70687 L
s
.50337 .70687 m
.50336 .70688 L
s
.50335 .70687 m
.50337 .70687 L
s
1 0 0 r
.74159 .63624 m
.74159 .63624 L
s
.74159 .63624 m
.74159 .63624 L
s
.74159 .63624 m
.74159 .63624 L
s
.74159 .63624 m
.74159 .63624 L
s
.74159 .63624 m
.74159 .63624 L
s
.74159 .63624 m
.74159 .63624 L
s
.74159 .63624 m
.74159 .63624 L
s
.74159 .63624 m
.74159 .63624 L
s
.74159 .63624 m
.74159 .63624 L
s
.55235 .58913 m
.55236 .58913 L
s
.55236 .58913 m
.55236 .58913 L
s
.55236 .58913 m
.55236 .58913 L
s
.55236 .58913 m
.55236 .58913 L
s
.55236 .58913 m
.55236 .58913 L
s
.55236 .58913 m
.55236 .58913 L
s
.55236 .58913 m
.55236 .58913 L
s
.55236 .58913 m
.55236 .58913 L
s
.55236 .58913 m
.55236 .58913 L
s
.36309 .54201 m
.36309 .54201 L
s
.36309 .54201 m
.36309 .54201 L
s
.36309 .54201 m
.36309 .54201 L
s
.36309 .54201 m
.36309 .54201 L
s
.36309 .54201 m
.36309 .54201 L
s
.36309 .54201 m
.36309 .54201 L
s
.36309 .54201 m
.36309 .54201 L
s
.36309 .54201 m
.36309 .54201 L
s
.36309 .54201 m
.36309 .54201 L
s
1 .001 0 r
.64069 .7297 m
.64073 .72968 L
s
.64072 .72968 m
.64073 .72969 L
s
.64072 .72968 m
.64072 .72968 L
s
.64072 .72968 m
.64073 .72968 L
s
.64073 .72969 m
.64072 .72969 L
s
.64073 .72968 m
.64073 .72969 L
s
.64072 .72969 m
.64072 .72968 L
s
.64072 .72968 m
.64073 .72968 L
s
.64073 .72968 m
.64072 .72969 L
s
.4514 .68259 m
.45148 .68256 L
s
.45147 .68257 m
.45146 .68257 L
s
.45146 .68255 m
.45147 .68257 L
s
.45148 .68256 m
.45147 .68257 L
s
.45145 .68256 m
.45146 .68255 L
s
.45146 .68255 m
.45148 .68256 L
s
.45146 .68257 m
.45145 .68256 L
s
.45148 .68256 m
.45146 .68257 L
s
.45145 .68256 m
.45148 .68256 L
s
1 0 0 r
.68979 .6119 m
.68979 .61189 L
s
.68979 .61189 m
.68979 .61189 L
s
.68979 .61189 m
.68979 .61189 L
s
.68979 .61189 m
.68979 .61189 L
s
.68979 .61189 m
.68979 .61189 L
s
.68979 .61189 m
.68979 .61189 L
s
.68979 .61189 m
.68979 .61189 L
s
.68979 .61189 m
.68979 .61189 L
s
.68979 .61189 m
.68979 .61189 L
s
1 .003 0 r
.53974 .82321 m
.53992 .82314 L
s
.53991 .82317 m
.53989 .82318 L
s
.53989 .82313 m
.53991 .82317 L
s
.53992 .82314 m
.53991 .82317 L
s
.53987 .82314 m
.53989 .82313 L
s
.53989 .82313 m
.53992 .82314 L
s
.53989 .82318 m
.53987 .82314 L
s
.53992 .82314 m
.53989 .82318 L
s
.53987 .82314 m
.53992 .82314 L
s
1 0 0 r
.50047 .56476 m
.50047 .56476 L
s
.50047 .56476 m
.50047 .56476 L
s
.50047 .56476 m
.50047 .56476 L
s
.50047 .56476 m
.50047 .56476 L
s
.50047 .56476 m
.50047 .56476 L
s
.50047 .56476 m
.50047 .56476 L
s
.50047 .56476 m
.50047 .56476 L
s
.50047 .56476 m
.50047 .56476 L
s
.50047 .56476 m
.50047 .56476 L
s
1 .001 0 r
.58884 .70539 m
.58888 .70537 L
s
.58887 .70537 m
.58888 .70538 L
s
.58887 .70537 m
.58887 .70537 L
s
.58887 .70537 m
.58888 .70537 L
s
.58888 .70538 m
.58887 .70538 L
s
.58888 .70537 m
.58888 .70538 L
s
.58887 .70538 m
.58887 .70537 L
s
.58887 .70537 m
.58888 .70537 L
s
.58888 .70537 m
.58887 .70538 L
s
.39946 .65825 m
.39953 .65823 L
s
.39953 .65824 m
.39952 .65824 L
s
.39952 .65822 m
.39953 .65824 L
s
.39953 .65823 m
.39953 .65824 L
s
.39951 .65823 m
.39952 .65822 L
s
.39952 .65822 m
.39953 .65823 L
s
.39953 .65823 m
.39952 .65824 L
s
.39951 .65823 m
.39953 .65823 L
s
.39952 .65824 m
.39951 .65823 L
s
1 0 0 r
.63795 .58753 m
.63795 .58753 L
s
.63795 .58753 m
.63795 .58753 L
s
.63795 .58753 m
.63795 .58753 L
s
.63795 .58753 m
.63795 .58753 L
s
.63795 .58753 m
.63795 .58753 L
s
.63795 .58753 m
.63795 .58753 L
s
.63795 .58753 m
.63795 .58753 L
s
.63795 .58753 m
.63795 .58753 L
s
.63795 .58753 m
.63795 .58753 L
s
1 .004 0 r
.48783 .79893 m
.48803 .79887 L
s
.48801 .79889 m
.48799 .79891 L
s
.48799 .79885 m
.48801 .79889 L
s
.48803 .79887 m
.48801 .79889 L
s
.48797 .79886 m
.48799 .79885 L
s
.48799 .79885 m
.48803 .79887 L
s
.48799 .79891 m
.48797 .79886 L
s
.48803 .79887 m
.48799 .79891 L
s
.48797 .79886 m
.48803 .79887 L
s
1 0 0 r
.44854 .54037 m
.44854 .54037 L
s
.44854 .54037 m
.44854 .54037 L
s
.44854 .54037 m
.44854 .54037 L
s
.44854 .54037 m
.44854 .54037 L
s
.44854 .54037 m
.44854 .54037 L
s
.44854 .54037 m
.44854 .54037 L
s
.44854 .54037 m
.44854 .54037 L
s
.44854 .54037 m
.44854 .54037 L
s
.44854 .54037 m
.44854 .54037 L
s
1 .001 0 r
.53694 .68106 m
.53698 .68104 L
s
.53697 .68104 m
.53698 .68105 L
s
.53697 .68104 m
.53697 .68104 L
s
.53697 .68104 m
.53698 .68104 L
s
.53698 .68105 m
.53697 .68105 L
s
.53698 .68104 m
.53698 .68105 L
s
.53697 .68105 m
.53697 .68104 L
s
.53697 .68104 m
.53698 .68104 L
s
.53698 .68104 m
.53697 .68105 L
s
1 0 0 r
.77553 .61031 m
.77553 .61031 L
s
.77553 .61031 m
.77553 .61031 L
s
.77553 .61031 m
.77553 .61031 L
s
.77553 .61031 m
.77553 .61031 L
s
.77553 .61031 m
.77553 .61031 L
s
.77553 .61031 m
.77553 .61031 L
s
.77553 .61031 m
.77553 .61031 L
s
.77553 .61031 m
.77553 .61031 L
s
.77553 .61031 m
.77553 .61031 L
s
.58606 .56314 m
.58606 .56314 L
s
.58606 .56314 m
.58606 .56314 L
s
.58606 .56314 m
.58606 .56314 L
s
.58606 .56314 m
.58606 .56314 L
s
.58606 .56314 m
.58606 .56314 L
s
.58606 .56314 m
.58606 .56314 L
s
.58606 .56314 m
.58606 .56314 L
s
.58606 .56314 m
.58606 .56314 L
s
.58606 .56314 m
.58606 .56314 L
s
1 .004 0 r
.43588 .77464 m
.4361 .77457 L
s
.43608 .7746 m
.43606 .77462 L
s
.43606 .77455 m
.43608 .7746 L
s
.4361 .77457 m
.43608 .7746 L
s
.43604 .77457 m
.43606 .77455 L
s
.43606 .77455 m
.4361 .77457 L
s
.4361 .77457 m
.43606 .77462 L
s
.43604 .77457 m
.4361 .77457 L
s
.43606 .77462 m
.43604 .77457 L
s
1 .001 0 r
.67451 .70388 m
.67454 .70387 L
s
.67453 .70387 m
.67454 .70387 L
s
.67453 .70387 m
.67453 .70387 L
s
.67453 .70387 m
.67454 .70387 L
s
.67454 .70387 m
.67453 .70388 L
s
.67454 .70387 m
.67454 .70387 L
s
.67453 .70388 m
.67453 .70387 L
s
.67453 .70387 m
.67454 .70387 L
s
.67454 .70387 m
.67453 .70388 L
s
.485 .65671 m
.48504 .65669 L
s
.48503 .65669 m
.48503 .6567 L
s
.48503 .65669 m
.48503 .65669 L
s
.48504 .65669 m
.48503 .65669 L
s
.48502 .65669 m
.48503 .65669 L
s
.48503 .65669 m
.48504 .65669 L
s
.48503 .6567 m
.48502 .65669 L
s
.48504 .65669 m
.48503 .6567 L
s
.48502 .65669 m
.48504 .65669 L
s
1 0 0 r
.72368 .58593 m
.72368 .58593 L
s
.72368 .58593 m
.72368 .58593 L
s
.72368 .58593 m
.72368 .58593 L
s
.72368 .58593 m
.72368 .58593 L
s
.72368 .58593 m
.72368 .58593 L
s
.72368 .58593 m
.72368 .58593 L
s
.72368 .58593 m
.72368 .58593 L
s
.72368 .58593 m
.72368 .58593 L
s
.72368 .58593 m
.72368 .58593 L
s
1 .003 0 r
.57345 .7975 m
.57358 .79744 L
s
.57357 .79746 m
.57356 .79747 L
s
.57355 .79743 m
.57357 .79746 L
s
.57358 .79744 m
.57357 .79746 L
s
.57354 .79744 m
.57355 .79743 L
s
.57355 .79743 m
.57358 .79744 L
s
.57356 .79747 m
.57354 .79744 L
s
.57358 .79744 m
.57356 .79747 L
s
.57354 .79744 m
.57358 .79744 L
s
1 0 0 r
.53413 .53873 m
.53413 .53873 L
s
.53413 .53873 m
.53413 .53873 L
s
.53413 .53873 m
.53413 .53873 L
s
.53413 .53873 m
.53413 .53873 L
s
.53413 .53873 m
.53413 .53873 L
s
.53413 .53873 m
.53413 .53873 L
s
.53413 .53873 m
.53413 .53873 L
s
.53413 .53873 m
.53413 .53873 L
s
.53413 .53873 m
.53413 .53873 L
s
1 .001 0 r
.62261 .67953 m
.62264 .67952 L
s
.62263 .67951 m
.62264 .67952 L
s
.62263 .67952 m
.62263 .67951 L
s
.62263 .67951 m
.62264 .67952 L
s
.62264 .67952 m
.62263 .67952 L
s
.62264 .67952 m
.62264 .67952 L
s
.62263 .67952 m
.62263 .67952 L
s
.62263 .67952 m
.62264 .67952 L
s
.62264 .67952 m
.62263 .67952 L
s
.43301 .63233 m
.43304 .63232 L
s
.43304 .63232 m
.43304 .63233 L
s
.43304 .63232 m
.43304 .63232 L
s
.43304 .63232 m
.43304 .63232 L
s
.43303 .63232 m
.43304 .63232 L
s
.43304 .63232 m
.43304 .63232 L
s
.43304 .63233 m
.43303 .63232 L
s
.43304 .63232 m
.43304 .63233 L
s
.43303 .63232 m
.43304 .63232 L
s
1 0 0 r
.67179 .56152 m
.67179 .56152 L
s
.67179 .56152 m
.67179 .56152 L
s
.67179 .56152 m
.67179 .56152 L
s
.67179 .56152 m
.67179 .56152 L
s
.67179 .56152 m
.67179 .56152 L
s
.67179 .56152 m
.67179 .56152 L
s
.67179 .56152 m
.67179 .56152 L
s
.67179 .56152 m
.67179 .56152 L
s
.67179 .56152 m
.67179 .56152 L
s
1 .003 0 r
.52149 .77318 m
.52164 .77312 L
s
.52162 .77315 m
.52161 .77316 L
s
.52161 .77311 m
.52162 .77315 L
s
.52164 .77312 m
.52162 .77315 L
s
.52159 .77312 m
.52161 .77311 L
s
.52161 .77311 m
.52164 .77312 L
s
.52161 .77316 m
.52159 .77312 L
s
.52164 .77312 m
.52161 .77316 L
s
.52159 .77312 m
.52164 .77312 L
s
1 0 0 r
.57066 .65516 m
.57069 .65514 L
s
.57068 .65514 m
.57069 .65515 L
s
.57068 .65515 m
.57068 .65514 L
s
.57068 .65514 m
.57069 .65514 L
s
.57069 .65515 m
.57068 .65515 L
s
.57069 .65514 m
.57069 .65515 L
s
.57068 .65515 m
.57068 .65515 L
s
.57068 .65515 m
.57069 .65514 L
s
.57069 .65514 m
.57068 .65515 L
s
.38098 .60794 m
.381 .60793 L
s
.381 .60793 m
.381 .60793 L
s
.381 .60793 m
.381 .60793 L
s
.381 .60793 m
.381 .60793 L
s
.381 .60793 m
.381 .60793 L
s
.381 .60793 m
.381 .60793 L
s
.381 .60793 m
.381 .60793 L
s
.381 .60793 m
.381 .60793 L
s
.381 .60793 m
.381 .60793 L
s
.80955 .58432 m
.80955 .58432 L
s
.80955 .58432 m
.80955 .58432 L
s
.80955 .58432 m
.80955 .58432 L
s
.80955 .58432 m
.80955 .58432 L
s
.80955 .58432 m
.80955 .58432 L
s
.80955 .58432 m
.80955 .58432 L
s
.80955 .58432 m
.80955 .58432 L
s
.80955 .58432 m
.80955 .58432 L
s
.80955 .58432 m
.80955 .58432 L
s
.61986 .53709 m
.61986 .53709 L
s
.61986 .53709 m
.61986 .53709 L
s
.61986 .53709 m
.61986 .53709 L
s
.61986 .53709 m
.61986 .53709 L
s
.61986 .53709 m
.61986 .53709 L
s
.61986 .53709 m
.61986 .53709 L
s
.61986 .53709 m
.61986 .53709 L
s
.61986 .53709 m
.61986 .53709 L
s
.61986 .53709 m
.61986 .53709 L
s
1 .003 0 r
.46949 .74884 m
.46965 .74879 L
s
.46963 .74881 m
.46962 .74882 L
s
.46962 .74877 m
.46963 .74881 L
s
.46965 .74879 m
.46963 .74881 L
s
.4696 .74879 m
.46962 .74877 L
s
.46962 .74877 m
.46965 .74879 L
s
.46962 .74882 m
.4696 .74879 L
s
.46965 .74879 m
.46962 .74882 L
s
.4696 .74879 m
.46965 .74879 L
s
1 0 0 r
.70842 .678 m
.70843 .67799 L
s
.70843 .67799 m
.70843 .67799 L
s
.70843 .67799 m
.70843 .67799 L
s
.70843 .67799 m
.70843 .67799 L
s
.70843 .67799 m
.70843 .678 L
s
.70843 .67799 m
.70843 .67799 L
s
.70843 .678 m
.70843 .67799 L
s
.70843 .67799 m
.70843 .67799 L
s
.70843 .67799 m
.70843 .678 L
s
.51867 .63076 m
.51869 .63075 L
s
.51869 .63075 m
.51869 .63076 L
s
.51869 .63075 m
.51869 .63075 L
s
.51869 .63075 m
.51869 .63075 L
s
.51869 .63076 m
.51869 .63076 L
s
.51869 .63075 m
.51869 .63076 L
s
.51869 .63076 m
.51869 .63075 L
s
.51869 .63075 m
.51869 .63075 L
s
.51869 .63075 m
.51869 .63076 L
s
.75766 .55989 m
.75766 .55989 L
s
.75766 .55989 m
.75766 .55989 L
s
.75766 .55989 m
.75766 .55989 L
s
.75766 .55989 m
.75766 .55989 L
s
.75766 .55989 m
.75766 .55989 L
s
.75766 .55989 m
.75766 .55989 L
s
.75766 .55989 m
.75766 .55989 L
s
.75766 .55989 m
.75766 .55989 L
s
.75766 .55989 m
.75766 .55989 L
s
1 .002 0 r
.60724 .77172 m
.60733 .77168 L
s
.60731 .77167 m
.60733 .77169 L
s
.6073 .77168 m
.60731 .77167 L
s
.60731 .77167 m
.60733 .77168 L
s
.60733 .77169 m
.60731 .7717 L
s
.60733 .77168 m
.60733 .77169 L
s
.60731 .7717 m
.6073 .77168 L
s
.6073 .77168 m
.60733 .77168 L
s
.60733 .77168 m
.60731 .7717 L
s
1 .003 0 r
.41744 .72448 m
.41761 .72443 L
s
.41759 .72446 m
.41758 .72447 L
s
.41758 .72442 m
.41759 .72446 L
s
.41761 .72443 m
.41759 .72446 L
s
.41756 .72443 m
.41758 .72442 L
s
.41758 .72442 m
.41761 .72443 L
s
.41761 .72443 m
.41758 .72447 L
s
.41756 .72443 m
.41761 .72443 L
s
.41758 .72447 m
.41756 .72443 L
s
1 0 0 r
.65647 .65361 m
.65648 .6536 L
s
.65648 .6536 m
.65648 .6536 L
s
.65648 .6536 m
.65648 .6536 L
s
.65648 .6536 m
.65648 .6536 L
s
.65648 .6536 m
.65648 .6536 L
s
.65648 .6536 m
.65648 .6536 L
s
.65648 .6536 m
.65648 .6536 L
s
.65648 .6536 m
.65648 .6536 L
s
.65648 .6536 m
.65648 .6536 L
s
1 .005 0 r
.50601 .86549 m
.5063 .8654 L
s
.50627 .86544 m
.50624 .86546 L
s
.50624 .86538 m
.50627 .86544 L
s
.5063 .8654 m
.50627 .86544 L
s
.50621 .8654 m
.50624 .86538 L
s
.50624 .86538 m
.5063 .8654 L
s
1 0 0 r
.46664 .60635 m
.46665 .60634 L
s
.46665 .60634 m
.46665 .60634 L
s
.46665 .60634 m
.46665 .60634 L
s
.46665 .60634 m
.46665 .60634 L
s
.46665 .60634 m
.46665 .60634 L
s
.46665 .60634 m
.46665 .60634 L
s
.46665 .60634 m
.46665 .60634 L
s
.46665 .60634 m
.46665 .60634 L
s
.46665 .60634 m
.46665 .60634 L
s
1 .005 0 r
.50624 .86546 m
.50621 .8654 L
s
.5063 .8654 m
.50624 .86546 L
s
.50621 .8654 m
.5063 .8654 L
s
1 0 0 r
.70572 .53544 m
.70572 .53544 L
s
.70572 .53544 m
.70572 .53544 L
s
.70572 .53544 m
.70572 .53544 L
s
.70572 .53544 m
.70572 .53544 L
s
.70572 .53544 m
.70572 .53544 L
s
.70572 .53544 m
.70572 .53544 L
s
.70572 .53544 m
.70572 .53544 L
s
.70572 .53544 m
.70572 .53544 L
s
.70572 .53544 m
.70572 .53544 L
s
1 .002 0 r
.55523 .74737 m
.55533 .74732 L
s
.55533 .74734 m
.55531 .74735 L
s
.55531 .74731 m
.55533 .74734 L
s
.55533 .74732 m
.55533 .74734 L
s
.5553 .74732 m
.55531 .74731 L
s
.55531 .74731 m
.55533 .74732 L
s
.55531 .74735 m
.5553 .74732 L
s
.55533 .74732 m
.55531 .74735 L
s
.5553 .74732 m
.55533 .74732 L
s
1 0 0 r
.60447 .62919 m
.60448 .62919 L
s
.60448 .62919 m
.60448 .62919 L
s
.60448 .62919 m
.60448 .62919 L
s
.60448 .62919 m
.60448 .62919 L
s
.60448 .62919 m
.60448 .62919 L
s
.60448 .62919 m
.60448 .62919 L
s
.60448 .62919 m
.60448 .62919 L
s
.60448 .62919 m
.60448 .62919 L
s
.60448 .62919 m
.60448 .62919 L
s
1 .005 0 r
.45395 .84117 m
.45427 .84108 L
s
.45423 .84112 m
.4542 .84114 L
s
.45421 .84105 m
.45423 .84112 L
s
.45427 .84108 m
.45423 .84112 L
s
.45418 .84107 m
.45421 .84105 L
s
.45421 .84105 m
.45427 .84108 L
s
1 0 0 r
.41455 .58191 m
.41456 .58191 L
s
.41456 .58191 m
.41456 .58191 L
s
.41456 .58191 m
.41456 .58191 L
s
.41456 .58191 m
.41456 .58191 L
s
.41456 .58191 m
.41456 .58191 L
s
.41456 .58191 m
.41456 .58191 L
s
.41456 .58191 m
.41456 .58191 L
s
.41456 .58191 m
.41456 .58191 L
s
.41456 .58191 m
.41456 .58191 L
s
1 .005 0 r
.45427 .84108 m
.4542 .84114 L
s
.45418 .84107 m
.45427 .84108 L
s
.4542 .84114 m
.45418 .84107 L
s
1 0 0 r
.84366 .55827 m
.84366 .55827 L
s
.84366 .55827 m
.84366 .55827 L
s
.84366 .55827 m
.84366 .55827 L
s
.84366 .55827 m
.84366 .55827 L
s
.84366 .55827 m
.84366 .55827 L
s
.84366 .55827 m
.84366 .55827 L
s
.84366 .55827 m
.84366 .55827 L
s
.84366 .55827 m
.84366 .55827 L
s
.84366 .55827 m
.84366 .55827 L
s
1 .002 0 r
.50318 .72299 m
.50329 .72294 L
s
.50328 .72296 m
.50327 .72297 L
s
.50327 .72293 m
.50328 .72296 L
s
.50329 .72294 m
.50328 .72296 L
s
.50325 .72294 m
.50327 .72293 L
s
.50327 .72293 m
.50329 .72294 L
s
.50327 .72297 m
.50325 .72294 L
s
.50329 .72294 m
.50327 .72297 L
s
.50325 .72294 m
.50329 .72294 L
s
1 0 0 r
.74241 .65205 m
.74242 .65205 L
s
.74241 .65205 m
.74242 .65205 L
s
.74241 .65205 m
.74241 .65205 L
s
.74241 .65205 m
.74242 .65205 L
s
.74242 .65205 m
.74241 .65205 L
s
.74242 .65205 m
.74242 .65205 L
s
.74241 .65205 m
.74241 .65205 L
s
.74241 .65205 m
.74242 .65205 L
s
.74242 .65205 m
.74241 .65205 L
s
.55243 .60476 m
.55244 .60475 L
s
.55244 .60475 m
.55244 .60475 L
s
.55244 .60475 m
.55244 .60475 L
s
.55244 .60475 m
.55244 .60475 L
s
.55244 .60475 m
.55244 .60475 L
s
.55244 .60475 m
.55244 .60475 L
s
.55244 .60475 m
.55244 .60475 L
s
.55244 .60475 m
.55244 .60475 L
s
.55244 .60475 m
.55244 .60475 L
s
.36243 .55745 m
.36243 .55745 L
s
.36243 .55745 m
.36243 .55745 L
s
.36243 .55745 m
.36243 .55745 L
s
.36243 .55745 m
.36243 .55745 L
s
.36243 .55745 m
.36243 .55745 L
s
.36243 .55745 m
.36243 .55745 L
s
.36243 .55745 m
.36243 .55745 L
s
.36243 .55745 m
.36243 .55745 L
s
.36243 .55745 m
.36243 .55745 L
s
.79171 .5338 m
.79171 .5338 L
s
.79171 .5338 m
.79171 .5338 L
s
.79171 .5338 m
.79171 .5338 L
s
.79171 .5338 m
.79171 .5338 L
s
.79171 .5338 m
.79171 .5338 L
s
.79171 .5338 m
.79171 .5338 L
s
.79171 .5338 m
.79171 .5338 L
s
.79171 .5338 m
.79171 .5338 L
s
.79171 .5338 m
.79171 .5338 L
s
1 .001 0 r
.64111 .74589 m
.64117 .74585 L
s
.64116 .74585 m
.64117 .74586 L
s
.64115 .74585 m
.64116 .74585 L
s
.64116 .74585 m
.64117 .74585 L
s
.64117 .74586 m
.64116 .74587 L
s
.64117 .74585 m
.64117 .74586 L
s
.64116 .74587 m
.64115 .74585 L
s
.64115 .74585 m
.64117 .74585 L
s
.64117 .74585 m
.64116 .74587 L
s
1 .002 0 r
.45108 .69859 m
.4512 .69854 L
s
.45119 .69856 m
.45117 .69857 L
s
.45118 .69854 m
.45119 .69856 L
s
.4512 .69854 m
.45119 .69856 L
s
.45116 .69854 m
.45118 .69854 L
s
.45118 .69854 m
.4512 .69854 L
s
.45117 .69857 m
.45116 .69854 L
s
.4512 .69854 m
.45117 .69857 L
s
.45116 .69854 m
.4512 .69854 L
s
1 0 0 r
.69041 .62762 m
.69041 .62762 L
s
.69041 .62761 m
.69041 .62762 L
s
.69041 .62762 m
.69041 .62761 L
s
.69041 .62761 m
.69041 .62762 L
s
.69041 .62762 m
.69041 .62762 L
s
.69041 .62762 m
.69041 .62762 L
s
.69041 .62762 m
.69041 .62762 L
s
.69041 .62762 m
.69041 .62762 L
s
.69041 .62762 m
.69041 .62762 L
s
1 .004 0 r
.53977 .83976 m
.53999 .83968 L
s
.53997 .83971 m
.53995 .83973 L
s
.53995 .83966 m
.53997 .83971 L
s
.53999 .83968 m
.53997 .83971 L
s
.53992 .83968 m
.53995 .83966 L
s
.53995 .83966 m
.53999 .83968 L
s
1 0 0 r
.50035 .5803 m
.50035 .5803 L
s
.50035 .5803 m
.50035 .5803 L
s
.50035 .5803 m
.50035 .5803 L
s
.50035 .5803 m
.50035 .5803 L
s
.50035 .5803 m
.50035 .5803 L
s
.50035 .5803 m
.50035 .5803 L
s
.50035 .5803 m
.50035 .5803 L
s
.50035 .5803 m
.50035 .5803 L
s
.50035 .5803 m
.50035 .5803 L
s
1 .004 0 r
.53995 .83973 m
.53992 .83968 L
s
.53999 .83968 m
.53995 .83973 L
s
.53992 .83968 m
.53999 .83968 L
s
1 .001 0 r
.58906 .72149 m
.58912 .72145 L
s
.58911 .72145 m
.58912 .72146 L
s
.5891 .72145 m
.58911 .72145 L
s
.58911 .72145 m
.58912 .72145 L
s
.58912 .72146 m
.58911 .72147 L
s
.58912 .72145 m
.58912 .72146 L
s
.58911 .72147 m
.5891 .72145 L
s
.5891 .72145 m
.58912 .72145 L
s
.58912 .72145 m
.58911 .72147 L
s
1 .002 0 r
.39894 .67416 m
.39906 .67413 L
s
.39904 .67414 m
.39903 .67415 L
s
.39903 .67412 m
.39904 .67414 L
s
.39906 .67413 m
.39904 .67414 L
s
.39902 .67413 m
.39903 .67412 L
s
.39903 .67412 m
.39906 .67413 L
s
.39906 .67413 m
.39903 .67415 L
s
.39902 .67413 m
.39906 .67413 L
s
.39903 .67415 m
.39902 .67413 L
s
1 0 0 r
.63836 .60316 m
.63837 .60316 L
s
.63837 .60316 m
.63837 .60316 L
s
.63837 .60316 m
.63837 .60316 L
s
.63837 .60316 m
.63837 .60316 L
s
.63837 .60316 m
.63837 .60316 L
s
.63837 .60316 m
.63837 .60316 L
s
.63837 .60316 m
.63837 .60316 L
s
.63837 .60316 m
.63837 .60316 L
s
.63837 .60316 m
.63837 .60316 L
s
1 .004 0 r
.48766 .8154 m
.48791 .81532 L
s
.48788 .81535 m
.48786 .81537 L
s
.48786 .81529 m
.48788 .81535 L
s
.48791 .81532 m
.48788 .81535 L
s
.48783 .81531 m
.48786 .81529 L
s
.48786 .81529 m
.48791 .81532 L
s
1 0 0 r
.44822 .55582 m
.44822 .55582 L
s
.44822 .55582 m
.44822 .55582 L
s
.44822 .55582 m
.44822 .55582 L
s
.44822 .55582 m
.44822 .55582 L
s
.44822 .55582 m
.44822 .55582 L
s
.44822 .55582 m
.44822 .55582 L
s
.44822 .55582 m
.44822 .55582 L
s
.44822 .55582 m
.44822 .55582 L
s
.44822 .55582 m
.44822 .55582 L
s
1 .004 0 r
.48786 .81537 m
.48783 .81531 L
s
.48791 .81532 m
.48786 .81537 L
s
.48783 .81531 m
.48791 .81532 L
s
1 0 0 r
.87784 .53215 m
.87784 .53215 L
s
.87784 .53215 m
.87784 .53215 L
s
.87784 .53215 m
.87784 .53215 L
s
.87784 .53215 m
.87784 .53215 L
s
.87784 .53215 m
.87784 .53215 L
s
.87784 .53215 m
.87784 .53215 L
s
.87784 .53215 m
.87784 .53215 L
s
.87784 .53215 m
.87784 .53215 L
s
.87784 .53215 m
.87784 .53215 L
s
1 .001 0 r
.53696 .69707 m
.53702 .69703 L
s
.53701 .69703 m
.53702 .69704 L
s
.537 .69703 m
.53701 .69703 L
s
.53701 .69703 m
.53702 .69703 L
s
.53702 .69704 m
.53701 .69705 L
s
.53702 .69703 m
.53702 .69704 L
s
.53701 .69705 m
.537 .69703 L
s
.537 .69703 m
.53702 .69703 L
s
.53702 .69703 m
.53701 .69705 L
s
1 0 0 r
.77648 .62604 m
.77648 .62604 L
s
.77648 .62604 m
.77648 .62604 L
s
.77648 .62604 m
.77648 .62604 L
s
.77648 .62604 m
.77648 .62604 L
s
.77648 .62604 m
.77648 .62604 L
s
.77648 .62604 m
.77648 .62604 L
s
.77648 .62604 m
.77648 .62604 L
s
.77648 .62604 m
.77648 .62604 L
s
.77648 .62604 m
.77648 .62604 L
s
.58627 .57869 m
.58628 .57868 L
s
.58628 .57868 m
.58628 .57869 L
s
.58628 .57868 m
.58628 .57868 L
s
.58628 .57868 m
.58628 .57868 L
s
.58628 .57869 m
.58628 .57869 L
s
.58628 .57868 m
.58628 .57869 L
s
.58628 .57869 m
.58628 .57868 L
s
.58628 .57868 m
.58628 .57868 L
s
.58628 .57868 m
.58628 .57869 L
s
1 .005 0 r
.4355 .79101 m
.43578 .79093 L
s
.43575 .79097 m
.43572 .79099 L
s
.43573 .79091 m
.43575 .79097 L
s
.43578 .79093 m
.43575 .79097 L
s
.4357 .79093 m
.43573 .79091 L
s
.43573 .79091 m
.43578 .79093 L
s
1 0 0 r
.39604 .53132 m
.39604 .53132 L
s
.39604 .53132 m
.39604 .53132 L
s
.39604 .53132 m
.39604 .53132 L
s
.39604 .53132 m
.39604 .53132 L
s
.39604 .53132 m
.39604 .53132 L
s
.39604 .53132 m
.39604 .53132 L
s
.39604 .53132 m
.39604 .53132 L
s
.39604 .53132 m
.39604 .53132 L
s
.39604 .53132 m
.39604 .53132 L
s
1 .005 0 r
.43578 .79093 m
.43572 .79099 L
s
.4357 .79093 m
.43578 .79093 L
s
.43572 .79099 m
.4357 .79093 L
s
1 .001 0 r
.67507 .71999 m
.67511 .71996 L
s
.6751 .71996 m
.67511 .71997 L
s
.67509 .71996 m
.6751 .71996 L
s
.6751 .71996 m
.67511 .71996 L
s
.67511 .71997 m
.6751 .71997 L
s
.67511 .71996 m
.67511 .71997 L
s
.6751 .71997 m
.67509 .71996 L
s
.67509 .71996 m
.67511 .71996 L
s
.67511 .71996 m
.6751 .71997 L
s
.48481 .67262 m
.48488 .67259 L
s
.48487 .67261 m
.48486 .67261 L
s
.48486 .67259 m
.48487 .67261 L
s
.48488 .67259 m
.48487 .67261 L
s
.48486 .67259 m
.48486 .67259 L
s
.48486 .67259 m
.48488 .67259 L
s
.48486 .67261 m
.48486 .67259 L
s
.48488 .67259 m
.48486 .67261 L
s
.48486 .67259 m
.48488 .67259 L
s
1 0 0 r
.72443 .60157 m
.72444 .60157 L
s
.72443 .60157 m
.72444 .60157 L
s
.72443 .60157 m
.72443 .60157 L
s
.72443 .60157 m
.72444 .60157 L
s
.72444 .60157 m
.72443 .60157 L
s
.72444 .60157 m
.72444 .60157 L
s
.72443 .60157 m
.72443 .60157 L
s
.72443 .60157 m
.72444 .60157 L
s
.72444 .60157 m
.72443 .60157 L
s
1 .003 0 r
.57361 .81397 m
.57378 .8139 L
s
.57376 .81393 m
.57374 .81394 L
s
.57374 .81389 m
.57376 .81393 L
s
.57378 .8139 m
.57376 .81393 L
s
.57372 .8139 m
.57374 .81389 L
s
.57374 .81389 m
.57378 .8139 L
s
.57374 .81394 m
.57372 .8139 L
s
.57378 .8139 m
.57374 .81394 L
s
.57372 .8139 m
.57378 .8139 L
s
1 0 0 r
.53414 .55419 m
.53414 .55419 L
s
.53414 .55419 m
.53414 .55419 L
s
.53414 .55419 m
.53414 .55419 L
s
.53414 .55419 m
.53414 .55419 L
s
.53414 .55419 m
.53414 .55419 L
s
.53414 .55419 m
.53414 .55419 L
s
.53414 .55419 m
.53414 .55419 L
s
.53414 .55419 m
.53414 .55419 L
s
.53414 .55419 m
.53414 .55419 L
s
1 .001 0 r
.62296 .69554 m
.623 .69552 L
s
.623 .69552 m
.623 .69553 L
s
.62299 .69552 m
.623 .69552 L
s
.623 .69552 m
.623 .69552 L
s
.623 .69553 m
.623 .69553 L
s
.623 .69552 m
.623 .69553 L
s
.623 .69553 m
.62299 .69552 L
s
.62299 .69552 m
.623 .69552 L
s
.623 .69552 m
.623 .69553 L
s
.43262 .64816 m
.43268 .64813 L
s
.43268 .64815 m
.43267 .64815 L
s
.43267 .64813 m
.43268 .64815 L
s
.43268 .64813 m
.43268 .64815 L
s
.43266 .64813 m
.43267 .64813 L
s
.43267 .64813 m
.43268 .64813 L
s
.43267 .64815 m
.43266 .64813 L
s
.43268 .64813 m
.43267 .64815 L
s
.43266 .64813 m
.43268 .64813 L
s
1 0 0 r
.67234 .57707 m
.67234 .57707 L
s
.67234 .57707 m
.67234 .57707 L
s
.67234 .57707 m
.67234 .57707 L
s
.67234 .57707 m
.67234 .57707 L
s
.67234 .57707 m
.67234 .57707 L
s
.67234 .57707 m
.67234 .57707 L
s
.67234 .57707 m
.67234 .57707 L
s
.67234 .57707 m
.67234 .57707 L
s
.67234 .57707 m
.67234 .57707 L
s
1 .003 0 r
.52145 .78957 m
.52164 .78949 L
s
.52162 .78952 m
.5216 .78954 L
s
.5216 .78948 m
.52162 .78952 L
s
.52164 .78949 m
.52162 .78952 L
s
.52158 .78949 m
.5216 .78948 L
s
.5216 .78948 m
.52164 .78949 L
s
.5216 .78954 m
.52158 .78949 L
s
.52164 .78949 m
.5216 .78954 L
s
.52158 .78949 m
.52164 .78949 L
s
1 0 0 r
.48196 .52967 m
.48196 .52967 L
s
.48196 .52967 m
.48196 .52967 L
s
.48196 .52967 m
.48196 .52967 L
s
.48196 .52967 m
.48196 .52967 L
s
.48196 .52967 m
.48196 .52967 L
s
.48196 .52967 m
.48196 .52967 L
s
.48196 .52967 m
.48196 .52967 L
s
.48196 .52967 m
.48196 .52967 L
s
.48196 .52967 m
.48196 .52967 L
s
1 .001 0 r
.57081 .67108 m
.57085 .67106 L
s
.57084 .67106 m
.57085 .67107 L
s
.57084 .67106 m
.57084 .67106 L
s
.57084 .67106 m
.57085 .67106 L
s
.57085 .67107 m
.57084 .67107 L
s
.57085 .67106 m
.57085 .67107 L
s
.57084 .67107 m
.57084 .67106 L
s
.57084 .67106 m
.57085 .67106 L
s
.57085 .67106 m
.57084 .67107 L
s
.38038 .62368 m
.38044 .62366 L
s
.38043 .62367 m
.38043 .62367 L
s
.38043 .62365 m
.38043 .62367 L
s
.38044 .62366 m
.38043 .62367 L
s
.38042 .62366 m
.38043 .62365 L
s
.38043 .62365 m
.38044 .62366 L
s
.38044 .62366 m
.38043 .62367 L
s
.38042 .62366 m
.38044 .62366 L
s
.38043 .62367 m
.38042 .62366 L
s
1 0 0 r
.81064 .59997 m
.81064 .59997 L
s
.81064 .59997 m
.81064 .59997 L
s
.81064 .59997 m
.81064 .59997 L
s
.81064 .59997 m
.81064 .59997 L
s
.81064 .59997 m
.81064 .59997 L
s
.81064 .59997 m
.81064 .59997 L
s
.81064 .59997 m
.81064 .59997 L
s
.81064 .59997 m
.81064 .59997 L
s
.81064 .59997 m
.81064 .59997 L
s
.6202 .55255 m
.6202 .55255 L
s
.6202 .55255 m
.6202 .55255 L
s
.6202 .55255 m
.6202 .55255 L
s
.6202 .55255 m
.6202 .55255 L
s
.6202 .55255 m
.6202 .55255 L
s
.6202 .55255 m
.6202 .55255 L
s
.6202 .55255 m
.6202 .55255 L
s
.6202 .55255 m
.6202 .55255 L
s
.6202 .55255 m
.6202 .55255 L
s
1 .004 0 r
.46924 .76514 m
.46945 .76507 L
s
.46943 .7651 m
.46941 .76511 L
s
.46941 .76505 m
.46943 .7651 L
s
.46945 .76507 m
.46943 .7651 L
s
.46939 .76506 m
.46941 .76505 L
s
.46941 .76505 m
.46945 .76507 L
s
.46941 .76511 m
.46939 .76506 L
s
.46945 .76507 m
.46941 .76511 L
s
.46939 .76506 m
.46945 .76507 L
s
1 .001 0 r
.70911 .69402 m
.70913 .694 L
s
.70913 .694 m
.70913 .69401 L
s
.70912 .69401 m
.70913 .694 L
s
.70913 .694 m
.70913 .694 L
s
.70913 .69401 m
.70913 .69401 L
s
.70913 .694 m
.70913 .69401 L
s
.70913 .69401 m
.70912 .69401 L
s
.70912 .69401 m
.70913 .694 L
s
.70913 .694 m
.70913 .69401 L
s
.51862 .6466 m
.51865 .64658 L
s
.51865 .64658 m
.51865 .64659 L
s
.51864 .64658 m
.51865 .64658 L
s
.51865 .64658 m
.51865 .64658 L
s
.51865 .64659 m
.51865 .64659 L
s
.51865 .64658 m
.51865 .64659 L
s
.51865 .64659 m
.51864 .64658 L
s
.51864 .64658 m
.51865 .64658 L
s
.51865 .64658 m
.51865 .64659 L
s
1 0 0 r
.75854 .57545 m
.75854 .57545 L
s
.75854 .57545 m
.75854 .57545 L
s
.75854 .57545 m
.75854 .57545 L
s
.75854 .57545 m
.75854 .57545 L
s
.75854 .57545 m
.75854 .57545 L
s
.75854 .57545 m
.75854 .57545 L
s
.75854 .57545 m
.75854 .57545 L
s
.75854 .57545 m
.75854 .57545 L
s
.75854 .57545 m
.75854 .57545 L
s
1 .002 0 r
.60753 .78812 m
.60765 .78806 L
s
.60763 .78805 m
.60764 .78808 L
s
.60761 .78806 m
.60763 .78805 L
s
.60763 .78805 m
.60765 .78806 L
s
.60764 .78808 m
.60763 .78809 L
s
.60765 .78806 m
.60764 .78808 L
s
.60763 .78809 m
.60761 .78806 L
s
.60761 .78806 m
.60765 .78806 L
s
.60765 .78806 m
.60763 .78809 L
s
1 0 0 r
.56802 .52801 m
.56802 .52801 L
s
.56802 .52801 m
.56802 .52801 L
s
.56802 .52801 m
.56802 .52801 L
s
.56802 .52801 m
.56802 .52801 L
s
.56802 .52801 m
.56802 .52801 L
s
.56802 .52801 m
.56802 .52801 L
s
.56802 .52801 m
.56802 .52801 L
s
.56802 .52801 m
.56802 .52801 L
s
.56802 .52801 m
.56802 .52801 L
s
1 .004 0 r
.41699 .74069 m
.41722 .74062 L
s
.41719 .74065 m
.41717 .74067 L
s
.41718 .7406 m
.41719 .74065 L
s
.41722 .74062 m
.41719 .74065 L
s
.41715 .74062 m
.41718 .7406 L
s
.41718 .7406 m
.41722 .74062 L
s
.41722 .74062 m
.41717 .74067 L
s
.41715 .74062 m
.41722 .74062 L
s
.41717 .74067 m
.41715 .74062 L
s
1 .001 0 r
.65696 .66954 m
.65698 .66952 L
s
.65697 .66952 m
.65698 .66953 L
s
.65697 .66952 m
.65697 .66952 L
s
.65697 .66952 m
.65698 .66952 L
s
.65698 .66953 m
.65697 .66953 L
s
.65698 .66952 m
.65698 .66953 L
s
.65697 .66953 m
.65697 .66952 L
s
.65697 .66952 m
.65698 .66952 L
s
.65698 .66952 m
.65697 .66953 L
s
.46638 .62209 m
.46641 .62208 L
s
.46641 .62208 m
.4664 .62209 L
s
.4664 .62208 m
.46641 .62208 L
s
.46641 .62208 m
.46641 .62208 L
s
.4664 .62208 m
.4664 .62208 L
s
.4664 .62208 m
.46641 .62208 L
s
.4664 .62209 m
.4664 .62208 L
s
.46641 .62208 m
.4664 .62209 L
s
.4664 .62208 m
.46641 .62208 L
s
1 0 0 r
.7064 .55091 m
.7064 .55091 L
s
.7064 .55091 m
.7064 .55091 L
s
.7064 .55091 m
.7064 .55091 L
s
.7064 .55091 m
.7064 .55091 L
s
.7064 .55091 m
.7064 .55091 L
s
.7064 .55091 m
.7064 .55091 L
s
.7064 .55091 m
.7064 .55091 L
s
.7064 .55091 m
.7064 .55091 L
s
.7064 .55091 m
.7064 .55091 L
s
1 .003 0 r
.55532 .76367 m
.55545 .76361 L
s
.55544 .76363 m
.55543 .76364 L
s
.55543 .7636 m
.55544 .76363 L
s
.55545 .76361 m
.55544 .76363 L
s
.55541 .76361 m
.55543 .7636 L
s
.55543 .7636 m
.55545 .76361 L
s
.55543 .76364 m
.55541 .76361 L
s
.55545 .76361 m
.55543 .76364 L
s
.55541 .76361 m
.55545 .76361 L
s
1 0 0 r
.60476 .64503 m
.60478 .64502 L
s
.60477 .64502 m
.60477 .64503 L
s
.60477 .64502 m
.60477 .64502 L
s
.60477 .64502 m
.60478 .64502 L
s
.60477 .64503 m
.60477 .64503 L
s
.60478 .64502 m
.60477 .64503 L
s
.60477 .64503 m
.60477 .64502 L
s
.60477 .64502 m
.60478 .64502 L
s
.60478 .64502 m
.60477 .64503 L
s
1 .006 0 r
.45364 .85785 m
.45402 .85774 L
s
.45398 .85779 m
.45394 .85782 L
s
.45395 .85771 m
.45398 .85779 L
s
.45402 .85774 m
.45398 .85779 L
s
.45391 .85773 m
.45395 .85771 L
s
.45395 .85771 m
.45402 .85774 L
s
1 0 0 r
.41409 .59757 m
.41411 .59756 L
s
.41411 .59756 m
.41411 .59756 L
s
.41411 .59756 m
.41411 .59756 L
s
.41411 .59756 m
.41411 .59756 L
s
.41411 .59756 m
.41411 .59756 L
s
.41411 .59756 m
.41411 .59756 L
s
.41411 .59756 m
.41411 .59756 L
s
.41411 .59756 m
.41411 .59756 L
s
.41411 .59756 m
.41411 .59756 L
s
1 .006 0 r
.45402 .85774 m
.45394 .85782 L
s
.45391 .85773 m
.45402 .85774 L
s
.45394 .85782 m
.45391 .85773 L
s
1 0 0 r
.84488 .57383 m
.84488 .57383 L
s
.84488 .57383 m
.84488 .57383 L
s
.84488 .57383 m
.84488 .57383 L
s
.84488 .57383 m
.84488 .57383 L
s
.84488 .57383 m
.84488 .57383 L
s
.84488 .57383 m
.84488 .57383 L
s
.84488 .57383 m
.84488 .57383 L
s
.84488 .57383 m
.84488 .57383 L
s
.84488 .57383 m
.84488 .57383 L
s
.65421 .52635 m
.65421 .52635 L
s
.65421 .52635 m
.65421 .52635 L
s
.65421 .52635 m
.65421 .52635 L
s
.65421 .52635 m
.65421 .52635 L
s
.65421 .52635 m
.65421 .52635 L
s
.65421 .52635 m
.65421 .52635 L
s
.65421 .52635 m
.65421 .52635 L
s
.65421 .52635 m
.65421 .52635 L
s
.65421 .52635 m
.65421 .52635 L
s
1 .003 0 r
.50307 .7392 m
.50321 .73914 L
s
.5032 .73916 m
.50318 .73917 L
s
.50318 .73913 m
.5032 .73916 L
s
.50321 .73914 m
.5032 .73916 L
s
.50317 .73914 m
.50318 .73913 L
s
.50318 .73913 m
.50321 .73914 L
s
.50318 .73917 m
.50317 .73914 L
s
.50321 .73914 m
.50318 .73917 L
s
.50317 .73914 m
.50321 .73914 L
s
1 0 0 r
.74323 .66799 m
.74325 .66798 L
s
.74324 .66798 m
.74325 .66798 L
s
.74324 .66798 m
.74324 .66798 L
s
.74324 .66798 m
.74325 .66798 L
s
.74325 .66798 m
.74324 .66799 L
s
.74325 .66798 m
.74325 .66798 L
s
.74324 .66799 m
.74324 .66798 L
s
.74324 .66798 m
.74325 .66798 L
s
.74325 .66798 m
.74324 .66799 L
s
.55251 .62051 m
.55253 .6205 L
s
.55252 .6205 m
.55253 .6205 L
s
.55252 .6205 m
.55252 .6205 L
s
.55252 .6205 m
.55253 .6205 L
s
.55253 .6205 m
.55252 .6205 L
s
.55253 .6205 m
.55253 .6205 L
s
.55252 .6205 m
.55252 .6205 L
s
.55252 .6205 m
.55253 .6205 L
s
.55253 .6205 m
.55252 .6205 L
s
.36176 .57302 m
.36177 .57301 L
s
.36177 .57302 m
.36177 .57302 L
s
.36177 .57301 m
.36177 .57302 L
s
.36177 .57301 m
.36177 .57302 L
s
.36177 .57301 m
.36177 .57301 L
s
.36177 .57301 m
.36177 .57301 L
s
.36177 .57301 m
.36177 .57302 L
s
.36177 .57301 m
.36177 .57301 L
s
.36177 .57302 m
.36177 .57301 L
s
.79273 .54927 m
.79273 .54927 L
s
.79273 .54927 m
.79273 .54927 L
s
.79273 .54927 m
.79273 .54927 L
s
.79273 .54927 m
.79273 .54927 L
s
.79273 .54927 m
.79273 .54927 L
s
.79273 .54927 m
.79273 .54927 L
s
.79273 .54927 m
.79273 .54927 L
s
.79273 .54927 m
.79273 .54927 L
s
.79273 .54927 m
.79273 .54927 L
s
1 .002 0 r
.64154 .7622 m
.64162 .76215 L
s
.64161 .76215 m
.64162 .76217 L
s
.64159 .76215 m
.64161 .76215 L
s
.64161 .76215 m
.64162 .76215 L
s
.64162 .76217 m
.64161 .76218 L
s
.64162 .76215 m
.64162 .76217 L
s
.64161 .76218 m
.64159 .76215 L
s
.64159 .76215 m
.64162 .76215 L
s
.64162 .76215 m
.64161 .76218 L
s
1 .003 0 r
.45076 .71471 m
.45092 .71465 L
s
.45091 .71468 m
.45089 .71469 L
s
.45089 .71464 m
.45091 .71468 L
s
.45092 .71465 m
.45091 .71468 L
s
.45088 .71465 m
.45089 .71464 L
s
.45089 .71464 m
.45092 .71465 L
s
.45089 .71469 m
.45088 .71465 L
s
.45092 .71465 m
.45089 .71469 L
s
.45088 .71465 m
.45092 .71465 L
s
1 0 0 r
.69103 .64347 m
.69104 .64346 L
s
.69104 .64346 m
.69104 .64346 L
s
.69104 .64346 m
.69104 .64346 L
s
.69104 .64346 m
.69104 .64346 L
s
.69104 .64346 m
.69104 .64346 L
s
.69104 .64346 m
.69104 .64346 L
s
.69104 .64346 m
.69104 .64346 L
s
.69104 .64346 m
.69104 .64346 L
s
.69104 .64346 m
.69104 .64346 L
s
1 .005 0 r
.5398 .85645 m
.54006 .85635 L
s
.54004 .85639 m
.54001 .85641 L
s
.54001 .85633 m
.54004 .85639 L
s
.54006 .85635 m
.54004 .85639 L
s
.53998 .85635 m
.54001 .85633 L
s
.54001 .85633 m
.54006 .85635 L
s
1 0 0 r
.50022 .59596 m
.50023 .59596 L
s
.50023 .59595 m
.50023 .59596 L
s
.50023 .59596 m
.50023 .59595 L
s
.50023 .59595 m
.50023 .59596 L
s
.50023 .59596 m
.50023 .59596 L
s
.50023 .59596 m
.50023 .59596 L
s
.50023 .59596 m
.50023 .59596 L
s
.50023 .59596 m
.50023 .59596 L
s
.50023 .59596 m
.50023 .59596 L
s
1 .005 0 r
.54001 .85641 m
.53998 .85635 L
s
.54006 .85635 m
.54001 .85641 L
s
.53998 .85635 m
.54006 .85635 L
s
1 0 0 r
.74054 .52469 m
.74054 .52469 L
s
.74054 .52469 m
.74054 .52469 L
s
.74054 .52469 m
.74054 .52469 L
s
.74054 .52469 m
.74054 .52469 L
s
.74054 .52469 m
.74054 .52469 L
s
.74054 .52469 m
.74054 .52469 L
s
.74054 .52469 m
.74054 .52469 L
s
.74054 .52469 m
.74054 .52469 L
s
.74054 .52469 m
.74054 .52469 L
s
1 .002 0 r
.58928 .73771 m
.58937 .73766 L
s
.58935 .73766 m
.58936 .73768 L
s
.58934 .73766 m
.58935 .73766 L
s
.58935 .73766 m
.58937 .73766 L
s
.58936 .73768 m
.58935 .73769 L
s
.58937 .73766 m
.58936 .73768 L
s
.58935 .73769 m
.58934 .73766 L
s
.58934 .73766 m
.58937 .73766 L
s
.58937 .73766 m
.58935 .73769 L
s
1 .003 0 r
.39842 .6902 m
.39859 .69015 L
s
.39857 .69017 m
.39855 .69018 L
s
.39855 .69013 m
.39857 .69017 L
s
.39859 .69015 m
.39857 .69017 L
s
.39854 .69014 m
.39855 .69013 L
s
.39855 .69013 m
.39859 .69015 L
s
.39859 .69015 m
.39855 .69018 L
s
.39854 .69014 m
.39859 .69015 L
s
.39855 .69018 m
.39854 .69014 L
s
1 0 0 r
.63878 .61892 m
.63879 .61892 L
s
.63879 .61892 m
.63879 .61892 L
s
.63879 .61892 m
.63879 .61892 L
s
.63879 .61892 m
.63879 .61892 L
s
.63879 .61892 m
.63879 .61892 L
s
.63879 .61892 m
.63879 .61892 L
s
.63879 .61892 m
.63879 .61892 L
s
.63879 .61892 m
.63879 .61892 L
s
.63879 .61892 m
.63879 .61892 L
s
1 .005 0 r
.48748 .832 m
.48779 .83189 L
s
.48775 .83194 m
.48772 .83196 L
s
.48772 .83187 m
.48775 .83194 L
s
.48779 .83189 m
.48775 .83194 L
s
.48769 .83189 m
.48772 .83187 L
s
.48772 .83187 m
.48779 .83189 L
s
1 0 0 r
.44788 .57139 m
.44789 .57139 L
s
.44789 .57139 m
.44789 .57139 L
s
.44789 .57139 m
.44789 .57139 L
s
.44789 .57139 m
.44789 .57139 L
s
.44789 .57139 m
.44789 .57139 L
s
.44789 .57139 m
.44789 .57139 L
s
.44789 .57139 m
.44789 .57139 L
s
.44789 .57139 m
.44789 .57139 L
s
.44789 .57139 m
.44789 .57139 L
s
1 .005 0 r
.48772 .83196 m
.48769 .83189 L
s
.48779 .83189 m
.48772 .83196 L
s
.48769 .83189 m
.48779 .83189 L
s
1 0 0 r
.87921 .54763 m
.87921 .54763 L
s
.87921 .54763 m
.87921 .54763 L
s
.87921 .54763 m
.87921 .54763 L
s
.87921 .54763 m
.87921 .54763 L
s
.87921 .54763 m
.87921 .54763 L
s
.87921 .54763 m
.87921 .54763 L
s
.87921 .54763 m
.87921 .54763 L
s
.87921 .54763 m
.87921 .54763 L
s
.87921 .54763 m
.87921 .54763 L
s
1 .002 0 r
.53697 .7132 m
.53707 .71315 L
s
.53705 .71314 m
.53706 .71317 L
s
.53704 .71315 m
.53705 .71314 L
s
.53705 .71314 m
.53707 .71315 L
s
.53706 .71317 m
.53705 .71318 L
s
.53707 .71315 m
.53706 .71317 L
s
.53705 .71318 m
.53704 .71315 L
s
.53704 .71315 m
.53707 .71315 L
s
.53707 .71315 m
.53705 .71318 L
s
1 0 0 r
.77744 .6419 m
.77745 .64189 L
s
.77745 .64189 m
.77745 .64189 L
s
.77745 .64189 m
.77745 .64189 L
s
.77745 .64189 m
.77745 .64189 L
s
.77745 .64189 m
.77745 .6419 L
s
.77745 .64189 m
.77745 .64189 L
s
.77745 .6419 m
.77745 .64189 L
s
.77745 .64189 m
.77745 .64189 L
s
.77745 .64189 m
.77745 .6419 L
s
.58649 .59436 m
.58649 .59435 L
s
.58649 .59435 m
.58649 .59435 L
s
.58649 .59435 m
.58649 .59435 L
s
.58649 .59435 m
.58649 .59435 L
s
.58649 .59435 m
.58649 .59435 L
s
.58649 .59435 m
.58649 .59435 L
s
.58649 .59435 m
.58649 .59435 L
s
.58649 .59435 m
.58649 .59435 L
s
.58649 .59435 m
.58649 .59435 L
s
1 .006 0 r
.43512 .80752 m
.43547 .80742 L
s
.43543 .80747 m
.43539 .80749 L
s
.4354 .80739 m
.43543 .80747 L
s
.43547 .80742 m
.43543 .80747 L
s
.43537 .80741 m
.4354 .80739 L
s
.4354 .80739 m
.43547 .80742 L
s
1 0 0 r
.3955 .5468 m
.3955 .5468 L
s
.3955 .5468 m
.3955 .5468 L
s
.3955 .5468 m
.3955 .5468 L
s
.3955 .5468 m
.3955 .5468 L
s
.3955 .5468 m
.3955 .5468 L
s
.3955 .5468 m
.3955 .5468 L
s
.3955 .5468 m
.3955 .5468 L
s
.3955 .5468 m
.3955 .5468 L
s
.3955 .5468 m
.3955 .5468 L
s
1 .006 0 r
.43547 .80742 m
.43539 .80749 L
s
.43537 .80741 m
.43547 .80742 L
s
.43539 .80749 m
.43537 .80741 L
s
1 0 0 r
.82701 .52303 m
.82701 .52303 L
s
.82701 .52303 m
.82701 .52303 L
s
.82701 .52303 m
.82701 .52303 L
s
.82701 .52303 m
.82701 .52303 L
s
.82701 .52303 m
.82701 .52303 L
s
.82701 .52303 m
.82701 .52303 L
s
.82701 .52303 m
.82701 .52303 L
s
.82701 .52303 m
.82701 .52303 L
s
.82701 .52303 m
.82701 .52303 L
s
1 .001 0 r
.67563 .73621 m
.67568 .73618 L
s
.67567 .73618 m
.67568 .73619 L
s
.67566 .73618 m
.67567 .73618 L
s
.67567 .73618 m
.67568 .73618 L
s
.67568 .73619 m
.67567 .7362 L
s
.67568 .73618 m
.67568 .73619 L
s
.67567 .7362 m
.67566 .73618 L
s
.67566 .73618 m
.67568 .73618 L
s
.67568 .73618 m
.67567 .7362 L
s
1 .002 0 r
.48462 .68867 m
.48472 .68862 L
s
.48472 .68864 m
.4847 .68865 L
s
.4847 .68861 m
.48472 .68864 L
s
.48472 .68862 m
.48472 .68864 L
s
.48469 .68862 m
.4847 .68861 L
s
.4847 .68861 m
.48472 .68862 L
s
.4847 .68865 m
.48469 .68862 L
s
.48472 .68862 m
.4847 .68865 L
s
.48469 .68862 m
.48472 .68862 L
s
1 0 0 r
.72519 .61733 m
.72519 .61733 L
s
.72519 .61733 m
.72519 .61733 L
s
.72519 .61733 m
.72519 .61733 L
s
.72519 .61733 m
.72519 .61733 L
s
.72519 .61733 m
.72519 .61733 L
s
.72519 .61733 m
.72519 .61733 L
s
.72519 .61733 m
.72519 .61733 L
s
.72519 .61733 m
.72519 .61733 L
s
.72519 .61733 m
.72519 .61733 L
s
1 .004 0 r
.57377 .83058 m
.57397 .83049 L
s
.57396 .83052 m
.57393 .83054 L
s
.57393 .83047 m
.57396 .83052 L
s
.57397 .83049 m
.57396 .83052 L
s
.57391 .83049 m
.57393 .83047 L
s
.57393 .83047 m
.57397 .83049 L
s
1 0 0 r
.53415 .56977 m
.53415 .56976 L
s
.53415 .56976 m
.53415 .56976 L
s
.53415 .56976 m
.53415 .56976 L
s
.53415 .56976 m
.53415 .56976 L
s
.53415 .56976 m
.53415 .56977 L
s
.53415 .56976 m
.53415 .56976 L
s
.53415 .56977 m
.53415 .56976 L
s
.53415 .56976 m
.53415 .56976 L
s
.53415 .56976 m
.53415 .56977 L
s
1 .004 0 r
.57393 .83054 m
.57391 .83049 L
s
.57397 .83049 m
.57393 .83054 L
s
.57391 .83049 m
.57397 .83049 L
s
1 0 0 r
.34307 .52219 m
.34307 .52219 L
s
.34307 .52219 m
.34307 .52219 L
s
.34307 .52219 m
.34307 .52219 L
s
.34307 .52219 m
.34307 .52219 L
s
.34307 .52219 m
.34307 .52219 L
s
.34307 .52219 m
.34307 .52219 L
s
.34307 .52219 m
.34307 .52219 L
s
.34307 .52219 m
.34307 .52219 L
s
.34307 .52219 m
.34307 .52219 L
s
1 .001 0 r
.62332 .71168 m
.62338 .71165 L
s
.62337 .71165 m
.62337 .71166 L
s
.62336 .71165 m
.62337 .71165 L
s
.62337 .71165 m
.62338 .71165 L
s
.62337 .71166 m
.62337 .71167 L
s
.62338 .71165 m
.62337 .71166 L
s
.62337 .71167 m
.62336 .71165 L
s
.62336 .71165 m
.62338 .71165 L
s
.62338 .71165 m
.62337 .71167 L
s
1 .002 0 r
.43222 .66411 m
.43233 .66407 L
s
.43232 .66409 m
.43231 .6641 L
s
.43231 .66407 m
.43232 .66409 L
s
.43233 .66407 m
.43232 .66409 L
s
.4323 .66407 m
.43231 .66407 L
s
.43231 .66407 m
.43233 .66407 L
s
.43231 .6641 m
.4323 .66407 L
s
.43233 .66407 m
.43231 .6641 L
s
.4323 .66407 m
.43233 .66407 L
s
1 0 0 r
.67289 .59275 m
.67289 .59274 L
s
.67289 .59274 m
.67289 .59274 L
s
.67289 .59274 m
.67289 .59274 L
s
.67289 .59274 m
.67289 .59274 L
s
.67289 .59274 m
.67289 .59274 L
s
.67289 .59274 m
.67289 .59274 L
s
.67289 .59274 m
.67289 .59274 L
s
.67289 .59274 m
.67289 .59274 L
s
.67289 .59274 m
.67289 .59274 L
s
1 .004 0 r
.5214 .80608 m
.52164 .80599 L
s
.52162 .80602 m
.52159 .80604 L
s
.52159 .80597 m
.52162 .80602 L
s
.52164 .80599 m
.52162 .80602 L
s
.52156 .80599 m
.52159 .80597 L
s
.52159 .80597 m
.52164 .80599 L
s
1 0 0 r
.48176 .54516 m
.48176 .54516 L
s
.48176 .54516 m
.48176 .54516 L
s
.48176 .54516 m
.48176 .54516 L
s
.48176 .54516 m
.48176 .54516 L
s
.48176 .54516 m
.48176 .54516 L
s
.48176 .54516 m
.48176 .54516 L
s
.48176 .54516 m
.48176 .54516 L
s
.48176 .54516 m
.48176 .54516 L
s
.48176 .54516 m
.48176 .54516 L
s
1 .004 0 r
.52159 .80604 m
.52156 .80599 L
s
.52164 .80599 m
.52159 .80604 L
s
.52156 .80599 m
.52164 .80599 L
s
1 0 0 r
.91362 .52136 m
.91362 .52136 L
s
.91362 .52136 m
.91362 .52136 L
s
.91362 .52136 m
.91362 .52136 L
s
.91362 .52136 m
.91362 .52136 L
s
.91362 .52136 m
.91362 .52136 L
s
.91362 .52136 m
.91362 .52136 L
s
.91362 .52136 m
.91362 .52136 L
s
.91362 .52136 m
.91362 .52136 L
s
.91362 .52136 m
.91362 .52136 L
s
1 .001 0 r
.57097 .68713 m
.57102 .6871 L
s
.57101 .6871 m
.57102 .68711 L
s
.571 .6871 m
.57101 .6871 L
s
.57101 .6871 m
.57102 .6871 L
s
.57102 .68711 m
.57101 .68712 L
s
.57102 .6871 m
.57102 .68711 L
s
.57101 .68712 m
.571 .6871 L
s
.571 .6871 m
.57102 .6871 L
s
.57102 .6871 m
.57101 .68712 L
s
1 .002 0 r
.37978 .63954 m
.37989 .63951 L
s
.37987 .63952 m
.37986 .63953 L
s
.37987 .6395 m
.37987 .63952 L
s
.37989 .63951 m
.37987 .63952 L
s
.37986 .6395 m
.37987 .6395 L
s
.37987 .6395 m
.37989 .63951 L
s
.37989 .63951 m
.37986 .63953 L
s
.37986 .6395 m
.37989 .63951 L
s
.37986 .63953 m
.37986 .6395 L
s
1 0 0 r
.81174 .61574 m
.81174 .61574 L
s
.81174 .61574 m
.81174 .61574 L
s
.81174 .61574 m
.81174 .61574 L
s
.81174 .61574 m
.81174 .61574 L
s
.81174 .61574 m
.81174 .61574 L
s
.81174 .61574 m
.81174 .61574 L
s
.81174 .61574 m
.81174 .61574 L
s
.81174 .61574 m
.81174 .61574 L
s
.81174 .61574 m
.81174 .61574 L
s
.62055 .56814 m
.62055 .56813 L
s
.62055 .56813 m
.62055 .56814 L
s
.62055 .56814 m
.62055 .56813 L
s
.62055 .56813 m
.62055 .56813 L
s
.62055 .56814 m
.62055 .56814 L
s
.62055 .56813 m
.62055 .56814 L
s
.62055 .56814 m
.62055 .56814 L
s
.62055 .56814 m
.62055 .56813 L
s
.62055 .56813 m
.62055 .56814 L
s
1 .005 0 r
.46899 .78156 m
.46926 .78147 L
s
.46923 .78151 m
.4692 .78153 L
s
.4692 .78145 m
.46923 .78151 L
s
.46926 .78147 m
.46923 .78151 L
s
.46918 .78147 m
.4692 .78145 L
s
.4692 .78145 m
.46926 .78147 L
s
1 0 0 r
.42933 .52052 m
.42933 .52052 L
s
.42933 .52052 m
.42933 .52052 L
s
.42933 .52052 m
.42933 .52052 L
s
.42933 .52052 m
.42933 .52052 L
s
.42933 .52052 m
.42933 .52052 L
s
.42933 .52052 m
.42933 .52052 L
s
.42933 .52052 m
.42933 .52052 L
s
.42933 .52052 m
.42933 .52052 L
s
.42933 .52052 m
.42933 .52052 L
s
1 .005 0 r
.4692 .78153 m
.46918 .78147 L
s
.46926 .78147 m
.4692 .78153 L
s
.46918 .78147 m
.46926 .78147 L
s
1 .001 0 r
.70981 .71017 m
.70984 .71014 L
s
.70983 .71014 m
.70984 .71015 L
s
.70983 .71015 m
.70983 .71014 L
s
.70983 .71014 m
.70984 .71014 L
s
.70984 .71015 m
.70983 .71015 L
s
.70984 .71014 m
.70984 .71015 L
s
.70983 .71015 m
.70983 .71015 L
s
.70983 .71015 m
.70984 .71014 L
s
.70984 .71014 m
.70983 .71015 L
s
.51856 .66256 m
.51862 .66253 L
s
.51861 .66252 m
.51862 .66254 L
s
.5186 .66253 m
.51861 .66252 L
s
.51861 .66252 m
.51862 .66253 L
s
.51862 .66254 m
.51861 .66254 L
s
.51862 .66253 m
.51862 .66254 L
s
.51861 .66254 m
.5186 .66253 L
s
.5186 .66253 m
.51862 .66253 L
s
.51862 .66253 m
.51861 .66254 L
s
1 0 0 r
.75943 .59113 m
.75944 .59113 L
s
.75943 .59113 m
.75944 .59113 L
s
.75943 .59113 m
.75943 .59113 L
s
.75943 .59113 m
.75944 .59113 L
s
.75944 .59113 m
.75943 .59113 L
s
.75944 .59113 m
.75944 .59113 L
s
.75943 .59113 m
.75943 .59113 L
s
.75943 .59113 m
.75944 .59113 L
s
.75944 .59113 m
.75943 .59113 L
s
1 .003 0 r
.60783 .80464 m
.60798 .80456 L
s
.60795 .80455 m
.60797 .80459 L
s
.60793 .80457 m
.60795 .80455 L
s
.60795 .80455 m
.60798 .80456 L
s
.60797 .80459 m
.60795 .8046 L
s
.60798 .80456 m
.60797 .80459 L
s
.60795 .8046 m
.60793 .80457 L
s
.60793 .80457 m
.60798 .80456 L
s
.60798 .80456 m
.60795 .8046 L
s
1 0 0 r
.56816 .54351 m
.56816 .54351 L
s
.56816 .54351 m
.56816 .54351 L
s
.56816 .54351 m
.56816 .54351 L
s
.56816 .54351 m
.56816 .54351 L
s
.56816 .54351 m
.56816 .54351 L
s
.56816 .54351 m
.56816 .54351 L
s
.56816 .54351 m
.56816 .54351 L
s
.56816 .54351 m
.56816 .54351 L
s
.56816 .54351 m
.56816 .54351 L
s
1 .005 0 r
.41653 .75703 m
.41683 .75694 L
s
.4168 .75698 m
.41677 .757 L
s
.41678 .75691 m
.4168 .75698 L
s
.41683 .75694 m
.4168 .75698 L
s
.41675 .75693 m
.41678 .75691 L
s
.41678 .75691 m
.41683 .75694 L
s
.41683 .75694 m
.41677 .757 L
s
.41675 .75693 m
.41683 .75694 L
s
.41677 .757 m
.41675 .75693 L
s
1 .001 0 r
.65745 .68559 m
.65748 .68557 L
s
.65747 .68557 m
.65748 .68558 L
s
.65747 .68557 m
.65747 .68557 L
s
.65747 .68557 m
.65748 .68557 L
s
.65748 .68558 m
.65747 .68558 L
s
.65748 .68557 m
.65748 .68558 L
s
.65747 .68558 m
.65747 .68557 L
s
.65747 .68557 m
.65748 .68557 L
s
.65748 .68557 m
.65747 .68558 L
s
.46612 .63796 m
.46617 .63794 L
s
.46617 .63795 m
.46616 .63795 L
s
.46616 .63793 m
.46617 .63795 L
s
.46617 .63794 m
.46617 .63795 L
s
.46616 .63794 m
.46616 .63793 L
s
.46616 .63793 m
.46617 .63794 L
s
.46616 .63795 m
.46616 .63794 L
s
.46617 .63794 m
.46616 .63795 L
s
.46616 .63794 m
.46617 .63794 L
s
1 0 0 r
.70709 .5665 m
.70709 .5665 L
s
.70709 .5665 m
.70709 .5665 L
s
.70709 .5665 m
.70709 .5665 L
s
.70709 .5665 m
.70709 .5665 L
s
.70709 .5665 m
.70709 .5665 L
s
.70709 .5665 m
.70709 .5665 L
s
.70709 .5665 m
.70709 .5665 L
s
.70709 .5665 m
.70709 .5665 L
s
.70709 .5665 m
.70709 .5665 L
s
1 .003 0 r
.55541 .7801 m
.55558 .78002 L
s
.55557 .78005 m
.55555 .78007 L
s
.55555 .78001 m
.55557 .78005 L
s
.55558 .78002 m
.55557 .78005 L
s
.55553 .78003 m
.55555 .78001 L
s
.55555 .78001 m
.55558 .78002 L
s
.55555 .78007 m
.55553 .78003 L
s
.55558 .78002 m
.55555 .78007 L
s
.55553 .78003 m
.55558 .78002 L
s
1 0 0 r
.51572 .51885 m
.51572 .51885 L
s
.51572 .51885 m
.51572 .51885 L
s
.51572 .51885 m
.51572 .51885 L
s
.51572 .51885 m
.51572 .51885 L
s
.51572 .51885 m
.51572 .51885 L
s
.51572 .51885 m
.51572 .51885 L
s
.51572 .51885 m
.51572 .51885 L
s
.51572 .51885 m
.51572 .51885 L
s
.51572 .51885 m
.51572 .51885 L
s
1 .001 0 r
.60504 .661 m
.60507 .66098 L
s
.60507 .66098 m
.60507 .66099 L
s
.60506 .66098 m
.60507 .66098 L
s
.60507 .66098 m
.60507 .66098 L
s
.60507 .66099 m
.60507 .66099 L
s
.60507 .66098 m
.60507 .66099 L
s
.60507 .66099 m
.60506 .66098 L
s
.60506 .66098 m
.60507 .66098 L
s
.60507 .66098 m
.60507 .66099 L
s
.41362 .61335 m
.41368 .61333 L
s
.41367 .61333 m
.41366 .61334 L
s
.41367 .61332 m
.41367 .61333 L
s
.41368 .61333 m
.41367 .61333 L
s
.41366 .61333 m
.41367 .61332 L
s
.41367 .61332 m
.41368 .61333 L
s
.41366 .61334 m
.41366 .61333 L
s
.41368 .61333 m
.41366 .61334 L
s
.41366 .61333 m
.41368 .61333 L
s
1 0 0 r
.84611 .58952 m
.84611 .58952 L
s
.84611 .58952 m
.84611 .58952 L
s
.84611 .58952 m
.84611 .58952 L
s
.84611 .58952 m
.84611 .58952 L
s
.84611 .58952 m
.84611 .58952 L
s
.84611 .58952 m
.84611 .58952 L
s
.84611 .58952 m
.84611 .58952 L
s
.84611 .58952 m
.84611 .58952 L
s
.84611 .58952 m
.84611 .58952 L
s
.65469 .54185 m
.65469 .54185 L
s
.65469 .54185 m
.65469 .54185 L
s
.65469 .54185 m
.65469 .54185 L
s
.65469 .54185 m
.65469 .54185 L
s
.65469 .54185 m
.65469 .54185 L
s
.65469 .54185 m
.65469 .54185 L
s
.65469 .54185 m
.65469 .54185 L
s
.65469 .54185 m
.65469 .54185 L
s
.65469 .54185 m
.65469 .54185 L
s
1 .004 0 r
.50295 .75554 m
.50314 .75546 L
s
.50313 .75549 m
.5031 .75551 L
s
.5031 .75545 m
.50313 .75549 L
s
.50314 .75546 m
.50313 .75549 L
s
.50308 .75547 m
.5031 .75545 L
s
.5031 .75545 m
.50314 .75546 L
s
.5031 .75551 m
.50308 .75547 L
s
.50314 .75546 m
.5031 .75551 L
s
.50308 .75547 m
.50314 .75546 L
s
1 0 0 r
.74407 .68406 m
.74409 .68404 L
s
.74408 .68404 m
.74409 .68404 L
s
.74408 .68404 m
.74408 .68404 L
s
.74408 .68404 m
.74409 .68404 L
s
.74409 .68404 m
.74408 .68405 L
s
.74409 .68404 m
.74409 .68404 L
s
.74408 .68405 m
.74408 .68404 L
s
.74408 .68404 m
.74409 .68404 L
s
.74409 .68404 m
.74408 .68405 L
s
1 .001 0 r
.55259 .63639 m
.55262 .63637 L
s
.55261 .63637 m
.55262 .63637 L
s
.55261 .63637 m
.55261 .63637 L
s
.55261 .63637 m
.55262 .63637 L
s
.55262 .63637 m
.55261 .63638 L
s
.55262 .63637 m
.55262 .63637 L
s
.55261 .63638 m
.55261 .63637 L
s
.55261 .63637 m
.55262 .63637 L
s
.55262 .63637 m
.55261 .63638 L
s
.36108 .58871 m
.36113 .5887 L
s
.36112 .5887 m
.36112 .5887 L
s
.36112 .58869 m
.36112 .5887 L
s
.36113 .5887 m
.36112 .5887 L
s
.36111 .58869 m
.36112 .58869 L
s
.36112 .58869 m
.36113 .5887 L
s
.36113 .5887 m
.36112 .5887 L
s
.36111 .58869 m
.36113 .5887 L
s
.36112 .5887 m
.36111 .58869 L
s
1 0 0 r
.79376 .56487 m
.79376 .56487 L
s
.79376 .56487 m
.79376 .56487 L
s
.79376 .56487 m
.79376 .56487 L
s
.79376 .56487 m
.79376 .56487 L
s
.79376 .56487 m
.79376 .56487 L
s
.79376 .56487 m
.79376 .56487 L
s
.79376 .56487 m
.79376 .56487 L
s
.79376 .56487 m
.79376 .56487 L
s
.79376 .56487 m
.79376 .56487 L
s
1 .002 0 r
.64197 .77864 m
.64208 .77858 L
s
.64205 .77857 m
.64207 .7786 L
s
.64204 .77858 m
.64205 .77857 L
s
.64205 .77857 m
.64208 .77858 L
s
.64207 .7786 m
.64206 .77861 L
s
.64208 .77858 m
.64207 .7786 L
s
.64206 .77861 m
.64204 .77858 L
s
.64204 .77858 m
.64208 .77858 L
s
.64208 .77858 m
.64206 .77861 L
s
1 0 0 r
.60225 .51718 m
.60225 .51718 L
s
.60225 .51718 m
.60225 .51718 L
s
.60225 .51718 m
.60225 .51718 L
s
.60225 .51718 m
.60225 .51718 L
s
.60225 .51718 m
.60225 .51718 L
s
.60225 .51718 m
.60225 .51718 L
s
.60225 .51718 m
.60225 .51718 L
s
.60225 .51718 m
.60225 .51718 L
s
.60225 .51718 m
.60225 .51718 L
s
1 .004 0 r
.45044 .73096 m
.45066 .73088 L
s
.45064 .73092 m
.45061 .73093 L
s
.45062 .73087 m
.45064 .73092 L
s
.45066 .73088 m
.45064 .73092 L
s
.45059 .73088 m
.45062 .73087 L
s
.45062 .73087 m
.45066 .73088 L
s
.45061 .73093 m
.45059 .73088 L
s
.45066 .73088 m
.45061 .73093 L
s
.45059 .73088 m
.45066 .73088 L
s
1 0 0 r
.69166 .65944 m
.69168 .65943 L
s
.69167 .65943 m
.69168 .65943 L
s
.69167 .65943 m
.69167 .65943 L
s
.69167 .65943 m
.69168 .65943 L
s
.69168 .65943 m
.69167 .65943 L
s
.69168 .65943 m
.69168 .65943 L
s
.69167 .65943 m
.69167 .65943 L
s
.69167 .65943 m
.69168 .65943 L
s
.69168 .65943 m
.69167 .65943 L
s
1 .001 0 r
.50009 .61175 m
.50012 .61173 L
s
.50011 .61173 m
.50012 .61174 L
s
.50011 .61173 m
.50011 .61173 L
s
.50011 .61173 m
.50012 .61173 L
s
.50012 .61174 m
.50011 .61174 L
s
.50012 .61173 m
.50012 .61174 L
s
.50011 .61174 m
.50011 .61173 L
s
.50011 .61173 m
.50012 .61173 L
s
.50012 .61173 m
.50011 .61174 L
s
1 0 0 r
.74136 .5402 m
.74136 .5402 L
s
.74136 .5402 m
.74136 .5402 L
s
.74136 .5402 m
.74136 .5402 L
s
.74136 .5402 m
.74136 .5402 L
s
.74136 .5402 m
.74136 .5402 L
s
.74136 .5402 m
.74136 .5402 L
s
.74136 .5402 m
.74136 .5402 L
s
.74136 .5402 m
.74136 .5402 L
s
.74136 .5402 m
.74136 .5402 L
s
1 .002 0 r
.5895 .75406 m
.58962 .754 L
s
.5896 .75399 m
.58961 .75402 L
s
.58958 .754 m
.5896 .75399 L
s
.5896 .75399 m
.58962 .754 L
s
.58961 .75402 m
.5896 .75403 L
s
.58962 .754 m
.58961 .75402 L
s
.5896 .75403 m
.58958 .754 L
s
.58958 .754 m
.58962 .754 L
s
.58962 .754 m
.5896 .75403 L
s
1 .004 0 r
.39789 .70636 m
.39813 .70629 L
s
.3981 .70632 m
.39808 .70634 L
s
.39808 .70627 m
.3981 .70632 L
s
.39813 .70629 m
.3981 .70632 L
s
.39806 .70628 m
.39808 .70627 L
s
.39808 .70627 m
.39813 .70629 L
s
.39813 .70629 m
.39808 .70634 L
s
.39806 .70628 m
.39813 .70629 L
s
.39808 .70634 m
.39806 .70628 L
s
1 0 0 r
.6392 .63481 m
.63922 .63479 L
s
.63921 .63479 m
.63922 .6348 L
s
.63921 .63479 m
.63921 .63479 L
s
.63921 .63479 m
.63922 .63479 L
s
.63922 .6348 m
.63921 .6348 L
s
.63922 .63479 m
.63922 .6348 L
s
.63921 .6348 m
.63921 .63479 L
s
.63921 .63479 m
.63922 .63479 L
s
.63922 .63479 m
.63921 .6348 L
s
1 .006 0 r
.4873 .84872 m
.48767 .8486 L
s
.48763 .84865 m
.48759 .84868 L
s
.48759 .84857 m
.48763 .84865 L
s
.48767 .8486 m
.48763 .84865 L
s
.48756 .8486 m
.48759 .84857 L
s
.48759 .84857 m
.48767 .8486 L
s
1 0 0 r
.44755 .58709 m
.44757 .58708 L
s
.44757 .58708 m
.44757 .58709 L
s
.44757 .58708 m
.44757 .58708 L
s
.44757 .58708 m
.44757 .58708 L
s
.44756 .58708 m
.44757 .58708 L
s
.44757 .58708 m
.44757 .58708 L
s
.44757 .58709 m
.44756 .58708 L
s
.44757 .58708 m
.44757 .58709 L
s
.44756 .58708 m
.44757 .58708 L
s
1 .006 0 r
.48759 .84868 m
.48756 .8486 L
s
.48767 .8486 m
.48759 .84868 L
s
.48756 .8486 m
.48767 .8486 L
s
1 0 0 r
.88058 .56323 m
.88058 .56323 L
s
.88058 .56323 m
.88058 .56323 L
s
.88058 .56323 m
.88058 .56323 L
s
.88058 .56323 m
.88058 .56323 L
s
.88058 .56323 m
.88058 .56323 L
s
.88058 .56323 m
.88058 .56323 L
s
.88058 .56323 m
.88058 .56323 L
s
.88058 .56323 m
.88058 .56323 L
s
.88058 .56323 m
.88058 .56323 L
s
.68892 .5155 m
.68892 .5155 L
s
.68892 .5155 m
.68892 .5155 L
s
.68892 .5155 m
.68892 .5155 L
s
.68892 .5155 m
.68892 .5155 L
s
.68892 .5155 m
.68892 .5155 L
s
.68892 .5155 m
.68892 .5155 L
s
.68892 .5155 m
.68892 .5155 L
s
.68892 .5155 m
.68892 .5155 L
s
.68892 .5155 m
.68892 .5155 L
s
1 .003 0 r
.53699 .72946 m
.53712 .72939 L
s
.5371 .72939 m
.53711 .72942 L
s
.53708 .7294 m
.5371 .72939 L
s
.5371 .72939 m
.53712 .72939 L
s
.53711 .72942 m
.5371 .72943 L
s
.53712 .72939 m
.53711 .72942 L
s
.5371 .72943 m
.53708 .7294 L
s
.53708 .7294 m
.53712 .72939 L
s
.53712 .72939 m
.5371 .72943 L
s
1 0 0 r
.77841 .65788 m
.77842 .65787 L
s
.77842 .65787 m
.77842 .65787 L
s
.77842 .65787 m
.77842 .65787 L
s
.77842 .65787 m
.77842 .65787 L
s
.77842 .65787 m
.77842 .65787 L
s
.77842 .65787 m
.77842 .65787 L
s
.77842 .65787 m
.77842 .65787 L
s
.77842 .65787 m
.77842 .65787 L
s
.77842 .65787 m
.77842 .65787 L
s
.5867 .61015 m
.58671 .61014 L
s
.58671 .61014 m
.58671 .61014 L
s
.58671 .61014 m
.58671 .61014 L
s
.58671 .61014 m
.58671 .61014 L
s
.58671 .61014 m
.58671 .61014 L
s
.58671 .61014 m
.58671 .61014 L
s
.58671 .61014 m
.58671 .61014 L
s
.58671 .61014 m
.58671 .61014 L
s
.58671 .61014 m
.58671 .61014 L
s
1 .007 0 r
.43473 .82416 m
.43515 .82404 L
s
.4351 .82409 m
.43507 .82412 L
s
.43507 .824 m
.4351 .82409 L
s
.43515 .82404 m
.4351 .82409 L
s
.43503 .82403 m
.43507 .824 L
s
.43507 .824 m
.43515 .82404 L
s
1 0 0 r
.39496 .56241 m
.39497 .5624 L
s
.39497 .56241 m
.39497 .56241 L
s
.39497 .5624 m
.39497 .56241 L
s
.39497 .5624 m
.39497 .56241 L
s
.39497 .5624 m
.39497 .5624 L
s
.39497 .5624 m
.39497 .5624 L
s
.39497 .56241 m
.39497 .5624 L
s
.39497 .5624 m
.39497 .56241 L
s
.39497 .5624 m
.39497 .5624 L
s
1 .007 0 r
.43515 .82404 m
.43507 .82412 L
s
.43503 .82403 m
.43515 .82404 L
s
.43507 .82412 m
.43503 .82403 L
s
1 0 0 r
.82818 .53854 m
.82818 .53854 L
s
.82818 .53854 m
.82818 .53854 L
s
.82818 .53854 m
.82818 .53854 L
s
.82818 .53854 m
.82818 .53854 L
s
.82818 .53854 m
.82818 .53854 L
s
.82818 .53854 m
.82818 .53854 L
s
.82818 .53854 m
.82818 .53854 L
s
.82818 .53854 m
.82818 .53854 L
s
.82818 .53854 m
.82818 .53854 L
s
1 .002 0 r
.6762 .75257 m
.67627 .75253 L
s
.67625 .75252 m
.67627 .75254 L
s
.67624 .75253 m
.67625 .75252 L
s
.67625 .75252 m
.67627 .75253 L
s
.67627 .75254 m
.67625 .75255 L
s
.67627 .75253 m
.67627 .75254 L
s
.67625 .75255 m
.67624 .75253 L
s
.67624 .75253 m
.67627 .75253 L
s
.67627 .75253 m
.67625 .75255 L
s
1 .003 0 r
.48443 .70484 m
.48458 .70477 L
s
.48457 .7048 m
.48455 .70481 L
s
.48455 .70476 m
.48457 .7048 L
s
.48458 .70477 m
.48457 .7048 L
s
.48453 .70477 m
.48455 .70476 L
s
.48455 .70476 m
.48458 .70477 L
s
.48455 .70481 m
.48453 .70477 L
s
.48458 .70477 m
.48455 .70481 L
s
.48453 .70477 m
.48458 .70477 L
s
1 0 0 r
.72595 .63322 m
.72596 .63321 L
s
.72596 .63321 m
.72596 .63322 L
s
.72596 .63322 m
.72596 .63321 L
s
.72596 .63321 m
.72596 .63321 L
s
.72596 .63322 m
.72596 .63322 L
s
.72596 .63321 m
.72596 .63322 L
s
.72596 .63322 m
.72596 .63322 L
s
.72596 .63322 m
.72596 .63321 L
s
.72596 .63321 m
.72596 .63322 L
s
1 .005 0 r
.57393 .84731 m
.57418 .84721 L
s
.57416 .84724 m
.57413 .84727 L
s
.57413 .84719 m
.57416 .84724 L
s
.57418 .84721 m
.57416 .84724 L
s
.5741 .84721 m
.57413 .84719 L
s
.57413 .84719 m
.57418 .84721 L
s
1 0 0 r
.53415 .58547 m
.53416 .58546 L
s
.53416 .58546 m
.53416 .58546 L
s
.53416 .58546 m
.53416 .58546 L
s
.53416 .58546 m
.53416 .58546 L
s
.53416 .58546 m
.53416 .58547 L
s
.53416 .58546 m
.53416 .58546 L
s
.53416 .58547 m
.53416 .58546 L
s
.53416 .58546 m
.53416 .58546 L
s
.53416 .58546 m
.53416 .58547 L
s
1 .005 0 r
.57413 .84727 m
.5741 .84721 L
s
.57418 .84721 m
.57413 .84727 L
s
.5741 .84721 m
.57418 .84721 L
s
1 0 0 r
.34232 .53771 m
.34233 .53771 L
s
.34233 .53771 m
.34233 .53771 L
s
.34233 .53771 m
.34233 .53771 L
s
.34233 .53771 m
.34233 .53771 L
s
.34232 .53771 m
.34233 .53771 L
s
.34233 .53771 m
.34233 .53771 L
s
.34233 .53771 m
.34233 .53771 L
s
.34232 .53771 m
.34233 .53771 L
s
.34233 .53771 m
.34232 .53771 L
s
.77573 .51383 m
.77573 .51383 L
s
.77573 .51383 m
.77573 .51383 L
s
.77573 .51383 m
.77573 .51383 L
s
.77573 .51383 m
.77573 .51383 L
s
.77573 .51383 m
.77573 .51383 L
s
.77573 .51383 m
.77573 .51383 L
s
.77573 .51383 m
.77573 .51383 L
s
.77573 .51383 m
.77573 .51383 L
s
.77573 .51383 m
.77573 .51383 L
s
1 .002 0 r
.62368 .72795 m
.62376 .7279 L
s
.62374 .7279 m
.62375 .72792 L
s
.62373 .72791 m
.62374 .7279 L
s
.62374 .7279 m
.62376 .7279 L
s
.62375 .72792 m
.62374 .72793 L
s
.62376 .7279 m
.62375 .72792 L
s
.62374 .72793 m
.62373 .72791 L
s
.62373 .72791 m
.62376 .7279 L
s
.62376 .7279 m
.62374 .72793 L
s
1 .003 0 r
.43183 .68019 m
.43199 .68013 L
s
.43197 .68016 m
.43195 .68017 L
s
.43196 .68012 m
.43197 .68016 L
s
.43199 .68013 m
.43197 .68016 L
s
.43194 .68013 m
.43196 .68012 L
s
.43196 .68012 m
.43199 .68013 L
s
.43195 .68017 m
.43194 .68013 L
s
.43199 .68013 m
.43195 .68017 L
s
.43194 .68013 m
.43199 .68013 L
s
1 0 0 r
.67345 .60854 m
.67345 .60854 L
s
.67345 .60854 m
.67345 .60854 L
s
.67345 .60854 m
.67345 .60854 L
s
.67345 .60854 m
.67345 .60854 L
s
.67345 .60854 m
.67345 .60854 L
s
.67345 .60854 m
.67345 .60854 L
s
.67345 .60854 m
.67345 .60854 L
s
.67345 .60854 m
.67345 .60854 L
s
.67345 .60854 m
.67345 .60854 L
s
1 .005 0 r
.52136 .82273 m
.52164 .82261 L
s
.52162 .82266 m
.52159 .82268 L
s
.52159 .82259 m
.52162 .82266 L
s
.52164 .82261 m
.52162 .82266 L
s
.52156 .82262 m
.52159 .82259 L
s
.52159 .82259 m
.52164 .82261 L
s
1 0 0 r
.48156 .56077 m
.48156 .56076 L
s
.48156 .56076 m
.48156 .56077 L
s
.48156 .56076 m
.48156 .56076 L
s
.48156 .56076 m
.48156 .56076 L
s
.48156 .56077 m
.48156 .56077 L
s
.48156 .56076 m
.48156 .56077 L
s
.48156 .56077 m
.48156 .56076 L
s
.48156 .56076 m
.48156 .56076 L
s
.48156 .56076 m
.48156 .56077 L
s
1 .005 0 r
.52159 .82268 m
.52156 .82262 L
s
.52164 .82261 m
.52159 .82268 L
s
.52156 .82262 m
.52164 .82261 L
s
1 0 0 r
.91513 .53688 m
.91513 .53688 L
s
.91513 .53688 m
.91513 .53688 L
s
.91513 .53688 m
.91513 .53688 L
s
.91513 .53688 m
.91513 .53688 L
s
.91513 .53688 m
.91513 .53688 L
s
.91513 .53688 m
.91513 .53688 L
s
.91513 .53688 m
.91513 .53688 L
s
.91513 .53688 m
.91513 .53688 L
s
.91513 .53688 m
.91513 .53688 L
s
1 .002 0 r
.57112 .70331 m
.5712 .70326 L
s
.57118 .70326 m
.5712 .70328 L
s
.57117 .70326 m
.57118 .70326 L
s
.57118 .70326 m
.5712 .70326 L
s
.5712 .70328 m
.57118 .70329 L
s
.5712 .70326 m
.5712 .70328 L
s
.57118 .70329 m
.57117 .70326 L
s
.57117 .70326 m
.5712 .70326 L
s
.5712 .70326 m
.57118 .70329 L
s
1 .003 0 r
.37917 .65553 m
.37935 .65548 L
s
.37933 .6555 m
.37931 .65551 L
s
.37931 .65546 m
.37933 .6555 L
s
.37935 .65548 m
.37933 .6555 L
s
.3793 .65547 m
.37931 .65546 L
s
.37931 .65546 m
.37935 .65548 L
s
.37935 .65548 m
.37931 .65551 L
s
.3793 .65547 m
.37935 .65548 L
s
.37931 .65551 m
.3793 .65547 L
s
1 0 0 r
.81284 .63164 m
.81285 .63163 L
s
.81285 .63163 m
.81285 .63163 L
s
.81284 .63163 m
.81285 .63163 L
s
.81285 .63163 m
.81285 .63163 L
s
.81285 .63163 m
.81285 .63163 L
s
.81285 .63163 m
.81285 .63163 L
s
.81285 .63163 m
.81284 .63163 L
s
.81284 .63163 m
.81285 .63163 L
s
.81285 .63163 m
.81285 .63163 L
s
.6209 .58385 m
.6209 .58384 L
s
.6209 .58384 m
.6209 .58384 L
s
.6209 .58384 m
.6209 .58384 L
s
.6209 .58384 m
.6209 .58384 L
s
.6209 .58384 m
.6209 .58384 L
s
.6209 .58384 m
.6209 .58384 L
s
.6209 .58384 m
.6209 .58384 L
s
.6209 .58384 m
.6209 .58384 L
s
.6209 .58384 m
.6209 .58384 L
s
1 .006 0 r
.46874 .79812 m
.46907 .79801 L
s
.46904 .79805 m
.469 .79808 L
s
.469 .79798 m
.46904 .79805 L
s
.46907 .79801 m
.46904 .79805 L
s
.46897 .798 m
.469 .79798 L
s
.469 .79798 m
.46907 .79801 L
s
1 0 0 r
.42892 .53605 m
.42892 .53604 L
s
.42892 .53604 m
.42892 .53605 L
s
.42892 .53604 m
.42892 .53604 L
s
.42892 .53604 m
.42892 .53604 L
s
.42892 .53605 m
.42892 .53605 L
s
.42892 .53604 m
.42892 .53605 L
s
.42892 .53605 m
.42892 .53604 L
s
.42892 .53604 m
.42892 .53604 L
s
.42892 .53604 m
.42892 .53605 L
s
1 .006 0 r
.469 .79808 m
.46897 .798 L
s
.46907 .79801 m
.469 .79808 L
s
.46897 .798 m
.46907 .79801 L
s
1 0 0 r
.86267 .51214 m
.86267 .51214 L
s
.86267 .51214 m
.86267 .51214 L
s
.86267 .51214 m
.86267 .51214 L
s
.86267 .51214 m
.86267 .51214 L
s
.86267 .51214 m
.86267 .51214 L
s
.86267 .51214 m
.86267 .51214 L
s
.86267 .51214 m
.86267 .51214 L
s
.86267 .51214 m
.86267 .51214 L
s
.86267 .51214 m
.86267 .51214 L
s
1 .001 0 r
.71051 .72644 m
.71055 .72641 L
s
.71055 .72641 m
.71055 .72642 L
s
.71054 .72641 m
.71055 .72641 L
s
.71055 .72641 m
.71055 .72641 L
s
.71055 .72642 m
.71055 .72642 L
s
.71055 .72641 m
.71055 .72642 L
s
.71055 .72642 m
.71054 .72641 L
s
.71054 .72641 m
.71055 .72641 L
s
.71055 .72641 m
.71055 .72642 L
s
1 .002 0 r
.51851 .67865 m
.5186 .6786 L
s
.51858 .67859 m
.51859 .67861 L
s
.51857 .6786 m
.51858 .67859 L
s
.51858 .67859 m
.5186 .6786 L
s
.51859 .67861 m
.51858 .67862 L
s
.5186 .6786 m
.51859 .67861 L
s
.51858 .67862 m
.51857 .6786 L
s
.51857 .6786 m
.5186 .6786 L
s
.5186 .6786 m
.51858 .67862 L
s
1 0 0 r
.76033 .60694 m
.76034 .60693 L
s
.76034 .60693 m
.76034 .60694 L
s
.76033 .60694 m
.76034 .60693 L
s
.76034 .60693 m
.76034 .60693 L
s
.76034 .60694 m
.76034 .60694 L
s
.76034 .60693 m
.76034 .60694 L
s
.76034 .60694 m
.76033 .60694 L
s
.76033 .60694 m
.76034 .60693 L
s
.76034 .60693 m
.76034 .60694 L
s
1 .004 0 r
.60813 .82129 m
.60831 .8212 L
s
.60827 .82119 m
.6083 .82123 L
s
.60825 .82121 m
.60827 .82119 L
s
.60827 .82119 m
.60831 .8212 L
s
.6083 .82123 m
.60827 .82125 L
s
.60831 .8212 m
.6083 .82123 L
s
1 0 0 r
.5683 .55912 m
.5683 .55912 L
s
.5683 .55912 m
.5683 .55912 L
s
.5683 .55912 m
.5683 .55912 L
s
.5683 .55912 m
.5683 .55912 L
s
.5683 .55912 m
.5683 .55912 L
s
.5683 .55912 m
.5683 .55912 L
s
.5683 .55912 m
.5683 .55912 L
s
.5683 .55912 m
.5683 .55912 L
s
.5683 .55912 m
.5683 .55912 L
s
1 .004 0 r
.60827 .82125 m
.60825 .82121 L
s
.60825 .82121 m
.60831 .8212 L
s
.60831 .8212 m
.60827 .82125 L
s
1 .006 0 r
.41607 .77349 m
.41645 .77338 L
s
.41641 .77343 m
.41638 .77346 L
s
.41638 .77335 m
.41641 .77343 L
s
.41645 .77338 m
.41641 .77343 L
s
.41634 .77337 m
.41638 .77335 L
s
.41638 .77335 m
.41645 .77338 L
s
1 0 0 r
.37623 .5113 m
.37623 .5113 L
s
.37623 .5113 m
.37623 .5113 L
s
.37623 .5113 m
.37623 .5113 L
s
.37623 .5113 m
.37623 .5113 L
s
.37623 .5113 m
.37623 .5113 L
s
.37623 .5113 m
.37623 .5113 L
s
.37623 .5113 m
.37623 .5113 L
s
.37623 .5113 m
.37623 .5113 L
s
.37623 .5113 m
.37623 .5113 L
s
1 .006 0 r
.41645 .77338 m
.41638 .77346 L
s
.41634 .77337 m
.41645 .77338 L
s
.41638 .77346 m
.41634 .77337 L
s
1 .001 0 r
.65794 .70178 m
.65799 .70175 L
s
.65798 .70174 m
.65799 .70176 L
s
.65797 .70175 m
.65798 .70174 L
s
.65798 .70174 m
.65799 .70175 L
s
.65799 .70176 m
.65798 .70176 L
s
.65799 .70175 m
.65799 .70176 L
s
.65798 .70176 m
.65797 .70175 L
s
.65797 .70175 m
.65799 .70175 L
s
.65799 .70175 m
.65798 .70176 L
s
1 .002 0 r
.46585 .65396 m
.46595 .65392 L
s
.46594 .65393 m
.46593 .65394 L
s
.46593 .65391 m
.46594 .65393 L
s
.46595 .65392 m
.46594 .65393 L
s
.46592 .65392 m
.46593 .65391 L
s
.46593 .65391 m
.46595 .65392 L
s
.46593 .65394 m
.46592 .65392 L
s
.46595 .65392 m
.46593 .65394 L
s
.46592 .65392 m
.46595 .65392 L
s
1 0 0 r
.70778 .58222 m
.70778 .58222 L
s
.70778 .58222 m
.70778 .58222 L
s
.70778 .58222 m
.70778 .58222 L
s
.70778 .58222 m
.70778 .58222 L
s
.70778 .58222 m
.70778 .58222 L
s
.70778 .58222 m
.70778 .58222 L
s
.70778 .58222 m
.70778 .58222 L
s
.70778 .58222 m
.70778 .58222 L
s
.70778 .58222 m
.70778 .58222 L
s
1 .004 0 r
.5555 .79666 m
.55571 .79657 L
s
.5557 .7966 m
.55567 .79662 L
s
.55567 .79655 m
.5557 .7966 L
s
.55571 .79657 m
.5557 .7966 L
s
.55564 .79657 m
.55567 .79655 L
s
.55567 .79655 m
.55571 .79657 L
s
1 0 0 r
.51565 .53438 m
.51565 .53438 L
s
.51565 .53438 m
.51565 .53438 L
s
.51565 .53438 m
.51565 .53438 L
s
.51565 .53438 m
.51565 .53438 L
s
.51565 .53438 m
.51565 .53438 L
s
.51565 .53438 m
.51565 .53438 L
s
.51565 .53438 m
.51565 .53438 L
s
.51565 .53438 m
.51565 .53438 L
s
.51565 .53438 m
.51565 .53438 L
s
1 .004 0 r
.55567 .79662 m
.55564 .79657 L
s
.55571 .79657 m
.55567 .79662 L
s
.55564 .79657 m
.55571 .79657 L
s
1 0 0 r
.94976 .51046 m
.94976 .51046 L
s
.94976 .51046 m
.94976 .51046 L
s
.94976 .51046 m
.94976 .51046 L
s
.94976 .51046 m
.94976 .51046 L
s
.94976 .51046 m
.94976 .51046 L
s
.94976 .51046 m
.94976 .51046 L
s
.94976 .51046 m
.94976 .51046 L
s
.94976 .51046 m
.94976 .51046 L
s
.94976 .51046 m
.94976 .51046 L
s
1 .001 0 r
.60533 .67709 m
.60538 .67706 L
s
.60537 .67706 m
.60538 .67707 L
s
.60536 .67706 m
.60537 .67706 L
s
.60537 .67706 m
.60538 .67706 L
s
.60538 .67707 m
.60537 .67708 L
s
.60538 .67706 m
.60538 .67707 L
s
.60537 .67708 m
.60536 .67706 L
s
.60536 .67706 m
.60538 .67706 L
s
.60538 .67706 m
.60537 .67708 L
s
1 .002 0 r
.41315 .62925 m
.41325 .62921 L
s
.41324 .62923 m
.41323 .62924 L
s
.41323 .62921 m
.41324 .62923 L
s
.41325 .62921 m
.41324 .62923 L
s
.41322 .62921 m
.41323 .62921 L
s
.41323 .62921 m
.41325 .62921 L
s
.41323 .62924 m
.41322 .62921 L
s
.41325 .62921 m
.41323 .62924 L
s
.41322 .62921 m
.41325 .62921 L
s
1 0 0 r
.84736 .60533 m
.84736 .60533 L
s
.84736 .60533 m
.84736 .60533 L
s
.84736 .60533 m
.84736 .60533 L
s
.84736 .60533 m
.84736 .60533 L
s
.84736 .60533 m
.84736 .60533 L
s
.84736 .60533 m
.84736 .60533 L
s
.84736 .60533 m
.84736 .60533 L
s
.84736 .60533 m
.84736 .60533 L
s
.84736 .60533 m
.84736 .60533 L
s
.65518 .55748 m
.65518 .55748 L
s
.65518 .55748 m
.65518 .55748 L
s
.65518 .55748 m
.65518 .55748 L
s
.65518 .55748 m
.65518 .55748 L
s
.65518 .55748 m
.65518 .55748 L
s
.65518 .55748 m
.65518 .55748 L
s
.65518 .55748 m
.65518 .55748 L
s
.65518 .55748 m
.65518 .55748 L
s
.65518 .55748 m
.65518 .55748 L
s
1 .005 0 r
.50283 .77202 m
.50308 .77192 L
s
.50306 .77195 m
.50303 .77197 L
s
.50303 .7719 m
.50306 .77195 L
s
.50308 .77192 m
.50306 .77195 L
s
.503 .77192 m
.50303 .7719 L
s
.50303 .7719 m
.50308 .77192 L
s
1 0 0 r
.46296 .50962 m
.46296 .50962 L
s
.46296 .50962 m
.46296 .50962 L
s
.46296 .50962 m
.46296 .50962 L
s
.46296 .50962 m
.46296 .50962 L
s
.46296 .50962 m
.46296 .50962 L
s
.46296 .50962 m
.46296 .50962 L
s
.46296 .50962 m
.46296 .50962 L
s
.46296 .50962 m
.46296 .50962 L
s
.46296 .50962 m
.46296 .50962 L
s
1 .005 0 r
.50303 .77197 m
.503 .77192 L
s
.50308 .77192 m
.50303 .77197 L
s
.503 .77192 m
.50308 .77192 L
s
1 .001 0 r
.74491 .70025 m
.74493 .70022 L
s
.74493 .70022 m
.74493 .70023 L
s
.74492 .70023 m
.74493 .70022 L
s
.74493 .70022 m
.74493 .70022 L
s
.74493 .70023 m
.74493 .70023 L
s
.74493 .70022 m
.74493 .70023 L
s
.74493 .70023 m
.74492 .70023 L
s
.74492 .70023 m
.74493 .70022 L
s
.74493 .70022 m
.74493 .70023 L
s
.55267 .65239 m
.55272 .65236 L
s
.55271 .65235 m
.55272 .65237 L
s
.5527 .65236 m
.55271 .65235 L
s
.55271 .65235 m
.55272 .65236 L
s
.55272 .65237 m
.55271 .65237 L
s
.55272 .65236 m
.55272 .65237 L
s
.55271 .65237 m
.5527 .65236 L
s
.5527 .65236 m
.55272 .65236 L
s
.55272 .65236 m
.55271 .65237 L
s
1 .002 0 r
.3604 .60452 m
.36049 .60449 L
s
.36048 .60451 m
.36047 .60451 L
s
.36048 .60449 m
.36048 .60451 L
s
.36049 .60449 m
.36048 .60451 L
s
.36047 .60449 m
.36048 .60449 L
s
.36048 .60449 m
.36049 .60449 L
s
.36049 .60449 m
.36047 .60451 L
s
.36047 .60449 m
.36049 .60449 L
s
.36047 .60451 m
.36047 .60449 L
s
1 0 0 r
.7948 .58059 m
.7948 .58059 L
s
.7948 .58059 m
.7948 .58059 L
s
.7948 .58059 m
.7948 .58059 L
s
.7948 .58059 m
.7948 .58059 L
s
.7948 .58059 m
.7948 .58059 L
s
.7948 .58059 m
.7948 .58059 L
s
.7948 .58059 m
.7948 .58059 L
s
.7948 .58059 m
.7948 .58059 L
s
.7948 .58059 m
.7948 .58059 L
s
1 .003 0 r
.64241 .79521 m
.64254 .79513 L
s
.64251 .79512 m
.64253 .79516 L
s
.64249 .79514 m
.64251 .79512 L
s
.64251 .79512 m
.64254 .79513 L
s
.64253 .79516 m
.64251 .79517 L
s
.64254 .79513 m
.64253 .79516 L
s
.64251 .79517 m
.64249 .79514 L
s
.64249 .79514 m
.64254 .79513 L
s
.64254 .79513 m
.64251 .79517 L
s
1 0 0 r
.60253 .53271 m
.60253 .53271 L
s
.60253 .53271 m
.60253 .53271 L
s
.60253 .53271 m
.60253 .53271 L
s
.60253 .53271 m
.60253 .53271 L
s
.60253 .53271 m
.60253 .53271 L
s
.60253 .53271 m
.60253 .53271 L
s
.60253 .53271 m
.60253 .53271 L
s
.60253 .53271 m
.60253 .53271 L
s
.60253 .53271 m
.60253 .53271 L
s
1 .005 0 r
.45011 .74735 m
.4504 .74724 L
s
.45037 .74729 m
.45034 .74731 L
s
.45034 .74722 m
.45037 .74729 L
s
.4504 .74724 m
.45037 .74729 L
s
.45031 .74724 m
.45034 .74722 L
s
.45034 .74722 m
.4504 .74724 L
s
.45034 .74731 m
.45031 .74724 L
s
.4504 .74724 m
.45034 .74731 L
s
.45031 .74724 m
.4504 .74724 L
s
1 .001 0 r
.69229 .67554 m
.69232 .67552 L
s
.69231 .67552 m
.69232 .67553 L
s
.69231 .67552 m
.69231 .67552 L
s
.69231 .67552 m
.69232 .67552 L
s
.69232 .67553 m
.69231 .67553 L
s
.69232 .67552 m
.69232 .67553 L
s
.69231 .67553 m
.69231 .67552 L
s
.69231 .67552 m
.69232 .67552 L
s
.69232 .67552 m
.69231 .67553 L
s
.49996 .62766 m
.50001 .62763 L
s
.5 .62763 m
.50001 .62764 L
s
.5 .62763 m
.5 .62763 L
s
.5 .62763 m
.50001 .62763 L
s
.50001 .62764 m
.5 .62765 L
s
.50001 .62763 m
.50001 .62764 L
s
.5 .62765 m
.5 .62763 L
s
.5 .62763 m
.50001 .62763 L
s
.50001 .62763 m
.5 .62765 L
s
1 0 0 r
.74219 .55583 m
.74219 .55583 L
s
.74219 .55583 m
.74219 .55583 L
s
.74219 .55583 m
.74219 .55583 L
s
.74219 .55583 m
.74219 .55583 L
s
.74219 .55583 m
.74219 .55583 L
s
.74219 .55583 m
.74219 .55583 L
s
.74219 .55583 m
.74219 .55583 L
s
.74219 .55583 m
.74219 .55583 L
s
.74219 .55583 m
.74219 .55583 L
s
1 .003 0 r
.58973 .77054 m
.58988 .77046 L
s
.58985 .77045 m
.58987 .77049 L
s
.58983 .77046 m
.58985 .77045 L
s
.58985 .77045 m
.58988 .77046 L
s
.58987 .77049 m
.58985 .7705 L
s
.58988 .77046 m
.58987 .77049 L
s
.58985 .7705 m
.58983 .77046 L
s
.58983 .77046 m
.58988 .77046 L
s
.58988 .77046 m
.58985 .7705 L
s
1 0 0 r
.54983 .50793 m
.54983 .50793 L
s
.54983 .50793 m
.54983 .50793 L
s
.54983 .50793 m
.54983 .50793 L
s
.54983 .50793 m
.54983 .50793 L
s
.54983 .50793 m
.54983 .50793 L
s
.54983 .50793 m
.54983 .50793 L
s
.54983 .50793 m
.54983 .50793 L
s
.54983 .50793 m
.54983 .50793 L
s
.54983 .50793 m
.54983 .50793 L
s
1 .005 0 r
.39735 .72265 m
.39768 .72256 L
s
.39764 .7226 m
.39761 .72262 L
s
.39761 .72253 m
.39764 .7226 L
s
.39768 .72256 m
.39764 .7226 L
s
.39758 .72255 m
.39761 .72253 L
s
.39761 .72253 m
.39768 .72256 L
s
.39768 .72256 m
.39761 .72262 L
s
.39758 .72255 m
.39768 .72256 L
s
.39761 .72262 m
.39758 .72255 L
s
1 .001 0 r
.63963 .65081 m
.63965 .65079 L
s
.63965 .65079 m
.63965 .6508 L
s
.63964 .6508 m
.63965 .65079 L
s
.63965 .65079 m
.63965 .65079 L
s
.63965 .6508 m
.63965 .6508 L
s
.63965 .65079 m
.63965 .6508 L
s
.63965 .6508 m
.63964 .6508 L
s
.63964 .6508 m
.63965 .65079 L
s
.63965 .65079 m
.63965 .6508 L
s
.44721 .60291 m
.44726 .60289 L
s
.44725 .6029 m
.44725 .6029 L
s
.44725 .60289 m
.44725 .6029 L
s
.44726 .60289 m
.44725 .6029 L
s
.44724 .60289 m
.44725 .60289 L
s
.44725 .60289 m
.44726 .60289 L
s
.44725 .6029 m
.44724 .60289 L
s
.44726 .60289 m
.44725 .6029 L
s
.44724 .60289 m
.44726 .60289 L
s
1 0 0 r
.88196 .57896 m
.88196 .57896 L
s
.88196 .57896 m
.88196 .57896 L
s
.88196 .57896 m
.88196 .57896 L
s
.88196 .57896 m
.88196 .57896 L
s
.88196 .57896 m
.88196 .57896 L
s
.88196 .57896 m
.88196 .57896 L
s
.88196 .57896 m
.88196 .57896 L
s
.88196 .57896 m
.88196 .57896 L
s
.88196 .57896 m
.88196 .57896 L
s
.68954 .53104 m
.68954 .53104 L
s
.68954 .53104 m
.68954 .53104 L
s
.68954 .53104 m
.68954 .53104 L
s
.68954 .53104 m
.68954 .53104 L
s
.68954 .53104 m
.68954 .53104 L
s
.68954 .53104 m
.68954 .53104 L
s
.68954 .53104 m
.68954 .53104 L
s
.68954 .53104 m
.68954 .53104 L
s
.68954 .53104 m
.68954 .53104 L
s
1 .003 0 r
.53701 .74585 m
.53718 .74576 L
s
.53715 .74575 m
.53717 .74579 L
s
.53712 .74577 m
.53715 .74575 L
s
.53715 .74575 m
.53718 .74576 L
s
.53717 .74579 m
.53715 .74581 L
s
.53718 .74576 m
.53717 .74579 L
s
.53715 .74581 m
.53712 .74577 L
s
.53712 .74577 m
.53718 .74576 L
s
.53718 .74576 m
.53715 .74581 L
s
1 0 0 r
.77939 .67399 m
.7794 .67397 L
s
.7794 .67397 m
.77941 .67397 L
s
.7794 .67397 m
.7794 .67397 L
s
.7794 .67397 m
.7794 .67397 L
s
.77941 .67397 m
.7794 .67398 L
s
.7794 .67397 m
.77941 .67397 L
s
.7794 .67398 m
.7794 .67397 L
s
.7794 .67397 m
.7794 .67397 L
s
.7794 .67397 m
.7794 .67398 L
s
1 .001 0 r
.58692 .62607 m
.58694 .62605 L
s
.58694 .62605 m
.58694 .62605 L
s
.58693 .62605 m
.58694 .62605 L
s
.58694 .62605 m
.58694 .62605 L
s
.58694 .62605 m
.58694 .62606 L
s
.58694 .62605 m
.58694 .62605 L
s
.58694 .62606 m
.58693 .62605 L
s
.58693 .62605 m
.58694 .62605 L
s
.58694 .62605 m
.58694 .62606 L
s
1 .008 0 r
.43434 .84093 m
.43484 .84079 L
s
.43478 .84085 m
.43474 .84089 L
s
.43474 .84074 m
.43478 .84085 L
s
.43484 .84079 m
.43478 .84085 L
s
1 .001 0 r
.39441 .57814 m
.39445 .57812 L
s
1 .008 0 r
.4347 .84078 m
.43474 .84074 L
s
.43474 .84074 m
.43484 .84079 L
s
1 .001 0 r
.39445 .57813 m
.39444 .57813 L
s
.39444 .57812 m
.39445 .57813 L
s
.39445 .57812 m
.39445 .57813 L
s
.39444 .57812 m
.39444 .57812 L
s
.39444 .57812 m
.39445 .57812 L
s
.39444 .57813 m
.39444 .57812 L
s
.39445 .57812 m
.39444 .57813 L
s
.39444 .57812 m
.39445 .57812 L
s
1 .008 0 r
.43484 .84079 m
.43474 .84089 L
s
.4347 .84078 m
.43484 .84079 L
s
.43474 .84089 m
.4347 .84078 L
s
1 0 0 r
.82935 .55417 m
.82935 .55417 L
s
.82935 .55417 m
.82935 .55417 L
s
.82935 .55417 m
.82935 .55417 L
s
.82935 .55417 m
.82935 .55417 L
s
.82935 .55417 m
.82935 .55417 L
s
.82935 .55417 m
.82935 .55417 L
s
.82935 .55417 m
.82935 .55417 L
s
.82935 .55417 m
.82935 .55417 L
s
.82935 .55417 m
.82935 .55417 L
s
1 .002 0 r
.67677 .76906 m
.67686 .769 L
s
.67684 .76899 m
.67686 .76902 L
s
.67683 .76901 m
.67684 .76899 L
s
.67684 .76899 m
.67686 .769 L
s
.67686 .76902 m
.67684 .76903 L
s
.67686 .769 m
.67686 .76902 L
s
.67684 .76903 m
.67683 .76901 L
s
.67683 .76901 m
.67686 .769 L
s
.67686 .769 m
.67684 .76903 L
s
1 0 0 r
.63684 .50624 m
.63684 .50624 L
s
.63684 .50624 m
.63684 .50624 L
s
.63684 .50624 m
.63684 .50624 L
s
.63684 .50624 m
.63684 .50624 L
s
.63684 .50624 m
.63684 .50624 L
s
.63684 .50624 m
.63684 .50624 L
s
.63684 .50624 m
.63684 .50624 L
s
.63684 .50624 m
.63684 .50624 L
s
.63684 .50624 m
.63684 .50624 L
s
1 .004 0 r
.48424 .72114 m
.48444 .72105 L
s
.48442 .72108 m
.4844 .7211 L
s
.4844 .72104 m
.48442 .72108 L
s
.48444 .72105 m
.48442 .72108 L
s
.48437 .72105 m
.4844 .72104 L
s
.4844 .72104 m
.48444 .72105 L
s
.4844 .7211 m
.48437 .72105 L
s
.48444 .72105 m
.4844 .7211 L
s
.48437 .72105 m
.48444 .72105 L
s
1 0 0 r
.72672 .64924 m
.72674 .64923 L
s
.72673 .64922 m
.72674 .64923 L
s
.72673 .64923 m
.72673 .64922 L
s
.72673 .64922 m
.72674 .64923 L
s
.72674 .64923 m
.72673 .64923 L
s
.72674 .64923 m
.72674 .64923 L
s
.72673 .64923 m
.72673 .64923 L
s
.72673 .64923 m
.72674 .64923 L
s
.72674 .64923 m
.72673 .64923 L
s
.53416 .6013 m
.53418 .60128 L
s
.53418 .60128 m
.53418 .60129 L
s
.53417 .60128 m
.53418 .60128 L
s
.53418 .60128 m
.53418 .60128 L
s
.53418 .60129 m
.53418 .60129 L
s
.53418 .60128 m
.53418 .60129 L
s
.53418 .60129 m
.53417 .60128 L
s
.53417 .60128 m
.53418 .60128 L
s
.53418 .60128 m
.53418 .60129 L
s
.34157 .55335 m
.34159 .55334 L
s
.34159 .55334 m
.34159 .55334 L
s
.34159 .55334 m
.34159 .55334 L
s
.34159 .55334 m
.34159 .55334 L
s
.34158 .55334 m
.34159 .55334 L
s
.34159 .55334 m
.34159 .55334 L
s
.34159 .55334 m
.34159 .55334 L
s
.34158 .55334 m
.34159 .55334 L
s
.34159 .55334 m
.34158 .55334 L
s
.77669 .52937 m
.77669 .52937 L
s
.77669 .52937 m
.77669 .52937 L
s
.77669 .52937 m
.77669 .52937 L
s
.77669 .52937 m
.77669 .52937 L
s
.77669 .52937 m
.77669 .52937 L
s
.77669 .52937 m
.77669 .52937 L
s
.77669 .52937 m
.77669 .52937 L
s
.77669 .52937 m
.77669 .52937 L
s
.77669 .52937 m
.77669 .52937 L
s
1 .002 0 r
.62404 .74435 m
.62414 .74429 L
s
.62412 .74428 m
.62414 .74431 L
s
.62411 .74429 m
.62412 .74428 L
s
.62412 .74428 m
.62414 .74429 L
s
.62414 .74431 m
.62412 .74432 L
s
.62414 .74429 m
.62414 .74431 L
s
.62412 .74432 m
.62411 .74429 L
s
.62411 .74429 m
.62414 .74429 L
s
.62414 .74429 m
.62412 .74432 L
s
1 .004 0 r
.43143 .6964 m
.43165 .69632 L
s
.43163 .69635 m
.43161 .69637 L
s
.43161 .6963 m
.43163 .69635 L
s
.43165 .69632 m
.43163 .69635 L
s
.43158 .69632 m
.43161 .6963 L
s
.43161 .6963 m
.43165 .69632 L
s
.43161 .69637 m
.43158 .69632 L
s
.43165 .69632 m
.43161 .69637 L
s
.43158 .69632 m
.43165 .69632 L
s
1 0 0 r
.67401 .62447 m
.67402 .62446 L
s
.67402 .62446 m
.67402 .62446 L
s
.67402 .62446 m
.67402 .62446 L
s
.67402 .62446 m
.67402 .62446 L
s
.67402 .62446 m
.67402 .62446 L
s
.67402 .62446 m
.67402 .62446 L
s
.67402 .62446 m
.67402 .62446 L
s
.67402 .62446 m
.67402 .62446 L
s
.67402 .62446 m
.67402 .62446 L
s
1 .006 0 r
.52132 .8395 m
.52165 .83937 L
s
1 0 0 r
.48136 .5765 m
.48137 .57649 L
s
1 .006 0 r
.52162 .83942 m
.52159 .83945 L
s
.52159 .83934 m
.52162 .83942 L
s
.52165 .83937 m
.52162 .83942 L
s
.52155 .83937 m
.52159 .83934 L
s
.52159 .83934 m
.52165 .83937 L
s
1 0 0 r
.48137 .57649 m
.48137 .5765 L
s
.48137 .57649 m
.48137 .57649 L
s
.48137 .57649 m
.48137 .57649 L
s
.48137 .5765 m
.48137 .5765 L
s
.48137 .57649 m
.48137 .5765 L
s
.48137 .5765 m
.48137 .57649 L
s
.48137 .57649 m
.48137 .57649 L
s
.48137 .57649 m
.48137 .5765 L
s
1 .006 0 r
.52159 .83945 m
.52155 .83937 L
s
.52165 .83937 m
.52159 .83945 L
s
.52155 .83937 m
.52165 .83937 L
s
1 0 0 r
.91665 .55252 m
.91665 .55252 L
s
.91665 .55252 m
.91665 .55252 L
s
.91665 .55252 m
.91665 .55252 L
s
.91665 .55252 m
.91665 .55252 L
s
.91665 .55252 m
.91665 .55252 L
s
.91665 .55252 m
.91665 .55252 L
s
.91665 .55252 m
.91665 .55252 L
s
.91665 .55252 m
.91665 .55252 L
s
.91665 .55252 m
.91665 .55252 L
s
.72399 .50454 m
.72399 .50454 L
s
.72399 .50454 m
.72399 .50454 L
s
.72399 .50454 m
.72399 .50454 L
s
.72399 .50454 m
.72399 .50454 L
s
.72399 .50454 m
.72399 .50454 L
s
.72399 .50454 m
.72399 .50454 L
s
.72399 .50454 m
.72399 .50454 L
s
.72399 .50454 m
.72399 .50454 L
s
.72399 .50454 m
.72399 .50454 L
s
1 .002 0 r
.57127 .71962 m
.57138 .71955 L
s
.57136 .71954 m
.57138 .71957 L
s
.57134 .71955 m
.57136 .71954 L
s
.57136 .71954 m
.57138 .71955 L
s
.57138 .71957 m
.57136 .71958 L
s
.57138 .71955 m
.57138 .71957 L
s
.57136 .71958 m
.57134 .71955 L
s
.57134 .71955 m
.57138 .71955 L
s
.57138 .71955 m
.57136 .71958 L
s
1 .004 0 r
.37857 .67165 m
.37882 .67157 L
s
.37879 .6716 m
.37877 .67162 L
s
.37877 .67155 m
.37879 .6716 L
s
.37882 .67157 m
.37879 .6716 L
s
.37875 .67156 m
.37877 .67155 L
s
.37877 .67155 m
.37882 .67157 L
s
1 0 0 r
.81396 .64766 m
.81397 .64765 L
s
1 .004 0 r
.37882 .67157 m
.37877 .67162 L
s
.37875 .67156 m
.37882 .67157 L
s
.37877 .67162 m
.37875 .67156 L
s
1 0 0 r
.81396 .64765 m
.81397 .64765 L
s
.81396 .64765 m
.81396 .64765 L
s
.81396 .64765 m
.81397 .64765 L
s
.81397 .64765 m
.81396 .64765 L
s
.81397 .64765 m
.81397 .64765 L
s
.81396 .64765 m
.81396 .64765 L
s
.81396 .64765 m
.81397 .64765 L
s
.81397 .64765 m
.81396 .64765 L
s
.62125 .59968 m
.62126 .59967 L
s
.62126 .59967 m
.62126 .59967 L
s
.62125 .59967 m
.62126 .59967 L
s
.62126 .59967 m
.62126 .59967 L
s
.62126 .59967 m
.62126 .59967 L
s
.62126 .59967 m
.62126 .59967 L
s
.62126 .59967 m
.62125 .59967 L
s
.62125 .59967 m
.62126 .59967 L
s
.62126 .59967 m
.62126 .59967 L
s
1 .007 0 r
.46849 .81481 m
.46888 .81467 L
s
.46884 .81473 m
.4688 .81476 L
s
.4688 .81464 m
.46884 .81473 L
s
.46888 .81467 m
.46884 .81473 L
s
1 0 0 r
.42851 .55169 m
.42852 .55168 L
s
1 .007 0 r
.46876 .81467 m
.4688 .81464 L
s
.4688 .81464 m
.46888 .81467 L
s
1 0 0 r
.42851 .55168 m
.42852 .55169 L
s
.42851 .55168 m
.42851 .55168 L
s
.42851 .55168 m
.42852 .55168 L
s
.42852 .55169 m
.42851 .55169 L
s
.42852 .55168 m
.42852 .55169 L
s
.42851 .55169 m
.42851 .55168 L
s
.42851 .55168 m
.42852 .55168 L
s
.42852 .55168 m
.42851 .55169 L
s
1 .007 0 r
.4688 .81476 m
.46876 .81467 L
s
.46888 .81467 m
.4688 .81476 L
s
.46876 .81467 m
.46888 .81467 L
s
1 0 0 r
.86399 .52769 m
.86399 .52769 L
s
.86399 .52769 m
.86399 .52769 L
s
.86399 .52769 m
.86399 .52769 L
s
.86399 .52769 m
.86399 .52769 L
s
.86399 .52769 m
.86399 .52769 L
s
.86399 .52769 m
.86399 .52769 L
s
.86399 .52769 m
.86399 .52769 L
s
.86399 .52769 m
.86399 .52769 L
s
.86399 .52769 m
.86399 .52769 L
s
1 .001 0 r
.71122 .74284 m
.71128 .7428 L
s
.71127 .7428 m
.71128 .74281 L
s
.71125 .74281 m
.71127 .7428 L
s
.71127 .7428 m
.71128 .7428 L
s
.71128 .74281 m
.71127 .74282 L
s
.71128 .7428 m
.71128 .74281 L
s
.71127 .74282 m
.71125 .74281 L
s
.71125 .74281 m
.71128 .7428 L
s
.71128 .7428 m
.71127 .74282 L
s
1 .003 0 r
.51845 .69486 m
.51858 .69479 L
s
.51855 .69479 m
.51857 .69482 L
s
.51854 .6948 m
.51855 .69479 L
s
.51855 .69479 m
.51858 .69479 L
s
.51857 .69482 m
.51855 .69483 L
s
.51858 .69479 m
.51857 .69482 L
s
.51855 .69483 m
.51854 .6948 L
s
.51854 .6948 m
.51858 .69479 L
s
.51858 .69479 m
.51855 .69483 L
s
1 0 0 r
.76124 .62287 m
.76125 .62286 L
s
.76125 .62286 m
.76125 .62286 L
s
.76124 .62286 m
.76125 .62286 L
s
.76125 .62286 m
.76125 .62286 L
s
.76125 .62286 m
.76125 .62287 L
s
.76125 .62286 m
.76125 .62286 L
s
.76125 .62287 m
.76124 .62286 L
s
.76124 .62286 m
.76125 .62286 L
s
.76125 .62286 m
.76125 .62287 L
s
1 .004 0 r
.60843 .83808 m
.60865 .83797 L
s
.6086 .83795 m
.60863 .83801 L
s
.60857 .83797 m
.6086 .83795 L
s
.6086 .83795 m
.60865 .83797 L
s
.60863 .83801 m
.6086 .83803 L
s
.60865 .83797 m
.60863 .83801 L
s
1 0 0 r
.56844 .57487 m
.56845 .57486 L
s
.56845 .57486 m
.56845 .57486 L
s
.56844 .57486 m
.56845 .57486 L
s
.56845 .57486 m
.56845 .57486 L
s
.56845 .57486 m
.56845 .57486 L
s
.56845 .57486 m
.56845 .57486 L
s
.56845 .57486 m
.56844 .57486 L
s
.56844 .57486 m
.56845 .57486 L
s
.56845 .57486 m
.56845 .57486 L
s
1 .004 0 r
.6086 .83803 m
.60857 .83797 L
s
.60857 .83797 m
.60865 .83797 L
s
.60865 .83797 m
.6086 .83803 L
s
1 .008 0 r
.41561 .79009 m
.41608 .78995 L
s
.41602 .79001 m
.41598 .79005 L
s
.41598 .78991 m
.41602 .79001 L
s
.41608 .78995 m
.41602 .79001 L
s
.41594 .78994 m
.41598 .78991 L
s
.41598 .78991 m
.41608 .78995 L
s
1 0 0 r
.37561 .52685 m
.37561 .52685 L
s
.37561 .52685 m
.37561 .52685 L
s
.37561 .52685 m
.37561 .52685 L
s
.37561 .52685 m
.37561 .52685 L
s
.37561 .52685 m
.37561 .52685 L
s
.37561 .52685 m
.37561 .52685 L
s
.37561 .52685 m
.37561 .52685 L
s
.37561 .52685 m
.37561 .52685 L
s
.37561 .52685 m
.37561 .52685 L
s
1 .008 0 r
.41608 .78995 m
.41598 .79005 L
s
.41594 .78994 m
.41608 .78995 L
s
.41598 .79005 m
.41594 .78994 L
s
1 0 0 r
.81128 .50285 m
.81128 .50285 L
s
.81128 .50285 m
.81128 .50285 L
s
.81128 .50285 m
.81128 .50285 L
s
.81128 .50285 m
.81128 .50285 L
s
.81128 .50285 m
.81128 .50285 L
s
.81128 .50285 m
.81128 .50285 L
s
.81128 .50285 m
.81128 .50285 L
s
.81128 .50285 m
.81128 .50285 L
s
.81128 .50285 m
.81128 .50285 L
s
1 .002 0 r
.65844 .71809 m
.65851 .71805 L
s
.65849 .71804 m
.65851 .71806 L
s
.65848 .71805 m
.65849 .71804 L
s
.65849 .71804 m
.65851 .71805 L
s
.65851 .71806 m
.65849 .71807 L
s
.65851 .71805 m
.65851 .71806 L
s
.65849 .71807 m
.65848 .71805 L
s
.65848 .71805 m
.65851 .71805 L
s
.65851 .71805 m
.65849 .71807 L
s
1 .003 0 r
.46559 .67008 m
.46573 .67002 L
s
.46572 .67004 m
.4657 .67005 L
s
.4657 .67001 m
.46572 .67004 L
s
.46573 .67002 m
.46572 .67004 L
s
.46568 .67002 m
.4657 .67001 L
s
.4657 .67001 m
.46573 .67002 L
s
.4657 .67005 m
.46568 .67002 L
s
.46573 .67002 m
.4657 .67005 L
s
.46568 .67002 m
.46573 .67002 L
s
1 0 0 r
.70848 .59806 m
.70848 .59805 L
s
.70848 .59805 m
.70848 .59805 L
s
.70848 .59805 m
.70848 .59805 L
s
.70848 .59805 m
.70848 .59805 L
s
.70848 .59805 m
.70848 .59806 L
s
.70848 .59805 m
.70848 .59805 L
s
.70848 .59806 m
.70848 .59805 L
s
.70848 .59805 m
.70848 .59805 L
s
.70848 .59805 m
.70848 .59806 L
s
1 .005 0 r
.55559 .81336 m
.55585 .81324 L
s
.55583 .81328 m
.5558 .81331 L
s
.5558 .81322 m
.55583 .81328 L
s
.55585 .81324 m
.55583 .81328 L
s
.55577 .81325 m
.5558 .81322 L
s
.5558 .81322 m
.55585 .81324 L
s
1 0 0 r
.51559 .55003 m
.51559 .55003 L
s
.51559 .55003 m
.51559 .55003 L
s
.51559 .55003 m
.51559 .55003 L
s
.51559 .55003 m
.51559 .55003 L
s
.51559 .55003 m
.51559 .55003 L
s
.51559 .55003 m
.51559 .55003 L
s
.51559 .55003 m
.51559 .55003 L
s
.51559 .55003 m
.51559 .55003 L
s
.51559 .55003 m
.51559 .55003 L
s
1 .005 0 r
.5558 .81331 m
.55577 .81325 L
s
.55585 .81324 m
.5558 .81331 L
s
.55577 .81325 m
.55585 .81324 L
s
1 0 0 r
.95142 .52602 m
.95142 .52602 L
s
.95142 .52602 m
.95142 .52602 L
s
.95142 .52602 m
.95142 .52602 L
s
.95142 .52602 m
.95142 .52602 L
s
.95142 .52602 m
.95142 .52602 L
s
.95142 .52602 m
.95142 .52602 L
s
.95142 .52602 m
.95142 .52602 L
s
.95142 .52602 m
.95142 .52602 L
s
.95142 .52602 m
.95142 .52602 L
s
.32267 .502 m
.32267 .502 L
s
.32267 .502 m
.32267 .502 L
s
.32267 .502 m
.32267 .502 L
s
.32267 .502 m
.32267 .502 L
s
.32267 .502 m
.32267 .502 L
s
.32267 .502 m
.32267 .502 L
s
.32267 .502 m
.32267 .502 L
s
.32267 .502 m
.32267 .502 L
s
.32267 .502 m
.32267 .502 L
s
1 .002 0 r
.60562 .69332 m
.60569 .69327 L
s
.60567 .69327 m
.60569 .69328 L
s
.60566 .69327 m
.60567 .69327 L
s
.60567 .69327 m
.60569 .69327 L
s
.60569 .69328 m
.60568 .69329 L
s
.60569 .69327 m
.60569 .69328 L
s
.60568 .69329 m
.60566 .69327 L
s
.60566 .69327 m
.60569 .69327 L
s
.60569 .69327 m
.60568 .69329 L
s
1 .003 0 r
.41268 .64529 m
.41283 .64522 L
s
.41282 .64525 m
.4128 .64526 L
s
.4128 .64521 m
.41282 .64525 L
s
.41283 .64522 m
.41282 .64525 L
s
.41278 .64522 m
.4128 .64521 L
s
.4128 .64521 m
.41283 .64522 L
s
.4128 .64526 m
.41278 .64522 L
s
.41283 .64522 m
.4128 .64526 L
s
.41278 .64522 m
.41283 .64522 L
s
1 0 0 r
.84861 .62127 m
.84862 .62126 L
s
.84862 .62126 m
.84862 .62126 L
s
.84861 .62126 m
.84862 .62126 L
s
.84862 .62126 m
.84862 .62126 L
s
.84862 .62126 m
.84862 .62126 L
s
.84862 .62126 m
.84862 .62126 L
s
.84862 .62126 m
.84861 .62126 L
s
.84861 .62126 m
.84862 .62126 L
s
.84862 .62126 m
.84862 .62126 L
s
.65566 .57323 m
.65567 .57322 L
s
.65567 .57322 m
.65567 .57322 L
s
.65567 .57322 m
.65567 .57322 L
s
.65567 .57322 m
.65567 .57322 L
s
.65567 .57322 m
.65567 .57322 L
s
.65567 .57322 m
.65567 .57322 L
s
.65567 .57322 m
.65567 .57322 L
s
.65567 .57322 m
.65567 .57322 L
s
.65567 .57322 m
.65567 .57322 L
s
1 .006 0 r
.50271 .78862 m
.50302 .7885 L
s
.50299 .78854 m
.50295 .78857 L
s
.50296 .78847 m
.50299 .78854 L
s
.50302 .7885 m
.50299 .78854 L
s
.50292 .7885 m
.50296 .78847 L
s
.50296 .78847 m
.50302 .7885 L
s
1 0 0 r
.46269 .52518 m
.46269 .52517 L
s
.46269 .52517 m
.46269 .52517 L
s
.46269 .52517 m
.46269 .52517 L
s
.46269 .52517 m
.46269 .52517 L
s
.46269 .52517 m
.46269 .52517 L
s
.46269 .52517 m
.46269 .52517 L
s
.46269 .52517 m
.46269 .52517 L
s
.46269 .52517 m
.46269 .52517 L
s
.46269 .52517 m
.46269 .52517 L
s
1 .006 0 r
.50295 .78857 m
.50292 .7885 L
s
.50302 .7885 m
.50295 .78857 L
s
.50292 .7885 m
.50302 .7885 L
s
1 0 0 r
.89871 .50115 m
.89871 .50115 L
s
.89871 .50115 m
.89871 .50115 L
s
.89871 .50115 m
.89871 .50115 L
s
.89871 .50115 m
.89871 .50115 L
s
.89871 .50115 m
.89871 .50115 L
s
.89871 .50115 m
.89871 .50115 L
s
.89871 .50115 m
.89871 .50115 L
s
.89871 .50115 m
.89871 .50115 L
s
.89871 .50115 m
.89871 .50115 L
s
1 .001 0 r
.74575 .71657 m
.74579 .71653 L
s
.74578 .71653 m
.74579 .71654 L
s
.74578 .71654 m
.74578 .71653 L
s
.74578 .71653 m
.74579 .71653 L
s
.74579 .71654 m
.74578 .71655 L
s
.74579 .71653 m
.74579 .71654 L
s
.74578 .71655 m
.74578 .71654 L
s
.74578 .71654 m
.74579 .71653 L
s
.74579 .71653 m
.74578 .71655 L
s
1 .002 0 r
.55275 .66852 m
.55283 .66847 L
s
.55281 .66847 m
.55282 .66849 L
s
.5528 .66848 m
.55281 .66847 L
s
.55281 .66847 m
.55283 .66847 L
s
.55282 .66849 m
.55281 .6685 L
s
.55283 .66847 m
.55282 .66849 L
s
.55281 .6685 m
.5528 .66848 L
s
.5528 .66848 m
.55283 .66847 L
s
.55283 .66847 m
.55281 .6685 L
s
1 .003 0 r
.35972 .62047 m
.35988 .62041 L
s
.35986 .62044 m
.35985 .62045 L
s
.35985 .6204 m
.35986 .62044 L
s
.35988 .62041 m
.35986 .62044 L
s
.35983 .62041 m
.35985 .6204 L
s
.35985 .6204 m
.35988 .62041 L
s
.35988 .62041 m
.35985 .62045 L
s
.35983 .62041 m
.35988 .62041 L
s
.35985 .62045 m
.35983 .62041 L
s
1 0 0 r
.79584 .59644 m
.79585 .59643 L
s
.79585 .59643 m
.79585 .59643 L
s
.79585 .59643 m
.79585 .59643 L
s
.79585 .59643 m
.79585 .59643 L
s
.79585 .59643 m
.79585 .59643 L
s
.79585 .59643 m
.79585 .59643 L
s
.79585 .59643 m
.79585 .59643 L
s
.79585 .59643 m
.79585 .59643 L
s
.79585 .59643 m
.79585 .59643 L
s
1 .003 0 r
.64284 .81191 m
.64301 .81182 L
s
.64297 .81181 m
.643 .81185 L
s
.64295 .81183 m
.64297 .81181 L
s
.64297 .81181 m
.64301 .81182 L
s
.643 .81185 m
.64297 .81187 L
s
.64301 .81182 m
.643 .81185 L
s
1 0 0 r
.60281 .54837 m
.60281 .54837 L
s
.60281 .54837 m
.60281 .54837 L
s
.60281 .54837 m
.60281 .54837 L
s
.60281 .54837 m
.60281 .54837 L
s
.60281 .54837 m
.60281 .54837 L
s
.60281 .54837 m
.60281 .54837 L
s
.60281 .54837 m
.60281 .54837 L
s
.60281 .54837 m
.60281 .54837 L
s
.60281 .54837 m
.60281 .54837 L
s
1 .003 0 r
.64297 .81187 m
.64295 .81183 L
s
.64295 .81183 m
.64301 .81182 L
s
.64301 .81182 m
.64297 .81187 L
s
1 .006 0 r
.44979 .76386 m
.45014 .76373 L
s
.45011 .76378 m
.45007 .76381 L
s
.45007 .7637 m
.45011 .76378 L
s
.45014 .76373 m
.45011 .76378 L
s
.45003 .76373 m
.45007 .7637 L
s
.45007 .7637 m
.45014 .76373 L
s
1 0 0 r
.40974 .5003 m
.40974 .5003 L
s
.40974 .5003 m
.40974 .5003 L
s
.40974 .5003 m
.40974 .5003 L
s
.40974 .5003 m
.40974 .5003 L
s
.40974 .5003 m
.40974 .5003 L
s
.40974 .5003 m
.40974 .5003 L
s
.40974 .5003 m
.40974 .5003 L
s
.40974 .5003 m
.40974 .5003 L
s
.40974 .5003 m
.40974 .5003 L
s
1 .006 0 r
.45007 .76381 m
.45003 .76373 L
s
.45014 .76373 m
.45007 .76381 L
s
.45003 .76373 m
.45014 .76373 L
s
1 .001 0 r
.69293 .69177 m
.69297 .69174 L
s
.69296 .69174 m
.69297 .69175 L
s
.69295 .69174 m
.69296 .69174 L
s
.69296 .69174 m
.69297 .69174 L
s
.69297 .69175 m
.69296 .69175 L
s
.69297 .69174 m
.69297 .69175 L
s
.69296 .69175 m
.69295 .69174 L
s
.69295 .69174 m
.69297 .69174 L
s
.69297 .69174 m
.69296 .69175 L
s
1 .002 0 r
.49983 .6437 m
.49991 .64365 L
s
.4999 .64365 m
.49991 .64367 L
s
.49989 .64366 m
.4999 .64365 L
s
.4999 .64365 m
.49991 .64365 L
s
.49991 .64367 m
.4999 .64368 L
s
.49991 .64365 m
.49991 .64367 L
s
.4999 .64368 m
.49989 .64366 L
s
.49989 .64366 m
.49991 .64365 L
s
.49991 .64365 m
.4999 .64368 L
s
1 0 0 r
.74303 .57158 m
.74303 .57158 L
s
.74303 .57158 m
.74303 .57158 L
s
.74303 .57158 m
.74303 .57158 L
s
.74303 .57158 m
.74303 .57158 L
s
.74303 .57158 m
.74303 .57158 L
s
.74303 .57158 m
.74303 .57158 L
s
.74303 .57158 m
.74303 .57158 L
s
.74303 .57158 m
.74303 .57158 L
s
.74303 .57158 m
.74303 .57158 L
s
1 .004 0 r
.58996 .78715 m
.59015 .78705 L
s
.59011 .78704 m
.59013 .78709 L
s
.59008 .78706 m
.59011 .78704 L
s
.59011 .78704 m
.59015 .78705 L
s
.59013 .78709 m
.59011 .7871 L
s
.59015 .78705 m
.59013 .78709 L
s
1 0 0 r
.5499 .52349 m
.5499 .52349 L
s
.5499 .52349 m
.5499 .52349 L
s
.5499 .52349 m
.5499 .52349 L
s
.5499 .52349 m
.5499 .52349 L
s
.5499 .52349 m
.5499 .52349 L
s
.5499 .52349 m
.5499 .52349 L
s
.5499 .52349 m
.5499 .52349 L
s
.5499 .52349 m
.5499 .52349 L
s
.5499 .52349 m
.5499 .52349 L
s
1 .004 0 r
.59011 .7871 m
.59008 .78706 L
s
.59008 .78706 m
.59015 .78705 L
s
.59015 .78705 m
.59011 .7871 L
s
1 .007 0 r
.39681 .73908 m
.39723 .73895 L
s
.39718 .73901 m
.39715 .73903 L
s
.39715 .73891 m
.39718 .73901 L
s
.39723 .73895 m
.39718 .73901 L
s
.39711 .73894 m
.39715 .73891 L
s
.39715 .73891 m
.39723 .73895 L
s
.39723 .73895 m
.39715 .73903 L
s
.39711 .73894 m
.39723 .73895 L
s
.39715 .73903 m
.39711 .73894 L
s
1 .001 0 r
.64005 .66695 m
.64009 .66692 L
s
.64008 .66692 m
.64009 .66693 L
s
.64008 .66692 m
.64008 .66692 L
s
.64008 .66692 m
.64009 .66692 L
s
.64009 .66693 m
.64009 .66694 L
s
.64009 .66692 m
.64009 .66693 L
s
.64009 .66694 m
.64008 .66692 L
s
.64008 .66692 m
.64009 .66692 L
s
.64009 .66692 m
.64009 .66694 L
s
1 .002 0 r
.44687 .61886 m
.44695 .61882 L
s
.44695 .61883 m
.44694 .61884 L
s
.44694 .61881 m
.44695 .61883 L
s
.44695 .61882 m
.44695 .61883 L
s
.44693 .61882 m
.44694 .61881 L
s
.44694 .61881 m
.44695 .61882 L
s
.44694 .61884 m
.44693 .61882 L
s
.44695 .61882 m
.44694 .61884 L
s
.44693 .61882 m
.44695 .61882 L
s
1 0 0 r
.88335 .59481 m
.88335 .59481 L
s
.88335 .59481 m
.88336 .59481 L
s
.88335 .59481 m
.88335 .59481 L
s
.88335 .59481 m
.88335 .59481 L
s
.88336 .59481 m
.88335 .59481 L
s
.88335 .59481 m
.88336 .59481 L
s
.88335 .59481 m
.88335 .59481 L
s
.88335 .59481 m
.88335 .59481 L
s
.88335 .59481 m
.88335 .59481 L
s
.69017 .54671 m
.69017 .5467 L
s
.69017 .5467 m
.69017 .5467 L
s
.69017 .5467 m
.69017 .5467 L
s
.69017 .5467 m
.69017 .5467 L
s
.69017 .5467 m
.69017 .5467 L
s
.69017 .5467 m
.69017 .5467 L
s
.69017 .5467 m
.69017 .5467 L
s
.69017 .5467 m
.69017 .5467 L
s
.69017 .5467 m
.69017 .5467 L
s
1 .004 0 r
.53703 .76237 m
.53724 .76226 L
s
.5372 .76225 m
.53723 .7623 L
s
.53717 .76227 m
.5372 .76225 L
s
.5372 .76225 m
.53724 .76226 L
s
.53723 .7623 m
.5372 .76232 L
s
.53724 .76226 m
.53723 .7623 L
s
1 0 0 r
.49695 .49859 m
.49695 .49859 L
s
.49695 .49859 m
.49695 .49859 L
s
.49695 .49859 m
.49695 .49859 L
s
.49695 .49859 m
.49695 .49859 L
s
.49695 .49859 m
.49695 .49859 L
s
.49695 .49859 m
.49695 .49859 L
s
.49695 .49859 m
.49695 .49859 L
s
.49695 .49859 m
.49695 .49859 L
s
.49695 .49859 m
.49695 .49859 L
s
1 .004 0 r
.5372 .76232 m
.53717 .76227 L
s
.53717 .76227 m
.53724 .76226 L
s
.53724 .76226 m
.5372 .76232 L
s
1 .001 0 r
.78037 .69022 m
.7804 .6902 L
s
.78039 .6902 m
.7804 .69021 L
s
.78039 .6902 m
.78039 .6902 L
s
.78039 .6902 m
.7804 .6902 L
s
.7804 .69021 m
.78039 .69021 L
s
.7804 .6902 m
.7804 .69021 L
s
.78039 .69021 m
.78039 .6902 L
s
.78039 .6902 m
.7804 .6902 L
s
.7804 .6902 m
.78039 .69021 L
s
.58713 .64211 m
.58717 .64208 L
s
.58717 .64208 m
.58717 .64209 L
s
.58716 .64209 m
.58717 .64208 L
s
.58717 .64208 m
.58717 .64208 L
s
.58717 .64209 m
.58717 .6421 L
s
.58717 .64208 m
.58717 .64209 L
s
.58717 .6421 m
.58716 .64209 L
s
.58716 .64209 m
.58717 .64208 L
s
.58717 .64208 m
.58717 .6421 L
s
1 .002 0 r
.39386 .594 m
.39394 .59396 L
s
.39394 .59397 m
.39393 .59398 L
s
.39393 .59396 m
.39394 .59397 L
s
.39394 .59396 m
.39394 .59397 L
s
.39392 .59396 m
.39393 .59396 L
s
.39393 .59396 m
.39394 .59396 L
s
.39393 .59398 m
.39392 .59396 L
s
.39394 .59396 m
.39393 .59398 L
s
.39392 .59396 m
.39394 .59396 L
s
1 0 0 r
.83053 .56994 m
.83054 .56993 L
s
.83054 .56993 m
.83054 .56993 L
s
.83053 .56993 m
.83054 .56993 L
s
.83054 .56993 m
.83054 .56993 L
s
.83054 .56993 m
.83054 .56993 L
s
.83054 .56993 m
.83054 .56993 L
s
.83054 .56993 m
.83053 .56993 L
s
.83053 .56993 m
.83054 .56993 L
s
.83054 .56993 m
.83054 .56993 L
s
1 .003 0 r
.67734 .78568 m
.67746 .78561 L
s
.67744 .7856 m
.67746 .78563 L
s
.67742 .78561 m
.67744 .7856 L
s
.67744 .7856 m
.67746 .78561 L
s
.67746 .78563 m
.67744 .78564 L
s
.67746 .78561 m
.67746 .78563 L
s
.67744 .78564 m
.67742 .78561 L
s
.67742 .78561 m
.67746 .78561 L
s
.67746 .78561 m
.67744 .78564 L
s
1 0 0 r
.63726 .52181 m
.63726 .52181 L
s
.63726 .52181 m
.63726 .52181 L
s
.63726 .52181 m
.63726 .52181 L
s
.63726 .52181 m
.63726 .52181 L
s
.63726 .52181 m
.63726 .52181 L
s
.63726 .52181 m
.63726 .52181 L
s
.63726 .52181 m
.63726 .52181 L
s
.63726 .52181 m
.63726 .52181 L
s
.63726 .52181 m
.63726 .52181 L
s
1 .005 0 r
.48405 .73756 m
.4843 .73745 L
s
.48428 .73749 m
.48425 .73752 L
s
.48425 .73743 m
.48428 .73749 L
s
.4843 .73745 m
.48428 .73749 L
s
.48422 .73746 m
.48425 .73743 L
s
.48425 .73743 m
.4843 .73745 L
s
.48425 .73752 m
.48422 .73746 L
s
.4843 .73745 m
.48425 .73752 L
s
.48422 .73746 m
.4843 .73745 L
s
1 .001 0 r
.7275 .66538 m
.72752 .66536 L
s
.72751 .66536 m
.72752 .66537 L
s
.72751 .66536 m
.72751 .66536 L
s
.72751 .66536 m
.72752 .66536 L
s
.72752 .66537 m
.72751 .66537 L
s
.72752 .66536 m
.72752 .66537 L
s
.72751 .66537 m
.72751 .66536 L
s
.72751 .66536 m
.72752 .66536 L
s
.72752 .66536 m
.72751 .66537 L
s
.53417 .61725 m
.53421 .61722 L
s
.5342 .61722 m
.5342 .61723 L
s
.53419 .61723 m
.5342 .61722 L
s
.5342 .61722 m
.53421 .61722 L
s
.5342 .61723 m
.5342 .61724 L
s
.53421 .61722 m
.5342 .61723 L
s
.5342 .61724 m
.53419 .61723 L
s
.53419 .61723 m
.53421 .61722 L
s
.53421 .61722 m
.5342 .61724 L
s
.3408 .56911 m
.34087 .56909 L
s
.34087 .5691 m
.34086 .5691 L
s
.34086 .56908 m
.34087 .5691 L
s
.34087 .56909 m
.34087 .5691 L
s
.34085 .56909 m
.34086 .56908 L
s
.34086 .56908 m
.34087 .56909 L
s
.34087 .56909 m
.34086 .5691 L
s
.34085 .56909 m
.34087 .56909 L
s
.34086 .5691 m
.34085 .56909 L
s
1 0 0 r
.77767 .54504 m
.77767 .54504 L
s
.77767 .54504 m
.77767 .54504 L
s
.77767 .54504 m
.77767 .54504 L
s
.77767 .54504 m
.77767 .54504 L
s
.77767 .54504 m
.77767 .54504 L
s
.77767 .54504 m
.77767 .54504 L
s
.77767 .54504 m
.77767 .54504 L
s
.77767 .54504 m
.77767 .54504 L
s
.77767 .54504 m
.77767 .54504 L
s
1 .003 0 r
.62441 .76087 m
.62454 .7608 L
s
.62451 .76079 m
.62453 .76082 L
s
.62449 .7608 m
.62451 .76079 L
s
.62451 .76079 m
.62454 .7608 L
s
.62453 .76082 m
.62451 .76084 L
s
.62454 .7608 m
.62453 .76082 L
s
.62451 .76084 m
.62449 .7608 L
s
.62449 .7608 m
.62454 .7608 L
s
.62454 .7608 m
.62451 .76084 L
s
1 0 0 r
.5843 .49689 m
.5843 .49689 L
s
.5843 .49689 m
.5843 .49689 L
s
.5843 .49689 m
.5843 .49689 L
s
.5843 .49689 m
.5843 .49689 L
s
.5843 .49689 m
.5843 .49689 L
s
.5843 .49689 m
.5843 .49689 L
s
.5843 .49689 m
.5843 .49689 L
s
.5843 .49689 m
.5843 .49689 L
s
.5843 .49689 m
.5843 .49689 L
s
1 .005 0 r
.43102 .71274 m
.43132 .71262 L
s
.4313 .71267 m
.43126 .71269 L
s
.43127 .7126 m
.4313 .71267 L
s
.43132 .71262 m
.4313 .71267 L
s
.43123 .71262 m
.43127 .7126 L
s
.43127 .7126 m
.43132 .71262 L
s
.43126 .71269 m
.43123 .71262 L
s
.43132 .71262 m
.43126 .71269 L
s
.43123 .71262 m
.43132 .71262 L
s
1 .001 0 r
.67457 .64052 m
.67459 .6405 L
s
.67459 .6405 m
.67459 .64051 L
s
.67458 .64051 m
.67459 .6405 L
s
.67459 .6405 m
.67459 .6405 L
s
.67459 .64051 m
.67459 .64051 L
s
.67459 .6405 m
.67459 .64051 L
s
.67459 .64051 m
.67458 .64051 L
s
.67458 .64051 m
.67459 .6405 L
s
.67459 .6405 m
.67459 .64051 L
s
.48115 .59237 m
.48119 .59234 L
s
.48118 .59234 m
.48119 .59235 L
s
.48118 .59234 m
.48118 .59234 L
s
.48118 .59234 m
.48119 .59234 L
s
.48119 .59235 m
.48118 .59235 L
s
.48119 .59234 m
.48119 .59235 L
s
.48118 .59235 m
.48118 .59234 L
s
.48118 .59234 m
.48119 .59234 L
s
.48119 .59234 m
.48118 .59235 L
s
1 0 0 r
.91818 .56829 m
.91818 .56829 L
s
.91818 .56829 m
.91818 .56829 L
s
.91818 .56829 m
.91818 .56829 L
s
.91818 .56829 m
.91818 .56829 L
s
.91818 .56829 m
.91818 .56829 L
s
.91818 .56829 m
.91818 .56829 L
s
.91818 .56829 m
.91818 .56829 L
s
.91818 .56829 m
.91818 .56829 L
s
.91818 .56829 m
.91818 .56829 L
s
.72476 .52012 m
.72476 .52012 L
s
.72476 .52012 m
.72476 .52012 L
s
.72476 .52012 m
.72476 .52012 L
s
.72476 .52012 m
.72476 .52012 L
s
.72476 .52012 m
.72476 .52012 L
s
.72476 .52012 m
.72476 .52012 L
s
.72476 .52012 m
.72476 .52012 L
s
.72476 .52012 m
.72476 .52012 L
s
.72476 .52012 m
.72476 .52012 L
s
1 .003 0 r
.57143 .73605 m
.57157 .73597 L
s
.57154 .73596 m
.57157 .73599 L
s
.57152 .73597 m
.57154 .73596 L
s
.57154 .73596 m
.57157 .73597 L
s
.57157 .73599 m
.57155 .73601 L
s
.57157 .73597 m
.57157 .73599 L
s
.57155 .73601 m
.57152 .73597 L
s
.57152 .73597 m
.57157 .73597 L
s
.57157 .73597 m
.57155 .73601 L
s
1 .006 0 r
.37795 .68789 m
.3783 .68778 L
s
.37826 .68783 m
.37823 .68785 L
s
.37823 .68775 m
.37826 .68783 L
s
.3783 .68778 m
.37826 .68783 L
s
.3782 .68778 m
.37823 .68775 L
s
.37823 .68775 m
.3783 .68778 L
s
1 0 0 r
.81508 .66381 m
.81509 .6638 L
s
.81509 .6638 m
.81509 .6638 L
s
.81509 .6638 m
.81509 .6638 L
s
.81509 .6638 m
.81509 .6638 L
s
.81509 .6638 m
.81509 .6638 L
s
.81509 .6638 m
.81509 .6638 L
s
.81509 .6638 m
.81509 .6638 L
s
.81509 .6638 m
.81509 .6638 L
s
.81509 .6638 m
.81509 .6638 L
s
1 .006 0 r
.3783 .68778 m
.37823 .68785 L
s
.3782 .68778 m
.3783 .68778 L
s
.37823 .68785 m
.3782 .68778 L
s
1 .001 0 r
.6216 .61564 m
.62162 .61562 L
s
.62162 .61562 m
.62162 .61563 L
s
.62161 .61562 m
.62162 .61562 L
s
.62162 .61562 m
.62162 .61562 L
s
.62162 .61563 m
.62162 .61563 L
s
.62162 .61562 m
.62162 .61563 L
s
.62162 .61563 m
.62161 .61562 L
s
.62161 .61562 m
.62162 .61562 L
s
.62162 .61562 m
.62162 .61563 L
s
1 .008 0 r
.46823 .83163 m
.4687 .83147 L
s
1 .001 0 r
.42809 .56746 m
.42812 .56744 L
s
.42812 .56744 m
.42812 .56745 L
s
.42811 .56744 m
.42812 .56744 L
s
.42812 .56744 m
.42812 .56744 L
s
.42812 .56745 m
.42812 .56745 L
s
.42812 .56744 m
.42812 .56745 L
s
1 .008 0 r
.46865 .83153 m
.46861 .83157 L
s
.46861 .83143 m
.46865 .83153 L
s
.4687 .83147 m
.46865 .83153 L
s
1 .001 0 r
.42812 .56745 m
.42811 .56744 L
s
.42811 .56744 m
.42812 .56744 L
s
.42812 .56744 m
.42812 .56745 L
s
1 .008 0 r
.46856 .83146 m
.46861 .83143 L
s
.46861 .83143 m
.4687 .83147 L
s
1 0 0 r
.86531 .54337 m
.86531 .54337 L
s
.86531 .54337 m
.86531 .54337 L
s
.86531 .54337 m
.86531 .54337 L
s
.86531 .54337 m
.86531 .54337 L
s
.86531 .54337 m
.86531 .54337 L
s
.86531 .54337 m
.86531 .54337 L
s
.86531 .54337 m
.86531 .54337 L
s
.86531 .54337 m
.86531 .54337 L
s
.86531 .54337 m
.86531 .54337 L
s
1 .008 0 r
.46861 .83157 m
.46856 .83146 L
s
.4687 .83147 m
.46861 .83157 L
s
.46856 .83146 m
.4687 .83147 L
s
1 .002 0 r
.71193 .75938 m
.71201 .75932 L
s
.71199 .75932 m
.71201 .75934 L
s
.71198 .75933 m
.71199 .75932 L
s
.71199 .75932 m
.71201 .75932 L
s
.71201 .75934 m
.71199 .75935 L
s
.71201 .75932 m
.71201 .75934 L
s
.71199 .75935 m
.71198 .75933 L
s
.71198 .75933 m
.71201 .75932 L
s
.71201 .75932 m
.71199 .75935 L
s
1 0 0 r
.6718 .49518 m
.6718 .49518 L
s
.6718 .49518 m
.6718 .49518 L
s
.6718 .49518 m
.6718 .49518 L
s
.6718 .49518 m
.6718 .49518 L
s
.6718 .49518 m
.6718 .49518 L
s
.6718 .49518 m
.6718 .49518 L
s
.6718 .49518 m
.6718 .49518 L
s
.6718 .49518 m
.6718 .49518 L
s
.6718 .49518 m
.6718 .49518 L
s
1 .003 0 r
.5184 .7112 m
.51857 .71112 L
s
.51853 .7111 m
.51856 .71115 L
s
.51851 .71112 m
.51853 .7111 L
s
.51853 .7111 m
.51857 .71112 L
s
.51856 .71115 m
.51853 .71116 L
s
.51857 .71112 m
.51856 .71115 L
s
.51853 .71116 m
.51851 .71112 L
s
.51851 .71112 m
.51857 .71112 L
s
.51857 .71112 m
.51853 .71116 L
s
1 0 0 r
.76215 .63893 m
.76217 .63892 L
s
.76216 .63892 m
.76217 .63892 L
s
.76216 .63892 m
.76216 .63892 L
s
.76216 .63892 m
.76217 .63892 L
s
.76217 .63892 m
.76216 .63892 L
s
.76217 .63892 m
.76217 .63892 L
s
.76216 .63892 m
.76216 .63892 L
s
.76216 .63892 m
.76217 .63892 L
s
.76217 .63892 m
.76216 .63892 L
s
.56858 .59073 m
.5686 .59072 L
s
.5686 .59072 m
.5686 .59072 L
s
.56859 .59072 m
.5686 .59072 L
s
.5686 .59072 m
.5686 .59072 L
s
.5686 .59072 m
.5686 .59073 L
s
.5686 .59072 m
.5686 .59072 L
s
.5686 .59073 m
.56859 .59072 L
s
.56859 .59072 m
.5686 .59072 L
s
.5686 .59072 m
.5686 .59073 L
s
1 .009 0 r
.41514 .80682 m
.4157 .80665 L
s
1 0 0 r
.37498 .54253 m
.375 .54252 L
s
.375 .54253 m
.375 .54253 L
s
.375 .54252 m
.375 .54253 L
s
.375 .54252 m
.375 .54253 L
s
.375 .54252 m
.375 .54252 L
s
.375 .54252 m
.375 .54252 L
s
1 .009 0 r
.41564 .80673 m
.41559 .80677 L
s
.41559 .80661 m
.41564 .80673 L
s
.4157 .80665 m
.41564 .80673 L
s
1 0 0 r
.375 .54253 m
.375 .54252 L
s
.375 .54252 m
.375 .54253 L
s
.375 .54252 m
.375 .54252 L
s
1 .009 0 r
.41554 .80665 m
.41559 .80661 L
s
.41559 .80661 m
.4157 .80665 L
s
1 0 0 r
.8124 .51843 m
.8124 .51843 L
s
.8124 .51843 m
.8124 .51843 L
s
.8124 .51843 m
.8124 .51843 L
s
.8124 .51843 m
.8124 .51843 L
s
.8124 .51843 m
.8124 .51843 L
s
.8124 .51843 m
.8124 .51843 L
s
.8124 .51843 m
.8124 .51843 L
s
.8124 .51843 m
.8124 .51843 L
s
.8124 .51843 m
.8124 .51843 L
s
1 .009 0 r
.4157 .80665 m
.41559 .80677 L
s
.41554 .80665 m
.4157 .80665 L
s
.41559 .80677 m
.41554 .80665 L
s
1 .002 0 r
.65894 .73453 m
.65903 .73448 L
s
.65901 .73447 m
.65903 .73449 L
s
.659 .73448 m
.65901 .73447 L
s
.65901 .73447 m
.65903 .73448 L
s
.65903 .73449 m
.65901 .7345 L
s
.65903 .73448 m
.65903 .73449 L
s
.65901 .7345 m
.659 .73448 L
s
.659 .73448 m
.65903 .73448 L
s
.65903 .73448 m
.65901 .7345 L
s
1 .004 0 r
.46532 .68634 m
.46552 .68624 L
s
.4655 .68628 m
.46548 .68629 L
s
.46548 .68623 m
.4655 .68628 L
s
.46552 .68624 m
.4655 .68628 L
s
.46545 .68625 m
.46548 .68623 L
s
.46548 .68623 m
.46552 .68624 L
s
.46548 .68629 m
.46545 .68625 L
s
.46552 .68624 m
.46548 .68629 L
s
.46545 .68625 m
.46552 .68624 L
s
1 0 0 r
.70918 .61403 m
.70919 .61401 L
s
.70919 .61401 m
.70919 .61402 L
s
.70918 .61402 m
.70919 .61401 L
s
.70919 .61401 m
.70919 .61401 L
s
.70919 .61402 m
.70919 .61402 L
s
.70919 .61401 m
.70919 .61402 L
s
.70919 .61402 m
.70918 .61402 L
s
.70918 .61402 m
.70919 .61401 L
s
.70919 .61401 m
.70919 .61402 L
s
1 .006 0 r
.55569 .83019 m
.55599 .83005 L
s
1 0 0 r
.51552 .56581 m
.51553 .5658 L
s
.51553 .5658 m
.51553 .5658 L
s
.51553 .5658 m
.51553 .5658 L
s
.51553 .5658 m
.51553 .5658 L
s
.51553 .5658 m
.51553 .5658 L
s
.51553 .5658 m
.51553 .5658 L
s
1 .006 0 r
.55597 .8301 m
.55593 .83013 L
s
.55593 .83003 m
.55597 .8301 L
s
.55599 .83005 m
.55597 .8301 L
s
.55589 .83006 m
.55593 .83003 L
s
.55593 .83003 m
.55599 .83005 L
s
1 0 0 r
.51553 .5658 m
.51553 .5658 L
s
.51553 .5658 m
.51553 .5658 L
s
.51553 .5658 m
.51553 .5658 L
s
1 .006 0 r
.55593 .83013 m
.55589 .83006 L
s
.55599 .83005 m
.55593 .83013 L
s
.55589 .83006 m
.55599 .83005 L
s
1 0 0 r
.9531 .5417 m
.9531 .5417 L
s
.9531 .5417 m
.9531 .5417 L
s
.9531 .5417 m
.9531 .5417 L
s
.9531 .5417 m
.9531 .5417 L
s
.9531 .5417 m
.9531 .5417 L
s
.9531 .5417 m
.9531 .5417 L
s
.9531 .5417 m
.9531 .5417 L
s
.9531 .5417 m
.9531 .5417 L
s
.9531 .5417 m
.9531 .5417 L
s
.32183 .51758 m
.32183 .51758 L
s
.32183 .51758 m
.32183 .51758 L
s
.32183 .51758 m
.32183 .51758 L
s
.32183 .51758 m
.32183 .51758 L
s
.32183 .51758 m
.32183 .51758 L
s
.32183 .51758 m
.32183 .51758 L
s
.32183 .51758 m
.32183 .51758 L
s
.32183 .51758 m
.32183 .51758 L
s
.32183 .51758 m
.32183 .51758 L
s
.75943 .49347 m
.75943 .49347 L
s
.75943 .49347 m
.75943 .49347 L
s
.75943 .49347 m
.75943 .49347 L
s
.75943 .49347 m
.75943 .49347 L
s
.75943 .49347 m
.75943 .49347 L
s
.75943 .49347 m
.75943 .49347 L
s
.75943 .49347 m
.75943 .49347 L
s
.75943 .49347 m
.75943 .49347 L
s
.75943 .49347 m
.75943 .49347 L
s
1 .002 0 r
.60591 .70967 m
.60601 .7096 L
s
.60599 .7096 m
.606 .70962 L
s
.60597 .70961 m
.60599 .7096 L
s
.60599 .7096 m
.60601 .7096 L
s
.606 .70962 m
.60599 .70964 L
s
.60601 .7096 m
.606 .70962 L
s
.60599 .70964 m
.60597 .70961 L
s
.60597 .70961 m
.60601 .7096 L
s
.60601 .7096 m
.60599 .70964 L
s
1 .004 0 r
.4122 .66145 m
.41243 .66135 L
s
.41241 .66139 m
.41238 .66141 L
s
.41238 .66134 m
.41241 .66139 L
s
.41243 .66135 m
.41241 .66139 L
s
.41236 .66135 m
.41238 .66134 L
s
.41238 .66134 m
.41243 .66135 L
s
1 0 0 r
.84988 .63733 m
.84988 .63732 L
s
.84988 .63732 m
.84988 .63733 L
s
.84988 .63733 m
.84988 .63732 L
s
.84988 .63732 m
.84988 .63732 L
s
.84988 .63733 m
.84988 .63733 L
s
.84988 .63732 m
.84988 .63733 L
s
.84988 .63733 m
.84988 .63733 L
s
.84988 .63733 m
.84988 .63732 L
s
.84988 .63732 m
.84988 .63733 L
s
1 .004 0 r
.41238 .66141 m
.41236 .66135 L
s
.41243 .66135 m
.41238 .66141 L
s
.41236 .66135 m
.41243 .66135 L
s
1 0 0 r
.65616 .5891 m
.65616 .58909 L
s
.65616 .58909 m
.65617 .58909 L
s
.65616 .58909 m
.65616 .58909 L
s
.65616 .58909 m
.65616 .58909 L
s
.65617 .58909 m
.65616 .58909 L
s
.65616 .58909 m
.65617 .58909 L
s
.65616 .58909 m
.65616 .58909 L
s
.65616 .58909 m
.65616 .58909 L
s
.65616 .58909 m
.65616 .58909 L
s
1 .007 0 r
.50259 .80536 m
.50296 .80521 L
s
1 0 0 r
.46241 .54086 m
.46241 .54085 L
s
.46241 .54085 m
.46241 .54085 L
s
.46241 .54085 m
.46241 .54085 L
s
.46241 .54085 m
.46241 .54085 L
s
.46241 .54085 m
.46241 .54086 L
s
.46241 .54085 m
.46241 .54085 L
s
.46241 .54086 m
.46241 .54085 L
s
.46241 .54085 m
.46241 .54085 L
s
.46241 .54085 m
.46241 .54086 L
s
1 .007 0 r
.50293 .80526 m
.50289 .8053 L
s
.50289 .80518 m
.50293 .80526 L
s
.50296 .80521 m
.50293 .80526 L
s
.50284 .80521 m
.50289 .80518 L
s
.50289 .80518 m
.50296 .80521 L
s
.50289 .8053 m
.50284 .80521 L
s
.50296 .80521 m
.50289 .8053 L
s
.50284 .80521 m
.50296 .80521 L
s
1 0 0 r
.90018 .51674 m
.90018 .51674 L
s
.90018 .51674 m
.90018 .51674 L
s
.90018 .51674 m
.90018 .51674 L
s
.90018 .51674 m
.90018 .51674 L
s
.90018 .51674 m
.90018 .51674 L
s
.90018 .51674 m
.90018 .51674 L
s
.90018 .51674 m
.90018 .51674 L
s
.90018 .51674 m
.90018 .51674 L
s
.90018 .51674 m
.90018 .51674 L
s
1 .001 0 r
.7466 .73302 m
.74666 .73298 L
s
.74665 .73297 m
.74666 .73299 L
s
.74664 .73298 m
.74665 .73297 L
s
.74665 .73297 m
.74666 .73298 L
s
.74666 .73299 m
.74665 .73299 L
s
.74666 .73298 m
.74666 .73299 L
s
.74665 .73299 m
.74664 .73298 L
s
.74664 .73298 m
.74666 .73298 L
s
.74666 .73298 m
.74665 .73299 L
s
1 .002 0 r
.55283 .68478 m
.55294 .68471 L
s
.55292 .68471 m
.55293 .68473 L
s
.5529 .68472 m
.55292 .68471 L
s
.55292 .68471 m
.55294 .68471 L
s
.55293 .68473 m
.55292 .68475 L
s
.55294 .68471 m
.55293 .68473 L
s
.55292 .68475 m
.5529 .68472 L
s
.5529 .68472 m
.55294 .68471 L
s
.55294 .68471 m
.55292 .68475 L
s
1 .004 0 r
.35902 .63653 m
.35929 .63645 L
s
.35926 .63649 m
.35923 .6365 L
s
.35924 .63643 m
.35926 .63649 L
s
.35929 .63645 m
.35926 .63649 L
s
.35921 .63644 m
.35924 .63643 L
s
.35924 .63643 m
.35929 .63645 L
s
1 0 0 r
.7969 .61241 m
.7969 .6124 L
s
1 .004 0 r
.35929 .63645 m
.35923 .6365 L
s
.35921 .63644 m
.35929 .63645 L
s
1 0 0 r
.7969 .6124 m
.7969 .6124 L
s
.7969 .6124 m
.7969 .6124 L
s
.7969 .6124 m
.7969 .6124 L
s
.7969 .6124 m
.7969 .6124 L
s
.7969 .6124 m
.7969 .6124 L
s
1 .004 0 r
.35923 .6365 m
.35921 .63644 L
s
1 0 0 r
.7969 .6124 m
.7969 .6124 L
s
.7969 .6124 m
.7969 .6124 L
s
.7969 .6124 m
.7969 .6124 L
s
1 .004 0 r
.64328 .82874 m
.64348 .82864 L
s
.64344 .82862 m
.64347 .82867 L
s
.64341 .82865 m
.64344 .82862 L
s
.64344 .82862 m
.64348 .82864 L
s
.64347 .82867 m
.64344 .82869 L
s
.64348 .82864 m
.64347 .82867 L
s
1 0 0 r
.60309 .56415 m
.60309 .56415 L
s
.60309 .56415 m
.60309 .56415 L
s
.60309 .56415 m
.60309 .56415 L
s
.60309 .56415 m
.60309 .56415 L
s
.60309 .56415 m
.60309 .56415 L
s
.60309 .56415 m
.60309 .56415 L
s
.60309 .56415 m
.60309 .56415 L
s
.60309 .56415 m
.60309 .56415 L
s
.60309 .56415 m
.60309 .56415 L
s
1 .004 0 r
.64344 .82869 m
.64341 .82865 L
s
.64341 .82865 m
.64348 .82864 L
s
.64348 .82864 m
.64344 .82869 L
s
1 .008 0 r
.44946 .7805 m
.44989 .78035 L
s
1 0 0 r
.40925 .51589 m
.40925 .51589 L
s
.40925 .51589 m
.40925 .51589 L
s
.40925 .51589 m
.40925 .51589 L
s
.40925 .51589 m
.40925 .51589 L
s
.40925 .51589 m
.40925 .51589 L
s
.40925 .51589 m
.40925 .51589 L
s
.40925 .51589 m
.40925 .51589 L
s
.40925 .51589 m
.40925 .51589 L
s
.40925 .51589 m
.40925 .51589 L
s
1 .008 0 r
.44985 .78041 m
.4498 .78044 L
s
.44981 .78031 m
.44985 .78041 L
s
.44989 .78035 m
.44985 .78041 L
s
.44976 .78035 m
.44981 .78031 L
s
.44981 .78031 m
.44989 .78035 L
s
.4498 .78044 m
.44976 .78035 L
s
.44989 .78035 m
.4498 .78044 L
s
.44976 .78035 m
.44989 .78035 L
s
1 0 0 r
.84721 .49175 m
.84721 .49175 L
s
.84721 .49175 m
.84721 .49175 L
s
.84721 .49175 m
.84721 .49175 L
s
.84721 .49175 m
.84721 .49175 L
s
.84721 .49175 m
.84721 .49175 L
s
.84721 .49175 m
.84721 .49175 L
s
.84721 .49175 m
.84721 .49175 L
s
.84721 .49175 m
.84721 .49175 L
s
.84721 .49175 m
.84721 .49175 L
s
1 .001 0 r
.69357 .70813 m
.69362 .70809 L
s
.69361 .70808 m
.69362 .7081 L
s
.6936 .70809 m
.69361 .70808 L
s
.69361 .70808 m
.69362 .70809 L
s
.69362 .7081 m
.69361 .70811 L
s
.69362 .70809 m
.69362 .7081 L
s
.69361 .70811 m
.6936 .70809 L
s
.6936 .70809 m
.69362 .70809 L
s
.69362 .70809 m
.69361 .70811 L
s
1 .002 0 r
.4997 .65987 m
.49982 .6598 L
s
.4998 .65979 m
.49982 .65982 L
s
.49978 .6598 m
.4998 .65979 L
s
.4998 .65979 m
.49982 .6598 L
s
.49982 .65982 m
.4998 .65983 L
s
.49982 .6598 m
.49982 .65982 L
s
.4998 .65983 m
.49978 .6598 L
s
.49978 .6598 m
.49982 .6598 L
s
.49982 .6598 m
.4998 .65983 L
s
1 0 0 r
.74387 .58746 m
.74388 .58746 L
s
.74387 .58746 m
.74388 .58746 L
s
.74387 .58746 m
.74387 .58746 L
s
.74387 .58746 m
.74388 .58746 L
s
.74388 .58746 m
.74387 .58746 L
s
.74388 .58746 m
.74388 .58746 L
s
.74387 .58746 m
.74387 .58746 L
s
.74387 .58746 m
.74388 .58746 L
s
.74388 .58746 m
.74387 .58746 L
s
1 .005 0 r
.59019 .80389 m
.59042 .80378 L
s
.59037 .80376 m
.5904 .80382 L
s
.59034 .80378 m
.59037 .80376 L
s
.59037 .80376 m
.59042 .80378 L
s
.5904 .80382 m
.59037 .80384 L
s
.59042 .80378 m
.5904 .80382 L
s
1 0 0 r
.54997 .53918 m
.54997 .53918 L
s
.54997 .53918 m
.54997 .53918 L
s
.54997 .53918 m
.54997 .53918 L
s
.54997 .53918 m
.54997 .53918 L
s
.54997 .53918 m
.54997 .53918 L
s
.54997 .53918 m
.54997 .53918 L
s
.54997 .53918 m
.54997 .53918 L
s
.54997 .53918 m
.54997 .53918 L
s
.54997 .53918 m
.54997 .53918 L
s
1 .005 0 r
.59037 .80384 m
.59034 .80378 L
s
.59034 .80378 m
.59042 .80378 L
s
.59042 .80378 m
.59037 .80384 L
s
1 .009 0 r
.39627 .75563 m
.39679 .75547 L
s
1 0 0 r
.35604 .49089 m
.35604 .49089 L
s
.35604 .49089 m
.35604 .49089 L
s
.35604 .49089 m
.35604 .49089 L
s
.35604 .49089 m
.35604 .49089 L
s
.35604 .49089 m
.35604 .49089 L
s
.35604 .49089 m
.35604 .49089 L
s
.35604 .49089 m
.35604 .49089 L
s
.35604 .49089 m
.35604 .49089 L
s
.35604 .49089 m
.35604 .49089 L
s
1 .009 0 r
.39673 .75554 m
.39669 .75558 L
s
.39669 .75543 m
.39673 .75554 L
s
.39679 .75547 m
.39673 .75554 L
s
.39664 .75546 m
.39669 .75543 L
s
.39669 .75543 m
.39679 .75547 L
s
.39679 .75547 m
.39669 .75558 L
s
.39664 .75546 m
.39679 .75547 L
s
.39669 .75558 m
.39664 .75546 L
s
1 .001 0 r
.64048 .68322 m
.64054 .68317 L
s
.64053 .68317 m
.64054 .68319 L
s
.64052 .68318 m
.64053 .68317 L
s
.64053 .68317 m
.64054 .68317 L
s
.64054 .68319 m
.64053 .6832 L
s
.64054 .68317 m
.64054 .68319 L
s
.64053 .6832 m
.64052 .68318 L
s
.64052 .68318 m
.64054 .68317 L
s
.64054 .68317 m
.64053 .6832 L
s
1 .003 0 r
.44653 .63493 m
.44666 .63487 L
s
.44665 .63489 m
.44663 .6349 L
s
.44664 .63486 m
.44665 .63489 L
s
.44666 .63487 m
.44665 .63489 L
s
.44662 .63487 m
.44664 .63486 L
s
.44664 .63486 m
.44666 .63487 L
s
.44663 .6349 m
.44662 .63487 L
s
.44666 .63487 m
.44663 .6349 L
s
.44662 .63487 m
.44666 .63487 L
s
1 0 0 r
.88476 .61079 m
.88476 .61079 L
s
.88476 .61079 m
.88476 .61079 L
s
.88476 .61079 m
.88476 .61079 L
s
.88476 .61079 m
.88476 .61079 L
s
.88476 .61079 m
.88476 .61079 L
s
.88476 .61079 m
.88476 .61079 L
s
.88476 .61079 m
.88476 .61079 L
s
.88476 .61079 m
.88476 .61079 L
s
.88476 .61079 m
.88476 .61079 L
s
.6908 .56249 m
.6908 .56249 L
s
.6908 .56249 m
.6908 .56249 L
s
.6908 .56249 m
.6908 .56249 L
s
.6908 .56249 m
.6908 .56249 L
s
.6908 .56249 m
.6908 .56249 L
s
.6908 .56249 m
.6908 .56249 L
s
.6908 .56249 m
.6908 .56249 L
s
.6908 .56249 m
.6908 .56249 L
s
.6908 .56249 m
.6908 .56249 L
s
1 .005 0 r
.53705 .77902 m
.53731 .77889 L
s
1 0 0 r
.49681 .51419 m
.49681 .51419 L
s
.49681 .51419 m
.49681 .51419 L
s
.49681 .51419 m
.49681 .51419 L
s
.49681 .51419 m
.49681 .51419 L
s
.49681 .51419 m
.49681 .51419 L
s
.49681 .51419 m
.49681 .51419 L
s
.49681 .51419 m
.49681 .51419 L
s
.49681 .51419 m
.49681 .51419 L
s
.49681 .51419 m
.49681 .51419 L
s
1 .005 0 r
.53726 .77887 m
.5373 .77894 L
s
.53722 .7789 m
.53726 .77887 L
s
.53726 .77887 m
.53731 .77889 L
s
.5373 .77894 m
.53726 .77896 L
s
.53731 .77889 m
.5373 .77894 L
s
.53726 .77896 m
.53722 .7789 L
s
.53722 .7789 m
.53731 .77889 L
s
.53731 .77889 m
.53726 .77896 L
s
1 0 0 r
.93513 .49004 m
.93513 .49004 L
s
.93513 .49004 m
.93513 .49004 L
s
.93513 .49004 m
.93513 .49004 L
s
.93513 .49004 m
.93513 .49004 L
s
.93513 .49004 m
.93513 .49004 L
s
.93513 .49004 m
.93513 .49004 L
s
.93513 .49004 m
.93513 .49004 L
s
.93513 .49004 m
.93513 .49004 L
s
.93513 .49004 m
.93513 .49004 L
s
1 .001 0 r
.78137 .70659 m
.7814 .70656 L
s
.78139 .70656 m
.7814 .70657 L
s
.78138 .70656 m
.78139 .70656 L
s
.78139 .70656 m
.7814 .70656 L
s
.7814 .70657 m
.78139 .70657 L
s
.7814 .70656 m
.7814 .70657 L
s
.78139 .70657 m
.78138 .70656 L
s
.78138 .70656 m
.7814 .70656 L
s
.7814 .70656 m
.78139 .70657 L
s
.58735 .65829 m
.58741 .65824 L
s
.5874 .65824 m
.58741 .65826 L
s
.58739 .65825 m
.5874 .65824 L
s
.5874 .65824 m
.58741 .65824 L
s
.58741 .65826 m
.5874 .65826 L
s
.58741 .65824 m
.58741 .65826 L
s
.5874 .65826 m
.58739 .65825 L
s
.58739 .65825 m
.58741 .65824 L
s
.58741 .65824 m
.5874 .65826 L
s
1 .003 0 r
.39331 .60998 m
.39345 .60992 L
s
.39344 .60994 m
.39342 .60995 L
s
.39342 .60991 m
.39344 .60994 L
s
.39345 .60992 m
.39344 .60994 L
s
.39341 .60992 m
.39342 .60991 L
s
.39342 .60991 m
.39345 .60992 L
s
.39342 .60995 m
.39341 .60992 L
s
.39345 .60992 m
.39342 .60995 L
s
.39341 .60992 m
.39345 .60992 L
s
1 0 0 r
.83173 .58582 m
.83173 .58582 L
s
.83173 .58582 m
.83173 .58582 L
s
.83173 .58582 m
.83173 .58582 L
s
.83173 .58582 m
.83173 .58582 L
s
.83173 .58582 m
.83173 .58582 L
s
.83173 .58582 m
.83173 .58582 L
s
.83173 .58582 m
.83173 .58582 L
s
.83173 .58582 m
.83173 .58582 L
s
.83173 .58582 m
.83173 .58582 L
s
1 .003 0 r
.67792 .80243 m
.67807 .80234 L
s
.67804 .80233 m
.67806 .80237 L
s
.67801 .80235 m
.67804 .80233 L
s
.67804 .80233 m
.67807 .80234 L
s
.67806 .80237 m
.67804 .80239 L
s
.67807 .80234 m
.67806 .80237 L
s
.67804 .80239 m
.67801 .80235 L
s
.67801 .80235 m
.67807 .80234 L
s
1 0 0 r
.63768 .5375 m
.63768 .5375 L
s
1 .003 0 r
.67807 .80234 m
.67804 .80239 L
s
1 0 0 r
.63768 .5375 m
.63768 .5375 L
s
.63768 .5375 m
.63768 .5375 L
s
.63768 .5375 m
.63768 .5375 L
s
.63768 .5375 m
.63768 .5375 L
s
.63768 .5375 m
.63768 .5375 L
s
.63768 .5375 m
.63768 .5375 L
s
.63768 .5375 m
.63768 .5375 L
s
.63768 .5375 m
.63768 .5375 L
s
1 .006 0 r
.48385 .75413 m
.48418 .75399 L
s
1 0 0 r
.4436 .48918 m
.4436 .48918 L
s
.4436 .48918 m
.4436 .48918 L
s
.4436 .48918 m
.4436 .48918 L
s
.4436 .48918 m
.4436 .48918 L
s
.4436 .48918 m
.4436 .48918 L
s
.4436 .48918 m
.4436 .48918 L
s
.4436 .48918 m
.4436 .48918 L
s
.4436 .48918 m
.4436 .48918 L
s
.4436 .48918 m
.4436 .48918 L
s
1 .006 0 r
.48415 .75404 m
.48411 .75406 L
s
.48411 .75396 m
.48415 .75404 L
s
.48418 .75399 m
.48415 .75404 L
s
.48407 .75399 m
.48411 .75396 L
s
.48411 .75396 m
.48418 .75399 L
s
.48411 .75406 m
.48407 .75399 L
s
.48418 .75399 m
.48411 .75406 L
s
.48407 .75399 m
.48418 .75399 L
s
1 .001 0 r
.72828 .68166 m
.72831 .68163 L
s
.7283 .68163 m
.72831 .68163 L
s
.7283 .68163 m
.7283 .68163 L
s
.7283 .68163 m
.72831 .68163 L
s
.72831 .68163 m
.7283 .68164 L
s
.72831 .68163 m
.72831 .68163 L
s
.7283 .68164 m
.7283 .68163 L
s
.7283 .68163 m
.72831 .68163 L
s
.72831 .68163 m
.7283 .68164 L
s
.53417 .63333 m
.53424 .63329 L
s
.53422 .63328 m
.53424 .6333 L
s
.53421 .63329 m
.53422 .63328 L
s
.53422 .63328 m
.53424 .63329 L
s
.53424 .6333 m
.53422 .63331 L
s
.53424 .63329 m
.53424 .6333 L
s
.53422 .63331 m
.53421 .63329 L
s
.53421 .63329 m
.53424 .63329 L
s
.53424 .63329 m
.53422 .63331 L
s
1 .003 0 r
.34004 .585 m
.34019 .58495 L
s
.34017 .58497 m
.34016 .58498 L
s
.34016 .58494 m
.34017 .58497 L
s
.34019 .58495 m
.34017 .58497 L
s
.34014 .58495 m
.34016 .58494 L
s
.34016 .58494 m
.34019 .58495 L
s
.34019 .58495 m
.34016 .58498 L
s
.34014 .58495 m
.34019 .58495 L
s
.34016 .58498 m
.34014 .58495 L
s
1 0 0 r
.77865 .56083 m
.77865 .56083 L
s
.77865 .56083 m
.77865 .56083 L
s
.77865 .56083 m
.77865 .56083 L
s
.77865 .56083 m
.77865 .56083 L
s
.77865 .56083 m
.77865 .56083 L
s
.77865 .56083 m
.77865 .56083 L
s
.77865 .56083 m
.77865 .56083 L
s
.77865 .56083 m
.77865 .56083 L
s
.77865 .56083 m
.77865 .56083 L
s
1 .003 0 r
.62478 .77753 m
.62494 .77744 L
s
.62491 .77743 m
.62493 .77747 L
s
.62488 .77745 m
.62491 .77743 L
s
.62491 .77743 m
.62494 .77744 L
s
.62493 .77747 m
.62491 .77749 L
s
.62494 .77744 m
.62493 .77747 L
s
1 0 0 r
.58451 .51249 m
.58451 .51249 L
s
.58451 .51249 m
.58451 .51249 L
s
.58451 .51249 m
.58451 .51249 L
s
.58451 .51249 m
.58451 .51249 L
s
.58451 .51249 m
.58451 .51249 L
s
.58451 .51249 m
.58451 .51249 L
s
.58451 .51249 m
.58451 .51249 L
s
.58451 .51249 m
.58451 .51249 L
s
.58451 .51249 m
.58451 .51249 L
s
1 .003 0 r
.62491 .77749 m
.62488 .77745 L
s
.62488 .77745 m
.62494 .77744 L
s
.62494 .77744 m
.62491 .77749 L
s
1 .007 0 r
.43062 .72921 m
.43101 .72906 L
s
.43097 .72912 m
.43093 .72915 L
s
.43093 .72903 m
.43097 .72912 L
s
.43101 .72906 m
.43097 .72912 L
s
.43089 .72906 m
.43093 .72903 L
s
.43093 .72903 m
.43101 .72906 L
s
.43093 .72915 m
.43089 .72906 L
s
.43101 .72906 m
.43093 .72915 L
s
.43089 .72906 m
.43101 .72906 L
s
1 .001 0 r
.67514 .6567 m
.67517 .65667 L
s
.67517 .65667 m
.67518 .65668 L
s
.67516 .65668 m
.67517 .65667 L
s
.67517 .65667 m
.67517 .65667 L
s
.67518 .65668 m
.67517 .65669 L
s
.67517 .65667 m
.67518 .65668 L
s
.67517 .65669 m
.67516 .65668 L
s
.67516 .65668 m
.67517 .65667 L
s
.67517 .65667 m
.67517 .65669 L
s
.48095 .60836 m
.48101 .60831 L
s
.481 .60831 m
.48101 .60833 L
s
.48099 .60832 m
.481 .60831 L
s
.481 .60831 m
.48101 .60831 L
s
.48101 .60833 m
.481 .60833 L
s
.48101 .60831 m
.48101 .60833 L
s
.481 .60833 m
.48099 .60832 L
s
.48099 .60832 m
.48101 .60831 L
s
.48101 .60831 m
.481 .60833 L
s
1 0 0 r
.91973 .58418 m
.91973 .58418 L
s
.91973 .58418 m
.91973 .58418 L
s
.91973 .58418 m
.91973 .58418 L
s
.91973 .58418 m
.91973 .58418 L
s
.91973 .58418 m
.91973 .58418 L
s
.91973 .58418 m
.91973 .58418 L
s
.91973 .58418 m
.91973 .58418 L
s
.91973 .58418 m
.91973 .58418 L
s
.91973 .58418 m
.91973 .58418 L
s
.72553 .53582 m
.72553 .53582 L
s
.72553 .53582 m
.72553 .53582 L
s
.72553 .53582 m
.72553 .53582 L
s
.72553 .53582 m
.72553 .53582 L
s
.72553 .53582 m
.72553 .53582 L
s
.72553 .53582 m
.72553 .53582 L
s
.72553 .53582 m
.72553 .53582 L
s
.72553 .53582 m
.72553 .53582 L
s
.72553 .53582 m
.72553 .53582 L
s
1 .004 0 r
.57158 .75262 m
.57177 .75251 L
s
.57173 .7525 m
.57176 .75255 L
s
.5717 .75252 m
.57173 .7525 L
s
.57173 .7525 m
.57177 .75251 L
s
.57176 .75255 m
.57173 .75257 L
s
.57177 .75251 m
.57176 .75255 L
s
1 0 0 r
.5313 .48745 m
.5313 .48745 L
s
.5313 .48745 m
.5313 .48745 L
s
.5313 .48745 m
.5313 .48745 L
s
.5313 .48745 m
.5313 .48745 L
s
.5313 .48745 m
.5313 .48745 L
s
.5313 .48745 m
.5313 .48745 L
s
.5313 .48745 m
.5313 .48745 L
s
.5313 .48745 m
.5313 .48745 L
s
.5313 .48745 m
.5313 .48745 L
s
1 .004 0 r
.57173 .75257 m
.5717 .75252 L
s
.5717 .75252 m
.57177 .75251 L
s
.57177 .75251 m
.57173 .75257 L
s
1 .008 0 r
.37733 .70427 m
.3778 .70412 L
s
1 .001 0 r
.81621 .68009 m
.81623 .68007 L
s
1 .008 0 r
.37775 .70419 m
.3777 .70422 L
s
.37771 .70409 m
.37775 .70419 L
s
.3778 .70412 m
.37775 .70419 L
s
.37766 .70412 m
.37771 .70409 L
s
.37771 .70409 m
.3778 .70412 L
s
1 .001 0 r
.81623 .68007 m
.81623 .68008 L
s
.81622 .68007 m
.81623 .68007 L
s
.81623 .68007 m
.81623 .68007 L
s
.81623 .68008 m
.81623 .68008 L
s
.81623 .68007 m
.81623 .68008 L
s
.81623 .68008 m
.81622 .68007 L
s
.81622 .68007 m
.81623 .68007 L
s
.81623 .68007 m
.81623 .68008 L
s
1 .008 0 r
.3778 .70412 m
.3777 .70422 L
s
.37766 .70412 m
.3778 .70412 L
s
.3777 .70422 m
.37766 .70412 L
s
1 .001 0 r
.62196 .63173 m
.62199 .6317 L
s
.62198 .6317 m
.62199 .63171 L
s
.62198 .6317 m
.62198 .6317 L
s
.62198 .6317 m
.62199 .6317 L
s
.62199 .63171 m
.62198 .63171 L
s
.62199 .6317 m
.62199 .63171 L
s
.62198 .63171 m
.62198 .6317 L
s
.62198 .6317 m
.62199 .6317 L
s
.62199 .6317 m
.62198 .63171 L
s
.42767 .58336 m
.42774 .58332 L
s
.42773 .58332 m
.42774 .58333 L
s
.42772 .58332 m
.42773 .58332 L
s
.42773 .58332 m
.42774 .58332 L
s
.42774 .58333 m
.42773 .58334 L
s
.42774 .58332 m
.42774 .58333 L
s
.42773 .58334 m
.42772 .58332 L
s
.42772 .58332 m
.42774 .58332 L
s
.42774 .58332 m
.42773 .58334 L
s
1 0 0 r
.86665 .55917 m
.86665 .55917 L
s
.86665 .55917 m
.86665 .55917 L
s
.86665 .55917 m
.86665 .55917 L
s
.86665 .55917 m
.86665 .55917 L
s
.86665 .55917 m
.86665 .55917 L
s
.86665 .55917 m
.86665 .55917 L
s
.86665 .55917 m
.86665 .55917 L
s
.86665 .55917 m
.86665 .55917 L
s
.86665 .55917 m
.86665 .55917 L
s
1 .002 0 r
.71265 .77605 m
.71275 .77598 L
s
.71273 .77597 m
.71275 .776 L
s
.71271 .77598 m
.71273 .77597 L
s
.71273 .77597 m
.71275 .77598 L
s
.71275 .776 m
.71273 .77601 L
s
.71275 .77598 m
.71275 .776 L
s
.71273 .77601 m
.71271 .77598 L
s
.71271 .77598 m
.71275 .77598 L
s
.71275 .77598 m
.71273 .77601 L
s
1 0 0 r
.67236 .51079 m
.67236 .51079 L
s
.67236 .51079 m
.67236 .51079 L
s
.67236 .51079 m
.67236 .51079 L
s
.67236 .51079 m
.67236 .51079 L
s
.67236 .51079 m
.67236 .51079 L
s
.67236 .51079 m
.67236 .51079 L
s
.67236 .51079 m
.67236 .51079 L
s
.67236 .51079 m
.67236 .51079 L
s
.67236 .51079 m
.67236 .51079 L
s
1 .004 0 r
.51834 .72768 m
.51856 .72756 L
s
.51852 .72755 m
.51855 .7276 L
s
.51849 .72757 m
.51852 .72755 L
s
.51852 .72755 m
.51856 .72756 L
s
.51855 .7276 m
.51852 .72763 L
s
.51856 .72756 m
.51855 .7276 L
s
.51852 .72763 m
.51849 .72757 L
s
.51849 .72757 m
.51856 .72756 L
s
.51856 .72756 m
.51852 .72763 L
s
1 .001 0 r
.76307 .65512 m
.76309 .6551 L
s
.76309 .6551 m
.76309 .6551 L
s
.76308 .6551 m
.76309 .6551 L
s
.76309 .6551 m
.76309 .6551 L
s
.76309 .6551 m
.76309 .65511 L
s
.76309 .6551 m
.76309 .6551 L
s
.76309 .65511 m
.76308 .6551 L
s
.76308 .6551 m
.76309 .6551 L
s
.76309 .6551 m
.76309 .65511 L
s
.56873 .60673 m
.56876 .6067 L
s
.56875 .6067 m
.56876 .60671 L
s
.56875 .60671 m
.56875 .6067 L
s
.56875 .6067 m
.56876 .6067 L
s
.56876 .60671 m
.56875 .60672 L
s
.56876 .6067 m
.56876 .60671 L
s
.56875 .60672 m
.56875 .60671 L
s
.56875 .60671 m
.56876 .6067 L
s
.56876 .6067 m
.56875 .60672 L
s
1 .011 0 r
.41467 .82368 m
.41533 .82349 L
s
1 .001 0 r
.37435 .55834 m
.37441 .55831 L
s
.37441 .55832 m
.3744 .55832 L
s
.3744 .5583 m
.37441 .55832 L
s
.37441 .55831 m
.37441 .55832 L
s
.37439 .55831 m
.3744 .5583 L
s
.3744 .5583 m
.37441 .55831 L
s
1 .011 0 r
.41525 .82358 m
.4152 .82362 L
s
.4152 .82343 m
.41525 .82358 L
s
.41533 .82349 m
.41525 .82358 L
s
1 .001 0 r
.3744 .55832 m
.37439 .55831 L
s
.37441 .55831 m
.3744 .55832 L
s
.37439 .55831 m
.37441 .55831 L
s
1 .011 0 r
.41514 .82348 m
.4152 .82343 L
s
.4152 .82343 m
.41533 .82349 L
s
1 0 0 r
.81352 .53414 m
.81352 .53414 L
s
.81352 .53414 m
.81352 .53414 L
s
.81352 .53414 m
.81352 .53414 L
s
.81352 .53414 m
.81352 .53414 L
s
.81352 .53414 m
.81352 .53414 L
s
.81352 .53414 m
.81352 .53414 L
s
.81352 .53414 m
.81352 .53414 L
s
.81352 .53414 m
.81352 .53414 L
s
.81352 .53414 m
.81352 .53414 L
s
1 .011 0 r
.41533 .82349 m
.4152 .82362 L
s
.41514 .82348 m
.41533 .82349 L
s
.4152 .82362 m
.41514 .82348 L
s
1 .003 0 r
.65945 .75111 m
.65956 .75103 L
s
.65954 .75103 m
.65956 .75106 L
s
.65952 .75104 m
.65954 .75103 L
s
.65954 .75103 m
.65956 .75103 L
s
.65956 .75106 m
.65954 .75107 L
s
.65956 .75103 m
.65956 .75106 L
s
.65954 .75107 m
.65952 .75104 L
s
.65952 .75104 m
.65956 .75103 L
s
.65956 .75103 m
.65954 .75107 L
s
1 0 0 r
.61914 .48573 m
.61914 .48573 L
s
.61914 .48573 m
.61914 .48573 L
s
.61914 .48573 m
.61914 .48573 L
s
.61914 .48573 m
.61914 .48573 L
s
.61914 .48573 m
.61914 .48573 L
s
.61914 .48573 m
.61914 .48573 L
s
.61914 .48573 m
.61914 .48573 L
s
.61914 .48573 m
.61914 .48573 L
s
.61914 .48573 m
.61914 .48573 L
s
1 .005 0 r
.46505 .70272 m
.46532 .7026 L
s
.4653 .70264 m
.46526 .70266 L
s
.46527 .70258 m
.4653 .70264 L
s
.46532 .7026 m
.4653 .70264 L
s
.46523 .7026 m
.46527 .70258 L
s
.46527 .70258 m
.46532 .7026 L
s
.46526 .70266 m
.46523 .7026 L
s
.46532 .7026 m
.46526 .70266 L
s
.46523 .7026 m
.46532 .7026 L
s
1 0 0 r
.70989 .63012 m
.7099 .6301 L
s
.7099 .6301 m
.70991 .63011 L
s
.7099 .63011 m
.7099 .6301 L
s
.7099 .6301 m
.7099 .6301 L
s
.70991 .63011 m
.7099 .63011 L
s
.7099 .6301 m
.70991 .63011 L
s
.7099 .63011 m
.7099 .63011 L
s
.7099 .63011 m
.7099 .6301 L
s
.7099 .6301 m
.7099 .63011 L
s
1 .001 0 r
.51545 .58171 m
.51548 .58169 L
s
.51547 .58169 m
.51548 .58169 L
s
.51547 .58169 m
.51547 .58169 L
s
.51547 .58169 m
.51548 .58169 L
s
.51548 .58169 m
.51547 .5817 L
s
.51548 .58169 m
.51548 .58169 L
s
.51547 .5817 m
.51547 .58169 L
s
.51547 .58169 m
.51548 .58169 L
s
.51548 .58169 m
.51547 .5817 L
s
1 0 0 r
.95478 .5575 m
.95479 .5575 L
s
.95479 .5575 m
.95479 .5575 L
s
.95478 .5575 m
.95479 .5575 L
s
.95479 .5575 m
.95479 .5575 L
s
.95479 .5575 m
.95479 .5575 L
s
.95479 .5575 m
.95479 .5575 L
s
.95479 .5575 m
.95478 .5575 L
s
.95478 .5575 m
.95479 .5575 L
s
.95479 .5575 m
.95479 .5575 L
s
1 .001 0 r
.32098 .53329 m
.32103 .53328 L
s
.32102 .53328 m
.32102 .53329 L
s
.32102 .53327 m
.32102 .53328 L
s
.32103 .53328 m
.32102 .53328 L
s
.32101 .53328 m
.32102 .53327 L
s
.32102 .53327 m
.32103 .53328 L
s
.32103 .53328 m
.32102 .53329 L
s
.32101 .53328 m
.32103 .53328 L
s
.32102 .53329 m
.32101 .53328 L
s
1 0 0 r
.76034 .50908 m
.76034 .50908 L
s
.76034 .50908 m
.76034 .50908 L
s
.76034 .50908 m
.76034 .50908 L
s
.76034 .50908 m
.76034 .50908 L
s
.76034 .50908 m
.76034 .50908 L
s
.76034 .50908 m
.76034 .50908 L
s
.76034 .50908 m
.76034 .50908 L
s
.76034 .50908 m
.76034 .50908 L
s
.76034 .50908 m
.76034 .50908 L
s
1 .003 0 r
.60621 .72615 m
.60633 .72607 L
s
.60631 .72606 m
.60633 .72609 L
s
.60629 .72608 m
.60631 .72606 L
s
.60631 .72606 m
.60633 .72607 L
s
.60633 .72609 m
.60631 .72611 L
s
.60633 .72607 m
.60633 .72609 L
s
.60631 .72611 m
.60629 .72608 L
s
.60629 .72608 m
.60633 .72607 L
s
.60633 .72607 m
.60631 .72611 L
s
1 .006 0 r
.41171 .67774 m
.41204 .67761 L
s
.41201 .67766 m
.41197 .67768 L
s
.41197 .67758 m
.41201 .67766 L
s
.41204 .67761 m
.41201 .67766 L
s
1 0 0 r
.85115 .65353 m
.85116 .65352 L
s
1 .006 0 r
.41194 .67761 m
.41197 .67758 L
s
.41197 .67758 m
.41204 .67761 L
s
1 0 0 r
.85116 .65351 m
.85116 .65352 L
s
.85116 .65352 m
.85116 .65351 L
s
.85116 .65351 m
.85116 .65352 L
s
.85116 .65352 m
.85116 .65352 L
s
.85116 .65352 m
.85116 .65352 L
s
.85116 .65352 m
.85116 .65352 L
s
.85116 .65352 m
.85116 .65352 L
s
.85116 .65352 m
.85116 .65352 L
s
1 .006 0 r
.41197 .67768 m
.41194 .67761 L
s
.41204 .67761 m
.41197 .67768 L
s
.41194 .67761 m
.41204 .67761 L
s
1 0 0 r
.65665 .6051 m
.65667 .60509 L
s
.65667 .60509 m
.65667 .60509 L
s
.65666 .60509 m
.65667 .60509 L
s
.65667 .60509 m
.65667 .60509 L
s
.65667 .60509 m
.65667 .60509 L
s
.65667 .60509 m
.65667 .60509 L
s
.65667 .60509 m
.65666 .60509 L
s
.65666 .60509 m
.65667 .60509 L
s
.65667 .60509 m
.65667 .60509 L
s
1 .008 0 r
.50247 .82223 m
.50291 .82205 L
s
1 .001 0 r
.46212 .55667 m
.46215 .55665 L
s
.46214 .55665 m
.46215 .55666 L
s
.46214 .55665 m
.46214 .55665 L
s
.46214 .55665 m
.46215 .55665 L
s
.46215 .55666 m
.46214 .55666 L
s
.46215 .55665 m
.46215 .55666 L
s
.46214 .55666 m
.46214 .55665 L
s
.46214 .55665 m
.46215 .55665 L
s
.46215 .55665 m
.46214 .55666 L
s
1 .008 0 r
.50287 .82212 m
.50282 .82216 L
s
.50282 .82202 m
.50287 .82212 L
s
.50291 .82205 m
.50287 .82212 L
s
.50277 .82206 m
.50282 .82202 L
s
.50282 .82202 m
.50291 .82205 L
s
1 0 0 r
.90165 .53245 m
.90165 .53245 L
s
.90165 .53245 m
.90165 .53245 L
s
.90165 .53245 m
.90165 .53245 L
s
.90165 .53245 m
.90165 .53245 L
s
.90165 .53245 m
.90165 .53245 L
s
.90165 .53245 m
.90165 .53245 L
s
.90165 .53245 m
.90165 .53245 L
s
.90165 .53245 m
.90165 .53245 L
s
.90165 .53245 m
.90165 .53245 L
s
1 .008 0 r
.50282 .82216 m
.50277 .82206 L
s
.50291 .82205 m
.50282 .82216 L
s
.50277 .82206 m
.50291 .82205 L
s
1 .002 0 r
.74746 .7496 m
.74753 .74955 L
s
.74752 .74954 m
.74753 .74956 L
s
.7475 .74955 m
.74752 .74954 L
s
.74752 .74954 m
.74753 .74955 L
s
.74753 .74956 m
.74752 .74957 L
s
.74753 .74955 m
.74753 .74956 L
s
.74752 .74957 m
.7475 .74955 L
s
.7475 .74955 m
.74753 .74955 L
s
.74753 .74955 m
.74752 .74957 L
s
1 0 0 r
.70712 .484 m
.70712 .484 L
s
.70712 .484 m
.70712 .484 L
s
.70712 .484 m
.70712 .484 L
s
.70712 .484 m
.70712 .484 L
s
.70712 .484 m
.70712 .484 L
s
.70712 .484 m
.70712 .484 L
s
.70712 .484 m
.70712 .484 L
s
.70712 .484 m
.70712 .484 L
s
.70712 .484 m
.70712 .484 L
s
1 .003 0 r
.55291 .70117 m
.55306 .70108 L
s
.55303 .70107 m
.55305 .70111 L
s
.55301 .70109 m
.55303 .70107 L
s
.55303 .70107 m
.55306 .70108 L
s
.55305 .70111 m
.55303 .70112 L
s
.55306 .70108 m
.55305 .70111 L
s
.55303 .70112 m
.55301 .70109 L
s
.55301 .70109 m
.55306 .70108 L
s
.55306 .70108 m
.55303 .70112 L
s
1 .006 0 r
.35833 .65273 m
.35871 .65261 L
s
.35867 .65266 m
.35863 .65269 L
s
.35864 .65258 m
.35867 .65266 L
s
.35871 .65261 m
.35867 .65266 L
s
.3586 .6526 m
.35864 .65258 L
s
.35864 .65258 m
.35871 .65261 L
s
1 0 0 r
.79796 .62851 m
.79797 .6285 L
s
.79797 .6285 m
.79797 .6285 L
s
.79796 .6285 m
.79797 .6285 L
s
.79797 .6285 m
.79797 .6285 L
s
.79797 .6285 m
.79797 .6285 L
s
.79797 .6285 m
.79797 .6285 L
s
.79797 .6285 m
.79796 .6285 L
s
.79796 .6285 m
.79797 .6285 L
s
.79797 .6285 m
.79797 .6285 L
s
1 .006 0 r
.35871 .65261 m
.35863 .65269 L
s
.3586 .6526 m
.35871 .65261 L
s
.35863 .65269 m
.3586 .6526 L
s
1 0 0 r
.60337 .58006 m
.60338 .58005 L
s
.60338 .58005 m
.60338 .58005 L
s
.60338 .58005 m
.60338 .58005 L
s
.60338 .58005 m
.60338 .58005 L
s
.60338 .58005 m
.60338 .58005 L
s
.60338 .58005 m
.60338 .58005 L
s
.60338 .58005 m
.60338 .58005 L
s
.60338 .58005 m
.60338 .58005 L
s
.60338 .58005 m
.60338 .58005 L
s
1 .009 0 r
.44912 .79728 m
.44965 .7971 L
s
1 0 0 r
.40875 .5316 m
.40877 .53159 L
s
.40876 .53159 m
.40877 .5316 L
s
.40876 .53159 m
.40876 .53159 L
s
.40876 .53159 m
.40877 .53159 L
s
.40877 .5316 m
.40876 .5316 L
s
.40877 .53159 m
.40877 .5316 L
s
.40876 .5316 m
.40876 .53159 L
s
.40876 .53159 m
.40877 .53159 L
s
.40877 .53159 m
.40876 .5316 L
s
1 .009 0 r
.4496 .79717 m
.44954 .79721 L
s
.44954 .79705 m
.4496 .79717 L
s
.44965 .7971 m
.4496 .79717 L
s
.44949 .79709 m
.44954 .79705 L
s
.44954 .79705 m
.44965 .7971 L
s
1 0 0 r
.84847 .50737 m
.84847 .50737 L
s
.84847 .50737 m
.84847 .50737 L
s
.84847 .50737 m
.84847 .50737 L
s
.84847 .50737 m
.84847 .50737 L
s
.84847 .50737 m
.84847 .50737 L
s
.84847 .50737 m
.84847 .50737 L
s
.84847 .50737 m
.84847 .50737 L
s
.84847 .50737 m
.84847 .50737 L
s
.84847 .50737 m
.84847 .50737 L
s
1 .009 0 r
.44954 .79721 m
.44949 .79709 L
s
.44965 .7971 m
.44954 .79721 L
s
.44949 .79709 m
.44965 .7971 L
s
1 .002 0 r
.69421 .72462 m
.69429 .72456 L
s
.69427 .72456 m
.69429 .72458 L
s
.69426 .72457 m
.69427 .72456 L
s
.69427 .72456 m
.69429 .72456 L
s
.69429 .72458 m
.69427 .72459 L
s
.69429 .72456 m
.69429 .72458 L
s
.69427 .72459 m
.69426 .72457 L
s
.69426 .72457 m
.69429 .72456 L
s
.69429 .72456 m
.69427 .72459 L
s
1 .003 0 r
.49957 .67616 m
.49974 .67607 L
s
.49971 .67606 m
.49973 .6761 L
s
.49968 .67607 m
.49971 .67606 L
s
.49971 .67606 m
.49974 .67607 L
s
.49973 .6761 m
.49971 .67612 L
s
.49974 .67607 m
.49973 .6761 L
s
.49971 .67612 m
.49968 .67607 L
s
.49968 .67607 m
.49974 .67607 L
s
.49974 .67607 m
.49971 .67612 L
s
1 0 0 r
.74472 .60347 m
.74473 .60346 L
s
.74473 .60346 m
.74473 .60346 L
s
.74472 .60346 m
.74473 .60346 L
s
.74473 .60346 m
.74473 .60346 L
s
.74473 .60346 m
.74473 .60347 L
s
.74473 .60346 m
.74473 .60346 L
s
.74473 .60347 m
.74472 .60346 L
s
.74472 .60346 m
.74473 .60346 L
s
.74473 .60346 m
.74473 .60347 L
s
1 .005 0 r
.59042 .82077 m
.59069 .82063 L
s
1 0 0 r
.55004 .555 m
.55005 .55499 L
s
.55005 .55499 m
.55005 .55499 L
s
.55005 .55499 m
.55005 .55499 L
s
.55005 .55499 m
.55005 .55499 L
s
.55005 .55499 m
.55005 .55499 L
s
.55005 .55499 m
.55005 .55499 L
s
.55005 .55499 m
.55005 .55499 L
s
.55005 .55499 m
.55005 .55499 L
s
.55005 .55499 m
.55005 .55499 L
s
1 .005 0 r
.59064 .82061 m
.59068 .82068 L
s
.5906 .82064 m
.59064 .82061 L
s
.59064 .82061 m
.59069 .82063 L
s
.59068 .82068 m
.59064 .82071 L
s
.59069 .82063 m
.59068 .82068 L
s
.59064 .82071 m
.5906 .82064 L
s
.5906 .82064 m
.59069 .82063 L
s
.59069 .82063 m
.59064 .82071 L
s
1 .011 0 r
.39572 .77232 m
.39636 .77213 L
s
1 0 0 r
.35533 .50652 m
.35534 .50651 L
s
.35534 .50651 m
.35534 .50652 L
s
.35534 .50651 m
.35534 .50651 L
s
.35534 .50651 m
.35534 .50651 L
s
.35533 .50651 m
.35534 .50651 L
s
.35534 .50651 m
.35534 .50651 L
s
.35534 .50652 m
.35533 .50651 L
s
.35534 .50651 m
.35534 .50652 L
s
.35533 .50651 m
.35534 .50651 L
s
1 .011 0 r
.39629 .77221 m
.39623 .77226 L
s
.39623 .77207 m
.39629 .77221 L
s
.39636 .77213 m
.39629 .77221 L
s
.39618 .77212 m
.39623 .77207 L
s
.39623 .77207 m
.39636 .77213 L
s
1 0 0 r
.79525 .48227 m
.79525 .48227 L
s
.79525 .48227 m
.79525 .48227 L
s
.79525 .48227 m
.79525 .48227 L
s
.79525 .48227 m
.79525 .48227 L
s
.79525 .48227 m
.79525 .48227 L
s
.79525 .48227 m
.79525 .48227 L
s
.79525 .48227 m
.79525 .48227 L
s
.79525 .48227 m
.79525 .48227 L
s
.79525 .48227 m
.79525 .48227 L
s
1 .011 0 r
.39636 .77213 m
.39623 .77226 L
s
.39618 .77212 m
.39636 .77213 L
s
.39623 .77226 m
.39618 .77212 L
s
1 .002 0 r
.64092 .69962 m
.641 .69956 L
s
.64098 .69955 m
.641 .69957 L
s
.64097 .69956 m
.64098 .69955 L
s
.64098 .69955 m
.641 .69956 L
s
.641 .69957 m
.64098 .69958 L
s
.641 .69956 m
.641 .69957 L
s
.64098 .69958 m
.64097 .69956 L
s
.64097 .69956 m
.641 .69956 L
s
.641 .69956 m
.64098 .69958 L
s
1 .004 0 r
.44618 .65114 m
.44638 .65104 L
s
.44637 .65107 m
.44634 .65109 L
s
.44634 .65103 m
.44637 .65107 L
s
.44638 .65104 m
.44637 .65107 L
s
.44632 .65104 m
.44634 .65103 L
s
.44634 .65103 m
.44638 .65104 L
s
1 0 0 r
.88617 .6269 m
.88618 .62689 L
s
.88618 .62689 m
.88618 .62689 L
s
.88618 .62689 m
.88618 .62689 L
s
.88618 .62689 m
.88618 .62689 L
s
.88618 .62689 m
.88618 .62689 L
s
.88618 .62689 m
.88618 .62689 L
s
.88618 .62689 m
.88618 .62689 L
s
.88618 .62689 m
.88618 .62689 L
s
.88618 .62689 m
.88618 .62689 L
s
1 .004 0 r
.44634 .65109 m
.44632 .65104 L
s
.44638 .65104 m
.44634 .65109 L
s
.44632 .65104 m
.44638 .65104 L
s
1 0 0 r
.69143 .57841 m
.69144 .5784 L
s
.69144 .5784 m
.69144 .5784 L
s
.69144 .5784 m
.69144 .5784 L
s
.69144 .5784 m
.69144 .5784 L
s
.69144 .5784 m
.69144 .5784 L
s
.69144 .5784 m
.69144 .5784 L
s
.69144 .5784 m
.69144 .5784 L
s
.69144 .5784 m
.69144 .5784 L
s
.69144 .5784 m
.69144 .5784 L
s
1 .006 0 r
.53706 .79581 m
.53739 .79565 L
s
1 0 0 r
.49666 .52991 m
.49667 .52991 L
s
.49667 .52991 m
.49667 .52991 L
s
.49667 .52991 m
.49667 .52991 L
s
.49667 .52991 m
.49667 .52991 L
s
.49667 .52991 m
.49667 .52991 L
s
.49667 .52991 m
.49667 .52991 L
s
.49667 .52991 m
.49667 .52991 L
s
.49667 .52991 m
.49667 .52991 L
s
.49667 .52991 m
.49667 .52991 L
s
1 .006 0 r
.53732 .79563 m
.53737 .79571 L
s
.53728 .79566 m
.53732 .79563 L
s
.53732 .79563 m
.53739 .79565 L
s
.53737 .79571 m
.53732 .79574 L
s
.53739 .79565 m
.53737 .79571 L
s
.53732 .79574 m
.53728 .79566 L
s
.53728 .79566 m
.53739 .79565 L
s
.53739 .79565 m
.53732 .79574 L
s
1 0 0 r
.93675 .50566 m
.93675 .50566 L
s
.93675 .50566 m
.93675 .50566 L
s
.93675 .50566 m
.93675 .50566 L
s
.93675 .50566 m
.93675 .50566 L
s
.93675 .50566 m
.93675 .50566 L
s
.93675 .50566 m
.93675 .50566 L
s
.93675 .50566 m
.93675 .50566 L
s
.93675 .50566 m
.93675 .50566 L
s
.93675 .50566 m
.93675 .50566 L
s
1 .001 0 r
.78237 .72308 m
.78241 .72305 L
s
1 0 0 r
.30186 .48141 m
.30186 .48141 L
s
.30186 .48141 m
.30186 .48141 L
s
.30186 .48141 m
.30186 .48141 L
s
.30186 .48141 m
.30186 .48141 L
s
.30186 .48141 m
.30186 .48141 L
s
.30186 .48141 m
.30186 .48141 L
s
.30186 .48141 m
.30186 .48141 L
s
.30186 .48141 m
.30186 .48141 L
s
.30186 .48141 m
.30186 .48141 L
s
1 .001 0 r
.7824 .72304 m
.78241 .72306 L
s
.78239 .72305 m
.7824 .72304 L
s
.7824 .72304 m
.78241 .72305 L
s
.78241 .72306 m
.7824 .72306 L
s
.78241 .72305 m
.78241 .72306 L
s
.7824 .72306 m
.78239 .72305 L
s
.78239 .72305 m
.78241 .72305 L
s
.78241 .72305 m
.7824 .72306 L
s
1 .002 0 r
.58757 .67459 m
.58766 .67453 L
s
.58764 .67452 m
.58766 .67455 L
s
.58763 .67453 m
.58764 .67452 L
s
.58764 .67452 m
.58766 .67453 L
s
.58766 .67455 m
.58764 .67456 L
s
.58766 .67453 m
.58766 .67455 L
s
.58764 .67456 m
.58763 .67453 L
s
.58763 .67453 m
.58766 .67453 L
s
.58766 .67453 m
.58764 .67456 L
s
1 .004 0 r
.39275 .62609 m
.39298 .62599 L
s
.39296 .62603 m
.39293 .62605 L
s
.39293 .62597 m
.39296 .62603 L
s
.39298 .62599 m
.39296 .62603 L
s
.39291 .62599 m
.39293 .62597 L
s
.39293 .62597 m
.39298 .62599 L
s
1 0 0 r
.83293 .60184 m
.83294 .60183 L
s
.83294 .60183 m
.83294 .60183 L
s
.83293 .60183 m
.83294 .60183 L
s
.83294 .60183 m
.83294 .60183 L
s
.83294 .60183 m
.83294 .60183 L
s
.83294 .60183 m
.83294 .60183 L
s
.83294 .60183 m
.83293 .60183 L
s
.83293 .60183 m
.83294 .60183 L
s
.83294 .60183 m
.83294 .60183 L
s
1 .004 0 r
.39293 .62605 m
.39291 .62599 L
s
.39298 .62599 m
.39293 .62605 L
s
.39291 .62599 m
.39298 .62599 L
s
.67851 .81932 m
.67868 .81921 L
s
.67864 .8192 m
.67867 .81924 L
s
.67862 .81922 m
.67864 .8192 L
s
.67864 .8192 m
.67868 .81921 L
s
.67867 .81924 m
.67865 .81926 L
s
.67868 .81921 m
.67867 .81924 L
s
1 0 0 r
.6381 .55332 m
.63811 .55332 L
s
.6381 .55332 m
.63811 .55332 L
s
.6381 .55332 m
.6381 .55332 L
s
.6381 .55332 m
.63811 .55332 L
s
.63811 .55332 m
.6381 .55332 L
s
.63811 .55332 m
.63811 .55332 L
s
.6381 .55332 m
.6381 .55332 L
s
.6381 .55332 m
.63811 .55332 L
s
.63811 .55332 m
.6381 .55332 L
s
1 .004 0 r
.67865 .81926 m
.67862 .81922 L
s
.67862 .81922 m
.67868 .81921 L
s
.67868 .81921 m
.67865 .81926 L
s
1 .007 0 r
.48366 .77082 m
.48406 .77065 L
s
1 0 0 r
.44324 .5048 m
.44324 .5048 L
s
.44324 .5048 m
.44324 .5048 L
s
.44324 .5048 m
.44324 .5048 L
s
.44324 .5048 m
.44324 .5048 L
s
.44324 .5048 m
.44324 .5048 L
s
.44324 .5048 m
.44324 .5048 L
s
.44324 .5048 m
.44324 .5048 L
s
.44324 .5048 m
.44324 .5048 L
s
.44324 .5048 m
.44324 .5048 L
s
1 .007 0 r
.48402 .77071 m
.48398 .77075 L
s
.48398 .77062 m
.48402 .77071 L
s
.48406 .77065 m
.48402 .77071 L
s
.48393 .77065 m
.48398 .77062 L
s
.48398 .77062 m
.48406 .77065 L
s
1 0 0 r
.88352 .48054 m
.88352 .48054 L
s
.88352 .48054 m
.88352 .48054 L
s
.88352 .48054 m
.88352 .48054 L
s
.88352 .48054 m
.88352 .48054 L
s
.88352 .48054 m
.88352 .48054 L
s
.88352 .48054 m
.88352 .48054 L
s
.88352 .48054 m
.88352 .48054 L
s
.88352 .48054 m
.88352 .48054 L
s
.88352 .48054 m
.88352 .48054 L
s
1 .007 0 r
.48398 .77075 m
.48393 .77065 L
s
.48406 .77065 m
.48398 .77075 L
s
.48393 .77065 m
.48406 .77065 L
s
1 .001 0 r
.72906 .69806 m
.72911 .69802 L
s
.7291 .69802 m
.72911 .69803 L
s
.72909 .69802 m
.7291 .69802 L
s
.7291 .69802 m
.72911 .69802 L
s
.72911 .69803 m
.7291 .69804 L
s
.72911 .69802 m
.72911 .69803 L
s
.7291 .69804 m
.72909 .69802 L
s
.72909 .69802 m
.72911 .69802 L
s
.72911 .69802 m
.7291 .69804 L
s
1 .002 0 r
.53418 .64954 m
.53428 .64948 L
s
.53426 .64947 m
.53427 .6495 L
s
.53424 .64948 m
.53426 .64947 L
s
.53426 .64947 m
.53428 .64948 L
s
.53427 .6495 m
.53426 .64951 L
s
.53428 .64948 m
.53427 .6495 L
s
.53426 .64951 m
.53424 .64948 L
s
.53424 .64948 m
.53428 .64948 L
s
.53428 .64948 m
.53426 .64951 L
s
1 .005 0 r
.33926 .60102 m
.33953 .60093 L
s
.3395 .60097 m
.33947 .60099 L
s
.33948 .60091 m
.3395 .60097 L
s
.33953 .60093 m
.3395 .60097 L
s
.33945 .60093 m
.33948 .60091 L
s
.33948 .60091 m
.33953 .60093 L
s
1 0 0 r
.77964 .57675 m
.77965 .57675 L
s
.77964 .57675 m
.77965 .57675 L
s
.77964 .57675 m
.77964 .57675 L
s
.77964 .57675 m
.77965 .57675 L
s
.77965 .57675 m
.77964 .57675 L
s
.77965 .57675 m
.77965 .57675 L
s
.77964 .57675 m
.77964 .57675 L
s
.77964 .57675 m
.77965 .57675 L
s
.77965 .57675 m
.77964 .57675 L
s
1 .005 0 r
.33953 .60093 m
.33947 .60099 L
s
.33945 .60093 m
.33953 .60093 L
s
.33947 .60099 m
.33945 .60093 L
s
1 .004 0 r
.62515 .79433 m
.62535 .79421 L
s
.62531 .7942 m
.62534 .79425 L
s
.62527 .79422 m
.62531 .7942 L
s
.62531 .7942 m
.62535 .79421 L
s
.62534 .79425 m
.62531 .79427 L
s
.62535 .79421 m
.62534 .79425 L
s
1 0 0 r
.58472 .52822 m
.58472 .52821 L
s
.58472 .52821 m
.58472 .52822 L
s
.58472 .52822 m
.58472 .52821 L
s
.58472 .52821 m
.58472 .52821 L
s
.58472 .52822 m
.58472 .52822 L
s
.58472 .52821 m
.58472 .52822 L
s
.58472 .52822 m
.58472 .52822 L
s
.58472 .52822 m
.58472 .52821 L
s
.58472 .52821 m
.58472 .52822 L
s
1 .004 0 r
.62531 .79427 m
.62527 .79422 L
s
.62527 .79422 m
.62535 .79421 L
s
.62535 .79421 m
.62531 .79427 L
s
1 .009 0 r
.43021 .74581 m
.43069 .74563 L
s
1 0 0 r
.38977 .47967 m
.38977 .47967 L
s
.38977 .47967 m
.38977 .47967 L
s
.38977 .47967 m
.38977 .47967 L
s
.38977 .47967 m
.38977 .47967 L
s
.38977 .47967 m
.38977 .47967 L
s
.38977 .47967 m
.38977 .47967 L
s
.38977 .47967 m
.38977 .47967 L
s
.38977 .47967 m
.38977 .47967 L
s
.38977 .47967 m
.38977 .47967 L
s
1 .009 0 r
.43065 .7457 m
.43059 .74574 L
s
.4306 .74559 m
.43065 .7457 L
s
.43069 .74563 m
.43065 .7457 L
s
.43054 .74563 m
.4306 .74559 L
s
.4306 .74559 m
.43069 .74563 L
s
.43059 .74574 m
.43054 .74563 L
s
.43069 .74563 m
.43059 .74574 L
s
.43054 .74563 m
.43069 .74563 L
s
1 .001 0 r
.67572 .67301 m
.67576 .67297 L
s
.67575 .67297 m
.67576 .67298 L
s
.67574 .67298 m
.67575 .67297 L
s
.67575 .67297 m
.67576 .67297 L
s
.67576 .67298 m
.67575 .67299 L
s
.67576 .67297 m
.67576 .67298 L
s
.67575 .67299 m
.67574 .67298 L
s
.67574 .67298 m
.67576 .67297 L
s
.67576 .67297 m
.67575 .67299 L
s
1 .002 0 r
.48074 .62447 m
.48085 .6244 L
s
.48083 .6244 m
.48084 .62443 L
s
.48081 .62441 m
.48083 .6244 L
s
.48083 .6244 m
.48085 .6244 L
s
.48084 .62443 m
.48083 .62444 L
s
.48085 .6244 m
.48084 .62443 L
s
.48083 .62444 m
.48081 .62441 L
s
.48081 .62441 m
.48085 .6244 L
s
.48085 .6244 m
.48083 .62444 L
s
1 0 0 r
.92129 .6002 m
.92129 .6002 L
s
.92129 .6002 m
.92129 .6002 L
s
.92129 .6002 m
.92129 .6002 L
s
.92129 .6002 m
.92129 .6002 L
s
.92129 .6002 m
.92129 .6002 L
s
.92129 .6002 m
.92129 .6002 L
s
.92129 .6002 m
.92129 .6002 L
s
.92129 .6002 m
.92129 .6002 L
s
.92129 .6002 m
.92129 .6002 L
s
.7263 .55165 m
.72631 .55165 L
s
.72631 .55165 m
.72631 .55165 L
s
.72631 .55165 m
.72631 .55165 L
s
.72631 .55165 m
.72631 .55165 L
s
.72631 .55165 m
.72631 .55165 L
s
.72631 .55165 m
.72631 .55165 L
s
.72631 .55165 m
.72631 .55165 L
s
.72631 .55165 m
.72631 .55165 L
s
.72631 .55165 m
.72631 .55165 L
s
1 .005 0 r
.57174 .76932 m
.57197 .76919 L
s
1 0 0 r
.53129 .50309 m
.53129 .50309 L
s
.53129 .50309 m
.53129 .50309 L
s
.53129 .50309 m
.53129 .50309 L
s
.53129 .50309 m
.53129 .50309 L
s
.53129 .50309 m
.53129 .50309 L
s
.53129 .50309 m
.53129 .50309 L
s
.53129 .50309 m
.53129 .50309 L
s
.53129 .50309 m
.53129 .50309 L
s
.53129 .50309 m
.53129 .50309 L
s
1 .005 0 r
.57193 .76917 m
.57196 .76923 L
s
.57189 .7692 m
.57193 .76917 L
s
.57193 .76917 m
.57197 .76919 L
s
.57196 .76923 m
.57193 .76926 L
s
.57197 .76919 m
.57196 .76923 L
s
.57193 .76926 m
.57189 .7692 L
s
.57189 .7692 m
.57197 .76919 L
s
.57197 .76919 m
.57193 .76926 L
s
1 .01 0 r
.37671 .72078 m
.3773 .72059 L
s
1 .001 0 r
.81736 .6965 m
.81738 .69647 L
s
.81738 .69647 m
.81738 .69648 L
s
.81737 .69648 m
.81738 .69647 L
s
.81738 .69647 m
.81738 .69647 L
s
.81738 .69648 m
.81738 .69649 L
s
.81738 .69647 m
.81738 .69648 L
s
.81738 .69649 m
.81737 .69648 L
s
.81737 .69648 m
.81738 .69647 L
s
1 .01 0 r
.37724 .72068 m
.37718 .72071 L
s
.37719 .72054 m
.37724 .72068 L
s
.3773 .72059 m
.37724 .72068 L
s
1 .001 0 r
.81738 .69647 m
.81738 .69649 L
s
1 .01 0 r
.37713 .72058 m
.37719 .72054 L
s
.37719 .72054 m
.3773 .72059 L
s
.3773 .72059 m
.37718 .72071 L
s
.37713 .72058 m
.3773 .72059 L
s
.37718 .72071 m
.37713 .72058 L
s
1 .001 0 r
.62232 .64795 m
.62237 .6479 L
s
.62236 .6479 m
.62237 .64792 L
s
.62235 .64791 m
.62236 .6479 L
s
.62236 .6479 m
.62237 .6479 L
s
.62237 .64792 m
.62236 .64792 L
s
.62237 .6479 m
.62237 .64792 L
s
.62236 .64792 m
.62235 .64791 L
s
.62235 .64791 m
.62237 .6479 L
s
.62237 .6479 m
.62236 .64792 L
s
1 .002 0 r
.42725 .59938 m
.42737 .59931 L
s
.42735 .59931 m
.42737 .59934 L
s
.42733 .59932 m
.42735 .59931 L
s
.42735 .59931 m
.42737 .59931 L
s
.42737 .59934 m
.42735 .59935 L
s
.42737 .59931 m
.42737 .59934 L
s
.42735 .59935 m
.42733 .59932 L
s
.42733 .59932 m
.42737 .59931 L
s
.42737 .59931 m
.42735 .59935 L
s
1 0 0 r
.86799 .5751 m
.86799 .57509 L
s
.86799 .57509 m
.86799 .57509 L
s
.86799 .57509 m
.86799 .57509 L
s
.86799 .57509 m
.86799 .57509 L
s
.86799 .57509 m
.86799 .57509 L
s
.86799 .57509 m
.86799 .57509 L
s
.86799 .57509 m
.86799 .57509 L
s
.86799 .57509 m
.86799 .57509 L
s
.86799 .57509 m
.86799 .57509 L
s
1 .003 0 r
.71338 .79285 m
.7135 .79276 L
s
.71347 .79276 m
.7135 .79279 L
s
.71345 .79277 m
.71347 .79276 L
s
.71347 .79276 m
.7135 .79276 L
s
.7135 .79279 m
.71347 .79281 L
s
.7135 .79276 m
.7135 .79279 L
s
.71347 .79281 m
.71345 .79277 L
s
.71345 .79277 m
.7135 .79276 L
s
.7135 .79276 m
.71347 .79281 L
s
1 0 0 r
.67292 .52652 m
.67292 .52652 L
s
.67292 .52652 m
.67292 .52652 L
s
.67292 .52652 m
.67292 .52652 L
s
.67292 .52652 m
.67292 .52652 L
s
.67292 .52652 m
.67292 .52652 L
s
.67292 .52652 m
.67292 .52652 L
s
.67292 .52652 m
.67292 .52652 L
s
.67292 .52652 m
.67292 .52652 L
s
.67292 .52652 m
.67292 .52652 L
s
1 .006 0 r
.51828 .74429 m
.51857 .74414 L
s
1 0 0 r
.47781 .47794 m
.47781 .47794 L
s
.47781 .47794 m
.47781 .47794 L
s
.47781 .47794 m
.47781 .47794 L
s
.47781 .47794 m
.47781 .47794 L
s
.47781 .47794 m
.47781 .47794 L
s
.47781 .47794 m
.47781 .47794 L
s
.47781 .47794 m
.47781 .47794 L
s
.47781 .47794 m
.47781 .47794 L
s
.47781 .47794 m
.47781 .47794 L
s
1 .006 0 r
.51851 .74412 m
.51855 .74419 L
s
.51847 .74415 m
.51851 .74412 L
s
.51851 .74412 m
.51857 .74414 L
s
.51855 .74419 m
.51851 .74422 L
s
.51857 .74414 m
.51855 .74419 L
s
.51851 .74422 m
.51847 .74415 L
s
.51847 .74415 m
.51857 .74414 L
s
.51857 .74414 m
.51851 .74422 L
s
1 .001 0 r
.764 .67143 m
.76403 .67141 L
s
.76402 .67141 m
.76403 .67141 L
s
.76402 .67141 m
.76402 .67141 L
s
.76402 .67141 m
.76403 .67141 L
s
.76403 .67141 m
.76402 .67142 L
s
.76403 .67141 m
.76403 .67141 L
s
.76402 .67142 m
.76402 .67141 L
s
.76402 .67141 m
.76403 .67141 L
s
.76403 .67141 m
.76402 .67142 L
s
.56887 .62285 m
.56893 .62281 L
s
.56892 .62281 m
.56893 .62283 L
s
.56891 .62282 m
.56892 .62281 L
s
.56892 .62281 m
.56893 .62281 L
s
.56893 .62283 m
.56892 .62283 L
s
.56893 .62281 m
.56893 .62283 L
s
.56892 .62283 m
.56891 .62282 L
s
.56891 .62282 m
.56893 .62281 L
s
.56893 .62281 m
.56892 .62283 L
s
1 .002 0 r
.37371 .57427 m
.37384 .57421 L
s
.37383 .57423 m
.37382 .57424 L
s
.37382 .5742 m
.37383 .57423 L
s
.37384 .57421 m
.37383 .57423 L
s
.3738 .57421 m
.37382 .5742 L
s
.37382 .5742 m
.37384 .57421 L
s
.37382 .57424 m
.3738 .57421 L
s
.37384 .57421 m
.37382 .57424 L
s
.3738 .57421 m
.37384 .57421 L
s
1 0 0 r
.81465 .54997 m
.81465 .54997 L
s
.81465 .54997 m
.81465 .54997 L
s
.81465 .54997 m
.81465 .54997 L
s
.81465 .54997 m
.81465 .54997 L
s
.81465 .54997 m
.81465 .54997 L
s
.81465 .54997 m
.81465 .54997 L
s
.81465 .54997 m
.81465 .54997 L
s
.81465 .54997 m
.81465 .54997 L
s
.81465 .54997 m
.81465 .54997 L
s
1 .003 0 r
.65996 .76782 m
.6601 .76773 L
s
.66007 .76772 m
.6601 .76775 L
s
.66005 .76773 m
.66007 .76772 L
s
.66007 .76772 m
.6601 .76773 L
s
.6601 .76775 m
.66008 .76777 L
s
.6601 .76773 m
.6601 .76775 L
s
1 0 0 r
.61949 .50137 m
.61949 .50137 L
s
.61949 .50137 m
.61949 .50137 L
s
.61949 .50137 m
.61949 .50137 L
s
.61949 .50137 m
.61949 .50137 L
s
.61949 .50137 m
.61949 .50137 L
s
.61949 .50137 m
.61949 .50137 L
s
.61949 .50137 m
.61949 .50137 L
s
.61949 .50137 m
.61949 .50137 L
s
.61949 .50137 m
.61949 .50137 L
s
1 .003 0 r
.66008 .76777 m
.66005 .76773 L
s
.66005 .76773 m
.6601 .76773 L
s
.6601 .76773 m
.66008 .76777 L
s
1 .007 0 r
.46478 .71923 m
.46512 .71908 L
s
.4651 .71913 m
.46505 .71916 L
s
.46506 .71905 m
.4651 .71913 L
s
.46512 .71908 m
.4651 .71913 L
s
.46501 .71908 m
.46506 .71905 L
s
.46506 .71905 m
.46512 .71908 L
s
.46505 .71916 m
.46501 .71908 L
s
.46512 .71908 m
.46505 .71916 L
s
.46501 .71908 m
.46512 .71908 L
s
1 .001 0 r
.7106 .64634 m
.71063 .64632 L
s
.71062 .64632 m
.71063 .64633 L
s
.71062 .64632 m
.71062 .64632 L
s
.71062 .64632 m
.71063 .64632 L
s
.71063 .64633 m
.71062 .64633 L
s
.71063 .64632 m
.71063 .64633 L
s
.71062 .64633 m
.71062 .64632 L
s
.71062 .64632 m
.71063 .64632 L
s
.71063 .64632 m
.71062 .64633 L
s
.51538 .59774 m
.51543 .5977 L
s
.51542 .5977 m
.51543 .59771 L
s
.51541 .5977 m
.51542 .5977 L
s
.51542 .5977 m
.51543 .5977 L
s
.51543 .59771 m
.51542 .59772 L
s
.51543 .5977 m
.51543 .59771 L
s
.51542 .59772 m
.51541 .5977 L
s
.51541 .5977 m
.51543 .5977 L
s
.51543 .5977 m
.51542 .59772 L
s
1 0 0 r
.95649 .57344 m
.95649 .57343 L
s
.95649 .57343 m
.95649 .57343 L
s
.95649 .57343 m
.95649 .57343 L
s
.95649 .57343 m
.95649 .57343 L
s
.95649 .57343 m
.95649 .57344 L
s
.95649 .57343 m
.95649 .57343 L
s
.95649 .57344 m
.95649 .57343 L
s
.95649 .57343 m
.95649 .57343 L
s
.95649 .57343 m
.95649 .57344 L
s
1 .002 0 r
.32013 .54913 m
.32026 .54909 L
s
.32024 .54911 m
.32023 .54911 L
s
.32023 .54908 m
.32024 .54911 L
s
.32026 .54909 m
.32024 .54911 L
s
.32022 .54908 m
.32023 .54908 L
s
.32023 .54908 m
.32026 .54909 L
s
.32026 .54909 m
.32023 .54911 L
s
.32022 .54908 m
.32026 .54909 L
s
.32023 .54911 m
.32022 .54908 L
s
1 0 0 r
.76126 .52482 m
.76126 .52482 L
s
.76126 .52482 m
.76126 .52482 L
s
.76126 .52482 m
.76126 .52482 L
s
.76126 .52482 m
.76126 .52482 L
s
.76126 .52482 m
.76126 .52482 L
s
.76126 .52482 m
.76126 .52482 L
s
.76126 .52482 m
.76126 .52482 L
s
.76126 .52482 m
.76126 .52482 L
s
.76126 .52482 m
.76126 .52482 L
s
1 .004 0 r
.6065 .74277 m
.60666 .74266 L
s
.60663 .74265 m
.60666 .74269 L
s
.6066 .74267 m
.60663 .74265 L
s
.60663 .74265 m
.60666 .74266 L
s
.60666 .74269 m
.60663 .74271 L
s
.60666 .74266 m
.60666 .74269 L
s
1 0 0 r
.566 .4762 m
.566 .4762 L
s
.566 .4762 m
.566 .4762 L
s
.566 .4762 m
.566 .4762 L
s
.566 .4762 m
.566 .4762 L
s
.566 .4762 m
.566 .4762 L
s
.566 .4762 m
.566 .4762 L
s
.566 .4762 m
.566 .4762 L
s
.566 .4762 m
.566 .4762 L
s
.566 .4762 m
.566 .4762 L
s
1 .004 0 r
.60663 .74271 m
.6066 .74267 L
s
.6066 .74267 m
.60666 .74266 L
s
.60666 .74266 m
.60663 .74271 L
s
1 .008 0 r
.41123 .69416 m
.41165 .69399 L
s
1 0 0 r
.85243 .66985 m
.85245 .66983 L
s
.85245 .66983 m
.85245 .66984 L
s
.85244 .66984 m
.85245 .66983 L
s
.85245 .66983 m
.85245 .66983 L
s
.85245 .66984 m
.85245 .66984 L
s
.85245 .66983 m
.85245 .66984 L
s
.85245 .66984 m
.85244 .66984 L
s
.85244 .66984 m
.85245 .66983 L
s
.85245 .66983 m
.85245 .66984 L
s
1 .008 0 r
.41162 .69406 m
.41157 .69409 L
s
.41157 .69396 m
.41162 .69406 L
s
.41165 .69399 m
.41162 .69406 L
s
.41152 .69399 m
.41157 .69396 L
s
.41157 .69396 m
.41165 .69399 L
s
.41157 .69409 m
.41152 .69399 L
s
.41165 .69399 m
.41157 .69409 L
s
.41152 .69399 m
.41165 .69399 L
s
1 .001 0 r
.65715 .62123 m
.65718 .62121 L
s
.65717 .62121 m
.65718 .62121 L
s
.65717 .62121 m
.65717 .62121 L
s
.65717 .62121 m
.65718 .62121 L
s
.65718 .62121 m
.65717 .62122 L
s
.65718 .62121 m
.65718 .62121 L
s
.65717 .62122 m
.65717 .62121 L
s
.65717 .62121 m
.65718 .62121 L
s
.65718 .62121 m
.65717 .62122 L
s
.46184 .57261 m
.46189 .57257 L
s
.46188 .57257 m
.46189 .57258 L
s
.46187 .57257 m
.46188 .57257 L
s
.46188 .57257 m
.46189 .57257 L
s
.46189 .57258 m
.46188 .57259 L
s
.46189 .57257 m
.46189 .57258 L
s
.46188 .57259 m
.46187 .57257 L
s
.46187 .57257 m
.46189 .57257 L
s
.46189 .57257 m
.46188 .57259 L
s
1 0 0 r
.90314 .54829 m
.90314 .54829 L
s
.90314 .54829 m
.90314 .54829 L
s
.90314 .54829 m
.90314 .54829 L
s
.90314 .54829 m
.90314 .54829 L
s
.90314 .54829 m
.90314 .54829 L
s
.90314 .54829 m
.90314 .54829 L
s
.90314 .54829 m
.90314 .54829 L
s
.90314 .54829 m
.90314 .54829 L
s
.90314 .54829 m
.90314 .54829 L
s
1 .002 0 r
.74833 .76631 m
.74842 .76625 L
s
.7484 .76624 m
.74842 .76627 L
s
.74838 .76626 m
.7484 .76624 L
s
.7484 .76624 m
.74842 .76625 L
s
.74842 .76627 m
.7484 .76628 L
s
.74842 .76625 m
.74842 .76627 L
s
.7484 .76628 m
.74838 .76626 L
s
.74838 .76626 m
.74842 .76625 L
s
.74842 .76625 m
.7484 .76628 L
s
1 0 0 r
.70782 .49965 m
.70782 .49965 L
s
.70782 .49965 m
.70782 .49965 L
s
.70782 .49965 m
.70782 .49965 L
s
.70782 .49965 m
.70782 .49965 L
s
.70782 .49965 m
.70782 .49965 L
s
.70782 .49965 m
.70782 .49965 L
s
.70782 .49965 m
.70782 .49965 L
s
.70782 .49965 m
.70782 .49965 L
s
.70782 .49965 m
.70782 .49965 L
s
1 .004 0 r
.55299 .71769 m
.55318 .71758 L
s
.55315 .71756 m
.55318 .71761 L
s
.55312 .71758 m
.55315 .71756 L
s
.55315 .71756 m
.55318 .71758 L
s
.55318 .71761 m
.55315 .71763 L
s
.55318 .71758 m
.55318 .71761 L
s
.55315 .71763 m
.55312 .71758 L
s
.55312 .71758 m
.55318 .71758 L
s
.55318 .71758 m
.55315 .71763 L
s
1 .009 0 r
.35763 .66906 m
.35815 .66889 L
s
1 0 0 r
.79903 .64474 m
.79904 .64472 L
s
.79904 .64472 m
.79905 .64473 L
s
.79904 .64473 m
.79904 .64472 L
s
.79904 .64472 m
.79904 .64472 L
s
.79905 .64473 m
.79904 .64473 L
s
.79904 .64472 m
.79905 .64473 L
s
1 .009 0 r
.3581 .66897 m
.35805 .669 L
s
.35805 .66885 m
.3581 .66897 L
s
.35815 .66889 m
.3581 .66897 L
s
1 0 0 r
.79904 .64473 m
.79904 .64473 L
s
.79904 .64473 m
.79904 .64472 L
s
.79904 .64472 m
.79904 .64473 L
s
1 .009 0 r
.358 .66888 m
.35805 .66885 L
s
.35805 .66885 m
.35815 .66889 L
s
.35815 .66889 m
.35805 .669 L
s
.358 .66888 m
.35815 .66889 L
s
.35805 .669 m
.358 .66888 L
s
1 .001 0 r
.60366 .5961 m
.60368 .59607 L
s
.60368 .59607 m
.60368 .59608 L
s
.60367 .59608 m
.60368 .59607 L
s
.60368 .59607 m
.60368 .59607 L
s
.60368 .59608 m
.60368 .59608 L
s
.60368 .59607 m
.60368 .59608 L
s
.60368 .59608 m
.60367 .59608 L
s
.60367 .59608 m
.60368 .59607 L
s
.60368 .59607 m
.60368 .59608 L
s
1 .011 0 r
.44879 .8142 m
.4494 .81398 L
s
1 .001 0 r
.40825 .54745 m
.4083 .54742 L
s
.40829 .54741 m
.4083 .54743 L
s
.40828 .54742 m
.40829 .54741 L
s
.40829 .54741 m
.4083 .54742 L
s
.4083 .54743 m
.40829 .54743 L
s
.4083 .54742 m
.4083 .54743 L
s
.40829 .54743 m
.40828 .54742 L
s
.40828 .54742 m
.4083 .54742 L
s
.4083 .54742 m
.40829 .54743 L
s
1 .011 0 r
.44934 .81407 m
.44928 .81412 L
s
.44928 .81393 m
.44934 .81407 L
s
.4494 .81398 m
.44934 .81407 L
s
.44922 .81398 m
.44928 .81393 L
s
.44928 .81393 m
.4494 .81398 L
s
1 0 0 r
.84975 .52312 m
.84975 .52312 L
s
.84975 .52312 m
.84975 .52312 L
s
.84975 .52312 m
.84975 .52312 L
s
.84975 .52312 m
.84975 .52312 L
s
.84975 .52312 m
.84975 .52312 L
s
.84975 .52312 m
.84975 .52312 L
s
.84975 .52312 m
.84975 .52312 L
s
.84975 .52312 m
.84975 .52312 L
s
.84975 .52312 m
.84975 .52312 L
s
1 .011 0 r
.44928 .81412 m
.44922 .81398 L
s
.4494 .81398 m
.44928 .81412 L
s
.44922 .81398 m
.4494 .81398 L
s
1 .002 0 r
.69487 .74124 m
.69496 .74117 L
s
.69494 .74116 m
.69496 .74119 L
s
.69492 .74118 m
.69494 .74116 L
s
.69494 .74116 m
.69496 .74117 L
s
.69496 .74119 m
.69494 .7412 L
s
.69496 .74117 m
.69496 .74119 L
s
.69494 .7412 m
.69492 .74118 L
s
.69492 .74118 m
.69496 .74117 L
s
.69496 .74117 m
.69494 .7412 L
s
1 0 0 r
.65434 .47445 m
.65434 .47445 L
s
.65434 .47445 m
.65434 .47445 L
s
.65434 .47445 m
.65434 .47445 L
s
.65434 .47445 m
.65434 .47445 L
s
.65434 .47445 m
.65434 .47445 L
s
.65434 .47445 m
.65434 .47445 L
s
.65434 .47445 m
.65434 .47445 L
s
.65434 .47445 m
.65434 .47445 L
s
.65434 .47445 m
.65434 .47445 L
s
1 .005 0 r
.49944 .69259 m
.49967 .69247 L
s
.49962 .69245 m
.49966 .69251 L
s
.49959 .69247 m
.49962 .69245 L
s
.49962 .69245 m
.49967 .69247 L
s
.49966 .69251 m
.49962 .69253 L
s
.49967 .69247 m
.49966 .69251 L
s
.49962 .69253 m
.49959 .69247 L
s
.49959 .69247 m
.49967 .69247 L
s
.49967 .69247 m
.49962 .69253 L
s
1 0 0 r
.74558 .61961 m
.74559 .61959 L
s
.74559 .61959 m
.74559 .6196 L
s
.74558 .61959 m
.74559 .61959 L
s
.74559 .61959 m
.74559 .61959 L
s
.74559 .6196 m
.74559 .6196 L
s
.74559 .61959 m
.74559 .6196 L
s
.74559 .6196 m
.74558 .61959 L
s
.74558 .61959 m
.74559 .61959 L
s
.74559 .61959 m
.74559 .6196 L
s
1 .001 0 r
.55011 .57094 m
.55013 .57092 L
s
.55013 .57092 m
.55013 .57093 L
s
.55012 .57092 m
.55013 .57092 L
s
.55013 .57092 m
.55013 .57092 L
s
.55013 .57093 m
.55013 .57093 L
s
.55013 .57092 m
.55013 .57093 L
s
.55013 .57093 m
.55012 .57092 L
s
.55012 .57092 m
.55013 .57092 L
s
.55013 .57092 m
.55013 .57093 L
s
1 .013 0 r
.39517 .78914 m
.39593 .78891 L
s
1 .001 0 r
.35461 .52227 m
.35465 .52225 L
s
.35465 .52225 m
.35464 .52226 L
s
.35465 .52224 m
.35465 .52225 L
s
.35465 .52225 m
.35465 .52225 L
s
.35464 .52225 m
.35465 .52224 L
s
.35465 .52224 m
.35465 .52225 L
s
.35464 .52226 m
.35464 .52225 L
s
.35465 .52225 m
.35464 .52226 L
s
.35464 .52225 m
.35465 .52225 L
s
1 .013 0 r
.39584 .78901 m
.39577 .78907 L
s
.39578 .78885 m
.39584 .78901 L
s
.39593 .78891 m
.39584 .78901 L
s
.39571 .7889 m
.39578 .78885 L
s
.39578 .78885 m
.39593 .78891 L
s
1 0 0 r
.79631 .49793 m
.79631 .49793 L
s
.79631 .49793 m
.79631 .49793 L
s
.79631 .49793 m
.79631 .49793 L
s
.79631 .49793 m
.79631 .49793 L
s
.79631 .49793 m
.79631 .49793 L
s
.79631 .49793 m
.79631 .49793 L
s
.79631 .49793 m
.79631 .49793 L
s
.79631 .49793 m
.79631 .49793 L
s
.79631 .49793 m
.79631 .49793 L
s
1 .013 0 r
.39593 .78891 m
.39577 .78907 L
s
.39571 .7889 m
.39593 .78891 L
s
1 .003 0 r
.64135 .71614 m
.64146 .71607 L
s
1 .013 0 r
.39577 .78907 m
.39571 .7889 L
s
1 .003 0 r
.64144 .71606 m
.64146 .71609 L
s
.64142 .71607 m
.64144 .71606 L
s
.64144 .71606 m
.64146 .71607 L
s
.64146 .71609 m
.64144 .7161 L
s
.64146 .71607 m
.64146 .71609 L
s
.64144 .7161 m
.64142 .71607 L
s
.64142 .71607 m
.64146 .71607 L
s
.64146 .71607 m
.64144 .7161 L
s
1 .005 0 r
.44583 .66747 m
.44611 .66733 L
s
1 0 0 r
.8876 .64314 m
.88761 .64312 L
s
.88761 .64312 m
.88761 .64313 L
s
.88761 .64313 m
.88761 .64312 L
s
.88761 .64312 m
.88761 .64312 L
s
.88761 .64313 m
.88761 .64313 L
s
.88761 .64312 m
.88761 .64313 L
s
1 .005 0 r
.44609 .66738 m
.44606 .66741 L
s
.44606 .66732 m
.44609 .66738 L
s
.44611 .66733 m
.44609 .66738 L
s
1 0 0 r
.88761 .64313 m
.88761 .64313 L
s
.88761 .64313 m
.88761 .64312 L
s
1 .005 0 r
.44602 .66734 m
.44606 .66732 L
s
.44606 .66732 m
.44611 .66733 L
s
1 0 0 r
.88761 .64312 m
.88761 .64313 L
s
1 .005 0 r
.44606 .66741 m
.44602 .66734 L
s
.44611 .66733 m
.44606 .66741 L
s
.44602 .66734 m
.44611 .66733 L
s
1 0 0 r
.69208 .59445 m
.69209 .59444 L
s
.69209 .59444 m
.69209 .59444 L
s
.69208 .59444 m
.69209 .59444 L
s
.69209 .59444 m
.69209 .59444 L
s
.69209 .59444 m
.69209 .59444 L
s
.69209 .59444 m
.69209 .59444 L
s
.69209 .59444 m
.69208 .59444 L
s
.69208 .59444 m
.69209 .59444 L
s
.69209 .59444 m
.69209 .59444 L
s
1 .007 0 r
.53708 .81273 m
.53747 .81255 L
s
1 0 0 r
.49652 .54576 m
.49654 .54575 L
s
.49653 .54574 m
.49654 .54575 L
s
.49653 .54575 m
.49653 .54574 L
s
.49653 .54574 m
.49654 .54575 L
s
.49654 .54575 m
.49653 .54575 L
s
.49654 .54575 m
.49654 .54575 L
s
.49653 .54575 m
.49653 .54575 L
s
.49653 .54575 m
.49654 .54575 L
s
.49654 .54575 m
.49653 .54575 L
s
1 .007 0 r
.53739 .81252 m
.53744 .81261 L
s
.53734 .81255 m
.53739 .81252 L
s
.53739 .81252 m
.53747 .81255 L
s
.53744 .81261 m
.53739 .81265 L
s
.53747 .81255 m
.53744 .81261 L
s
1 0 0 r
.93838 .52141 m
.93838 .52141 L
s
.93838 .52141 m
.93838 .52141 L
s
.93838 .52141 m
.93838 .52141 L
s
.93838 .52141 m
.93838 .52141 L
s
.93838 .52141 m
.93838 .52141 L
s
.93838 .52141 m
.93838 .52141 L
s
.93838 .52141 m
.93838 .52141 L
s
.93838 .52141 m
.93838 .52141 L
s
.93838 .52141 m
.93838 .52141 L
s
1 .007 0 r
.53739 .81265 m
.53734 .81255 L
s
.53734 .81255 m
.53747 .81255 L
s
.53747 .81255 m
.53739 .81265 L
s
1 .001 0 r
.78337 .73971 m
.78343 .73967 L
s
1 0 0 r
.30093 .49706 m
.30095 .49706 L
s
.30094 .49706 m
.30094 .49706 L
s
.30094 .49706 m
.30094 .49706 L
s
.30095 .49706 m
.30094 .49706 L
s
.30094 .49706 m
.30094 .49706 L
s
.30094 .49706 m
.30095 .49706 L
s
.30095 .49706 m
.30094 .49706 L
s
.30094 .49706 m
.30095 .49706 L
s
.30094 .49706 m
.30094 .49706 L
s
1 .001 0 r
.78342 .73966 m
.78343 .73968 L
s
.78341 .73967 m
.78342 .73966 L
s
.78342 .73966 m
.78343 .73967 L
s
.78343 .73968 m
.78342 .73969 L
s
.78343 .73967 m
.78343 .73968 L
s
.78342 .73969 m
.78341 .73967 L
s
.78341 .73967 m
.78343 .73967 L
s
.78343 .73967 m
.78342 .73969 L
s
1 0 0 r
.74282 .47271 m
.74282 .47271 L
s
.74282 .47271 m
.74282 .47271 L
s
.74282 .47271 m
.74282 .47271 L
s
.74282 .47271 m
.74282 .47271 L
s
.74282 .47271 m
.74282 .47271 L
s
.74282 .47271 m
.74282 .47271 L
s
.74282 .47271 m
.74282 .47271 L
s
.74282 .47271 m
.74282 .47271 L
s
.74282 .47271 m
.74282 .47271 L
s
1 .003 0 r
.58779 .69103 m
.58791 .69094 L
s
.58789 .69093 m
.58791 .69097 L
s
.58787 .69095 m
.58789 .69093 L
s
.58789 .69093 m
.58791 .69094 L
s
.58791 .69097 m
.58789 .69098 L
s
.58791 .69094 m
.58791 .69097 L
s
.58789 .69098 m
.58787 .69095 L
s
.58787 .69095 m
.58791 .69094 L
s
.58791 .69094 m
.58789 .69098 L
s
1 .006 0 r
.39218 .64233 m
.39253 .64219 L
s
1 0 0 r
.83414 .61798 m
.83415 .61797 L
s
.83415 .61797 m
.83415 .61797 L
s
.83415 .61797 m
.83415 .61797 L
s
.83415 .61797 m
.83415 .61797 L
s
1 .006 0 r
.3925 .64224 m
.39246 .64227 L
s
.39246 .64216 m
.3925 .64224 L
s
.39253 .64219 m
.3925 .64224 L
s
1 0 0 r
.83415 .61797 m
.83415 .61798 L
s
.83415 .61797 m
.83415 .61797 L
s
.83415 .61798 m
.83415 .61797 L
s
.83415 .61797 m
.83415 .61797 L
s
.83415 .61797 m
.83415 .61798 L
s
1 .006 0 r
.39242 .64219 m
.39246 .64216 L
s
.39246 .64216 m
.39253 .64219 L
s
.39246 .64227 m
.39242 .64219 L
s
.39253 .64219 m
.39246 .64227 L
s
.39242 .64219 m
.39253 .64219 L
s
1 0 0 r
.63853 .56927 m
.63854 .56926 L
s
.63854 .56926 m
.63854 .56927 L
s
.63853 .56926 m
.63854 .56926 L
s
.63854 .56926 m
.63854 .56926 L
s
.63854 .56927 m
.63854 .56927 L
s
.63854 .56926 m
.63854 .56927 L
s
.63854 .56927 m
.63853 .56926 L
s
.63853 .56926 m
.63854 .56926 L
s
.63854 .56926 m
.63854 .56927 L
s
1 .009 0 r
.48346 .78765 m
.48394 .78744 L
s
1 0 0 r
.44288 .52056 m
.44289 .52055 L
s
.44289 .52055 m
.44289 .52055 L
s
.44289 .52055 m
.44289 .52055 L
s
.44289 .52055 m
.44289 .52055 L
s
.44289 .52055 m
.44289 .52055 L
s
.44289 .52055 m
.44289 .52055 L
s
.44289 .52055 m
.44289 .52055 L
s
.44289 .52055 m
.44289 .52055 L
s
.44289 .52055 m
.44289 .52055 L
s
1 .009 0 r
.4839 .78752 m
.48384 .78756 L
s
.48384 .78741 m
.4839 .78752 L
s
.48394 .78744 m
.4839 .78752 L
s
.48378 .78745 m
.48384 .78741 L
s
.48384 .78741 m
.48394 .78744 L
s
1 0 0 r
.88493 .4962 m
.88493 .4962 L
s
.88493 .4962 m
.88493 .4962 L
s
.88493 .4962 m
.88493 .4962 L
s
.88493 .4962 m
.88493 .4962 L
s
.88493 .4962 m
.88493 .4962 L
s
.88493 .4962 m
.88493 .4962 L
s
.88493 .4962 m
.88493 .4962 L
s
.88493 .4962 m
.88493 .4962 L
s
.88493 .4962 m
.88493 .4962 L
s
1 .009 0 r
.48384 .78756 m
.48378 .78745 L
s
.48394 .78744 m
.48384 .78756 L
s
.48378 .78745 m
.48394 .78744 L
s
1 .002 0 r
.72986 .7146 m
.72992 .71454 L
s
.72991 .71454 m
.72992 .71456 L
s
.72989 .71455 m
.72991 .71454 L
s
.72991 .71454 m
.72992 .71454 L
s
.72992 .71456 m
.72991 .71457 L
s
.72992 .71454 m
.72992 .71456 L
s
.72991 .71457 m
.72989 .71455 L
s
.72989 .71455 m
.72992 .71454 L
s
.72992 .71454 m
.72991 .71457 L
s
1 .003 0 r
.53419 .66589 m
.53433 .66579 L
s
.5343 .66578 m
.53432 .66582 L
s
.53427 .6658 m
.5343 .66578 L
s
.5343 .66578 m
.53433 .66579 L
s
.53432 .66582 m
.5343 .66584 L
s
.53433 .66579 m
.53432 .66582 L
s
.5343 .66584 m
.53427 .6658 L
s
.53427 .6658 m
.53433 .66579 L
s
.53433 .66579 m
.5343 .66584 L
s
1 .007 0 r
.33848 .61717 m
.3389 .61703 L
s
.33886 .61709 m
.33881 .61711 L
s
.33882 .617 m
.33886 .61709 L
s
.3389 .61703 m
.33886 .61709 L
s
.33878 .61702 m
.33882 .617 L
s
.33882 .617 m
.3389 .61703 L
s
1 0 0 r
.78064 .5928 m
.78065 .5928 L
s
.78065 .5928 m
.78065 .5928 L
s
.78064 .5928 m
.78065 .5928 L
s
.78065 .5928 m
.78065 .5928 L
s
.78065 .5928 m
.78065 .5928 L
s
.78065 .5928 m
.78065 .5928 L
s
.78065 .5928 m
.78064 .5928 L
s
.78064 .5928 m
.78065 .5928 L
s
.78065 .5928 m
.78065 .5928 L
s
1 .007 0 r
.3389 .61703 m
.33881 .61711 L
s
.33878 .61702 m
.3389 .61703 L
s
.33881 .61711 m
.33878 .61702 L
s
1 .005 0 r
.62552 .81126 m
.62576 .81112 L
s
1 0 0 r
.58493 .54407 m
.58494 .54406 L
s
.58494 .54406 m
.58494 .54407 L
s
.58493 .54407 m
.58494 .54406 L
s
.58494 .54406 m
.58494 .54406 L
s
.58494 .54407 m
.58494 .54407 L
s
.58494 .54406 m
.58494 .54407 L
s
.58494 .54407 m
.58493 .54407 L
s
.58493 .54407 m
.58494 .54406 L
s
.58494 .54406 m
.58494 .54407 L
s
1 .005 0 r
.62571 .8111 m
.62575 .81116 L
s
.62567 .81113 m
.62571 .8111 L
s
.62571 .8111 m
.62576 .81112 L
s
.62575 .81116 m
.62571 .81119 L
s
.62576 .81112 m
.62575 .81116 L
s
.62571 .81119 m
.62567 .81113 L
s
.62567 .81113 m
.62576 .81112 L
s
.62576 .81112 m
.62571 .81119 L
s
1 .01 0 r
.42979 .76254 m
.43038 .76232 L
s
1 0 0 r
.38919 .49533 m
.38919 .49533 L
s
.38919 .49533 m
.38919 .49533 L
s
.38919 .49533 m
.38919 .49533 L
s
.38919 .49533 m
.38919 .49533 L
s
.38919 .49533 m
.38919 .49533 L
s
.38919 .49533 m
.38919 .49533 L
s
.38919 .49533 m
.38919 .49533 L
s
.38919 .49533 m
.38919 .49533 L
s
.38919 .49533 m
.38919 .49533 L
s
1 .01 0 r
.43033 .76241 m
.43026 .76246 L
s
.43027 .76228 m
.43033 .76241 L
s
.43038 .76232 m
.43033 .76241 L
s
.4302 .76232 m
.43027 .76228 L
s
.43027 .76228 m
.43038 .76232 L
s
1 0 0 r
.83144 .47096 m
.83144 .47096 L
s
.83144 .47096 m
.83144 .47096 L
s
.83144 .47096 m
.83144 .47096 L
s
.83144 .47096 m
.83144 .47096 L
s
.83144 .47096 m
.83144 .47096 L
s
.83144 .47096 m
.83144 .47096 L
s
.83144 .47096 m
.83144 .47096 L
s
.83144 .47096 m
.83144 .47096 L
s
.83144 .47096 m
.83144 .47096 L
s
1 .01 0 r
.43026 .76246 m
.4302 .76232 L
s
.43038 .76232 m
.43026 .76246 L
s
.4302 .76232 m
.43038 .76232 L
s
1 .002 0 r
.67629 .68946 m
.67636 .6894 L
s
.67635 .6894 m
.67636 .68942 L
s
.67633 .68941 m
.67635 .6894 L
s
.67635 .6894 m
.67636 .6894 L
s
.67636 .68942 m
.67635 .68943 L
s
.67636 .6894 m
.67636 .68942 L
s
.67635 .68943 m
.67633 .68941 L
s
.67633 .68941 m
.67636 .6894 L
s
.67636 .6894 m
.67635 .68943 L
s
1 .004 0 r
.48053 .64072 m
.48069 .64062 L
s
.48066 .64061 m
.48069 .64065 L
s
.48063 .64063 m
.48066 .64061 L
s
.48066 .64061 m
.48069 .64062 L
s
.48069 .64065 m
.48066 .64067 L
s
.48069 .64062 m
.48069 .64065 L
s
1 0 0 r
.92286 .61635 m
.92286 .61634 L
s
.92286 .61634 m
.92286 .61635 L
s
.92286 .61635 m
.92286 .61634 L
s
.92286 .61634 m
.92286 .61634 L
s
.92286 .61635 m
.92286 .61635 L
s
.92286 .61634 m
.92286 .61635 L
s
.92286 .61635 m
.92286 .61635 L
s
.92286 .61635 m
.92286 .61634 L
s
.92286 .61634 m
.92286 .61635 L
s
1 .004 0 r
.48066 .64067 m
.48063 .64063 L
s
.48063 .64063 m
.48069 .64062 L
s
.48069 .64062 m
.48066 .64067 L
s
1 0 0 r
.72709 .5676 m
.72709 .5676 L
s
.72709 .5676 m
.72709 .5676 L
s
.72709 .5676 m
.72709 .5676 L
s
.72709 .5676 m
.72709 .5676 L
s
.72709 .5676 m
.72709 .5676 L
s
.72709 .5676 m
.72709 .5676 L
s
.72709 .5676 m
.72709 .5676 L
s
.72709 .5676 m
.72709 .5676 L
s
.72709 .5676 m
.72709 .5676 L
s
1 .006 0 r
.5719 .78616 m
.57218 .786 L
s
1 0 0 r
.53129 .51885 m
.53129 .51884 L
s
.53129 .51884 m
.53129 .51885 L
s
.53129 .51885 m
.53129 .51884 L
s
.53129 .51884 m
.53129 .51884 L
s
.53129 .51885 m
.53129 .51885 L
s
.53129 .51884 m
.53129 .51885 L
s
.53129 .51885 m
.53129 .51885 L
s
.53129 .51885 m
.53129 .51884 L
s
.53129 .51884 m
.53129 .51885 L
s
1 .006 0 r
.57213 .78598 m
.57217 .78605 L
s
.57208 .78601 m
.57213 .78598 L
s
.57213 .78598 m
.57218 .786 L
s
.57217 .78605 m
.57213 .78608 L
s
.57218 .786 m
.57217 .78605 L
s
.57213 .78608 m
.57208 .78601 L
s
.57208 .78601 m
.57218 .786 L
s
.57218 .786 m
.57213 .78608 L
s
1 .012 0 r
.37608 .73742 m
.37681 .73719 L
s
1 .001 0 r
.81851 .71304 m
.81854 .71301 L
s
1 0 0 r
.33545 .47009 m
.33545 .47009 L
s
.33545 .47009 m
.33545 .47009 L
s
.33545 .47009 m
.33545 .47009 L
s
.33545 .47009 m
.33545 .47009 L
s
.33545 .47009 m
.33545 .47009 L
s
.33545 .47009 m
.33545 .47009 L
s
.33545 .47009 m
.33545 .47009 L
s
.33545 .47009 m
.33545 .47009 L
s
.33545 .47009 m
.33545 .47009 L
s
1 .001 0 r
.81854 .71301 m
.81855 .71302 L
s
.81853 .71301 m
.81854 .71301 L
s
.81854 .71301 m
.81854 .71301 L
s
.81855 .71302 m
.81854 .71303 L
s
.81854 .71301 m
.81855 .71302 L
s
.81854 .71303 m
.81853 .71301 L
s
.81853 .71301 m
.81854 .71301 L
s
.81854 .71301 m
.81854 .71303 L
s
1 .012 0 r
.37673 .73729 m
.37666 .73734 L
s
.37667 .73713 m
.37673 .73729 L
s
.37681 .73719 m
.37673 .73729 L
s
.3766 .73718 m
.37667 .73713 L
s
.37667 .73713 m
.37681 .73719 L
s
.37681 .73719 m
.37666 .73734 L
s
.3766 .73718 m
.37681 .73719 L
s
.37666 .73734 m
.3766 .73718 L
s
1 .002 0 r
.62268 .66429 m
.62275 .66424 L
s
.62274 .66423 m
.62275 .66425 L
s
.62272 .66424 m
.62274 .66423 L
s
.62274 .66423 m
.62275 .66424 L
s
.62275 .66425 m
.62274 .66426 L
s
.62275 .66424 m
.62275 .66425 L
s
.62274 .66426 m
.62272 .66424 L
s
.62272 .66424 m
.62275 .66424 L
s
.62275 .66424 m
.62274 .66426 L
s
1 .004 0 r
.42682 .61554 m
.42702 .61543 L
s
.42698 .61542 m
.42701 .61547 L
s
.42695 .61543 m
.42698 .61542 L
s
.42698 .61542 m
.42702 .61543 L
s
.42701 .61547 m
.42698 .61548 L
s
.42702 .61543 m
.42701 .61547 L
s
1 0 0 r
.86935 .59115 m
.86935 .59115 L
s
.86935 .59115 m
.86935 .59115 L
s
.86935 .59115 m
.86935 .59115 L
s
.86935 .59115 m
.86935 .59115 L
s
.86935 .59115 m
.86935 .59115 L
s
.86935 .59115 m
.86935 .59115 L
s
.86935 .59115 m
.86935 .59115 L
s
.86935 .59115 m
.86935 .59115 L
s
.86935 .59115 m
.86935 .59115 L
s
1 .004 0 r
.42698 .61548 m
.42695 .61543 L
s
.42695 .61543 m
.42702 .61543 L
s
.42702 .61543 m
.42698 .61548 L
s
1 .003 0 r
.71411 .80979 m
.71425 .80969 L
s
.71422 .80968 m
.71425 .80972 L
s
.7142 .8097 m
.71422 .80968 L
s
.71422 .80968 m
.71425 .80969 L
s
.71425 .80972 m
.71423 .80974 L
s
.71425 .80969 m
.71425 .80972 L
s
1 0 0 r
.67349 .54238 m
.67349 .54238 L
s
.67349 .54238 m
.67349 .54238 L
s
.67349 .54238 m
.67349 .54238 L
s
.67349 .54238 m
.67349 .54238 L
s
.67349 .54238 m
.67349 .54238 L
s
.67349 .54238 m
.67349 .54238 L
s
.67349 .54238 m
.67349 .54238 L
s
.67349 .54238 m
.67349 .54238 L
s
.67349 .54238 m
.67349 .54238 L
s
1 .003 0 r
.71423 .80974 m
.7142 .8097 L
s
.7142 .8097 m
.71425 .80969 L
s
.71425 .80969 m
.71423 .80974 L
s
1 .007 0 r
.51823 .76103 m
.51857 .76085 L
s
1 0 0 r
.47759 .4936 m
.47759 .4936 L
s
.47759 .4936 m
.47759 .4936 L
s
.47759 .4936 m
.47759 .4936 L
s
.47759 .4936 m
.47759 .4936 L
s
.47759 .4936 m
.47759 .4936 L
s
.47759 .4936 m
.47759 .4936 L
s
.47759 .4936 m
.47759 .4936 L
s
.47759 .4936 m
.47759 .4936 L
s
.47759 .4936 m
.47759 .4936 L
s
1 .007 0 r
.5185 .76083 m
.51855 .76092 L
s
.51845 .76086 m
.5185 .76083 L
s
.5185 .76083 m
.51857 .76085 L
s
.51855 .76092 m
.5185 .76095 L
s
.51857 .76085 m
.51855 .76092 L
s
1 0 0 r
.92021 .46921 m
.92021 .46921 L
s
.92021 .46921 m
.92021 .46921 L
s
.92021 .46921 m
.92021 .46921 L
s
.92021 .46921 m
.92021 .46921 L
s
.92021 .46921 m
.92021 .46921 L
s
.92021 .46921 m
.92021 .46921 L
s
.92021 .46921 m
.92021 .46921 L
s
.92021 .46921 m
.92021 .46921 L
s
.92021 .46921 m
.92021 .46921 L
s
1 .007 0 r
.5185 .76095 m
.51845 .76086 L
s
.51845 .76086 m
.51857 .76085 L
s
.51857 .76085 m
.5185 .76095 L
s
1 .001 0 r
.76494 .68788 m
.76498 .68785 L
s
.76497 .68785 m
.76498 .68786 L
s
.76496 .68785 m
.76497 .68785 L
s
.76497 .68785 m
.76498 .68785 L
s
.76498 .68786 m
.76497 .68786 L
s
.76498 .68785 m
.76498 .68786 L
s
.76497 .68786 m
.76496 .68785 L
s
.76496 .68785 m
.76498 .68785 L
s
.76498 .68785 m
.76497 .68786 L
s
1 .002 0 r
.56902 .63911 m
.5691 .63905 L
s
.56908 .63904 m
.5691 .63907 L
s
.56907 .63905 m
.56908 .63904 L
s
.56908 .63904 m
.5691 .63905 L
s
.5691 .63907 m
.56908 .63908 L
s
.5691 .63905 m
.5691 .63907 L
s
.56908 .63908 m
.56907 .63905 L
s
.56907 .63905 m
.5691 .63905 L
s
.5691 .63905 m
.56908 .63908 L
s
1 .004 0 r
.37307 .59033 m
.3733 .59022 L
s
.37329 .59026 m
.37326 .59028 L
s
.37326 .59021 m
.37329 .59026 L
s
.3733 .59022 m
.37329 .59026 L
s
.37323 .59022 m
.37326 .59021 L
s
.37326 .59021 m
.3733 .59022 L
s
1 0 0 r
.81579 .56593 m
.81579 .56593 L
s
.81579 .56593 m
.81579 .56593 L
s
.81579 .56593 m
.81579 .56593 L
s
.81579 .56593 m
.81579 .56593 L
s
.81579 .56593 m
.81579 .56593 L
s
.81579 .56593 m
.81579 .56593 L
s
.81579 .56593 m
.81579 .56593 L
s
.81579 .56593 m
.81579 .56593 L
s
.81579 .56593 m
.81579 .56593 L
s
1 .004 0 r
.37326 .59028 m
.37323 .59022 L
s
.3733 .59022 m
.37326 .59028 L
s
.37323 .59022 m
.3733 .59022 L
s
.66048 .78466 m
.66065 .78455 L
s
.66061 .78454 m
.66065 .78458 L
s
.66058 .78456 m
.66061 .78454 L
s
.66061 .78454 m
.66065 .78455 L
s
.66065 .78458 m
.66062 .78461 L
s
.66065 .78455 m
.66065 .78458 L
s
1 0 0 r
.61984 .51714 m
.61984 .51713 L
s
.61984 .51713 m
.61984 .51714 L
s
.61984 .51713 m
.61984 .51713 L
s
.61984 .51713 m
.61984 .51713 L
s
.61984 .51714 m
.61984 .51714 L
s
.61984 .51713 m
.61984 .51714 L
s
.61984 .51714 m
.61984 .51713 L
s
.61984 .51713 m
.61984 .51713 L
s
.61984 .51713 m
.61984 .51714 L
s
1 .004 0 r
.66062 .78461 m
.66058 .78456 L
s
.66058 .78456 m
.66065 .78455 L
s
.66065 .78455 m
.66062 .78461 L
s
1 .008 0 r
.4645 .73588 m
.46494 .73569 L
s
1 0 0 r
.42385 .46833 m
.42385 .46833 L
s
.42385 .46833 m
.42385 .46833 L
s
.42385 .46833 m
.42385 .46833 L
s
.42385 .46833 m
.42385 .46833 L
s
.42385 .46833 m
.42385 .46833 L
s
.42385 .46833 m
.42385 .46833 L
s
.42385 .46833 m
.42385 .46833 L
s
.42385 .46833 m
.42385 .46833 L
s
.42385 .46833 m
.42385 .46833 L
s
1 .008 0 r
.46491 .73576 m
.46485 .7358 L
s
.46485 .73565 m
.46491 .73576 L
s
.46494 .73569 m
.46491 .73576 L
s
.4648 .73569 m
.46485 .73565 L
s
.46485 .73565 m
.46494 .73569 L
s
.46485 .7358 m
.4648 .73569 L
s
.46494 .73569 m
.46485 .7358 L
s
.4648 .73569 m
.46494 .73569 L
s
1 .001 0 r
.71132 .6627 m
.71136 .66266 L
s
.71135 .66266 m
.71136 .66267 L
s
.71134 .66267 m
.71135 .66266 L
s
.71135 .66266 m
.71136 .66266 L
s
.71136 .66267 m
.71135 .66268 L
s
.71136 .66266 m
.71136 .66267 L
s
.71135 .66268 m
.71134 .66267 L
s
.71134 .66267 m
.71136 .66266 L
s
.71136 .66266 m
.71135 .66268 L
s
1 .002 0 r
.51531 .6139 m
.5154 .61384 L
s
.51538 .61383 m
.5154 .61386 L
s
.51536 .61384 m
.51538 .61383 L
s
.51538 .61383 m
.5154 .61384 L
s
.5154 .61386 m
.51538 .61387 L
s
.5154 .61384 m
.5154 .61386 L
s
.51538 .61387 m
.51536 .61384 L
s
.51536 .61384 m
.5154 .61384 L
s
.5154 .61384 m
.51538 .61387 L
s
1 0 0 r
.9582 .5895 m
.9582 .5895 L
s
.9582 .5895 m
.9582 .5895 L
s
.9582 .5895 m
.9582 .5895 L
s
.9582 .5895 m
.9582 .5895 L
s
.9582 .5895 m
.9582 .5895 L
s
.9582 .5895 m
.9582 .5895 L
s
.9582 .5895 m
.9582 .5895 L
s
.9582 .5895 m
.9582 .5895 L
s
.9582 .5895 m
.9582 .5895 L
s
1 .004 0 r
.31927 .56509 m
.31954 .565 L
s
.31951 .56504 m
.31948 .56506 L
s
.31948 .56498 m
.31951 .56504 L
s
.31954 .565 m
.31951 .56504 L
s
.31946 .565 m
.31948 .56498 L
s
.31948 .56498 m
.31954 .565 L
s
1 0 0 r
.76219 .54069 m
.76219 .54069 L
s
.76219 .54069 m
.76219 .54069 L
s
.76219 .54069 m
.76219 .54069 L
s
.76219 .54069 m
.76219 .54069 L
s
.76219 .54069 m
.76219 .54069 L
s
.76219 .54069 m
.76219 .54069 L
s
.76219 .54069 m
.76219 .54069 L
s
.76219 .54069 m
.76219 .54069 L
s
.76219 .54069 m
.76219 .54069 L
s
1 .004 0 r
.31954 .565 m
.31948 .56506 L
s
.31946 .565 m
.31954 .565 L
s
.31948 .56506 m
.31946 .565 L
s
.6068 .75952 m
.607 .75939 L
s
1 0 0 r
.56614 .49187 m
.56614 .49187 L
s
.56614 .49187 m
.56614 .49187 L
s
.56614 .49187 m
.56614 .49187 L
s
.56614 .49187 m
.56614 .49187 L
s
.56614 .49187 m
.56614 .49187 L
s
.56614 .49187 m
.56614 .49187 L
s
.56614 .49187 m
.56614 .49187 L
s
.56614 .49187 m
.56614 .49187 L
s
.56614 .49187 m
.56614 .49187 L
s
1 .004 0 r
.60696 .75938 m
.607 .75943 L
s
.60693 .7594 m
.60696 .75938 L
s
.60696 .75938 m
.607 .75939 L
s
.607 .75943 m
.60696 .75945 L
s
.607 .75939 m
.607 .75943 L
s
.60696 .75945 m
.60693 .7594 L
s
.60693 .7594 m
.607 .75939 L
s
.607 .75939 m
.60696 .75945 L
s
1 .01 0 r
.41074 .71071 m
.41128 .7105 L
s
1 .001 0 r
.85373 .68631 m
.85375 .68629 L
s
.85375 .68628 m
.85375 .68629 L
s
.85374 .68629 m
.85375 .68628 L
s
.85375 .68628 m
.85375 .68629 L
s
.85375 .68629 m
.85375 .6863 L
s
.85375 .68629 m
.85375 .68629 L
s
.85375 .6863 m
.85374 .68629 L
s
.85374 .68629 m
.85375 .68629 L
s
.85375 .68629 m
.85375 .6863 L
s
1 .01 0 r
.41123 .71058 m
.41117 .71062 L
s
.41118 .71046 m
.41123 .71058 L
s
.41128 .7105 m
.41123 .71058 L
s
.41111 .7105 m
.41118 .71046 L
s
.41118 .71046 m
.41128 .7105 L
s
.41117 .71062 m
.41111 .7105 L
s
.41128 .7105 m
.41117 .71062 L
s
.41111 .7105 m
.41128 .7105 L
s
1 .001 0 r
.65766 .63749 m
.6577 .63746 L
s
.65769 .63745 m
.6577 .63747 L
s
.65768 .63746 m
.65769 .63745 L
s
.65769 .63745 m
.6577 .63746 L
s
.6577 .63747 m
.65769 .63747 L
s
.6577 .63746 m
.6577 .63747 L
s
.65769 .63747 m
.65768 .63746 L
s
.65768 .63746 m
.6577 .63746 L
s
.6577 .63746 m
.65769 .63747 L
s
1 .002 0 r
.46155 .58867 m
.46165 .58861 L
s
.46163 .5886 m
.46165 .58863 L
s
.46161 .58861 m
.46163 .5886 L
s
.46163 .5886 m
.46165 .58861 L
s
.46165 .58863 m
.46163 .58864 L
s
.46165 .58861 m
.46165 .58863 L
s
.46163 .58864 m
.46161 .58861 L
s
.46161 .58861 m
.46165 .58861 L
s
.46165 .58861 m
.46163 .58864 L
s
1 0 0 r
.90464 .56426 m
.90464 .56425 L
s
.90464 .56425 m
.90464 .56425 L
s
.90464 .56425 m
.90464 .56425 L
s
.90464 .56425 m
.90464 .56425 L
s
.90464 .56425 m
.90464 .56426 L
s
.90464 .56425 m
.90464 .56425 L
s
.90464 .56426 m
.90464 .56425 L
s
.90464 .56425 m
.90464 .56425 L
s
.90464 .56425 m
.90464 .56426 L
s
1 .003 0 r
.7492 .78317 m
.74931 .78309 L
s
.74929 .78308 m
.74931 .78311 L
s
.74927 .7831 m
.74929 .78308 L
s
.74929 .78308 m
.74931 .78309 L
s
.74931 .78311 m
.74929 .78312 L
s
.74931 .78309 m
.74931 .78311 L
s
.74929 .78312 m
.74927 .7831 L
s
.74927 .7831 m
.74931 .78309 L
s
.74931 .78309 m
.74929 .78312 L
s
1 0 0 r
.70853 .51542 m
.70854 .51542 L
s
.70853 .51542 m
.70854 .51542 L
s
.70853 .51542 m
.70853 .51542 L
s
.70853 .51542 m
.70854 .51542 L
s
.70854 .51542 m
.70853 .51542 L
s
.70854 .51542 m
.70854 .51542 L
s
.70853 .51542 m
.70853 .51542 L
s
.70853 .51542 m
.70854 .51542 L
s
.70854 .51542 m
.70853 .51542 L
s
1 .005 0 r
.55308 .73435 m
.55332 .7342 L
s
1 0 0 r
.51239 .46658 m
.51239 .46658 L
s
.51239 .46658 m
.51239 .46658 L
s
.51239 .46658 m
.51239 .46658 L
s
.51239 .46658 m
.51239 .46658 L
s
.51239 .46658 m
.51239 .46658 L
s
.51239 .46658 m
.51239 .46658 L
s
.51239 .46658 m
.51239 .46658 L
s
.51239 .46658 m
.51239 .46658 L
s
.51239 .46658 m
.51239 .46658 L
s
1 .005 0 r
.55327 .73419 m
.55331 .73425 L
s
.55323 .73421 m
.55327 .73419 L
s
.55327 .73419 m
.55332 .7342 L
s
.55331 .73425 m
.55327 .73428 L
s
.55332 .7342 m
.55331 .73425 L
s
.55327 .73428 m
.55323 .73421 L
s
.55323 .73421 m
.55332 .7342 L
s
.55332 .7342 m
.55327 .73428 L
s
1 .012 0 r
.35692 .68552 m
.35761 .6853 L
s
1 .001 0 r
.80011 .6611 m
.80013 .66108 L
s
.80013 .66108 m
.80013 .66109 L
s
.80012 .66108 m
.80013 .66108 L
s
.80013 .66108 m
.80013 .66108 L
s
.80013 .66109 m
.80013 .66109 L
s
.80013 .66108 m
.80013 .66109 L
s
.80013 .66109 m
.80012 .66108 L
s
.80012 .66108 m
.80013 .66108 L
s
.80013 .66108 m
.80013 .66109 L
s
1 .012 0 r
.35753 .6854 m
.35747 .68544 L
s
.35748 .68525 m
.35753 .6854 L
s
.35761 .6853 m
.35753 .6854 L
s
.35741 .68529 m
.35748 .68525 L
s
.35748 .68525 m
.35761 .6853 L
s
.35761 .6853 m
.35747 .68544 L
s
.35741 .68529 m
.35761 .6853 L
s
.35747 .68544 m
.35741 .68529 L
s
1 .001 0 r
.60394 .61226 m
.60399 .61223 L
s
.60398 .61223 m
.60399 .61224 L
s
.60397 .61223 m
.60398 .61223 L
s
.60398 .61223 m
.60399 .61223 L
s
.60399 .61224 m
.60398 .61224 L
s
.60399 .61223 m
.60399 .61224 L
s
.60398 .61224 m
.60397 .61223 L
s
.60397 .61223 m
.60399 .61223 L
s
.60399 .61223 m
.60398 .61224 L
s
1 .002 0 r
.40775 .56342 m
.40785 .56335 L
s
.40783 .56335 m
.40785 .56338 L
s
.40782 .56336 m
.40783 .56335 L
s
.40783 .56335 m
.40785 .56335 L
s
.40785 .56338 m
.40783 .56339 L
s
.40785 .56335 m
.40785 .56338 L
s
.40783 .56339 m
.40782 .56336 L
s
.40782 .56336 m
.40785 .56335 L
s
.40785 .56335 m
.40783 .56339 L
s
1 0 0 r
.85103 .53899 m
.85103 .53899 L
s
.85103 .53899 m
.85103 .53899 L
s
.85103 .53899 m
.85103 .53899 L
s
.85103 .53899 m
.85103 .53899 L
s
.85103 .53899 m
.85103 .53899 L
s
.85103 .53899 m
.85103 .53899 L
s
.85103 .53899 m
.85103 .53899 L
s
.85103 .53899 m
.85103 .53899 L
s
.85103 .53899 m
.85103 .53899 L
s
1 .003 0 r
.69552 .758 m
.69564 .75791 L
s
.69562 .7579 m
.69564 .75794 L
s
.69559 .75792 m
.69562 .7579 L
s
.69562 .7579 m
.69564 .75791 L
s
.69564 .75794 m
.69562 .75795 L
s
.69564 .75791 m
.69564 .75794 L
s
.69562 .75795 m
.69559 .75792 L
s
.69559 .75792 m
.69564 .75791 L
s
.69564 .75791 m
.69562 .75795 L
s
1 0 0 r
.65483 .49013 m
.65483 .49013 L
s
.65483 .49013 m
.65483 .49013 L
s
.65483 .49013 m
.65483 .49013 L
s
.65483 .49013 m
.65483 .49013 L
s
.65483 .49013 m
.65483 .49013 L
s
.65483 .49013 m
.65483 .49013 L
s
.65483 .49013 m
.65483 .49013 L
s
.65483 .49013 m
.65483 .49013 L
s
.65483 .49013 m
.65483 .49013 L
s
1 .006 0 r
.4993 .70916 m
.4996 .70899 L
s
.49954 .70897 m
.49959 .70905 L
s
.4995 .709 m
.49954 .70897 L
s
.49954 .70897 m
.4996 .70899 L
s
.49959 .70905 m
.49954 .70908 L
s
.4996 .70899 m
.49959 .70905 L
s
.49954 .70908 m
.4995 .709 L
s
.4995 .709 m
.4996 .70899 L
s
.4996 .70899 m
.49954 .70908 L
s
1 .001 0 r
.74644 .63588 m
.74646 .63585 L
s
.74646 .63585 m
.74646 .63586 L
s
.74645 .63586 m
.74646 .63585 L
s
.74646 .63585 m
.74646 .63585 L
s
.74646 .63586 m
.74646 .63586 L
s
.74646 .63585 m
.74646 .63586 L
s
.74646 .63586 m
.74645 .63586 L
s
.74645 .63586 m
.74646 .63585 L
s
.74646 .63585 m
.74646 .63586 L
s
.55018 .58701 m
.55022 .58698 L
s
.55022 .58698 m
.55022 .58699 L
s
.55021 .58698 m
.55022 .58698 L
s
.55022 .58698 m
.55022 .58698 L
s
.55022 .58699 m
.55022 .58699 L
s
.55022 .58698 m
.55022 .58699 L
s
.55022 .58699 m
.55021 .58698 L
s
.55021 .58698 m
.55022 .58698 L
s
.55022 .58698 m
.55022 .58699 L
s
1 .015 0 r
.39461 .80609 m
.3955 .80584 L
s
1 .002 0 r
.35389 .53814 m
.354 .53809 L
s
.35399 .53811 m
.35398 .53812 L
s
.35398 .53808 m
.35399 .53811 L
s
.354 .53809 m
.35399 .53811 L
s
.35397 .53809 m
.35398 .53808 L
s
.35398 .53808 m
.354 .53809 L
s
.35398 .53812 m
.35397 .53809 L
s
.354 .53809 m
.35398 .53812 L
s
.35397 .53809 m
.354 .53809 L
s
1 .015 0 r
.3954 .80595 m
.39532 .80602 L
s
.39532 .80576 m
.3954 .80595 L
s
.3955 .80584 m
.3954 .80595 L
s
.39524 .80582 m
.39532 .80576 L
s
.39532 .80576 m
.3955 .80584 L
s
1 0 0 r
.79738 .5137 m
.79738 .5137 L
s
.79738 .5137 m
.79738 .5137 L
s
.79738 .5137 m
.79738 .5137 L
s
.79738 .5137 m
.79738 .5137 L
s
.79738 .5137 m
.79738 .5137 L
s
.79738 .5137 m
.79738 .5137 L
s
.79738 .5137 m
.79738 .5137 L
s
.79738 .5137 m
.79738 .5137 L
s
.79738 .5137 m
.79738 .5137 L
s
1 .003 0 r
.6418 .73281 m
.64193 .73271 L
s
1 .015 0 r
.3955 .80584 m
.39532 .80602 L
s
.39524 .80582 m
.3955 .80584 L
s
.39532 .80602 m
.39524 .80582 L
s
1 .003 0 r
.6419 .7327 m
.64193 .73274 L
s
.64188 .73272 m
.6419 .7327 L
s
.6419 .7327 m
.64193 .73271 L
s
.64193 .73274 m
.6419 .73276 L
s
.64193 .73271 m
.64193 .73274 L
s
1 0 0 r
.60108 .46482 m
.60108 .46482 L
s
.60108 .46482 m
.60108 .46482 L
s
.60108 .46482 m
.60108 .46482 L
s
.60108 .46482 m
.60108 .46482 L
s
.60108 .46482 m
.60108 .46482 L
s
.60108 .46482 m
.60108 .46482 L
s
.60108 .46482 m
.60108 .46482 L
s
.60108 .46482 m
.60108 .46482 L
s
.60108 .46482 m
.60108 .46482 L
s
1 .003 0 r
.6419 .73276 m
.64188 .73272 L
s
.64188 .73272 m
.64193 .73271 L
s
.64193 .73271 m
.6419 .73276 L
s
1 .007 0 r
.44548 .68394 m
.44585 .68376 L
s
1 0 0 r
.88904 .6595 m
.88905 .65949 L
s
.88905 .65949 m
.88905 .65949 L
s
.88905 .65949 m
.88905 .65949 L
s
.88905 .65949 m
.88905 .65949 L
s
.88905 .65949 m
.88905 .6595 L
s
.88905 .65949 m
.88905 .65949 L
s
.88905 .6595 m
.88905 .65949 L
s
.88905 .65949 m
.88905 .65949 L
s
.88905 .65949 m
.88905 .6595 L
s
1 .007 0 r
.44583 .68382 m
.44578 .68386 L
s
.44578 .68373 m
.44583 .68382 L
s
.44585 .68376 m
.44583 .68382 L
s
.44573 .68376 m
.44578 .68373 L
s
.44578 .68373 m
.44585 .68376 L
s
.44578 .68386 m
.44573 .68376 L
s
.44585 .68376 m
.44578 .68386 L
s
.44573 .68376 m
.44585 .68376 L
s
1 .001 0 r
.69272 .61063 m
.69274 .6106 L
s
.69274 .6106 m
.69274 .61061 L
s
.69273 .61061 m
.69274 .6106 L
s
.69274 .6106 m
.69274 .6106 L
s
.69274 .61061 m
.69274 .61061 L
s
.69274 .6106 m
.69274 .61061 L
s
.69274 .61061 m
.69273 .61061 L
s
.69273 .61061 m
.69274 .6106 L
s
.69274 .6106 m
.69274 .61061 L
s
.49637 .56174 m
.49641 .5617 L
s
.49641 .5617 m
.49641 .56172 L
s
.4964 .56171 m
.49641 .5617 L
s
.49641 .5617 m
.49641 .5617 L
s
.49641 .56172 m
.49641 .56172 L
s
.49641 .5617 m
.49641 .56172 L
s
.49641 .56172 m
.4964 .56171 L
s
.4964 .56171 m
.49641 .5617 L
s
.49641 .5617 m
.49641 .56172 L
s
1 0 0 r
.94002 .53729 m
.94002 .53729 L
s
.94002 .53729 m
.94003 .53729 L
s
.94002 .53729 m
.94002 .53729 L
s
.94002 .53729 m
.94002 .53729 L
s
.94003 .53729 m
.94002 .53729 L
s
.94002 .53729 m
.94003 .53729 L
s
.94002 .53729 m
.94002 .53729 L
s
.94002 .53729 m
.94002 .53729 L
s
.94002 .53729 m
.94002 .53729 L
s
1 .002 0 r
.78439 .75648 m
.78446 .75642 L
s
.29999 .51284 m
.30008 .51281 L
s
.30007 .51283 m
.30006 .51283 L
s
.30006 .51281 m
.30007 .51283 L
s
.30008 .51281 m
.30007 .51283 L
s
.30005 .51281 m
.30006 .51281 L
s
.30006 .51281 m
.30008 .51281 L
s
.30008 .51281 m
.30006 .51283 L
s
.30005 .51281 m
.30008 .51281 L
s
.30006 .51283 m
.30005 .51281 L
s
.78445 .75641 m
.78446 .75643 L
s
.78443 .75643 m
.78445 .75641 L
s
.78445 .75641 m
.78446 .75642 L
s
.78446 .75643 m
.78445 .75645 L
s
.78446 .75642 m
.78446 .75643 L
s
.78445 .75645 m
.78443 .75643 L
s
.78443 .75643 m
.78446 .75642 L
s
.78446 .75642 m
.78445 .75645 L
s
1 0 0 r
.74367 .48839 m
.74367 .48839 L
s
.74367 .48839 m
.74367 .48839 L
s
.74367 .48839 m
.74367 .48839 L
s
.74367 .48839 m
.74367 .48839 L
s
.74367 .48839 m
.74367 .48839 L
s
.74367 .48839 m
.74367 .48839 L
s
.74367 .48839 m
.74367 .48839 L
s
.74367 .48839 m
.74367 .48839 L
s
.74367 .48839 m
.74367 .48839 L
s
1 .004 0 r
.58802 .7076 m
.58818 .70748 L
s
.58814 .70748 m
.58817 .70752 L
s
.58812 .70749 m
.58814 .70748 L
s
.58814 .70748 m
.58818 .70748 L
s
.58817 .70752 m
.58814 .70754 L
s
.58818 .70748 m
.58817 .70752 L
s
.58814 .70754 m
.58812 .70749 L
s
.58812 .70749 m
.58818 .70748 L
s
.58818 .70748 m
.58814 .70754 L
s
1 .009 0 r
.39161 .6587 m
.39209 .65851 L
s
1 0 0 r
.83537 .63426 m
.83538 .63424 L
s
.83538 .63424 m
.83538 .63424 L
s
.83537 .63424 m
.83538 .63424 L
s
.83538 .63424 m
.83538 .63424 L
s
.83538 .63424 m
.83538 .63425 L
s
.83538 .63424 m
.83538 .63424 L
s
.83538 .63425 m
.83537 .63424 L
s
.83537 .63424 m
.83538 .63424 L
s
.83538 .63424 m
.83538 .63425 L
s
1 .009 0 r
.39205 .65858 m
.39199 .65862 L
s
.39199 .65847 m
.39205 .65858 L
s
.39209 .65851 m
.39205 .65858 L
s
.39194 .65851 m
.39199 .65847 L
s
.39199 .65847 m
.39209 .65851 L
s
.39199 .65862 m
.39194 .65851 L
s
.39209 .65851 m
.39199 .65862 L
s
.39194 .65851 m
.39209 .65851 L
s
1 .001 0 r
.63896 .58535 m
.63898 .58533 L
s
.63897 .58533 m
.63898 .58534 L
s
.63897 .58533 m
.63897 .58533 L
s
.63897 .58533 m
.63898 .58533 L
s
.63898 .58534 m
.63897 .58534 L
s
.63898 .58533 m
.63898 .58534 L
s
.63897 .58534 m
.63897 .58533 L
s
.63897 .58533 m
.63898 .58533 L
s
.63898 .58533 m
.63897 .58534 L
s
1 .01 0 r
.48326 .80461 m
.48382 .80438 L
s
1 .001 0 r
.44251 .53644 m
.44255 .53641 L
s
.44254 .53641 m
.44255 .53642 L
s
.44254 .53642 m
.44254 .53641 L
s
.44254 .53641 m
.44255 .53641 L
s
.44255 .53642 m
.44254 .53643 L
s
.44255 .53641 m
.44255 .53642 L
s
.44254 .53643 m
.44254 .53642 L
s
.44254 .53642 m
.44255 .53641 L
s
.44255 .53641 m
.44254 .53643 L
s
1 .01 0 r
.48378 .80446 m
.48371 .80451 L
s
.48371 .80433 m
.48378 .80446 L
s
.48382 .80438 m
.48378 .80446 L
s
.48364 .80438 m
.48371 .80433 L
s
.48371 .80433 m
.48382 .80438 L
s
1 0 0 r
.88636 .51198 m
.88636 .51198 L
s
.88636 .51198 m
.88636 .51198 L
s
.88636 .51198 m
.88636 .51198 L
s
.88636 .51198 m
.88636 .51198 L
s
.88636 .51198 m
.88636 .51198 L
s
.88636 .51198 m
.88636 .51198 L
s
.88636 .51198 m
.88636 .51198 L
s
.88636 .51198 m
.88636 .51198 L
s
.88636 .51198 m
.88636 .51198 L
s
1 .002 0 r
.73066 .73127 m
.73074 .7312 L
s
1 .01 0 r
.48371 .80451 m
.48364 .80438 L
s
.48382 .80438 m
.48371 .80451 L
s
.48364 .80438 m
.48382 .80438 L
s
1 .002 0 r
.73072 .7312 m
.73074 .73122 L
s
.7307 .73121 m
.73072 .7312 L
s
.73072 .7312 m
.73074 .7312 L
s
.73074 .73122 m
.73072 .73123 L
s
.73074 .7312 m
.73074 .73122 L
s
.73072 .73123 m
.7307 .73121 L
s
.7307 .73121 m
.73074 .7312 L
s
.73074 .7312 m
.73072 .73123 L
s
1 0 0 r
.68992 .46306 m
.68992 .46306 L
s
.68992 .46306 m
.68992 .46306 L
s
.68992 .46306 m
.68992 .46306 L
s
.68992 .46306 m
.68992 .46306 L
s
.68992 .46306 m
.68992 .46306 L
s
.68992 .46306 m
.68992 .46306 L
s
.68992 .46306 m
.68992 .46306 L
s
.68992 .46306 m
.68992 .46306 L
s
.68992 .46306 m
.68992 .46306 L
s
1 .004 0 r
.53419 .68236 m
.53438 .68223 L
s
.53434 .68222 m
.53438 .68227 L
s
.53431 .68224 m
.53434 .68222 L
s
.53434 .68222 m
.53438 .68223 L
s
.53438 .68227 m
.53434 .6823 L
s
.53438 .68223 m
.53438 .68227 L
s
.53434 .6823 m
.53431 .68224 L
s
.53431 .68224 m
.53438 .68223 L
s
.53438 .68223 m
.53434 .6823 L
s
1 .01 0 r
.33769 .63344 m
.3383 .63325 L
s
1 0 0 r
.78165 .60898 m
.78166 .60897 L
s
.78165 .60897 m
.78166 .60897 L
s
.78165 .60897 m
.78165 .60897 L
s
.78165 .60897 m
.78166 .60897 L
s
.78166 .60897 m
.78166 .60898 L
s
.78166 .60897 m
.78166 .60897 L
s
.78166 .60898 m
.78165 .60897 L
s
.78165 .60897 m
.78166 .60897 L
s
.78166 .60897 m
.78166 .60898 L
s
1 .01 0 r
.33823 .63334 m
.33817 .63337 L
s
.33818 .6332 m
.33823 .63334 L
s
.3383 .63325 m
.33823 .63334 L
s
.33812 .63324 m
.33818 .6332 L
s
.33818 .6332 m
.3383 .63325 L
s
.3383 .63325 m
.33817 .63337 L
s
.33812 .63324 m
.3383 .63325 L
s
.33817 .63337 m
.33812 .63324 L
s
1 0 0 r
.58514 .56006 m
.58516 .56004 L
s
.58516 .56004 m
.58516 .56004 L
s
.58515 .56004 m
.58516 .56004 L
s
.58516 .56004 m
.58516 .56004 L
s
.58516 .56004 m
.58516 .56005 L
s
.58516 .56004 m
.58516 .56004 L
s
.58516 .56005 m
.58515 .56004 L
s
.58515 .56004 m
.58516 .56004 L
s
.58516 .56004 m
.58516 .56005 L
s
1 .012 0 r
.42938 .77941 m
.43008 .77916 L
s
1 .001 0 r
.38861 .51112 m
.38864 .5111 L
s
.38863 .5111 m
.38863 .51111 L
s
.38863 .5111 m
.38863 .5111 L
s
.38863 .5111 m
.38864 .5111 L
s
.38863 .51111 m
.38863 .51111 L
s
.38864 .5111 m
.38863 .51111 L
s
.38863 .51111 m
.38863 .5111 L
s
.38863 .5111 m
.38864 .5111 L
s
.38864 .5111 m
.38863 .51111 L
s
1 .012 0 r
.43001 .77926 m
.42994 .77931 L
s
.42994 .7791 m
.43001 .77926 L
s
.43008 .77916 m
.43001 .77926 L
s
1 0 0 r
.83265 .48665 m
.83265 .48665 L
s
1 .012 0 r
.42987 .77915 m
.42994 .7791 L
s
.42994 .7791 m
.43008 .77916 L
s
1 0 0 r
.83265 .48665 m
.83265 .48665 L
s
.83265 .48665 m
.83265 .48665 L
s
.83265 .48665 m
.83265 .48665 L
s
.83265 .48665 m
.83265 .48665 L
s
.83265 .48665 m
.83265 .48665 L
s
.83265 .48665 m
.83265 .48665 L
s
.83265 .48665 m
.83265 .48665 L
s
.83265 .48665 m
.83265 .48665 L
s
1 .002 0 r
.67688 .70603 m
.67696 .70596 L
s
1 .012 0 r
.42994 .77931 m
.42987 .77915 L
s
.43008 .77916 m
.42994 .77931 L
s
.42987 .77915 m
.43008 .77916 L
s
1 .002 0 r
.67695 .70596 m
.67697 .70598 L
s
.67693 .70597 m
.67695 .70596 L
s
.67695 .70596 m
.67696 .70596 L
s
.67697 .70598 m
.67695 .70599 L
s
.67696 .70596 m
.67697 .70598 L
s
.67695 .70599 m
.67693 .70597 L
s
.67693 .70597 m
.67696 .70596 L
s
.67696 .70596 m
.67695 .70599 L
s
1 .005 0 r
.48032 .6571 m
.48055 .65696 L
s
1 0 0 r
.92444 .63263 m
.92445 .63262 L
s
.92445 .63262 m
.92445 .63263 L
s
.92444 .63262 m
.92445 .63262 L
s
.92445 .63262 m
.92445 .63262 L
s
.92445 .63263 m
.92445 .63263 L
s
.92445 .63262 m
.92445 .63263 L
s
.92445 .63263 m
.92444 .63262 L
s
.92444 .63262 m
.92445 .63262 L
s
.92445 .63262 m
.92445 .63263 L
s
1 .005 0 r
.4805 .65695 m
.48054 .65701 L
s
.48047 .65697 m
.4805 .65695 L
s
.4805 .65695 m
.48055 .65696 L
s
.48054 .65701 m
.4805 .65703 L
s
.48055 .65696 m
.48054 .65701 L
s
.4805 .65703 m
.48047 .65697 L
s
.48047 .65697 m
.48055 .65696 L
s
.48055 .65696 m
.4805 .65703 L
s
1 0 0 r
.72788 .58369 m
.72789 .58368 L
s
.72788 .58368 m
.72789 .58368 L
s
.72788 .58368 m
.72788 .58368 L
s
.72788 .58368 m
.72789 .58368 L
s
.72789 .58368 m
.72788 .58368 L
s
.72789 .58368 m
.72789 .58368 L
s
.72788 .58368 m
.72788 .58368 L
s
.72788 .58368 m
.72789 .58368 L
s
.72789 .58368 m
.72788 .58368 L
s
1 .007 0 r
.57206 .80313 m
.5724 .80294 L
s
1 0 0 r
.53128 .53474 m
.53129 .53472 L
s
.53129 .53472 m
.53129 .53473 L
s
.53129 .53473 m
.53129 .53472 L
s
.53129 .53472 m
.53129 .53472 L
s
.53129 .53473 m
.53129 .53473 L
s
.53129 .53472 m
.53129 .53473 L
s
.53129 .53473 m
.53129 .53473 L
s
.53129 .53473 m
.53129 .53472 L
s
.53129 .53472 m
.53129 .53473 L
s
1 .007 0 r
.57233 .80292 m
.57238 .803 L
s
.57228 .80296 m
.57233 .80292 L
s
.57233 .80292 m
.5724 .80294 L
s
.57238 .803 m
.57233 .80304 L
s
.5724 .80294 m
.57238 .803 L
s
1 .015 0 r
.37544 .75419 m
.37633 .75393 L
s
1 .007 0 r
.57233 .80304 m
.57228 .80296 L
s
.57228 .80296 m
.5724 .80294 L
s
.5724 .80294 m
.57233 .80304 L
s
1 .001 0 r
.81967 .72972 m
.81971 .72968 L
s
1 0 0 r
.33465 .48578 m
.33467 .48577 L
s
.33466 .48577 m
.33466 .48577 L
s
.33466 .48577 m
.33466 .48577 L
s
.33467 .48577 m
.33466 .48577 L
s
.33466 .48577 m
.33466 .48577 L
s
.33466 .48577 m
.33467 .48577 L
s
.33466 .48577 m
.33466 .48577 L
s
.33467 .48577 m
.33466 .48577 L
s
.33466 .48577 m
.33467 .48577 L
s
1 .001 0 r
.8197 .72968 m
.81972 .72969 L
s
.81969 .72968 m
.8197 .72968 L
s
.8197 .72968 m
.81971 .72968 L
s
.81972 .72969 m
.81971 .7297 L
s
.81971 .72968 m
.81972 .72969 L
s
.81971 .7297 m
.81969 .72968 L
s
.81969 .72968 m
.81971 .72968 L
s
.81971 .72968 m
.81971 .7297 L
s
1 .015 0 r
.37623 .75405 m
.37615 .75411 L
s
.37616 .75385 m
.37623 .75405 L
s
.37633 .75393 m
.37623 .75405 L
s
.37607 .75391 m
.37616 .75385 L
s
.37616 .75385 m
.37633 .75393 L
s
1 0 0 r
.7789 .4613 m
.7789 .4613 L
s
.7789 .4613 m
.7789 .4613 L
s
.7789 .4613 m
.7789 .4613 L
s
.7789 .4613 m
.7789 .4613 L
s
.7789 .4613 m
.7789 .4613 L
s
.7789 .4613 m
.7789 .4613 L
s
.7789 .4613 m
.7789 .4613 L
s
.7789 .4613 m
.7789 .4613 L
s
.7789 .4613 m
.7789 .4613 L
s
1 .002 0 r
.62305 .68078 m
.62315 .6807 L
s
1 .015 0 r
.37633 .75393 m
.37615 .75411 L
s
.37607 .75391 m
.37633 .75393 L
s
.37615 .75411 m
.37607 .75391 L
s
1 .002 0 r
.62313 .68069 m
.62315 .68072 L
s
.62311 .6807 m
.62313 .68069 L
s
.62313 .68069 m
.62315 .6807 L
s
.62315 .68072 m
.62313 .68073 L
s
.62315 .6807 m
.62315 .68072 L
s
.62313 .68073 m
.62311 .6807 L
s
.62311 .6807 m
.62315 .6807 L
s
.62315 .6807 m
.62313 .68073 L
s
1 .006 0 r
.42639 .63182 m
.42668 .63166 L
s
1 0 0 r
.87072 .60734 m
.87072 .60733 L
s
.87072 .60733 m
.87072 .60733 L
s
.87072 .60733 m
.87072 .60733 L
s
.87072 .60733 m
.87072 .60733 L
s
.87072 .60733 m
.87072 .60733 L
s
.87072 .60733 m
.87072 .60733 L
s
.87072 .60733 m
.87072 .60733 L
s
.87072 .60733 m
.87072 .60733 L
s
.87072 .60733 m
.87072 .60733 L
s
1 .006 0 r
.42663 .63165 m
.42667 .63172 L
s
.42659 .63167 m
.42663 .63165 L
s
.42663 .63165 m
.42668 .63166 L
s
.42667 .63172 m
.42662 .63174 L
s
.42668 .63166 m
.42667 .63172 L
s
.42662 .63174 m
.42659 .63167 L
s
.42659 .63167 m
.42668 .63166 L
s
.42668 .63166 m
.42662 .63174 L
s
1 0 0 r
.67406 .55837 m
.67407 .55836 L
s
.67406 .55836 m
.67407 .55836 L
s
.67406 .55836 m
.67406 .55836 L
s
.67406 .55836 m
.67407 .55836 L
s
.67407 .55836 m
.67406 .55837 L
s
.67407 .55836 m
.67407 .55836 L
s
.67406 .55837 m
.67406 .55836 L
s
.67406 .55836 m
.67407 .55836 L
s
.67407 .55836 m
.67406 .55837 L
s
1 .008 0 r
.51817 .77791 m
.51859 .7777 L
s
1 0 0 r
.47737 .5094 m
.47738 .50939 L
s
.47738 .50939 m
.47738 .50939 L
s
.47737 .50939 m
.47738 .50939 L
s
.47738 .50939 m
.47738 .50939 L
s
.47738 .50939 m
.47738 .50939 L
s
.47738 .50939 m
.47738 .50939 L
s
.47738 .50939 m
.47737 .50939 L
s
.47737 .50939 m
.47738 .50939 L
s
.47738 .50939 m
.47738 .50939 L
s
1 .008 0 r
.5185 .77767 m
.51856 .77777 L
s
.51844 .77771 m
.5185 .77767 L
s
.5185 .77767 m
.51859 .7777 L
s
.51856 .77777 m
.5185 .77781 L
s
.51859 .7777 m
.51856 .77777 L
s
1 0 0 r
.92178 .48491 m
.92178 .48491 L
s
.92178 .48491 m
.92178 .48491 L
s
.92178 .48491 m
.92178 .48491 L
s
.92178 .48491 m
.92178 .48491 L
s
.92178 .48491 m
.92178 .48491 L
s
.92178 .48491 m
.92178 .48491 L
s
.92178 .48491 m
.92178 .48491 L
s
.92178 .48491 m
.92178 .48491 L
s
.92178 .48491 m
.92178 .48491 L
s
1 .008 0 r
.5185 .77781 m
.51844 .77771 L
s
.51844 .77771 m
.51859 .7777 L
s
.51859 .7777 m
.5185 .77781 L
s
1 .001 0 r
.76588 .70447 m
.76593 .70442 L
s
1 0 0 r
.28065 .46041 m
.28065 .46041 L
s
.28065 .46041 m
.28065 .46041 L
s
.28065 .46041 m
.28065 .46041 L
s
.28065 .46041 m
.28065 .46041 L
s
.28065 .46041 m
.28065 .46041 L
s
.28065 .46041 m
.28065 .46041 L
s
.28065 .46041 m
.28065 .46041 L
s
.28065 .46041 m
.28065 .46041 L
s
.28065 .46041 m
.28065 .46041 L
s
1 .001 0 r
.76592 .70442 m
.76593 .70443 L
s
.76591 .70443 m
.76592 .70442 L
s
.76592 .70442 m
.76593 .70442 L
s
.76593 .70443 m
.76592 .70444 L
s
.76593 .70442 m
.76593 .70443 L
s
.76592 .70444 m
.76591 .70443 L
s
.76591 .70443 m
.76593 .70442 L
s
.76593 .70442 m
.76592 .70444 L
s
1 .003 0 r
.56917 .6555 m
.56928 .65541 L
s
.56926 .6554 m
.56928 .65543 L
s
.56924 .65542 m
.56926 .6554 L
s
.56926 .6554 m
.56928 .65541 L
s
.56928 .65543 m
.56926 .65545 L
s
.56928 .65541 m
.56928 .65543 L
s
.56926 .65545 m
.56924 .65542 L
s
.56924 .65542 m
.56928 .65541 L
s
.56928 .65541 m
.56926 .65545 L
s
1 .007 0 r
.37242 .60652 m
.37279 .60635 L
s
1 0 0 r
.81694 .58202 m
.81695 .58202 L
s
.81695 .58202 m
.81695 .58202 L
s
.81694 .58202 m
.81695 .58202 L
s
.81695 .58202 m
.81695 .58202 L
s
.81695 .58202 m
.81695 .58202 L
s
.81695 .58202 m
.81695 .58202 L
s
.81695 .58202 m
.81694 .58202 L
s
.81694 .58202 m
.81695 .58202 L
s
.81695 .58202 m
.81695 .58202 L
s
1 .007 0 r
.37276 .60641 m
.37272 .60644 L
s
.37272 .60633 m
.37276 .60641 L
s
.37279 .60635 m
.37276 .60641 L
s
.37267 .60635 m
.37272 .60633 L
s
.37272 .60633 m
.37279 .60635 L
s
1 .005 0 r
.661 .80164 m
.6612 .80151 L
s
1 .007 0 r
.37272 .60644 m
.37267 .60635 L
s
.37279 .60635 m
.37272 .60644 L
s
.37267 .60635 m
.37279 .60635 L
s
1 0 0 r
.62019 .53303 m
.6202 .53302 L
s
.6202 .53302 m
.6202 .53303 L
s
.62019 .53303 m
.6202 .53302 L
s
.6202 .53302 m
.6202 .53302 L
s
.6202 .53303 m
.6202 .53303 L
s
.6202 .53302 m
.6202 .53303 L
s
.6202 .53303 m
.62019 .53303 L
s
.62019 .53303 m
.6202 .53302 L
s
.6202 .53302 m
.6202 .53303 L
s
1 .005 0 r
.66116 .80149 m
.6612 .80155 L
s
.66113 .80152 m
.66116 .80149 L
s
.66116 .80149 m
.6612 .80151 L
s
.6612 .80155 m
.66116 .80158 L
s
.6612 .80151 m
.6612 .80155 L
s
.66116 .80158 m
.66113 .80152 L
s
.66113 .80152 m
.6612 .80151 L
s
.6612 .80151 m
.66116 .80158 L
s
1 .01 0 r
.46423 .75267 m
.46476 .75243 L
s
1 0 0 r
.42341 .48403 m
.42341 .48403 L
s
.42341 .48403 m
.42341 .48403 L
s
.42341 .48403 m
.42341 .48403 L
s
.42341 .48403 m
.42341 .48403 L
s
.42341 .48403 m
.42341 .48403 L
s
.42341 .48403 m
.42341 .48403 L
s
.42341 .48403 m
.42341 .48403 L
s
.42341 .48403 m
.42341 .48403 L
s
.42341 .48403 m
.42341 .48403 L
s
1 .01 0 r
.46472 .75252 m
.46465 .75256 L
s
.46465 .75239 m
.46472 .75252 L
s
.46476 .75243 m
.46472 .75252 L
s
.46458 .75244 m
.46465 .75239 L
s
.46465 .75239 m
.46476 .75243 L
s
1 0 0 r
.86802 .45953 m
.86802 .45953 L
s
.86802 .45953 m
.86802 .45953 L
s
.86802 .45953 m
.86802 .45953 L
s
.86802 .45953 m
.86802 .45953 L
s
.86802 .45953 m
.86802 .45953 L
s
.86802 .45953 m
.86802 .45953 L
s
.86802 .45953 m
.86802 .45953 L
s
.86802 .45953 m
.86802 .45953 L
s
.86802 .45953 m
.86802 .45953 L
s
1 .01 0 r
.46465 .75256 m
.46458 .75244 L
s
.46476 .75243 m
.46465 .75256 L
s
.46458 .75244 m
.46476 .75243 L
s
1 .001 0 r
.71205 .67919 m
.7121 .67914 L
s
.71209 .67914 m
.7121 .67915 L
s
.71208 .67914 m
.71209 .67914 L
s
.71209 .67914 m
.7121 .67914 L
s
.7121 .67915 m
.71209 .67916 L
s
.7121 .67914 m
.7121 .67915 L
s
.71209 .67916 m
.71208 .67914 L
s
.71208 .67914 m
.7121 .67914 L
s
.7121 .67914 m
.71209 .67916 L
s
1 .003 0 r
.51524 .63019 m
.51537 .6301 L
s
.51535 .63009 m
.51537 .63013 L
s
.51532 .63011 m
.51535 .63009 L
s
.51535 .63009 m
.51537 .6301 L
s
.51537 .63013 m
.51535 .63014 L
s
.51537 .6301 m
.51537 .63013 L
s
1 0 0 r
.95993 .60569 m
.95994 .60569 L
s
.95993 .60569 m
.95994 .60569 L
s
.95993 .60569 m
.95993 .60569 L
s
.95993 .60569 m
.95994 .60569 L
s
.95994 .60569 m
.95993 .60569 L
s
.95994 .60569 m
.95994 .60569 L
s
.95993 .60569 m
.95993 .60569 L
s
.95993 .60569 m
.95994 .60569 L
s
.95994 .60569 m
.95993 .60569 L
s
1 .003 0 r
.51535 .63014 m
.51532 .63011 L
s
.51532 .63011 m
.51537 .6301 L
s
.51537 .6301 m
.51535 .63014 L
s
1 .008 0 r
.3184 .58119 m
.31886 .58103 L
s
1 0 0 r
.76312 .55668 m
.76312 .55668 L
s
1 .008 0 r
.31882 .5811 m
.31877 .58113 L
s
.31878 .581 m
.31882 .5811 L
s
.31886 .58103 m
.31882 .5811 L
s
1 0 0 r
.76312 .55668 m
.76312 .55668 L
s
.76312 .55668 m
.76312 .55668 L
s
.76312 .55668 m
.76312 .55668 L
s
.76312 .55668 m
.76312 .55668 L
s
.76312 .55668 m
.76312 .55668 L
s
.76312 .55668 m
.76312 .55668 L
s
.76312 .55668 m
.76312 .55668 L
s
.76312 .55668 m
.76312 .55668 L
s
1 .008 0 r
.31873 .58102 m
.31878 .581 L
s
.31878 .581 m
.31886 .58103 L
s
.31886 .58103 m
.31877 .58113 L
s
.31873 .58102 m
.31886 .58103 L
s
.31877 .58113 m
.31873 .58102 L
s
1 .005 0 r
.6071 .7764 m
.60735 .77625 L
s
1 0 0 r
.56628 .50767 m
.56628 .50766 L
s
.56628 .50766 m
.56628 .50767 L
s
.56628 .50767 m
.56628 .50766 L
s
.56628 .50766 m
.56628 .50766 L
s
.56628 .50767 m
.56628 .50767 L
s
.56628 .50766 m
.56628 .50767 L
s
.56628 .50767 m
.56628 .50767 L
s
.56628 .50767 m
.56628 .50766 L
s
.56628 .50766 m
.56628 .50767 L
s
1 .005 0 r
.6073 .77623 m
.60734 .7763 L
s
.60726 .77626 m
.6073 .77623 L
s
.6073 .77623 m
.60735 .77625 L
s
.60734 .7763 m
.6073 .77633 L
s
.60735 .77625 m
.60734 .7763 L
s
.6073 .77633 m
.60726 .77626 L
s
.60726 .77626 m
.60735 .77625 L
s
.60735 .77625 m
.6073 .77633 L
s
1 .012 0 r
.41024 .7274 m
.41092 .72714 L
s
1 .001 0 r
.85503 .7029 m
.85506 .70287 L
s
1 0 0 r
.3694 .45864 m
.3694 .45864 L
s
.3694 .45864 m
.3694 .45864 L
s
.3694 .45864 m
.3694 .45864 L
s
.3694 .45864 m
.3694 .45864 L
s
.3694 .45864 m
.3694 .45864 L
s
.3694 .45864 m
.3694 .45864 L
s
.3694 .45864 m
.3694 .45864 L
s
.3694 .45864 m
.3694 .45864 L
s
.3694 .45864 m
.3694 .45864 L
s
1 .001 0 r
.85506 .70287 m
.85507 .70288 L
s
.85505 .70287 m
.85506 .70287 L
s
.85506 .70287 m
.85506 .70287 L
s
.85507 .70288 m
.85506 .70288 L
s
.85506 .70287 m
.85507 .70288 L
s
.85506 .70288 m
.85505 .70287 L
s
.85505 .70287 m
.85506 .70287 L
s
.85506 .70287 m
.85506 .70288 L
s
1 .012 0 r
.41086 .72724 m
.41078 .7273 L
s
.41078 .72709 m
.41086 .72724 L
s
.41092 .72714 m
.41086 .72724 L
s
.41071 .72714 m
.41078 .72709 L
s
.41078 .72709 m
.41092 .72714 L
s
1 .002 0 r
.65817 .65389 m
.65822 .65383 L
s
1 .012 0 r
.41078 .7273 m
.41071 .72714 L
s
.41092 .72714 m
.41078 .7273 L
s
.41071 .72714 m
.41092 .72714 L
s
1 .002 0 r
.65821 .65383 m
.65823 .65385 L
s
.6582 .65384 m
.65821 .65383 L
s
.65821 .65383 m
.65822 .65383 L
s
.65823 .65385 m
.65821 .65386 L
s
.65822 .65383 m
.65823 .65385 L
s
.65821 .65386 m
.6582 .65384 L
s
.6582 .65384 m
.65822 .65383 L
s
.65822 .65383 m
.65821 .65386 L
s
1 .003 0 r
.46127 .60487 m
.46142 .60476 L
s
.46139 .60475 m
.46142 .6048 L
s
.46136 .60477 m
.46139 .60475 L
s
.46139 .60475 m
.46142 .60476 L
s
.46142 .6048 m
.46139 .60481 L
s
.46142 .60476 m
.46142 .6048 L
s
1 0 0 r
.90615 .58035 m
.90616 .58035 L
s
.90616 .58035 m
.90616 .58035 L
s
.90616 .58035 m
.90616 .58035 L
s
.90616 .58035 m
.90616 .58035 L
s
.90616 .58035 m
.90616 .58035 L
s
.90616 .58035 m
.90616 .58035 L
s
.90616 .58035 m
.90616 .58035 L
s
.90616 .58035 m
.90616 .58035 L
s
.90616 .58035 m
.90616 .58035 L
s
1 .003 0 r
.46139 .60481 m
.46136 .60477 L
s
.46136 .60477 m
.46142 .60476 L
s
.46142 .60476 m
.46139 .60481 L
s
.75009 .80015 m
.75021 .80006 L
s
.75018 .80005 m
.75021 .80009 L
s
.75016 .80007 m
.75018 .80005 L
s
.75018 .80005 m
.75021 .80006 L
s
.75021 .80009 m
.75019 .80011 L
s
.75021 .80006 m
.75021 .80009 L
s
1 0 0 r
.70925 .53132 m
.70925 .53132 L
s
1 .003 0 r
.75019 .80011 m
.75016 .80007 L
s
.75016 .80007 m
.75021 .80006 L
s
1 0 0 r
.70925 .53132 m
.70925 .53132 L
s
.70925 .53132 m
.70925 .53132 L
s
.70925 .53132 m
.70925 .53132 L
s
.70925 .53132 m
.70925 .53132 L
s
.70925 .53132 m
.70925 .53132 L
s
.70925 .53132 m
.70925 .53132 L
s
.70925 .53132 m
.70925 .53132 L
s
.70925 .53132 m
.70925 .53132 L
s
1 .003 0 r
.75021 .80006 m
.75019 .80011 L
s
1 .006 0 r
.55316 .75114 m
.55346 .75096 L
s
1 0 0 r
.51231 .48228 m
.51231 .48228 L
s
.51231 .48228 m
.51231 .48228 L
s
.51231 .48228 m
.51231 .48228 L
s
.51231 .48228 m
.51231 .48228 L
s
.51231 .48228 m
.51231 .48228 L
s
.51231 .48228 m
.51231 .48228 L
s
.51231 .48228 m
.51231 .48228 L
s
.51231 .48228 m
.51231 .48228 L
s
.51231 .48228 m
.51231 .48228 L
s
1 .006 0 r
.5534 .75094 m
.55345 .75102 L
s
.55335 .75097 m
.5534 .75094 L
s
.5534 .75094 m
.55346 .75096 L
s
.55345 .75102 m
.5534 .75105 L
s
.55346 .75096 m
.55345 .75102 L
s
1 .015 0 r
.3562 .70211 m
.35708 .70184 L
s
1 .006 0 r
.5534 .75105 m
.55335 .75097 L
s
.55335 .75097 m
.55346 .75096 L
s
.55346 .75096 m
.5534 .75105 L
s
1 .001 0 r
.8012 .6776 m
.80123 .67757 L
s
.80122 .67757 m
.80123 .67758 L
s
.80121 .67757 m
.80122 .67757 L
s
.80122 .67757 m
.80123 .67757 L
s
.80123 .67758 m
.80122 .67758 L
s
.80123 .67757 m
.80123 .67758 L
s
.80122 .67758 m
.80121 .67757 L
s
.80121 .67757 m
.80123 .67757 L
s
.80123 .67757 m
.80122 .67758 L
s
1 .015 0 r
.35698 .70197 m
.3569 .70202 L
s
.35691 .70177 m
.35698 .70197 L
s
.35708 .70184 m
.35698 .70197 L
s
.35682 .70183 m
.35691 .70177 L
s
.35691 .70177 m
.35708 .70184 L
s
1 .002 0 r
.60424 .62856 m
.6043 .62851 L
s
1 .015 0 r
.35708 .70184 m
.3569 .70202 L
s
.35682 .70183 m
.35708 .70184 L
s
1 .002 0 r
.60428 .6285 m
.6043 .62852 L
s
.60427 .62851 m
.60428 .6285 L
s
.60428 .6285 m
.6043 .62851 L
s
1 .015 0 r
.3569 .70202 m
.35682 .70183 L
s
1 .002 0 r
.6043 .62852 m
.60428 .62853 L
s
.6043 .62851 m
.6043 .62852 L
s
.60428 .62853 m
.60427 .62851 L
s
.60427 .62851 m
.6043 .62851 L
s
.6043 .62851 m
.60428 .62853 L
s
1 .004 0 r
.40724 .57952 m
.40743 .57941 L
s
.40739 .5794 m
.40742 .57945 L
s
.40736 .57941 m
.40739 .5794 L
s
.40739 .5794 m
.40743 .57941 L
s
.40742 .57945 m
.40739 .57946 L
s
.40743 .57941 m
.40742 .57945 L
s
1 0 0 r
.85233 .55499 m
.85233 .55499 L
s
.85233 .55499 m
.85233 .55499 L
s
.85233 .55499 m
.85233 .55499 L
s
.85233 .55499 m
.85233 .55499 L
s
.85233 .55499 m
.85233 .55499 L
s
.85233 .55499 m
.85233 .55499 L
s
.85233 .55499 m
.85233 .55499 L
s
.85233 .55499 m
.85233 .55499 L
s
.85233 .55499 m
.85233 .55499 L
s
1 .004 0 r
.40739 .57946 m
.40736 .57941 L
s
.40736 .57941 m
.40743 .57941 L
s
.40743 .57941 m
.40739 .57946 L
s
1 .003 0 r
.69619 .77489 m
.69633 .77479 L
s
.6963 .77478 m
.69633 .77482 L
s
.69627 .7748 m
.6963 .77478 L
s
.6963 .77478 m
.69633 .77479 L
s
.69633 .77482 m
.6963 .77484 L
s
.69633 .77479 m
.69633 .77482 L
s
1 0 0 r
.65533 .50594 m
.65533 .50594 L
s
.65533 .50594 m
.65533 .50594 L
s
.65533 .50594 m
.65533 .50594 L
s
.65533 .50594 m
.65533 .50594 L
s
.65533 .50594 m
.65533 .50594 L
s
.65533 .50594 m
.65533 .50594 L
s
.65533 .50594 m
.65533 .50594 L
s
.65533 .50594 m
.65533 .50594 L
s
.65533 .50594 m
.65533 .50594 L
s
1 .003 0 r
.6963 .77484 m
.69627 .7748 L
s
.69627 .7748 m
.69633 .77479 L
s
.69633 .77479 m
.6963 .77484 L
s
1 .008 0 r
.49917 .72585 m
.49954 .72565 L
s
1 0 0 r
.4583 .45687 m
.4583 .45687 L
s
.4583 .45687 m
.4583 .45687 L
s
.4583 .45687 m
.4583 .45687 L
s
.4583 .45687 m
.4583 .45687 L
s
.4583 .45687 m
.4583 .45687 L
s
.4583 .45687 m
.4583 .45687 L
s
.4583 .45687 m
.4583 .45687 L
s
.4583 .45687 m
.4583 .45687 L
s
.4583 .45687 m
.4583 .45687 L
s
1 .008 0 r
.49947 .72562 m
.49952 .72572 L
s
.49941 .72566 m
.49947 .72562 L
s
.49947 .72562 m
.49954 .72565 L
s
.49952 .72572 m
.49947 .72575 L
s
.49954 .72565 m
.49952 .72572 L
s
.49947 .72575 m
.49941 .72566 L
s
.49941 .72566 m
.49954 .72565 L
s
.49954 .72565 m
.49947 .72575 L
s
1 .001 0 r
.74731 .65228 m
.74734 .65224 L
s
.74733 .65224 m
.74734 .65225 L
s
.74733 .65225 m
.74733 .65224 L
s
.74733 .65224 m
.74734 .65224 L
s
.74734 .65225 m
.74733 .65226 L
s
.74734 .65224 m
.74734 .65225 L
s
.74733 .65226 m
.74733 .65225 L
s
.74733 .65225 m
.74734 .65224 L
s
.74734 .65224 m
.74733 .65226 L
s
1 .002 0 r
.55026 .60322 m
.55032 .60316 L
s
.55031 .60315 m
.55032 .60317 L
s
.55029 .60316 m
.55031 .60315 L
s
.55031 .60315 m
.55032 .60316 L
s
.55032 .60317 m
.55031 .60318 L
s
.55032 .60316 m
.55032 .60317 L
s
.55031 .60318 m
.55029 .60316 L
s
.55029 .60316 m
.55032 .60316 L
s
.55032 .60316 m
.55031 .60318 L
s
1 .004 0 r
.35317 .55415 m
.35339 .55404 L
s
.35338 .55408 m
.35335 .5541 L
s
.35335 .55403 m
.35338 .55408 L
s
.35339 .55404 m
.35338 .55408 L
s
.35332 .55404 m
.35335 .55403 L
s
.35335 .55403 m
.35339 .55404 L
s
1 0 0 r
.79845 .52961 m
.79845 .52961 L
s
.79845 .52961 m
.79846 .52961 L
s
.79845 .52961 m
.79845 .52961 L
s
.79845 .52961 m
.79845 .52961 L
s
.79846 .52961 m
.79845 .52961 L
s
.79845 .52961 m
.79846 .52961 L
s
.79845 .52961 m
.79845 .52961 L
s
.79845 .52961 m
.79845 .52961 L
s
.79845 .52961 m
.79845 .52961 L
s
1 .004 0 r
.35335 .5541 m
.35332 .55404 L
s
.35339 .55404 m
.35335 .5541 L
s
.35332 .55404 m
.35339 .55404 L
s
.64224 .74961 m
.64241 .74949 L
s
.64237 .74948 m
.64241 .74952 L
s
.64234 .7495 m
.64237 .74948 L
s
.64237 .74948 m
.64241 .74949 L
s
1 0 0 r
.60136 .48053 m
.60136 .48053 L
s
1 .004 0 r
.64241 .74952 m
.64237 .74954 L
s
.64241 .74949 m
.64241 .74952 L
s
1 0 0 r
.60136 .48053 m
.60136 .48053 L
s
.60136 .48053 m
.60136 .48053 L
s
.60136 .48053 m
.60136 .48053 L
s
.60136 .48053 m
.60136 .48053 L
s
.60136 .48053 m
.60136 .48053 L
s
.60136 .48053 m
.60136 .48053 L
s
.60136 .48053 m
.60136 .48053 L
s
.60136 .48053 m
.60136 .48053 L
s
1 .004 0 r
.64237 .74954 m
.64234 .7495 L
s
.64234 .7495 m
.64241 .74949 L
s
.64241 .74949 m
.64237 .74954 L
s
1 .009 0 r
.44513 .70054 m
.4456 .70031 L
s
1 .001 0 r
.89049 .67601 m
.89051 .67599 L
s
.8905 .67599 m
.89051 .67599 L
s
.8905 .67599 m
.8905 .67599 L
s
.8905 .67599 m
.89051 .67599 L
s
.89051 .67599 m
.89051 .676 L
s
.89051 .67599 m
.89051 .67599 L
s
.89051 .676 m
.8905 .67599 L
s
.8905 .67599 m
.89051 .67599 L
s
.89051 .67599 m
.89051 .676 L
s
1 .009 0 r
.44557 .70039 m
.44551 .70043 L
s
.44551 .70028 m
.44557 .70039 L
s
.4456 .70031 m
.44557 .70039 L
s
.44545 .70032 m
.44551 .70028 L
s
.44551 .70028 m
.4456 .70031 L
s
.44551 .70043 m
.44545 .70032 L
s
.4456 .70031 m
.44551 .70043 L
s
.44545 .70032 m
.4456 .70031 L
s
1 .001 0 r
.69337 .62693 m
.69341 .6269 L
s
.6934 .6269 m
.69341 .62691 L
s
.69339 .6269 m
.6934 .6269 L
s
.6934 .6269 m
.69341 .6269 L
s
.69341 .62691 m
.6934 .62691 L
s
.69341 .6269 m
.69341 .62691 L
s
.6934 .62691 m
.69339 .6269 L
s
.69339 .6269 m
.69341 .6269 L
s
.69341 .6269 m
.6934 .62691 L
s
1 .002 0 r
.49623 .57785 m
.4963 .57779 L
s
.49628 .57778 m
.4963 .5778 L
s
.49627 .57779 m
.49628 .57778 L
s
.49628 .57778 m
.4963 .57779 L
s
.4963 .5778 m
.49628 .57781 L
s
.4963 .57779 m
.4963 .5778 L
s
.49628 .57781 m
.49627 .57779 L
s
.49627 .57779 m
.4963 .57779 L
s
.4963 .57779 m
.49628 .57781 L
s
1 0 0 r
.94168 .5533 m
.94168 .5533 L
s
.94168 .5533 m
.94168 .5533 L
s
.94168 .5533 m
.94168 .5533 L
s
.94168 .5533 m
.94168 .5533 L
s
.94168 .5533 m
.94168 .5533 L
s
.94168 .5533 m
.94168 .5533 L
s
.94168 .5533 m
.94168 .5533 L
s
.94168 .5533 m
.94168 .5533 L
s
.94168 .5533 m
.94168 .5533 L
s
1 .002 0 r
.78542 .77338 m
.7855 .77331 L
s
1 .004 0 r
.29904 .52875 m
.2993 .52867 L
s
1 .002 0 r
.78549 .7733 m
.78551 .77333 L
s
.78547 .77332 m
.78549 .7733 L
s
.78549 .7733 m
.7855 .77331 L
s
1 .004 0 r
.29927 .5287 m
.29924 .52872 L
s
.29925 .52865 m
.29927 .5287 L
s
.2993 .52867 m
.29927 .5287 L
s
1 .002 0 r
.78551 .77333 m
.78549 .77334 L
s
.7855 .77331 m
.78551 .77333 L
s
1 .004 0 r
.29922 .52866 m
.29925 .52865 L
s
.29925 .52865 m
.2993 .52867 L
s
1 .002 0 r
.78549 .77334 m
.78547 .77332 L
s
.78547 .77332 m
.7855 .77331 L
s
.7855 .77331 m
.78549 .77334 L
s
1 0 0 r
.74453 .5042 m
.74453 .5042 L
s
.74453 .5042 m
.74453 .5042 L
s
.74453 .5042 m
.74453 .5042 L
s
.74453 .5042 m
.74453 .5042 L
s
.74453 .5042 m
.74453 .5042 L
s
.74453 .5042 m
.74453 .5042 L
s
.74453 .5042 m
.74453 .5042 L
s
.74453 .5042 m
.74453 .5042 L
s
.74453 .5042 m
.74453 .5042 L
s
1 .004 0 r
.2993 .52867 m
.29924 .52872 L
s
.29922 .52866 m
.2993 .52867 L
s
.29924 .52872 m
.29922 .52866 L
s
1 .005 0 r
.58824 .7243 m
.58844 .72416 L
s
1 0 0 r
.54735 .4551 m
.54735 .4551 L
s
.54735 .4551 m
.54735 .4551 L
s
.54735 .4551 m
.54735 .4551 L
s
.54735 .4551 m
.54735 .4551 L
s
.54735 .4551 m
.54735 .4551 L
s
.54735 .4551 m
.54735 .4551 L
s
.54735 .4551 m
.54735 .4551 L
s
.54735 .4551 m
.54735 .4551 L
s
.54735 .4551 m
.54735 .4551 L
s
1 .005 0 r
.5884 .72415 m
.58844 .7242 L
s
.58837 .72417 m
.5884 .72415 L
s
.5884 .72415 m
.58844 .72416 L
s
.58844 .7242 m
.5884 .72423 L
s
.58844 .72416 m
.58844 .7242 L
s
.5884 .72423 m
.58837 .72417 L
s
.58837 .72417 m
.58844 .72416 L
s
.58844 .72416 m
.5884 .72423 L
s
1 .011 0 r
.39104 .67521 m
.39166 .67495 L
s
1 .001 0 r
.8366 .65066 m
.83662 .65064 L
s
.83661 .65064 m
.83662 .65065 L
s
.83661 .65065 m
.83661 .65064 L
s
.83661 .65064 m
.83662 .65064 L
s
.83662 .65065 m
.83661 .65065 L
s
.83662 .65064 m
.83662 .65065 L
s
.83661 .65065 m
.83661 .65065 L
s
.83661 .65065 m
.83662 .65064 L
s
.83662 .65064 m
.83661 .65065 L
s
1 .011 0 r
.39161 .67505 m
.39153 .6751 L
s
.39154 .67491 m
.39161 .67505 L
s
.39166 .67495 m
.39161 .67505 L
s
.39147 .67495 m
.39154 .67491 L
s
.39154 .67491 m
.39166 .67495 L
s
1 .001 0 r
.63939 .60156 m
.63942 .60153 L
s
1 .011 0 r
.39153 .6751 m
.39147 .67495 L
s
.39166 .67495 m
.39153 .6751 L
s
.39147 .67495 m
.39166 .67495 L
s
1 .001 0 r
.63941 .60153 m
.63942 .60154 L
s
.63941 .60153 m
.63941 .60153 L
s
.63941 .60153 m
.63942 .60153 L
s
.63942 .60154 m
.63942 .60154 L
s
.63942 .60153 m
.63942 .60154 L
s
.63942 .60154 m
.63941 .60153 L
s
.63941 .60153 m
.63942 .60153 L
s
.63942 .60153 m
.63942 .60154 L
s
1 .002 0 r
.44215 .55245 m
.44223 .55239 L
s
.44221 .55239 m
.44223 .55241 L
s
.4422 .5524 m
.44221 .55239 L
s
.44221 .55239 m
.44223 .55239 L
s
.44223 .55241 m
.44221 .55242 L
s
.44223 .55239 m
.44223 .55241 L
s
.44221 .55242 m
.4422 .5524 L
s
.4422 .5524 m
.44223 .55239 L
s
.44223 .55239 m
.44221 .55242 L
s
1 0 0 r
.8878 .5279 m
.88781 .52789 L
s
.8878 .52789 m
.88781 .52789 L
s
.8878 .52789 m
.8878 .52789 L
s
.8878 .52789 m
.88781 .52789 L
s
.88781 .52789 m
.8878 .5279 L
s
.88781 .52789 m
.88781 .52789 L
s
.8878 .5279 m
.8878 .52789 L
s
.8878 .52789 m
.88781 .52789 L
s
.88781 .52789 m
.8878 .5279 L
s
1 .003 0 r
.73147 .74807 m
.73156 .74799 L
s
.73154 .74799 m
.73157 .74801 L
s
.73152 .748 m
.73154 .74799 L
s
.73154 .74799 m
.73156 .74799 L
s
.73157 .74801 m
.73154 .74803 L
s
.73156 .74799 m
.73157 .74801 L
s
.73154 .74803 m
.73152 .748 L
s
.73152 .748 m
.73156 .74799 L
s
.73156 .74799 m
.73154 .74803 L
s
1 0 0 r
.69056 .47877 m
.69056 .47877 L
s
.69056 .47877 m
.69056 .47877 L
s
.69056 .47877 m
.69056 .47877 L
s
.69056 .47877 m
.69056 .47877 L
s
.69056 .47877 m
.69056 .47877 L
s
.69056 .47877 m
.69056 .47877 L
s
.69056 .47877 m
.69056 .47877 L
s
.69056 .47877 m
.69056 .47877 L
s
.69056 .47877 m
.69056 .47877 L
s
1 .005 0 r
.5342 .69897 m
.53444 .69881 L
s
.53439 .69879 m
.53444 .69886 L
s
.53435 .69882 m
.53439 .69879 L
s
.53439 .69879 m
.53444 .69881 L
s
.53444 .69886 m
.53439 .69889 L
s
.53444 .69881 m
.53444 .69886 L
s
.53439 .69889 m
.53435 .69882 L
s
.53435 .69882 m
.53444 .69881 L
s
.53444 .69881 m
.53439 .69889 L
s
1 .014 0 r
.3369 .64986 m
.33772 .64959 L
s
1 .001 0 r
.78266 .6253 m
.78268 .62528 L
s
.78267 .62527 m
.78268 .62528 L
s
.78267 .62528 m
.78267 .62527 L
s
.78267 .62527 m
.78268 .62528 L
s
.78268 .62528 m
.78267 .62528 L
s
.78268 .62528 m
.78268 .62528 L
s
.78267 .62528 m
.78267 .62528 L
s
.78267 .62528 m
.78268 .62528 L
s
.78268 .62528 m
.78267 .62528 L
s
1 .014 0 r
.33763 .64971 m
.33755 .64976 L
s
.33756 .64953 m
.33763 .64971 L
s
.33772 .64959 m
.33763 .64971 L
s
.33748 .64958 m
.33756 .64953 L
s
.33756 .64953 m
.33772 .64959 L
s
1 .001 0 r
.58536 .57617 m
.58539 .57614 L
s
.58538 .57614 m
.58539 .57615 L
s
.58537 .57614 m
.58538 .57614 L
s
.58538 .57614 m
.58539 .57614 L
s
1 .014 0 r
.33772 .64959 m
.33755 .64976 L
s
.33748 .64958 m
.33772 .64959 L
s
1 .001 0 r
.58539 .57615 m
.58538 .57615 L
s
.58539 .57614 m
.58539 .57615 L
s
1 .014 0 r
.33755 .64976 m
.33748 .64958 L
s
1 .001 0 r
.58538 .57615 m
.58537 .57614 L
s
.58537 .57614 m
.58539 .57614 L
s
.58539 .57614 m
.58538 .57615 L
s
1 .014 0 r
.42896 .79642 m
.42978 .79612 L
s
1 .002 0 r
.38802 .52704 m
.3881 .52698 L
s
.38809 .52698 m
.3881 .527 L
s
.38807 .52699 m
.38809 .52698 L
s
.38809 .52698 m
.3881 .52698 L
s
.3881 .527 m
.38808 .52701 L
s
.3881 .52698 m
.3881 .527 L
s
.38808 .52701 m
.38807 .52699 L
s
.38807 .52699 m
.3881 .52698 L
s
.3881 .52698 m
.38808 .52701 L
s
1 0 0 r
.83388 .50247 m
.83388 .50247 L
s
.83388 .50247 m
.83388 .50247 L
s
.83388 .50247 m
.83388 .50247 L
s
.83388 .50247 m
.83388 .50247 L
s
.83388 .50247 m
.83388 .50247 L
s
.83388 .50247 m
.83388 .50247 L
s
.83388 .50247 m
.83388 .50247 L
s
.83388 .50247 m
.83388 .50247 L
s
.83388 .50247 m
.83388 .50247 L
s
1 .014 0 r
.4297 .79624 m
.42961 .79631 L
s
.42962 .79606 m
.4297 .79624 L
s
.42978 .79612 m
.4297 .79624 L
s
.42953 .79612 m
.42962 .79606 L
s
.42962 .79606 m
.42978 .79612 L
s
1 .003 0 r
.67747 .72274 m
.67758 .72265 L
s
.67755 .72265 m
.67758 .72268 L
s
.67753 .72266 m
.67755 .72265 L
s
.67755 .72265 m
.67758 .72265 L
s
.67758 .72268 m
.67755 .72269 L
s
.67758 .72265 m
.67758 .72268 L
s
1 .014 0 r
.42961 .79631 m
.42953 .79612 L
s
.42978 .79612 m
.42961 .79631 L
s
.42953 .79612 m
.42978 .79612 L
s
1 .003 0 r
.67755 .72269 m
.67753 .72266 L
s
.67753 .72266 m
.67758 .72265 L
s
.67758 .72265 m
.67755 .72269 L
s
1 0 0 r
.63654 .45332 m
.63654 .45332 L
s
.63654 .45332 m
.63654 .45332 L
s
.63654 .45332 m
.63654 .45332 L
s
.63654 .45332 m
.63654 .45332 L
s
.63654 .45332 m
.63654 .45332 L
s
.63654 .45332 m
.63654 .45332 L
s
.63654 .45332 m
.63654 .45332 L
s
.63654 .45332 m
.63654 .45332 L
s
.63654 .45332 m
.63654 .45332 L
s
1 .006 0 r
.48011 .67361 m
.48041 .67343 L
s
1 0 0 r
.92604 .64905 m
.92605 .64903 L
s
.92605 .64903 m
.92605 .64904 L
s
.92604 .64904 m
.92605 .64903 L
s
.92605 .64903 m
.92605 .64903 L
s
.92605 .64904 m
.92605 .64904 L
s
.92605 .64903 m
.92605 .64904 L
s
.92605 .64904 m
.92604 .64904 L
s
.92604 .64904 m
.92605 .64903 L
s
.92605 .64903 m
.92605 .64904 L
s
1 .006 0 r
.48035 .67341 m
.4804 .67349 L
s
.4803 .67344 m
.48035 .67341 L
s
.48035 .67341 m
.48041 .67343 L
s
.4804 .67349 m
.48035 .67352 L
s
.48041 .67343 m
.4804 .67349 L
s
.48035 .67352 m
.4803 .67344 L
s
.4803 .67344 m
.48041 .67343 L
s
.48041 .67343 m
.48035 .67352 L
s
1 .001 0 r
.72867 .59991 m
.72869 .59989 L
s
.72869 .59989 m
.72869 .59989 L
s
.72868 .59989 m
.72869 .59989 L
s
.72869 .59989 m
.72869 .59989 L
s
.72869 .59989 m
.72869 .59989 L
s
.72869 .59989 m
.72869 .59989 L
s
.72869 .59989 m
.72868 .59989 L
s
.72868 .59989 m
.72869 .59989 L
s
.72869 .59989 m
.72869 .59989 L
s
.53128 .55076 m
.5313 .55073 L
s
.5313 .55073 m
.53131 .55073 L
s
.53129 .55073 m
.5313 .55073 L
s
.5313 .55073 m
.5313 .55073 L
s
.53131 .55073 m
.5313 .55074 L
s
.5313 .55073 m
.53131 .55073 L
s
.5313 .55074 m
.53129 .55073 L
s
.53129 .55073 m
.5313 .55073 L
s
.5313 .55073 m
.5313 .55074 L
s
1 .017 0 r
.3748 .77111 m
.37585 .77079 L
s
1 .002 0 r
.82084 .74654 m
.8209 .74648 L
s
1 .001 0 r
.33385 .5016 m
.33392 .50156 L
s
.33391 .50157 m
.3339 .50158 L
s
.3339 .50156 m
.33391 .50157 L
s
.33392 .50156 m
.33391 .50157 L
s
.33389 .50156 m
.3339 .50156 L
s
.3339 .50156 m
.33392 .50156 L
s
1 .002 0 r
.82088 .74648 m
.8209 .7465 L
s
.82087 .74649 m
.82088 .74648 L
s
.82088 .74648 m
.8209 .74648 L
s
.8209 .7465 m
.82089 .74651 L
s
.8209 .74648 m
.8209 .7465 L
s
1 .001 0 r
.3339 .50158 m
.33389 .50156 L
s
.33392 .50156 m
.3339 .50158 L
s
.33389 .50156 m
.33392 .50156 L
s
1 .002 0 r
.82089 .74651 m
.82087 .74649 L
s
.82087 .74649 m
.8209 .74648 L
s
.8209 .74648 m
.82089 .74651 L
s
1 0 0 r
.7799 .47702 m
.7799 .47702 L
s
.7799 .47702 m
.7799 .47702 L
s
.7799 .47702 m
.7799 .47702 L
s
.7799 .47702 m
.7799 .47702 L
s
.7799 .47702 m
.7799 .47702 L
s
.7799 .47702 m
.7799 .47702 L
s
.7799 .47702 m
.7799 .47702 L
s
.7799 .47702 m
.7799 .47702 L
s
.7799 .47702 m
.7799 .47702 L
s
1 .017 0 r
.37573 .77094 m
.37563 .77101 L
s
.37564 .7707 m
.37573 .77094 L
s
.37585 .77079 m
.37573 .77094 L
s
.37555 .77078 m
.37564 .7707 L
s
.37564 .7707 m
.37585 .77079 L
s
1 .003 0 r
.62342 .69739 m
.62354 .69729 L
s
.62352 .69728 m
.62355 .69732 L
s
.62349 .6973 m
.62352 .69728 L
s
.62352 .69728 m
.62354 .69729 L
s
.62355 .69732 m
.62352 .69734 L
s
.62354 .69729 m
.62355 .69732 L
s
1 .017 0 r
.37585 .77079 m
.37563 .77101 L
s
.37555 .77078 m
.37585 .77079 L
s
.37563 .77101 m
.37555 .77078 L
s
1 .003 0 r
.62352 .69734 m
.62349 .6973 L
s
.62349 .6973 m
.62354 .69729 L
s
.62354 .69729 m
.62352 .69734 L
s
1 .008 0 r
.42596 .64824 m
.42636 .64802 L
s
1 0 0 r
.87209 .62366 m
.8721 .62365 L
s
.8721 .62364 m
.87211 .62365 L
s
.8721 .62365 m
.8721 .62364 L
s
.8721 .62364 m
.8721 .62365 L
s
.87211 .62365 m
.8721 .62365 L
s
.8721 .62365 m
.87211 .62365 L
s
.8721 .62365 m
.8721 .62365 L
s
.8721 .62365 m
.8721 .62365 L
s
.8721 .62365 m
.8721 .62365 L
s
1 .008 0 r
.42628 .648 m
.42634 .6481 L
s
.42623 .64803 m
.42628 .648 L
s
.42628 .648 m
.42636 .64802 L
s
.42634 .6481 m
.42628 .64813 L
s
.42636 .64802 m
.42634 .6481 L
s
.42628 .64813 m
.42623 .64803 L
s
.42623 .64803 m
.42636 .64802 L
s
.42636 .64802 m
.42628 .64813 L
s
1 0 0 r
.67464 .57449 m
.67465 .57447 L
s
.67465 .57447 m
.67465 .57448 L
s
.67464 .57448 m
.67465 .57447 L
s
.67465 .57447 m
.67465 .57447 L
s
.67465 .57448 m
.67465 .57448 L
s
.67465 .57447 m
.67465 .57448 L
s
.67465 .57448 m
.67464 .57448 L
s
.67464 .57448 m
.67465 .57447 L
s
.67465 .57447 m
.67465 .57448 L
s
1 .01 0 r
.51811 .79492 m
.5186 .79468 L
s
1 .001 0 r
.47714 .52532 m
.47717 .52529 L
s
.47716 .52529 m
.47717 .5253 L
s
.47716 .5253 m
.47716 .52529 L
s
.47716 .52529 m
.47717 .52529 L
s
.47717 .5253 m
.47716 .5253 L
s
.47717 .52529 m
.47717 .5253 L
s
.47716 .5253 m
.47716 .5253 L
s
.47716 .5253 m
.47717 .52529 L
s
.47717 .52529 m
.47716 .5253 L
s
1 0 0 r
.92337 .50073 m
.92337 .50073 L
s
.92337 .50073 m
.92337 .50073 L
s
.92337 .50073 m
.92337 .50073 L
s
.92337 .50073 m
.92337 .50073 L
s
.92337 .50073 m
.92337 .50073 L
s
.92337 .50073 m
.92337 .50073 L
s
.92337 .50073 m
.92337 .50073 L
s
.92337 .50073 m
.92337 .50073 L
s
.92337 .50073 m
.92337 .50073 L
s
1 .01 0 r
.5185 .79464 m
.51857 .79476 L
s
.51843 .79469 m
.5185 .79464 L
s
.5185 .79464 m
.5186 .79468 L
s
.51857 .79476 m
.5185 .79481 L
s
.5186 .79468 m
.51857 .79476 L
s
1 .002 0 r
.76683 .72119 m
.7669 .72113 L
s
1 .01 0 r
.5185 .79481 m
.51843 .79469 L
s
.51843 .79469 m
.5186 .79468 L
s
1 .001 0 r
.27962 .47614 m
.27966 .47612 L
s
1 .01 0 r
.5186 .79468 m
.5185 .79481 L
s
1 .001 0 r
.27966 .47613 m
.27965 .47613 L
s
.27965 .47612 m
.27966 .47613 L
s
.27966 .47612 m
.27966 .47613 L
s
.27965 .47612 m
.27965 .47612 L
s
.27965 .47612 m
.27966 .47612 L
s
.27966 .47612 m
.27965 .47613 L
s
.27965 .47612 m
.27966 .47612 L
s
.27965 .47613 m
.27965 .47612 L
s
1 .002 0 r
.76688 .72112 m
.7669 .72114 L
s
.76687 .72113 m
.76688 .72112 L
s
.76688 .72112 m
.7669 .72113 L
s
.7669 .72114 m
.76689 .72115 L
s
.7669 .72113 m
.7669 .72114 L
s
.76689 .72115 m
.76687 .72113 L
s
.76687 .72113 m
.7669 .72113 L
s
.7669 .72113 m
.76689 .72115 L
s
1 0 0 r
.72588 .45154 m
.72588 .45154 L
s
.72588 .45154 m
.72588 .45154 L
s
.72588 .45154 m
.72588 .45154 L
s
.72588 .45154 m
.72588 .45154 L
s
.72588 .45154 m
.72588 .45154 L
s
.72588 .45154 m
.72588 .45154 L
s
.72588 .45154 m
.72588 .45154 L
s
.72588 .45154 m
.72588 .45154 L
s
.72588 .45154 m
.72588 .45154 L
s
1 .004 0 r
.56932 .67202 m
.56947 .6719 L
s
.56944 .67189 m
.56947 .67193 L
s
.56941 .67191 m
.56944 .67189 L
s
.56944 .67189 m
.56947 .6719 L
s
.56947 .67193 m
.56944 .67195 L
s
.56947 .6719 m
.56947 .67193 L
s
.56944 .67195 m
.56941 .67191 L
s
.56941 .67191 m
.56947 .6719 L
s
.56947 .6719 m
.56944 .67195 L
s
1 .01 0 r
.37177 .62284 m
.3723 .6226 L
s
1 0 0 r
.8181 .59825 m
.81811 .59823 L
s
.81811 .59823 m
.81811 .59824 L
s
.81811 .59824 m
.81811 .59823 L
s
.81811 .59823 m
.81811 .59823 L
s
.81811 .59824 m
.81811 .59824 L
s
.81811 .59823 m
.81811 .59824 L
s
.81811 .59824 m
.81811 .59824 L
s
.81811 .59824 m
.81811 .59823 L
s
.81811 .59823 m
.81811 .59824 L
s
1 .01 0 r
.37226 .62269 m
.37219 .62273 L
s
.3722 .62257 m
.37226 .62269 L
s
.3723 .6226 m
.37226 .62269 L
s
.37213 .6226 m
.3722 .62257 L
s
.3722 .62257 m
.3723 .6226 L
s
.37219 .62273 m
.37213 .6226 L
s
.3723 .6226 m
.37219 .62273 L
s
.37213 .6226 m
.3723 .6226 L
s
1 0 0 r
.62055 .54906 m
.62056 .54904 L
s
.62056 .54904 m
.62056 .54904 L
s
.62056 .54904 m
.62056 .54904 L
s
.62056 .54904 m
.62056 .54904 L
s
.62056 .54904 m
.62056 .54905 L
s
.62056 .54904 m
.62056 .54904 L
s
.62056 .54905 m
.62056 .54904 L
s
.62056 .54904 m
.62056 .54904 L
s
.62056 .54904 m
.62056 .54905 L
s
1 .012 0 r
.46395 .76959 m
.46458 .76931 L
s
1 0 0 r
.42296 .49986 m
.42298 .49984 L
s
.42298 .49984 m
.42298 .49985 L
s
.42298 .49984 m
.42298 .49984 L
s
.42298 .49984 m
.42298 .49984 L
s
.42298 .49985 m
.42298 .49985 L
s
.42298 .49984 m
.42298 .49985 L
s
.42298 .49985 m
.42298 .49984 L
s
.42298 .49984 m
.42298 .49984 L
s
.42298 .49984 m
.42298 .49985 L
s
.86939 .47526 m
.86939 .47526 L
s
.86939 .47526 m
.86939 .47526 L
s
.86939 .47526 m
.86939 .47526 L
s
.86939 .47526 m
.86939 .47526 L
s
.86939 .47526 m
.86939 .47526 L
s
.86939 .47526 m
.86939 .47526 L
s
.86939 .47526 m
.86939 .47526 L
s
.86939 .47526 m
.86939 .47526 L
s
.86939 .47526 m
.86939 .47526 L
s
1 .012 0 r
.46453 .76941 m
.46445 .76946 L
s
.46445 .76926 m
.46453 .76941 L
s
.46458 .76931 m
.46453 .76941 L
s
.46437 .76931 m
.46445 .76926 L
s
.46445 .76926 m
.46458 .76931 L
s
1 .002 0 r
.71278 .69581 m
.71285 .69575 L
s
1 .012 0 r
.46445 .76946 m
.46437 .76931 L
s
.46458 .76931 m
.46445 .76946 L
s
.46437 .76931 m
.46458 .76931 L
s
1 .002 0 r
.71284 .69574 m
.71285 .69576 L
s
.71282 .69575 m
.71284 .69574 L
s
.71284 .69574 m
.71285 .69575 L
s
.71285 .69576 m
.71284 .69578 L
s
.71285 .69575 m
.71285 .69576 L
s
.71284 .69578 m
.71282 .69575 L
s
.71282 .69575 m
.71285 .69575 L
s
.71285 .69575 m
.71284 .69578 L
s
1 .004 0 r
.51517 .64662 m
.51535 .64648 L
s
1 0 0 r
.96167 .62202 m
.96168 .62201 L
s
.96168 .62201 m
.96168 .62201 L
s
.96168 .62201 m
.96168 .62201 L
s
.96168 .62201 m
.96168 .62201 L
s
.96168 .62201 m
.96168 .62201 L
s
.96168 .62201 m
.96168 .62201 L
s
.96168 .62201 m
.96168 .62201 L
s
.96168 .62201 m
.96168 .62201 L
s
.96168 .62201 m
.96168 .62201 L
s
1 .004 0 r
.51532 .64647 m
.51535 .64652 L
s
.51528 .6465 m
.51532 .64647 L
s
.51532 .64647 m
.51535 .64648 L
s
.51535 .64652 m
.51532 .64655 L
s
.51535 .64648 m
.51535 .64652 L
s
.51532 .64655 m
.51528 .6465 L
s
.51528 .6465 m
.51535 .64648 L
s
.51535 .64648 m
.51532 .64655 L
s
1 .012 0 r
.31753 .59742 m
.31824 .59718 L
s
1 0 0 r
.76406 .57281 m
.76407 .5728 L
s
.76407 .5728 m
.76407 .5728 L
s
.76406 .5728 m
.76407 .5728 L
s
.76407 .5728 m
.76407 .5728 L
s
.76407 .5728 m
.76407 .57281 L
s
.76407 .5728 m
.76407 .5728 L
s
.76407 .57281 m
.76406 .5728 L
s
.76406 .5728 m
.76407 .5728 L
s
.76407 .5728 m
.76407 .57281 L
s
1 .012 0 r
.31817 .59728 m
.31809 .59732 L
s
.3181 .59712 m
.31817 .59728 L
s
.31824 .59718 m
.31817 .59728 L
s
.31803 .59716 m
.3181 .59712 L
s
.3181 .59712 m
.31824 .59718 L
s
1 .006 0 r
.60741 .79343 m
.6077 .79324 L
s
1 .012 0 r
.31824 .59718 m
.31809 .59732 L
s
.31803 .59716 m
.31824 .59718 L
s
.31809 .59732 m
.31803 .59716 L
s
1 0 0 r
.56641 .5236 m
.56642 .52359 L
s
.56642 .52358 m
.56642 .52359 L
s
.56642 .52359 m
.56642 .52358 L
s
.56642 .52358 m
.56642 .52359 L
s
.56642 .52359 m
.56642 .52359 L
s
.56642 .52359 m
.56642 .52359 L
s
.56642 .52359 m
.56642 .52359 L
s
.56642 .52359 m
.56642 .52359 L
s
.56642 .52359 m
.56642 .52359 L
s
1 .006 0 r
.60764 .79322 m
.60769 .7933 L
s
.60759 .79326 m
.60764 .79322 L
s
.60764 .79322 m
.6077 .79324 L
s
.60769 .7933 m
.60764 .79334 L
s
.6077 .79324 m
.60769 .7933 L
s
1 .014 0 r
.40974 .74423 m
.41056 .74391 L
s
1 .006 0 r
.60764 .79334 m
.60759 .79326 L
s
.60759 .79326 m
.6077 .79324 L
s
.6077 .79324 m
.60764 .79334 L
s
1 .001 0 r
.85635 .71963 m
.85639 .71959 L
s
1 0 0 r
.36874 .47437 m
.36874 .47437 L
s
.36874 .47437 m
.36874 .47437 L
s
.36874 .47437 m
.36874 .47437 L
s
.36874 .47437 m
.36874 .47437 L
s
.36874 .47437 m
.36874 .47437 L
s
.36874 .47437 m
.36874 .47437 L
s
.36874 .47437 m
.36874 .47437 L
s
.36874 .47437 m
.36874 .47437 L
s
.36874 .47437 m
.36874 .47437 L
s
1 .001 0 r
.85638 .71958 m
.85639 .7196 L
s
.85637 .71959 m
.85638 .71958 L
s
.85638 .71958 m
.85639 .71959 L
s
.85639 .7196 m
.85638 .7196 L
s
.85639 .71959 m
.85639 .7196 L
s
.85638 .7196 m
.85637 .71959 L
s
.85637 .71959 m
.85639 .71959 L
s
.85639 .71959 m
.85638 .7196 L
s
1 0 0 r
.81536 .44976 m
.81536 .44976 L
s
.81536 .44976 m
.81536 .44976 L
s
.81536 .44976 m
.81536 .44976 L
s
.81536 .44976 m
.81536 .44976 L
s
.81536 .44976 m
.81536 .44976 L
s
.81536 .44976 m
.81536 .44976 L
s
.81536 .44976 m
.81536 .44976 L
s
.81536 .44976 m
.81536 .44976 L
s
.81536 .44976 m
.81536 .44976 L
s
1 .014 0 r
.41048 .74404 m
.41039 .7441 L
s
.4104 .74385 m
.41048 .74404 L
s
.41056 .74391 m
.41048 .74404 L
s
.4103 .74391 m
.4104 .74385 L
s
.4104 .74385 m
.41056 .74391 L
s
1 .002 0 r
.65868 .67041 m
.65876 .67034 L
s
.65874 .67034 m
.65876 .67036 L
s
.65872 .67035 m
.65874 .67034 L
s
.65874 .67034 m
.65876 .67034 L
s
.65876 .67036 m
.65874 .67038 L
s
.65876 .67034 m
.65876 .67036 L
s
.65874 .67038 m
.65872 .67035 L
s
.65872 .67035 m
.65876 .67034 L
s
.65876 .67034 m
.65874 .67038 L
s
1 .014 0 r
.41039 .7441 m
.4103 .74391 L
s
.41056 .74391 m
.41039 .7441 L
s
.4103 .74391 m
.41056 .74391 L
s
1 .005 0 r
.46098 .6212 m
.4612 .62104 L
s
1 0 0 r
.90768 .59658 m
.90768 .59658 L
s
.90768 .59658 m
.90768 .59658 L
s
.90768 .59658 m
.90768 .59658 L
s
.90768 .59658 m
.90768 .59658 L
s
.90768 .59658 m
.90768 .59658 L
s
.90768 .59658 m
.90768 .59658 L
s
.90768 .59658 m
.90768 .59658 L
s
.90768 .59658 m
.90768 .59658 L
s
.90768 .59658 m
.90768 .59658 L
s
1 .005 0 r
.46116 .62103 m
.4612 .62109 L
s
.46112 .62105 m
.46116 .62103 L
s
.46116 .62103 m
.4612 .62104 L
s
.4612 .62109 m
.46116 .62112 L
s
.4612 .62104 m
.4612 .62109 L
s
.46116 .62112 m
.46112 .62105 L
s
.46112 .62105 m
.4612 .62104 L
s
.4612 .62104 m
.46116 .62112 L
s
1 0 0 r
.70997 .54735 m
.70998 .54735 L
s
.70998 .54734 m
.70998 .54735 L
s
.70997 .54735 m
.70998 .54734 L
s
.70998 .54734 m
.70998 .54735 L
s
.70998 .54735 m
.70998 .54735 L
s
.70998 .54735 m
.70998 .54735 L
s
.70998 .54735 m
.70997 .54735 L
s
.70997 .54735 m
.70998 .54735 L
s
.70998 .54735 m
.70998 .54735 L
s
1 .008 0 r
.55325 .76807 m
.5536 .76786 L
s
1 0 0 r
.51223 .49811 m
.51224 .49811 L
s
.51223 .49811 m
.51224 .49811 L
s
.51223 .49811 m
.51223 .49811 L
s
.51223 .49811 m
.51224 .49811 L
s
.51224 .49811 m
.51223 .49811 L
s
.51224 .49811 m
.51224 .49811 L
s
.51223 .49811 m
.51223 .49811 L
s
.51223 .49811 m
.51224 .49811 L
s
.51224 .49811 m
.51223 .49811 L
s
1 .008 0 r
.55353 .76783 m
.55359 .76792 L
s
.55347 .76787 m
.55353 .76783 L
s
.55353 .76783 m
.5536 .76786 L
s
.55359 .76792 m
.55353 .76796 L
s
.5536 .76786 m
.55359 .76792 L
s
1 .018 0 r
.35548 .71884 m
.35655 .71851 L
s
1 .008 0 r
.55353 .76796 m
.55347 .76787 L
s
.55347 .76787 m
.5536 .76786 L
s
.5536 .76786 m
.55353 .76796 L
s
1 .001 0 r
.80229 .69423 m
.80233 .69419 L
s
1 0 0 r
.31446 .44887 m
.31446 .44887 L
s
.31446 .44887 m
.31446 .44887 L
s
.31446 .44887 m
.31446 .44887 L
s
.31446 .44887 m
.31446 .44887 L
s
.31446 .44887 m
.31446 .44887 L
s
.31446 .44887 m
.31446 .44887 L
s
.31446 .44887 m
.31446 .44887 L
s
.31446 .44887 m
.31446 .44887 L
s
.31446 .44887 m
.31446 .44887 L
s
1 .001 0 r
.80232 .69419 m
.80234 .6942 L
s
.80231 .69419 m
.80232 .69419 L
s
.80232 .69419 m
.80233 .69419 L
s
.80234 .6942 m
.80233 .69421 L
s
.80233 .69419 m
.80234 .6942 L
s
.80233 .69421 m
.80231 .69419 L
s
.80231 .69419 m
.80233 .69419 L
s
.80233 .69419 m
.80233 .69421 L
s
1 .018 0 r
.35643 .71866 m
.35633 .71873 L
s
.35634 .71843 m
.35643 .71866 L
s
.35655 .71851 m
.35643 .71866 L
s
.35624 .7185 m
.35634 .71843 L
s
.35634 .71843 m
.35655 .71851 L
s
1 .002 0 r
.60453 .64499 m
.60462 .64492 L
s
.6046 .64491 m
.60462 .64494 L
s
.60458 .64492 m
.6046 .64491 L
s
.6046 .64491 m
.60462 .64492 L
s
.60462 .64494 m
.6046 .64495 L
s
.60462 .64492 m
.60462 .64494 L
s
.6046 .64495 m
.60458 .64492 L
s
.60458 .64492 m
.60462 .64492 L
s
.60462 .64492 m
.6046 .64495 L
s
1 .018 0 r
.35655 .71851 m
.35633 .71873 L
s
.35624 .7185 m
.35655 .71851 L
s
.35633 .71873 m
.35624 .7185 L
s
1 .006 0 r
.40673 .59575 m
.40702 .59558 L
s
1 0 0 r
.85363 .57113 m
.85364 .57112 L
s
.85364 .57112 m
.85364 .57112 L
s
.85364 .57112 m
.85364 .57112 L
s
.85364 .57112 m
.85364 .57112 L
s
.85364 .57112 m
.85364 .57112 L
s
.85364 .57112 m
.85364 .57112 L
s
.85364 .57112 m
.85364 .57112 L
s
.85364 .57112 m
.85364 .57112 L
s
.85364 .57112 m
.85364 .57112 L
s
1 .006 0 r
.40697 .59556 m
.40701 .59564 L
s
.40692 .59559 m
.40697 .59556 L
s
.40697 .59556 m
.40702 .59558 L
s
.40701 .59564 m
.40696 .59566 L
s
.40702 .59558 m
.40701 .59564 L
s
1 .004 0 r
.69686 .79192 m
.69703 .7918 L
s
1 .006 0 r
.40696 .59566 m
.40692 .59559 L
s
.40692 .59559 m
.40702 .59558 L
s
.40702 .59558 m
.40696 .59566 L
s
1 0 0 r
.65583 .52187 m
.65584 .52187 L
s
1 .004 0 r
.69699 .79179 m
.69703 .79183 L
s
.69696 .79181 m
.69699 .79179 L
s
.69699 .79179 m
.69703 .7918 L
s
1 0 0 r
.65583 .52187 m
.65584 .52187 L
s
.65583 .52187 m
.65583 .52187 L
s
.65583 .52187 m
.65584 .52187 L
s
.65584 .52187 m
.65583 .52187 L
s
.65584 .52187 m
.65584 .52187 L
s
.65583 .52187 m
.65583 .52187 L
s
.65583 .52187 m
.65584 .52187 L
s
.65584 .52187 m
.65583 .52187 L
s
1 .004 0 r
.69703 .79183 m
.69699 .79186 L
s
.69703 .7918 m
.69703 .79183 L
s
.69699 .79186 m
.69696 .79181 L
s
.69696 .79181 m
.69703 .7918 L
s
.69703 .7918 m
.69699 .79186 L
s
1 .009 0 r
.49903 .74268 m
.49949 .74244 L
s
1 0 0 r
.458 .47261 m
.458 .47261 L
s
.458 .47261 m
.458 .47261 L
s
.458 .47261 m
.458 .47261 L
s
.458 .47261 m
.458 .47261 L
s
.458 .47261 m
.458 .47261 L
s
.458 .47261 m
.458 .47261 L
s
.458 .47261 m
.458 .47261 L
s
.458 .47261 m
.458 .47261 L
s
.458 .47261 m
.458 .47261 L
s
1 .009 0 r
.4994 .74241 m
.49946 .74252 L
s
.49933 .74245 m
.4994 .74241 L
s
.4994 .74241 m
.49949 .74244 L
s
.49946 .74252 m
.49939 .74257 L
s
.49949 .74244 m
.49946 .74252 L
s
1 0 0 r
.905 .44797 m
.905 .44797 L
s
.905 .44797 m
.905 .44797 L
s
.905 .44797 m
.905 .44797 L
s
.905 .44797 m
.905 .44797 L
s
.905 .44797 m
.905 .44797 L
s
.905 .44797 m
.905 .44797 L
s
.905 .44797 m
.905 .44797 L
s
.905 .44797 m
.905 .44797 L
s
.905 .44797 m
.905 .44797 L
s
1 .009 0 r
.49939 .74257 m
.49933 .74245 L
s
.49933 .74245 m
.49949 .74244 L
s
.49949 .74244 m
.49939 .74257 L
s
1 .001 0 r
.74819 .66881 m
.74823 .66877 L
s
.74822 .66876 m
.74823 .66878 L
s
.74821 .66877 m
.74822 .66876 L
s
.74822 .66876 m
.74823 .66877 L
s
.74823 .66878 m
.74822 .66879 L
s
.74823 .66877 m
.74823 .66878 L
s
.74822 .66879 m
.74821 .66877 L
s
.74821 .66877 m
.74823 .66877 L
s
.74823 .66877 m
.74822 .66879 L
s
1 .003 0 r
.55033 .61955 m
.55043 .61946 L
s
.55041 .61946 m
.55043 .61949 L
s
.55038 .61947 m
.55041 .61946 L
s
.55041 .61946 m
.55043 .61946 L
s
.55043 .61949 m
.55041 .6195 L
s
.55043 .61946 m
.55043 .61949 L
s
.55041 .6195 m
.55038 .61947 L
s
.55038 .61947 m
.55043 .61946 L
s
.55043 .61946 m
.55041 .6195 L
s
1 .007 0 r
.35244 .57028 m
.35282 .5701 L
s
1 0 0 r
.79954 .54565 m
.79954 .54564 L
s
.79954 .54564 m
.79954 .54564 L
s
.79954 .54564 m
.79954 .54564 L
s
.79954 .54564 m
.79954 .54564 L
s
.79954 .54564 m
.79954 .54564 L
s
.79954 .54564 m
.79954 .54564 L
s
.79954 .54564 m
.79954 .54564 L
s
.79954 .54564 m
.79954 .54564 L
s
.79954 .54564 m
.79954 .54564 L
s
1 .007 0 r
.3528 .57017 m
.35274 .57019 L
s
.35275 .57007 m
.3528 .57017 L
s
.35282 .5701 m
.3528 .57017 L
s
.3527 .5701 m
.35275 .57007 L
s
.35275 .57007 m
.35282 .5701 L
s
1 .005 0 r
.64269 .76654 m
.64289 .7664 L
s
1 .007 0 r
.35274 .57019 m
.3527 .5701 L
s
.35282 .5701 m
.35274 .57019 L
s
.3527 .5701 m
.35282 .5701 L
s
1 0 0 r
.60164 .49637 m
.60165 .49636 L
s
.60165 .49636 m
.60165 .49637 L
s
.60164 .49636 m
.60165 .49636 L
s
.60165 .49636 m
.60165 .49636 L
s
.60165 .49637 m
.60165 .49637 L
s
.60165 .49636 m
.60165 .49637 L
s
.60165 .49637 m
.60164 .49636 L
s
.60164 .49636 m
.60165 .49636 L
s
.60165 .49636 m
.60165 .49637 L
s
1 .005 0 r
.64285 .76638 m
.64289 .76644 L
s
.64281 .76641 m
.64285 .76638 L
s
.64285 .76638 m
.64289 .7664 L
s
.64289 .76644 m
.64285 .76647 L
s
.64289 .7664 m
.64289 .76644 L
s
.64285 .76647 m
.64281 .76641 L
s
.64281 .76641 m
.64289 .7664 L
s
.64289 .7664 m
.64285 .76647 L
s
1 .011 0 r
.44477 .71728 m
.44536 .71699 L
s
1 .001 0 r
.89195 .69265 m
.89198 .69262 L
s
1 0 0 r
.40371 .44708 m
.40371 .44708 L
s
.40371 .44708 m
.40371 .44708 L
s
.40371 .44708 m
.40371 .44708 L
s
.40371 .44708 m
.40371 .44708 L
s
.40371 .44708 m
.40371 .44708 L
s
.40371 .44708 m
.40371 .44708 L
s
.40371 .44708 m
.40371 .44708 L
s
.40371 .44708 m
.40371 .44708 L
s
.40371 .44708 m
.40371 .44708 L
s
1 .001 0 r
.89197 .69262 m
.89198 .69262 L
s
.89197 .69262 m
.89197 .69262 L
s
.89197 .69262 m
.89198 .69262 L
s
.89198 .69262 m
.89197 .69263 L
s
.89198 .69262 m
.89198 .69262 L
s
.89197 .69263 m
.89197 .69262 L
s
.89197 .69262 m
.89198 .69262 L
s
.89198 .69262 m
.89197 .69263 L
s
1 .011 0 r
.44532 .7171 m
.44524 .71715 L
s
.44525 .71695 m
.44532 .7171 L
s
.44536 .71699 m
.44532 .7171 L
s
.44516 .717 m
.44525 .71695 L
s
.44525 .71695 m
.44536 .71699 L
s
1 .001 0 r
.69403 .64337 m
.69408 .64332 L
s
.69407 .64332 m
.69408 .64333 L
s
.69406 .64333 m
.69407 .64332 L
s
.69407 .64332 m
.69408 .64332 L
s
.69408 .64333 m
.69407 .64334 L
s
.69408 .64332 m
.69408 .64333 L
s
1 .011 0 r
.44524 .71715 m
.44516 .717 L
s
.44536 .71699 m
.44524 .71715 L
s
.44516 .717 m
.44536 .71699 L
s
1 .001 0 r
.69407 .64334 m
.69406 .64333 L
s
.69406 .64333 m
.69408 .64332 L
s
.69408 .64332 m
.69407 .64334 L
s
1 .003 0 r
.49608 .59409 m
.49619 .59399 L
s
.49617 .59398 m
.4962 .59402 L
s
.49615 .594 m
.49617 .59398 L
s
.49617 .59398 m
.49619 .59399 L
s
.4962 .59402 m
.49617 .59403 L
s
.49619 .59399 m
.4962 .59402 L
s
1 0 0 r
.94335 .56944 m
.94336 .56944 L
s
.94336 .56944 m
.94336 .56944 L
s
.94336 .56944 m
.94336 .56944 L
s
.94336 .56944 m
.94336 .56944 L
s
.94336 .56944 m
.94336 .56944 L
s
.94336 .56944 m
.94336 .56944 L
s
1 .003 0 r
.49617 .59403 m
.49615 .594 L
s
.49615 .594 m
.49619 .59399 L
s
1 0 0 r
.94336 .56944 m
.94336 .56944 L
s
.94336 .56944 m
.94336 .56944 L
s
.94336 .56944 m
.94336 .56944 L
s
1 .003 0 r
.49619 .59399 m
.49617 .59403 L
s
.78645 .79042 m
.78656 .79033 L
s
1 .009 0 r
.29809 .54479 m
.2986 .54462 L
s
1 .003 0 r
.78653 .79032 m
.78656 .79036 L
s
.78651 .79034 m
.78653 .79032 L
s
.78653 .79032 m
.78656 .79033 L
s
.78656 .79036 m
.78654 .79037 L
s
.78656 .79033 m
.78656 .79036 L
s
.78654 .79037 m
.78651 .79034 L
s
.78651 .79034 m
.78656 .79033 L
s
.78656 .79033 m
.78654 .79037 L
s
1 0 0 r
.7454 .52014 m
.7454 .52014 L
s
.7454 .52014 m
.7454 .52014 L
s
.7454 .52014 m
.7454 .52014 L
s
.7454 .52014 m
.7454 .52014 L
s
.7454 .52014 m
.7454 .52014 L
s
.7454 .52014 m
.7454 .52014 L
s
.7454 .52014 m
.7454 .52014 L
s
.7454 .52014 m
.7454 .52014 L
s
.7454 .52014 m
.7454 .52014 L
s
1 .009 0 r
.29855 .5447 m
.29849 .54472 L
s
.2985 .54458 m
.29855 .5447 L
s
.2986 .54462 m
.29855 .5447 L
s
.29845 .54461 m
.2985 .54458 L
s
.2985 .54458 m
.2986 .54462 L
s
1 .006 0 r
.58847 .74114 m
.58872 .74097 L
s
1 .009 0 r
.2986 .54462 m
.29849 .54472 L
s
.29845 .54461 m
.2986 .54462 L
s
.29849 .54472 m
.29845 .54461 L
s
1 0 0 r
.54741 .47084 m
.54741 .47084 L
s
.54741 .47084 m
.54741 .47084 L
s
.54741 .47084 m
.54741 .47084 L
s
.54741 .47084 m
.54741 .47084 L
s
.54741 .47084 m
.54741 .47084 L
s
.54741 .47084 m
.54741 .47084 L
s
.54741 .47084 m
.54741 .47084 L
s
.54741 .47084 m
.54741 .47084 L
s
.54741 .47084 m
.54741 .47084 L
s
1 .006 0 r
.58867 .74095 m
.58872 .74102 L
s
.58862 .74098 m
.58867 .74095 L
s
.58867 .74095 m
.58872 .74097 L
s
.58872 .74102 m
.58867 .74105 L
s
.58872 .74097 m
.58872 .74102 L
s
.58867 .74105 m
.58862 .74098 L
s
.58862 .74098 m
.58872 .74097 L
s
1 .014 0 r
.39046 .69185 m
.39125 .69153 L
s
1 .006 0 r
.58872 .74097 m
.58867 .74105 L
s
1 .001 0 r
.83784 .6672 m
.83787 .66718 L
s
.83786 .66717 m
.83787 .66718 L
s
.83786 .66718 m
.83786 .66717 L
s
.83786 .66717 m
.83787 .66718 L
s
.83787 .66718 m
.83786 .66719 L
s
.83787 .66718 m
.83787 .66718 L
s
.83786 .66719 m
.83786 .66718 L
s
.83786 .66718 m
.83787 .66718 L
s
.83787 .66718 m
.83786 .66719 L
s
1 .014 0 r
.39118 .69166 m
.39108 .69171 L
s
.39109 .69147 m
.39118 .69166 L
s
.39125 .69153 m
.39118 .69166 L
s
.391 .69153 m
.39109 .69147 L
s
.39109 .69147 m
.39125 .69153 L
s
1 .001 0 r
.63983 .6179 m
.63987 .61785 L
s
.63986 .61785 m
.63988 .61787 L
s
.63985 .61786 m
.63986 .61785 L
s
.63986 .61785 m
.63987 .61785 L
s
.63988 .61787 m
.63987 .61788 L
s
.63987 .61785 m
.63988 .61787 L
s
.63987 .61788 m
.63985 .61786 L
s
.63985 .61786 m
.63987 .61785 L
s
.63987 .61785 m
.63987 .61788 L
s
1 .014 0 r
.39108 .69171 m
.391 .69153 L
s
.39125 .69153 m
.39108 .69171 L
s
.391 .69153 m
.39125 .69153 L
s
1 .003 0 r
.44178 .5686 m
.44192 .56849 L
s
.44189 .56848 m
.44192 .56852 L
s
.44186 .5685 m
.44189 .56848 L
s
.44189 .56848 m
.44192 .56849 L
s
.44192 .56852 m
.44189 .56854 L
s
.44192 .56849 m
.44192 .56852 L
s
1 0 0 r
.88926 .54394 m
.88926 .54394 L
s
.88926 .54394 m
.88926 .54394 L
s
.88926 .54394 m
.88926 .54394 L
s
.88926 .54394 m
.88926 .54394 L
s
.88926 .54394 m
.88926 .54394 L
s
.88926 .54394 m
.88926 .54394 L
s
.88926 .54394 m
.88926 .54394 L
s
.88926 .54394 m
.88926 .54394 L
s
.88926 .54394 m
.88926 .54394 L
s
1 .003 0 r
.44189 .56854 m
.44186 .5685 L
s
.44186 .5685 m
.44192 .56849 L
s
.44192 .56849 m
.44189 .56854 L
s
.73228 .76502 m
.7324 .76492 L
s
.73237 .76491 m
.7324 .76495 L
s
.73235 .76493 m
.73237 .76491 L
s
.73237 .76491 m
.7324 .76492 L
s
.7324 .76495 m
.73238 .76496 L
s
.7324 .76492 m
.7324 .76495 L
s
1 0 0 r
.6912 .49462 m
.69121 .49462 L
s
.69121 .49462 m
.69121 .49462 L
s
.6912 .49462 m
.69121 .49462 L
s
.69121 .49462 m
.69121 .49462 L
s
.69121 .49462 m
.69121 .49462 L
s
.69121 .49462 m
.69121 .49462 L
s
.69121 .49462 m
.6912 .49462 L
s
.6912 .49462 m
.69121 .49462 L
s
.69121 .49462 m
.69121 .49462 L
s
1 .003 0 r
.73238 .76496 m
.73235 .76493 L
s
.73235 .76493 m
.7324 .76492 L
s
.7324 .76492 m
.73238 .76496 L
s
1 .007 0 r
.53421 .71571 m
.53451 .71551 L
s
1 0 0 r
.49312 .44529 m
.49312 .44529 L
s
.49312 .44529 m
.49312 .44529 L
s
.49312 .44529 m
.49312 .44529 L
s
.49312 .44529 m
.49312 .44529 L
s
.49312 .44529 m
.49312 .44529 L
s
.49312 .44529 m
.49312 .44529 L
s
.49312 .44529 m
.49312 .44529 L
s
.49312 .44529 m
.49312 .44529 L
s
.49312 .44529 m
.49312 .44529 L
s
1 .007 0 r
.53445 .71549 m
.53451 .71558 L
s
.5344 .71553 m
.53445 .71549 L
s
.53445 .71549 m
.53451 .71551 L
s
.53451 .71558 m
.53445 .71561 L
s
.53451 .71551 m
.53451 .71558 L
s
1 .018 0 r
.3361 .6664 m
.33716 .66606 L
s
1 .007 0 r
.53445 .71561 m
.5344 .71553 L
s
.5344 .71553 m
.53451 .71551 L
s
.53451 .71551 m
.53445 .71561 L
s
1 .001 0 r
.78368 .64174 m
.78371 .64171 L
s
.7837 .64171 m
.78371 .64172 L
s
.7837 .64172 m
.7837 .64171 L
s
.7837 .64171 m
.78371 .64171 L
s
.78371 .64172 m
.7837 .64172 L
s
.78371 .64171 m
.78371 .64172 L
s
.7837 .64172 m
.7837 .64172 L
s
.7837 .64172 m
.78371 .64171 L
s
.78371 .64171 m
.7837 .64172 L
s
1 .018 0 r
.33704 .66621 m
.33694 .66628 L
s
.33695 .66598 m
.33704 .66621 L
s
.33716 .66606 m
.33704 .66621 L
s
.33685 .66604 m
.33695 .66598 L
s
.33695 .66598 m
.33716 .66606 L
s
1 .001 0 r
.58557 .59242 m
.58562 .59236 L
s
.58561 .59236 m
.58563 .59238 L
s
.5856 .59237 m
.58561 .59236 L
s
.58561 .59236 m
.58562 .59236 L
s
.58563 .59238 m
.58561 .59239 L
s
.58562 .59236 m
.58563 .59238 L
s
.58561 .59239 m
.5856 .59237 L
s
.5856 .59237 m
.58562 .59236 L
s
.58562 .59236 m
.58561 .59239 L
s
1 .018 0 r
.33716 .66606 m
.33694 .66628 L
s
.33685 .66604 m
.33716 .66606 L
s
.33694 .66628 m
.33685 .66604 L
s
1 .004 0 r
.38743 .54308 m
.3876 .54297 L
s
.38757 .54296 m
.38759 .54301 L
s
.38754 .54298 m
.38757 .54296 L
s
.38757 .54296 m
.3876 .54297 L
s
.38759 .54301 m
.38756 .54302 L
s
.3876 .54297 m
.38759 .54301 L
s
1 0 0 r
.83511 .51841 m
.83511 .51841 L
s
.83511 .51841 m
.83511 .51841 L
s
.83511 .51841 m
.83511 .51841 L
s
.83511 .51841 m
.83511 .51841 L
s
.83511 .51841 m
.83511 .51841 L
s
.83511 .51841 m
.83511 .51841 L
s
.83511 .51841 m
.83511 .51841 L
s
.83511 .51841 m
.83511 .51841 L
s
.83511 .51841 m
.83511 .51841 L
s
1 .004 0 r
.38756 .54302 m
.38754 .54298 L
s
.38754 .54298 m
.3876 .54297 L
s
.3876 .54297 m
.38756 .54302 L
s
.67806 .73959 m
.6782 .73948 L
s
.67817 .73947 m
.6782 .73951 L
s
.67814 .73949 m
.67817 .73947 L
s
.67817 .73947 m
.6782 .73948 L
s
.6782 .73951 m
.67817 .73953 L
s
.6782 .73948 m
.6782 .73951 L
s
1 0 0 r
.63696 .46907 m
.63696 .46907 L
s
.63696 .46907 m
.63696 .46907 L
s
.63696 .46907 m
.63696 .46907 L
s
.63696 .46907 m
.63696 .46907 L
s
.63696 .46907 m
.63696 .46907 L
s
.63696 .46907 m
.63696 .46907 L
s
.63696 .46907 m
.63696 .46907 L
s
.63696 .46907 m
.63696 .46907 L
s
.63696 .46907 m
.63696 .46907 L
s
1 .004 0 r
.67817 .73953 m
.67814 .73949 L
s
.67814 .73949 m
.6782 .73948 L
s
.6782 .73948 m
.67817 .73953 L
s
1 .008 0 r
.47989 .69026 m
.48029 .69003 L
s
1 .001 0 r
.92765 .6656 m
.92766 .66558 L
s
.92766 .66558 m
.92766 .66558 L
s
.92765 .66558 m
.92766 .66558 L
s
.92766 .66558 m
.92766 .66558 L
s
.92766 .66558 m
.92766 .66558 L
s
.92766 .66558 m
.92766 .66558 L
s
.92766 .66558 m
.92765 .66558 L
s
.92765 .66558 m
.92766 .66558 L
s
.92766 .66558 m
.92766 .66558 L
s
1 .008 0 r
.48021 .69 m
.48027 .6901 L
s
.48014 .69004 m
.48021 .69 L
s
.48021 .69 m
.48029 .69003 L
s
.48027 .6901 m
.48021 .69015 L
s
.48029 .69003 m
.48027 .6901 L
s
.48021 .69015 m
.48014 .69004 L
s
.48014 .69004 m
.48029 .69003 L
s
.48029 .69003 m
.48021 .69015 L
s
1 .001 0 r
.72948 .61625 m
.7295 .61623 L
s
.72949 .61622 m
.7295 .61623 L
s
.72949 .61623 m
.72949 .61622 L
s
.72949 .61622 m
.7295 .61623 L
s
.7295 .61623 m
.72949 .61624 L
s
.7295 .61623 m
.7295 .61623 L
s
.72949 .61624 m
.72949 .61623 L
s
.72949 .61623 m
.7295 .61623 L
s
.7295 .61623 m
.72949 .61624 L
s
.53127 .56691 m
.53132 .56685 L
s
.53131 .56685 m
.53133 .56687 L
s
.5313 .56686 m
.53131 .56685 L
s
.53131 .56685 m
.53132 .56685 L
s
.53133 .56687 m
.53131 .56688 L
s
.53132 .56685 m
.53133 .56687 L
s
.53131 .56688 m
.5313 .56686 L
s
.5313 .56686 m
.53132 .56685 L
s
.53132 .56685 m
.53131 .56688 L
s
1 .02 0 r
.37416 .78816 m
.37536 .7878 L
s
1 .002 0 r
.82202 .76349 m
.82209 .76342 L
s
1 .004 0 r
.33303 .51755 m
.33323 .51744 L
s
1 .002 0 r
.82208 .76342 m
.82209 .76344 L
s
.82206 .76343 m
.82208 .76342 L
s
.82208 .76342 m
.82209 .76342 L
s
.82209 .76344 m
.82208 .76345 L
s
.82209 .76342 m
.82209 .76344 L
s
.82208 .76345 m
.82206 .76343 L
s
.82206 .76343 m
.82209 .76342 L
s
.82209 .76342 m
.82208 .76345 L
s
1 .004 0 r
.33322 .51748 m
.33319 .51749 L
s
.33319 .51743 m
.33322 .51748 L
s
.33323 .51744 m
.33322 .51748 L
s
.33316 .51744 m
.33319 .51743 L
s
.33319 .51743 m
.33323 .51744 L
s
1 0 0 r
.78091 .49287 m
.78091 .49287 L
s
.78091 .49287 m
.78091 .49287 L
s
.78091 .49287 m
.78091 .49287 L
s
.78091 .49287 m
.78091 .49287 L
s
.78091 .49287 m
.78091 .49287 L
s
.78091 .49287 m
.78091 .49287 L
s
.78091 .49287 m
.78091 .49287 L
s
.78091 .49287 m
.78091 .49287 L
s
.78091 .49287 m
.78091 .49287 L
s
1 .004 0 r
.33319 .51749 m
.33316 .51744 L
s
.33323 .51744 m
.33319 .51749 L
s
.33316 .51744 m
.33323 .51744 L
s
1 .02 0 r
.37523 .78796 m
.37512 .78805 L
s
.37513 .7877 m
.37523 .78796 L
s
.37536 .7878 m
.37523 .78796 L
s
.37502 .78778 m
.37513 .7877 L
s
.37513 .7877 m
.37536 .7878 L
s
1 .004 0 r
.62379 .71414 m
.62395 .71401 L
s
1 0 0 r
.58267 .4435 m
.58267 .4435 L
s
.58267 .4435 m
.58267 .4435 L
s
.58267 .4435 m
.58267 .4435 L
s
.58267 .4435 m
.58267 .4435 L
s
.58267 .4435 m
.58267 .4435 L
s
.58267 .4435 m
.58267 .4435 L
s
.58267 .4435 m
.58267 .4435 L
s
.58267 .4435 m
.58267 .4435 L
s
.58267 .4435 m
.58267 .4435 L
s
1 .004 0 r
.62392 .714 m
.62395 .71405 L
s
.62388 .71403 m
.62392 .714 L
s
.62392 .714 m
.62395 .71401 L
s
.62395 .71405 m
.62392 .71407 L
s
.62395 .71401 m
.62395 .71405 L
s
.62392 .71407 m
.62388 .71403 L
s
.62388 .71403 m
.62395 .71401 L
s
.62395 .71401 m
.62392 .71407 L
s
1 .02 0 r
.37536 .7878 m
.37512 .78805 L
s
.37502 .78778 m
.37536 .7878 L
s
.37512 .78805 m
.37502 .78778 L
s
1 .01 0 r
.42553 .66479 m
.42605 .66451 L
s
1 0 0 r
.87348 .64011 m
.8735 .64009 L
s
.87349 .64009 m
.8735 .6401 L
s
.87349 .64009 m
.87349 .64009 L
s
.87349 .64009 m
.8735 .64009 L
s
.8735 .6401 m
.8735 .6401 L
s
.8735 .64009 m
.8735 .6401 L
s
.8735 .6401 m
.87349 .64009 L
s
.87349 .64009 m
.8735 .64009 L
s
.8735 .64009 m
.8735 .6401 L
s
1 .01 0 r
.42595 .66448 m
.42602 .66461 L
s
.42587 .66452 m
.42595 .66448 L
s
.42595 .66448 m
.42605 .66451 L
s
.42602 .66461 m
.42594 .66466 L
s
.42605 .66451 m
.42602 .66461 L
s
1 .001 0 r
.67522 .59074 m
.67524 .59072 L
s
.67524 .59072 m
.67524 .59072 L
s
.67523 .59072 m
.67524 .59072 L
s
.67524 .59072 m
.67524 .59072 L
s
.67524 .59072 m
.67524 .59073 L
s
.67524 .59072 m
.67524 .59072 L
s
1 .01 0 r
.42594 .66466 m
.42587 .66452 L
s
.42587 .66452 m
.42605 .66451 L
s
.42605 .66451 m
.42594 .66466 L
s
1 .001 0 r
.67524 .59073 m
.67523 .59072 L
s
.67523 .59072 m
.67524 .59072 L
s
.67524 .59072 m
.67524 .59073 L
s
.47692 .54137 m
.47697 .54132 L
s
.47696 .54132 m
.47697 .54133 L
s
.47695 .54132 m
.47696 .54132 L
s
.47696 .54132 m
.47697 .54132 L
s
.47697 .54133 m
.47696 .54134 L
s
.47697 .54132 m
.47697 .54133 L
s
.47696 .54134 m
.47695 .54132 L
s
.47695 .54132 m
.47697 .54132 L
s
.47697 .54132 m
.47696 .54134 L
s
1 0 0 r
.92497 .51668 m
.92497 .51668 L
s
.92497 .51668 m
.92497 .51668 L
s
.92497 .51668 m
.92497 .51668 L
s
.92497 .51668 m
.92497 .51668 L
s
.92497 .51668 m
.92497 .51668 L
s
.92497 .51668 m
.92497 .51668 L
s
.92497 .51668 m
.92497 .51668 L
s
.92497 .51668 m
.92497 .51668 L
s
.92497 .51668 m
.92497 .51668 L
s
1 .002 0 r
.76779 .73804 m
.76787 .73797 L
s
1 .003 0 r
.27859 .49199 m
.27879 .49191 L
s
.27877 .49195 m
.27875 .49196 L
s
.27875 .4919 m
.27877 .49195 L
s
.27879 .49191 m
.27877 .49195 L
s
.27873 .49191 m
.27875 .4919 L
s
.27875 .4919 m
.27879 .49191 L
s
1 .002 0 r
.76786 .73796 m
.76788 .73799 L
s
.76784 .73798 m
.76786 .73796 L
s
.76786 .73796 m
.76787 .73797 L
s
.76788 .73799 m
.76786 .738 L
s
.76787 .73797 m
.76788 .73799 L
s
.76786 .738 m
.76784 .73798 L
s
.76784 .73798 m
.76787 .73797 L
s
.76787 .73797 m
.76786 .738 L
s
1 .003 0 r
.27879 .49191 m
.27875 .49196 L
s
.27873 .49191 m
.27879 .49191 L
s
.27875 .49196 m
.27873 .49191 L
s
1 0 0 r
.72667 .46729 m
.72667 .46729 L
s
.72667 .46729 m
.72667 .46729 L
s
.72667 .46729 m
.72667 .46729 L
s
.72667 .46729 m
.72667 .46729 L
s
.72667 .46729 m
.72667 .46729 L
s
.72667 .46729 m
.72667 .46729 L
s
.72667 .46729 m
.72667 .46729 L
s
.72667 .46729 m
.72667 .46729 L
s
.72667 .46729 m
.72667 .46729 L
s
1 .005 0 r
.56947 .68867 m
.56967 .68852 L
s
.56963 .68851 m
.56967 .68857 L
s
.56959 .68854 m
.56963 .68851 L
s
.56963 .68851 m
.56967 .68852 L
s
.56967 .68857 m
.56963 .68859 L
s
.56967 .68852 m
.56967 .68857 L
s
.56963 .68859 m
.56959 .68854 L
s
.56959 .68854 m
.56967 .68852 L
s
.56967 .68852 m
.56963 .68859 L
s
1 .013 0 r
.37111 .63929 m
.37183 .63897 L
s
1 0 0 r
.81927 .6146 m
.81928 .61458 L
s
.81928 .61458 m
.81929 .61459 L
s
.81928 .61459 m
.81928 .61458 L
s
.81928 .61458 m
.81928 .61458 L
s
.81929 .61459 m
.81928 .61459 L
s
.81928 .61458 m
.81929 .61459 L
s
.81928 .61459 m
.81928 .61459 L
s
.81928 .61459 m
.81928 .61458 L
s
.81928 .61458 m
.81928 .61459 L
s
1 .013 0 r
.37178 .6391 m
.37168 .63915 L
s
.37169 .63893 m
.37178 .6391 L
s
.37183 .63897 m
.37178 .6391 L
s
.3716 .63898 m
.37169 .63893 L
s
.37169 .63893 m
.37183 .63897 L
s
1 .001 0 r
.62091 .56521 m
.62093 .56518 L
s
.62093 .56518 m
.62093 .56519 L
s
.62092 .56519 m
.62093 .56518 L
s
.62093 .56518 m
.62093 .56518 L
s
.62093 .56519 m
.62093 .5652 L
s
.62093 .56518 m
.62093 .56519 L
s
.62093 .5652 m
.62092 .56519 L
s
.62092 .56519 m
.62093 .56518 L
s
.62093 .56518 m
.62093 .5652 L
s
1 .013 0 r
.37168 .63915 m
.3716 .63898 L
s
.37183 .63897 m
.37168 .63915 L
s
.3716 .63898 m
.37183 .63897 L
s
1 .014 0 r
.46367 .78665 m
.4644 .78632 L
s
1 .001 0 r
.42252 .51581 m
.42257 .51576 L
s
.42256 .51576 m
.42257 .51578 L
s
.42255 .51577 m
.42256 .51576 L
s
.42256 .51576 m
.42257 .51576 L
s
.42257 .51578 m
.42256 .51579 L
s
.42257 .51576 m
.42257 .51578 L
s
.42256 .51579 m
.42255 .51577 L
s
.42255 .51577 m
.42257 .51576 L
s
.42257 .51576 m
.42256 .51579 L
s
1 0 0 r
.87077 .49111 m
.87077 .49111 L
s
.87077 .49111 m
.87077 .49111 L
s
.87077 .49111 m
.87077 .49111 L
s
.87077 .49111 m
.87077 .49111 L
s
.87077 .49111 m
.87077 .49111 L
s
.87077 .49111 m
.87077 .49111 L
s
.87077 .49111 m
.87077 .49111 L
s
.87077 .49111 m
.87077 .49111 L
s
.87077 .49111 m
.87077 .49111 L
s
1 .014 0 r
.46435 .78644 m
.46425 .78651 L
s
.46426 .78626 m
.46435 .78644 L
s
.4644 .78632 m
.46435 .78644 L
s
.46416 .78633 m
.46426 .78626 L
s
.46426 .78626 m
.4644 .78632 L
s
1 .002 0 r
.71352 .71257 m
.71361 .71249 L
s
.71359 .71248 m
.71361 .71251 L
s
.71357 .7125 m
.71359 .71248 L
s
.71359 .71248 m
.71361 .71249 L
s
.71361 .71251 m
.71359 .71253 L
s
.71361 .71249 m
.71361 .71251 L
s
.71359 .71253 m
.71357 .7125 L
s
.71357 .7125 m
.71361 .71249 L
s
.71361 .71249 m
.71359 .71253 L
s
1 0 0 r
.67237 .4417 m
.67237 .4417 L
s
.67237 .4417 m
.67237 .4417 L
s
.67237 .4417 m
.67237 .4417 L
s
.67237 .4417 m
.67237 .4417 L
s
.67237 .4417 m
.67237 .4417 L
s
.67237 .4417 m
.67237 .4417 L
s
.67237 .4417 m
.67237 .4417 L
s
.67237 .4417 m
.67237 .4417 L
s
.67237 .4417 m
.67237 .4417 L
s
1 .014 0 r
.46425 .78651 m
.46416 .78633 L
s
.4644 .78632 m
.46425 .78651 L
s
.46416 .78633 m
.4644 .78632 L
s
1 .006 0 r
.5151 .66318 m
.51535 .663 L
s
1 0 0 r
.96343 .63848 m
.96344 .63846 L
s
.96344 .63846 m
.96344 .63847 L
s
.96344 .63847 m
.96344 .63846 L
s
.96344 .63846 m
.96344 .63846 L
s
.96344 .63847 m
.96344 .63847 L
s
.96344 .63846 m
.96344 .63847 L
s
.96344 .63847 m
.96344 .63847 L
s
.96344 .63847 m
.96344 .63846 L
s
.96344 .63846 m
.96344 .63847 L
s
1 .006 0 r
.5153 .66299 m
.51534 .66305 L
s
.51525 .66301 m
.5153 .66299 L
s
.5153 .66299 m
.51535 .663 L
s
.51534 .66305 m
.5153 .66308 L
s
.51535 .663 m
.51534 .66305 L
s
.5153 .66308 m
.51525 .66301 L
s
.51525 .66301 m
.51535 .663 L
s
1 .017 0 r
.31665 .61377 m
.31765 .61344 L
s
1 .006 0 r
.51535 .663 m
.5153 .66308 L
s
1 0 0 r
.76501 .58907 m
.76502 .58905 L
s
.76502 .58905 m
.76502 .58906 L
s
.76502 .58906 m
.76502 .58905 L
s
.76502 .58905 m
.76502 .58905 L
s
.76502 .58906 m
.76502 .58906 L
s
.76502 .58905 m
.76502 .58906 L
s
.76502 .58906 m
.76502 .58906 L
s
.76502 .58906 m
.76502 .58905 L
s
.76502 .58905 m
.76502 .58906 L
s
1 .017 0 r
.31755 .61359 m
.31745 .61365 L
s
.31746 .61336 m
.31755 .61359 L
s
.31765 .61344 m
.31755 .61359 L
s
.31736 .61342 m
.31746 .61336 L
s
.31746 .61336 m
.31765 .61344 L
s
1 .001 0 r
.56655 .53966 m
.56657 .53963 L
s
.56657 .53963 m
.56658 .53964 L
s
.56656 .53963 m
.56657 .53963 L
s
.56657 .53963 m
.56657 .53963 L
s
.56658 .53964 m
.56657 .53964 L
s
.56657 .53963 m
.56658 .53964 L
s
.56657 .53964 m
.56656 .53963 L
s
.56656 .53963 m
.56657 .53963 L
s
.56657 .53963 m
.56657 .53964 L
s
1 .017 0 r
.40924 .76119 m
.4102 .76082 L
s
.31765 .61344 m
.31745 .61365 L
s
.31736 .61342 m
.31765 .61344 L
s
.31745 .61365 m
.31736 .61342 L
s
1 .001 0 r
.85768 .73649 m
.85773 .73644 L
s
.36806 .49023 m
.36811 .49019 L
s
.3681 .49019 m
.36811 .49021 L
s
.36809 .4902 m
.3681 .49019 L
s
.3681 .49019 m
.36811 .49019 L
s
.36811 .49021 m
.3681 .49021 L
s
.36811 .49019 m
.36811 .49021 L
s
.85772 .73644 m
.85773 .73645 L
s
.8577 .73645 m
.85772 .73644 L
s
.85772 .73644 m
.85773 .73644 L
s
.85773 .73645 m
.85772 .73646 L
s
.85773 .73644 m
.85773 .73645 L
s
.3681 .49021 m
.36809 .4902 L
s
.36809 .4902 m
.36811 .49019 L
s
.36811 .49019 m
.3681 .49021 L
s
.85772 .73646 m
.8577 .73645 L
s
.8577 .73645 m
.85773 .73644 L
s
.85773 .73644 m
.85772 .73646 L
s
1 0 0 r
.81652 .46552 m
.81652 .46552 L
s
.81652 .46552 m
.81652 .46552 L
s
.81652 .46552 m
.81652 .46552 L
s
.81652 .46552 m
.81652 .46552 L
s
.81652 .46552 m
.81652 .46552 L
s
.81652 .46552 m
.81652 .46552 L
s
.81652 .46552 m
.81652 .46552 L
s
.81652 .46552 m
.81652 .46552 L
s
.81652 .46552 m
.81652 .46552 L
s
1 .017 0 r
.41011 .76097 m
.41 .76105 L
s
.41001 .76075 m
.41011 .76097 L
s
.4102 .76082 m
.41011 .76097 L
s
.4099 .76082 m
.41001 .76075 L
s
.41001 .76075 m
.4102 .76082 L
s
1 .003 0 r
.6592 .68708 m
.6593 .68698 L
s
.65928 .68698 m
.6593 .68701 L
s
.65925 .68699 m
.65928 .68698 L
s
.65928 .68698 m
.6593 .68698 L
s
.6593 .68701 m
.65928 .68703 L
s
.6593 .68698 m
.6593 .68701 L
s
.65928 .68703 m
.65925 .68699 L
s
.65925 .68699 m
.6593 .68698 L
s
.6593 .68698 m
.65928 .68703 L
s
1 .017 0 r
.41 .76105 m
.4099 .76082 L
s
.4102 .76082 m
.41 .76105 L
s
.4099 .76082 m
.4102 .76082 L
s
1 .007 0 r
.46068 .63766 m
.461 .63745 L
s
1 0 0 r
.90922 .61295 m
.90922 .61294 L
s
.90922 .61293 m
.90923 .61294 L
s
.90922 .61294 m
.90922 .61293 L
s
.90922 .61293 m
.90922 .61294 L
s
.90923 .61294 m
.90922 .61294 L
s
.90922 .61294 m
.90923 .61294 L
s
.90922 .61294 m
.90922 .61294 L
s
.90922 .61294 m
.90922 .61294 L
s
.90922 .61294 m
.90922 .61294 L
s
1 .007 0 r
.46094 .63743 m
.46099 .63752 L
s
.46088 .63746 m
.46094 .63743 L
s
.46094 .63743 m
.461 .63745 L
s
.46099 .63752 m
.46093 .63755 L
s
.461 .63745 m
.46099 .63752 L
s
.46093 .63755 m
.46088 .63746 L
s
.46088 .63746 m
.461 .63745 L
s
.461 .63745 m
.46093 .63755 L
s
1 0 0 r
.7107 .56352 m
.71071 .5635 L
s
.71071 .5635 m
.71071 .5635 L
s
.7107 .5635 m
.71071 .5635 L
s
.71071 .5635 m
.71071 .5635 L
s
.71071 .5635 m
.71071 .56351 L
s
.71071 .5635 m
.71071 .5635 L
s
.71071 .56351 m
.7107 .5635 L
s
.7107 .5635 m
.71071 .5635 L
s
.71071 .5635 m
.71071 .56351 L
s
1 .009 0 r
.55333 .78513 m
.55375 .78489 L
s
1 .001 0 r
.51215 .51408 m
.51216 .51406 L
s
.51216 .51405 m
.51217 .51406 L
s
.51216 .51406 m
.51216 .51405 L
s
.51216 .51405 m
.51216 .51406 L
s
.51217 .51406 m
.51216 .51406 L
s
.51216 .51406 m
.51217 .51406 L
s
.51216 .51406 m
.51216 .51406 L
s
.51216 .51406 m
.51216 .51406 L
s
.51216 .51406 m
.51216 .51406 L
s
1 .021 0 r
.35476 .73571 m
.35602 .73532 L
s
1 .009 0 r
.55367 .78486 m
.55374 .78497 L
s
.5536 .7849 m
.55367 .78486 L
s
.55367 .78486 m
.55375 .78489 L
s
.55374 .78497 m
.55367 .78501 L
s
.55375 .78489 m
.55374 .78497 L
s
.55367 .78501 m
.5536 .7849 L
s
.5536 .7849 m
.55375 .78489 L
s
1 .002 0 r
.8034 .711 m
.80345 .71094 L
s
1 .009 0 r
.55375 .78489 m
.55367 .78501 L
s
1 .001 0 r
.31356 .46463 m
.31359 .46461 L
s
.31359 .46461 m
.31359 .46462 L
s
.31358 .46461 m
.31359 .46461 L
s
.31359 .46461 m
.31359 .46461 L
s
.31359 .46462 m
.31359 .46462 L
s
.31359 .46461 m
.31359 .46462 L
s
.31359 .46462 m
.31358 .46461 L
s
.31358 .46461 m
.31359 .46461 L
s
.31359 .46461 m
.31359 .46462 L
s
1 .002 0 r
.80344 .71094 m
.80345 .71096 L
s
.80343 .71095 m
.80344 .71094 L
s
.80344 .71094 m
.80345 .71094 L
s
.80345 .71096 m
.80344 .71097 L
s
.80345 .71094 m
.80345 .71096 L
s
.80344 .71097 m
.80343 .71095 L
s
.80343 .71095 m
.80345 .71094 L
s
.80345 .71094 m
.80344 .71097 L
s
1 0 0 r
.76222 .4399 m
.76222 .4399 L
s
.76222 .4399 m
.76222 .4399 L
s
.76222 .4399 m
.76222 .4399 L
s
.76222 .4399 m
.76222 .4399 L
s
.76222 .4399 m
.76222 .4399 L
s
.76222 .4399 m
.76222 .4399 L
s
.76222 .4399 m
.76222 .4399 L
s
.76222 .4399 m
.76222 .4399 L
s
.76222 .4399 m
.76222 .4399 L
s
1 .021 0 r
.35589 .7355 m
.35576 .73558 L
s
.35578 .73522 m
.35589 .7355 L
s
.35602 .73532 m
.35589 .7355 L
s
.35566 .7353 m
.35578 .73522 L
s
.35578 .73522 m
.35602 .73532 L
s
1 .003 0 r
.60482 .66156 m
.60494 .66145 L
s
.60492 .66145 m
.60495 .66148 L
s
.60489 .66147 m
.60492 .66145 L
s
.60492 .66145 m
.60494 .66145 L
s
.60495 .66148 m
.60492 .6615 L
s
.60494 .66145 m
.60495 .66148 L
s
.60492 .6615 m
.60489 .66147 L
s
.60489 .66147 m
.60494 .66145 L
s
.60494 .66145 m
.60492 .6615 L
s
1 .021 0 r
.35602 .73532 m
.35576 .73558 L
s
.35566 .7353 m
.35602 .73532 L
s
1 .009 0 r
.40621 .61212 m
.40664 .61187 L
s
1 .021 0 r
.35576 .73558 m
.35566 .7353 L
s
1 0 0 r
.85495 .58739 m
.85496 .58738 L
s
.85496 .58738 m
.85496 .58739 L
s
.85495 .58738 m
.85496 .58738 L
s
.85496 .58738 m
.85496 .58738 L
s
.85496 .58739 m
.85496 .58739 L
s
.85496 .58738 m
.85496 .58739 L
s
.85496 .58739 m
.85495 .58738 L
s
.85495 .58738 m
.85496 .58738 L
s
.85496 .58738 m
.85496 .58739 L
s
1 .009 0 r
.40656 .61184 m
.40662 .61195 L
s
.40649 .61188 m
.40656 .61184 L
s
.40656 .61184 m
.40664 .61187 L
s
.40662 .61195 m
.40655 .61199 L
s
.40664 .61187 m
.40662 .61195 L
s
.40655 .61199 m
.40649 .61188 L
s
.40649 .61188 m
.40664 .61187 L
s
.40664 .61187 m
.40655 .61199 L
s
1 0 0 r
.65634 .53794 m
.65635 .53792 L
s
.65634 .53792 m
.65635 .53793 L
s
.65634 .53793 m
.65634 .53792 L
s
.65634 .53792 m
.65635 .53792 L
s
.65635 .53793 m
.65634 .53793 L
s
.65635 .53792 m
.65635 .53793 L
s
.65634 .53793 m
.65634 .53793 L
s
.65634 .53793 m
.65635 .53792 L
s
.65635 .53792 m
.65634 .53793 L
s
1 .011 0 r
.4989 .75966 m
.49944 .75936 L
s
1 0 0 r
.45769 .48847 m
.4577 .48846 L
s
.4577 .48846 m
.4577 .48846 L
s
.4577 .48846 m
.4577 .48846 L
s
.4577 .48846 m
.4577 .48846 L
s
.4577 .48846 m
.4577 .48846 L
s
.4577 .48846 m
.4577 .48846 L
s
.4577 .48846 m
.4577 .48846 L
s
.4577 .48846 m
.4577 .48846 L
s
.4577 .48846 m
.4577 .48846 L
s
.90652 .46374 m
.90652 .46374 L
s
.90652 .46374 m
.90652 .46374 L
s
.90652 .46374 m
.90652 .46374 L
s
.90652 .46374 m
.90652 .46374 L
s
.90652 .46374 m
.90652 .46374 L
s
.90652 .46374 m
.90652 .46374 L
s
.90652 .46374 m
.90652 .46374 L
s
.90652 .46374 m
.90652 .46374 L
s
.90652 .46374 m
.90652 .46374 L
s
1 .011 0 r
.49933 .75933 m
.49941 .75946 L
s
.49925 .75938 m
.49933 .75933 L
s
.49933 .75933 m
.49944 .75936 L
s
.49941 .75946 m
.49933 .75952 L
s
.49944 .75936 m
.49941 .75946 L
s
1 .002 0 r
.74907 .68548 m
.74913 .68542 L
s
1 0 0 r
.25901 .439 m
.25901 .439 L
s
.25901 .439 m
.25901 .439 L
s
.25901 .439 m
.25901 .439 L
s
.25901 .439 m
.25901 .439 L
s
.25901 .439 m
.25901 .439 L
s
.25901 .439 m
.25901 .439 L
s
.25901 .439 m
.25901 .439 L
s
.25901 .439 m
.25901 .439 L
s
.25901 .439 m
.25901 .439 L
s
1 .002 0 r
.74912 .68542 m
.74913 .68544 L
s
.7491 .68543 m
.74912 .68542 L
s
.74912 .68542 m
.74913 .68542 L
s
1 .011 0 r
.49933 .75952 m
.49925 .75938 L
s
.49925 .75938 m
.49944 .75936 L
s
1 .002 0 r
.74913 .68544 m
.74912 .68545 L
s
.74913 .68542 m
.74913 .68544 L
s
1 .011 0 r
.49944 .75936 m
.49933 .75952 L
s
1 .002 0 r
.74912 .68545 m
.7491 .68543 L
s
.7491 .68543 m
.74913 .68542 L
s
.74913 .68542 m
.74912 .68545 L
s
1 .004 0 r
.5504 .63602 m
.55054 .6359 L
s
.55051 .63589 m
.55054 .63593 L
s
.55048 .63591 m
.55051 .63589 L
s
.55051 .63589 m
.55054 .6359 L
s
.55054 .63593 m
.55051 .63595 L
s
.55054 .6359 m
.55054 .63593 L
s
.55051 .63595 m
.55048 .63591 L
s
.55048 .63591 m
.55054 .6359 L
s
.55054 .6359 m
.55051 .63595 L
s
1 .011 0 r
.3517 .58655 m
.3523 .58626 L
s
1 0 0 r
.80064 .56182 m
.80064 .56181 L
s
.80064 .56181 m
.80064 .56181 L
s
.80064 .56181 m
.80064 .56181 L
s
.80064 .56181 m
.80064 .56181 L
s
.80064 .56181 m
.80064 .56181 L
s
.80064 .56181 m
.80064 .56181 L
s
.80064 .56181 m
.80064 .56181 L
s
.80064 .56181 m
.80064 .56181 L
s
.80064 .56181 m
.80064 .56181 L
s
1 .006 0 r
.64314 .78362 m
.64338 .78344 L
s
1 .011 0 r
.35225 .58637 m
.35217 .58642 L
s
.35218 .58623 m
.35225 .58637 L
s
.3523 .58626 m
.35225 .58637 L
s
.3521 .58627 m
.35218 .58623 L
s
.35218 .58623 m
.3523 .58626 L
s
1 0 0 r
.60193 .51234 m
.60193 .51233 L
s
.60193 .51233 m
.60193 .51233 L
s
.60193 .51233 m
.60193 .51233 L
s
.60193 .51233 m
.60193 .51233 L
s
.60193 .51233 m
.60193 .51233 L
s
.60193 .51233 m
.60193 .51233 L
s
.60193 .51233 m
.60193 .51233 L
s
.60193 .51233 m
.60193 .51233 L
s
.60193 .51233 m
.60193 .51233 L
s
1 .011 0 r
.35217 .58642 m
.3521 .58627 L
s
.3523 .58626 m
.35217 .58642 L
s
.3521 .58627 m
.3523 .58626 L
s
1 .006 0 r
.64333 .78343 m
.64338 .7835 L
s
.64329 .78346 m
.64333 .78343 L
s
.64333 .78343 m
.64338 .78344 L
s
.64338 .7835 m
.64334 .78353 L
s
.64338 .78344 m
.64338 .7835 L
s
1 .014 0 r
.44441 .73415 m
.44512 .73381 L
s
1 .006 0 r
.64334 .78353 m
.64329 .78346 L
s
.64329 .78346 m
.64338 .78344 L
s
.64338 .78344 m
.64334 .78353 L
s
1 .001 0 r
.89343 .70942 m
.89346 .70938 L
s
1 0 0 r
.40319 .46285 m
.40319 .46284 L
s
.40319 .46284 m
.40319 .46284 L
s
.40319 .46284 m
.40319 .46284 L
s
.40319 .46284 m
.40319 .46284 L
s
.40319 .46284 m
.40319 .46284 L
s
.40319 .46284 m
.40319 .46284 L
s
.40319 .46284 m
.40319 .46284 L
s
.40319 .46284 m
.40319 .46284 L
s
.40319 .46284 m
.40319 .46284 L
s
1 .001 0 r
.89345 .70938 m
.89346 .70939 L
s
.89344 .70939 m
.89345 .70938 L
s
.89345 .70938 m
.89346 .70938 L
s
.89346 .70939 m
.89345 .7094 L
s
.89346 .70938 m
.89346 .70939 L
s
.89345 .7094 m
.89344 .70939 L
s
.89344 .70939 m
.89346 .70938 L
s
.89346 .70938 m
.89345 .7094 L
s
1 0 0 r
.85222 .4381 m
.85222 .4381 L
s
.85222 .4381 m
.85222 .4381 L
s
.85222 .4381 m
.85222 .4381 L
s
.85222 .4381 m
.85222 .4381 L
s
.85222 .4381 m
.85222 .4381 L
s
.85222 .4381 m
.85222 .4381 L
s
.85222 .4381 m
.85222 .4381 L
s
.85222 .4381 m
.85222 .4381 L
s
.85222 .4381 m
.85222 .4381 L
s
1 .014 0 r
.44508 .73394 m
.44498 .734 L
s
.44498 .73376 m
.44508 .73394 L
s
.44512 .73381 m
.44508 .73394 L
s
.44489 .73383 m
.44498 .73376 L
s
.44498 .73376 m
.44512 .73381 L
s
1 .002 0 r
.69469 .65994 m
.69476 .65988 L
s
.69474 .65988 m
.69476 .6599 L
s
.69473 .65989 m
.69474 .65988 L
s
.69474 .65988 m
.69476 .65988 L
s
.69476 .6599 m
.69474 .65991 L
s
.69476 .65988 m
.69476 .6599 L
s
.69474 .65991 m
.69473 .65989 L
s
.69473 .65989 m
.69476 .65988 L
s
.69476 .65988 m
.69474 .65991 L
s
1 .014 0 r
.44498 .734 m
.44489 .73383 L
s
.44512 .73381 m
.44498 .734 L
s
.44489 .73383 m
.44512 .73381 L
s
1 .004 0 r
.49593 .61046 m
.4961 .61031 L
s
1 0 0 r
.94504 .58571 m
.94504 .58571 L
s
.94504 .58571 m
.94505 .58571 L
s
.94504 .58571 m
.94504 .58571 L
s
.94504 .58571 m
.94504 .58571 L
s
.94505 .58571 m
.94504 .58571 L
s
.94504 .58571 m
.94505 .58571 L
s
.94504 .58571 m
.94504 .58571 L
s
.94504 .58571 m
.94504 .58571 L
s
.94504 .58571 m
.94504 .58571 L
s
1 .004 0 r
.49607 .61031 m
.4961 .61036 L
s
.49603 .61033 m
.49607 .61031 L
s
.49607 .61031 m
.4961 .61031 L
s
.4961 .61036 m
.49607 .61038 L
s
.4961 .61031 m
.4961 .61036 L
s
.49607 .61038 m
.49603 .61033 L
s
.49603 .61033 m
.4961 .61031 L
s
.4961 .61031 m
.49607 .61038 L
s
1 .014 0 r
.29713 .56097 m
.29799 .56067 L
s
1 0 0 r
.74627 .53622 m
.74627 .53621 L
s
.74627 .53621 m
.74628 .53621 L
s
.74627 .53621 m
.74627 .53621 L
s
.74627 .53621 m
.74627 .53621 L
s
.74628 .53621 m
.74627 .53621 L
s
.74627 .53621 m
.74628 .53621 L
s
.74627 .53621 m
.74627 .53621 L
s
.74627 .53621 m
.74627 .53621 L
s
.74627 .53621 m
.74627 .53621 L
s
1 .007 0 r
.5887 .75812 m
.589 .75791 L
s
1 .014 0 r
.2979 .5608 m
.29781 .56085 L
s
.29782 .56061 m
.2979 .5608 L
s
.29799 .56067 m
.2979 .5608 L
s
.29773 .56065 m
.29782 .56061 L
s
.29782 .56061 m
.29799 .56067 L
s
1 0 0 r
.54747 .48671 m
.54747 .4867 L
s
.54747 .4867 m
.54747 .48671 L
s
.54747 .48671 m
.54747 .4867 L
s
.54747 .4867 m
.54747 .4867 L
s
.54747 .48671 m
.54747 .48671 L
s
.54747 .4867 m
.54747 .48671 L
s
.54747 .48671 m
.54747 .48671 L
s
.54747 .48671 m
.54747 .4867 L
s
.54747 .4867 m
.54747 .48671 L
s
1 .014 0 r
.29799 .56067 m
.29781 .56085 L
s
.29773 .56065 m
.29799 .56067 L
s
.29781 .56085 m
.29773 .56065 L
s
1 .007 0 r
.58894 .75789 m
.589 .75798 L
s
.58889 .75793 m
.58894 .75789 L
s
.58894 .75789 m
.589 .75791 L
s
.589 .75798 m
.58894 .75801 L
s
.589 .75791 m
.589 .75798 L
s
1 .017 0 r
.38988 .70863 m
.39084 .70824 L
s
1 .007 0 r
.58894 .75801 m
.58889 .75793 L
s
.58889 .75793 m
.589 .75791 L
s
.589 .75791 m
.58894 .75801 L
s
1 .001 0 r
.8391 .68388 m
.83913 .68384 L
s
1 0 0 r
.34863 .4372 m
.34863 .4372 L
s
.34863 .4372 m
.34863 .4372 L
s
.34863 .4372 m
.34863 .4372 L
s
.34863 .4372 m
.34863 .4372 L
s
.34863 .4372 m
.34863 .4372 L
s
.34863 .4372 m
.34863 .4372 L
s
.34863 .4372 m
.34863 .4372 L
s
.34863 .4372 m
.34863 .4372 L
s
.34863 .4372 m
.34863 .4372 L
s
1 .001 0 r
.83912 .68384 m
.83913 .68385 L
s
.83911 .68385 m
.83912 .68384 L
s
.83912 .68384 m
.83913 .68384 L
s
.83913 .68385 m
.83912 .68386 L
s
.83913 .68384 m
.83913 .68385 L
s
.83912 .68386 m
.83911 .68385 L
s
.83911 .68385 m
.83913 .68384 L
s
.83913 .68384 m
.83912 .68386 L
s
1 .017 0 r
.39075 .70839 m
.39064 .70847 L
s
.39065 .70817 m
.39075 .70839 L
s
.39084 .70824 m
.39075 .70839 L
s
1 .002 0 r
.64027 .63438 m
.64033 .63431 L
s
1 .017 0 r
.39054 .70824 m
.39065 .70817 L
s
.39065 .70817 m
.39084 .70824 L
s
1 .002 0 r
.64032 .63431 m
.64034 .63433 L
s
.6403 .63432 m
.64032 .63431 L
s
.64032 .63431 m
.64033 .63431 L
s
.64034 .63433 m
.64032 .63434 L
s
.64033 .63431 m
.64034 .63433 L
s
.64032 .63434 m
.6403 .63432 L
s
.6403 .63432 m
.64033 .63431 L
s
.64033 .63431 m
.64032 .63434 L
s
1 .017 0 r
.39064 .70847 m
.39054 .70824 L
s
.39084 .70824 m
.39064 .70847 L
s
.39054 .70824 m
.39084 .70824 L
s
1 .005 0 r
.44141 .58487 m
.44163 .5847 L
s
1 0 0 r
.89072 .56011 m
.89072 .56011 L
s
.89072 .56011 m
.89073 .56011 L
s
.89072 .56011 m
.89072 .56011 L
s
.89072 .56011 m
.89072 .56011 L
s
.89073 .56011 m
.89072 .56011 L
s
.89072 .56011 m
.89073 .56011 L
s
.89072 .56011 m
.89072 .56011 L
s
.89072 .56011 m
.89072 .56011 L
s
.89072 .56011 m
.89072 .56011 L
s
1 .005 0 r
.44158 .58469 m
.44162 .58476 L
s
.44154 .58472 m
.44158 .58469 L
s
.44158 .58469 m
.44163 .5847 L
s
.44162 .58476 m
.44158 .58478 L
s
.44163 .5847 m
.44162 .58476 L
s
.44158 .58478 m
.44154 .58472 L
s
.44154 .58472 m
.44163 .5847 L
s
.44163 .5847 m
.44158 .58478 L
s
1 .004 0 r
.7331 .7821 m
.73324 .78198 L
s
.73321 .78197 m
.73325 .78201 L
s
.73318 .782 m
.73321 .78197 L
s
.73321 .78197 m
.73324 .78198 L
s
1 0 0 r
.69186 .51059 m
.69186 .51059 L
s
1 .004 0 r
.73325 .78201 m
.73322 .78204 L
s
.73324 .78198 m
.73325 .78201 L
s
1 0 0 r
.69186 .51059 m
.69186 .51059 L
s
.69186 .51059 m
.69186 .51059 L
s
.69186 .51059 m
.69186 .51059 L
s
.69186 .51059 m
.69186 .51059 L
s
.69186 .51059 m
.69186 .51059 L
s
.69186 .51059 m
.69186 .51059 L
s
.69186 .51059 m
.69186 .51059 L
s
.69186 .51059 m
.69186 .51059 L
s
1 .004 0 r
.73322 .78204 m
.73318 .782 L
s
.73318 .782 m
.73324 .78198 L
s
.73324 .78198 m
.73322 .78204 L
s
1 .008 0 r
.53421 .73259 m
.53459 .73235 L
s
1 0 0 r
.49296 .46106 m
.49296 .46106 L
s
.49296 .46106 m
.49296 .46106 L
s
.49296 .46106 m
.49296 .46106 L
s
.49296 .46106 m
.49296 .46106 L
s
.49296 .46106 m
.49296 .46106 L
s
.49296 .46106 m
.49296 .46106 L
s
.49296 .46106 m
.49296 .46106 L
s
.49296 .46106 m
.49296 .46106 L
s
.49296 .46106 m
.49296 .46106 L
s
1 .022 0 r
.33529 .68308 m
.33661 .68266 L
s
1 .008 0 r
.53451 .73233 m
.53458 .73243 L
s
.53445 .73237 m
.53451 .73233 L
s
.53451 .73233 m
.53459 .73235 L
s
.53458 .73243 m
.53451 .73247 L
s
.53459 .73235 m
.53458 .73243 L
s
.53451 .73247 m
.53445 .73237 L
s
.53445 .73237 m
.53459 .73235 L
s
.53459 .73235 m
.53451 .73247 L
s
1 .001 0 r
.78471 .65832 m
.78475 .65828 L
s
.78474 .65828 m
.78475 .65829 L
s
.78473 .65829 m
.78474 .65828 L
s
.78474 .65828 m
.78475 .65828 L
s
.78475 .65829 m
.78474 .6583 L
s
.78475 .65828 m
.78475 .65829 L
s
.78474 .6583 m
.78473 .65829 L
s
.78473 .65829 m
.78475 .65828 L
s
.78475 .65828 m
.78474 .6583 L
s
1 .022 0 r
.33646 .68285 m
.33633 .68293 L
s
.33635 .68256 m
.33646 .68285 L
s
.33661 .68266 m
.33646 .68285 L
s
1 .002 0 r
.58579 .6088 m
.58587 .60872 L
s
1 .022 0 r
.33622 .68264 m
.33635 .68256 L
s
.33635 .68256 m
.33661 .68266 L
s
1 .002 0 r
.58585 .60872 m
.58587 .60874 L
s
.58583 .60873 m
.58585 .60872 L
s
.58585 .60872 m
.58587 .60872 L
s
.58587 .60874 m
.58585 .60875 L
s
.58587 .60872 m
.58587 .60874 L
s
.58585 .60875 m
.58583 .60873 L
s
.58583 .60873 m
.58587 .60872 L
s
.58587 .60872 m
.58585 .60875 L
s
1 .006 0 r
.38683 .55926 m
.38713 .55907 L
s
1 .022 0 r
.33661 .68266 m
.33633 .68293 L
s
.33622 .68264 m
.33661 .68266 L
s
.33633 .68293 m
.33622 .68264 L
s
1 0 0 r
.83635 .53449 m
.83635 .53449 L
s
.83635 .53449 m
.83636 .53449 L
s
.83635 .53449 m
.83635 .53449 L
s
.83635 .53449 m
.83635 .53449 L
s
.83636 .53449 m
.83635 .53449 L
s
.83635 .53449 m
.83636 .53449 L
s
.83635 .53449 m
.83635 .53449 L
s
.83635 .53449 m
.83635 .53449 L
s
.83635 .53449 m
.83635 .53449 L
s
1 .006 0 r
.38707 .55905 m
.38712 .55913 L
s
.38702 .55908 m
.38707 .55905 L
s
.38707 .55905 m
.38713 .55907 L
s
.38712 .55913 m
.38707 .55916 L
s
.38713 .55907 m
.38712 .55913 L
s
1 .004 0 r
.67866 .75658 m
.67882 .75644 L
s
1 .006 0 r
.38707 .55916 m
.38702 .55908 L
s
.38702 .55908 m
.38713 .55907 L
s
.38713 .55907 m
.38707 .55916 L
s
1 0 0 r
.63739 .48495 m
.63739 .48494 L
s
.63739 .48494 m
.63739 .48494 L
s
.63739 .48494 m
.63739 .48494 L
s
.63739 .48494 m
.63739 .48494 L
s
.63739 .48494 m
.63739 .48494 L
s
.63739 .48494 m
.63739 .48494 L
s
.63739 .48494 m
.63739 .48494 L
s
.63739 .48494 m
.63739 .48494 L
s
.63739 .48494 m
.63739 .48494 L
s
1 .004 0 r
.67879 .75643 m
.67883 .75648 L
s
.67875 .75646 m
.67879 .75643 L
s
.67879 .75643 m
.67882 .75644 L
s
.67883 .75648 m
.67879 .75651 L
s
.67882 .75644 m
.67883 .75648 L
s
.67879 .75651 m
.67875 .75646 L
s
.67875 .75646 m
.67882 .75644 L
s
.67882 .75644 m
.67879 .75651 L
s
1 .01 0 r
.47967 .70705 m
.48017 .70676 L
s
1 .001 0 r
.92927 .68228 m
.92929 .68226 L
s
1 0 0 r
.4384 .43539 m
.4384 .43539 L
s
.4384 .43539 m
.4384 .43539 L
s
.4384 .43539 m
.4384 .43539 L
s
.4384 .43539 m
.4384 .43539 L
s
.4384 .43539 m
.4384 .43539 L
s
.4384 .43539 m
.4384 .43539 L
s
.4384 .43539 m
.4384 .43539 L
s
.4384 .43539 m
.4384 .43539 L
s
.4384 .43539 m
.4384 .43539 L
s
1 .001 0 r
.92929 .68225 m
.92929 .68226 L
s
.92928 .68226 m
.92929 .68225 L
s
.92929 .68225 m
.92929 .68226 L
s
.92929 .68226 m
.92929 .68227 L
s
.92929 .68226 m
.92929 .68226 L
s
.92929 .68227 m
.92928 .68226 L
s
.92928 .68226 m
.92929 .68226 L
s
.92929 .68226 m
.92929 .68227 L
s
1 .01 0 r
.48007 .70673 m
.48015 .70685 L
s
.47999 .70678 m
.48007 .70673 L
s
.48007 .70673 m
.48017 .70676 L
s
.48015 .70685 m
.48007 .7069 L
s
.48017 .70676 m
.48015 .70685 L
s
1 .001 0 r
.73028 .63274 m
.73032 .6327 L
s
.73031 .63269 m
.73032 .63271 L
s
.7303 .6327 m
.73031 .63269 L
s
.73031 .63269 m
.73032 .6327 L
s
.73032 .63271 m
.73031 .63271 L
s
.73032 .6327 m
.73032 .63271 L
s
1 .01 0 r
.48007 .7069 m
.47999 .70678 L
s
.47999 .70678 m
.48017 .70676 L
s
1 .001 0 r
.73031 .63271 m
.7303 .6327 L
s
.7303 .6327 m
.73032 .6327 L
s
1 .01 0 r
.48017 .70676 m
.48007 .7069 L
s
1 .001 0 r
.73032 .6327 m
.73031 .63271 L
s
1 .002 0 r
.53127 .58319 m
.53135 .5831 L
s
.53133 .5831 m
.53135 .58313 L
s
.53131 .58311 m
.53133 .5831 L
s
.53133 .5831 m
.53135 .5831 L
s
.53135 .58313 m
.53133 .58314 L
s
.53135 .5831 m
.53135 .58313 L
s
.53133 .58314 m
.53131 .58311 L
s
.53131 .58311 m
.53135 .5831 L
s
.53135 .5831 m
.53133 .58314 L
s
.82321 .78058 m
.8233 .7805 L
s
1 .008 0 r
.33221 .53363 m
.33262 .53341 L
s
1 .002 0 r
.82328 .78049 m
.8233 .78052 L
s
.82326 .78051 m
.82328 .78049 L
s
.82328 .78049 m
.8233 .7805 L
s
.8233 .78052 m
.82328 .78054 L
s
.8233 .7805 m
.8233 .78052 L
s
.82328 .78054 m
.82326 .78051 L
s
.82326 .78051 m
.8233 .7805 L
s
.8233 .7805 m
.82328 .78054 L
s
1 0 0 r
.78193 .50885 m
.78194 .50884 L
s
.78194 .50884 m
.78194 .50884 L
s
.78193 .50884 m
.78194 .50884 L
s
.78194 .50884 m
.78194 .50884 L
s
.78194 .50884 m
.78194 .50884 L
s
.78194 .50884 m
.78194 .50884 L
s
.78194 .50884 m
.78193 .50884 L
s
.78193 .50884 m
.78194 .50884 L
s
.78194 .50884 m
.78194 .50884 L
s
1 .008 0 r
.33259 .53349 m
.33253 .53352 L
s
.33254 .53339 m
.33259 .53349 L
s
.33262 .53341 m
.33259 .53349 L
s
.33248 .53342 m
.33254 .53339 L
s
.33254 .53339 m
.33262 .53341 L
s
1 .005 0 r
.62416 .73103 m
.62437 .73087 L
s
1 .008 0 r
.33253 .53352 m
.33248 .53342 L
s
.33262 .53341 m
.33253 .53352 L
s
.33248 .53342 m
.33262 .53341 L
s
1 0 0 r
.58288 .45927 m
.58288 .45927 L
s
.58288 .45927 m
.58288 .45927 L
s
.58288 .45927 m
.58288 .45927 L
s
.58288 .45927 m
.58288 .45927 L
s
.58288 .45927 m
.58288 .45927 L
s
.58288 .45927 m
.58288 .45927 L
s
.58288 .45927 m
.58288 .45927 L
s
.58288 .45927 m
.58288 .45927 L
s
.58288 .45927 m
.58288 .45927 L
s
1 .005 0 r
.62432 .73086 m
.62437 .73092 L
s
.62428 .73089 m
.62432 .73086 L
s
.62432 .73086 m
.62437 .73087 L
s
.62437 .73092 m
.62433 .73095 L
s
.62437 .73087 m
.62437 .73092 L
s
.62433 .73095 m
.62428 .73089 L
s
.62428 .73089 m
.62437 .73087 L
s
.62437 .73087 m
.62433 .73095 L
s
1 .013 0 r
.42509 .68148 m
.42575 .68113 L
s
1 .001 0 r
.87488 .6567 m
.87491 .65667 L
s
.8749 .65667 m
.87491 .65668 L
s
.87489 .65668 m
.8749 .65667 L
s
.8749 .65667 m
.87491 .65667 L
s
.87491 .65668 m
.8749 .65668 L
s
.87491 .65667 m
.87491 .65668 L
s
.8749 .65668 m
.87489 .65668 L
s
.87489 .65668 m
.87491 .65667 L
s
.87491 .65667 m
.8749 .65668 L
s
1 .013 0 r
.42562 .68109 m
.42571 .68125 L
s
.42552 .68115 m
.42562 .68109 L
s
.42562 .68109 m
.42575 .68113 L
s
.42571 .68125 m
.42562 .68131 L
s
.42575 .68113 m
.42571 .68125 L
s
1 .001 0 r
.6758 .60713 m
.67584 .60709 L
s
.67583 .60709 m
.67584 .6071 L
s
.67582 .60709 m
.67583 .60709 L
s
.67583 .60709 m
.67584 .60709 L
s
.67584 .6071 m
.67583 .60711 L
s
.67584 .60709 m
.67584 .6071 L
s
.67583 .60711 m
.67582 .60709 L
s
.67582 .60709 m
.67584 .60709 L
s
.67584 .60709 m
.67583 .60711 L
s
1 .013 0 r
.42562 .68131 m
.42552 .68115 L
s
.42552 .68115 m
.42575 .68113 L
s
.42575 .68113 m
.42562 .68131 L
s
1 .003 0 r
.47669 .55756 m
.47679 .55746 L
s
.47677 .55746 m
.47679 .55749 L
s
.47674 .55747 m
.47677 .55746 L
s
.47677 .55746 m
.47679 .55746 L
s
.47679 .55749 m
.47677 .5575 L
s
.47679 .55746 m
.47679 .55749 L
s
.47677 .5575 m
.47674 .55747 L
s
.47674 .55747 m
.47679 .55746 L
s
1 0 0 r
.92658 .53276 m
.92659 .53276 L
s
1 .003 0 r
.47679 .55746 m
.47677 .5575 L
s
1 0 0 r
.92659 .53276 m
.92659 .53276 L
s
.92658 .53276 m
.92659 .53276 L
s
.92659 .53276 m
.92659 .53276 L
s
.92659 .53276 m
.92659 .53276 L
s
.92659 .53276 m
.92659 .53276 L
s
.92659 .53276 m
.92658 .53276 L
s
.92658 .53276 m
.92659 .53276 L
s
.92659 .53276 m
.92659 .53276 L
s
1 .003 0 r
.76876 .75504 m
.76886 .75494 L
s
1 .009 0 r
.27754 .50797 m
.2781 .50777 L
s
1 .003 0 r
.76884 .75494 m
.76886 .75497 L
s
.76882 .75496 m
.76884 .75494 L
s
.76884 .75494 m
.76886 .75494 L
s
.76886 .75497 m
.76884 .75499 L
s
.76886 .75494 m
.76886 .75497 L
s
.76884 .75499 m
.76882 .75496 L
s
.76882 .75496 m
.76886 .75494 L
s
.76886 .75494 m
.76884 .75499 L
s
1 0 0 r
.72747 .48318 m
.72747 .48318 L
s
.72747 .48318 m
.72747 .48318 L
s
.72747 .48318 m
.72747 .48318 L
s
.72747 .48318 m
.72747 .48318 L
s
.72747 .48318 m
.72747 .48318 L
s
.72747 .48318 m
.72747 .48318 L
s
.72747 .48318 m
.72747 .48318 L
s
.72747 .48318 m
.72747 .48318 L
s
.72747 .48318 m
.72747 .48318 L
s
1 .009 0 r
.27804 .50786 m
.27798 .50789 L
s
.27799 .50773 m
.27804 .50786 L
s
.2781 .50777 m
.27804 .50786 L
s
.27793 .50776 m
.27799 .50773 L
s
.27799 .50773 m
.2781 .50777 L
s
1 .006 0 r
.56962 .70546 m
.56987 .70527 L
s
1 .009 0 r
.2781 .50777 m
.27798 .50789 L
s
.27793 .50776 m
.2781 .50777 L
s
.27798 .50789 m
.27793 .50776 L
s
1 0 0 r
.52831 .43358 m
.52831 .43358 L
s
.52831 .43358 m
.52831 .43358 L
s
.52831 .43358 m
.52831 .43358 L
s
.52831 .43358 m
.52831 .43358 L
s
.52831 .43358 m
.52831 .43358 L
s
.52831 .43358 m
.52831 .43358 L
s
.52831 .43358 m
.52831 .43358 L
s
.52831 .43358 m
.52831 .43358 L
s
.52831 .43358 m
.52831 .43358 L
s
1 .006 0 r
.56982 .70526 m
.56987 .70533 L
s
.56977 .70529 m
.56982 .70526 L
s
.56982 .70526 m
.56987 .70527 L
s
.56987 .70533 m
.56982 .70536 L
s
.56987 .70527 m
.56987 .70533 L
s
1 .017 0 r
.37045 .65588 m
.37138 .65548 L
s
1 .006 0 r
.56982 .70536 m
.56977 .70529 L
s
.56977 .70529 m
.56987 .70527 L
s
.56987 .70527 m
.56982 .70536 L
s
1 .001 0 r
.82045 .63109 m
.82047 .63107 L
s
.82047 .63107 m
.82047 .63107 L
s
.82046 .63107 m
.82047 .63107 L
s
.82047 .63107 m
.82047 .63107 L
s
.82047 .63107 m
.82047 .63108 L
s
.82047 .63107 m
.82047 .63107 L
s
.82047 .63108 m
.82046 .63107 L
s
.82046 .63107 m
.82047 .63107 L
s
.82047 .63107 m
.82047 .63108 L
s
.62127 .5815 m
.62131 .58146 L
s
1 .017 0 r
.37131 .65563 m
.37119 .6557 L
s
.3712 .65541 m
.37131 .65563 L
s
.37138 .65548 m
.37131 .65563 L
s
.37108 .65548 m
.3712 .65541 L
s
.3712 .65541 m
.37138 .65548 L
s
1 .001 0 r
.6213 .58145 m
.62131 .58147 L
s
.62129 .58146 m
.6213 .58145 L
s
.6213 .58145 m
.62131 .58146 L
s
.62131 .58147 m
.6213 .58147 L
s
.62131 .58146 m
.62131 .58147 L
s
.6213 .58147 m
.62129 .58146 L
s
.62129 .58146 m
.62131 .58146 L
s
.62131 .58146 m
.6213 .58147 L
s
1 .017 0 r
.37119 .6557 m
.37108 .65548 L
s
.37138 .65548 m
.37119 .6557 L
s
.37108 .65548 m
.37138 .65548 L
s
1 .003 0 r
.42206 .5319 m
.42218 .5318 L
s
.42215 .53179 m
.42218 .53183 L
s
.42213 .53181 m
.42215 .53179 L
s
.42215 .53179 m
.42218 .5318 L
s
.42218 .53183 m
.42215 .53184 L
s
.42218 .5318 m
.42218 .53183 L
s
1 0 0 r
.87216 .5071 m
.87216 .5071 L
s
.87216 .5071 m
.87216 .5071 L
s
.87216 .5071 m
.87216 .5071 L
s
.87216 .5071 m
.87216 .5071 L
s
.87216 .5071 m
.87216 .5071 L
s
.87216 .5071 m
.87216 .5071 L
s
.87216 .5071 m
.87216 .5071 L
s
.87216 .5071 m
.87216 .5071 L
s
.87216 .5071 m
.87216 .5071 L
s
1 .003 0 r
.42215 .53184 m
.42213 .53181 L
s
.42213 .53181 m
.42218 .5318 L
s
.42218 .5318 m
.42215 .53184 L
s
.71426 .72947 m
.71438 .72936 L
s
.71435 .72936 m
.71438 .72939 L
s
.71433 .72938 m
.71435 .72936 L
s
.71435 .72936 m
.71438 .72936 L
s
.71438 .72939 m
.71436 .72941 L
s
.71438 .72936 m
.71438 .72939 L
s
1 0 0 r
.67295 .45748 m
.67295 .45748 L
s
.67295 .45748 m
.67295 .45748 L
s
.67295 .45748 m
.67295 .45748 L
s
.67295 .45748 m
.67295 .45748 L
s
.67295 .45748 m
.67295 .45748 L
s
.67295 .45748 m
.67295 .45748 L
s
.67295 .45748 m
.67295 .45748 L
s
.67295 .45748 m
.67295 .45748 L
s
.67295 .45748 m
.67295 .45748 L
s
1 .003 0 r
.71436 .72941 m
.71433 .72938 L
s
.71433 .72938 m
.71438 .72936 L
s
.71438 .72936 m
.71436 .72941 L
s
1 .007 0 r
.51503 .67987 m
.51534 .67964 L
s
1 0 0 r
.9652 .65507 m
.96522 .65505 L
s
.96521 .65505 m
.96522 .65506 L
s
.96521 .65506 m
.96521 .65505 L
s
.96521 .65505 m
.96522 .65505 L
s
.96522 .65506 m
.96522 .65506 L
s
.96522 .65505 m
.96522 .65506 L
s
.96522 .65506 m
.96521 .65506 L
s
.96521 .65506 m
.96522 .65505 L
s
.96522 .65505 m
.96522 .65506 L
s
1 .007 0 r
.51528 .67963 m
.51534 .67971 L
s
.51522 .67967 m
.51528 .67963 L
s
.51528 .67963 m
.51534 .67964 L
s
.51534 .67971 m
.51528 .67975 L
s
.51534 .67964 m
.51534 .67971 L
s
1 .022 0 r
.31576 .63027 m
.31709 .62983 L
s
1 .007 0 r
.51528 .67975 m
.51522 .67967 L
s
.51522 .67967 m
.51534 .67964 L
s
.51534 .67964 m
.51528 .67975 L
s
1 .001 0 r
.76597 .60546 m
.76598 .60544 L
s
.76598 .60544 m
.76599 .60544 L
s
.76597 .60544 m
.76598 .60544 L
s
.76598 .60544 m
.76598 .60544 L
s
.76599 .60544 m
.76598 .60545 L
s
.76598 .60544 m
.76599 .60544 L
s
.76598 .60545 m
.76597 .60544 L
s
.76597 .60544 m
.76598 .60544 L
s
.76598 .60544 m
.76598 .60545 L
s
1 .022 0 r
.31695 .63003 m
.31682 .6301 L
s
.31684 .62973 m
.31695 .63003 L
s
.31709 .62983 m
.31695 .63003 L
s
1 .001 0 r
.56669 .55585 m
.56673 .5558 L
s
1 .022 0 r
.3167 .62981 m
.31684 .62973 L
s
.31684 .62973 m
.31709 .62983 L
s
1 .001 0 r
.56672 .5558 m
.56673 .55581 L
s
.56671 .55581 m
.56672 .5558 L
s
.56672 .5558 m
.56673 .5558 L
s
.56673 .55581 m
.56672 .55582 L
s
.56673 .5558 m
.56673 .55581 L
s
.56672 .55582 m
.56671 .55581 L
s
.56671 .55581 m
.56673 .5558 L
s
.56673 .5558 m
.56672 .55582 L
s
1 .019 0 r
.40873 .77829 m
.40984 .77787 L
s
1 .002 0 r
.85901 .75349 m
.85908 .75343 L
s
1 .003 0 r
.36739 .50622 m
.36752 .50612 L
s
1 .022 0 r
.31709 .62983 m
.31682 .6301 L
s
.3167 .62981 m
.31709 .62983 L
s
.31682 .6301 m
.3167 .62981 L
s
1 .002 0 r
.85906 .75343 m
.85908 .75344 L
s
.85905 .75344 m
.85906 .75343 L
s
.85906 .75343 m
.85908 .75343 L
s
.85908 .75344 m
.85906 .75346 L
s
.85908 .75343 m
.85908 .75344 L
s
.85906 .75346 m
.85905 .75344 L
s
.85905 .75344 m
.85908 .75343 L
s
.85908 .75343 m
.85906 .75346 L
s
1 .003 0 r
.3675 .50611 m
.36752 .50615 L
s
.36747 .50613 m
.3675 .50611 L
s
.3675 .50611 m
.36752 .50612 L
s
.36752 .50615 m
.36749 .50616 L
s
.36752 .50612 m
.36752 .50615 L
s
1 0 0 r
.81769 .48141 m
.81769 .4814 L
s
.81769 .4814 m
.81769 .4814 L
s
.81769 .4814 m
.81769 .4814 L
s
.81769 .4814 m
.81769 .4814 L
s
.81769 .4814 m
.81769 .48141 L
s
.81769 .4814 m
.81769 .4814 L
s
.81769 .48141 m
.81769 .4814 L
s
.81769 .4814 m
.81769 .4814 L
s
.81769 .4814 m
.81769 .48141 L
s
1 .003 0 r
.36749 .50616 m
.36747 .50613 L
s
.36747 .50613 m
.36752 .50612 L
s
.36752 .50612 m
.36749 .50616 L
s
1 .004 0 r
.65972 .70388 m
.65985 .70376 L
s
1 .019 0 r
.40974 .77804 m
.40961 .77813 L
s
.40962 .77779 m
.40974 .77804 L
s
.40984 .77787 m
.40974 .77804 L
s
.4095 .77787 m
.40962 .77779 L
s
.40962 .77779 m
.40984 .77787 L
s
1 .004 0 r
.65982 .70375 m
.65985 .70379 L
s
.65979 .70377 m
.65982 .70375 L
s
.65982 .70375 m
.65985 .70376 L
s
.65985 .70379 m
.65982 .70381 L
s
.65985 .70376 m
.65985 .70379 L
s
1 0 0 r
.61838 .43177 m
.61838 .43177 L
s
.61838 .43177 m
.61838 .43177 L
s
.61838 .43177 m
.61838 .43177 L
s
.61838 .43177 m
.61838 .43177 L
s
.61838 .43177 m
.61838 .43177 L
s
.61838 .43177 m
.61838 .43177 L
s
.61838 .43177 m
.61838 .43177 L
s
.61838 .43177 m
.61838 .43177 L
s
.61838 .43177 m
.61838 .43177 L
s
1 .004 0 r
.65982 .70381 m
.65979 .70377 L
s
.65979 .70377 m
.65985 .70376 L
s
.65985 .70376 m
.65982 .70381 L
s
1 .009 0 r
.46039 .65426 m
.46081 .65398 L
s
1 .019 0 r
.40961 .77813 m
.4095 .77787 L
s
.40984 .77787 m
.40961 .77813 L
s
.4095 .77787 m
.40984 .77787 L
s
1 0 0 r
.91077 .62944 m
.91078 .62943 L
s
.91078 .62943 m
.91078 .62943 L
s
.91077 .62943 m
.91078 .62943 L
s
.91078 .62943 m
.91078 .62943 L
s
.91078 .62943 m
.91078 .62943 L
s
.91078 .62943 m
.91078 .62943 L
s
.91078 .62943 m
.91077 .62943 L
s
.91077 .62943 m
.91078 .62943 L
s
.91078 .62943 m
.91078 .62943 L
s
1 .009 0 r
.46072 .65396 m
.4608 .65407 L
s
.46065 .654 m
.46072 .65396 L
s
.46072 .65396 m
.46081 .65398 L
s
.4608 .65407 m
.46072 .65411 L
s
.46081 .65398 m
.4608 .65407 L
s
1 .001 0 r
.71143 .57981 m
.71145 .57979 L
s
1 .009 0 r
.46072 .65411 m
.46065 .654 L
s
.46065 .654 m
.46081 .65398 L
s
.46081 .65398 m
.46072 .65411 L
s
1 .001 0 r
.71145 .57979 m
.71145 .57979 L
s
.71144 .57979 m
.71145 .57979 L
s
.71145 .57979 m
.71145 .57979 L
s
.71145 .57979 m
.71145 .5798 L
s
.71145 .57979 m
.71145 .57979 L
s
.71145 .5798 m
.71144 .57979 L
s
.71144 .57979 m
.71145 .57979 L
s
.71145 .57979 m
.71145 .5798 L
s
.51206 .53017 m
.5121 .53012 L
s
.51209 .53012 m
.5121 .53014 L
s
.51208 .53013 m
.51209 .53012 L
s
.51209 .53012 m
.5121 .53012 L
s
.5121 .53014 m
.51209 .53014 L
s
.5121 .53012 m
.5121 .53014 L
s
.51209 .53014 m
.51208 .53013 L
s
.51208 .53013 m
.5121 .53012 L
s
.5121 .53012 m
.51209 .53014 L
s
1 .024 0 r
.35403 .75272 m
.3555 .75227 L
s
1 .002 0 r
.80451 .7279 m
.80458 .72783 L
s
1 .003 0 r
.31266 .48052 m
.31281 .48043 L
s
1 .002 0 r
.80457 .72783 m
.80458 .72785 L
s
.80455 .72784 m
.80457 .72783 L
s
.80457 .72783 m
.80458 .72783 L
s
.80458 .72785 m
.80457 .72786 L
s
.80458 .72783 m
.80458 .72785 L
s
.80457 .72786 m
.80455 .72784 L
s
.80455 .72784 m
.80458 .72783 L
s
1 .003 0 r
.31278 .48042 m
.3128 .48046 L
s
.31276 .48043 m
.31278 .48042 L
s
.31278 .48042 m
.31281 .48043 L
s
.3128 .48046 m
.31278 .48047 L
s
.31281 .48043 m
.3128 .48046 L
s
1 .002 0 r
.80458 .72783 m
.80457 .72786 L
s
1 .003 0 r
.31278 .48047 m
.31276 .48043 L
s
.31276 .48043 m
.31281 .48043 L
s
.31281 .48043 m
.31278 .48047 L
s
1 0 0 r
.76317 .45569 m
.76317 .45569 L
s
.76317 .45569 m
.76317 .45569 L
s
.76317 .45569 m
.76317 .45569 L
s
.76317 .45569 m
.76317 .45569 L
s
.76317 .45569 m
.76317 .45569 L
s
.76317 .45569 m
.76317 .45569 L
s
.76317 .45569 m
.76317 .45569 L
s
.76317 .45569 m
.76317 .45569 L
s
.76317 .45569 m
.76317 .45569 L
s
1 .004 0 r
.60512 .67826 m
.60528 .67812 L
s
1 .024 0 r
.35534 .75247 m
.35519 .75257 L
s
.35521 .75215 m
.35534 .75247 L
s
.3555 .75227 m
.35534 .75247 L
s
.35507 .75225 m
.35521 .75215 L
s
.35521 .75215 m
.3555 .75227 L
s
1 .004 0 r
.60524 .67812 m
.60528 .67816 L
s
.60521 .67814 m
.60524 .67812 L
s
.60524 .67812 m
.60528 .67812 L
s
.60528 .67816 m
.60525 .67819 L
s
.60528 .67812 m
.60528 .67816 L
s
.60525 .67819 m
.60521 .67814 L
s
.60521 .67814 m
.60528 .67812 L
s
.60528 .67812 m
.60525 .67819 L
s
1 .012 0 r
.40569 .62862 m
.40628 .62828 L
s
1 .024 0 r
.3555 .75227 m
.35519 .75257 L
s
.35507 .75225 m
.3555 .75227 L
s
.35519 .75257 m
.35507 .75225 L
s
1 0 0 r
.85628 .60379 m
.85629 .60378 L
s
.85629 .60378 m
.85629 .60378 L
s
.85628 .60378 m
.85629 .60378 L
s
.85629 .60378 m
.85629 .60378 L
s
.85629 .60378 m
.85629 .60378 L
s
.85629 .60378 m
.85629 .60378 L
s
.85629 .60378 m
.85628 .60378 L
s
.85628 .60378 m
.85629 .60378 L
s
.85629 .60378 m
.85629 .60378 L
s
1 .012 0 r
.40616 .62824 m
.40625 .62839 L
s
.40607 .6283 m
.40616 .62824 L
s
.40616 .62824 m
.40628 .62828 L
s
.40625 .62839 m
.40616 .62845 L
s
.40628 .62828 m
.40625 .62839 L
s
1 .001 0 r
.65685 .55413 m
.65686 .55411 L
s
.65686 .55411 m
.65687 .55412 L
s
.65685 .55411 m
.65686 .55411 L
s
.65686 .55411 m
.65686 .55411 L
s
.65687 .55412 m
.65686 .55412 L
s
.65686 .55411 m
.65687 .55412 L
s
.65686 .55412 m
.65685 .55411 L
s
.65685 .55411 m
.65686 .55411 L
s
.65686 .55411 m
.65686 .55412 L
s
1 .012 0 r
.40616 .62845 m
.40607 .6283 L
s
.40607 .6283 m
.40628 .62828 L
s
.40628 .62828 m
.40616 .62845 L
s
1 .013 0 r
.49876 .77677 m
.49939 .77643 L
s
1 .001 0 r
.45738 .50447 m
.45742 .50443 L
s
.45741 .50443 m
.45742 .50444 L
s
.4574 .50443 m
.45741 .50443 L
s
.45741 .50443 m
.45742 .50443 L
s
.45742 .50444 m
.45741 .50444 L
s
.45742 .50443 m
.45742 .50444 L
s
.45741 .50444 m
.4574 .50443 L
s
.4574 .50443 m
.45742 .50443 L
s
.45742 .50443 m
.45741 .50444 L
s
1 0 0 r
.90806 .47963 m
.90806 .47963 L
s
.90806 .47963 m
.90806 .47963 L
s
.90806 .47963 m
.90806 .47963 L
s
.90806 .47963 m
.90806 .47963 L
s
.90806 .47963 m
.90806 .47963 L
s
.90806 .47963 m
.90806 .47963 L
s
.90806 .47963 m
.90806 .47963 L
s
.90806 .47963 m
.90806 .47963 L
s
.90806 .47963 m
.90806 .47963 L
s
1 .013 0 r
.49927 .77638 m
.49936 .77654 L
s
.49917 .77645 m
.49927 .77638 L
s
.49927 .77638 m
.49939 .77643 L
s
.49936 .77654 m
.49926 .77661 L
s
.49939 .77643 m
.49936 .77654 L
s
1 .002 0 r
.74996 .70229 m
.75004 .70221 L
s
.25789 .45479 m
.258 .45475 L
s
.25799 .45477 m
.25798 .45477 L
s
.25798 .45474 m
.25799 .45477 L
s
.258 .45475 m
.25799 .45477 L
s
.25797 .45475 m
.25798 .45474 L
s
.25798 .45474 m
.258 .45475 L
s
.258 .45475 m
.25798 .45477 L
s
.25797 .45475 m
.258 .45475 L
s
.25798 .45477 m
.25797 .45475 L
s
.75002 .70221 m
.75004 .70223 L
s
.75 .70222 m
.75002 .70221 L
s
.75002 .70221 m
.75004 .70221 L
s
.75004 .70223 m
.75002 .70225 L
s
.75004 .70221 m
.75004 .70223 L
s
.75002 .70225 m
.75 .70222 L
s
.75 .70222 m
.75004 .70221 L
s
.75004 .70221 m
.75002 .70225 L
s
1 0 0 r
.7086 .42995 m
.7086 .42995 L
s
.7086 .42995 m
.7086 .42995 L
s
.7086 .42995 m
.7086 .42995 L
s
.7086 .42995 m
.7086 .42995 L
s
.7086 .42995 m
.7086 .42995 L
s
.7086 .42995 m
.7086 .42995 L
s
.7086 .42995 m
.7086 .42995 L
s
.7086 .42995 m
.7086 .42995 L
s
.7086 .42995 m
.7086 .42995 L
s
1 .013 0 r
.49926 .77661 m
.49917 .77645 L
s
.49917 .77645 m
.49939 .77643 L
s
.49939 .77643 m
.49926 .77661 L
s
1 .005 0 r
.55047 .65263 m
.55066 .65246 L
s
.55063 .65245 m
.55067 .65251 L
s
.55058 .65248 m
.55063 .65245 L
s
.55063 .65245 m
.55066 .65246 L
s
.55067 .65251 m
.55063 .65254 L
s
.55066 .65246 m
.55067 .65251 L
s
.55063 .65254 m
.55058 .65248 L
s
.55058 .65248 m
.55066 .65246 L
s
.55066 .65246 m
.55063 .65254 L
s
1 .016 0 r
.35095 .60296 m
.3518 .60255 L
s
1 0 0 r
.80174 .57812 m
.80175 .5781 L
s
.80175 .5781 m
.80175 .57811 L
s
.80174 .57811 m
.80175 .5781 L
s
.80175 .5781 m
.80175 .5781 L
s
.80175 .57811 m
.80175 .57811 L
s
.80175 .5781 m
.80175 .57811 L
s
.80175 .57811 m
.80174 .57811 L
s
.80174 .57811 m
.80175 .5781 L
s
.80175 .5781 m
.80175 .57811 L
s
1 .001 0 r
.60221 .52843 m
.60223 .52841 L
s
1 .016 0 r
.35174 .6027 m
.35163 .60277 L
s
.35164 .6025 m
.35174 .6027 L
s
.3518 .60255 m
.35174 .6027 L
s
.35152 .60256 m
.35164 .6025 L
s
.35164 .6025 m
.3518 .60255 L
s
1 .001 0 r
.60222 .52841 m
.60223 .52842 L
s
.60222 .52842 m
.60222 .52841 L
s
.60222 .52841 m
.60223 .52841 L
s
.60223 .52842 m
.60222 .52842 L
s
.60223 .52841 m
.60223 .52842 L
s
.60222 .52842 m
.60222 .52842 L
s
.60222 .52842 m
.60223 .52841 L
s
.60223 .52841 m
.60222 .52842 L
s
1 .016 0 r
.44405 .75117 m
.44489 .75077 L
s
.35163 .60277 m
.35152 .60256 L
s
.3518 .60255 m
.35163 .60277 L
s
.35152 .60256 m
.3518 .60255 L
s
1 .001 0 r
.89491 .72633 m
.89496 .72629 L
s
.40265 .47874 m
.40268 .47871 L
s
.40268 .47871 m
.40268 .47872 L
s
.40267 .47872 m
.40268 .47871 L
s
.40268 .47871 m
.40268 .47871 L
s
.40268 .47872 m
.40268 .47873 L
s
.40268 .47871 m
.40268 .47872 L
s
.89495 .72628 m
.89496 .7263 L
s
.89494 .72629 m
.89495 .72628 L
s
.89495 .72628 m
.89496 .72629 L
s
.40268 .47873 m
.40267 .47872 L
s
.40267 .47872 m
.40268 .47871 L
s
.40268 .47871 m
.40268 .47873 L
s
.89496 .7263 m
.89495 .72631 L
s
.89496 .72629 m
.89496 .7263 L
s
.89495 .72631 m
.89494 .72629 L
s
.89494 .72629 m
.89496 .72629 L
s
.89496 .72629 m
.89495 .72631 L
s
1 0 0 r
.85354 .45389 m
.85354 .45389 L
s
.85354 .45389 m
.85354 .45389 L
s
.85354 .45389 m
.85354 .45389 L
s
.85354 .45389 m
.85354 .45389 L
s
.85354 .45389 m
.85354 .45389 L
s
.85354 .45389 m
.85354 .45389 L
s
.85354 .45389 m
.85354 .45389 L
s
.85354 .45389 m
.85354 .45389 L
s
.85354 .45389 m
.85354 .45389 L
s
1 .002 0 r
.69536 .67665 m
.69544 .67657 L
s
1 .016 0 r
.44483 .75091 m
.44472 .75099 L
s
.44472 .75071 m
.44483 .75091 L
s
.44489 .75077 m
.44483 .75091 L
s
.44461 .75078 m
.44472 .75071 L
s
.44472 .75071 m
.44489 .75077 L
s
1 .002 0 r
.69543 .67656 m
.69545 .67659 L
s
.69541 .67658 m
.69543 .67656 L
s
.69543 .67656 m
.69544 .67657 L
s
.69545 .67659 m
.69543 .67661 L
s
.69544 .67657 m
.69545 .67659 L
s
.69543 .67661 m
.69541 .67658 L
s
.69541 .67658 m
.69544 .67657 L
s
.69544 .67657 m
.69543 .67661 L
s
1 .016 0 r
.44472 .75099 m
.44461 .75078 L
s
.44489 .75077 m
.44472 .75099 L
s
.44461 .75078 m
.44489 .75077 L
s
1 .006 0 r
.49578 .62697 m
.49602 .62677 L
s
1 0 0 r
.94674 .60212 m
.94675 .60211 L
s
.94674 .60211 m
.94675 .60211 L
s
.94674 .60211 m
.94674 .60211 L
s
.94674 .60211 m
.94675 .60211 L
s
.94675 .60211 m
.94675 .60211 L
s
.94675 .60211 m
.94675 .60211 L
s
.94675 .60211 m
.94674 .60211 L
s
.94674 .60211 m
.94675 .60211 L
s
.94675 .60211 m
.94675 .60211 L
s
1 .006 0 r
.49597 .62676 m
.49602 .62683 L
s
.49592 .62679 m
.49597 .62676 L
s
.49597 .62676 m
.49602 .62677 L
s
.49602 .62683 m
.49597 .62686 L
s
.49602 .62677 m
.49602 .62683 L
s
1 .021 0 r
.29616 .57727 m
.29744 .57683 L
s
1 .006 0 r
.49597 .62686 m
.49592 .62679 L
s
.49592 .62679 m
.49602 .62677 L
s
.49602 .62677 m
.49597 .62686 L
s
1 0 0 r
.74715 .55242 m
.74716 .55241 L
s
.74716 .55241 m
.74716 .55241 L
s
.74715 .55241 m
.74716 .55241 L
s
.74716 .55241 m
.74716 .55241 L
s
.74716 .55241 m
.74716 .55241 L
s
.74716 .55241 m
.74716 .55241 L
s
.74716 .55241 m
.74715 .55241 L
s
.74715 .55241 m
.74716 .55241 L
s
.74716 .55241 m
.74716 .55241 L
s
1 .008 0 r
.58893 .77524 m
.58929 .775 L
s
1 .021 0 r
.29731 .57703 m
.29717 .5771 L
s
.2972 .57674 m
.29731 .57703 L
s
.29744 .57683 m
.29731 .57703 L
s
1 0 0 r
.54753 .50271 m
.54754 .50269 L
s
1 .021 0 r
.29706 .57681 m
.2972 .57674 L
s
.2972 .57674 m
.29744 .57683 L
s
1 0 0 r
.54754 .50269 m
.54754 .5027 L
s
.54753 .5027 m
.54754 .50269 L
s
.54754 .50269 m
.54754 .50269 L
s
.54754 .5027 m
.54754 .5027 L
s
.54754 .50269 m
.54754 .5027 L
s
.54754 .5027 m
.54753 .5027 L
s
.54753 .5027 m
.54754 .50269 L
s
.54754 .50269 m
.54754 .5027 L
s
1 .02 0 r
.38929 .72555 m
.39043 .72508 L
s
1 .008 0 r
.58922 .77497 m
.58928 .77507 L
s
.58915 .77502 m
.58922 .77497 L
s
.58922 .77497 m
.58929 .775 L
s
.58928 .77507 m
.58922 .77512 L
s
.58929 .775 m
.58928 .77507 L
s
.58922 .77512 m
.58915 .77502 L
s
.58915 .77502 m
.58929 .775 L
s
.58929 .775 m
.58922 .77512 L
s
1 .001 0 r
.84036 .7007 m
.8404 .70065 L
s
1 0 0 r
.34787 .453 m
.34789 .45298 L
s
.34789 .45298 m
.34789 .45298 L
s
.34788 .45298 m
.34789 .45298 L
s
.34789 .45298 m
.34789 .45298 L
s
.34789 .45298 m
.34788 .45299 L
s
.34789 .45298 m
.34789 .45298 L
s
.34788 .45299 m
.34788 .45298 L
s
.34788 .45298 m
.34789 .45298 L
s
.34789 .45298 m
.34788 .45299 L
s
1 .021 0 r
.29744 .57683 m
.29717 .5771 L
s
.29706 .57681 m
.29744 .57683 L
s
.29717 .5771 m
.29706 .57681 L
s
1 .001 0 r
.84039 .70065 m
.84041 .70066 L
s
.84038 .70066 m
.84039 .70065 L
s
.84039 .70065 m
.8404 .70065 L
s
.84041 .70066 m
.84039 .70067 L
s
.8404 .70065 m
.84041 .70066 L
s
.84039 .70067 m
.84038 .70066 L
s
.84038 .70066 m
.8404 .70065 L
s
.8404 .70065 m
.84039 .70067 L
s
1 0 0 r
.79896 .42813 m
.79896 .42813 L
s
.79896 .42813 m
.79896 .42813 L
s
.79896 .42813 m
.79896 .42813 L
s
.79896 .42813 m
.79896 .42813 L
s
.79896 .42813 m
.79896 .42813 L
s
.79896 .42813 m
.79896 .42813 L
s
.79896 .42813 m
.79896 .42813 L
s
.79896 .42813 m
.79896 .42813 L
s
.79896 .42813 m
.79896 .42813 L
s
1 .003 0 r
.64071 .65099 m
.6408 .6509 L
s
1 .02 0 r
.39033 .72527 m
.3902 .72535 L
s
.39021 .725 m
.39033 .72527 L
s
.39043 .72508 m
.39033 .72527 L
s
.39007 .72509 m
.39021 .725 L
s
.39021 .725 m
.39043 .72508 L
s
1 .003 0 r
.64078 .65089 m
.64081 .65092 L
s
.64076 .65091 m
.64078 .65089 L
s
.64078 .65089 m
.6408 .6509 L
s
.64081 .65092 m
.64079 .65094 L
s
.6408 .6509 m
.64081 .65092 L
s
.64079 .65094 m
.64076 .65091 L
s
.64076 .65091 m
.6408 .6509 L
s
.6408 .6509 m
.64079 .65094 L
s
1 .008 0 r
.44103 .60128 m
.44135 .60104 L
s
1 .02 0 r
.3902 .72535 m
.39007 .72509 L
s
.39043 .72508 m
.3902 .72535 L
s
.39007 .72509 m
.39043 .72508 L
s
1 0 0 r
.8922 .57642 m
.8922 .57641 L
s
.8922 .57641 m
.8922 .57642 L
s
.8922 .57641 m
.8922 .57641 L
s
.8922 .57641 m
.8922 .57641 L
s
.8922 .57642 m
.8922 .57642 L
s
.8922 .57641 m
.8922 .57642 L
s
.8922 .57642 m
.8922 .57641 L
s
.8922 .57641 m
.8922 .57641 L
s
.8922 .57641 m
.8922 .57642 L
s
1 .008 0 r
.44129 .60102 m
.44135 .60111 L
s
.44123 .60106 m
.44129 .60102 L
s
.44129 .60102 m
.44135 .60104 L
s
.44135 .60111 m
.44129 .60115 L
s
.44135 .60104 m
.44135 .60111 L
s
.44129 .60115 m
.44123 .60106 L
s
.44123 .60106 m
.44135 .60104 L
s
.44135 .60104 m
.44129 .60115 L
s
1 0 0 r
.69251 .5267 m
.69252 .52669 L
s
.69252 .52669 m
.69252 .52669 L
s
.69251 .52669 m
.69252 .52669 L
s
.69252 .52669 m
.69252 .52669 L
s
.69252 .52669 m
.69252 .52669 L
s
.69252 .52669 m
.69252 .52669 L
s
.69252 .52669 m
.69251 .52669 L
s
.69251 .52669 m
.69252 .52669 L
s
.69252 .52669 m
.69252 .52669 L
s
1 .01 0 r
.53422 .74962 m
.53467 .74933 L
s
1 0 0 r
.49279 .47696 m
.4928 .47695 L
s
.4928 .47695 m
.4928 .47696 L
s
.4928 .47696 m
.4928 .47695 L
s
.4928 .47695 m
.4928 .47695 L
s
.4928 .47696 m
.4928 .47696 L
s
.4928 .47695 m
.4928 .47696 L
s
.4928 .47696 m
.4928 .47696 L
s
.4928 .47696 m
.4928 .47695 L
s
.4928 .47695 m
.4928 .47696 L
s
1 .026 0 r
.33448 .6999 m
.33606 .6994 L
s
1 .01 0 r
.53458 .7493 m
.53466 .74942 L
s
.5345 .74935 m
.53458 .7493 L
s
.53458 .7493 m
.53467 .74933 L
s
.53466 .74942 m
.53458 .74947 L
s
.53467 .74933 m
.53466 .74942 L
s
1 .001 0 r
.78575 .67504 m
.7858 .67499 L
s
1 0 0 r
.29304 .42722 m
.29304 .42722 L
s
.29304 .42722 m
.29304 .42722 L
s
.29304 .42722 m
.29304 .42722 L
s
.29304 .42722 m
.29304 .42722 L
s
.29304 .42722 m
.29304 .42722 L
s
.29304 .42722 m
.29304 .42722 L
s
.29304 .42722 m
.29304 .42722 L
s
.29304 .42722 m
.29304 .42722 L
s
.29304 .42722 m
.29304 .42722 L
s
1 .01 0 r
.53458 .74947 m
.5345 .74935 L
s
.5345 .74935 m
.53467 .74933 L
s
1 .001 0 r
.78579 .67498 m
.7858 .675 L
s
.78578 .67499 m
.78579 .67498 L
s
.78579 .67498 m
.7858 .67499 L
s
1 .01 0 r
.53467 .74933 m
.53458 .74947 L
s
1 .001 0 r
.7858 .675 m
.78579 .67501 L
s
.7858 .67499 m
.7858 .675 L
s
.78579 .67501 m
.78578 .67499 L
s
.78578 .67499 m
.7858 .67499 L
s
.7858 .67499 m
.78579 .67501 L
s
1 .003 0 r
.58601 .62531 m
.58612 .6252 L
s
1 .026 0 r
.33589 .69963 m
.33573 .69973 L
s
.33575 .69928 m
.33589 .69963 L
s
.33606 .6994 m
.33589 .69963 L
s
.3356 .69938 m
.33575 .69928 L
s
.33575 .69928 m
.33606 .6994 L
s
1 .003 0 r
.5861 .6252 m
.58612 .62523 L
s
.58607 .62521 m
.5861 .6252 L
s
.5861 .6252 m
.58612 .6252 L
s
.58612 .62523 m
.5861 .62525 L
s
.58612 .6252 m
.58612 .62523 L
s
.5861 .62525 m
.58607 .62521 L
s
.58607 .62521 m
.58612 .6252 L
s
.58612 .6252 m
.5861 .62525 L
s
1 .01 0 r
.38623 .57557 m
.38669 .57527 L
s
1 0 0 r
.83761 .5507 m
.83761 .55069 L
s
.83761 .55069 m
.83761 .5507 L
s
.83761 .5507 m
.83761 .55069 L
s
.83761 .55069 m
.83761 .55069 L
s
.83761 .5507 m
.83761 .5507 L
s
.83761 .55069 m
.83761 .5507 L
s
.83761 .5507 m
.83761 .5507 L
s
.83761 .5507 m
.83761 .55069 L
s
.83761 .55069 m
.83761 .5507 L
s
1 .026 0 r
.33606 .6994 m
.33573 .69973 L
s
.3356 .69938 m
.33606 .6994 L
s
.33573 .69973 m
.3356 .69938 L
s
1 .005 0 r
.67926 .7737 m
.67946 .77354 L
s
1 .01 0 r
.3866 .57525 m
.38667 .57537 L
s
.38652 .57529 m
.3866 .57525 L
s
.3866 .57525 m
.38669 .57527 L
s
.38667 .57537 m
.38659 .57542 L
s
.38669 .57527 m
.38667 .57537 L
s
1 0 0 r
.63782 .50095 m
.63783 .50094 L
s
.63783 .50094 m
.63783 .50095 L
s
.63783 .50095 m
.63783 .50094 L
s
.63783 .50094 m
.63783 .50094 L
s
.63783 .50095 m
.63783 .50095 L
s
.63783 .50094 m
.63783 .50095 L
s
.63783 .50095 m
.63783 .50095 L
s
.63783 .50095 m
.63783 .50094 L
s
.63783 .50094 m
.63783 .50095 L
s
1 .01 0 r
.38659 .57542 m
.38652 .57529 L
s
.38652 .57529 m
.38669 .57527 L
s
.38669 .57527 m
.38659 .57542 L
s
1 .005 0 r
.67942 .77353 m
.67946 .77359 L
s
.67938 .77356 m
.67942 .77353 L
s
.67942 .77353 m
.67946 .77354 L
s
.67946 .77359 m
.67942 .77362 L
s
.67946 .77354 m
.67946 .77359 L
s
.67942 .77362 m
.67938 .77356 L
s
.67938 .77356 m
.67946 .77354 L
s
.67946 .77354 m
.67942 .77362 L
s
1 .012 0 r
.47946 .72397 m
.48005 .72362 L
s
1 .001 0 r
.93091 .6991 m
.93093 .69907 L
s
1 0 0 r
.43801 .45119 m
.43801 .45119 L
s
.43801 .45119 m
.43801 .45119 L
s
.43801 .45119 m
.43801 .45119 L
s
.43801 .45119 m
.43801 .45119 L
s
.43801 .45119 m
.43801 .45119 L
s
.43801 .45119 m
.43801 .45119 L
s
.43801 .45119 m
.43801 .45119 L
s
.43801 .45119 m
.43801 .45119 L
s
.43801 .45119 m
.43801 .45119 L
s
1 .001 0 r
.93093 .69907 m
.93094 .69908 L
s
.93092 .69907 m
.93093 .69907 L
s
.93093 .69907 m
.93093 .69907 L
s
.93094 .69908 m
.93093 .69908 L
s
.93093 .69907 m
.93094 .69908 L
s
.93093 .69908 m
.93092 .69907 L
s
.93092 .69907 m
.93093 .69907 L
s
.93093 .69907 m
.93093 .69908 L
s
1 0 0 r
.88948 .42631 m
.88948 .42631 L
s
.88948 .42631 m
.88948 .42631 L
s
.88948 .42631 m
.88948 .42631 L
s
.88948 .42631 m
.88948 .42631 L
s
.88948 .42631 m
.88948 .42631 L
s
.88948 .42631 m
.88948 .42631 L
s
.88948 .42631 m
.88948 .42631 L
s
.88948 .42631 m
.88948 .42631 L
s
.88948 .42631 m
.88948 .42631 L
s
1 .012 0 r
.47993 .72358 m
.48003 .72374 L
s
.47984 .72365 m
.47993 .72358 L
s
.47993 .72358 m
.48005 .72362 L
s
.48003 .72374 m
.47993 .7238 L
s
.48005 .72362 m
.48003 .72374 L
s
1 .002 0 r
.7311 .64936 m
.73115 .6493 L
s
.73114 .6493 m
.73115 .64931 L
s
.73112 .64931 m
.73114 .6493 L
s
.73114 .6493 m
.73115 .6493 L
s
.73115 .64931 m
.73114 .64932 L
s
.73115 .6493 m
.73115 .64931 L
s
.73114 .64932 m
.73112 .64931 L
s
.73112 .64931 m
.73115 .6493 L
s
.73115 .6493 m
.73114 .64932 L
s
1 .012 0 r
.47993 .7238 m
.47984 .72365 L
s
.47984 .72365 m
.48005 .72362 L
s
.48005 .72362 m
.47993 .7238 L
s
1 .004 0 r
.53126 .5996 m
.53139 .59948 L
s
.53136 .59947 m
.53139 .59951 L
s
.53133 .59949 m
.53136 .59947 L
s
.53136 .59947 m
.53139 .59948 L
s
.53139 .59951 m
.53136 .59953 L
s
.53139 .59948 m
.53139 .59951 L
s
.53136 .59953 m
.53133 .59949 L
s
.53133 .59949 m
.53139 .59948 L
s
.53139 .59948 m
.53136 .59953 L
s
1 .013 0 r
.33139 .54984 m
.33207 .54948 L
s
1 0 0 r
.78296 .52496 m
.78297 .52495 L
s
.78297 .52495 m
.78297 .52495 L
s
.78296 .52495 m
.78297 .52495 L
s
.78297 .52495 m
.78297 .52495 L
s
.78297 .52495 m
.78297 .52495 L
s
.78297 .52495 m
.78297 .52495 L
s
.78297 .52495 m
.78296 .52495 L
s
.78296 .52495 m
.78297 .52495 L
s
.78297 .52495 m
.78297 .52495 L
s
1 .006 0 r
.62454 .74806 m
.62479 .74787 L
s
1 .013 0 r
.33203 .54961 m
.33193 .54966 L
s
.33194 .54944 m
.33203 .54961 L
s
.33207 .54948 m
.33203 .54961 L
s
.33184 .54949 m
.33194 .54944 L
s
.33194 .54944 m
.33207 .54948 L
s
1 0 0 r
.58309 .47518 m
.58309 .47518 L
s
.58309 .47518 m
.58309 .47518 L
s
.58309 .47518 m
.58309 .47518 L
s
.58309 .47518 m
.58309 .47518 L
s
.58309 .47518 m
.58309 .47518 L
s
.58309 .47518 m
.58309 .47518 L
s
.58309 .47518 m
.58309 .47518 L
s
.58309 .47518 m
.58309 .47518 L
s
.58309 .47518 m
.58309 .47518 L
s
1 .006 0 r
.62474 .74785 m
.62479 .74793 L
s
.62469 .74789 m
.62474 .74785 L
s
.62474 .74785 m
.62479 .74787 L
s
.62479 .74793 m
.62474 .74796 L
s
.62479 .74787 m
.62479 .74793 L
s
1 .016 0 r
.42464 .6983 m
.42546 .69788 L
s
1 .013 0 r
.33193 .54966 m
.33184 .54949 L
s
.33207 .54948 m
.33193 .54966 L
s
.33184 .54949 m
.33207 .54948 L
s
1 .006 0 r
.62474 .74796 m
.62469 .74789 L
s
.62469 .74789 m
.62479 .74787 L
s
.62479 .74787 m
.62474 .74796 L
s
1 .001 0 r
.8763 .67342 m
.87632 .67339 L
s
1 0 0 r
.38317 .4254 m
.38317 .4254 L
s
.38317 .4254 m
.38317 .4254 L
s
.38317 .4254 m
.38317 .4254 L
s
.38317 .4254 m
.38317 .4254 L
s
.38317 .4254 m
.38317 .4254 L
s
.38317 .4254 m
.38317 .4254 L
s
.38317 .4254 m
.38317 .4254 L
s
.38317 .4254 m
.38317 .4254 L
s
.38317 .4254 m
.38317 .4254 L
s
1 .001 0 r
.87632 .67339 m
.87633 .6734 L
s
.87631 .67339 m
.87632 .67339 L
s
.87632 .67339 m
.87632 .67339 L
s
.87633 .6734 m
.87632 .6734 L
s
.87632 .67339 m
.87633 .6734 L
s
.87632 .6734 m
.87631 .67339 L
s
.87631 .67339 m
.87632 .67339 L
s
.87632 .67339 m
.87632 .6734 L
s
1 .002 0 r
.6764 .62365 m
.67645 .62359 L
s
1 .016 0 r
.4253 .69783 m
.42541 .69803 L
s
.42518 .6979 m
.4253 .69783 L
s
.4253 .69783 m
.42546 .69788 L
s
.42541 .69803 m
.42529 .6981 L
s
.42546 .69788 m
.42541 .69803 L
s
1 .002 0 r
.67644 .62359 m
.67645 .62361 L
s
.67642 .6236 m
.67644 .62359 L
s
.67644 .62359 m
.67645 .62359 L
s
.67645 .62361 m
.67644 .62362 L
s
.67645 .62359 m
.67645 .62361 L
s
.67644 .62362 m
.67642 .6236 L
s
.67642 .6236 m
.67645 .62359 L
s
.67645 .62359 m
.67644 .62362 L
s
1 .004 0 r
.47646 .57387 m
.47661 .57372 L
s
1 .016 0 r
.42529 .6981 m
.42518 .6979 L
s
.42518 .6979 m
.42546 .69788 L
s
.42546 .69788 m
.42529 .6981 L
s
1 0 0 r
.92821 .54898 m
.92821 .54898 L
s
.92821 .54898 m
.92821 .54898 L
s
.92821 .54898 m
.92821 .54898 L
s
.92821 .54898 m
.92821 .54898 L
s
.92821 .54898 m
.92821 .54898 L
s
.92821 .54898 m
.92821 .54898 L
s
.92821 .54898 m
.92821 .54898 L
s
.92821 .54898 m
.92821 .54898 L
s
.92821 .54898 m
.92821 .54898 L
s
1 .004 0 r
.47658 .57372 m
.47662 .57377 L
s
.47655 .57374 m
.47658 .57372 L
s
.47658 .57372 m
.47661 .57372 L
s
.47662 .57377 m
.47658 .57379 L
s
.47661 .57372 m
.47662 .57377 L
s
.47658 .57379 m
.47655 .57374 L
s
.47655 .57374 m
.47661 .57372 L
s
.47661 .57372 m
.47658 .57379 L
s
1 .003 0 r
.76974 .77217 m
.76986 .77206 L
s
1 .018 0 r
.27649 .52409 m
.27757 .5237 L
s
1 .003 0 r
.76983 .77205 m
.76986 .77209 L
s
.7698 .77207 m
.76983 .77205 L
s
.76983 .77205 m
.76986 .77206 L
s
.76986 .77209 m
.76983 .77211 L
s
.76986 .77206 m
.76986 .77209 L
s
1 0 0 r
.72827 .49919 m
.72827 .49919 L
s
.72827 .49919 m
.72827 .49919 L
s
.72827 .49919 m
.72827 .49919 L
s
.72827 .49919 m
.72827 .49919 L
s
.72827 .49919 m
.72827 .49919 L
s
.72827 .49919 m
.72827 .49919 L
s
.72827 .49919 m
.72827 .49919 L
s
.72827 .49919 m
.72827 .49919 L
s
.72827 .49919 m
.72827 .49919 L
s
1 .003 0 r
.76983 .77211 m
.7698 .77207 L
s
.7698 .77207 m
.76986 .77206 L
s
.76986 .77206 m
.76983 .77211 L
s
1 .007 0 r
.56977 .7224 m
.57008 .72216 L
s
1 .018 0 r
.27746 .52387 m
.27734 .52393 L
s
.27736 .52362 m
.27746 .52387 L
s
.27757 .5237 m
.27746 .52387 L
s
.27725 .52368 m
.27736 .52362 L
s
.27736 .52362 m
.27757 .5237 L
s
1 0 0 r
.5283 .44939 m
.5283 .44939 L
s
.5283 .44939 m
.5283 .44939 L
s
.5283 .44939 m
.5283 .44939 L
s
.5283 .44939 m
.5283 .44939 L
s
.5283 .44939 m
.5283 .44939 L
s
.5283 .44939 m
.5283 .44939 L
s
.5283 .44939 m
.5283 .44939 L
s
.5283 .44939 m
.5283 .44939 L
s
.5283 .44939 m
.5283 .44939 L
s
1 .007 0 r
.57002 .72215 m
.57008 .72223 L
s
.56996 .72219 m
.57002 .72215 L
s
.57002 .72215 m
.57008 .72216 L
s
1 .021 0 r
.36978 .67261 m
.37094 .67211 L
s
1 .007 0 r
.57008 .72223 m
.57002 .72227 L
s
.57008 .72216 m
.57008 .72223 L
s
1 .018 0 r
.27757 .5237 m
.27734 .52393 L
s
.27725 .52368 m
.27757 .5237 L
s
.27734 .52393 m
.27725 .52368 L
s
1 .007 0 r
.57002 .72227 m
.56996 .72219 L
s
.56996 .72219 m
.57008 .72216 L
s
.57008 .72216 m
.57002 .72227 L
s
1 .001 0 r
.82164 .64772 m
.82167 .64768 L
s
.82166 .64768 m
.82167 .64769 L
s
.82165 .64769 m
.82166 .64768 L
s
.82166 .64768 m
.82167 .64768 L
s
.82167 .64769 m
.82166 .6477 L
s
.82167 .64768 m
.82167 .64769 L
s
.82166 .6477 m
.82165 .64769 L
s
.82165 .64769 m
.82167 .64768 L
s
.82167 .64768 m
.82166 .6477 L
s
1 .002 0 r
.62164 .59792 m
.62169 .59786 L
s
.62168 .59785 m
.6217 .59787 L
s
.62167 .59787 m
.62168 .59785 L
s
.62168 .59785 m
.62169 .59786 L
s
.6217 .59787 m
.62168 .59788 L
s
.62169 .59786 m
.6217 .59787 L
s
.62168 .59788 m
.62167 .59787 L
s
.62167 .59787 m
.62169 .59786 L
s
.62169 .59786 m
.62168 .59788 L
s
1 .021 0 r
.37084 .6723 m
.3707 .67239 L
s
.37071 .67203 m
.37084 .6723 L
s
.37094 .67211 m
.37084 .6723 L
s
.37056 .67212 m
.37071 .67203 L
s
.37071 .67203 m
.37094 .67211 L
s
1 .005 0 r
.42161 .54812 m
.42181 .54794 L
s
1 .021 0 r
.3707 .67239 m
.37056 .67212 L
s
.37094 .67211 m
.3707 .67239 L
s
1 0 0 r
.87356 .52321 m
.87357 .52321 L
s
.87357 .52321 m
.87357 .52321 L
s
.87356 .52321 m
.87357 .52321 L
s
.87357 .52321 m
.87357 .52321 L
s
.87357 .52321 m
.87357 .52321 L
s
.87357 .52321 m
.87357 .52321 L
s
.87357 .52321 m
.87356 .52321 L
s
.87356 .52321 m
.87357 .52321 L
s
.87357 .52321 m
.87357 .52321 L
s
1 .021 0 r
.37056 .67212 m
.37094 .67211 L
s
1 .005 0 r
.42177 .54793 m
.42181 .548 L
s
.42172 .54796 m
.42177 .54793 L
s
.42177 .54793 m
.42181 .54794 L
s
.42181 .548 m
.42177 .54802 L
s
.42181 .54794 m
.42181 .548 L
s
.42177 .54802 m
.42172 .54796 L
s
.42172 .54796 m
.42181 .54794 L
s
.42181 .54794 m
.42177 .54802 L
s
1 .004 0 r
.71501 .7465 m
.71515 .74638 L
s
.71512 .74637 m
.71516 .74641 L
s
.71509 .74639 m
.71512 .74637 L
s
.71512 .74637 m
.71515 .74638 L
s
1 0 0 r
.67353 .4734 m
.67353 .4734 L
s
.67353 .4734 m
.67353 .4734 L
s
.67353 .4734 m
.67353 .4734 L
s
.67353 .4734 m
.67353 .4734 L
s
.67353 .4734 m
.67353 .4734 L
s
.67353 .4734 m
.67353 .4734 L
s
.67353 .4734 m
.67353 .4734 L
s
.67353 .4734 m
.67353 .4734 L
s
.67353 .4734 m
.67353 .4734 L
s
1 .004 0 r
.71516 .74641 m
.71513 .74644 L
s
.71515 .74638 m
.71516 .74641 L
s
.71513 .74644 m
.71509 .74639 L
s
.71509 .74639 m
.71515 .74638 L
s
.71515 .74638 m
.71513 .74644 L
s
1 .009 0 r
.51496 .69671 m
.51535 .69642 L
s
1 .001 0 r
.96699 .6718 m
.96701 .67178 L
s
1 0 0 r
.47346 .42357 m
.47346 .42357 L
s
.47346 .42357 m
.47346 .42357 L
s
.47346 .42357 m
.47346 .42357 L
s
.47346 .42357 m
.47346 .42357 L
s
.47346 .42357 m
.47346 .42357 L
s
.47346 .42357 m
.47346 .42357 L
s
.47346 .42357 m
.47346 .42357 L
s
.47346 .42357 m
.47346 .42357 L
s
.47346 .42357 m
.47346 .42357 L
s
1 .001 0 r
.967 .67178 m
.96701 .67179 L
s
.967 .67178 m
.967 .67178 L
s
.967 .67178 m
.96701 .67178 L
s
.96701 .67179 m
.96701 .67179 L
s
.96701 .67178 m
.96701 .67179 L
s
.96701 .67179 m
.967 .67178 L
s
.967 .67178 m
.96701 .67178 L
s
.96701 .67178 m
.96701 .67179 L
s
1 .028 0 r
.31487 .6469 m
.31654 .64635 L
s
1 .009 0 r
.51527 .6964 m
.51535 .69651 L
s
.5152 .69645 m
.51527 .6964 L
s
.51527 .6964 m
.51535 .69642 L
s
.51535 .69651 m
.51527 .69656 L
s
.51535 .69642 m
.51535 .69651 L
s
1 .001 0 r
.76693 .62199 m
.76696 .62195 L
s
1 .009 0 r
.51527 .69656 m
.5152 .69645 L
s
.5152 .69645 m
.51535 .69642 L
s
.51535 .69642 m
.51527 .69656 L
s
1 .001 0 r
.76695 .62195 m
.76696 .62196 L
s
.76694 .62196 m
.76695 .62195 L
s
.76695 .62195 m
.76696 .62195 L
s
.76696 .62196 m
.76695 .62197 L
s
.76696 .62195 m
.76696 .62196 L
s
.76695 .62197 m
.76694 .62196 L
s
.76694 .62196 m
.76696 .62195 L
s
.76696 .62195 m
.76695 .62197 L
s
1 .002 0 r
.56683 .57217 m
.56689 .5721 L
s
.56688 .5721 m
.5669 .57212 L
s
.56686 .57211 m
.56688 .5721 L
s
.56688 .5721 m
.56689 .5721 L
s
.5669 .57212 m
.56688 .57213 L
s
.56689 .5721 m
.5669 .57212 L
s
1 .028 0 r
.31637 .64659 m
.3162 .6467 L
s
.31622 .64622 m
.31637 .64659 L
s
.31654 .64635 m
.31637 .64659 L
s
1 .002 0 r
.56688 .57213 m
.56686 .57211 L
s
.56686 .57211 m
.56689 .5721 L
s
.56689 .5721 m
.56688 .57213 L
s
1 .028 0 r
.31605 .64632 m
.31622 .64622 L
s
.31622 .64622 m
.31654 .64635 L
s
1 .002 0 r
.86036 .77063 m
.86044 .77056 L
s
1 .006 0 r
.36671 .52234 m
.36698 .52213 L
s
1 .002 0 r
.86042 .77055 m
.86044 .77058 L
s
.8604 .77057 m
.86042 .77055 L
s
.86042 .77055 m
.86044 .77056 L
s
.86044 .77058 m
.86042 .77059 L
s
.86044 .77056 m
.86044 .77058 L
s
.86042 .77059 m
.8604 .77057 L
s
.8604 .77057 m
.86044 .77056 L
s
.86044 .77056 m
.86042 .77059 L
s
1 0 0 r
.81887 .49742 m
.81887 .49742 L
s
.81887 .49742 m
.81887 .49742 L
s
.81887 .49742 m
.81887 .49742 L
s
.81887 .49742 m
.81887 .49742 L
s
.81887 .49742 m
.81887 .49742 L
s
.81887 .49742 m
.81887 .49742 L
s
.81887 .49742 m
.81887 .49742 L
s
.81887 .49742 m
.81887 .49742 L
s
.81887 .49742 m
.81887 .49742 L
s
1 .006 0 r
.36693 .52212 m
.36698 .5222 L
s
.36687 .52215 m
.36693 .52212 L
s
.36693 .52212 m
.36698 .52213 L
s
1 .028 0 r
.31654 .64635 m
.3162 .6467 L
s
.31605 .64632 m
.31654 .64635 L
s
1 .006 0 r
.36698 .5222 m
.36692 .52223 L
s
.36698 .52213 m
.36698 .5222 L
s
1 .028 0 r
.3162 .6467 m
.31605 .64632 L
s
1 .004 0 r
.66024 .72082 m
.6604 .72067 L
s
1 .006 0 r
.36692 .52223 m
.36687 .52215 L
s
.36687 .52215 m
.36698 .52213 L
s
.36698 .52213 m
.36692 .52223 L
s
1 0 0 r
.61873 .44758 m
.61873 .44758 L
s
.61873 .44758 m
.61873 .44758 L
s
.61873 .44758 m
.61873 .44758 L
s
.61873 .44758 m
.61873 .44758 L
s
.61873 .44758 m
.61873 .44758 L
s
.61873 .44758 m
.61873 .44758 L
s
.61873 .44758 m
.61873 .44758 L
s
.61873 .44758 m
.61873 .44758 L
s
.61873 .44758 m
.61873 .44758 L
s
1 .004 0 r
.66037 .72066 m
.66041 .72071 L
s
.66033 .72069 m
.66037 .72066 L
s
.66037 .72066 m
.6604 .72067 L
s
.66041 .72071 m
.66037 .72074 L
s
.6604 .72067 m
.66041 .72071 L
s
.66037 .72074 m
.66033 .72069 L
s
.66033 .72069 m
.6604 .72067 L
s
.6604 .72067 m
.66037 .72074 L
s
1 .012 0 r
.46009 .67099 m
.46062 .67064 L
s
1 .001 0 r
.91233 .64608 m
.91235 .64605 L
s
.91234 .64605 m
.91235 .64606 L
s
.91234 .64606 m
.91234 .64605 L
s
.91234 .64605 m
.91235 .64605 L
s
.91235 .64606 m
.91234 .64606 L
s
.91235 .64605 m
.91235 .64606 L
s
.91234 .64606 m
.91234 .64606 L
s
.91234 .64606 m
.91235 .64605 L
s
.91235 .64605 m
.91234 .64606 L
s
1 .012 0 r
.46052 .67061 m
.46061 .67076 L
s
.46042 .67067 m
.46052 .67061 L
s
.46052 .67061 m
.46062 .67064 L
s
.46061 .67076 m
.46051 .67081 L
s
.46062 .67064 m
.46061 .67076 L
s
1 .001 0 r
.71217 .59624 m
.7122 .5962 L
s
.71219 .5962 m
.7122 .59621 L
s
.71218 .59621 m
.71219 .5962 L
s
.71219 .5962 m
.7122 .5962 L
s
.7122 .59621 m
.71219 .59622 L
s
.7122 .5962 m
.7122 .59621 L
s
.71219 .59622 m
.71218 .59621 L
s
.71218 .59621 m
.7122 .5962 L
s
.7122 .5962 m
.71219 .59622 L
s
1 .012 0 r
.46051 .67081 m
.46042 .67067 L
s
.46042 .67067 m
.46062 .67064 L
s
.46062 .67064 m
.46051 .67081 L
s
1 .002 0 r
.51198 .54639 m
.51204 .54632 L
s
.51203 .54631 m
.51205 .54634 L
s
.51201 .54633 m
.51203 .54631 L
s
.51203 .54631 m
.51204 .54632 L
s
.51205 .54634 m
.51203 .54635 L
s
.51204 .54632 m
.51205 .54634 L
s
.51203 .54635 m
.51201 .54633 L
s
.51201 .54633 m
.51204 .54632 L
s
.51204 .54632 m
.51203 .54635 L
s
1 .027 0 r
.35329 .76986 m
.35497 .76936 L
s
1 .002 0 r
.80564 .74495 m
.80572 .74486 L
s
1 .008 0 r
.31175 .49654 m
.31215 .4963 L
s
1 .002 0 r
.8057 .74486 m
.80572 .74488 L
s
.80568 .74487 m
.8057 .74486 L
s
.8057 .74486 m
.80572 .74486 L
s
.80572 .74488 m
.8057 .7449 L
s
.80572 .74486 m
.80572 .74488 L
s
.8057 .7449 m
.80568 .74487 L
s
.80568 .74487 m
.80572 .74486 L
s
.80572 .74486 m
.8057 .7449 L
s
1 0 0 r
.76412 .47161 m
.76412 .47161 L
s
.76412 .47161 m
.76412 .47161 L
s
.76412 .47161 m
.76412 .47161 L
s
.76412 .47161 m
.76412 .47161 L
s
.76412 .47161 m
.76412 .47161 L
s
.76412 .47161 m
.76412 .47161 L
s
.76412 .47161 m
.76412 .47161 L
s
.76412 .47161 m
.76412 .47161 L
s
.76412 .47161 m
.76412 .47161 L
s
1 .008 0 r
.31208 .49628 m
.31214 .49638 L
s
.31201 .49631 m
.31208 .49628 L
s
.31208 .49628 m
.31215 .4963 L
s
.31214 .49638 m
.31207 .49641 L
s
.31215 .4963 m
.31214 .49638 L
s
1 .005 0 r
.60542 .6951 m
.60562 .69493 L
s
1 .027 0 r
.35478 .76959 m
.35462 .7697 L
s
.35464 .76921 m
.35478 .76959 L
s
.35497 .76936 m
.35478 .76959 L
s
1 .008 0 r
.31207 .49641 m
.31201 .49631 L
s
.31201 .49631 m
.31215 .4963 L
s
.31215 .4963 m
.31207 .49641 L
s
1 .027 0 r
.35448 .76933 m
.35464 .76921 L
s
.35464 .76921 m
.35497 .76936 L
s
1 0 0 r
.56389 .42174 m
.56389 .42174 L
s
.56389 .42174 m
.56389 .42174 L
s
.56389 .42174 m
.56389 .42174 L
s
.56389 .42174 m
.56389 .42174 L
s
.56389 .42174 m
.56389 .42174 L
s
.56389 .42174 m
.56389 .42174 L
s
.56389 .42174 m
.56389 .42174 L
s
.56389 .42174 m
.56389 .42174 L
s
.56389 .42174 m
.56389 .42174 L
s
1 .005 0 r
.60558 .69492 m
.60562 .69498 L
s
.60553 .69495 m
.60558 .69492 L
s
.60558 .69492 m
.60562 .69493 L
s
.60562 .69498 m
.60558 .69501 L
s
.60562 .69493 m
.60562 .69498 L
s
.60558 .69501 m
.60553 .69495 L
s
.60553 .69495 m
.60562 .69493 L
s
.60562 .69493 m
.60558 .69501 L
s
1 .015 0 r
.40517 .64526 m
.40593 .64482 L
s
1 .001 0 r
.85762 .62033 m
.85763 .6203 L
s
.85763 .6203 m
.85763 .62031 L
s
.85762 .62031 m
.85763 .6203 L
s
.85763 .6203 m
.85763 .6203 L
s
.85763 .62031 m
.85763 .62031 L
s
.85763 .6203 m
.85763 .62031 L
s
.85763 .62031 m
.85762 .62031 L
s
.85762 .62031 m
.85763 .6203 L
s
.85763 .6203 m
.85763 .62031 L
s
1 .027 0 r
.35497 .76936 m
.35462 .7697 L
s
.35448 .76933 m
.35497 .76936 L
s
.35462 .7697 m
.35448 .76933 L
s
1 .001 0 r
.65736 .57047 m
.65739 .57043 L
s
.65738 .57043 m
.65739 .57044 L
s
.65737 .57043 m
.65738 .57043 L
s
.65738 .57043 m
.65739 .57043 L
s
.65739 .57044 m
.65738 .57044 L
s
.65739 .57043 m
.65739 .57044 L
s
.65738 .57044 m
.65737 .57043 L
s
.65737 .57043 m
.65739 .57043 L
s
.65739 .57043 m
.65738 .57044 L
s
1 .015 0 r
.40578 .64477 m
.40589 .64497 L
s
.40566 .64484 m
.40578 .64477 L
s
.40578 .64477 m
.40593 .64482 L
s
.40589 .64497 m
.40577 .64504 L
s
.40593 .64482 m
.40589 .64497 L
s
.40577 .64504 m
.40566 .64484 L
s
.40566 .64484 m
.40593 .64482 L
s
.40593 .64482 m
.40577 .64504 L
s
1 .002 0 r
.45707 .52059 m
.45714 .52051 L
s
.45713 .52051 m
.45715 .52053 L
s
.45711 .52052 m
.45713 .52051 L
s
.45713 .52051 m
.45714 .52051 L
s
.45715 .52053 m
.45713 .52055 L
s
.45714 .52051 m
.45715 .52053 L
s
.45713 .52055 m
.45711 .52052 L
s
.45711 .52052 m
.45714 .52051 L
s
.45714 .52051 m
.45713 .52055 L
s
1 0 0 r
.90962 .49566 m
.90962 .49566 L
s
.90962 .49566 m
.90962 .49566 L
s
.90962 .49566 m
.90962 .49566 L
s
.90962 .49566 m
.90962 .49566 L
s
.90962 .49566 m
.90962 .49566 L
s
.90962 .49566 m
.90962 .49566 L
s
.90962 .49566 m
.90962 .49566 L
s
.90962 .49566 m
.90962 .49566 L
s
.90962 .49566 m
.90962 .49566 L
s
1 .003 0 r
.75086 .71924 m
.75095 .71914 L
s
1 .01 0 r
.25675 .47072 m
.25733 .4705 L
s
1 .003 0 r
.75093 .71914 m
.75096 .71917 L
s
.75091 .71915 m
.75093 .71914 L
s
.75093 .71914 m
.75095 .71914 L
s
.75096 .71917 m
.75094 .71918 L
s
.75095 .71914 m
.75096 .71917 L
s
.75094 .71918 m
.75091 .71915 L
s
.75091 .71915 m
.75095 .71914 L
s
.75095 .71914 m
.75094 .71918 L
s
1 0 0 r
.70932 .44577 m
.70932 .44577 L
s
.70932 .44577 m
.70932 .44577 L
s
.70932 .44577 m
.70932 .44577 L
s
.70932 .44577 m
.70932 .44577 L
s
.70932 .44577 m
.70932 .44577 L
s
.70932 .44577 m
.70932 .44577 L
s
.70932 .44577 m
.70932 .44577 L
s
.70932 .44577 m
.70932 .44577 L
s
.70932 .44577 m
.70932 .44577 L
s
1 .01 0 r
.25727 .47059 m
.25721 .47062 L
s
.25722 .47046 m
.25727 .47059 L
s
.25733 .4705 m
.25727 .47059 L
s
.25715 .47049 m
.25722 .47046 L
s
.25722 .47046 m
.25733 .4705 L
s
1 .006 0 r
.55055 .66937 m
.55079 .66916 L
s
1 .01 0 r
.25733 .4705 m
.25721 .47062 L
s
.25715 .47049 m
.25733 .4705 L
s
.25721 .47062 m
.25715 .47049 L
s
1 .006 0 r
.55074 .66915 m
.5508 .66922 L
s
.55069 .66918 m
.55074 .66915 L
s
.55074 .66915 m
.55079 .66916 L
s
.5508 .66922 m
.55074 .66925 L
s
.55079 .66916 m
.5508 .66922 L
s
1 .021 0 r
.3502 .61949 m
.35133 .61896 L
s
1 .006 0 r
.55074 .66925 m
.55069 .66918 L
s
.55069 .66918 m
.55079 .66916 L
s
.55079 .66916 m
.55074 .66925 L
s
1 .001 0 r
.80285 .59455 m
.80287 .59453 L
s
.80286 .59453 m
.80287 .59454 L
s
.80286 .59454 m
.80286 .59453 L
s
.80286 .59453 m
.80287 .59453 L
s
.80287 .59454 m
.80286 .59454 L
s
.80287 .59453 m
.80287 .59454 L
s
.80286 .59454 m
.80286 .59454 L
s
.80286 .59454 m
.80287 .59453 L
s
.80287 .59453 m
.80286 .59454 L
s
.6025 .54467 m
.60253 .54463 L
s
.60252 .54463 m
.60253 .54464 L
s
.60251 .54463 m
.60252 .54463 L
s
.60252 .54463 m
.60253 .54463 L
s
.60253 .54464 m
.60252 .54464 L
s
.60253 .54463 m
.60253 .54464 L
s
.60252 .54464 m
.60251 .54463 L
s
.60251 .54463 m
.60253 .54463 L
s
.60253 .54463 m
.60252 .54464 L
s
1 .018 0 r
.44368 .76832 m
.44465 .76786 L
s
1 .021 0 r
.35125 .61916 m
.3511 .61925 L
s
.35111 .61889 m
.35125 .61916 L
s
.35133 .61896 m
.35125 .61916 L
s
.35096 .61897 m
.35111 .61889 L
s
.35111 .61889 m
.35133 .61896 L
s
1 .002 0 r
.89641 .74338 m
.89646 .74333 L
s
.40212 .49477 m
.4022 .49468 L
s
.89645 .74333 m
.89647 .74334 L
s
.89644 .74334 m
.89645 .74333 L
s
.89645 .74333 m
.89646 .74333 L
s
.89647 .74334 m
.89645 .74335 L
s
.89646 .74333 m
.89647 .74334 L
s
.89645 .74335 m
.89644 .74334 L
s
.89644 .74334 m
.89646 .74333 L
s
.89646 .74333 m
.89645 .74335 L
s
.40218 .49468 m
.4022 .49471 L
s
.40216 .49469 m
.40218 .49468 L
s
.40218 .49468 m
.4022 .49468 L
s
.4022 .49471 m
.40218 .49472 L
s
.4022 .49468 m
.4022 .49471 L
s
.40218 .49472 m
.40216 .49469 L
s
.40216 .49469 m
.4022 .49468 L
s
.4022 .49468 m
.40218 .49472 L
s
1 0 0 r
.85487 .46982 m
.85487 .46982 L
s
.85487 .46982 m
.85487 .46982 L
s
.85487 .46982 m
.85487 .46982 L
s
.85487 .46982 m
.85487 .46982 L
s
.85487 .46982 m
.85487 .46982 L
s
.85487 .46982 m
.85487 .46982 L
s
.85487 .46982 m
.85487 .46982 L
s
.85487 .46982 m
.85487 .46982 L
s
.85487 .46982 m
.85487 .46982 L
s
1 .021 0 r
.3511 .61925 m
.35096 .61897 L
s
.35133 .61896 m
.3511 .61925 L
s
.35096 .61897 m
.35133 .61896 L
s
1 .003 0 r
.69604 .6935 m
.69614 .69339 L
s
1 .018 0 r
.44459 .76803 m
.44446 .76812 L
s
.44446 .76779 m
.44459 .76803 L
s
.44465 .76786 m
.44459 .76803 L
s
.44433 .76788 m
.44446 .76779 L
s
.44446 .76779 m
.44465 .76786 L
s
1 .003 0 r
.69612 .69339 m
.69615 .69342 L
s
.69609 .69341 m
.69612 .69339 L
s
.69612 .69339 m
.69614 .69339 L
s
.69615 .69342 m
.69612 .69344 L
s
.69614 .69339 m
.69615 .69342 L
s
1 0 0 r
.65448 .41991 m
.65448 .41991 L
s
.65448 .41991 m
.65448 .41991 L
s
.65448 .41991 m
.65448 .41991 L
s
.65448 .41991 m
.65448 .41991 L
s
.65448 .41991 m
.65448 .41991 L
s
.65448 .41991 m
.65448 .41991 L
s
.65448 .41991 m
.65448 .41991 L
s
.65448 .41991 m
.65448 .41991 L
s
.65448 .41991 m
.65448 .41991 L
s
1 .003 0 r
.69612 .69344 m
.69609 .69341 L
s
.69609 .69341 m
.69614 .69339 L
s
.69614 .69339 m
.69612 .69344 L
s
1 .008 0 r
.49563 .64361 m
.49594 .64335 L
s
1 .018 0 r
.44446 .76812 m
.44433 .76788 L
s
.44465 .76786 m
.44446 .76812 L
s
.44433 .76788 m
.44465 .76786 L
s
1 0 0 r
.94845 .61866 m
.94846 .61865 L
s
.94846 .61865 m
.94846 .61865 L
s
.94846 .61865 m
.94846 .61865 L
s
.94846 .61865 m
.94846 .61865 L
s
.94846 .61865 m
.94846 .61865 L
s
.94846 .61865 m
.94846 .61865 L
s
.94846 .61865 m
.94846 .61865 L
s
.94846 .61865 m
.94846 .61865 L
s
.94846 .61865 m
.94846 .61865 L
s
1 .029 0 r
.29518 .59371 m
.29694 .59311 L
s
1 .008 0 r
.49588 .64333 m
.49595 .64343 L
s
.49581 .64338 m
.49588 .64333 L
s
.49588 .64333 m
.49594 .64335 L
s
.49595 .64343 m
.49588 .64347 L
s
.49594 .64335 m
.49595 .64343 L
s
.49588 .64347 m
.49581 .64338 L
s
.49581 .64338 m
.49594 .64335 L
s
.49594 .64335 m
.49588 .64347 L
s
1 .001 0 r
.74804 .56876 m
.74805 .56874 L
s
.74805 .56874 m
.74805 .56874 L
s
.74804 .56874 m
.74805 .56874 L
s
.74805 .56874 m
.74805 .56874 L
s
.74805 .56874 m
.74805 .56874 L
s
.74805 .56874 m
.74805 .56874 L
s
.74805 .56874 m
.74804 .56874 L
s
.74804 .56874 m
.74805 .56874 L
s
.74805 .56874 m
.74805 .56874 L
s
.54759 .51884 m
.54761 .51881 L
s
.54761 .51881 m
.54762 .51882 L
s
.5476 .51881 m
.54761 .51881 L
s
.54761 .51881 m
.54761 .51881 L
s
.54762 .51882 m
.54761 .51882 L
s
.54761 .51881 m
.54762 .51882 L
s
.54761 .51882 m
.5476 .51881 L
s
.5476 .51881 m
.54761 .51881 L
s
.54761 .51881 m
.54761 .51882 L
s
1 .029 0 r
.29676 .59338 m
.29657 .59348 L
s
.2966 .59298 m
.29676 .59338 L
s
.29694 .59311 m
.29676 .59338 L
s
1 .024 0 r
.3887 .7426 m
.39003 .74207 L
s
1 .029 0 r
.29642 .59308 m
.2966 .59298 L
s
.2966 .59298 m
.29694 .59311 L
s
1 .002 0 r
.84163 .71765 m
.84169 .71759 L
s
.34711 .46892 m
.34719 .46884 L
s
.84168 .71759 m
.84169 .71761 L
s
.84166 .7176 m
.84168 .71759 L
s
.84168 .71759 m
.84169 .71759 L
s
.84169 .71761 m
.84168 .71762 L
s
.84169 .71759 m
.84169 .71761 L
s
.84168 .71762 m
.84166 .7176 L
s
.84166 .7176 m
.84169 .71759 L
s
.84169 .71759 m
.84168 .71762 L
s
.34718 .46884 m
.3472 .46887 L
s
.34716 .46885 m
.34718 .46884 L
s
.34718 .46884 m
.34719 .46884 L
s
.3472 .46887 m
.34717 .46888 L
s
.34719 .46884 m
.3472 .46887 L
s
.34717 .46888 m
.34716 .46885 L
s
.34716 .46885 m
.34719 .46884 L
s
.34719 .46884 m
.34717 .46888 L
s
1 0 0 r
.80006 .44396 m
.80006 .44396 L
s
.80006 .44396 m
.80006 .44396 L
s
.80006 .44396 m
.80006 .44396 L
s
.80006 .44396 m
.80006 .44396 L
s
.80006 .44396 m
.80006 .44396 L
s
.80006 .44396 m
.80006 .44396 L
s
.80006 .44396 m
.80006 .44396 L
s
.80006 .44396 m
.80006 .44396 L
s
.80006 .44396 m
.80006 .44396 L
s
1 .003 0 r
.64116 .66774 m
.64128 .66762 L
s
1 .029 0 r
.29694 .59311 m
.29657 .59348 L
s
.29642 .59308 m
.29694 .59311 L
s
.29657 .59348 m
.29642 .59308 L
s
1 .003 0 r
.64125 .66761 m
.64129 .66765 L
s
.64122 .66763 m
.64125 .66761 L
s
.64125 .66761 m
.64128 .66762 L
s
1 .024 0 r
.38991 .74228 m
.38975 .74238 L
s
.38977 .74197 m
.38991 .74228 L
s
.39003 .74207 m
.38991 .74228 L
s
1 .003 0 r
.64129 .66765 m
.64126 .66767 L
s
.64128 .66762 m
.64129 .66765 L
s
1 .024 0 r
.38961 .74207 m
.38977 .74197 L
s
.38977 .74197 m
.39003 .74207 L
s
1 .003 0 r
.64126 .66767 m
.64122 .66763 L
s
.64122 .66763 m
.64128 .66762 L
s
.64128 .66762 m
.64126 .66767 L
s
1 .01 0 r
.44065 .61783 m
.44109 .6175 L
s
1 0 0 r
.89369 .59287 m
.89369 .59285 L
s
.89369 .59285 m
.8937 .59285 L
s
.89369 .59285 m
.89369 .59285 L
s
.89369 .59285 m
.89369 .59285 L
s
.8937 .59285 m
.89369 .59286 L
s
.89369 .59285 m
.8937 .59285 L
s
.89369 .59286 m
.89369 .59285 L
s
.89369 .59285 m
.89369 .59285 L
s
.89369 .59285 m
.89369 .59286 L
s
1 .024 0 r
.38975 .74238 m
.38961 .74207 L
s
.39003 .74207 m
.38975 .74238 L
s
.38961 .74207 m
.39003 .74207 L
s
1 .01 0 r
.44101 .61748 m
.44109 .6176 L
s
.44092 .61753 m
.44101 .61748 L
s
.44101 .61748 m
.44109 .6175 L
s
.44109 .6176 m
.441 .61765 L
s
.44109 .6175 m
.44109 .6176 L
s
1 0 0 r
.69317 .54294 m
.69319 .54292 L
s
.69318 .54292 m
.69319 .54292 L
s
.69318 .54292 m
.69318 .54292 L
s
.69318 .54292 m
.69319 .54292 L
s
.69319 .54292 m
.69318 .54292 L
s
.69319 .54292 m
.69319 .54292 L
s
.69318 .54292 m
.69318 .54292 L
s
.69318 .54292 m
.69319 .54292 L
s
.69319 .54292 m
.69318 .54292 L
s
1 .01 0 r
.441 .61765 m
.44092 .61753 L
s
.44092 .61753 m
.44109 .6175 L
s
.44109 .6175 m
.441 .61765 L
s
1 .012 0 r
.53423 .76678 m
.53476 .76644 L
s
1 .001 0 r
.49263 .493 m
.49265 .49297 L
s
.49265 .49297 m
.49265 .49298 L
s
.49264 .49297 m
.49265 .49297 L
s
.49265 .49297 m
.49265 .49297 L
s
.49265 .49298 m
.49265 .49298 L
s
.49265 .49297 m
.49265 .49298 L
s
.49265 .49298 m
.49264 .49297 L
s
.49264 .49297 m
.49265 .49297 L
s
.49265 .49297 m
.49265 .49298 L
s
1 .03 0 r
.33366 .71686 m
.3355 .71628 L
s
1 .012 0 r
.53465 .76641 m
.53474 .76655 L
s
.53456 .76647 m
.53465 .76641 L
s
.53465 .76641 m
.53476 .76644 L
s
.53474 .76655 m
.53465 .76661 L
s
.53476 .76644 m
.53474 .76655 L
s
1 .002 0 r
.7868 .69189 m
.78686 .69183 L
s
.29205 .44305 m
.29212 .443 L
s
.29211 .443 m
.29212 .44302 L
s
.29209 .44301 m
.29211 .443 L
s
.29211 .443 m
.29212 .443 L
s
.29212 .44302 m
.2921 .44302 L
s
.29212 .443 m
.29212 .44302 L
s
.78685 .69182 m
.78687 .69184 L
s
.78683 .69184 m
.78685 .69182 L
s
.78685 .69182 m
.78686 .69183 L
s
.78687 .69184 m
.78685 .69186 L
s
.78686 .69183 m
.78687 .69184 L
s
.2921 .44302 m
.29209 .44301 L
s
.29209 .44301 m
.29212 .443 L
s
.29212 .443 m
.2921 .44302 L
s
.78685 .69186 m
.78683 .69184 L
s
.78683 .69184 m
.78686 .69183 L
s
.78686 .69183 m
.78685 .69186 L
s
1 .012 0 r
.53465 .76661 m
.53456 .76647 L
s
.53456 .76647 m
.53476 .76644 L
s
.53476 .76644 m
.53465 .76661 L
s
1 0 0 r
.74521 .41808 m
.74521 .41808 L
s
.74521 .41808 m
.74521 .41808 L
s
.74521 .41808 m
.74521 .41808 L
s
.74521 .41808 m
.74521 .41808 L
s
.74521 .41808 m
.74521 .41808 L
s
.74521 .41808 m
.74521 .41808 L
s
.74521 .41808 m
.74521 .41808 L
s
.74521 .41808 m
.74521 .41808 L
s
.74521 .41808 m
.74521 .41808 L
s
1 .004 0 r
.58623 .64196 m
.58637 .64181 L
s
1 .03 0 r
.33531 .71654 m
.33512 .71666 L
s
.33515 .71613 m
.33531 .71654 L
s
.3355 .71628 m
.33531 .71654 L
s
1 .004 0 r
.58635 .64181 m
.58638 .64186 L
s
.58631 .64183 m
.58635 .64181 L
s
.58635 .64181 m
.58637 .64181 L
s
1 .03 0 r
.33497 .71625 m
.33515 .71613 L
s
.33515 .71613 m
.3355 .71628 L
s
1 .004 0 r
.58638 .64186 m
.58635 .64188 L
s
.58637 .64181 m
.58638 .64186 L
s
.58635 .64188 m
.58631 .64183 L
s
.58631 .64183 m
.58637 .64181 L
s
.58637 .64181 m
.58635 .64188 L
s
1 .014 0 r
.38563 .59202 m
.38628 .5916 L
s
1 0 0 r
.83887 .56705 m
.83888 .56703 L
s
.83887 .56703 m
.83888 .56704 L
s
.83887 .56704 m
.83887 .56703 L
s
.83887 .56703 m
.83888 .56703 L
s
.83888 .56704 m
.83887 .56704 L
s
.83888 .56703 m
.83888 .56704 L
s
.83887 .56704 m
.83887 .56704 L
s
.83887 .56704 m
.83888 .56703 L
s
.83888 .56703 m
.83887 .56704 L
s
1 .03 0 r
.3355 .71628 m
.33512 .71666 L
s
.33497 .71625 m
.3355 .71628 L
s
.33512 .71666 m
.33497 .71625 L
s
1 0 0 r
.63826 .51709 m
.63827 .51707 L
s
.63827 .51707 m
.63827 .51708 L
s
.63826 .51708 m
.63827 .51707 L
s
.63827 .51707 m
.63827 .51707 L
s
.63827 .51708 m
.63827 .51708 L
s
.63827 .51707 m
.63827 .51708 L
s
.63827 .51708 m
.63826 .51708 L
s
.63826 .51708 m
.63827 .51707 L
s
.63827 .51707 m
.63827 .51708 L
s
1 .014 0 r
.38615 .59156 m
.38626 .59174 L
s
.38604 .59163 m
.38615 .59156 L
s
.38615 .59156 m
.38628 .5916 L
s
.38626 .59174 m
.38614 .5918 L
s
.38628 .5916 m
.38626 .59174 L
s
1 .015 0 r
.47924 .74104 m
.47994 .74063 L
s
1 .014 0 r
.38614 .5918 m
.38604 .59163 L
s
.38604 .59163 m
.38628 .5916 L
s
.38628 .5916 m
.38614 .5918 L
s
1 .001 0 r
.93256 .71606 m
.93259 .71602 L
s
.43762 .46713 m
.43763 .46711 L
s
.43763 .46711 m
.43764 .46711 L
s
.43762 .46711 m
.43763 .46711 L
s
.43763 .46711 m
.43763 .46711 L
s
.43764 .46711 m
.43763 .46712 L
s
.43763 .46711 m
.43764 .46711 L
s
.43763 .46712 m
.43762 .46711 L
s
.43762 .46711 m
.43763 .46711 L
s
.43763 .46711 m
.43763 .46712 L
s
.93258 .71602 m
.93259 .71603 L
s
.93257 .71603 m
.93258 .71602 L
s
.93258 .71602 m
.93259 .71602 L
s
.93259 .71603 m
.93258 .71604 L
s
.93259 .71602 m
.93259 .71603 L
s
.93258 .71604 m
.93257 .71603 L
s
.93257 .71603 m
.93259 .71602 L
s
.93259 .71602 m
.93258 .71604 L
s
1 0 0 r
.89096 .44214 m
.89096 .44214 L
s
.89096 .44214 m
.89096 .44214 L
s
.89096 .44214 m
.89096 .44214 L
s
.89096 .44214 m
.89096 .44214 L
s
.89096 .44214 m
.89096 .44214 L
s
.89096 .44214 m
.89096 .44214 L
s
.89096 .44214 m
.89096 .44214 L
s
.89096 .44214 m
.89096 .44214 L
s
.89096 .44214 m
.89096 .44214 L
s
1 .002 0 r
.73192 .66611 m
.73199 .66604 L
s
1 0 0 r
.23694 .41716 m
.23695 .41716 L
s
.23695 .41716 m
.23695 .41716 L
s
.23695 .41716 m
.23695 .41716 L
s
.23695 .41716 m
.23695 .41716 L
s
.23695 .41716 m
.23695 .41716 L
s
.23695 .41716 m
.23695 .41716 L
s
.23695 .41716 m
.23695 .41716 L
s
.23695 .41716 m
.23695 .41716 L
s
.23695 .41716 m
.23695 .41716 L
s
1 .015 0 r
.4798 .74058 m
.47991 .74076 L
s
.47969 .74065 m
.4798 .74058 L
s
.4798 .74058 m
.47994 .74063 L
s
.47991 .74076 m
.4798 .74084 L
s
.47994 .74063 m
.47991 .74076 L
s
1 .002 0 r
.73197 .66604 m
.73199 .66606 L
s
.73195 .66605 m
.73197 .66604 L
s
.73197 .66604 m
.73199 .66604 L
s
.73199 .66606 m
.73197 .66607 L
s
.73199 .66604 m
.73199 .66606 L
s
.73197 .66607 m
.73195 .66605 L
s
.73195 .66605 m
.73199 .66604 L
s
.73199 .66604 m
.73197 .66607 L
s
1 .015 0 r
.4798 .74084 m
.47969 .74065 L
s
.47969 .74065 m
.47994 .74063 L
s
.47994 .74063 m
.4798 .74084 L
s
1 .005 0 r
.53125 .61616 m
.53143 .61598 L
s
.5314 .61597 m
.53144 .61603 L
s
.53135 .616 m
.5314 .61597 L
s
.5314 .61597 m
.53143 .61598 L
s
.53144 .61603 m
.5314 .61606 L
s
.53143 .61598 m
.53144 .61603 L
s
.5314 .61606 m
.53135 .616 L
s
.53135 .616 m
.53143 .61598 L
s
.53143 .61598 m
.5314 .61606 L
s
1 .02 0 r
.33055 .56619 m
.33158 .56565 L
s
1 0 0 r
.784 .5412 m
.78401 .54119 L
s
.784 .54119 m
.78401 .54119 L
s
.784 .54119 m
.784 .54119 L
s
.784 .54119 m
.78401 .54119 L
s
.78401 .54119 m
.78401 .5412 L
s
.78401 .54119 m
.78401 .54119 L
s
.78401 .5412 m
.784 .54119 L
s
.784 .54119 m
.78401 .54119 L
s
.78401 .54119 m
.78401 .5412 L
s
1 .007 0 r
.62492 .76523 m
.62521 .765 L
s
1 0 0 r
.58329 .49122 m
.5833 .49121 L
s
.5833 .49121 m
.5833 .49121 L
s
.5833 .49121 m
.5833 .49121 L
s
.5833 .49121 m
.5833 .49121 L
s
.5833 .49121 m
.5833 .49122 L
s
.5833 .49121 m
.5833 .49121 L
s
.5833 .49122 m
.5833 .49121 L
s
.5833 .49121 m
.5833 .49121 L
s
.5833 .49121 m
.5833 .49122 L
s
1 .007 0 r
.62515 .76499 m
.62522 .76507 L
s
.62509 .76503 m
.62515 .76499 L
s
.62515 .76499 m
.62521 .765 L
s
1 .019 0 r
.4242 .71527 m
.42517 .71477 L
s
1 .007 0 r
.62522 .76507 m
.62516 .76511 L
s
.62521 .765 m
.62522 .76507 L
s
1 .02 0 r
.33152 .56584 m
.33137 .56592 L
s
.33139 .56559 m
.33152 .56584 L
s
.33158 .56565 m
.33152 .56584 L
s
.33123 .56567 m
.33139 .56559 L
s
.33139 .56559 m
.33158 .56565 L
s
1 .007 0 r
.62516 .76511 m
.62509 .76503 L
s
.62509 .76503 m
.62521 .765 L
s
.62521 .765 m
.62516 .76511 L
s
1 .001 0 r
.87772 .69029 m
.87776 .69024 L
s
1 0 0 r
.38256 .44124 m
.38256 .44122 L
s
.38256 .44122 m
.38256 .44123 L
s
.38256 .44123 m
.38256 .44122 L
s
.38256 .44122 m
.38256 .44122 L
s
.38256 .44123 m
.38256 .44123 L
s
.38256 .44122 m
.38256 .44123 L
s
.38256 .44123 m
.38256 .44123 L
s
.38256 .44123 m
.38256 .44122 L
s
.38256 .44122 m
.38256 .44123 L
s
1 .001 0 r
.87775 .69024 m
.87776 .69025 L
s
.87774 .69025 m
.87775 .69024 L
s
.87775 .69024 m
.87776 .69024 L
s
.87776 .69025 m
.87775 .69026 L
s
.87776 .69024 m
.87776 .69025 L
s
.87775 .69026 m
.87774 .69025 L
s
.87774 .69025 m
.87776 .69024 L
s
.87776 .69024 m
.87775 .69026 L
s
1 0 0 r
.8361 .41624 m
.8361 .41624 L
s
.8361 .41624 m
.8361 .41624 L
s
.8361 .41624 m
.8361 .41624 L
s
.8361 .41624 m
.8361 .41624 L
s
.8361 .41624 m
.8361 .41624 L
s
.8361 .41624 m
.8361 .41624 L
s
.8361 .41624 m
.8361 .41624 L
s
.8361 .41624 m
.8361 .41624 L
s
.8361 .41624 m
.8361 .41624 L
s
1 .02 0 r
.33137 .56592 m
.33123 .56567 L
s
.33158 .56565 m
.33137 .56592 L
s
.33123 .56567 m
.33158 .56565 L
s
1 .002 0 r
.67699 .64031 m
.67706 .64023 L
s
.67705 .64022 m
.67707 .64025 L
s
.67703 .64024 m
.67705 .64022 L
s
.67705 .64022 m
.67706 .64023 L
s
.67707 .64025 m
.67705 .64026 L
s
.67706 .64023 m
.67707 .64025 L
s
.67705 .64026 m
.67703 .64024 L
s
.67703 .64024 m
.67706 .64023 L
s
.67706 .64023 m
.67705 .64026 L
s
1 .019 0 r
.42498 .7147 m
.42511 .71494 L
s
.42483 .71479 m
.42498 .7147 L
s
.42498 .7147 m
.42517 .71477 L
s
.42511 .71494 m
.42497 .71503 L
s
.42517 .71477 m
.42511 .71494 L
s
1 .006 0 r
.47623 .59033 m
.47645 .59011 L
s
1 .019 0 r
.42497 .71503 m
.42483 .71479 L
s
.42483 .71479 m
.42517 .71477 L
s
.42517 .71477 m
.42497 .71503 L
s
1 0 0 r
.92985 .56533 m
.92985 .56532 L
s
.92985 .56532 m
.92986 .56533 L
s
.92985 .56533 m
.92985 .56532 L
s
.92985 .56532 m
.92985 .56532 L
s
.92986 .56533 m
.92985 .56533 L
s
.92985 .56532 m
.92986 .56533 L
s
.92985 .56533 m
.92985 .56533 L
s
.92985 .56533 m
.92985 .56532 L
s
.92985 .56532 m
.92985 .56533 L
s
1 .006 0 r
.47641 .5901 m
.47646 .59017 L
s
.47635 .59013 m
.47641 .5901 L
s
.47641 .5901 m
.47645 .59011 L
s
.47646 .59017 m
.47641 .59021 L
s
.47645 .59011 m
.47646 .59017 L
s
1 .029 0 r
.27543 .54033 m
.27717 .53971 L
s
1 .006 0 r
.47641 .59021 m
.47635 .59013 L
s
.47635 .59013 m
.47645 .59011 L
s
.47645 .59011 m
.47641 .59021 L
s
1 0 0 r
.72908 .51534 m
.72909 .51533 L
s
.72909 .51533 m
.72909 .51533 L
s
.72908 .51533 m
.72909 .51533 L
s
.72909 .51533 m
.72909 .51533 L
s
.72909 .51533 m
.72909 .51533 L
s
.72909 .51533 m
.72909 .51533 L
s
.72909 .51533 m
.72908 .51533 L
s
.72908 .51533 m
.72909 .51533 L
s
.72909 .51533 m
.72909 .51533 L
s
1 .009 0 r
.56993 .73947 m
.5703 .73919 L
s
1 0 0 r
.52828 .46533 m
.52828 .46532 L
s
.52828 .46532 m
.52828 .46532 L
s
.52828 .46532 m
.52828 .46532 L
s
.52828 .46532 m
.52828 .46532 L
s
.52828 .46532 m
.52828 .46533 L
s
.52828 .46532 m
.52828 .46532 L
s
.52828 .46533 m
.52828 .46532 L
s
.52828 .46532 m
.52828 .46532 L
s
.52828 .46532 m
.52828 .46533 L
s
1 .025 0 r
.3691 .68948 m
.37049 .68888 L
s
1 .029 0 r
.27699 .53999 m
.27681 .54008 L
s
.27684 .53959 m
.27699 .53999 L
s
.27717 .53971 m
.27699 .53999 L
s
.27665 .53968 m
.27684 .53959 L
s
.27684 .53959 m
.27717 .53971 L
s
1 .009 0 r
.57022 .73917 m
.5703 .73927 L
s
.57015 .73922 m
.57022 .73917 L
s
.57022 .73917 m
.5703 .73919 L
s
.5703 .73927 m
.57022 .73932 L
s
.5703 .73919 m
.5703 .73927 L
s
1 .001 0 r
.82284 .66448 m
.82287 .66444 L
s
1 0 0 r
.32744 .41532 m
.32744 .41532 L
s
.32744 .41532 m
.32744 .41532 L
s
.32744 .41532 m
.32744 .41532 L
s
.32744 .41532 m
.32744 .41532 L
s
.32744 .41532 m
.32744 .41532 L
s
.32744 .41532 m
.32744 .41532 L
s
.32744 .41532 m
.32744 .41532 L
s
.32744 .41532 m
.32744 .41532 L
s
.32744 .41532 m
.32744 .41532 L
s
1 .009 0 r
.57022 .73932 m
.57015 .73922 L
s
.57015 .73922 m
.5703 .73919 L
s
.5703 .73919 m
.57022 .73932 L
s
1 .001 0 r
.82287 .66443 m
.82288 .66445 L
s
.82285 .66444 m
.82287 .66443 L
s
.82287 .66443 m
.82287 .66444 L
s
.82288 .66445 m
.82287 .66446 L
s
.82287 .66444 m
.82288 .66445 L
s
.82287 .66446 m
.82285 .66444 L
s
.82285 .66444 m
.82287 .66444 L
s
.82287 .66444 m
.82287 .66446 L
s
1 .003 0 r
.62201 .61448 m
.62209 .61439 L
s
1 .029 0 r
.27717 .53971 m
.27681 .54008 L
s
.27665 .53968 m
.27717 .53971 L
s
.27681 .54008 m
.27665 .53968 L
s
1 .003 0 r
.62207 .61438 m
.6221 .61441 L
s
.62205 .6144 m
.62207 .61438 L
s
.62207 .61438 m
.62209 .61439 L
s
.6221 .61441 m
.62207 .61443 L
s
.62209 .61439 m
.6221 .61441 L
s
.62207 .61443 m
.62205 .6144 L
s
.62205 .6144 m
.62209 .61439 L
s
.62209 .61439 m
.62207 .61443 L
s
1 .025 0 r
.37038 .68911 m
.37021 .68922 L
s
.37023 .68878 m
.37038 .68911 L
s
.37049 .68888 m
.37038 .68911 L
s
.37005 .68889 m
.37023 .68878 L
s
.37023 .68878 m
.37049 .68888 L
s
1 .008 0 r
.42115 .56447 m
.42146 .5642 L
s
1 0 0 r
.87498 .53947 m
.87498 .53946 L
s
.87498 .53946 m
.87498 .53946 L
s
.87498 .53946 m
.87498 .53946 L
s
.87498 .53946 m
.87498 .53946 L
s
.87498 .53946 m
.87498 .53946 L
s
.87498 .53946 m
.87498 .53946 L
s
.87498 .53946 m
.87498 .53946 L
s
.87498 .53946 m
.87498 .53946 L
s
.87498 .53946 m
.87498 .53946 L
s
1 .004 0 r
.71577 .76368 m
.71594 .76353 L
s
1 .008 0 r
.4214 .56419 m
.42147 .56428 L
s
.42133 .56423 m
.4214 .56419 L
s
.4214 .56419 m
.42146 .5642 L
s
1 .025 0 r
.37021 .68922 m
.37005 .68889 L
s
.37049 .68888 m
.37021 .68922 L
s
1 .008 0 r
.42147 .56428 m
.4214 .56432 L
s
.42146 .5642 m
.42147 .56428 L
s
1 .025 0 r
.37005 .68889 m
.37049 .68888 L
s
1 .008 0 r
.4214 .56432 m
.42133 .56423 L
s
.42133 .56423 m
.42146 .5642 L
s
.42146 .5642 m
.4214 .56432 L
s
1 0 0 r
.67411 .48944 m
.67412 .48944 L
s
.67411 .48944 m
.67412 .48944 L
s
.67411 .48944 m
.67411 .48944 L
s
.67411 .48944 m
.67412 .48944 L
s
.67412 .48944 m
.67411 .48944 L
s
.67412 .48944 m
.67412 .48944 L
s
.67411 .48944 m
.67411 .48944 L
s
.67411 .48944 m
.67412 .48944 L
s
.67412 .48944 m
.67411 .48944 L
s
1 .004 0 r
.7159 .76352 m
.71594 .76357 L
s
.71586 .76355 m
.7159 .76352 L
s
.7159 .76352 m
.71594 .76353 L
s
.71594 .76357 m
.71591 .7636 L
s
.71594 .76353 m
.71594 .76357 L
s
.71591 .7636 m
.71586 .76355 L
s
.71586 .76355 m
.71594 .76353 L
s
.71594 .76353 m
.71591 .7636 L
s
1 .011 0 r
.51488 .71368 m
.51536 .71334 L
s
1 .001 0 r
.96879 .68867 m
.96882 .68864 L
s
1 0 0 r
.47321 .43941 m
.47321 .43941 L
s
.47321 .43941 m
.47321 .43941 L
s
.47321 .43941 m
.47321 .43941 L
s
.47321 .43941 m
.47321 .43941 L
s
.47321 .43941 m
.47321 .43941 L
s
.47321 .43941 m
.47321 .43941 L
s
.47321 .43941 m
.47321 .43941 L
s
.47321 .43941 m
.47321 .43941 L
s
.47321 .43941 m
.47321 .43941 L
s
1 .001 0 r
.96881 .68864 m
.96882 .68865 L
s
.9688 .68865 m
.96881 .68864 L
s
.96881 .68864 m
.96882 .68864 L
s
.96882 .68865 m
.96881 .68866 L
s
.96882 .68864 m
.96882 .68865 L
s
.96881 .68866 m
.9688 .68865 L
s
.9688 .68865 m
.96882 .68864 L
s
.96882 .68864 m
.96881 .68866 L
s
1 .034 0 r
.31396 .66367 m
.316 .663 L
s
1 .011 0 r
.51527 .71331 m
.51536 .71344 L
s
.51518 .71337 m
.51527 .71331 L
s
.51527 .71331 m
.51536 .71334 L
s
.51536 .71344 m
.51527 .7135 L
s
.51536 .71334 m
.51536 .71344 L
s
1 .001 0 r
.7679 .63866 m
.76794 .63861 L
s
.76793 .63861 m
.76794 .63862 L
s
.76792 .63861 m
.76793 .63861 L
s
.76793 .63861 m
.76794 .63861 L
s
.76794 .63862 m
.76793 .63863 L
s
.76794 .63861 m
.76794 .63862 L
s
.76793 .63863 m
.76792 .63861 L
s
.76792 .63861 m
.76794 .63861 L
s
.76794 .63861 m
.76793 .63863 L
s
1 .011 0 r
.51527 .7135 m
.51518 .71337 L
s
.51518 .71337 m
.51536 .71334 L
s
.51536 .71334 m
.51527 .7135 L
s
1 .003 0 r
.56698 .58863 m
.56707 .58852 L
s
.56705 .58852 m
.56707 .58855 L
s
.56702 .58854 m
.56705 .58852 L
s
.56705 .58852 m
.56707 .58852 L
s
.56707 .58855 m
.56705 .58857 L
s
.56707 .58852 m
.56707 .58855 L
s
.56705 .58857 m
.56702 .58854 L
s
.56702 .58854 m
.56707 .58852 L
s
.56707 .58852 m
.56705 .58857 L
s
1 .034 0 r
.31578 .6633 m
.31558 .66343 L
s
.31561 .66284 m
.31578 .6633 L
s
.316 .663 m
.31578 .6633 L
s
.3154 .66297 m
.31561 .66284 L
s
.31561 .66284 m
.316 .663 L
s
1 .011 0 r
.36602 .5386 m
.36649 .53824 L
s
1 0 0 r
.82006 .51358 m
.82006 .51357 L
s
.82006 .51357 m
.82006 .51357 L
s
.82006 .51357 m
.82006 .51357 L
s
.82006 .51357 m
.82006 .51357 L
s
.82006 .51357 m
.82006 .51357 L
s
.82006 .51357 m
.82006 .51357 L
s
.82006 .51357 m
.82006 .51357 L
s
.82006 .51357 m
.82006 .51357 L
s
.82006 .51357 m
.82006 .51357 L
s
1 .005 0 r
.66077 .7379 m
.66097 .73772 L
s
1 .011 0 r
.3664 .53822 m
.36649 .53835 L
s
.3663 .53827 m
.3664 .53822 L
s
.3664 .53822 m
.36649 .53824 L
s
.36649 .53835 m
.36639 .5384 L
s
.36649 .53824 m
.36649 .53835 L
s
1 0 0 r
.61909 .46353 m
.61909 .46353 L
s
.61909 .46353 m
.61909 .46353 L
s
.61909 .46353 m
.61909 .46353 L
s
.61909 .46353 m
.61909 .46353 L
s
.61909 .46353 m
.61909 .46353 L
s
.61909 .46353 m
.61909 .46353 L
s
1 .034 0 r
.316 .663 m
.31558 .66343 L
s
.3154 .66297 m
.316 .663 L
s
1 0 0 r
.61909 .46353 m
.61909 .46353 L
s
.61909 .46353 m
.61909 .46353 L
s
.61909 .46353 m
.61909 .46353 L
s
1 .034 0 r
.31558 .66343 m
.3154 .66297 L
s
1 .005 0 r
.66093 .73771 m
.66098 .73777 L
s
.66088 .73774 m
.66093 .73771 L
s
.66093 .73771 m
.66097 .73772 L
s
.66098 .73777 m
.66093 .7378 L
s
.66097 .73772 m
.66098 .73777 L
s
1 .011 0 r
.36639 .5384 m
.3663 .53827 L
s
.3663 .53827 m
.36649 .53824 L
s
.36649 .53824 m
.36639 .5384 L
s
1 .005 0 r
.66093 .7378 m
.66088 .73774 L
s
.66088 .73774 m
.66097 .73772 L
s
1 .014 0 r
.45979 .68787 m
.46044 .68744 L
s
1 .005 0 r
.66097 .73772 m
.66093 .7378 L
s
1 .001 0 r
.9139 .66285 m
.91393 .66282 L
s
1 0 0 r
.41809 .41347 m
.41809 .41347 L
s
.41809 .41347 m
.41809 .41347 L
s
.41809 .41347 m
.41809 .41347 L
s
.41809 .41347 m
.41809 .41347 L
s
.41809 .41347 m
.41809 .41347 L
s
.41809 .41347 m
.41809 .41347 L
s
.41809 .41347 m
.41809 .41347 L
s
.41809 .41347 m
.41809 .41347 L
s
.41809 .41347 m
.41809 .41347 L
s
1 .001 0 r
.91392 .66282 m
.91393 .66283 L
s
.91391 .66282 m
.91392 .66282 L
s
.91392 .66282 m
.91393 .66282 L
s
.91393 .66283 m
.91392 .66283 L
s
.91393 .66282 m
.91393 .66283 L
s
.91392 .66283 m
.91391 .66282 L
s
.91391 .66282 m
.91393 .66282 L
s
.91393 .66282 m
.91392 .66283 L
s
.71292 .61281 m
.71295 .61275 L
s
.71295 .61275 m
.71296 .61277 L
s
.71293 .61276 m
.71295 .61275 L
s
.71295 .61275 m
.71295 .61275 L
s
1 .014 0 r
.46031 .6874 m
.46043 .68758 L
s
.4602 .68747 m
.46031 .6874 L
s
.46031 .6874 m
.46044 .68744 L
s
1 .001 0 r
.71296 .61277 m
.71295 .61278 L
s
.71295 .61275 m
.71296 .61277 L
s
.71295 .61278 m
.71293 .61276 L
s
.71293 .61276 m
.71295 .61275 L
s
1 .014 0 r
.46043 .68758 m
.46031 .68765 L
s
.46044 .68744 m
.46043 .68758 L
s
1 .001 0 r
.71295 .61275 m
.71295 .61278 L
s
1 .014 0 r
.46031 .68765 m
.4602 .68747 L
s
.4602 .68747 m
.46044 .68744 L
s
.46044 .68744 m
.46031 .68765 L
s
1 .003 0 r
.51189 .56276 m
.512 .56263 L
s
.51198 .56263 m
.51201 .56266 L
s
.51195 .56265 m
.51198 .56263 L
s
.51198 .56263 m
.512 .56263 L
s
.51201 .56266 m
.51198 .56268 L
s
.512 .56263 m
.51201 .56266 L
s
.51198 .56268 m
.51195 .56265 L
s
.51195 .56265 m
.512 .56263 L
s
.512 .56263 m
.51198 .56268 L
s
.80677 .76213 m
.80687 .76203 L
s
1 .016 0 r
.31084 .5127 m
.31163 .51222 L
s
1 .003 0 r
.80685 .76203 m
.80688 .76206 L
s
.80682 .76205 m
.80685 .76203 L
s
.80685 .76203 m
.80687 .76203 L
s
.80688 .76206 m
.80685 .76208 L
s
.80687 .76203 m
.80688 .76206 L
s
.80685 .76208 m
.80682 .76205 L
s
.80682 .76205 m
.80687 .76203 L
s
1 0 0 r
.76508 .48766 m
.76508 .48766 L
s
.76508 .48766 m
.76508 .48766 L
s
.76508 .48766 m
.76508 .48766 L
s
.76508 .48766 m
.76508 .48766 L
s
.76508 .48766 m
.76508 .48766 L
s
.76508 .48766 m
.76508 .48766 L
s
.76508 .48766 m
.76508 .48766 L
s
.76508 .48766 m
.76508 .48766 L
s
.76508 .48766 m
.76508 .48766 L
s
1 .003 0 r
.80687 .76203 m
.80685 .76208 L
s
1 .006 0 r
.60572 .71209 m
.60596 .71187 L
s
1 0 0 r
.56402 .43759 m
.56402 .43759 L
s
.56402 .43759 m
.56402 .43759 L
s
.56402 .43759 m
.56402 .43759 L
s
.56402 .43759 m
.56402 .43759 L
s
.56402 .43759 m
.56402 .43759 L
s
.56402 .43759 m
.56402 .43759 L
s
.56402 .43759 m
.56402 .43759 L
s
.56402 .43759 m
.56402 .43759 L
s
.56402 .43759 m
.56402 .43759 L
s
1 .016 0 r
.31148 .51218 m
.31159 .51239 L
s
.31135 .51224 m
.31148 .51218 L
s
.31148 .51218 m
.31163 .51222 L
s
.31159 .51239 m
.31146 .51245 L
s
.31163 .51222 m
.31159 .51239 L
s
1 .006 0 r
.60592 .71186 m
.60597 .71193 L
s
.60586 .7119 m
.60592 .71186 L
s
.60592 .71186 m
.60596 .71187 L
s
.60597 .71193 m
.60592 .71197 L
s
.60596 .71187 m
.60597 .71193 L
s
1 .019 0 r
.40464 .66203 m
.40558 .66149 L
s
1 .006 0 r
.60592 .71197 m
.60586 .7119 L
s
.60586 .7119 m
.60596 .71187 L
s
.60596 .71187 m
.60592 .71197 L
s
1 .001 0 r
.85897 .637 m
.85899 .63697 L
s
1 .016 0 r
.31146 .51245 m
.31135 .51224 L
s
.31135 .51224 m
.31163 .51222 L
s
.31163 .51222 m
.31146 .51245 L
s
1 .001 0 r
.85898 .63697 m
.85899 .63698 L
s
.85897 .63697 m
.85898 .63697 L
s
.85898 .63697 m
.85899 .63697 L
s
.85899 .63698 m
.85898 .63698 L
s
.85899 .63697 m
.85899 .63698 L
s
.85898 .63698 m
.85897 .63697 L
s
.85897 .63697 m
.85899 .63697 L
s
.85899 .63697 m
.85898 .63698 L
s
.65788 .58693 m
.65792 .58688 L
s
.65791 .58687 m
.65793 .58689 L
s
.6579 .58688 m
.65791 .58687 L
s
.65791 .58687 m
.65792 .58688 L
s
.65793 .58689 m
.65791 .5869 L
s
.65792 .58688 m
.65793 .58689 L
s
.65791 .5869 m
.6579 .58688 L
s
.6579 .58688 m
.65792 .58688 L
s
.65792 .58688 m
.65791 .5869 L
s
1 .019 0 r
.4054 .66143 m
.40554 .66168 L
s
.40525 .66152 m
.4054 .66143 L
s
.4054 .66143 m
.40558 .66149 L
s
.40554 .66168 m
.40539 .66176 L
s
.40558 .66149 m
.40554 .66168 L
s
1 .004 0 r
.45676 .53686 m
.45689 .53671 L
s
1 0 0 r
.91118 .51181 m
.91118 .51181 L
s
.91118 .51181 m
.91118 .51181 L
s
.91118 .51181 m
.91118 .51181 L
s
.91118 .51181 m
.91118 .51181 L
s
.91118 .51181 m
.91118 .51181 L
s
.91118 .51181 m
.91118 .51181 L
s
.91118 .51181 m
.91118 .51181 L
s
.91118 .51181 m
.91118 .51181 L
s
.91118 .51181 m
.91118 .51181 L
s
1 .019 0 r
.40539 .66176 m
.40525 .66152 L
s
.40525 .66152 m
.40558 .66149 L
s
1 .004 0 r
.45686 .5367 m
.4569 .53675 L
s
.45682 .53673 m
.45686 .5367 L
s
.45686 .5367 m
.45689 .53671 L
s
1 .019 0 r
.40558 .66149 m
.40539 .66176 L
s
1 .004 0 r
.4569 .53675 m
.45686 .53677 L
s
.45689 .53671 m
.4569 .53675 L
s
.45686 .53677 m
.45682 .53673 L
s
.45682 .53673 m
.45689 .53671 L
s
.45689 .53671 m
.45686 .53677 L
s
1 .003 0 r
.75177 .73632 m
.75188 .73621 L
s
1 .024 0 r
.25561 .48677 m
.25706 .48622 L
s
1 .003 0 r
.75186 .7362 m
.75189 .73624 L
s
.75183 .73622 m
.75186 .7362 L
s
.75186 .7362 m
.75188 .73621 L
s
.75189 .73624 m
.75186 .73626 L
s
.75188 .73621 m
.75189 .73624 L
s
1 0 0 r
.71006 .46173 m
.71006 .46172 L
s
.71006 .46172 m
.71006 .46172 L
s
.71006 .46172 m
.71006 .46172 L
s
.71006 .46172 m
.71006 .46172 L
s
.71006 .46172 m
.71006 .46172 L
s
.71006 .46172 m
.71006 .46172 L
s
.71006 .46172 m
.71006 .46172 L
s
.71006 .46172 m
.71006 .46172 L
s
.71006 .46172 m
.71006 .46172 L
s
1 .003 0 r
.75186 .73626 m
.75183 .73622 L
s
.75183 .73622 m
.75188 .73621 L
s
.75188 .73621 m
.75186 .73626 L
s
1 .008 0 r
.55062 .68625 m
.55093 .68599 L
s
1 0 0 r
.5089 .41163 m
.5089 .41163 L
s
.5089 .41163 m
.5089 .41163 L
s
.5089 .41163 m
.5089 .41163 L
s
.5089 .41163 m
.5089 .41163 L
s
.5089 .41163 m
.5089 .41163 L
s
.5089 .41163 m
.5089 .41163 L
s
.5089 .41163 m
.5089 .41163 L
s
.5089 .41163 m
.5089 .41163 L
s
.5089 .41163 m
.5089 .41163 L
s
1 .024 0 r
.25691 .48646 m
.25675 .48654 L
s
.25678 .48613 m
.25691 .48646 L
s
.25706 .48622 m
.25691 .48646 L
s
.25662 .4862 m
.25678 .48613 L
s
.25678 .48613 m
.25706 .48622 L
s
1 .026 0 r
.34944 .63617 m
.35087 .6355 L
s
1 .008 0 r
.55087 .68597 m
.55094 .68606 L
s
.5508 .68602 m
.55087 .68597 L
s
.55087 .68597 m
.55093 .68599 L
s
.55094 .68606 m
.55087 .68611 L
s
.55093 .68599 m
.55094 .68606 L
s
.55087 .68611 m
.5508 .68602 L
s
.5508 .68602 m
.55093 .68599 L
s
.55093 .68599 m
.55087 .68611 L
s
1 .001 0 r
.80398 .61113 m
.804 .6111 L
s
.80399 .61109 m
.804 .6111 L
s
.80398 .6111 m
.80399 .61109 L
s
.80399 .61109 m
.804 .6111 L
s
.804 .6111 m
.80399 .61111 L
s
.804 .6111 m
.804 .6111 L
s
.80399 .61111 m
.80398 .6111 L
s
.80398 .6111 m
.804 .6111 L
s
.804 .6111 m
.80399 .61111 L
s
1 .024 0 r
.25706 .48622 m
.25675 .48654 L
s
.25662 .4862 m
.25706 .48622 L
s
.25675 .48654 m
.25662 .4862 L
s
1 .002 0 r
.60279 .56103 m
.60283 .56097 L
s
.60282 .56097 m
.60284 .56099 L
s
.60281 .56098 m
.60282 .56097 L
s
.60282 .56097 m
.60283 .56097 L
s
.60284 .56099 m
.60282 .561 L
s
.60283 .56097 m
.60284 .56099 L
s
.60282 .561 m
.60281 .56098 L
s
.60281 .56098 m
.60283 .56097 L
s
.60283 .56097 m
.60282 .561 L
s
.89792 .76058 m
.89799 .76051 L
s
1 .026 0 r
.35077 .63575 m
.35058 .63586 L
s
.3506 .6354 m
.35077 .63575 L
s
.35087 .6355 m
.35077 .63575 L
s
1 .005 0 r
.40157 .51093 m
.40174 .51075 L
s
1 .026 0 r
.3504 .63551 m
.3506 .6354 L
s
.3506 .6354 m
.35087 .6355 L
s
1 .002 0 r
.89797 .76051 m
.89799 .76053 L
s
.89796 .76052 m
.89797 .76051 L
s
.89797 .76051 m
.89799 .76051 L
s
.89799 .76053 m
.89798 .76054 L
s
.89799 .76051 m
.89799 .76053 L
s
.89798 .76054 m
.89796 .76052 L
s
.89796 .76052 m
.89799 .76051 L
s
.89799 .76051 m
.89798 .76054 L
s
1 0 0 r
.8562 .48588 m
.8562 .48588 L
s
.8562 .48588 m
.85621 .48588 L
s
.8562 .48588 m
.8562 .48588 L
s
.8562 .48588 m
.8562 .48588 L
s
.85621 .48588 m
.8562 .48588 L
s
.8562 .48588 m
.85621 .48588 L
s
.8562 .48588 m
.8562 .48588 L
s
.8562 .48588 m
.8562 .48588 L
s
.8562 .48588 m
.8562 .48588 L
s
1 .005 0 r
.40171 .51075 m
.40175 .5108 L
s
.40166 .51077 m
.40171 .51075 L
s
.40171 .51075 m
.40174 .51075 L
s
.40175 .5108 m
.4017 .51083 L
s
.40174 .51075 m
.40175 .5108 L
s
.4017 .51083 m
.40166 .51077 L
s
.40166 .51077 m
.40174 .51075 L
s
.40174 .51075 m
.4017 .51083 L
s
1 .004 0 r
.69672 .71049 m
.69684 .71036 L
s
1 .026 0 r
.35058 .63586 m
.3504 .63551 L
s
.35087 .6355 m
.35058 .63586 L
s
.3504 .63551 m
.35087 .6355 L
s
1 0 0 r
.65498 .43576 m
.65498 .43576 L
s
.65498 .43576 m
.65498 .43576 L
s
.65498 .43576 m
.65498 .43576 L
s
.65498 .43576 m
.65498 .43576 L
s
.65498 .43576 m
.65498 .43576 L
s
.65498 .43576 m
.65498 .43576 L
s
.65498 .43576 m
.65498 .43576 L
s
.65498 .43576 m
.65498 .43576 L
s
.65498 .43576 m
.65498 .43576 L
s
1 .004 0 r
.69682 .71035 m
.69685 .71039 L
s
.69678 .71037 m
.69682 .71035 L
s
.69682 .71035 m
.69684 .71036 L
s
.69685 .71039 m
.69682 .71042 L
s
.69684 .71036 m
.69685 .71039 L
s
.69682 .71042 m
.69678 .71037 L
s
.69678 .71037 m
.69684 .71036 L
s
.69684 .71036 m
.69682 .71042 L
s
1 .01 0 r
.49547 .66039 m
.49588 .66006 L
s
1 .001 0 r
.95018 .63534 m
.95019 .63532 L
s
.95019 .63532 m
.9502 .63532 L
s
.95019 .63532 m
.95019 .63532 L
s
.95019 .63532 m
.95019 .63532 L
s
.9502 .63532 m
.95019 .63533 L
s
.95019 .63532 m
.9502 .63532 L
s
.95019 .63533 m
.95019 .63532 L
s
.95019 .63532 m
.95019 .63532 L
s
.95019 .63532 m
.95019 .63533 L
s
1 .037 0 r
.2942 .61029 m
.29646 .60952 L
s
1 .01 0 r
.4958 .66004 m
.49588 .66016 L
s
.49571 .6601 m
.4958 .66004 L
s
.4958 .66004 m
.49588 .66006 L
s
.49588 .66016 m
.4958 .66022 L
s
.49588 .66006 m
.49588 .66016 L
s
1 .001 0 r
.74893 .58523 m
.74895 .5852 L
s
.74895 .5852 m
.74896 .58521 L
s
.74894 .5852 m
.74895 .5852 L
s
.74895 .5852 m
.74895 .5852 L
s
.74896 .58521 m
.74895 .58521 L
s
.74895 .5852 m
.74896 .58521 L
s
.74895 .58521 m
.74894 .5852 L
s
.74894 .5852 m
.74895 .5852 L
s
.74895 .5852 m
.74895 .58521 L
s
1 .01 0 r
.4958 .66022 m
.49571 .6601 L
s
.49571 .6601 m
.49588 .66006 L
s
.49588 .66006 m
.4958 .66022 L
s
1 .002 0 r
.54765 .53511 m
.5477 .53505 L
s
.54769 .53505 m
.5477 .53506 L
s
.54767 .53506 m
.54769 .53505 L
s
.54769 .53505 m
.5477 .53505 L
s
.5477 .53506 m
.54769 .53507 L
s
.5477 .53505 m
.5477 .53506 L
s
.54769 .53507 m
.54767 .53506 L
s
.54767 .53506 m
.5477 .53505 L
s
.5477 .53505 m
.54769 .53507 L
s
1 .027 0 r
.3881 .7598 m
.38962 .7592 L
s
1 .002 0 r
.84292 .73475 m
.84298 .73467 L
s
1 .037 0 r
.29622 .60986 m
.29598 .60999 L
s
.29602 .60935 m
.29622 .60986 L
s
.29646 .60952 m
.29622 .60986 L
s
1 .006 0 r
.34634 .48499 m
.34657 .48477 L
s
1 .037 0 r
.29579 .60948 m
.29602 .60935 L
s
.29602 .60935 m
.29646 .60952 L
s
1 .002 0 r
.84297 .73467 m
.84299 .73469 L
s
.84295 .73468 m
.84297 .73467 L
s
.84297 .73467 m
.84298 .73467 L
s
.84299 .73469 m
.84297 .7347 L
s
.84298 .73467 m
.84299 .73469 L
s
.84297 .7347 m
.84295 .73468 L
s
.84295 .73468 m
.84298 .73467 L
s
.84298 .73467 m
.84297 .7347 L
s
1 0 0 r
.80118 .45992 m
.80118 .45992 L
s
.80118 .45992 m
.80118 .45992 L
s
.80118 .45992 m
.80118 .45992 L
s
.80118 .45992 m
.80118 .45992 L
s
.80118 .45992 m
.80118 .45992 L
s
.80118 .45992 m
.80118 .45992 L
s
.80118 .45992 m
.80118 .45992 L
s
.80118 .45992 m
.80118 .45992 L
s
.80118 .45992 m
.80118 .45992 L
s
1 .006 0 r
.34652 .48476 m
.34658 .48483 L
s
.34647 .48479 m
.34652 .48476 L
s
.34652 .48476 m
.34657 .48477 L
s
.34658 .48483 m
.34652 .48486 L
s
.34657 .48477 m
.34658 .48483 L
s
1 .004 0 r
.64161 .68463 m
.64176 .68448 L
s
1 .006 0 r
.34652 .48486 m
.34647 .48479 L
s
.34647 .48479 m
.34657 .48477 L
s
.34657 .48477 m
.34652 .48486 L
s
1 0 0 r
.59986 .40978 m
.59986 .40978 L
s
.59986 .40978 m
.59986 .40978 L
s
.59986 .40978 m
.59986 .40978 L
s
.59986 .40978 m
.59986 .40978 L
s
.59986 .40978 m
.59986 .40978 L
s
.59986 .40978 m
.59986 .40978 L
s
.59986 .40978 m
.59986 .40978 L
s
.59986 .40978 m
.59986 .40978 L
s
.59986 .40978 m
.59986 .40978 L
s
1 .004 0 r
.64173 .68447 m
.64177 .68452 L
s
.64169 .6845 m
.64173 .68447 L
s
.64173 .68447 m
.64176 .68448 L
s
.64177 .68452 m
.64173 .68455 L
s
.64176 .68448 m
.64177 .68452 L
s
1 .027 0 r
.38949 .75943 m
.3893 .75956 L
s
.38932 .75908 m
.38949 .75943 L
s
.38962 .7592 m
.38949 .75943 L
s
1 .004 0 r
.64173 .68455 m
.64169 .6845 L
s
.64169 .6845 m
.64176 .68448 L
s
.64176 .68448 m
.64173 .68455 L
s
1 .027 0 r
.38914 .7592 m
.38932 .75908 L
s
.38932 .75908 m
.38962 .7592 L
s
1 .013 0 r
.44027 .63451 m
.44084 .63408 L
s
1 .037 0 r
.29646 .60952 m
.29598 .60999 L
s
.29579 .60948 m
.29646 .60952 L
s
.29598 .60999 m
.29579 .60948 L
s
1 0 0 r
.89519 .60945 m
.8952 .60943 L
s
.8952 .60943 m
.8952 .60943 L
s
.89519 .60943 m
.8952 .60943 L
s
.8952 .60943 m
.8952 .60943 L
s
.8952 .60943 m
.8952 .60943 L
s
.8952 .60943 m
.8952 .60943 L
s
.8952 .60943 m
.89519 .60943 L
s
.89519 .60943 m
.8952 .60943 L
s
.8952 .60943 m
.8952 .60943 L
s
1 .027 0 r
.3893 .75956 m
.38914 .7592 L
s
.38962 .7592 m
.3893 .75956 L
s
.38914 .7592 m
.38962 .7592 L
s
1 .001 0 r
.69384 .55931 m
.69386 .55928 L
s
.69386 .55928 m
.69387 .55929 L
s
.69385 .55928 m
.69386 .55928 L
s
.69386 .55928 m
.69386 .55928 L
s
.69387 .55929 m
.69386 .55929 L
s
.69386 .55928 m
.69387 .55929 L
s
.69386 .55929 m
.69385 .55928 L
s
.69385 .55928 m
.69386 .55928 L
s
.69386 .55928 m
.69386 .55929 L
s
1 .013 0 r
.44073 .63405 m
.44084 .63422 L
s
.44062 .63412 m
.44073 .63405 L
s
.44073 .63405 m
.44084 .63408 L
s
.44084 .63422 m
.44073 .63428 L
s
.44084 .63408 m
.44084 .63422 L
s
.44073 .63428 m
.44062 .63412 L
s
.44062 .63412 m
.44084 .63408 L
s
.44084 .63408 m
.44073 .63428 L
s
1 .002 0 r
.49246 .50917 m
.49251 .5091 L
s
.4925 .5091 m
.49251 .50912 L
s
.49248 .50911 m
.4925 .5091 L
s
.4925 .5091 m
.49251 .5091 L
s
.49251 .50912 m
.4925 .50913 L
s
.49251 .5091 m
.49251 .50912 L
s
.4925 .50913 m
.49248 .50911 L
s
.49248 .50911 m
.49251 .5091 L
s
.49251 .5091 m
.4925 .50913 L
s
1 .034 0 r
.33283 .73396 m
.33495 .7333 L
s
1 .002 0 r
.78786 .70889 m
.78793 .70881 L
s
1 .008 0 r
.29105 .45901 m
.2914 .45876 L
s
1 .002 0 r
.78792 .7088 m
.78794 .70883 L
s
.7879 .70882 m
.78792 .7088 L
s
.78792 .7088 m
.78793 .70881 L
s
.78794 .70883 m
.78792 .70884 L
s
.78793 .70881 m
.78794 .70883 L
s
.78792 .70884 m
.7879 .70882 L
s
.7879 .70882 m
.78793 .70881 L
s
.78793 .70881 m
.78792 .70884 L
s
1 0 0 r
.7461 .43394 m
.7461 .43393 L
s
.7461 .43393 m
.7461 .43393 L
s
.7461 .43393 m
.7461 .43393 L
s
.7461 .43393 m
.7461 .43393 L
s
.7461 .43393 m
.7461 .43393 L
s
.7461 .43393 m
.7461 .43393 L
s
.7461 .43393 m
.7461 .43393 L
s
.7461 .43393 m
.7461 .43393 L
s
.7461 .43393 m
.7461 .43393 L
s
1 .008 0 r
.29133 .45874 m
.29139 .45884 L
s
.29127 .45878 m
.29133 .45874 L
s
.29133 .45874 m
.2914 .45876 L
s
.29139 .45884 m
.29133 .45887 L
s
.2914 .45876 m
.29139 .45884 L
s
1 .005 0 r
.58646 .65875 m
.58664 .65856 L
s
1 .008 0 r
.29133 .45887 m
.29127 .45878 L
s
.29127 .45878 m
.2914 .45876 L
s
.2914 .45876 m
.29133 .45887 L
s
1 .034 0 r
.33472 .7336 m
.33451 .73374 L
s
.33454 .73313 m
.33472 .7336 L
s
.33495 .7333 m
.33472 .7336 L
s
1 .005 0 r
.5866 .65855 m
.58665 .65861 L
s
.58656 .65859 m
.5866 .65855 L
s
.5866 .65855 m
.58664 .65856 L
s
.58665 .65861 m
.5866 .65865 L
s
.58664 .65856 m
.58665 .65861 L
s
1 .034 0 r
.33433 .73327 m
.33454 .73313 L
s
.33454 .73313 m
.33495 .7333 L
s
1 .005 0 r
.5866 .65865 m
.58656 .65859 L
s
.58656 .65859 m
.58664 .65856 L
s
1 .018 0 r
.38502 .6086 m
.38588 .60804 L
s
1 .005 0 r
.58664 .65856 m
.5866 .65865 L
s
1 0 0 r
.84014 .58353 m
.84015 .58351 L
s
.84015 .58351 m
.84016 .58351 L
s
.84015 .58351 m
.84015 .58351 L
s
.84015 .58351 m
.84015 .58351 L
s
.84016 .58351 m
.84015 .58351 L
s
.84015 .58351 m
.84016 .58351 L
s
.84015 .58351 m
.84015 .58351 L
s
.84015 .58351 m
.84015 .58351 L
s
.84015 .58351 m
.84015 .58351 L
s
1 .001 0 r
.6387 .53337 m
.63872 .53333 L
s
1 .034 0 r
.33495 .7333 m
.33451 .73374 L
s
.33433 .73327 m
.33495 .7333 L
s
1 .001 0 r
.63871 .53333 m
.63872 .53334 L
s
.63871 .53334 m
.63871 .53333 L
s
.63871 .53333 m
.63872 .53333 L
s
.63872 .53334 m
.63871 .53335 L
s
.63872 .53333 m
.63872 .53334 L
s
.63871 .53335 m
.63871 .53334 L
s
.63871 .53334 m
.63872 .53333 L
s
1 .034 0 r
.33451 .73374 m
.33433 .73327 L
s
1 .001 0 r
.63872 .53333 m
.63871 .53335 L
s
1 .017 0 r
.47902 .75824 m
.47983 .75777 L
s
1 .018 0 r
.38572 .608 m
.38586 .60823 L
s
.38556 .60808 m
.38572 .608 L
s
.38572 .608 m
.38588 .60804 L
s
.38586 .60823 m
.3857 .60831 L
s
.38588 .60804 m
.38586 .60823 L
s
1 .001 0 r
.93422 .73317 m
.93426 .73312 L
s
1 .002 0 r
.43722 .4832 m
.43727 .48313 L
s
1 .001 0 r
.93425 .73311 m
.93427 .73313 L
s
.93424 .73312 m
.93425 .73311 L
s
.93425 .73311 m
.93426 .73312 L
s
.93427 .73313 m
.93425 .73314 L
s
.93426 .73312 m
.93427 .73313 L
s
.93425 .73314 m
.93424 .73312 L
s
.93424 .73312 m
.93426 .73312 L
s
.93426 .73312 m
.93425 .73314 L
s
1 .002 0 r
.43726 .48313 m
.43727 .48315 L
s
.43724 .48314 m
.43726 .48313 L
s
.43726 .48313 m
.43727 .48313 L
s
.43727 .48315 m
.43726 .48316 L
s
.43727 .48313 m
.43727 .48315 L
s
.43726 .48316 m
.43724 .48314 L
s
.43724 .48314 m
.43727 .48313 L
s
.43727 .48313 m
.43726 .48316 L
s
1 0 0 r
.89245 .45811 m
.89245 .45811 L
s
.89245 .45811 m
.89245 .45811 L
s
.89245 .45811 m
.89245 .45811 L
s
.89245 .45811 m
.89245 .45811 L
s
.89245 .45811 m
.89245 .45811 L
s
.89245 .45811 m
.89245 .45811 L
s
.89245 .45811 m
.89245 .45811 L
s
.89245 .45811 m
.89245 .45811 L
s
.89245 .45811 m
.89245 .45811 L
s
1 .018 0 r
.3857 .60831 m
.38556 .60808 L
s
.38556 .60808 m
.38588 .60804 L
s
.38588 .60804 m
.3857 .60831 L
s
1 .003 0 r
.73275 .68301 m
.73283 .68292 L
s
1 .008 0 r
.23571 .43302 m
.23621 .43282 L
s
1 .003 0 r
.73282 .68291 m
.73284 .68294 L
s
.73279 .68293 m
.73282 .68291 L
s
.73282 .68291 m
.73283 .68292 L
s
.73284 .68294 m
.73282 .68296 L
s
.73283 .68292 m
.73284 .68294 L
s
1 .017 0 r
.47967 .75771 m
.4798 .75793 L
s
.47954 .7578 m
.47967 .75771 L
s
.47967 .75771 m
.47983 .75777 L
s
1 .003 0 r
.73282 .68296 m
.73279 .68293 L
s
.73279 .68293 m
.73283 .68292 L
s
1 .017 0 r
.4798 .75793 m
.47967 .75801 L
s
.47983 .75777 m
.4798 .75793 L
s
1 .003 0 r
.73283 .68292 m
.73282 .68296 L
s
1 0 0 r
.69097 .40793 m
.69097 .40793 L
s
.69097 .40793 m
.69097 .40793 L
s
.69097 .40793 m
.69097 .40793 L
s
.69097 .40793 m
.69097 .40793 L
s
.69097 .40793 m
.69097 .40793 L
s
.69097 .40793 m
.69097 .40793 L
s
.69097 .40793 m
.69097 .40793 L
s
.69097 .40793 m
.69097 .40793 L
s
.69097 .40793 m
.69097 .40793 L
s
1 .008 0 r
.23616 .4329 m
.2361 .43293 L
s
.23611 .43279 m
.23616 .4329 L
s
.23621 .43282 m
.23616 .4329 L
s
.23606 .43281 m
.23611 .43279 L
s
.23611 .43279 m
.23621 .43282 L
s
1 .007 0 r
.53125 .63285 m
.53148 .63261 L
s
1 .008 0 r
.2361 .43293 m
.23606 .43281 L
s
.23621 .43282 m
.2361 .43293 L
s
.23606 .43281 m
.23621 .43282 L
s
1 .017 0 r
.47967 .75801 m
.47954 .7578 L
s
.47954 .7578 m
.47983 .75777 L
s
.47983 .75777 m
.47967 .75801 L
s
1 .007 0 r
.53144 .6326 m
.5315 .63268 L
s
.53138 .63264 m
.53144 .6326 L
s
.53144 .6326 m
.53148 .63261 L
s
.5315 .63268 m
.53144 .63272 L
s
.53148 .63261 m
.5315 .63268 L
s
1 .027 0 r
.32971 .58267 m
.33113 .58193 L
s
1 .007 0 r
.53144 .63272 m
.53138 .63264 L
s
.53138 .63264 m
.53148 .63261 L
s
.53148 .63261 m
.53144 .63272 L
s
1 0 0 r
.78505 .55758 m
.78506 .55757 L
s
.78505 .55757 m
.78506 .55757 L
s
.78505 .55757 m
.78505 .55757 L
s
.78505 .55757 m
.78506 .55757 L
s
.78506 .55757 m
.78505 .55757 L
s
.78506 .55757 m
.78506 .55757 L
s
.78505 .55757 m
.78505 .55757 L
s
.78505 .55757 m
.78506 .55757 L
s
.78506 .55757 m
.78505 .55757 L
s
1 .001 0 r
.58351 .5074 m
.58352 .50737 L
s
.58352 .50737 m
.58352 .50738 L
s
.58351 .50737 m
.58352 .50737 L
s
.58352 .50737 m
.58352 .50737 L
s
.58352 .50738 m
.58352 .50738 L
s
.58352 .50737 m
.58352 .50738 L
s
.58352 .50738 m
.58351 .50737 L
s
.58351 .50737 m
.58352 .50737 L
s
.58352 .50737 m
.58352 .50738 L
s
1 .022 0 r
.42375 .73238 m
.42488 .7318 L
s
1 .001 0 r
.87916 .70729 m
.8792 .70723 L
s
.38193 .4572 m
.38197 .45714 L
s
.87919 .70723 m
.87921 .70725 L
s
.87918 .70724 m
.87919 .70723 L
s
.87919 .70723 m
.8792 .70723 L
s
.87921 .70725 m
.87919 .70726 L
s
.8792 .70723 m
.87921 .70725 L
s
.38196 .45714 m
.38198 .45716 L
s
.38195 .45715 m
.38196 .45714 L
s
.38196 .45714 m
.38197 .45714 L
s
1 .027 0 r
.33105 .5822 m
.33084 .58231 L
s
.33086 .58185 m
.33105 .5822 L
s
.33113 .58193 m
.33105 .5822 L
s
1 .001 0 r
.87919 .70726 m
.87918 .70724 L
s
.87918 .70724 m
.8792 .70723 L
s
.38198 .45716 m
.38196 .45717 L
s
.38197 .45714 m
.38198 .45716 L
s
1 .027 0 r
.33065 .58196 m
.33086 .58185 L
s
.33086 .58185 m
.33113 .58193 L
s
1 .001 0 r
.8792 .70723 m
.87919 .70726 L
s
.38196 .45717 m
.38195 .45715 L
s
.38195 .45715 m
.38197 .45714 L
s
.38197 .45714 m
.38196 .45717 L
s
1 0 0 r
.83736 .4321 m
.83736 .4321 L
s
.83736 .4321 m
.83736 .4321 L
s
.83736 .4321 m
.83736 .4321 L
s
.83736 .4321 m
.83736 .4321 L
s
.83736 .4321 m
.83736 .4321 L
s
.83736 .4321 m
.83736 .4321 L
s
.83736 .4321 m
.83736 .4321 L
s
.83736 .4321 m
.83736 .4321 L
s
.83736 .4321 m
.83736 .4321 L
s
1 .003 0 r
.67759 .65711 m
.67768 .657 L
s
.67766 .65699 m
.67769 .65703 L
s
.67764 .65701 m
.67766 .65699 L
s
.67766 .65699 m
.67768 .657 L
s
.67769 .65703 m
.67767 .65705 L
s
.67768 .657 m
.67769 .65703 L
s
.67767 .65705 m
.67764 .65701 L
s
.67764 .65701 m
.67768 .657 L
s
.67768 .657 m
.67767 .65705 L
s
1 .027 0 r
.33084 .58231 m
.33065 .58196 L
s
.33113 .58193 m
.33084 .58231 L
s
.33065 .58196 m
.33113 .58193 L
s
1 .022 0 r
.42466 .73172 m
.42481 .732 L
s
.42449 .73182 m
.42466 .73172 L
s
.42466 .73172 m
.42488 .7318 L
s
.42481 .732 m
.42465 .73211 L
s
.42488 .7318 m
.42481 .732 L
s
1 .008 0 r
.47599 .60692 m
.47631 .60662 L
s
1 0 0 r
.9315 .58182 m
.93151 .58181 L
s
.93151 .58181 m
.93151 .58181 L
s
.93151 .58181 m
.93151 .58181 L
s
.93151 .58181 m
.93151 .58181 L
s
.93151 .58181 m
.93151 .58181 L
s
.93151 .58181 m
.93151 .58181 L
s
.93151 .58181 m
.93151 .58181 L
s
.93151 .58181 m
.93151 .58181 L
s
.93151 .58181 m
.93151 .58181 L
s
1 .022 0 r
.42465 .73211 m
.42449 .73182 L
s
.42449 .73182 m
.42488 .7318 L
s
.42488 .7318 m
.42465 .73211 L
s
1 .041 0 r
.27436 .55672 m
.27685 .55583 L
s
1 .008 0 r
.47624 .60661 m
.47632 .60671 L
s
.47617 .60665 m
.47624 .60661 L
s
.47624 .60661 m
.47631 .60662 L
s
.47632 .60671 m
.47624 .60675 L
s
.47631 .60662 m
.47632 .60671 L
s
1 0 0 r
.7299 .53162 m
.72991 .5316 L
s
1 .008 0 r
.47624 .60675 m
.47617 .60665 L
s
.47617 .60665 m
.47631 .60662 L
s
1 0 0 r
.72991 .5316 m
.72991 .5316 L
s
.7299 .5316 m
.72991 .5316 L
s
.72991 .5316 m
.72991 .5316 L
s
.72991 .5316 m
.72991 .53161 L
s
.72991 .5316 m
.72991 .5316 L
s
.72991 .53161 m
.7299 .5316 L
s
.7299 .5316 m
.72991 .5316 L
s
.72991 .5316 m
.72991 .53161 L
s
1 .008 0 r
.47631 .60662 m
.47624 .60675 L
s
1 .01 0 r
.57008 .75668 m
.57052 .75636 L
s
1 .001 0 r
.52826 .4814 m
.52827 .48138 L
s
.52827 .48138 m
.52828 .48139 L
s
.52827 .48138 m
.52827 .48138 L
s
.52827 .48138 m
.52827 .48138 L
s
.52828 .48139 m
.52827 .48139 L
s
.52827 .48138 m
.52828 .48139 L
s
.52827 .48139 m
.52827 .48138 L
s
.52827 .48138 m
.52827 .48138 L
s
.52827 .48138 m
.52827 .48139 L
s
1 .029 0 r
.36842 .70649 m
.37005 .70579 L
s
1 .01 0 r
.57043 .75633 m
.57052 .75646 L
s
.57034 .75639 m
.57043 .75633 L
s
.57043 .75633 m
.57052 .75636 L
s
.57052 .75646 m
.57043 .75652 L
s
.57052 .75636 m
.57052 .75646 L
s
1 .002 0 r
.82405 .68139 m
.82409 .68133 L
s
1 .001 0 r
.32659 .43118 m
.32662 .43115 L
s
.32661 .43115 m
.32662 .43116 L
s
.3266 .43115 m
.32661 .43115 L
s
.32661 .43115 m
.32662 .43115 L
s
.32662 .43116 m
.32661 .43116 L
s
.32662 .43115 m
.32662 .43116 L
s
.32661 .43116 m
.3266 .43115 L
s
.3266 .43115 m
.32662 .43115 L
s
.32662 .43115 m
.32661 .43116 L
s
1 .002 0 r
.82408 .68132 m
.8241 .68134 L
s
.82407 .68134 m
.82408 .68132 L
s
.82408 .68132 m
.82409 .68133 L
s
.8241 .68134 m
.82408 .68135 L
s
.82409 .68133 m
.8241 .68134 L
s
.82408 .68135 m
.82407 .68134 L
s
.82407 .68134 m
.82409 .68133 L
s
.82409 .68133 m
.82408 .68135 L
s
1 .01 0 r
.57043 .75652 m
.57034 .75639 L
s
.57034 .75639 m
.57052 .75636 L
s
1 .041 0 r
.2766 .55623 m
.27633 .55636 L
s
.27637 .55566 m
.2766 .55623 L
s
.27685 .55583 m
.2766 .55623 L
s
1 .01 0 r
.57052 .75636 m
.57043 .75652 L
s
1 .041 0 r
.27611 .5558 m
.27637 .55566 L
s
.27637 .55566 m
.27685 .55583 L
s
1 0 0 r
.78223 .40607 m
.78223 .40607 L
s
.78223 .40607 m
.78223 .40607 L
s
.78223 .40607 m
.78223 .40607 L
s
.78223 .40607 m
.78223 .40607 L
s
.78223 .40607 m
.78223 .40607 L
s
.78223 .40607 m
.78223 .40607 L
s
.78223 .40607 m
.78223 .40607 L
s
.78223 .40607 m
.78223 .40607 L
s
.78223 .40607 m
.78223 .40607 L
s
1 .003 0 r
.62238 .63118 m
.62249 .63105 L
s
.62247 .63105 m
.6225 .63109 L
s
.62243 .63107 m
.62247 .63105 L
s
.62247 .63105 m
.62249 .63105 L
s
.6225 .63109 m
.62247 .63111 L
s
.62249 .63105 m
.6225 .63109 L
s
.62247 .63111 m
.62243 .63107 L
s
.62243 .63107 m
.62249 .63105 L
s
.62249 .63105 m
.62247 .63111 L
s
1 .011 0 r
.42068 .58096 m
.42113 .58057 L
s
1 .029 0 r
.36992 .70606 m
.36972 .70619 L
s
.36974 .70567 m
.36992 .70606 L
s
.37005 .70579 m
.36992 .70606 L
s
.36953 .7058 m
.36974 .70567 L
s
.36974 .70567 m
.37005 .70579 L
s
1 0 0 r
.8764 .55585 m
.87641 .55584 L
s
.87641 .55584 m
.87641 .55584 L
s
.87641 .55584 m
.87641 .55584 L
s
.87641 .55584 m
.87641 .55584 L
s
.87641 .55584 m
.87641 .55585 L
s
.87641 .55584 m
.87641 .55584 L
s
.87641 .55585 m
.87641 .55584 L
s
.87641 .55584 m
.87641 .55584 L
s
.87641 .55584 m
.87641 .55585 L
s
1 .041 0 r
.27685 .55583 m
.27633 .55636 L
s
.27611 .5558 m
.27685 .55583 L
s
.27633 .55636 m
.27611 .5558 L
s
1 0 0 r
.6747 .50562 m
.67471 .50561 L
s
1 .011 0 r
.42105 .58055 m
.42114 .58069 L
s
.42094 .58061 m
.42105 .58055 L
s
.42105 .58055 m
.42113 .58057 L
s
1 0 0 r
.67471 .50561 m
.67471 .50561 L
s
.6747 .50561 m
.67471 .50561 L
s
.67471 .50561 m
.67471 .50561 L
s
.67471 .50561 m
.67471 .50562 L
s
.67471 .50561 m
.67471 .50561 L
s
.67471 .50562 m
.6747 .50561 L
s
.6747 .50561 m
.67471 .50561 L
s
.67471 .50561 m
.67471 .50562 L
s
1 .011 0 r
.42114 .58069 m
.42104 .58075 L
s
.42113 .58057 m
.42114 .58069 L
s
1 .029 0 r
.36972 .70619 m
.36953 .7058 L
s
.37005 .70579 m
.36972 .70619 L
s
.36953 .7058 m
.37005 .70579 L
s
1 .013 0 r
.51481 .73079 m
.51538 .73039 L
s
1 .011 0 r
.42104 .58075 m
.42094 .58061 L
s
.42094 .58061 m
.42113 .58057 L
s
.42113 .58057 m
.42104 .58075 L
s
1 .001 0 r
.97061 .70568 m
.97064 .70565 L
s
1 0 0 r
.47297 .45539 m
.47297 .45537 L
s
.47297 .45537 m
.47298 .45538 L
s
.47297 .45537 m
.47297 .45537 L
s
.47297 .45537 m
.47297 .45537 L
s
.47298 .45538 m
.47297 .45538 L
s
.47297 .45537 m
.47298 .45538 L
s
.47297 .45538 m
.47297 .45537 L
s
.47297 .45537 m
.47297 .45537 L
s
.47297 .45537 m
.47297 .45538 L
s
1 .001 0 r
.97063 .70565 m
.97064 .70566 L
s
.97062 .70565 m
.97063 .70565 L
s
.97063 .70565 m
.97064 .70565 L
s
.97064 .70566 m
.97063 .70566 L
s
.97064 .70565 m
.97064 .70566 L
s
.97063 .70566 m
.97062 .70565 L
s
.97062 .70565 m
.97064 .70565 L
s
.97064 .70565 m
.97063 .70566 L
s
1 .039 0 r
.31305 .68057 m
.31545 .6798 L
s
1 .002 0 r
.76888 .65546 m
.76893 .65539 L
s
1 0 0 r
.27119 .40514 m
.2712 .40514 L
s
.2712 .40514 m
.2712 .40514 L
s
.2712 .40514 m
.2712 .40514 L
s
.2712 .40514 m
.2712 .40514 L
s
.2712 .40514 m
.2712 .40514 L
s
.2712 .40514 m
.2712 .40514 L
s
.2712 .40514 m
.2712 .40514 L
s
.2712 .40514 m
.2712 .40514 L
s
.2712 .40514 m
.2712 .40514 L
s
1 .013 0 r
.51527 .73036 m
.51537 .73052 L
s
.51516 .73043 m
.51527 .73036 L
s
.51527 .73036 m
.51538 .73039 L
s
.51537 .73052 m
.51526 .73059 L
s
.51538 .73039 m
.51537 .73052 L
s
1 .002 0 r
.76892 .65539 m
.76894 .65541 L
s
.76891 .6554 m
.76892 .65539 L
s
.76892 .65539 m
.76893 .65539 L
s
.76894 .65541 m
.76892 .65542 L
s
.76893 .65539 m
.76894 .65541 L
s
.76892 .65542 m
.76891 .6554 L
s
.76891 .6554 m
.76893 .65539 L
s
.76893 .65539 m
.76892 .65542 L
s
1 .013 0 r
.51526 .73059 m
.51516 .73043 L
s
.51516 .73043 m
.51538 .73039 L
s
.51538 .73039 m
.51526 .73059 L
s
1 .004 0 r
.56712 .60523 m
.56725 .60508 L
s
.56722 .60507 m
.56726 .60512 L
s
.56718 .6051 m
.56722 .60507 L
s
.56722 .60507 m
.56725 .60508 L
s
.56726 .60512 m
.56722 .60514 L
s
.56725 .60508 m
.56726 .60512 L
s
.56722 .60514 m
.56718 .6051 L
s
.56718 .6051 m
.56725 .60508 L
s
.56725 .60508 m
.56722 .60514 L
s
1 .017 0 r
.36532 .55499 m
.36604 .55444 L
s
1 .039 0 r
.3152 .68015 m
.31495 .6803 L
s
.31499 .67961 m
.3152 .68015 L
s
.31545 .6798 m
.3152 .68015 L
s
.31475 .67976 m
.31499 .67961 L
s
.31499 .67961 m
.31545 .6798 L
s
1 0 0 r
.82125 .52986 m
.82126 .52985 L
s
.82126 .52985 m
.82126 .52986 L
s
.82125 .52986 m
.82126 .52985 L
s
.82126 .52985 m
.82126 .52985 L
s
.82126 .52986 m
.82126 .52986 L
s
.82126 .52985 m
.82126 .52986 L
s
.82126 .52986 m
.82125 .52986 L
s
.82125 .52986 m
.82126 .52985 L
s
.82126 .52985 m
.82126 .52986 L
s
1 .006 0 r
.66131 .75512 m
.66154 .75491 L
s
1 0 0 r
.61945 .47961 m
.61946 .4796 L
s
.61946 .4796 m
.61946 .4796 L
s
.61945 .4796 m
.61946 .4796 L
s
.61946 .4796 m
.61946 .4796 L
s
.61946 .4796 m
.61946 .4796 L
s
.61946 .4796 m
.61946 .4796 L
s
.61946 .4796 m
.61945 .4796 L
s
.61945 .4796 m
.61946 .4796 L
s
.61946 .4796 m
.61946 .4796 L
s
1 .006 0 r
.66149 .75489 m
.66155 .75497 L
s
.66144 .75493 m
.66149 .75489 L
s
.66149 .75489 m
.66154 .75491 L
s
.66155 .75497 m
.6615 .75501 L
s
.66154 .75491 m
.66155 .75497 L
s
1 .017 0 r
.45949 .70488 m
.46027 .70437 L
s
.3659 .55441 m
.36603 .55462 L
s
.36576 .55449 m
.3659 .55441 L
s
.3659 .55441 m
.36604 .55444 L
s
1 .006 0 r
.6615 .75501 m
.66144 .75493 L
s
.66144 .75493 m
.66154 .75491 L
s
1 .017 0 r
.36603 .55462 m
.36589 .55469 L
s
.36604 .55444 m
.36603 .55462 L
s
1 .006 0 r
.66154 .75491 m
.6615 .75501 L
s
1 .039 0 r
.31545 .6798 m
.31495 .6803 L
s
.31475 .67976 m
.31545 .6798 L
s
.31495 .6803 m
.31475 .67976 L
s
1 .001 0 r
.91549 .67976 m
.91552 .67972 L
s
1 0 0 r
.41762 .42935 m
.41762 .42934 L
s
.41762 .42934 m
.41762 .42934 L
s
.41762 .42934 m
.41762 .42934 L
s
.41762 .42934 m
.41762 .42934 L
s
.41762 .42934 m
.41762 .42934 L
s
.41762 .42934 m
.41762 .42934 L
s
.41762 .42934 m
.41762 .42934 L
s
.41762 .42934 m
.41762 .42934 L
s
.41762 .42934 m
.41762 .42934 L
s
1 .001 0 r
.91552 .67972 m
.91553 .67973 L
s
.91551 .67973 m
.91552 .67972 L
s
.91552 .67972 m
.91552 .67972 L
s
.91553 .67973 m
.91552 .67974 L
s
.91552 .67972 m
.91553 .67973 L
s
.91552 .67974 m
.91551 .67973 L
s
.91551 .67973 m
.91552 .67972 L
s
.91552 .67972 m
.91552 .67974 L
s
1 .017 0 r
.36589 .55469 m
.36576 .55449 L
s
.36576 .55449 m
.36604 .55444 L
s
.36604 .55444 m
.36589 .55469 L
s
1 0 0 r
.87365 .40421 m
.87365 .40421 L
s
.87365 .40421 m
.87365 .40421 L
s
.87365 .40421 m
.87365 .40421 L
s
.87365 .40421 m
.87365 .40421 L
s
.87365 .40421 m
.87365 .40421 L
s
.87365 .40421 m
.87365 .40421 L
s
.87365 .40421 m
.87365 .40421 L
s
.87365 .40421 m
.87365 .40421 L
s
.87365 .40421 m
.87365 .40421 L
s
1 .002 0 r
.71367 .62951 m
.71372 .62944 L
s
.71371 .62944 m
.71373 .62946 L
s
.71369 .62945 m
.71371 .62944 L
s
.71371 .62944 m
.71372 .62944 L
s
.71373 .62946 m
.71371 .62947 L
s
.71372 .62944 m
.71373 .62946 L
s
.71371 .62947 m
.71369 .62945 L
s
.71369 .62945 m
.71372 .62944 L
s
.71372 .62944 m
.71371 .62947 L
s
1 .017 0 r
.46011 .70433 m
.46025 .70454 L
s
.45998 .70441 m
.46011 .70433 L
s
.46011 .70433 m
.46027 .70437 L
s
.46025 .70454 m
.46011 .70463 L
s
.46027 .70437 m
.46025 .70454 L
s
1 .005 0 r
.51181 .57925 m
.51196 .57907 L
s
1 .017 0 r
.46011 .70463 m
.45998 .70441 L
s
.45998 .70441 m
.46027 .70437 L
s
.46027 .70437 m
.46011 .70463 L
s
1 .005 0 r
.51193 .57906 m
.51198 .57912 L
s
.51188 .57909 m
.51193 .57906 L
s
.51193 .57906 m
.51196 .57907 L
s
.51198 .57912 m
.51193 .57915 L
s
.51196 .57907 m
.51198 .57912 L
s
.51193 .57915 m
.51188 .57909 L
s
.51188 .57909 m
.51196 .57907 L
s
.51196 .57907 m
.51193 .57915 L
s
1 .026 0 r
.30991 .52899 m
.3112 .52822 L
s
1 0 0 r
.76605 .50385 m
.76605 .50384 L
s
.76605 .50384 m
.76606 .50384 L
s
.76605 .50384 m
.76605 .50384 L
s
.76605 .50384 m
.76605 .50384 L
s
.76606 .50384 m
.76605 .50385 L
s
.76605 .50384 m
.76606 .50384 L
s
.76605 .50385 m
.76605 .50384 L
s
.76605 .50384 m
.76605 .50384 L
s
.76605 .50384 m
.76605 .50385 L
s
1 .008 0 r
.60603 .72921 m
.60632 .72895 L
s
1 0 0 r
.56415 .45357 m
.56415 .45356 L
s
.56415 .45356 m
.56416 .45357 L
s
.56415 .45357 m
.56415 .45356 L
s
.56415 .45356 m
.56415 .45356 L
s
.56416 .45357 m
.56415 .45357 L
s
.56415 .45356 m
.56416 .45357 L
s
.56415 .45357 m
.56415 .45357 L
s
.56415 .45357 m
.56415 .45356 L
s
.56415 .45356 m
.56415 .45357 L
s
1 .023 0 r
.40411 .67895 m
.40525 .6783 L
s
1 .008 0 r
.60626 .72894 m
.60633 .72902 L
s
.60619 .72898 m
.60626 .72894 L
s
.60626 .72894 m
.60632 .72895 L
s
.60633 .72902 m
.60626 .72907 L
s
.60632 .72895 m
.60633 .72902 L
s
.60626 .72907 m
.60619 .72898 L
s
.60619 .72898 m
.60632 .72895 L
s
.60632 .72895 m
.60626 .72907 L
s
1 .001 0 r
.86033 .65381 m
.86035 .65377 L
s
1 0 0 r
.36222 .40328 m
.36222 .40328 L
s
.36222 .40328 m
.36222 .40328 L
s
.36222 .40328 m
.36222 .40328 L
s
.36222 .40328 m
.36222 .40328 L
s
.36222 .40328 m
.36222 .40328 L
s
.36222 .40328 m
.36222 .40328 L
s
.36222 .40328 m
.36222 .40328 L
s
.36222 .40328 m
.36222 .40328 L
s
.36222 .40328 m
.36222 .40328 L
s
1 .001 0 r
.86035 .65377 m
.86036 .65378 L
s
.86034 .65378 m
.86035 .65377 L
s
.86035 .65377 m
.86035 .65377 L
s
.86036 .65378 m
.86035 .65379 L
s
.86035 .65377 m
.86036 .65378 L
s
.86035 .65379 m
.86034 .65378 L
s
.86034 .65378 m
.86035 .65377 L
s
.86035 .65377 m
.86035 .65379 L
s
1 .026 0 r
.31095 .52815 m
.31114 .52848 L
s
.31074 .52826 m
.31095 .52815 L
s
.31095 .52815 m
.3112 .52822 L
s
.31114 .52848 m
.31093 .52859 L
s
.3112 .52822 m
.31114 .52848 L
s
1 .002 0 r
.6584 .60354 m
.65846 .60346 L
s
.65845 .60345 m
.65847 .60348 L
s
.65843 .60347 m
.65845 .60345 L
s
.65845 .60345 m
.65846 .60346 L
s
.65847 .60348 m
.65845 .60349 L
s
.65846 .60346 m
.65847 .60348 L
s
.65845 .60349 m
.65843 .60347 L
s
.65843 .60347 m
.65846 .60346 L
s
.65846 .60346 m
.65845 .60349 L
s
1 .026 0 r
.31093 .52859 m
.31074 .52826 L
s
.31074 .52826 m
.3112 .52822 L
s
.3112 .52822 m
.31093 .52859 L
s
1 .006 0 r
.45644 .55325 m
.45664 .55302 L
s
1 .023 0 r
.40502 .67823 m
.40519 .67852 L
s
.40484 .67834 m
.40502 .67823 L
s
.40502 .67823 m
.40525 .6783 L
s
.40519 .67852 m
.40501 .67863 L
s
.40525 .6783 m
.40519 .67852 L
s
1 0 0 r
.91276 .52811 m
.91276 .5281 L
s
.91276 .5281 m
.91276 .5281 L
s
.91276 .5281 m
.91276 .5281 L
s
.91276 .5281 m
.91276 .5281 L
s
.91276 .5281 m
.91276 .5281 L
s
.91276 .5281 m
.91276 .5281 L
s
.91276 .5281 m
.91276 .5281 L
s
.91276 .5281 m
.91276 .5281 L
s
.91276 .5281 m
.91276 .5281 L
s
1 .006 0 r
.45661 .55301 m
.45666 .55308 L
s
.45655 .55305 m
.45661 .55301 L
s
.45661 .55301 m
.45664 .55302 L
s
1 .004 0 r
.75268 .75355 m
.75282 .75342 L
s
1 .006 0 r
.45666 .55308 m
.4566 .55312 L
s
.45664 .55302 m
.45666 .55308 L
s
1 .044 0 r
.25445 .50296 m
.25708 .50198 L
s
1 .006 0 r
.4566 .55312 m
.45655 .55305 L
s
.45655 .55305 m
.45664 .55302 L
s
1 .023 0 r
.40501 .67863 m
.40484 .67834 L
s
.40484 .67834 m
.40525 .6783 L
s
.40525 .6783 m
.40501 .67863 L
s
1 .006 0 r
.45664 .55302 m
.4566 .55312 L
s
1 0 0 r
.7108 .47781 m
.7108 .47781 L
s
.7108 .47781 m
.7108 .47781 L
s
.7108 .47781 m
.7108 .47781 L
s
.7108 .47781 m
.7108 .47781 L
s
.7108 .47781 m
.7108 .47781 L
s
.7108 .47781 m
.7108 .47781 L
s
.7108 .47781 m
.7108 .47781 L
s
.7108 .47781 m
.7108 .47781 L
s
.7108 .47781 m
.7108 .47781 L
s
1 .004 0 r
.75279 .75341 m
.75283 .75345 L
s
.75275 .75343 m
.75279 .75341 L
s
.75279 .75341 m
.75282 .75342 L
s
.75283 .75345 m
.75279 .75348 L
s
.75282 .75342 m
.75283 .75345 L
s
.75279 .75348 m
.75275 .75343 L
s
.75275 .75343 m
.75282 .75342 L
s
.75282 .75342 m
.75279 .75348 L
s
1 .01 0 r
.5507 .70327 m
.55107 .70296 L
s
1 0 0 r
.5088 .42751 m
.5088 .4275 L
s
.5088 .4275 m
.5088 .42751 L
s
.5088 .4275 m
.5088 .4275 L
s
.5088 .4275 m
.5088 .4275 L
s
.5088 .42751 m
.5088 .42751 L
s
.5088 .4275 m
.5088 .42751 L
s
.5088 .42751 m
.5088 .4275 L
s
.5088 .4275 m
.5088 .4275 L
s
.5088 .4275 m
.5088 .42751 L
s
1 .032 0 r
.34868 .65299 m
.35042 .65217 L
s
1 .01 0 r
.551 .70294 m
.55108 .70305 L
s
.55091 .70299 m
.551 .70294 L
s
.551 .70294 m
.55107 .70296 L
s
.55108 .70305 m
.551 .7031 L
s
.55107 .70296 m
.55108 .70305 L
s
1 .001 0 r
.80511 .62784 m
.80514 .62779 L
s
.80513 .62779 m
.80514 .62781 L
s
.80512 .6278 m
.80513 .62779 L
s
.80513 .62779 m
.80514 .62779 L
s
.80514 .62781 m
.80513 .62781 L
s
.80514 .62779 m
.80514 .62781 L
s
.80513 .62781 m
.80512 .6278 L
s
.80512 .6278 m
.80514 .62779 L
s
.80514 .62779 m
.80513 .62781 L
s
1 .01 0 r
.551 .7031 m
.55091 .70299 L
s
.55091 .70299 m
.55107 .70296 L
s
.55107 .70296 m
.551 .7031 L
s
1 .044 0 r
.25682 .50241 m
.25653 .50254 L
s
.25658 .5018 m
.25682 .50241 L
s
.25708 .50198 m
.25682 .50241 L
s
.25628 .50194 m
.25658 .5018 L
s
.25658 .5018 m
.25708 .50198 L
s
1 .002 0 r
.60308 .57754 m
.60315 .57745 L
s
.60313 .57745 m
.60316 .57747 L
s
.60311 .57746 m
.60313 .57745 L
s
.60313 .57745 m
.60315 .57745 L
s
.60316 .57747 m
.60313 .57749 L
s
.60315 .57745 m
.60316 .57747 L
s
.60313 .57749 m
.60311 .57746 L
s
.60311 .57746 m
.60315 .57745 L
s
.60315 .57745 m
.60313 .57749 L
s
1 .008 0 r
.40103 .52723 m
.40131 .52692 L
s
1 0 0 r
.85755 .50207 m
.85756 .50207 L
s
.85756 .50207 m
.85756 .50207 L
s
.85755 .50207 m
.85756 .50207 L
s
.85756 .50207 m
.85756 .50207 L
s
.85756 .50207 m
.85756 .50207 L
s
.85756 .50207 m
.85756 .50207 L
s
.85756 .50207 m
.85755 .50207 L
s
.85755 .50207 m
.85756 .50207 L
s
.85756 .50207 m
.85756 .50207 L
s
1 .032 0 r
.3503 .65248 m
.35006 .65262 L
s
.35008 .65206 m
.3503 .65248 L
s
.35042 .65217 m
.3503 .65248 L
s
.34985 .65219 m
.35008 .65206 L
s
.35008 .65206 m
.35042 .65217 L
s
1 .005 0 r
.6974 .72762 m
.69756 .72746 L
s
1 .044 0 r
.25708 .50198 m
.25653 .50254 L
s
.25628 .50194 m
.25708 .50198 L
s
.25653 .50254 m
.25628 .50194 L
s
1 .008 0 r
.40126 .52691 m
.40133 .52701 L
s
.40118 .52696 m
.40126 .52691 L
s
.40126 .52691 m
.40131 .52692 L
s
.40133 .52701 m
.40125 .52705 L
s
.40131 .52692 m
.40133 .52701 L
s
1 0 0 r
.65549 .45175 m
.65549 .45175 L
s
.65549 .45175 m
.65549 .45175 L
s
.65549 .45175 m
.65549 .45175 L
s
.65549 .45175 m
.65549 .45175 L
s
.65549 .45175 m
.65549 .45175 L
s
.65549 .45175 m
.65549 .45175 L
s
.65549 .45175 m
.65549 .45175 L
s
.65549 .45175 m
.65549 .45175 L
s
.65549 .45175 m
.65549 .45175 L
s
1 .008 0 r
.40125 .52705 m
.40118 .52696 L
s
.40118 .52696 m
.40131 .52692 L
s
.40131 .52692 m
.40125 .52705 L
s
1 .005 0 r
.69752 .72745 m
.69757 .7275 L
s
.69748 .72748 m
.69752 .72745 L
s
.69752 .72745 m
.69756 .72746 L
s
.69757 .7275 m
.69753 .72753 L
s
.69756 .72746 m
.69757 .7275 L
s
.69753 .72753 m
.69748 .72748 L
s
.69748 .72748 m
.69756 .72746 L
s
.69756 .72746 m
.69753 .72753 L
s
1 .012 0 r
.49532 .67731 m
.49582 .67691 L
s
1 .032 0 r
.35006 .65262 m
.34985 .65219 L
s
.35042 .65217 m
.35006 .65262 L
s
.34985 .65219 m
.35042 .65217 L
s
1 .001 0 r
.95192 .65216 m
.95194 .65213 L
s
1 0 0 r
.4534 .40142 m
.4534 .40142 L
s
.4534 .40142 m
.4534 .40142 L
s
.4534 .40142 m
.4534 .40142 L
s
.4534 .40142 m
.4534 .40142 L
s
.4534 .40142 m
.4534 .40142 L
s
.4534 .40142 m
.4534 .40142 L
s
.4534 .40142 m
.4534 .40142 L
s
.4534 .40142 m
.4534 .40142 L
s
.4534 .40142 m
.4534 .40142 L
s
1 .001 0 r
.95194 .65213 m
.95194 .65214 L
s
.95193 .65214 m
.95194 .65213 L
s
.95194 .65213 m
.95194 .65213 L
s
.95194 .65214 m
.95194 .65214 L
s
.95194 .65213 m
.95194 .65214 L
s
.95194 .65214 m
.95193 .65214 L
s
.95193 .65214 m
.95194 .65213 L
s
.95194 .65213 m
.95194 .65214 L
s
1 .046 0 r
.2932 .627 m
.29597 .62607 L
s
1 .001 0 r
.74984 .60184 m
.74987 .6018 L
s
1 .012 0 r
.49572 .67688 m
.49583 .67703 L
s
.49561 .67695 m
.49572 .67688 L
s
.49572 .67688 m
.49582 .67691 L
s
1 .001 0 r
.74986 .6018 m
.74987 .60181 L
s
.74985 .6018 m
.74986 .6018 L
s
.74986 .6018 m
.74987 .6018 L
s
.74987 .60181 m
.74986 .60181 L
s
.74987 .6018 m
.74987 .60181 L
s
1 .012 0 r
.49583 .67703 m
.49572 .6771 L
s
.49582 .67691 m
.49583 .67703 L
s
1 .001 0 r
.74986 .60181 m
.74985 .6018 L
s
.74985 .6018 m
.74987 .6018 L
s
.74987 .6018 m
.74986 .60181 L
s
1 .012 0 r
.49572 .6771 m
.49561 .67695 L
s
.49561 .67695 m
.49582 .67691 L
s
.49582 .67691 m
.49572 .6771 L
s
1 .003 0 r
.54772 .55152 m
.54778 .55141 L
s
.54777 .55141 m
.5478 .55144 L
s
.54775 .55143 m
.54777 .55141 L
s
.54777 .55141 m
.54778 .55141 L
s
.5478 .55144 m
.54777 .55146 L
s
.54778 .55141 m
.5478 .55144 L
s
.54777 .55146 m
.54775 .55143 L
s
.54775 .55143 m
.54778 .55141 L
s
.54778 .55141 m
.54777 .55146 L
s
.84421 .75198 m
.84429 .75189 L
s
1 .012 0 r
.34556 .50118 m
.34602 .50075 L
s
1 .003 0 r
.84428 .75189 m
.8443 .75192 L
s
.84425 .75191 m
.84428 .75189 L
s
.84428 .75189 m
.84429 .75189 L
s
.8443 .75192 m
.84428 .75193 L
s
.84429 .75189 m
.8443 .75192 L
s
.84428 .75193 m
.84425 .75191 L
s
.84425 .75191 m
.84429 .75189 L
s
.84429 .75189 m
.84428 .75193 L
s
1 0 0 r
.8023 .47601 m
.8023 .47601 L
s
.8023 .47601 m
.8023 .47601 L
s
.8023 .47601 m
.8023 .47601 L
s
.8023 .47601 m
.8023 .47601 L
s
.8023 .47601 m
.8023 .47601 L
s
.8023 .47601 m
.8023 .47601 L
s
.8023 .47601 m
.8023 .47601 L
s
.8023 .47601 m
.8023 .47601 L
s
.8023 .47601 m
.8023 .47601 L
s
1 .046 0 r
.29568 .62649 m
.29539 .62665 L
s
.29544 .62586 m
.29568 .62649 L
s
.29597 .62607 m
.29568 .62649 L
s
.29515 .62603 m
.29544 .62586 L
s
.29544 .62586 m
.29597 .62607 L
s
1 .005 0 r
.64207 .70166 m
.64225 .70147 L
s
1 0 0 r
.60014 .42566 m
.60014 .42566 L
s
.60014 .42566 m
.60014 .42566 L
s
.60014 .42566 m
.60014 .42566 L
s
.60014 .42566 m
.60014 .42566 L
s
.60014 .42566 m
.60014 .42566 L
s
.60014 .42566 m
.60014 .42566 L
s
.60014 .42566 m
.60014 .42566 L
s
.60014 .42566 m
.60014 .42566 L
s
.60014 .42566 m
.60014 .42566 L
s
1 .012 0 r
.34593 .50073 m
.34604 .50088 L
s
.34582 .50079 m
.34593 .50073 L
s
.34593 .50073 m
.34602 .50075 L
s
.34604 .50088 m
.34592 .50094 L
s
.34602 .50075 m
.34604 .50088 L
s
1 .005 0 r
.64222 .70146 m
.64227 .70152 L
s
.64217 .70149 m
.64222 .70146 L
s
.64222 .70146 m
.64225 .70147 L
s
.64227 .70152 m
.64222 .70156 L
s
.64225 .70147 m
.64227 .70152 L
s
1 .017 0 r
.43989 .65133 m
.4406 .6508 L
s
1 .005 0 r
.64222 .70156 m
.64217 .70149 L
s
.64217 .70149 m
.64225 .70147 L
s
.64225 .70147 m
.64222 .70156 L
s
1 .012 0 r
.34592 .50094 m
.34582 .50079 L
s
.34582 .50079 m
.34602 .50075 L
s
.34602 .50075 m
.34592 .50094 L
s
1 .001 0 r
.8967 .62616 m
.89672 .62614 L
s
.89671 .62614 m
.89672 .62614 L
s
.89671 .62614 m
.89671 .62614 L
s
.89671 .62614 m
.89672 .62614 L
s
.89672 .62614 m
.89672 .62615 L
s
.89672 .62614 m
.89672 .62614 L
s
.89672 .62615 m
.89671 .62614 L
s
.89671 .62614 m
.89672 .62614 L
s
.89672 .62614 m
.89672 .62615 L
s
1 .046 0 r
.29597 .62607 m
.29539 .62665 L
s
.29515 .62603 m
.29597 .62607 L
s
.29539 .62665 m
.29515 .62603 L
s
1 .001 0 r
.69452 .57582 m
.69454 .57577 L
s
.69454 .57577 m
.69455 .57578 L
s
.69453 .57578 m
.69454 .57577 L
s
.69454 .57577 m
.69454 .57577 L
s
.69455 .57578 m
.69454 .57579 L
s
.69454 .57577 m
.69455 .57578 L
s
.69454 .57579 m
.69453 .57578 L
s
.69453 .57578 m
.69454 .57577 L
s
.69454 .57577 m
.69454 .57579 L
s
1 .017 0 r
.44046 .65076 m
.4406 .65097 L
s
.44032 .65085 m
.44046 .65076 L
s
.44046 .65076 m
.4406 .6508 L
s
.4406 .65097 m
.44046 .65105 L
s
.4406 .6508 m
.4406 .65097 L
s
1 .003 0 r
.4923 .52547 m
.49237 .52535 L
s
1 .017 0 r
.44046 .65105 m
.44032 .65085 L
s
.44032 .65085 m
.4406 .6508 L
s
.4406 .6508 m
.44046 .65105 L
s
1 .039 0 r
.332 .7512 m
.33438 .75047 L
s
1 .003 0 r
.49236 .52535 m
.49239 .52538 L
s
.49233 .52537 m
.49236 .52535 L
s
.49236 .52535 m
.49237 .52535 L
s
.49239 .52538 m
.49236 .5254 L
s
.49237 .52535 m
.49239 .52538 L
s
.49236 .5254 m
.49233 .52537 L
s
.49233 .52537 m
.49237 .52535 L
s
.49237 .52535 m
.49236 .5254 L
s
.78893 .72603 m
.78902 .72593 L
s
1 .02 0 r
.29004 .47511 m
.29093 .47446 L
s
1 .003 0 r
.789 .72592 m
.78902 .72595 L
s
.78897 .72594 m
.789 .72592 L
s
.789 .72592 m
.78902 .72593 L
s
.78902 .72595 m
.789 .72597 L
s
.78902 .72593 m
.78902 .72595 L
s
.789 .72597 m
.78897 .72594 L
s
.78897 .72594 m
.78902 .72593 L
s
1 0 0 r
.74699 .44993 m
.74699 .44992 L
s
.74699 .44992 m
.74699 .44992 L
s
.74699 .44992 m
.74699 .44992 L
s
.74699 .44992 m
.74699 .44992 L
s
.74699 .44992 m
.74699 .44992 L
s
.74699 .44992 m
.74699 .44992 L
s
.74699 .44992 m
.74699 .44992 L
s
.74699 .44992 m
.74699 .44992 L
s
.74699 .44992 m
.74699 .44992 L
s
1 .003 0 r
.78902 .72593 m
.789 .72597 L
s
1 .007 0 r
.58668 .67568 m
.58691 .67545 L
s
1 0 0 r
.54473 .39955 m
.54473 .39955 L
s
.54473 .39955 m
.54473 .39955 L
s
.54473 .39955 m
.54473 .39955 L
s
.54473 .39955 m
.54473 .39955 L
s
.54473 .39955 m
.54473 .39955 L
s
.54473 .39955 m
.54473 .39955 L
s
.54473 .39955 m
.54473 .39955 L
s
.54473 .39955 m
.54473 .39955 L
s
.54473 .39955 m
.54473 .39955 L
s
1 .007 0 r
.58687 .67543 m
.58693 .67551 L
s
.58681 .67547 m
.58687 .67543 L
s
.58687 .67543 m
.58691 .67545 L
s
1 .023 0 r
.3844 .62532 m
.3855 .62462 L
s
1 .039 0 r
.33412 .7508 m
.33389 .75096 L
s
.33392 .75027 m
.33412 .7508 L
s
.33438 .75047 m
.33412 .7508 L
s
1 .007 0 r
.58693 .67551 m
.58687 .67555 L
s
.58691 .67545 m
.58693 .67551 L
s
1 .039 0 r
.33368 .75043 m
.33392 .75027 L
s
.33392 .75027 m
.33438 .75047 L
s
1 .007 0 r
.58687 .67555 m
.58681 .67547 L
s
.58681 .67547 m
.58691 .67545 L
s
.58691 .67545 m
.58687 .67555 L
s
1 .02 0 r
.29076 .47442 m
.29092 .47467 L
s
.29059 .4745 m
.29076 .47442 L
s
.29076 .47442 m
.29093 .47446 L
s
.29092 .47467 m
.29074 .47475 L
s
.29093 .47446 m
.29092 .47467 L
s
1 .001 0 r
.84143 .60014 m
.84144 .60012 L
s
.84144 .60012 m
.84145 .60012 L
s
.84143 .60012 m
.84144 .60012 L
s
.84144 .60012 m
.84144 .60012 L
s
.84145 .60012 m
.84144 .60013 L
s
.84144 .60012 m
.84145 .60012 L
s
.84144 .60013 m
.84143 .60012 L
s
.84143 .60012 m
.84144 .60012 L
s
.84144 .60012 m
.84144 .60013 L
s
1 .02 0 r
.29074 .47475 m
.29059 .4745 L
s
.29059 .4745 m
.29093 .47446 L
s
.29093 .47446 m
.29074 .47475 L
s
1 .001 0 r
.63914 .54978 m
.63917 .54973 L
s
.63917 .54973 m
.63918 .54974 L
s
.63915 .54973 m
.63917 .54973 L
s
.63917 .54973 m
.63917 .54973 L
s
.63918 .54974 m
.63917 .54975 L
s
.63917 .54973 m
.63918 .54974 L
s
.63917 .54975 m
.63915 .54973 L
s
.63915 .54973 m
.63917 .54973 L
s
.63917 .54973 m
.63917 .54975 L
s
1 .039 0 r
.33438 .75047 m
.33389 .75096 L
s
.33368 .75043 m
.33438 .75047 L
s
.33389 .75096 m
.33368 .75043 L
s
1 .002 0 r
.9359 .75041 m
.93595 .75035 L
s
1 .003 0 r
.43683 .4994 m
.43692 .49926 L
s
1 .002 0 r
.93594 .75035 m
.93595 .75037 L
s
.93592 .75036 m
.93594 .75035 L
s
.93594 .75035 m
.93595 .75035 L
s
.93595 .75037 m
.93594 .75038 L
s
.93595 .75035 m
.93595 .75037 L
s
1 .023 0 r
.38529 .62456 m
.38547 .62485 L
s
.38509 .62467 m
.38529 .62456 L
s
.38529 .62456 m
.3855 .62462 L
s
1 .002 0 r
.93594 .75038 m
.93592 .75036 L
s
.93592 .75036 m
.93595 .75035 L
s
.93595 .75035 m
.93594 .75038 L
s
1 .023 0 r
.38547 .62485 m
.38527 .62496 L
s
.3855 .62462 m
.38547 .62485 L
s
1 0 0 r
.89395 .47421 m
.89395 .4742 L
s
.89395 .4742 m
.89395 .47421 L
s
.89395 .47421 m
.89395 .4742 L
s
.89395 .4742 m
.89395 .4742 L
s
.89395 .47421 m
.89395 .47421 L
s
.89395 .4742 m
.89395 .47421 L
s
.89395 .47421 m
.89395 .47421 L
s
.89395 .47421 m
.89395 .4742 L
s
.89395 .4742 m
.89395 .47421 L
s
1 .003 0 r
.4369 .49926 m
.43693 .4993 L
s
.43686 .49928 m
.4369 .49926 L
s
.4369 .49926 m
.43692 .49926 L
s
.43693 .4993 m
.4369 .49932 L
s
.43692 .49926 m
.43693 .4993 L
s
.4369 .49932 m
.43686 .49928 L
s
.43686 .49928 m
.43692 .49926 L
s
.43692 .49926 m
.4369 .49932 L
s
.73359 .70005 m
.73369 .69993 L
s
1 .037 0 r
.23447 .44901 m
.23667 .44812 L
s
1 .023 0 r
.38527 .62496 m
.38509 .62467 L
s
.38509 .62467 m
.3855 .62462 L
s
.3855 .62462 m
.38527 .62496 L
s
1 .003 0 r
.73367 .69993 m
.7337 .69996 L
s
.73364 .69995 m
.73367 .69993 L
s
.73367 .69993 m
.73369 .69993 L
s
.7337 .69996 m
.73367 .69998 L
s
.73369 .69993 m
.7337 .69996 L
s
1 0 0 r
.69163 .42382 m
.69163 .42382 L
s
.69163 .42382 m
.69163 .42382 L
s
.69163 .42382 m
.69163 .42382 L
s
.69163 .42382 m
.69163 .42382 L
s
.69163 .42382 m
.69163 .42382 L
s
.69163 .42382 m
.69163 .42382 L
s
.69163 .42382 m
.69163 .42382 L
s
.69163 .42382 m
.69163 .42382 L
s
.69163 .42382 m
.69163 .42382 L
s
1 .003 0 r
.73367 .69998 m
.73364 .69995 L
s
.73364 .69995 m
.73369 .69993 L
s
.73369 .69993 m
.73367 .69998 L
s
1 .008 0 r
.53124 .64968 m
.53154 .64938 L
s
1 .035 0 r
.32887 .59929 m
.3307 .59835 L
s
1 .008 0 r
.53148 .64936 m
.53156 .64946 L
s
.53141 .64941 m
.53148 .64936 L
s
.53148 .64936 m
.53154 .64938 L
s
.53156 .64946 m
.53148 .64951 L
s
.53154 .64938 m
.53156 .64946 L
s
1 .001 0 r
.7861 .5741 m
.78612 .57407 L
s
1 .008 0 r
.53148 .64951 m
.53141 .64941 L
s
.53141 .64941 m
.53154 .64938 L
s
1 .001 0 r
.78611 .57407 m
.78612 .57408 L
s
.78611 .57408 m
.78611 .57407 L
s
.78611 .57407 m
.78612 .57407 L
s
.78612 .57408 m
.78611 .57408 L
s
.78612 .57407 m
.78612 .57408 L
s
1 .008 0 r
.53154 .64938 m
.53148 .64951 L
s
1 .001 0 r
.78611 .57408 m
.78611 .57408 L
s
.78611 .57408 m
.78612 .57407 L
s
.78612 .57407 m
.78611 .57408 L
s
1 .037 0 r
.23646 .4485 m
.2362 .44861 L
s
.23625 .44799 m
.23646 .4485 L
s
.23667 .44812 m
.23646 .4485 L
s
.23599 .4481 m
.23625 .44799 L
s
.23625 .44799 m
.23667 .44812 L
s
1 .001 0 r
.58372 .52371 m
.58375 .52365 L
s
.58374 .52365 m
.58375 .52367 L
s
.58373 .52366 m
.58374 .52365 L
s
.58374 .52365 m
.58375 .52365 L
s
.58375 .52367 m
.58374 .52368 L
s
.58375 .52365 m
.58375 .52367 L
s
.58374 .52368 m
.58373 .52366 L
s
.58373 .52366 m
.58375 .52365 L
s
.58375 .52365 m
.58374 .52368 L
s
1 .025 0 r
.42329 .74963 m
.42459 .74897 L
s
1 .002 0 r
.88061 .72443 m
.88066 .72437 L
s
1 .004 0 r
.3813 .4733 m
.38141 .47314 L
s
1 .002 0 r
.88065 .72436 m
.88067 .72438 L
s
.88063 .72438 m
.88065 .72436 L
s
.88065 .72436 m
.88066 .72437 L
s
.88067 .72438 m
.88065 .7244 L
s
.88066 .72437 m
.88067 .72438 L
s
.88065 .7244 m
.88063 .72438 L
s
.88063 .72438 m
.88066 .72437 L
s
.88066 .72437 m
.88065 .7244 L
s
1 .037 0 r
.2362 .44861 m
.23599 .4481 L
s
.23667 .44812 m
.2362 .44861 L
s
.23599 .4481 m
.23667 .44812 L
s
1 0 0 r
.83864 .4481 m
.83864 .4481 L
s
.83864 .4481 m
.83864 .4481 L
s
.83864 .4481 m
.83864 .4481 L
s
.83864 .4481 m
.83864 .4481 L
s
.83864 .4481 m
.83864 .4481 L
s
.83864 .4481 m
.83864 .4481 L
s
.83864 .4481 m
.83864 .4481 L
s
.83864 .4481 m
.83864 .4481 L
s
.83864 .4481 m
.83864 .4481 L
s
1 .004 0 r
.38139 .47314 m
.38143 .47318 L
s
.38135 .47316 m
.38139 .47314 L
s
.38139 .47314 m
.38141 .47314 L
s
.38143 .47318 m
.38139 .47321 L
s
.38141 .47314 m
.38143 .47318 L
s
.38139 .47321 m
.38135 .47316 L
s
.38135 .47316 m
.38141 .47314 L
s
.38141 .47314 m
.38139 .47321 L
s
.6782 .67404 m
.67832 .67391 L
s
1 .035 0 r
.33059 .59869 m
.33032 .59884 L
s
.33035 .59823 m
.33059 .59869 L
s
.3307 .59835 m
.33059 .59869 L
s
.33008 .59838 m
.33035 .59823 L
s
.33035 .59823 m
.3307 .59835 L
s
1 0 0 r
.63622 .39768 m
.63622 .39768 L
s
.63622 .39768 m
.63622 .39768 L
s
.63622 .39768 m
.63622 .39768 L
s
.63622 .39768 m
.63622 .39768 L
s
.63622 .39768 m
.63622 .39768 L
s
.63622 .39768 m
.63622 .39768 L
s
.63622 .39768 m
.63622 .39768 L
s
.63622 .39768 m
.63622 .39768 L
s
.63622 .39768 m
.63622 .39768 L
s
1 .004 0 r
.67829 .6739 m
.67833 .67394 L
s
.67826 .67393 m
.67829 .6739 L
s
.67829 .6739 m
.67832 .67391 L
s
.67833 .67394 m
.67829 .67397 L
s
.67832 .67391 m
.67833 .67394 L
s
.67829 .67397 m
.67826 .67393 L
s
.67826 .67393 m
.67832 .67391 L
s
.67832 .67391 m
.67829 .67397 L
s
1 .011 0 r
.47576 .62365 m
.47617 .62326 L
s
1 .025 0 r
.42433 .74888 m
.42451 .7492 L
s
.42414 .749 m
.42433 .74888 L
s
.42433 .74888 m
.42459 .74897 L
s
.42451 .7492 m
.42432 .74932 L
s
.42459 .74897 m
.42451 .7492 L
s
1 0 0 r
.93317 .59844 m
.93318 .59843 L
s
.93318 .59843 m
.93318 .59843 L
s
.93317 .59843 m
.93318 .59843 L
s
.93318 .59843 m
.93318 .59843 L
s
.93318 .59843 m
.93318 .59843 L
s
.93318 .59843 m
.93318 .59843 L
s
.93318 .59843 m
.93317 .59843 L
s
.93317 .59843 m
.93318 .59843 L
s
.93318 .59843 m
.93318 .59843 L
s
1 .035 0 r
.33032 .59884 m
.33008 .59838 L
s
.3307 .59835 m
.33032 .59884 L
s
.33008 .59838 m
.3307 .59835 L
s
1 .054 0 r
.27328 .57324 m
.27655 .57209 L
s
1 .025 0 r
.42432 .74932 m
.42414 .749 L
s
.42414 .749 m
.42459 .74897 L
s
.42459 .74897 m
.42432 .74932 L
s
1 .001 0 r
.73072 .54803 m
.73074 .54801 L
s
1 .011 0 r
.47609 .62324 m
.47618 .62337 L
s
.47599 .6233 m
.47609 .62324 L
s
.47609 .62324 m
.47617 .62326 L
s
1 .001 0 r
.73074 .54801 m
.73074 .54801 L
s
.73073 .54801 m
.73074 .54801 L
s
.73074 .54801 m
.73074 .54801 L
s
.73074 .54801 m
.73074 .54802 L
s
.73074 .54801 m
.73074 .54801 L
s
1 .011 0 r
.47618 .62337 m
.47608 .62343 L
s
.47617 .62326 m
.47618 .62337 L
s
1 .001 0 r
.73074 .54802 m
.73073 .54801 L
s
.73073 .54801 m
.73074 .54801 L
s
.73074 .54801 m
.73074 .54802 L
s
1 .011 0 r
.47608 .62343 m
.47599 .6233 L
s
.47599 .6233 m
.47617 .62326 L
s
.47617 .62326 m
.47608 .62343 L
s
1 .001 0 r
.52824 .49761 m
.52827 .49756 L
s
.52826 .49756 m
.52828 .49757 L
s
.52825 .49757 m
.52826 .49756 L
s
.52826 .49756 m
.52827 .49756 L
s
.52828 .49757 m
.52826 .49758 L
s
.52827 .49756 m
.52828 .49757 L
s
.52826 .49758 m
.52825 .49757 L
s
.52825 .49757 m
.52827 .49756 L
s
.52827 .49756 m
.52826 .49758 L
s
1 .033 0 r
.36774 .72364 m
.36961 .72284 L
s
1 .002 0 r
.82526 .69843 m
.82532 .69836 L
s
1 .005 0 r
.32573 .44718 m
.32587 .44699 L
s
1 .002 0 r
.82531 .69835 m
.82533 .69838 L
s
.82529 .69837 m
.82531 .69835 L
s
.82531 .69835 m
.82532 .69836 L
s
.82533 .69838 m
.82531 .69839 L
s
.82532 .69836 m
.82533 .69838 L
s
.82531 .69839 m
.82529 .69837 L
s
.82529 .69837 m
.82532 .69836 L
s
.82532 .69836 m
.82531 .69839 L
s
1 0 0 r
.78327 .42197 m
.78327 .42197 L
s
.78327 .42197 m
.78327 .42197 L
s
.78327 .42197 m
.78327 .42197 L
s
.78327 .42197 m
.78327 .42197 L
s
.78327 .42197 m
.78327 .42197 L
s
.78327 .42197 m
.78327 .42197 L
s
.78327 .42197 m
.78327 .42197 L
s
.78327 .42197 m
.78327 .42197 L
s
.78327 .42197 m
.78327 .42197 L
s
1 .005 0 r
.32585 .44699 m
.32589 .44704 L
s
.3258 .44702 m
.32585 .44699 L
s
.32585 .44699 m
.32587 .44699 L
s
.32589 .44704 m
.32584 .44707 L
s
.32587 .44699 m
.32589 .44704 L
s
.32584 .44707 m
.3258 .44702 L
s
.3258 .44702 m
.32587 .44699 L
s
1 .004 0 r
.62276 .64802 m
.62289 .64785 L
s
1 .005 0 r
.32587 .44699 m
.32584 .44707 L
s
1 .054 0 r
.27622 .5726 m
.27586 .57278 L
s
.27592 .57186 m
.27622 .5726 L
s
.27655 .57209 m
.27622 .5726 L
s
.27557 .57204 m
.27592 .57186 L
s
.27592 .57186 m
.27655 .57209 L
s
1 .004 0 r
.62287 .64785 m
.62291 .64789 L
s
.62283 .64787 m
.62287 .64785 L
s
.62287 .64785 m
.62289 .64785 L
s
.62291 .64789 m
.62287 .64792 L
s
.62289 .64785 m
.62291 .64789 L
s
.62287 .64792 m
.62283 .64787 L
s
.62283 .64787 m
.62289 .64785 L
s
.62289 .64785 m
.62287 .64792 L
s
1 .015 0 r
.42022 .59759 m
.42082 .59707 L
s
1 0 0 r
.87784 .57238 m
.87785 .57236 L
s
1 .033 0 r
.36946 .72315 m
.36922 .7233 L
s
.36924 .72271 m
.36946 .72315 L
s
.36961 .72284 m
.36946 .72315 L
s
1 0 0 r
.87785 .57236 m
.87785 .57236 L
s
.87784 .57236 m
.87785 .57236 L
s
.87785 .57236 m
.87785 .57236 L
s
.87785 .57236 m
.87785 .57237 L
s
.87785 .57236 m
.87785 .57236 L
s
.87785 .57237 m
.87784 .57236 L
s
.87784 .57236 m
.87785 .57236 L
s
1 .033 0 r
.36901 .72286 m
.36924 .72271 L
s
.36924 .72271 m
.36961 .72284 L
s
1 0 0 r
.87785 .57236 m
.87785 .57237 L
s
1 .001 0 r
.6753 .52194 m
.67531 .52192 L
s
.67531 .52192 m
.67531 .52192 L
s
.6753 .52192 m
.67531 .52192 L
s
.67531 .52192 m
.67531 .52192 L
s
.67531 .52192 m
.67531 .52193 L
s
.67531 .52192 m
.67531 .52192 L
s
.67531 .52193 m
.6753 .52192 L
s
.6753 .52192 m
.67531 .52192 L
s
.67531 .52192 m
.67531 .52193 L
s
1 .015 0 r
.51474 .74805 m
.5154 .74759 L
s
.4207 .59704 m
.42084 .59722 L
s
.42057 .59712 m
.4207 .59704 L
s
.4207 .59704 m
.42082 .59707 L
s
.42084 .59722 m
.4207 .5973 L
s
.42082 .59707 m
.42084 .59722 L
s
1 .054 0 r
.27655 .57209 m
.27586 .57278 L
s
.27557 .57204 m
.27655 .57209 L
s
.27586 .57278 m
.27557 .57204 L
s
1 .033 0 r
.36922 .7233 m
.36901 .72286 L
s
.36961 .72284 m
.36922 .7233 L
s
.36901 .72286 m
.36961 .72284 L
s
1 .001 0 r
.97244 .72284 m
.97248 .72279 L
s
.47272 .47149 m
.47274 .47145 L
s
.97247 .72279 m
.97248 .7228 L
s
.97246 .7228 m
.97247 .72279 L
s
.97247 .72279 m
.97248 .72279 L
s
.97248 .7228 m
.97247 .72281 L
s
.97248 .72279 m
.97248 .7228 L
s
.47273 .47145 m
.47275 .47146 L
s
.47272 .47145 m
.47273 .47145 L
s
.47273 .47145 m
.47274 .47145 L
s
.97247 .72281 m
.97246 .7228 L
s
.97246 .7228 m
.97248 .72279 L
s
.47275 .47146 m
.47273 .47147 L
s
.47274 .47145 m
.47275 .47146 L
s
.97248 .72279 m
.97247 .72281 L
s
.47273 .47147 m
.47272 .47145 L
s
.47272 .47145 m
.47274 .47145 L
s
.47274 .47145 m
.47273 .47147 L
s
1 .015 0 r
.4207 .5973 m
.42057 .59712 L
s
.42057 .59712 m
.42082 .59707 L
s
.42082 .59707 m
.4207 .5973 L
s
1 .045 0 r
.31213 .69762 m
.31489 .69674 L
s
1 .002 0 r
.76987 .6724 m
.76993 .67232 L
s
1 .005 0 r
.2701 .42104 m
.27029 .42084 L
s
1 .002 0 r
.76992 .67232 m
.76994 .67234 L
s
.7699 .67233 m
.76992 .67232 L
s
.76992 .67232 m
.76993 .67232 L
s
.76994 .67234 m
.76992 .67236 L
s
.76993 .67232 m
.76994 .67234 L
s
.76992 .67236 m
.7699 .67233 L
s
.7699 .67233 m
.76993 .67232 L
s
1 .015 0 r
.51527 .74755 m
.51539 .74773 L
s
.51514 .74763 m
.51527 .74755 L
s
.51527 .74755 m
.5154 .74759 L
s
1 .002 0 r
.76993 .67232 m
.76992 .67236 L
s
1 .015 0 r
.51539 .74773 m
.51527 .74782 L
s
.5154 .74759 m
.51539 .74773 L
s
1 0 0 r
.72786 .39581 m
.72786 .39581 L
s
.72786 .39581 m
.72786 .39581 L
s
.72786 .39581 m
.72786 .39581 L
s
.72786 .39581 m
.72786 .39581 L
s
.72786 .39581 m
.72786 .39581 L
s
.72786 .39581 m
.72786 .39581 L
s
.72786 .39581 m
.72786 .39581 L
s
.72786 .39581 m
.72786 .39581 L
s
.72786 .39581 m
.72786 .39581 L
s
1 .005 0 r
.27026 .42084 m
.2703 .4209 L
s
.27021 .42086 m
.27026 .42084 L
s
.27026 .42084 m
.27029 .42084 L
s
.2703 .4209 m
.27025 .42092 L
s
.27029 .42084 m
.2703 .4209 L
s
.56727 .62196 m
.56743 .62176 L
s
.27025 .42092 m
.27021 .42086 L
s
.27021 .42086 m
.27029 .42084 L
s
.27029 .42084 m
.27025 .42092 L
s
1 .015 0 r
.51527 .74782 m
.51514 .74763 L
s
.51514 .74763 m
.5154 .74759 L
s
.5154 .74759 m
.51527 .74782 L
s
1 .005 0 r
.5674 .62176 m
.56745 .62182 L
s
.56735 .62179 m
.5674 .62176 L
s
.5674 .62176 m
.56743 .62176 L
s
.56745 .62182 m
.5674 .62185 L
s
.56743 .62176 m
.56745 .62182 L
s
1 .023 0 r
.36463 .57151 m
.36561 .57077 L
s
1 .005 0 r
.5674 .62185 m
.56735 .62179 L
s
.56735 .62179 m
.56743 .62176 L
s
.56743 .62176 m
.5674 .62185 L
s
1 .045 0 r
.3146 .69714 m
.31432 .69731 L
s
.31436 .69652 m
.3146 .69714 L
s
.31489 .69674 m
.3146 .69714 L
s
1 0 0 r
.82246 .54629 m
.82247 .54627 L
s
.82247 .54627 m
.82247 .54627 L
s
.82246 .54627 m
.82247 .54627 L
s
.82247 .54627 m
.82247 .54627 L
s
.82247 .54627 m
.82247 .54628 L
s
.82247 .54627 m
.82247 .54627 L
s
.82247 .54628 m
.82246 .54627 L
s
.82246 .54627 m
.82247 .54627 L
s
.82247 .54627 m
.82247 .54628 L
s
1 .045 0 r
.31408 .6967 m
.31436 .69652 L
s
.31436 .69652 m
.31489 .69674 L
s
1 .001 0 r
.61982 .49582 m
.61983 .4958 L
s
.61982 .4958 m
.61983 .49581 L
s
.61982 .49581 m
.61982 .4958 L
s
.61982 .4958 m
.61983 .4958 L
s
.61983 .49581 m
.61982 .49581 L
s
.61983 .4958 m
.61983 .49581 L
s
.61982 .49581 m
.61982 .49581 L
s
.61982 .49581 m
.61983 .4958 L
s
.61983 .4958 m
.61982 .49581 L
s
1 .02 0 r
.45918 .72204 m
.4601 .72145 L
s
1 .001 0 r
.9171 .69681 m
.91713 .69676 L
s
.41714 .44535 m
.41715 .44531 L
s
.41715 .44531 m
.41716 .44532 L
s
.41714 .44532 m
.41715 .44531 L
s
.41715 .44531 m
.41715 .44531 L
s
.91712 .69676 m
.91714 .69678 L
s
.91711 .69677 m
.91712 .69676 L
s
.91712 .69676 m
.91713 .69676 L
s
.41716 .44532 m
.41715 .44533 L
s
.41715 .44531 m
.41716 .44532 L
s
.91714 .69678 m
.91713 .69678 L
s
.91713 .69676 m
.91714 .69678 L
s
.41715 .44533 m
.41714 .44532 L
s
.41714 .44532 m
.41715 .44531 L
s
.41715 .44531 m
.41715 .44533 L
s
.91713 .69678 m
.91711 .69677 L
s
.91711 .69677 m
.91713 .69676 L
s
.91713 .69676 m
.91713 .69678 L
s
1 .023 0 r
.36543 .57072 m
.36561 .571 L
s
.36522 .57083 m
.36543 .57072 L
s
.36543 .57072 m
.36561 .57077 L
s
1 .045 0 r
.31489 .69674 m
.31432 .69731 L
s
.31408 .6967 m
.31489 .69674 L
s
1 .023 0 r
.36561 .571 m
.36541 .57111 L
s
.36561 .57077 m
.36561 .571 L
s
1 .045 0 r
.31432 .69731 m
.31408 .6967 L
s
1 0 0 r
.87507 .42011 m
.87507 .42011 L
s
.87507 .42011 m
.87507 .42011 L
s
.87507 .42011 m
.87507 .42011 L
s
.87507 .42011 m
.87507 .42011 L
s
.87507 .42011 m
.87507 .42011 L
s
.87507 .42011 m
.87507 .42011 L
s
.87507 .42011 m
.87507 .42011 L
s
.87507 .42011 m
.87507 .42011 L
s
.87507 .42011 m
.87507 .42011 L
s
1 .002 0 r
.71443 .64635 m
.71449 .64626 L
s
1 .001 0 r
.21442 .39487 m
.21449 .39484 L
s
.21449 .39485 m
.21448 .39486 L
s
.21448 .39484 m
.21449 .39485 L
s
.21449 .39484 m
.21449 .39485 L
s
.21447 .39484 m
.21448 .39484 L
s
.21448 .39484 m
.21449 .39484 L
s
.21448 .39486 m
.21447 .39484 L
s
.21449 .39484 m
.21448 .39486 L
s
.21447 .39484 m
.21449 .39484 L
s
1 .002 0 r
.71448 .64626 m
.7145 .64628 L
s
.71446 .64627 m
.71448 .64626 L
s
.71448 .64626 m
.71449 .64626 L
s
.7145 .64628 m
.71448 .6463 L
s
.71449 .64626 m
.7145 .64628 L
s
1 .023 0 r
.36541 .57111 m
.36522 .57083 L
s
.36522 .57083 m
.36561 .57077 L
s
1 .002 0 r
.71448 .6463 m
.71446 .64627 L
s
.71446 .64627 m
.71449 .64626 L
s
.71449 .64626 m
.71448 .6463 L
s
1 .023 0 r
.36561 .57077 m
.36541 .57111 L
s
1 .02 0 r
.45992 .72139 m
.46007 .72164 L
s
.45975 .7215 m
.45992 .72139 L
s
.45992 .72139 m
.4601 .72145 L
s
.46007 .72164 m
.45991 .72174 L
s
.4601 .72145 m
.46007 .72164 L
s
1 .007 0 r
.51172 .59589 m
.51193 .59563 L
s
1 .02 0 r
.45991 .72174 m
.45975 .7215 L
s
.45975 .7215 m
.4601 .72145 L
s
.4601 .72145 m
.45991 .72174 L
s
1 .037 0 r
.30898 .54541 m
.31083 .54431 L
s
1 .007 0 r
.51189 .59563 m
.51196 .5957 L
s
.51183 .59567 m
.51189 .59563 L
s
.51189 .59563 m
.51193 .59563 L
s
.51196 .5957 m
.51189 .59574 L
s
.51193 .59563 m
.51196 .5957 L
s
.51189 .59574 m
.51183 .59567 L
s
.51183 .59567 m
.51193 .59563 L
s
.51193 .59563 m
.51189 .59574 L
s
1 0 0 r
.76703 .52017 m
.76703 .52016 L
s
.76703 .52016 m
.76704 .52016 L
s
.76703 .52016 m
.76703 .52016 L
s
.76703 .52016 m
.76703 .52016 L
s
.76704 .52016 m
.76703 .52016 L
s
.76703 .52016 m
.76704 .52016 L
s
.76703 .52016 m
.76703 .52016 L
s
.76703 .52016 m
.76703 .52016 L
s
.76703 .52016 m
.76703 .52016 L
s
1 .009 0 r
.60634 .74647 m
.60668 .74617 L
s
1 0 0 r
.56428 .46968 m
.56429 .46966 L
s
.56429 .46967 m
.56429 .46967 L
s
.56429 .46967 m
.56429 .46967 L
s
.56429 .46967 m
.56429 .46966 L
s
.56429 .46967 m
.56429 .46967 L
s
.56429 .46966 m
.56429 .46967 L
s
.56429 .46967 m
.56429 .46967 L
s
.56429 .46967 m
.56429 .46966 L
s
.56429 .46966 m
.56429 .46967 L
s
1 .027 0 r
.40357 .696 m
.40491 .69525 L
s
1 .009 0 r
.60661 .74615 m
.60669 .74626 L
s
.60653 .74621 m
.60661 .74615 L
s
.60661 .74615 m
.60668 .74617 L
s
.60669 .74626 m
.60661 .74631 L
s
.60668 .74617 m
.60669 .74626 L
s
1 .001 0 r
.8617 .67076 m
.86174 .67071 L
s
.36151 .41919 m
.36152 .41916 L
s
.36151 .41916 m
.36152 .41917 L
s
.36151 .41917 m
.36151 .41916 L
s
.36151 .41916 m
.36152 .41916 L
s
.36152 .41917 m
.36151 .41917 L
s
.36152 .41916 m
.36152 .41917 L
s
.36151 .41917 m
.36151 .41917 L
s
.36151 .41917 m
.36152 .41916 L
s
1 .009 0 r
.60661 .74631 m
.60653 .74621 L
s
.60653 .74621 m
.60668 .74617 L
s
1 .001 0 r
.36152 .41916 m
.36151 .41917 L
s
.86173 .67071 m
.86174 .67072 L
s
.86171 .67072 m
.86173 .67071 L
s
.86173 .67071 m
.86174 .67071 L
s
1 .009 0 r
.60668 .74617 m
.60661 .74631 L
s
1 .001 0 r
.86174 .67072 m
.86173 .67073 L
s
.86174 .67071 m
.86174 .67072 L
s
.86173 .67073 m
.86171 .67072 L
s
.86171 .67072 m
.86174 .67071 L
s
.86174 .67071 m
.86173 .67073 L
s
1 0 0 r
.81965 .39393 m
.81965 .39393 L
s
.81965 .39393 m
.81965 .39393 L
s
.81965 .39393 m
.81965 .39393 L
s
.81965 .39393 m
.81965 .39393 L
s
.81965 .39393 m
.81965 .39393 L
s
.81965 .39393 m
.81965 .39393 L
s
.81965 .39393 m
.81965 .39393 L
s
.81965 .39393 m
.81965 .39393 L
s
.81965 .39393 m
.81965 .39393 L
s
1 .003 0 r
.65893 .62028 m
.65901 .62017 L
s
.65899 .62017 m
.65902 .6202 L
s
.65896 .62019 m
.65899 .62017 L
s
.65899 .62017 m
.65901 .62017 L
s
.65902 .6202 m
.65899 .62022 L
s
.65901 .62017 m
.65902 .6202 L
s
.65899 .62022 m
.65896 .62019 L
s
.65896 .62019 m
.65901 .62017 L
s
.65901 .62017 m
.65899 .62022 L
s
1 .037 0 r
.31048 .54422 m
.31075 .5447 L
s
.31017 .54437 m
.31048 .54422 L
s
.31048 .54422 m
.31083 .54431 L
s
.31075 .5447 m
.31044 .54485 L
s
.31083 .54431 m
.31075 .5447 L
s
1 .009 0 r
.45613 .56979 m
.45642 .56945 L
s
1 .027 0 r
.40465 .69516 m
.40485 .69551 L
s
.40443 .69529 m
.40465 .69516 L
s
.40465 .69516 m
.40491 .69525 L
s
1 0 0 r
.91435 .54454 m
.91436 .54453 L
s
1 .027 0 r
.40485 .69551 m
.40463 .69564 L
s
.40491 .69525 m
.40485 .69551 L
s
1 0 0 r
.91436 .54453 m
.91436 .54453 L
s
.91435 .54453 m
.91436 .54453 L
s
.91436 .54453 m
.91436 .54453 L
s
.91436 .54453 m
.91436 .54453 L
s
.91436 .54453 m
.91436 .54453 L
s
.91436 .54453 m
.91435 .54453 L
s
.91435 .54453 m
.91436 .54453 L
s
.91436 .54453 m
.91436 .54453 L
s
1 .066 0 r
.25329 .51929 m
.25723 .51782 L
s
1 .009 0 r
.45636 .56944 m
.45644 .56954 L
s
.45627 .56949 m
.45636 .56944 L
s
.45636 .56944 m
.45642 .56945 L
s
.45644 .56954 m
.45636 .5696 L
s
.45642 .56945 m
.45644 .56954 L
s
1 .037 0 r
.31044 .54485 m
.31017 .54437 L
s
.31017 .54437 m
.31083 .54431 L
s
.31083 .54431 m
.31044 .54485 L
s
1 0 0 r
.71154 .49403 m
.71155 .49402 L
s
.71155 .49402 m
.71155 .49402 L
s
.71154 .49402 m
.71155 .49402 L
s
.71155 .49402 m
.71155 .49402 L
s
.71155 .49402 m
.71155 .49403 L
s
.71155 .49402 m
.71155 .49402 L
s
.71155 .49403 m
.71154 .49402 L
s
.71154 .49402 m
.71155 .49402 L
s
.71155 .49402 m
.71155 .49403 L
s
1 .009 0 r
.45636 .5696 m
.45627 .56949 L
s
.45627 .56949 m
.45642 .56945 L
s
.45642 .56945 m
.45636 .5696 L
s
1 .027 0 r
.40463 .69564 m
.40443 .69529 L
s
.40443 .69529 m
.40491 .69525 L
s
.40491 .69525 m
.40463 .69564 L
s
1 .011 0 r
.55077 .72044 m
.55122 .72006 L
s
1 0 0 r
.5087 .44352 m
.50871 .44351 L
s
.5087 .44351 m
.50871 .44351 L
s
.5087 .44351 m
.5087 .44351 L
s
.5087 .44351 m
.50871 .44351 L
s
.50871 .44351 m
.5087 .44351 L
s
.50871 .44351 m
.50871 .44351 L
s
.5087 .44351 m
.5087 .44351 L
s
.5087 .44351 m
.50871 .44351 L
s
.50871 .44351 m
.5087 .44351 L
s
1 .038 0 r
.34791 .66994 m
.34996 .66899 L
s
1 .001 0 r
.80625 .64469 m
.80629 .64463 L
s
1 0 0 r
.30582 .393 m
.30582 .39299 L
s
.30582 .39299 m
.30583 .39299 L
s
.30582 .39299 m
.30582 .39299 L
s
.30582 .39299 m
.30582 .39299 L
s
.30583 .39299 m
.30582 .39299 L
s
.30582 .39299 m
.30583 .39299 L
s
.30582 .39299 m
.30582 .39299 L
s
.30582 .39299 m
.30582 .39299 L
s
.30582 .39299 m
.30582 .39299 L
s
1 .011 0 r
.55113 .72004 m
.55123 .72017 L
s
.55103 .7201 m
.55113 .72004 L
s
.55113 .72004 m
.55122 .72006 L
s
.55123 .72017 m
.55113 .72024 L
s
.55122 .72006 m
.55123 .72017 L
s
1 .001 0 r
.80628 .64463 m
.80629 .64465 L
s
.80626 .64464 m
.80628 .64463 L
s
.80628 .64463 m
.80629 .64463 L
s
.80629 .64465 m
.80628 .64466 L
s
.80629 .64463 m
.80629 .64465 L
s
.80628 .64466 m
.80626 .64464 L
s
.80626 .64464 m
.80629 .64463 L
s
.80629 .64463 m
.80628 .64466 L
s
1 .011 0 r
.55113 .72024 m
.55103 .7201 L
s
.55103 .7201 m
.55122 .72006 L
s
.55122 .72006 m
.55113 .72024 L
s
1 .003 0 r
.60338 .59418 m
.60347 .59405 L
s
.60345 .59405 m
.60348 .59408 L
s
.60342 .59407 m
.60345 .59405 L
s
.60345 .59405 m
.60347 .59405 L
s
.60348 .59408 m
.60345 .59411 L
s
.60347 .59405 m
.60348 .59408 L
s
.60345 .59411 m
.60342 .59407 L
s
.60342 .59407 m
.60347 .59405 L
s
.60347 .59405 m
.60345 .59411 L
s
1 .013 0 r
.40048 .54366 m
.40091 .54319 L
s
1 .066 0 r
.25685 .51846 m
.2564 .51867 L
s
.25648 .51755 m
.25685 .51846 L
s
.25723 .51782 m
.25685 .51846 L
s
.25604 .51776 m
.25648 .51755 L
s
.25648 .51755 m
.25723 .51782 L
s
1 0 0 r
.85892 .5184 m
.85892 .51839 L
s
.85892 .51839 m
.85892 .51839 L
s
.85892 .51839 m
.85892 .51839 L
s
.85892 .51839 m
.85892 .51839 L
s
.85892 .51839 m
.85892 .51839 L
s
.85892 .51839 m
.85892 .51839 L
s
.85892 .51839 m
.85892 .51839 L
s
.85892 .51839 m
.85892 .51839 L
s
.85892 .51839 m
.85892 .51839 L
s
1 .005 0 r
.69809 .74489 m
.69828 .7447 L
s
1 .038 0 r
.34982 .66935 m
.34954 .66951 L
s
.34957 .66885 m
.34982 .66935 L
s
.34996 .66899 m
.34982 .66935 L
s
.34929 .66901 m
.34957 .66885 L
s
.34957 .66885 m
.34996 .66899 L
s
1 0 0 r
.65601 .46787 m
.65601 .46786 L
s
.65601 .46786 m
.65601 .46786 L
s
.65601 .46786 m
.65601 .46786 L
s
.65601 .46786 m
.65601 .46786 L
s
.65601 .46786 m
.65601 .46786 L
s
.65601 .46786 m
.65601 .46786 L
s
.65601 .46786 m
.65601 .46786 L
s
.65601 .46786 m
.65601 .46786 L
s
.65601 .46786 m
.65601 .46786 L
s
1 .005 0 r
.69824 .74469 m
.69829 .74475 L
s
.69819 .74473 m
.69824 .74469 L
s
.69824 .74469 m
.69828 .7447 L
s
1 .013 0 r
.40083 .54318 m
.40094 .54332 L
s
.40071 .54325 m
.40083 .54318 L
s
.40083 .54318 m
.40091 .54319 L
s
1 .005 0 r
.69829 .74475 m
.69824 .74479 L
s
.69828 .7447 m
.69829 .74475 L
s
1 .013 0 r
.40094 .54332 m
.40082 .54339 L
s
.40091 .54319 m
.40094 .54332 L
s
1 .015 0 r
.49516 .69438 m
.49577 .6939 L
s
1 .005 0 r
.69824 .74479 m
.69819 .74473 L
s
.69819 .74473 m
.69828 .7447 L
s
.69828 .7447 m
.69824 .74479 L
s
1 .013 0 r
.40082 .54339 m
.40071 .54325 L
s
.40071 .54325 m
.40091 .54319 L
s
.40091 .54319 m
.40082 .54339 L
s
1 .001 0 r
.95368 .66912 m
.9537 .66908 L
s
1 0 0 r
.45307 .41733 m
.45307 .41732 L
s
.45307 .41732 m
.45307 .41732 L
s
.45307 .41732 m
.45307 .41732 L
s
.45307 .41732 m
.45307 .41732 L
s
.45307 .41732 m
.45307 .41733 L
s
.45307 .41732 m
.45307 .41732 L
s
.45307 .41733 m
.45307 .41732 L
s
.45307 .41732 m
.45307 .41732 L
s
.45307 .41732 m
.45307 .41733 L
s
1 .001 0 r
.9537 .66908 m
.95371 .66909 L
s
.95369 .66909 m
.9537 .66908 L
s
.9537 .66908 m
.9537 .66908 L
s
.95371 .66909 m
.9537 .6691 L
s
.9537 .66908 m
.95371 .66909 L
s
.9537 .6691 m
.95369 .66909 L
s
.95369 .66909 m
.9537 .66908 L
s
.9537 .66908 m
.9537 .6691 L
s
1 .054 0 r
.2922 .64386 m
.29547 .64276 L
s
1 .038 0 r
.34954 .66951 m
.34929 .66901 L
s
.34996 .66899 m
.34954 .66951 L
s
.34929 .66901 m
.34996 .66899 L
s
1 .002 0 r
.75075 .61859 m
.75079 .61853 L
s
.75078 .61853 m
.75079 .61854 L
s
.75076 .61854 m
.75078 .61853 L
s
.75078 .61853 m
.75079 .61853 L
s
.75079 .61854 m
.75078 .61856 L
s
.75079 .61853 m
.75079 .61854 L
s
1 .066 0 r
.25723 .51782 m
.2564 .51867 L
s
.25604 .51776 m
.25723 .51782 L
s
1 .002 0 r
.75078 .61856 m
.75076 .61854 L
s
.75076 .61854 m
.75079 .61853 L
s
1 .066 0 r
.2564 .51867 m
.25604 .51776 L
s
1 .002 0 r
.75079 .61853 m
.75078 .61856 L
s
1 .015 0 r
.49565 .69386 m
.49577 .69404 L
s
.49552 .69395 m
.49565 .69386 L
s
.49565 .69386 m
.49577 .6939 L
s
.49577 .69404 m
.49565 .69412 L
s
.49577 .6939 m
.49577 .69404 L
s
1 .004 0 r
.54778 .56806 m
.54788 .5679 L
s
1 .015 0 r
.49565 .69412 m
.49552 .69395 L
s
.49552 .69395 m
.49577 .6939 L
s
.49577 .6939 m
.49565 .69412 L
s
1 .004 0 r
.54786 .5679 m
.5479 .56794 L
s
.54782 .56793 m
.54786 .5679 L
s
.54786 .5679 m
.54788 .5679 L
s
.5479 .56794 m
.54786 .56797 L
s
.54788 .5679 m
.5479 .56794 L
s
.54786 .56797 m
.54782 .56793 L
s
.54782 .56793 m
.54788 .5679 L
s
.54788 .5679 m
.54786 .56797 L
s
1 .02 0 r
.34478 .51751 m
.34554 .5168 L
s
1 0 0 r
.80343 .49224 m
.80343 .49223 L
s
.80343 .49223 m
.80343 .49223 L
s
.80343 .49223 m
.80343 .49223 L
s
.80343 .49223 m
.80343 .49223 L
s
.80343 .49223 m
.80343 .49223 L
s
.80343 .49223 m
.80343 .49223 L
s
.80343 .49223 m
.80343 .49223 L
s
.80343 .49223 m
.80343 .49223 L
s
.80343 .49223 m
.80343 .49223 L
s
1 .007 0 r
.64253 .71883 m
.64275 .7186 L
s
1 .054 0 r
.29513 .64325 m
.29479 .64345 L
s
.29484 .64251 m
.29513 .64325 L
s
.29547 .64276 m
.29513 .64325 L
s
.2945 .64271 m
.29484 .64251 L
s
.29484 .64251 m
.29547 .64276 L
s
1 0 0 r
.60042 .44168 m
.60042 .44168 L
s
.60042 .44168 m
.60042 .44168 L
s
.60042 .44168 m
.60042 .44168 L
s
.60042 .44168 m
.60042 .44168 L
s
.60042 .44168 m
.60042 .44168 L
s
.60042 .44168 m
.60042 .44168 L
s
.60042 .44168 m
.60042 .44168 L
s
.60042 .44168 m
.60042 .44168 L
s
.60042 .44168 m
.60042 .44168 L
s
1 .007 0 r
.64271 .71859 m
.64277 .71867 L
s
.64265 .71863 m
.64271 .71859 L
s
.64271 .71859 m
.64275 .7186 L
s
1 .02 0 r
.4395 .66829 m
.44037 .66766 L
s
1 .007 0 r
.64277 .71867 m
.64271 .71871 L
s
.64275 .7186 m
.64277 .71867 L
s
.64271 .71871 m
.64265 .71863 L
s
.64265 .71863 m
.64275 .7186 L
s
.64275 .7186 m
.64271 .71871 L
s
1 .001 0 r
.89823 .64302 m
.89825 .64299 L
s
1 0 0 r
.39738 .39111 m
.39738 .39111 L
s
.39738 .39111 m
.39738 .39111 L
s
.39738 .39111 m
.39738 .39111 L
s
.39738 .39111 m
.39738 .39111 L
s
.39738 .39111 m
.39738 .39111 L
s
.39738 .39111 m
.39738 .39111 L
s
.39738 .39111 m
.39738 .39111 L
s
.39738 .39111 m
.39738 .39111 L
s
.39738 .39111 m
.39738 .39111 L
s
1 .001 0 r
.89824 .64299 m
.89825 .64299 L
s
.89824 .64299 m
.89824 .64299 L
s
.89824 .64299 m
.89825 .64299 L
s
.89825 .64299 m
.89825 .643 L
s
.89825 .64299 m
.89825 .64299 L
s
.89825 .643 m
.89824 .64299 L
s
.89824 .64299 m
.89825 .64299 L
s
.89825 .64299 m
.89825 .643 L
s
1 .02 0 r
.34539 .51677 m
.34556 .51701 L
s
.34521 .51687 m
.34539 .51677 L
s
.34539 .51677 m
.34554 .5168 L
s
.34556 .51701 m
.34538 .51711 L
s
.34554 .5168 m
.34556 .51701 L
s
1 .002 0 r
.69519 .59247 m
.69524 .5924 L
s
1 .02 0 r
.34538 .51711 m
.34521 .51687 L
s
.34521 .51687 m
.34554 .5168 L
s
.34554 .5168 m
.34538 .51711 L
s
1 .002 0 r
.69523 .5924 m
.69524 .59242 L
s
.69521 .59241 m
.69523 .5924 L
s
.69523 .5924 m
.69524 .5924 L
s
.69524 .59242 m
.69523 .59243 L
s
.69524 .5924 m
.69524 .59242 L
s
.69523 .59243 m
.69521 .59241 L
s
.69521 .59241 m
.69524 .5924 L
s
.69524 .5924 m
.69523 .59243 L
s
1 .054 0 r
.29547 .64276 m
.29479 .64345 L
s
.2945 .64271 m
.29547 .64276 L
s
.29479 .64345 m
.2945 .64271 L
s
1 .005 0 r
.49213 .54191 m
.49225 .54172 L
s
1 .02 0 r
.4402 .66761 m
.44036 .66786 L
s
.44002 .66772 m
.4402 .66761 L
s
.4402 .66761 m
.44037 .66766 L
s
.44036 .66786 m
.44019 .66796 L
s
.44037 .66766 m
.44036 .66786 L
s
1 .005 0 r
.49223 .54172 m
.49227 .54177 L
s
.49218 .54175 m
.49223 .54172 L
s
.49223 .54172 m
.49225 .54172 L
s
.49227 .54177 m
.49223 .5418 L
s
.49225 .54172 m
.49227 .54177 L
s
.49223 .5418 m
.49218 .54175 L
s
.49218 .54175 m
.49225 .54172 L
s
1 .003 0 r
.79 .74331 m
.79011 .74319 L
s
1 .005 0 r
.49225 .54172 m
.49223 .5418 L
s
1 .02 0 r
.44019 .66796 m
.44002 .66772 L
s
.44002 .66772 m
.44037 .66766 L
s
1 .036 0 r
.28903 .49134 m
.29067 .49014 L
s
1 .02 0 r
.44037 .66766 m
.44019 .66796 L
s
1 .003 0 r
.79009 .74318 m
.79012 .74322 L
s
.79006 .7432 m
.79009 .74318 L
s
.79009 .74318 m
.79011 .74319 L
s
1 0 0 r
.74789 .46605 m
.74789 .46605 L
s
.74789 .46605 m
.74789 .46605 L
s
.74789 .46605 m
.74789 .46605 L
s
.74789 .46605 m
.74789 .46605 L
s
.74789 .46605 m
.74789 .46605 L
s
.74789 .46605 m
.74789 .46605 L
s
1 .003 0 r
.79012 .74322 m
.79009 .74324 L
s
.79011 .74319 m
.79012 .74322 L
s
1 0 0 r
.74789 .46605 m
.74789 .46605 L
s
.74789 .46605 m
.74789 .46605 L
s
.74789 .46605 m
.74789 .46605 L
s
1 .003 0 r
.79009 .74324 m
.79006 .7432 L
s
.79006 .7432 m
.79011 .74319 L
s
.79011 .74319 m
.79009 .74324 L
s
1 .008 0 r
.58691 .69275 m
.58719 .69247 L
s
1 0 0 r
.54478 .41547 m
.54478 .41547 L
s
.54478 .41547 m
.54478 .41547 L
s
.54478 .41547 m
.54478 .41547 L
s
.54478 .41547 m
.54478 .41547 L
s
.54478 .41547 m
.54478 .41547 L
s
.54478 .41547 m
.54478 .41547 L
s
.54478 .41547 m
.54478 .41547 L
s
.54478 .41547 m
.54478 .41547 L
s
.54478 .41547 m
.54478 .41547 L
s
1 .029 0 r
.38378 .64219 m
.38513 .64133 L
s
1 .008 0 r
.58714 .69245 m
.58721 .69254 L
s
.58706 .6925 m
.58714 .69245 L
s
.58714 .69245 m
.58719 .69247 L
s
.58721 .69254 m
.58714 .6926 L
s
.58719 .69247 m
.58721 .69254 L
s
1 .001 0 r
.84272 .6169 m
.84274 .61686 L
s
1 .008 0 r
.58714 .6926 m
.58706 .6925 L
s
.58706 .6925 m
.58719 .69247 L
s
.58719 .69247 m
.58714 .6926 L
s
1 .001 0 r
.84274 .61686 m
.84275 .61687 L
s
.84273 .61687 m
.84274 .61686 L
s
.84274 .61686 m
.84274 .61686 L
s
.84275 .61687 m
.84274 .61688 L
s
.84274 .61686 m
.84275 .61687 L
s
.84274 .61688 m
.84273 .61687 L
s
.84273 .61687 m
.84274 .61686 L
s
.84274 .61686 m
.84274 .61688 L
s
1 .002 0 r
.63959 .56632 m
.63963 .56625 L
s
.63962 .56625 m
.63964 .56627 L
s
.63961 .56626 m
.63962 .56625 L
s
.63962 .56625 m
.63963 .56625 L
s
.63964 .56627 m
.63962 .56628 L
s
.63963 .56625 m
.63964 .56627 L
s
.63962 .56628 m
.63961 .56626 L
s
.63961 .56626 m
.63963 .56625 L
s
.63963 .56625 m
.63962 .56628 L
s
1 .036 0 r
.29036 .49007 m
.29064 .49053 L
s
.29003 .49023 m
.29036 .49007 L
s
.29036 .49007 m
.29067 .49014 L
s
.29064 .49053 m
.29032 .49069 L
s
.29067 .49014 m
.29064 .49053 L
s
1 .006 0 r
.43642 .51574 m
.43658 .5155 L
s
1 0 0 r
.89547 .49044 m
.89547 .49044 L
s
.89547 .49044 m
.89547 .49044 L
s
.89547 .49044 m
.89547 .49044 L
s
.89547 .49044 m
.89547 .49044 L
s
.89547 .49044 m
.89547 .49044 L
s
.89547 .49044 m
.89547 .49044 L
s
.89547 .49044 m
.89547 .49044 L
s
.89547 .49044 m
.89547 .49044 L
s
.89547 .49044 m
.89547 .49044 L
s
1 .029 0 r
.38487 .64125 m
.38509 .64161 L
s
.38463 .64139 m
.38487 .64125 L
s
.38487 .64125 m
.38513 .64133 L
s
.38509 .64161 m
.38485 .64175 L
s
.38513 .64133 m
.38509 .64161 L
s
1 .006 0 r
.43655 .51549 m
.43661 .51556 L
s
.43649 .51553 m
.43655 .51549 L
s
.43655 .51549 m
.43658 .5155 L
s
1 .004 0 r
.73443 .71723 m
.73456 .71709 L
s
1 .006 0 r
.43661 .51556 m
.43655 .51559 L
s
.43658 .5155 m
.43661 .51556 L
s
1 .081 0 r
.23322 .46514 m
.23801 .46321 L
s
1 .006 0 r
.43655 .51559 m
.43649 .51553 L
s
.43649 .51553 m
.43658 .5155 L
s
.43658 .5155 m
.43655 .51559 L
s
1 0 0 r
.6923 .43984 m
.6923 .43984 L
s
.6923 .43984 m
.6923 .43984 L
s
.6923 .43984 m
.6923 .43984 L
s
.6923 .43984 m
.6923 .43984 L
s
.6923 .43984 m
.6923 .43984 L
s
.6923 .43984 m
.6923 .43984 L
s
.6923 .43984 m
.6923 .43984 L
s
.6923 .43984 m
.6923 .43984 L
s
.6923 .43984 m
.6923 .43984 L
s
1 .004 0 r
.73453 .71708 m
.73457 .71712 L
s
.73449 .71711 m
.73453 .71708 L
s
.73453 .71708 m
.73456 .71709 L
s
.73457 .71712 m
.73453 .71715 L
s
.73456 .71709 m
.73457 .71712 L
s
1 .036 0 r
.29032 .49069 m
.29003 .49023 L
s
.29003 .49023 m
.29067 .49014 L
s
1 .004 0 r
.73453 .71715 m
.73449 .71711 L
s
.73449 .71711 m
.73456 .71709 L
s
1 .036 0 r
.29067 .49014 m
.29032 .49069 L
s
1 .004 0 r
.73456 .71709 m
.73453 .71715 L
s
1 .01 0 r
.53124 .66665 m
.53161 .66628 L
s
1 .029 0 r
.38485 .64175 m
.38463 .64139 L
s
.38463 .64139 m
.38513 .64133 L
s
.38513 .64133 m
.38485 .64175 L
s
1 0 0 r
.48909 .38923 m
.48909 .38923 L
s
.48909 .38923 m
.48909 .38923 L
s
.48909 .38923 m
.48909 .38923 L
s
.48909 .38923 m
.48909 .38923 L
s
.48909 .38923 m
.48909 .38923 L
s
.48909 .38923 m
.48909 .38923 L
s
.48909 .38923 m
.48909 .38923 L
s
.48909 .38923 m
.48909 .38923 L
s
.48909 .38923 m
.48909 .38923 L
s
1 .043 0 r
.32801 .61605 m
.33027 .6149 L
s
1 .01 0 r
.53154 .66626 m
.53163 .66638 L
s
.53144 .66632 m
.53154 .66626 L
s
.53154 .66626 m
.53161 .66628 L
s
1 .001 0 r
.78717 .59076 m
.78719 .59072 L
s
1 .01 0 r
.53163 .66638 m
.53154 .66645 L
s
.53161 .66628 m
.53163 .66638 L
s
1 .001 0 r
.78718 .59072 m
.78719 .59073 L
s
.78717 .59072 m
.78718 .59072 L
s
.78718 .59072 m
.78719 .59072 L
s
.78719 .59073 m
.78718 .59073 L
s
.78719 .59072 m
.78719 .59073 L
s
.78718 .59073 m
.78717 .59072 L
s
.78717 .59072 m
.78719 .59072 L
s
.78719 .59072 m
.78718 .59073 L
s
1 .01 0 r
.53154 .66645 m
.53144 .66632 L
s
.53144 .66632 m
.53161 .66628 L
s
.53161 .66628 m
.53154 .66645 L
s
1 .002 0 r
.58393 .54015 m
.58398 .54007 L
s
.58397 .54007 m
.58399 .54009 L
s
.58395 .54008 m
.58397 .54007 L
s
.58397 .54007 m
.58398 .54007 L
s
.58399 .54009 m
.58397 .5401 L
s
.58398 .54007 m
.58399 .54009 L
s
.58397 .5401 m
.58395 .54008 L
s
.58395 .54008 m
.58398 .54007 L
s
.58398 .54007 m
.58397 .5401 L
s
.88207 .74172 m
.88213 .74164 L
s
1 .008 0 r
.38067 .48954 m
.38089 .48921 L
s
1 .002 0 r
.88212 .74164 m
.88214 .74166 L
s
.8821 .74165 m
.88212 .74164 L
s
.88212 .74164 m
.88213 .74164 L
s
.88214 .74166 m
.88212 .74168 L
s
.88213 .74164 m
.88214 .74166 L
s
.88212 .74168 m
.8821 .74165 L
s
.8821 .74165 m
.88213 .74164 L
s
.88213 .74164 m
.88212 .74168 L
s
1 0 0 r
.83992 .46423 m
.83992 .46423 L
s
.83992 .46423 m
.83992 .46423 L
s
.83992 .46423 m
.83992 .46423 L
s
.83992 .46423 m
.83992 .46423 L
s
.83992 .46423 m
.83992 .46423 L
s
.83992 .46423 m
.83992 .46423 L
s
.83992 .46423 m
.83992 .46423 L
s
.83992 .46423 m
.83992 .46423 L
s
.83992 .46423 m
.83992 .46423 L
s
1 .005 0 r
.67881 .69112 m
.67895 .69095 L
s
1 .008 0 r
.38085 .48921 m
.38093 .4893 L
s
.38077 .48925 m
.38085 .48921 L
s
.38085 .48921 m
.38089 .48921 L
s
.38093 .4893 m
.38085 .48934 L
s
.38089 .48921 m
.38093 .4893 L
s
1 0 0 r
.63665 .4136 m
.63665 .4136 L
s
.63665 .4136 m
.63665 .4136 L
s
.63665 .4136 m
.63665 .4136 L
s
.63665 .4136 m
.63665 .4136 L
s
.63665 .4136 m
.63665 .4136 L
s
.63665 .4136 m
.63665 .4136 L
s
.63665 .4136 m
.63665 .4136 L
s
.63665 .4136 m
.63665 .4136 L
s
.63665 .4136 m
.63665 .4136 L
s
1 .081 0 r
.23757 .46404 m
.237 .46428 L
s
.2371 .46292 m
.23757 .46404 L
s
.23801 .46321 m
.23757 .46404 L
s
1 .008 0 r
.38085 .48934 m
.38077 .48925 L
s
.38077 .48925 m
.38089 .48921 L
s
.38089 .48921 m
.38085 .48934 L
s
1 .005 0 r
.67892 .69095 m
.67897 .691 L
s
.67888 .69098 m
.67892 .69095 L
s
.67892 .69095 m
.67895 .69095 L
s
.67897 .691 m
.67893 .69103 L
s
.67895 .69095 m
.67897 .691 L
s
1 .043 0 r
.33013 .61532 m
.3298 .6155 L
s
.32983 .61476 m
.33013 .61532 L
s
.33027 .6149 m
.33013 .61532 L
s
.3295 .61494 m
.32983 .61476 L
s
.32983 .61476 m
.33027 .6149 L
s
1 .005 0 r
.67893 .69103 m
.67888 .69098 L
s
.67888 .69098 m
.67895 .69095 L
s
1 .081 0 r
.23654 .46316 m
.2371 .46292 L
s
.2371 .46292 m
.23801 .46321 L
s
1 .005 0 r
.67895 .69095 m
.67893 .69103 L
s
1 .014 0 r
.47552 .64051 m
.47604 .64003 L
s
1 .001 0 r
.93485 .61521 m
.93487 .61518 L
s
.93486 .61518 m
.93487 .61519 L
s
.93486 .61519 m
.93486 .61518 L
s
.93486 .61518 m
.93487 .61518 L
s
.93487 .61519 m
.93486 .61519 L
s
.93487 .61518 m
.93487 .61519 L
s
.93486 .61519 m
.93486 .61519 L
s
.93486 .61519 m
.93487 .61518 L
s
.93487 .61518 m
.93486 .61519 L
s
1 .067 0 r
.27219 .5899 m
.27623 .58849 L
s
1 .001 0 r
.73156 .56459 m
.73158 .56455 L
s
.73157 .56455 m
.73158 .56456 L
s
.73156 .56455 m
.73157 .56455 L
s
.73157 .56455 m
.73158 .56455 L
s
.73158 .56456 m
.73157 .56456 L
s
.73158 .56455 m
.73158 .56456 L
s
.73157 .56456 m
.73156 .56455 L
s
.73156 .56455 m
.73158 .56455 L
s
.73158 .56455 m
.73157 .56456 L
s
1 .014 0 r
.47593 .64001 m
.47606 .64017 L
s
.47581 .64009 m
.47593 .64001 L
s
.47593 .64001 m
.47604 .64003 L
s
.47606 .64017 m
.47593 .64025 L
s
.47604 .64003 m
.47606 .64017 L
s
1 .043 0 r
.3298 .6155 m
.3295 .61494 L
s
.33027 .6149 m
.3298 .6155 L
s
.3295 .61494 m
.33027 .6149 L
s
1 .002 0 r
.52823 .51396 m
.52827 .51387 L
s
1 .014 0 r
.47593 .64025 m
.47581 .64009 L
s
.47581 .64009 m
.47604 .64003 L
s
.47604 .64003 m
.47593 .64025 L
s
1 .002 0 r
.52826 .51386 m
.52828 .51389 L
s
.52824 .51388 m
.52826 .51386 L
s
.52826 .51386 m
.52827 .51387 L
s
.52828 .51389 m
.52826 .5139 L
s
.52827 .51387 m
.52828 .51389 L
s
.52826 .5139 m
.52824 .51388 L
s
.52824 .51388 m
.52827 .51387 L
s
1 .037 0 r
.36705 .74093 m
.36915 .74005 L
s
1 .002 0 r
.52827 .51387 m
.52826 .5139 L
s
.82649 .71562 m
.82657 .71553 L
s
1 .013 0 r
.32486 .46332 m
.32524 .46282 L
s
1 .002 0 r
.82655 .71552 m
.82657 .71555 L
s
.82653 .71554 m
.82655 .71552 L
s
.82655 .71552 m
.82657 .71553 L
s
.82657 .71555 m
.82655 .71557 L
s
.82657 .71553 m
.82657 .71555 L
s
.82655 .71557 m
.82653 .71554 L
s
.82653 .71554 m
.82657 .71553 L
s
.82657 .71553 m
.82655 .71557 L
s
1 0 0 r
.78433 .43799 m
.78433 .43799 L
s
.78433 .43799 m
.78433 .43799 L
s
.78433 .43799 m
.78433 .43799 L
s
.78433 .43799 m
.78433 .43799 L
s
.78433 .43799 m
.78433 .43799 L
s
.78433 .43799 m
.78433 .43799 L
s
.78433 .43799 m
.78433 .43799 L
s
.78433 .43799 m
.78433 .43799 L
s
.78433 .43799 m
.78433 .43799 L
s
1 .081 0 r
.237 .46428 m
.23654 .46316 L
s
.23801 .46321 m
.237 .46428 L
s
.23654 .46316 m
.23801 .46321 L
s
1 .006 0 r
.62314 .66499 m
.62331 .66479 L
s
1 0 0 r
.58096 .38734 m
.58096 .38734 L
s
.58096 .38734 m
.58096 .38734 L
s
.58096 .38734 m
.58096 .38734 L
s
.58096 .38734 m
.58096 .38734 L
s
.58096 .38734 m
.58096 .38734 L
s
.58096 .38734 m
.58096 .38734 L
s
.58096 .38734 m
.58096 .38734 L
s
.58096 .38734 m
.58096 .38734 L
s
.58096 .38734 m
.58096 .38734 L
s
1 .006 0 r
.62327 .66478 m
.62333 .66484 L
s
.62322 .66482 m
.62327 .66478 L
s
.62327 .66478 m
.62331 .66479 L
s
1 .013 0 r
.32517 .46281 m
.32528 .46295 L
s
.32504 .46288 m
.32517 .46281 L
s
.32517 .46281 m
.32524 .46282 L
s
1 .006 0 r
.62333 .66484 m
.62328 .66488 L
s
.62331 .66479 m
.62333 .66484 L
s
1 .02 0 r
.41975 .61436 m
.42052 .61369 L
s
1 .013 0 r
.32528 .46295 m
.32516 .46302 L
s
.32524 .46282 m
.32528 .46295 L
s
1 .006 0 r
.62328 .66488 m
.62322 .66482 L
s
.62322 .66482 m
.62331 .66479 L
s
1 .067 0 r
.27582 .58911 m
.27538 .58934 L
s
.27546 .5882 m
.27582 .58911 L
s
.27623 .58849 m
.27582 .58911 L
s
1 .006 0 r
.62331 .66479 m
.62328 .66488 L
s
1 .067 0 r
.27502 .58843 m
.27546 .5882 L
s
.27546 .5882 m
.27623 .58849 L
s
1 .013 0 r
.32516 .46302 m
.32504 .46288 L
s
.32504 .46288 m
.32524 .46282 L
s
1 .001 0 r
.87929 .58904 m
.8793 .58902 L
s
1 .013 0 r
.32524 .46282 m
.32516 .46302 L
s
1 .001 0 r
.8793 .58902 m
.87931 .58902 L
s
.8793 .58902 m
.8793 .58902 L
s
.8793 .58902 m
.8793 .58902 L
s
.87931 .58902 m
.8793 .58903 L
s
.8793 .58902 m
.87931 .58902 L
s
.8793 .58903 m
.8793 .58902 L
s
.8793 .58902 m
.8793 .58902 L
s
.8793 .58902 m
.8793 .58903 L
s
1 .037 0 r
.36898 .74039 m
.36872 .74056 L
s
.36874 .73989 m
.36898 .74039 L
s
.36915 .74005 m
.36898 .74039 L
s
.36848 .74006 m
.36874 .73989 L
s
.36874 .73989 m
.36915 .74005 L
s
1 .001 0 r
.6759 .53839 m
.67591 .53835 L
s
.67591 .53835 m
.67592 .53836 L
s
.6759 .53836 m
.67591 .53835 L
s
.67591 .53835 m
.67591 .53835 L
s
.67592 .53836 m
.67591 .53837 L
s
.67591 .53835 m
.67592 .53836 L
s
.67591 .53837 m
.6759 .53836 L
s
.6759 .53836 m
.67591 .53835 L
s
.67591 .53835 m
.67591 .53837 L
s
.97429 .74013 m
.97433 .74008 L
s
1 .002 0 r
.47247 .48774 m
.47251 .48764 L
s
1 .02 0 r
.42037 .61366 m
.42054 .61389 L
s
.42019 .61376 m
.42037 .61366 L
s
.42037 .61366 m
.42052 .61369 L
s
1 .001 0 r
.97432 .74008 m
.97434 .74009 L
s
.97431 .74009 m
.97432 .74008 L
s
.97432 .74008 m
.97433 .74008 L
s
.97434 .74009 m
.97433 .7401 L
s
.97433 .74008 m
.97434 .74009 L
s
1 .02 0 r
.42054 .61389 m
.42036 .614 L
s
.42052 .61369 m
.42054 .61389 L
s
1 .001 0 r
.97433 .7401 m
.97431 .74009 L
s
.97431 .74009 m
.97433 .74008 L
s
.97433 .74008 m
.97433 .7401 L
s
1 .037 0 r
.36872 .74056 m
.36848 .74006 L
s
.36915 .74005 m
.36872 .74056 L
s
1 .002 0 r
.4725 .48764 m
.47253 .48766 L
s
.47248 .48765 m
.4725 .48764 L
s
.4725 .48764 m
.47251 .48764 L
s
.47253 .48766 m
.4725 .48768 L
s
.47251 .48764 m
.47253 .48766 L
s
1 .037 0 r
.36848 .74006 m
.36915 .74005 L
s
1 .05 0 r
.31121 .71481 m
.31431 .71383 L
s
1 .002 0 r
.4725 .48768 m
.47248 .48765 L
s
.47248 .48765 m
.47251 .48764 L
s
.47251 .48764 m
.4725 .48768 L
s
1 .003 0 r
.77087 .68949 m
.77095 .68939 L
s
1 .02 0 r
.42036 .614 m
.42019 .61376 L
s
.42019 .61376 m
.42052 .61369 L
s
1 .025 0 r
.269 .43707 m
.26989 .43615 L
s
1 .02 0 r
.42052 .61369 m
.42036 .614 L
s
1 .067 0 r
.27623 .58849 m
.27538 .58934 L
s
.27502 .58843 m
.27623 .58849 L
s
.27538 .58934 m
.27502 .58843 L
s
1 .003 0 r
.77093 .68938 m
.77096 .68941 L
s
.7709 .6894 m
.77093 .68938 L
s
.77093 .68938 m
.77095 .68939 L
s
.77096 .68941 m
.77093 .68943 L
s
.77095 .68939 m
.77096 .68941 L
s
.77093 .68943 m
.7709 .6894 L
s
.7709 .6894 m
.77095 .68939 L
s
1 0 0 r
.72868 .41174 m
.72868 .41174 L
s
.72868 .41174 m
.72868 .41174 L
s
.72868 .41174 m
.72868 .41174 L
s
.72868 .41174 m
.72868 .41174 L
s
.72868 .41174 m
.72868 .41174 L
s
.72868 .41174 m
.72868 .41174 L
s
.72868 .41174 m
.72868 .41174 L
s
.72868 .41174 m
.72868 .41174 L
s
.72868 .41174 m
.72868 .41174 L
s
1 .003 0 r
.77095 .68939 m
.77093 .68943 L
s
1 .007 0 r
.56741 .63884 m
.56763 .63858 L
s
1 .03 0 r
.36392 .58818 m
.36521 .58721 L
s
1 .007 0 r
.56758 .63857 m
.56765 .63865 L
s
.56752 .63862 m
.56758 .63857 L
s
.56758 .63857 m
.56763 .63858 L
s
.56765 .63865 m
.56758 .63869 L
s
.56763 .63858 m
.56765 .63865 L
s
.56758 .63869 m
.56752 .63862 L
s
.56752 .63862 m
.56763 .63858 L
s
.56763 .63858 m
.56758 .63869 L
s
1 .001 0 r
.82368 .56285 m
.82369 .56282 L
s
.82369 .56282 m
.82369 .56283 L
s
.82368 .56283 m
.82369 .56282 L
s
.82369 .56282 m
.82369 .56282 L
s
.82369 .56283 m
.82369 .56283 L
s
.82369 .56282 m
.82369 .56283 L
s
.82369 .56283 m
.82368 .56283 L
s
.82368 .56283 m
.82369 .56282 L
s
.82369 .56282 m
.82369 .56283 L
s
1 .05 0 r
.31398 .71427 m
.31366 .71448 L
s
.31371 .71358 m
.31398 .71427 L
s
.31431 .71383 m
.31398 .71427 L
s
.3134 .71378 m
.31371 .71358 L
s
.31371 .71358 m
.31431 .71383 L
s
1 .025 0 r
.26972 .43613 m
.26994 .43642 L
s
.26948 .43624 m
.26972 .43613 L
s
.26972 .43613 m
.26989 .43615 L
s
1 .001 0 r
.62018 .51217 m
.6202 .51213 L
s
1 .025 0 r
.26994 .43642 m
.2697 .43654 L
s
.26989 .43615 m
.26994 .43642 L
s
1 .001 0 r
.6202 .51213 m
.62021 .51214 L
s
.62019 .51214 m
.6202 .51213 L
s
.6202 .51213 m
.6202 .51213 L
s
.62021 .51214 m
.6202 .51215 L
s
.6202 .51213 m
.62021 .51214 L
s
.6202 .51215 m
.62019 .51214 L
s
.62019 .51214 m
.6202 .51213 L
s
.6202 .51213 m
.6202 .51215 L
s
1 .023 0 r
.45887 .73934 m
.45993 .73867 L
s
1 .002 0 r
.91871 .71401 m
.91876 .71395 L
s
1 .025 0 r
.2697 .43654 m
.26948 .43624 L
s
.26948 .43624 m
.26989 .43615 L
s
1 .003 0 r
.41665 .46149 m
.4167 .46138 L
s
1 .025 0 r
.26989 .43615 m
.2697 .43654 L
s
1 .002 0 r
.91875 .71395 m
.91876 .71396 L
s
.91873 .71396 m
.91875 .71395 L
s
.91875 .71395 m
.91876 .71395 L
s
.91876 .71396 m
.91875 .71397 L
s
.91876 .71395 m
.91876 .71396 L
s
.91875 .71397 m
.91873 .71396 L
s
.91873 .71396 m
.91876 .71395 L
s
.91876 .71395 m
.91875 .71397 L
s
1 .003 0 r
.41669 .46138 m
.41672 .46141 L
s
.41667 .4614 m
.41669 .46138 L
s
.41669 .46138 m
.4167 .46138 L
s
.41672 .46141 m
.41669 .46143 L
s
.4167 .46138 m
.41672 .46141 L
s
1 0 0 r
.87651 .43615 m
.87651 .43615 L
s
.87651 .43615 m
.87651 .43615 L
s
.87651 .43615 m
.87651 .43615 L
s
.87651 .43615 m
.87651 .43615 L
s
.87651 .43615 m
.87651 .43615 L
s
.87651 .43615 m
.87651 .43615 L
s
.87651 .43615 m
.87651 .43615 L
s
.87651 .43615 m
.87651 .43615 L
s
.87651 .43615 m
.87651 .43615 L
s
1 .003 0 r
.41669 .46143 m
.41667 .4614 L
s
.41667 .4614 m
.4167 .46138 L
s
.4167 .46138 m
.41669 .46143 L
s
.71519 .66334 m
.71528 .66322 L
s
1 .078 0 r
.21309 .4108 m
.21747 .40873 L
s
1 .05 0 r
.31431 .71383 m
.31366 .71448 L
s
.3134 .71378 m
.31431 .71383 L
s
.31366 .71448 m
.3134 .71378 L
s
1 .03 0 r
.36496 .58715 m
.3652 .58752 L
s
.3647 .58729 m
.36496 .58715 L
s
.36496 .58715 m
.36521 .58721 L
s
.3652 .58752 m
.36494 .58766 L
s
.36521 .58721 m
.3652 .58752 L
s
1 .003 0 r
.71526 .66322 m
.71529 .66325 L
s
.71523 .66324 m
.71526 .66322 L
s
.71526 .66322 m
.71528 .66322 L
s
.71529 .66325 m
.71526 .66327 L
s
.71528 .66322 m
.71529 .66325 L
s
1 0 0 r
.67298 .38545 m
.67298 .38545 L
s
.67298 .38545 m
.67298 .38545 L
s
.67298 .38545 m
.67298 .38545 L
s
.67298 .38545 m
.67298 .38545 L
s
.67298 .38545 m
.67298 .38545 L
s
.67298 .38545 m
.67298 .38545 L
s
.67298 .38545 m
.67298 .38545 L
s
.67298 .38545 m
.67298 .38545 L
s
.67298 .38545 m
.67298 .38545 L
s
1 .003 0 r
.71526 .66327 m
.71523 .66324 L
s
.71523 .66324 m
.71528 .66322 L
s
.71528 .66322 m
.71526 .66327 L
s
1 .009 0 r
.51163 .61266 m
.51192 .61233 L
s
1 .023 0 r
.45972 .7386 m
.4599 .73889 L
s
.45953 .73872 m
.45972 .7386 L
s
.45972 .7386 m
.45993 .73867 L
s
.4599 .73889 m
.45971 .73901 L
s
.45993 .73867 m
.4599 .73889 L
s
1 .03 0 r
.36494 .58766 m
.3647 .58729 L
s
.3647 .58729 m
.36521 .58721 L
s
.36521 .58721 m
.36494 .58766 L
s
1 .049 0 r
.30804 .56198 m
.31049 .56053 L
s
1 .009 0 r
.51186 .61232 m
.51194 .61242 L
s
.51177 .61237 m
.51186 .61232 L
s
.51186 .61232 m
.51192 .61233 L
s
1 .023 0 r
.45971 .73901 m
.45953 .73872 L
s
.45953 .73872 m
.45993 .73867 L
s
.45993 .73867 m
.45971 .73901 L
s
1 .009 0 r
.51194 .61242 m
.51186 .61247 L
s
.51192 .61233 m
.51194 .61242 L
s
1 .001 0 r
.76801 .53663 m
.76802 .53661 L
s
.76802 .53661 m
.76803 .53661 L
s
.76802 .53661 m
.76802 .53661 L
s
.76802 .53661 m
.76802 .53661 L
s
.76803 .53661 m
.76802 .53662 L
s
.76802 .53661 m
.76803 .53661 L
s
.76802 .53662 m
.76802 .53661 L
s
.76802 .53661 m
.76802 .53661 L
s
.76802 .53661 m
.76802 .53662 L
s
1 .009 0 r
.51186 .61247 m
.51177 .61237 L
s
.51177 .61237 m
.51192 .61233 L
s
.51192 .61233 m
.51186 .61247 L
s
1 .001 0 r
.56442 .48593 m
.56443 .48589 L
s
.56443 .48589 m
.56444 .4859 L
s
.56442 .4859 m
.56443 .48589 L
s
.56443 .48589 m
.56443 .48589 L
s
.56444 .4859 m
.56443 .48591 L
s
.56443 .48589 m
.56444 .4859 L
s
.56443 .48591 m
.56442 .4859 L
s
.56442 .4859 m
.56443 .48589 L
s
.56443 .48589 m
.56443 .48591 L
s
1 .031 0 r
.40303 .7132 m
.40457 .71234 L
s
1 .002 0 r
.86308 .68786 m
.86313 .68779 L
s
1 .003 0 r
.36079 .43522 m
.36084 .43511 L
s
1 .002 0 r
.86312 .68779 m
.86314 .68781 L
s
.8631 .6878 m
.86312 .68779 L
s
.86312 .68779 m
.86313 .68779 L
s
.86314 .68781 m
.86312 .68782 L
s
.86313 .68779 m
.86314 .68781 L
s
.86312 .68782 m
.8631 .6878 L
s
.8631 .6878 m
.86313 .68779 L
s
.86313 .68779 m
.86312 .68782 L
s
1 .003 0 r
.36083 .43511 m
.36085 .43514 L
s
.3608 .43513 m
.36083 .43511 L
s
.36083 .43511 m
.36084 .43511 L
s
.36085 .43514 m
.36082 .43515 L
s
.36084 .43511 m
.36085 .43514 L
s
1 0 0 r
.82086 .40987 m
.82086 .40987 L
s
.82086 .40987 m
.82086 .40987 L
s
.82086 .40987 m
.82086 .40987 L
s
.82086 .40987 m
.82086 .40987 L
s
.82086 .40987 m
.82086 .40987 L
s
.82086 .40987 m
.82086 .40987 L
s
.82086 .40987 m
.82086 .40987 L
s
.82086 .40987 m
.82086 .40987 L
s
.82086 .40987 m
.82086 .40987 L
s
1 .003 0 r
.36082 .43515 m
.3608 .43513 L
s
.3608 .43513 m
.36084 .43511 L
s
.36084 .43511 m
.36082 .43515 L
s
1 .004 0 r
.65946 .63716 m
.65956 .63702 L
s
.65954 .63702 m
.65958 .63706 L
s
.6595 .63704 m
.65954 .63702 L
s
.65954 .63702 m
.65956 .63702 L
s
.65958 .63706 m
.65954 .63708 L
s
.65956 .63702 m
.65958 .63706 L
s
.65954 .63708 m
.6595 .63704 L
s
.6595 .63704 m
.65956 .63702 L
s
.65956 .63702 m
.65954 .63708 L
s
1 .012 0 r
.4558 .58646 m
.4562 .58601 L
s
1 .078 0 r
.21713 .40956 m
.21654 .40979 L
s
.21665 .4085 m
.21713 .40956 L
s
.21747 .40873 m
.21713 .40956 L
s
.21606 .40873 m
.21665 .4085 L
s
.21665 .4085 m
.21747 .40873 L
s
1 0 0 r
.91596 .5611 m
.91596 .56109 L
s
.91596 .56109 m
.91597 .56109 L
s
.91596 .56109 m
.91596 .56109 L
s
.91596 .56109 m
.91596 .56109 L
s
.91597 .56109 m
.91596 .5611 L
s
.91596 .56109 m
.91597 .56109 L
s
.91596 .5611 m
.91596 .56109 L
s
.91596 .56109 m
.91596 .56109 L
s
.91596 .56109 m
.91596 .5611 L
s
1 .049 0 r
.31002 .5604 m
.31038 .56104 L
s
.30962 .56061 m
.31002 .5604 L
s
.31002 .5604 m
.31049 .56053 L
s
.31038 .56104 m
.30997 .56124 L
s
.31049 .56053 m
.31038 .56104 L
s
1 .031 0 r
.40427 .71224 m
.4045 .71264 L
s
.40402 .71239 m
.40427 .71224 L
s
.40427 .71224 m
.40457 .71234 L
s
.4045 .71264 m
.40425 .71279 L
s
.40457 .71234 m
.4045 .71264 L
s
1 .088 0 r
.25211 .53575 m
.25738 .5338 L
s
1 0 0 r
.7123 .51039 m
.7123 .51037 L
s
.7123 .51037 m
.71231 .51037 L
s
.7123 .51037 m
.7123 .51037 L
s
.7123 .51037 m
.7123 .51037 L
s
.71231 .51037 m
.7123 .51038 L
s
.7123 .51037 m
.71231 .51037 L
s
.7123 .51038 m
.7123 .51037 L
s
.7123 .51037 m
.7123 .51037 L
s
.7123 .51037 m
.7123 .51038 L
s
1 .012 0 r
.45612 .58599 m
.45624 .58613 L
s
.45601 .58606 m
.45612 .58599 L
s
.45612 .58599 m
.4562 .58601 L
s
.45624 .58613 m
.45612 .5862 L
s
.4562 .58601 m
.45624 .58613 L
s
1 .013 0 r
.55085 .73775 m
.55137 .73731 L
s
1 .012 0 r
.45612 .5862 m
.45601 .58606 L
s
.45601 .58606 m
.4562 .58601 L
s
.4562 .58601 m
.45612 .5862 L
s
1 .031 0 r
.40425 .71279 m
.40402 .71239 L
s
.40402 .71239 m
.40457 .71234 L
s
.40457 .71234 m
.40425 .71279 L
s
1 .001 0 r
.5086 .45966 m
.50861 .45963 L
s
.50861 .45963 m
.50862 .45964 L
s
.5086 .45964 m
.50861 .45963 L
s
.50861 .45963 m
.50861 .45963 L
s
.50862 .45964 m
.50861 .45964 L
s
.50861 .45963 m
.50862 .45964 L
s
.50861 .45964 m
.5086 .45964 L
s
.5086 .45964 m
.50861 .45963 L
s
.50861 .45963 m
.50861 .45964 L
s
1 .043 0 r
.34713 .68704 m
.3495 .68596 L
s
1 .049 0 r
.30997 .56124 m
.30962 .56061 L
s
.30962 .56061 m
.31049 .56053 L
s
.31049 .56053 m
.30997 .56124 L
s
1 .002 0 r
.8074 .66168 m
.80745 .66161 L
s
.30487 .40893 m
.30491 .40883 L
s
.80744 .66161 m
.80746 .66163 L
s
.80742 .66162 m
.80744 .66161 L
s
.80744 .66161 m
.80745 .66161 L
s
1 .013 0 r
.55127 .73728 m
.55139 .73744 L
s
.55115 .73736 m
.55127 .73728 L
s
.55127 .73728 m
.55137 .73731 L
s
1 .002 0 r
.80746 .66163 m
.80744 .66164 L
s
.80745 .66161 m
.80746 .66163 L
s
.80744 .66164 m
.80742 .66162 L
s
.80742 .66162 m
.80745 .66161 L
s
.80745 .66161 m
.80744 .66164 L
s
.3049 .40883 m
.30492 .40885 L
s
.30488 .40885 m
.3049 .40883 L
s
.3049 .40883 m
.30491 .40883 L
s
1 .013 0 r
.55139 .73744 m
.55127 .73752 L
s
.55137 .73731 m
.55139 .73744 L
s
1 .002 0 r
.30492 .40885 m
.3049 .40887 L
s
.30491 .40883 m
.30492 .40885 L
s
.3049 .40887 m
.30488 .40885 L
s
.30488 .40885 m
.30491 .40883 L
s
.30491 .40883 m
.3049 .40887 L
s
1 0 0 r
.76516 .38356 m
.76516 .38356 L
s
.76516 .38356 m
.76516 .38356 L
s
.76516 .38356 m
.76516 .38356 L
s
.76516 .38356 m
.76516 .38356 L
s
.76516 .38356 m
.76516 .38356 L
s
.76516 .38356 m
.76516 .38356 L
s
.76516 .38356 m
.76516 .38356 L
s
.76516 .38356 m
.76516 .38356 L
s
.76516 .38356 m
.76516 .38356 L
s
1 .078 0 r
.21654 .40979 m
.21606 .40873 L
s
.21747 .40873 m
.21654 .40979 L
s
1 .013 0 r
.55127 .73752 m
.55115 .73736 L
s
.55115 .73736 m
.55137 .73731 L
s
.55137 .73731 m
.55127 .73752 L
s
1 .004 0 r
.60368 .61096 m
.6038 .61079 L
s
1 .078 0 r
.21606 .40873 m
.21747 .40873 L
s
1 .004 0 r
.60377 .61079 m
.60381 .61083 L
s
.60373 .61082 m
.60377 .61079 L
s
.60377 .61079 m
.6038 .61079 L
s
.60381 .61083 m
.60377 .61086 L
s
.6038 .61079 m
.60381 .61083 L
s
.60377 .61086 m
.60373 .61082 L
s
.60373 .61082 m
.6038 .61079 L
s
.6038 .61079 m
.60377 .61086 L
s
1 .018 0 r
.39992 .56023 m
.40054 .55958 L
s
1 0 0 r
.86029 .53486 m
.86029 .53485 L
s
.86029 .53485 m
.8603 .53485 L
s
.86029 .53485 m
.86029 .53485 L
s
.86029 .53485 m
.86029 .53485 L
s
.8603 .53485 m
.86029 .53486 L
s
.86029 .53485 m
.8603 .53485 L
s
.86029 .53486 m
.86029 .53485 L
s
.86029 .53485 m
.86029 .53485 L
s
.86029 .53485 m
.86029 .53486 L
s
.65653 .48412 m
.65653 .4841 L
s
.65653 .48411 m
.65654 .48411 L
s
.65653 .48411 m
.65653 .48411 L
s
.65653 .48411 m
.65653 .4841 L
s
.65654 .48411 m
.65653 .48411 L
s
.65653 .4841 m
.65654 .48411 L
s
1 .043 0 r
.34933 .68636 m
.34901 .68656 L
s
.34904 .68579 m
.34933 .68636 L
s
.3495 .68596 m
.34933 .68636 L
s
1 0 0 r
.65653 .48411 m
.65653 .48411 L
s
.65653 .48411 m
.65653 .4841 L
s
.65653 .4841 m
.65653 .48411 L
s
1 .043 0 r
.34872 .68598 m
.34904 .68579 L
s
.34904 .68579 m
.3495 .68596 L
s
1 .088 0 r
.25686 .53465 m
.25628 .53494 L
s
.25638 .53344 m
.25686 .53465 L
s
.25738 .5338 m
.25686 .53465 L
s
1 .017 0 r
.495 .71159 m
.49572 .71102 L
s
1 .088 0 r
.25579 .53373 m
.25638 .53344 L
s
.25638 .53344 m
.25738 .5338 L
s
1 .001 0 r
.95545 .68622 m
.95548 .68618 L
s
.45273 .43337 m
.45274 .43335 L
s
1 .018 0 r
.40042 .55955 m
.40058 .55976 L
s
.40025 .55965 m
.40042 .55955 L
s
.40042 .55955 m
.40054 .55958 L
s
1 .001 0 r
.45274 .43335 m
.45274 .43335 L
s
.45273 .43335 m
.45274 .43335 L
s
.45274 .43335 m
.45274 .43335 L
s
.45274 .43335 m
.45274 .43336 L
s
.45274 .43335 m
.45274 .43335 L
s
.45274 .43336 m
.45273 .43335 L
s
.45273 .43335 m
.45274 .43335 L
s
.45274 .43335 m
.45274 .43336 L
s
.95547 .68618 m
.95549 .68619 L
s
.95546 .68618 m
.95547 .68618 L
s
.95547 .68618 m
.95548 .68618 L
s
.95549 .68619 m
.95548 .6862 L
s
.95548 .68618 m
.95549 .68619 L
s
1 .018 0 r
.40058 .55976 m
.40041 .55986 L
s
.40054 .55958 m
.40058 .55976 L
s
1 .001 0 r
.95548 .6862 m
.95546 .68618 L
s
.95546 .68618 m
.95548 .68618 L
s
.95548 .68618 m
.95548 .6862 L
s
1 .061 0 r
.29119 .66085 m
.29495 .65961 L
s
1 .018 0 r
.40041 .55986 m
.40025 .55965 L
s
.40025 .55965 m
.40054 .55958 L
s
.40054 .55958 m
.40041 .55986 L
s
1 .002 0 r
.75167 .63548 m
.75172 .6354 L
s
1 0 0 r
.2489 .38261 m
.24891 .3826 L
s
.24891 .3826 m
.24891 .3826 L
s
.2489 .3826 m
.24891 .3826 L
s
.24891 .3826 m
.24891 .3826 L
s
.24891 .3826 m
.24891 .3826 L
s
.24891 .3826 m
.24891 .3826 L
s
.24891 .3826 m
.2489 .3826 L
s
.2489 .3826 m
.24891 .3826 L
s
.24891 .3826 m
.24891 .3826 L
s
1 .002 0 r
.75171 .6354 m
.75173 .63542 L
s
.75169 .63541 m
.75171 .6354 L
s
.75171 .6354 m
.75172 .6354 L
s
.75173 .63542 m
.75171 .63544 L
s
.75172 .6354 m
.75173 .63542 L
s
1 .043 0 r
.34901 .68656 m
.34872 .68598 L
s
.3495 .68596 m
.34901 .68656 L
s
1 .002 0 r
.75171 .63544 m
.75169 .63541 L
s
.75169 .63541 m
.75172 .6354 L
s
1 .043 0 r
.34872 .68598 m
.3495 .68596 L
s
1 .002 0 r
.75172 .6354 m
.75171 .63544 L
s
1 .017 0 r
.49558 .71098 m
.49573 .71119 L
s
.49542 .71108 m
.49558 .71098 L
s
.49558 .71098 m
.49572 .71102 L
s
.49573 .71119 m
.49557 .71129 L
s
.49572 .71102 m
.49573 .71119 L
s
1 .005 0 r
.54784 .58474 m
.54799 .58453 L
s
1 .017 0 r
.49557 .71129 m
.49542 .71108 L
s
.49542 .71108 m
.49572 .71102 L
s
.49572 .71102 m
.49557 .71129 L
s
1 .005 0 r
.54796 .58452 m
.54801 .58458 L
s
.54791 .58456 m
.54796 .58452 L
s
.54796 .58452 m
.54799 .58453 L
s
.54801 .58458 m
.54796 .58461 L
s
.54799 .58453 m
.54801 .58458 L
s
1 .029 0 r
.34399 .53398 m
.3451 .53294 L
s
1 .005 0 r
.54796 .58461 m
.54791 .58456 L
s
.54791 .58456 m
.54799 .58453 L
s
.54799 .58453 m
.54796 .58461 L
s
1 0 0 r
.80457 .5086 m
.80457 .50859 L
s
.80457 .50859 m
.80457 .50859 L
s
.80457 .50859 m
.80457 .50859 L
s
.80457 .50859 m
.80457 .50859 L
s
.80457 .50859 m
.80457 .50859 L
s
.80457 .50859 m
.80457 .50859 L
s
.80457 .50859 m
.80457 .50859 L
s
.80457 .50859 m
.80457 .50859 L
s
.80457 .50859 m
.80457 .50859 L
s
1 .008 0 r
.64299 .73615 m
.64326 .73588 L
s
1 .088 0 r
.25738 .5338 m
.25628 .53494 L
s
.25579 .53373 m
.25738 .5338 L
s
.25628 .53494 m
.25579 .53373 L
s
1 0 0 r
.60071 .45783 m
.60071 .45782 L
s
.60071 .45782 m
.60071 .45782 L
s
.60071 .45782 m
.60071 .45782 L
s
.60071 .45782 m
.60071 .45782 L
s
.60071 .45782 m
.60071 .45782 L
s
.60071 .45782 m
.60071 .45782 L
s
.60071 .45782 m
.60071 .45782 L
s
.60071 .45782 m
.60071 .45782 L
s
.60071 .45782 m
.60071 .45782 L
s
1 .061 0 r
.29455 .66017 m
.29416 .6604 L
s
.29423 .65932 m
.29455 .66017 L
s
.29495 .65961 m
.29455 .66017 L
s
.29383 .65955 m
.29423 .65932 L
s
.29423 .65932 m
.29495 .65961 L
s
1 .024 0 r
.43911 .6854 m
.44014 .68465 L
s
1 .008 0 r
.6432 .73587 m
.64328 .73595 L
s
.64313 .73592 m
.6432 .73587 L
s
.6432 .73587 m
.64326 .73588 L
s
.64328 .73595 m
.64321 .736 L
s
.64326 .73588 m
.64328 .73595 L
s
.64321 .736 m
.64313 .73592 L
s
.64313 .73592 m
.64326 .73588 L
s
1 .001 0 r
.89977 .66002 m
.8998 .65998 L
s
1 .008 0 r
.64326 .73588 m
.64321 .736 L
s
1 0 0 r
.39681 .40705 m
.39681 .40704 L
s
.39681 .40704 m
.39682 .40704 L
s
.39681 .40704 m
.39681 .40704 L
s
.39681 .40704 m
.39681 .40704 L
s
.39682 .40704 m
.39681 .40705 L
s
.39681 .40704 m
.39682 .40704 L
s
.39681 .40705 m
.39681 .40704 L
s
.39681 .40704 m
.39681 .40704 L
s
.39681 .40704 m
.39681 .40705 L
s
1 .001 0 r
.89979 .65997 m
.8998 .65999 L
s
.89978 .65998 m
.89979 .65997 L
s
.89979 .65997 m
.8998 .65998 L
s
.8998 .65999 m
.89979 .66 L
s
.8998 .65998 m
.8998 .65999 L
s
.89979 .66 m
.89978 .65998 L
s
.89978 .65998 m
.8998 .65998 L
s
.8998 .65998 m
.89979 .66 L
s
1 0 0 r
.85749 .38166 m
.85749 .38166 L
s
.85749 .38166 m
.85749 .38166 L
s
.85749 .38166 m
.85749 .38166 L
s
.85749 .38166 m
.85749 .38166 L
s
.85749 .38166 m
.85749 .38166 L
s
.85749 .38166 m
.85749 .38166 L
s
.85749 .38166 m
.85749 .38166 L
s
.85749 .38166 m
.85749 .38166 L
s
.85749 .38166 m
.85749 .38166 L
s
1 .002 0 r
.69588 .60926 m
.69594 .60917 L
s
.69592 .60916 m
.69595 .60919 L
s
.6959 .60918 m
.69592 .60916 L
s
.69592 .60916 m
.69594 .60917 L
s
.69595 .60919 m
.69593 .6092 L
s
.69594 .60917 m
.69595 .60919 L
s
.69593 .6092 m
.6959 .60918 L
s
.6959 .60918 m
.69594 .60917 L
s
1 .029 0 r
.34489 .5329 m
.34514 .53325 L
s
.34461 .53305 m
.34489 .5329 L
s
.34489 .5329 m
.3451 .53294 L
s
1 .002 0 r
.69594 .60917 m
.69593 .6092 L
s
1 .029 0 r
.34514 .53325 m
.34486 .5334 L
s
.3451 .53294 m
.34514 .53325 L
s
1 .007 0 r
.49196 .55849 m
.49214 .55821 L
s
1 .061 0 r
.29495 .65961 m
.29416 .6604 L
s
.29383 .65955 m
.29495 .65961 L
s
1 .024 0 r
.43993 .68459 m
.44013 .68489 L
s
.43973 .68472 m
.43993 .68459 L
s
.43993 .68459 m
.44014 .68465 L
s
1 .061 0 r
.29416 .6604 m
.29383 .65955 L
s
1 .024 0 r
.44013 .68489 m
.43992 .68501 L
s
.44014 .68465 m
.44013 .68489 L
s
1 .029 0 r
.34486 .5334 m
.34461 .53305 L
s
.34461 .53305 m
.3451 .53294 L
s
.3451 .53294 m
.34486 .5334 L
s
1 .056 0 r
.288 .5077 m
.29051 .50589 L
s
1 .007 0 r
.4921 .55821 m
.49217 .55828 L
s
.49204 .55825 m
.4921 .55821 L
s
.4921 .55821 m
.49214 .55821 L
s
.49217 .55828 m
.4921 .55833 L
s
.49214 .55821 m
.49217 .55828 L
s
.4921 .55833 m
.49204 .55825 L
s
.49204 .55825 m
.49214 .55821 L
s
.49214 .55821 m
.4921 .55833 L
s
1 0 0 r
.74879 .48231 m
.7488 .4823 L
s
.7488 .4823 m
.7488 .4823 L
s
.74879 .4823 m
.7488 .4823 L
s
.7488 .4823 m
.7488 .4823 L
s
.7488 .4823 m
.7488 .48231 L
s
.7488 .4823 m
.7488 .4823 L
s
.7488 .48231 m
.74879 .4823 L
s
.74879 .4823 m
.7488 .4823 L
s
.7488 .4823 m
.7488 .48231 L
s
1 .024 0 r
.43992 .68501 m
.43973 .68472 L
s
.43973 .68472 m
.44014 .68465 L
s
.44014 .68465 m
.43992 .68501 L
s
1 .01 0 r
.58714 .70997 m
.58748 .70963 L
s
1 0 0 r
.54483 .43152 m
.54483 .43151 L
s
.54483 .43151 m
.54484 .43151 L
s
.54483 .43151 m
.54483 .43151 L
s
.54483 .43151 m
.54483 .43151 L
s
.54484 .43151 m
.54483 .43151 L
s
.54483 .43151 m
.54484 .43151 L
s
.54483 .43151 m
.54483 .43151 L
s
.54483 .43151 m
.54483 .43151 L
s
.54483 .43151 m
.54483 .43151 L
s
1 .034 0 r
.38315 .65919 m
.38475 .65818 L
s
1 .01 0 r
.58741 .70961 m
.5875 .70972 L
s
.58732 .70967 m
.58741 .70961 L
s
.58741 .70961 m
.58748 .70963 L
s
1 .001 0 r
.84403 .6338 m
.84406 .63375 L
s
1 .01 0 r
.5875 .70972 m
.58741 .70978 L
s
.58748 .70963 m
.5875 .70972 L
s
1 0 0 r
.34084 .38071 m
.34084 .38071 L
s
.34084 .38071 m
.34084 .38071 L
s
.34084 .38071 m
.34084 .38071 L
s
.34084 .38071 m
.34084 .38071 L
s
.34084 .38071 m
.34084 .38071 L
s
.34084 .38071 m
.34084 .38071 L
s
.34084 .38071 m
.34084 .38071 L
s
.34084 .38071 m
.34084 .38071 L
s
.34084 .38071 m
.34084 .38071 L
s
1 .001 0 r
.84405 .63375 m
.84406 .63376 L
s
.84404 .63376 m
.84405 .63375 L
s
.84405 .63375 m
.84406 .63375 L
s
.84406 .63376 m
.84405 .63377 L
s
.84406 .63375 m
.84406 .63376 L
s
.84405 .63377 m
.84404 .63376 L
s
.84404 .63376 m
.84406 .63375 L
s
.84406 .63375 m
.84405 .63377 L
s
1 .01 0 r
.58741 .70978 m
.58732 .70967 L
s
.58732 .70967 m
.58748 .70963 L
s
.58748 .70963 m
.58741 .70978 L
s
1 .003 0 r
.64004 .58301 m
.6401 .5829 L
s
.64009 .5829 m
.64012 .58293 L
s
.64006 .58292 m
.64009 .5829 L
s
.64009 .5829 m
.6401 .5829 L
s
.64012 .58293 m
.64009 .58295 L
s
.6401 .5829 m
.64012 .58293 L
s
.64009 .58295 m
.64006 .58292 L
s
.64006 .58292 m
.6401 .5829 L
s
.6401 .5829 m
.64009 .58295 L
s
1 .009 0 r
.43602 .53221 m
.43627 .53184 L
s
1 0 0 r
.89699 .50681 m
.897 .5068 L
s
.897 .5068 m
.897 .5068 L
s
.89699 .5068 m
.897 .5068 L
s
.897 .5068 m
.897 .5068 L
s
.897 .5068 m
.897 .5068 L
s
.897 .5068 m
.897 .5068 L
s
.897 .5068 m
.89699 .5068 L
s
.89699 .5068 m
.897 .5068 L
s
.897 .5068 m
.897 .5068 L
s
1 .005 0 r
.73528 .73455 m
.73543 .73438 L
s
1 .128 0 r
.23196 .4814 m
.23955 .47837 L
s
1 .009 0 r
.43622 .53184 m
.43631 .53194 L
s
.43613 .53189 m
.43622 .53184 L
s
.43622 .53184 m
.43627 .53184 L
s
1 .034 0 r
.38444 .65809 m
.3847 .65851 L
s
.38416 .65825 m
.38444 .65809 L
s
.38444 .65809 m
.38475 .65818 L
s
1 0 0 r
.69297 .456 m
.69297 .45599 L
s
.69297 .45599 m
.69297 .45599 L
s
.69297 .45599 m
.69297 .45599 L
s
.69297 .45599 m
.69297 .45599 L
s
.69297 .45599 m
.69297 .45599 L
s
.69297 .45599 m
.69297 .45599 L
s
.69297 .45599 m
.69297 .45599 L
s
.69297 .45599 m
.69297 .45599 L
s
1 .034 0 r
.3847 .65851 m
.38442 .65868 L
s
.38475 .65818 m
.3847 .65851 L
s
1 0 0 r
.69297 .45599 m
.69297 .45599 L
s
1 .009 0 r
.43631 .53194 m
.43622 .53199 L
s
.43627 .53184 m
.43631 .53194 L
s
1 .005 0 r
.7354 .73438 m
.73545 .73443 L
s
.73536 .73441 m
.7354 .73438 L
s
.7354 .73438 m
.73543 .73438 L
s
.73545 .73443 m
.7354 .73446 L
s
.73543 .73438 m
.73545 .73443 L
s
1 .009 0 r
.43622 .53199 m
.43613 .53189 L
s
.43613 .53189 m
.43627 .53184 L
s
1 .005 0 r
.7354 .73446 m
.73536 .73441 L
s
.73536 .73441 m
.73543 .73438 L
s
1 .009 0 r
.43627 .53184 m
.43622 .53199 L
s
1 .005 0 r
.73543 .73438 m
.7354 .73446 L
s
1 .013 0 r
.53123 .68376 m
.53169 .68332 L
s
1 .056 0 r
.29004 .50578 m
.29047 .50648 L
s
.28954 .50602 m
.29004 .50578 L
s
.29004 .50578 m
.29051 .50589 L
s
.29047 .50648 m
.28998 .50672 L
s
.29051 .50589 m
.29047 .50648 L
s
1 0 0 r
.48891 .40518 m
.48891 .40517 L
s
.48891 .40517 m
.48891 .40517 L
s
.48891 .40517 m
.48891 .40517 L
s
.48891 .40517 m
.48891 .40517 L
s
.48891 .40517 m
.48891 .40517 L
s
.48891 .40517 m
.48891 .40517 L
s
.48891 .40517 m
.48891 .40517 L
s
.48891 .40517 m
.48891 .40517 L
s
.48891 .40517 m
.48891 .40517 L
s
1 .051 0 r
.32715 .63296 m
.32982 .63159 L
s
1 .034 0 r
.38442 .65868 m
.38416 .65825 L
s
.38416 .65825 m
.38475 .65818 L
s
.38475 .65818 m
.38442 .65868 L
s
1 .001 0 r
.78824 .60755 m
.78827 .6075 L
s
.78826 .6075 m
.78827 .60751 L
s
.78825 .60751 m
.78826 .6075 L
s
.78826 .6075 m
.78827 .6075 L
s
.78827 .60751 m
.78826 .60752 L
s
.78827 .6075 m
.78827 .60751 L
s
.78826 .60752 m
.78825 .60751 L
s
.78825 .60751 m
.78827 .6075 L
s
.78827 .6075 m
.78826 .60752 L
s
1 .013 0 r
.53159 .6833 m
.53171 .68344 L
s
.53148 .68337 m
.53159 .6833 L
s
.53159 .6833 m
.53169 .68332 L
s
.53171 .68344 m
.53159 .68352 L
s
.53169 .68332 m
.53171 .68344 L
s
.53159 .68352 m
.53148 .68337 L
s
.53148 .68337 m
.53169 .68332 L
s
.53169 .68332 m
.53159 .68352 L
s
1 .003 0 r
.58415 .55674 m
.58422 .55661 L
s
1 .056 0 r
.28998 .50672 m
.28954 .50602 L
s
.28954 .50602 m
.29051 .50589 L
s
1 .003 0 r
.5842 .55661 m
.58423 .55664 L
s
.58417 .55663 m
.5842 .55661 L
s
.5842 .55661 m
.58422 .55661 L
s
1 .056 0 r
.29051 .50589 m
.28998 .50672 L
s
1 .003 0 r
.58423 .55664 m
.5842 .55666 L
s
.58422 .55661 m
.58423 .55664 L
s
.5842 .55666 m
.58417 .55663 L
s
.58417 .55663 m
.58422 .55661 L
s
.58422 .55661 m
.5842 .55666 L
s
1 .014 0 r
.38003 .50591 m
.38041 .50536 L
s
1 0 0 r
.84122 .4805 m
.84122 .48049 L
s
.84122 .48049 m
.84122 .48049 L
s
.84122 .48049 m
.84122 .48049 L
s
.84122 .48049 m
.84122 .48049 L
s
.84122 .48049 m
.84122 .48049 L
s
.84122 .48049 m
.84122 .48049 L
s
.84122 .48049 m
.84122 .48049 L
s
.84122 .48049 m
.84122 .48049 L
s
.84122 .48049 m
.84122 .48049 L
s
1 .006 0 r
.67943 .70835 m
.6796 .70814 L
s
1 0 0 r
.63709 .42966 m
.63709 .42965 L
s
.63709 .42965 m
.63709 .42966 L
s
.63709 .42966 m
.63709 .42965 L
s
.63709 .42965 m
.63709 .42965 L
s
.63709 .42966 m
.63709 .42966 L
s
.63709 .42965 m
.63709 .42966 L
s
.63709 .42966 m
.63709 .42966 L
s
.63709 .42966 m
.63709 .42965 L
s
.63709 .42965 m
.63709 .42966 L
s
1 .006 0 r
.67957 .70813 m
.67962 .7082 L
s
.67951 .70817 m
.67957 .70813 L
s
.67957 .70813 m
.6796 .70814 L
s
.67962 .7082 m
.67957 .70823 L
s
.6796 .70814 m
.67962 .7082 L
s
1 .017 0 r
.47528 .65753 m
.47591 .65694 L
s
1 .006 0 r
.67957 .70823 m
.67951 .70817 L
s
.67951 .70817 m
.6796 .70814 L
s
1 .014 0 r
.38034 .50535 m
.38047 .50551 L
s
.3802 .50543 m
.38034 .50535 L
s
.38034 .50535 m
.38041 .50536 L
s
1 .006 0 r
.6796 .70814 m
.67957 .70823 L
s
1 .014 0 r
.38047 .50551 m
.38033 .50559 L
s
.38041 .50536 m
.38047 .50551 L
s
1 .001 0 r
.93655 .63211 m
.93657 .63208 L
s
1 0 0 r
.43293 .37881 m
.43293 .37881 L
s
.43293 .37881 m
.43293 .37881 L
s
.43293 .37881 m
.43293 .37881 L
s
.43293 .37881 m
.43293 .37881 L
s
.43293 .37881 m
.43293 .37881 L
s
.43293 .37881 m
.43293 .37881 L
s
.43293 .37881 m
.43293 .37881 L
s
.43293 .37881 m
.43293 .37881 L
s
.43293 .37881 m
.43293 .37881 L
s
1 .001 0 r
.93656 .63208 m
.93657 .63209 L
s
.93655 .63209 m
.93656 .63208 L
s
.93656 .63208 m
.93657 .63208 L
s
1 .051 0 r
.32966 .63209 m
.32927 .63231 L
s
.32931 .63142 m
.32966 .63209 L
s
.32982 .63159 m
.32966 .63209 L
s
1 .001 0 r
.93657 .63209 m
.93656 .63209 L
s
.93657 .63208 m
.93657 .63209 L
s
.93656 .63209 m
.93655 .63209 L
s
.93655 .63209 m
.93657 .63208 L
s
.93657 .63208 m
.93656 .63209 L
s
1 .051 0 r
.32892 .63164 m
.32931 .63142 L
s
.32931 .63142 m
.32982 .63159 L
s
1 .014 0 r
.38033 .50559 m
.3802 .50543 L
s
.3802 .50543 m
.38041 .50536 L
s
.38041 .50536 m
.38033 .50559 L
s
1 .078 0 r
.27109 .6067 m
.27587 .60504 L
s
1 .001 0 r
.7324 .58128 m
.73242 .58122 L
s
.73242 .58122 m
.73243 .58124 L
s
.7324 .58123 m
.73242 .58122 L
s
.73242 .58122 m
.73242 .58122 L
s
.73243 .58124 m
.73242 .58125 L
s
.73242 .58122 m
.73243 .58124 L
s
.73242 .58125 m
.7324 .58123 L
s
.7324 .58123 m
.73242 .58122 L
s
.73242 .58122 m
.73242 .58125 L
s
1 .017 0 r
.47579 .65691 m
.47594 .65711 L
s
.47563 .65701 m
.47579 .65691 L
s
.47579 .65691 m
.47591 .65694 L
s
.47594 .65711 m
.47578 .65721 L
s
.47591 .65694 m
.47594 .65711 L
s
1 .004 0 r
.52821 .53044 m
.52828 .53029 L
s
.52827 .53029 m
.5283 .53033 L
s
.52823 .53032 m
.52827 .53029 L
s
.52827 .53029 m
.52828 .53029 L
s
1 .128 0 r
.23884 .47967 m
.23794 .48006 L
s
.23811 .4779 m
.23884 .47967 L
s
.23955 .47837 m
.23884 .47967 L
s
1 .017 0 r
.47578 .65721 m
.47563 .65701 L
s
.47563 .65701 m
.47591 .65694 L
s
1 .004 0 r
.5283 .53033 m
.52827 .53035 L
s
.52828 .53029 m
.5283 .53033 L
s
.52827 .53035 m
.52823 .53032 L
s
.52823 .53032 m
.52828 .53029 L
s
1 .017 0 r
.47591 .65694 m
.47578 .65721 L
s
1 .051 0 r
.32927 .63231 m
.32892 .63164 L
s
.32982 .63159 m
.32927 .63231 L
s
1 .004 0 r
.52828 .53029 m
.52827 .53035 L
s
1 .051 0 r
.32892 .63164 m
.32982 .63159 L
s
1 .003 0 r
.82773 .73295 m
.82782 .73284 L
s
1 .024 0 r
.32398 .47959 m
.32471 .47864 L
s
1 .128 0 r
.23721 .47829 m
.23811 .4779 L
s
.23811 .4779 m
.23955 .47837 L
s
1 .003 0 r
.8278 .73284 m
.82783 .73287 L
s
.82777 .73286 m
.8278 .73284 L
s
.8278 .73284 m
.82782 .73284 L
s
.82783 .73287 m
.8278 .73289 L
s
.82782 .73284 m
.82783 .73287 L
s
1 0 0 r
.78539 .45416 m
.78539 .45416 L
s
.78539 .45416 m
.78539 .45416 L
s
.78539 .45416 m
.78539 .45416 L
s
.78539 .45416 m
.78539 .45416 L
s
.78539 .45416 m
.78539 .45416 L
s
.78539 .45416 m
.78539 .45416 L
s
.78539 .45416 m
.78539 .45416 L
s
.78539 .45416 m
.78539 .45416 L
s
.78539 .45416 m
.78539 .45416 L
s
1 .003 0 r
.8278 .73289 m
.82777 .73286 L
s
.82777 .73286 m
.82782 .73284 L
s
.82782 .73284 m
.8278 .73289 L
s
1 .007 0 r
.62352 .68212 m
.62373 .68186 L
s
1 0 0 r
.58116 .40329 m
.58116 .40329 L
s
.58116 .40329 m
.58116 .40329 L
s
.58116 .40329 m
.58116 .40329 L
s
.58116 .40329 m
.58116 .40329 L
s
.58116 .40329 m
.58116 .40329 L
s
.58116 .40329 m
.58116 .40329 L
s
.58116 .40329 m
.58116 .40329 L
s
.58116 .40329 m
.58116 .40329 L
s
.58116 .40329 m
.58116 .40329 L
s
1 .024 0 r
.41927 .63127 m
.42023 .63045 L
s
1 .007 0 r
.62369 .68185 m
.62375 .68193 L
s
.62362 .6819 m
.62369 .68185 L
s
.62369 .68185 m
.62373 .68186 L
s
.62375 .68193 m
.62369 .68197 L
s
.62373 .68186 m
.62375 .68193 L
s
.62369 .68197 m
.62362 .6819 L
s
.62362 .6819 m
.62373 .68186 L
s
.62373 .68186 m
.62369 .68197 L
s
1 .001 0 r
.88075 .60584 m
.88077 .60581 L
s
.88077 .60581 m
.88078 .60582 L
s
.88076 .60582 m
.88077 .60581 L
s
.88077 .60581 m
.88077 .60581 L
s
.88078 .60582 m
.88077 .60582 L
s
.88077 .60581 m
.88078 .60582 L
s
.88077 .60582 m
.88076 .60582 L
s
.88076 .60582 m
.88077 .60581 L
s
.88077 .60581 m
.88077 .60582 L
s
1 .078 0 r
.27538 .60578 m
.27487 .60606 L
s
.27496 .60469 m
.27538 .60578 L
s
.27587 .60504 m
.27538 .60578 L
s
.27444 .60497 m
.27496 .60469 L
s
.27496 .60469 m
.27587 .60504 L
s
1 .001 0 r
.6765 .55498 m
.67653 .55492 L
s
1 .024 0 r
.32457 .47862 m
.3248 .4789 L
s
.32433 .47876 m
.32457 .47862 L
s
.32457 .47862 m
.32471 .47864 L
s
1 .001 0 r
.67652 .55492 m
.67654 .55494 L
s
.67651 .55493 m
.67652 .55492 L
s
.67652 .55492 m
.67653 .55492 L
s
.67654 .55494 m
.67652 .55495 L
s
.67653 .55492 m
.67654 .55494 L
s
.67652 .55495 m
.67651 .55493 L
s
.67651 .55493 m
.67653 .55492 L
s
1 .024 0 r
.3248 .4789 m
.32455 .47903 L
s
.32471 .47864 m
.3248 .4789 L
s
1 .001 0 r
.67653 .55492 m
.67652 .55495 L
s
1 .004 0 r
.47221 .50412 m
.4723 .50394 L
s
1 .024 0 r
.32455 .47903 m
.32433 .47876 L
s
.32433 .47876 m
.32471 .47864 L
s
.32471 .47864 m
.32455 .47903 L
s
1 .056 0 r
.31028 .73215 m
.31371 .73107 L
s
1 .004 0 r
.47228 .50394 m
.47232 .50398 L
s
.47224 .50397 m
.47228 .50394 L
s
.47228 .50394 m
.4723 .50394 L
s
1 .024 0 r
.42004 .6304 m
.42025 .6307 L
s
.41982 .63054 m
.42004 .6304 L
s
.42004 .6304 m
.42023 .63045 L
s
1 .004 0 r
.47232 .50398 m
.47228 .50401 L
s
.4723 .50394 m
.47232 .50398 L
s
.47228 .50401 m
.47224 .50397 L
s
.47224 .50397 m
.4723 .50394 L
s
1 .024 0 r
.42025 .6307 m
.42003 .63083 L
s
.42023 .63045 m
.42025 .6307 L
s
1 .004 0 r
.4723 .50394 m
.47228 .50401 L
s
1 .003 0 r
.77187 .70672 m
.77197 .7066 L
s
1 .056 0 r
.26789 .45324 m
.26993 .45113 L
s
1 .003 0 r
.77195 .70659 m
.77198 .70663 L
s
.77192 .70662 m
.77195 .70659 L
s
.77195 .70659 m
.77197 .7066 L
s
1 0 0 r
.7295 .4278 m
.72951 .42779 L
s
.72951 .4278 m
.72951 .4278 L
s
.7295 .4278 m
.72951 .4278 L
s
.72951 .4278 m
.72951 .42779 L
s
.72951 .4278 m
.72951 .4278 L
s
.72951 .42779 m
.72951 .4278 L
s
.72951 .4278 m
.7295 .4278 L
s
.7295 .4278 m
.72951 .42779 L
s
.72951 .42779 m
.72951 .4278 L
s
1 .003 0 r
.77198 .70663 m
.77195 .70665 L
s
.77197 .7066 m
.77198 .70663 L
s
.77195 .70665 m
.77192 .70662 L
s
.77192 .70662 m
.77197 .7066 L
s
.77197 .7066 m
.77195 .70665 L
s
1 .024 0 r
.42003 .63083 m
.41982 .63054 L
s
.41982 .63054 m
.42023 .63045 L
s
.42023 .63045 m
.42003 .63083 L
s
1 .009 0 r
.56756 .65586 m
.56783 .65554 L
s
1 .128 0 r
.23794 .48006 m
.23721 .47829 L
s
.23955 .47837 m
.23794 .48006 L
s
.23721 .47829 m
.23955 .47837 L
s
1 0 0 r
.52518 .37691 m
.52518 .37691 L
s
.52518 .37691 m
.52518 .37691 L
s
.52518 .37691 m
.52518 .37691 L
s
.52518 .37691 m
.52518 .37691 L
s
.52518 .37691 m
.52518 .37691 L
s
.52518 .37691 m
.52518 .37691 L
s
.52518 .37691 m
.52518 .37691 L
s
.52518 .37691 m
.52518 .37691 L
s
.52518 .37691 m
.52518 .37691 L
s
1 .078 0 r
.27587 .60504 m
.27487 .60606 L
s
.27444 .60497 m
.27587 .60504 L
s
.27487 .60606 m
.27444 .60497 L
s
1 .037 0 r
.36321 .60499 m
.36481 .6038 L
s
1 .009 0 r
.56777 .65553 m
.56786 .65562 L
s
.56769 .65558 m
.56777 .65553 L
s
.56777 .65553 m
.56783 .65554 L
s
.56786 .65562 m
.56777 .65568 L
s
.56783 .65554 m
.56786 .65562 L
s
1 .001 0 r
.82491 .57955 m
.82492 .57951 L
s
.82492 .57951 m
.82493 .57952 L
s
.82491 .57952 m
.82492 .57951 L
s
.82492 .57951 m
.82492 .57951 L
s
1 .009 0 r
.56777 .65568 m
.56769 .65558 L
s
.56769 .65558 m
.56783 .65554 L
s
1 .001 0 r
.82493 .57952 m
.82492 .57953 L
s
.82492 .57951 m
.82493 .57952 L
s
.82492 .57953 m
.82491 .57952 L
s
.82491 .57952 m
.82492 .57951 L
s
.82492 .57951 m
.82492 .57953 L
s
1 .009 0 r
.56783 .65554 m
.56777 .65568 L
s
1 .056 0 r
.31334 .73156 m
.31299 .73179 L
s
.31305 .73079 m
.31334 .73156 L
s
.31371 .73107 m
.31334 .73156 L
s
.3127 .73102 m
.31305 .73079 L
s
.31305 .73079 m
.31371 .73107 L
s
1 .002 0 r
.62055 .52866 m
.62058 .5286 L
s
.62057 .5286 m
.62059 .52861 L
s
.62056 .52861 m
.62057 .5286 L
s
.62057 .5286 m
.62058 .5286 L
s
.62059 .52861 m
.62058 .52862 L
s
.62058 .5286 m
.62059 .52861 L
s
.62058 .52862 m
.62056 .52861 L
s
.62056 .52861 m
.62058 .5286 L
s
.62058 .5286 m
.62058 .52862 L
s
.92034 .73135 m
.9204 .73128 L
s
1 .005 0 r
.41616 .47777 m
.41626 .47754 L
s
1 .002 0 r
.92038 .73127 m
.9204 .73129 L
s
.92037 .73129 m
.92038 .73127 L
s
.92038 .73127 m
.9204 .73128 L
s
.9204 .73129 m
.92039 .73131 L
s
.9204 .73128 m
.9204 .73129 L
s
.92039 .73131 m
.92037 .73129 L
s
.92037 .73129 m
.9204 .73128 L
s
.9204 .73128 m
.92039 .73131 L
s
1 0 0 r
.87796 .45232 m
.87796 .45232 L
s
.87796 .45232 m
.87796 .45232 L
s
.87796 .45232 m
.87796 .45232 L
s
.87796 .45232 m
.87796 .45232 L
s
.87796 .45232 m
.87796 .45232 L
s
.87796 .45232 m
.87796 .45232 L
s
.87796 .45232 m
.87796 .45232 L
s
.87796 .45232 m
.87796 .45232 L
s
.87796 .45232 m
.87796 .45232 L
s
1 .005 0 r
.41625 .47754 m
.4163 .4776 L
s
.41619 .47758 m
.41625 .47754 L
s
.41625 .47754 m
.41626 .47754 L
s
.4163 .4776 m
.41624 .47763 L
s
.41626 .47754 m
.4163 .4776 L
s
1 .004 0 r
.71596 .68047 m
.71607 .68032 L
s
1 .238 0 r
.21174 .42686 m
.22514 .42057 L
s
1 .005 0 r
.41624 .47763 m
.41619 .47758 L
s
.41619 .47758 m
.41626 .47754 L
s
.41626 .47754 m
.41624 .47763 L
s
1 0 0 r
.67357 .40141 m
.67357 .40141 L
s
.67357 .40141 m
.67357 .40141 L
s
.67357 .40141 m
.67357 .40141 L
s
.67357 .40141 m
.67357 .40141 L
s
.67357 .40141 m
.67357 .40141 L
s
.67357 .40141 m
.67357 .40141 L
s
.67357 .40141 m
.67357 .40141 L
s
.67357 .40141 m
.67357 .40141 L
s
.67357 .40141 m
.67357 .40141 L
s
1 .004 0 r
.71605 .68032 m
.71609 .68036 L
s
.71601 .68034 m
.71605 .68032 L
s
.71605 .68032 m
.71607 .68032 L
s
.71609 .68036 m
.71605 .68038 L
s
.71607 .68032 m
.71609 .68036 L
s
1 .056 0 r
.31371 .73107 m
.31299 .73179 L
s
.3127 .73102 m
.31371 .73107 L
s
1 .004 0 r
.71605 .68038 m
.71601 .68034 L
s
.71601 .68034 m
.71607 .68032 L
s
1 .056 0 r
.31299 .73179 m
.3127 .73102 L
s
1 .004 0 r
.71607 .68032 m
.71605 .68038 L
s
1 .011 0 r
.51155 .62958 m
.5119 .62916 L
s
1 .037 0 r
.3645 .60371 m
.3648 .60417 L
s
.36418 .6039 m
.3645 .60371 L
s
.3645 .60371 m
.36481 .6038 L
s
.3648 .60417 m
.36448 .60435 L
s
.36481 .6038 m
.3648 .60417 L
s
1 .061 0 r
.3071 .57868 m
.31014 .5769 L
s
1 .056 0 r
.26955 .45108 m
.27004 .45175 L
s
.269 .45135 m
.26955 .45108 L
s
.26955 .45108 m
.26993 .45113 L
s
1 .001 0 r
.76901 .55323 m
.76902 .55319 L
s
1 .056 0 r
.27004 .45175 m
.26949 .45202 L
s
.26993 .45113 m
.27004 .45175 L
s
1 .001 0 r
.76902 .55319 m
.76903 .5532 L
s
.76901 .5532 m
.76902 .55319 L
s
.76902 .55319 m
.76902 .55319 L
s
.76903 .5532 m
.76902 .55321 L
s
.76902 .55319 m
.76903 .5532 L
s
.76902 .55321 m
.76901 .5532 L
s
.76901 .5532 m
.76902 .55319 L
s
.76902 .55319 m
.76902 .55321 L
s
1 .011 0 r
.51183 .62914 m
.51194 .62927 L
s
.51173 .62921 m
.51183 .62914 L
s
.51183 .62914 m
.5119 .62916 L
s
.51194 .62927 m
.51183 .62934 L
s
.5119 .62916 m
.51194 .62927 L
s
1 .037 0 r
.36448 .60435 m
.36418 .6039 L
s
.36418 .6039 m
.36481 .6038 L
s
.36481 .6038 m
.36448 .60435 L
s
1 .011 0 r
.51183 .62934 m
.51173 .62921 L
s
.51173 .62921 m
.5119 .62916 L
s
.5119 .62916 m
.51183 .62934 L
s
1 .002 0 r
.56455 .50232 m
.56458 .50225 L
s
.56457 .50225 m
.56459 .50226 L
s
.56456 .50226 m
.56457 .50225 L
s
.56457 .50225 m
.56458 .50225 L
s
.56459 .50226 m
.56457 .50227 L
s
.56458 .50225 m
.56459 .50226 L
s
.56457 .50227 m
.56456 .50226 L
s
.56456 .50226 m
.56458 .50225 L
s
.56458 .50225 m
.56457 .50227 L
s
1 .035 0 r
.40248 .73055 m
.40422 .72958 L
s
1 .002 0 r
.86448 .7051 m
.86453 .70502 L
s
1 .007 0 r
.36006 .4514 m
.36019 .45108 L
s
1 .056 0 r
.26949 .45202 m
.269 .45135 L
s
.269 .45135 m
.26993 .45113 L
s
1 .002 0 r
.86452 .70501 m
.86454 .70504 L
s
.8645 .70503 m
.86452 .70501 L
s
.86452 .70501 m
.86453 .70502 L
s
.86454 .70504 m
.86452 .70505 L
s
.86453 .70502 m
.86454 .70504 L
s
.86452 .70505 m
.8645 .70503 L
s
.8645 .70503 m
.86453 .70502 L
s
.86453 .70502 m
.86452 .70505 L
s
1 0 0 r
.82208 .42593 m
.82208 .42593 L
s
.82208 .42593 m
.82208 .42593 L
s
.82208 .42593 m
.82208 .42593 L
s
.82208 .42593 m
.82208 .42593 L
s
.82208 .42593 m
.82208 .42593 L
s
.82208 .42593 m
.82208 .42593 L
s
.82208 .42593 m
.82208 .42593 L
s
.82208 .42593 m
.82208 .42593 L
s
.82208 .42593 m
.82208 .42593 L
s
1 .056 0 r
.26993 .45113 m
.26949 .45202 L
s
1 .005 0 r
.66 .65419 m
.66012 .65401 L
s
1 .007 0 r
.36017 .45109 m
.36024 .45116 L
s
.36009 .45113 m
.36017 .45109 L
s
.36017 .45109 m
.36019 .45108 L
s
.36024 .45116 m
.36016 .45121 L
s
.36019 .45108 m
.36024 .45116 L
s
.36016 .45121 m
.36009 .45113 L
s
.36009 .45113 m
.36019 .45108 L
s
1 0 0 r
.61758 .375 m
.61758 .375 L
s
.61758 .375 m
.61758 .375 L
s
.61758 .375 m
.61758 .375 L
s
.61758 .375 m
.61758 .375 L
s
.61758 .375 m
.61758 .375 L
s
.61758 .375 m
.61758 .375 L
s
.61758 .375 m
.61758 .375 L
s
.61758 .375 m
.61758 .375 L
s
.61758 .375 m
.61758 .375 L
s
1 .007 0 r
.36019 .45108 m
.36016 .45121 L
s
1 .005 0 r
.6601 .65401 m
.66014 .65406 L
s
.66005 .65404 m
.6601 .65401 L
s
.6601 .65401 m
.66012 .65401 L
s
.66014 .65406 m
.6601 .65409 L
s
.66012 .65401 m
.66014 .65406 L
s
.6601 .65409 m
.66005 .65404 L
s
.66005 .65404 m
.66012 .65401 L
s
.66012 .65401 m
.6601 .65409 L
s
1 .016 0 r
.45548 .60327 m
.45599 .60269 L
s
1 0 0 r
.91758 .57781 m
.91759 .57779 L
s
.91758 .57779 m
.91759 .5778 L
s
.91758 .5778 m
.91758 .57779 L
s
.91758 .57779 m
.91759 .57779 L
s
.91759 .5778 m
.91758 .5778 L
s
.91759 .57779 m
.91759 .5778 L
s
.91758 .5778 m
.91758 .5778 L
s
.91758 .5778 m
.91759 .57779 L
s
.91759 .57779 m
.91758 .5778 L
s
1 .108 0 r
.25093 .55235 m
.25744 .54996 L
s
1 .035 0 r
.40388 .72947 m
.40414 .72991 L
s
.40361 .72964 m
.40388 .72947 L
s
.40388 .72947 m
.40422 .72958 L
s
.40414 .72991 m
.40386 .73009 L
s
.40422 .72958 m
.40414 .72991 L
s
1 .001 0 r
.71306 .52688 m
.71307 .52685 L
s
.71307 .52685 m
.71307 .52686 L
s
.71306 .52686 m
.71307 .52685 L
s
.71307 .52685 m
.71307 .52685 L
s
.71307 .52686 m
.71307 .52686 L
s
.71307 .52685 m
.71307 .52686 L
s
.71307 .52686 m
.71306 .52686 L
s
.71306 .52686 m
.71307 .52685 L
s
.71307 .52685 m
.71307 .52686 L
s
1 .061 0 r
.30956 .57673 m
.31 .57752 L
s
.30905 .57699 m
.30956 .57673 L
s
.30956 .57673 m
.31014 .5769 L
s
.31 .57752 m
.3095 .57778 L
s
.31014 .5769 m
.31 .57752 L
s
1 .016 0 r
.45589 .60267 m
.45604 .60285 L
s
.45574 .60276 m
.45589 .60267 L
s
.45589 .60267 m
.45599 .60269 L
s
.45604 .60285 m
.45589 .60294 L
s
.45599 .60269 m
.45604 .60285 L
s
1 .002 0 r
.5085 .47595 m
.50852 .47587 L
s
.50852 .47587 m
.50854 .47589 L
s
.5085 .47589 m
.50852 .47587 L
s
.50852 .47587 m
.50852 .47587 L
s
.50854 .47589 m
.50852 .4759 L
s
.50852 .47587 m
.50854 .47589 L
s
.50852 .4759 m
.5085 .47589 L
s
.5085 .47589 m
.50852 .47587 L
s
.50852 .47587 m
.50852 .4759 L
s
1 .016 0 r
.45589 .60294 m
.45574 .60276 L
s
.45574 .60276 m
.45599 .60269 L
s
1 .048 0 r
.34635 .70428 m
.34901 .70307 L
s
1 .016 0 r
.45599 .60269 m
.45589 .60294 L
s
1 .035 0 r
.40386 .73009 m
.40361 .72964 L
s
.40361 .72964 m
.40422 .72958 L
s
.40422 .72958 m
.40386 .73009 L
s
1 .002 0 r
.80856 .67882 m
.80862 .67873 L
s
1 .011 0 r
.30391 .425 m
.30409 .42451 L
s
1 .002 0 r
.80861 .67873 m
.80863 .67875 L
s
.80859 .67874 m
.80861 .67873 L
s
.80861 .67873 m
.80862 .67873 L
s
.80863 .67875 m
.80861 .67877 L
s
.80862 .67873 m
.80863 .67875 L
s
.80861 .67877 m
.80859 .67874 L
s
.80859 .67874 m
.80862 .67873 L
s
.80862 .67873 m
.80861 .67877 L
s
1 0 0 r
.76614 .39952 m
.76614 .39952 L
s
.76614 .39952 m
.76614 .39952 L
s
.76614 .39952 m
.76614 .39952 L
s
.76614 .39952 m
.76614 .39952 L
s
.76614 .39952 m
.76614 .39952 L
s
.76614 .39952 m
.76614 .39952 L
s
.76614 .39952 m
.76614 .39952 L
s
.76614 .39952 m
.76614 .39952 L
s
.76614 .39952 m
.76614 .39952 L
s
1 .006 0 r
.60398 .62789 m
.60413 .62767 L
s
1 .061 0 r
.3095 .57778 m
.30905 .57699 L
s
.30905 .57699 m
.31014 .5769 L
s
.31014 .5769 m
.3095 .57778 L
s
1 .011 0 r
.30406 .42451 m
.30417 .42463 L
s
.30394 .42459 m
.30406 .42451 L
s
.30406 .42451 m
.30409 .42451 L
s
1 .006 0 r
.6041 .62766 m
.60416 .62772 L
s
.60405 .6277 m
.6041 .62766 L
s
.6041 .62766 m
.60413 .62767 L
s
.60416 .62772 m
.6041 .62776 L
s
.60413 .62767 m
.60416 .62772 L
s
1 .023 0 r
.39936 .57694 m
.40018 .57608 L
s
1 .011 0 r
.30417 .42463 m
.30405 .4247 L
s
.30409 .42451 m
.30417 .42463 L
s
1 .006 0 r
.6041 .62776 m
.60405 .6277 L
s
.60405 .6277 m
.60413 .62767 L
s
.60413 .62767 m
.6041 .62776 L
s
1 .011 0 r
.30405 .4247 m
.30394 .42459 L
s
.30394 .42459 m
.30409 .42451 L
s
.30409 .42451 m
.30405 .4247 L
s
1 0 0 r
.86167 .55147 m
.86168 .55145 L
s
.86168 .55145 m
.86168 .55145 L
s
.86167 .55145 m
.86168 .55145 L
s
.86168 .55145 m
.86168 .55145 L
s
.86168 .55145 m
.86168 .55146 L
s
.86168 .55145 m
.86168 .55145 L
s
.86168 .55146 m
.86167 .55145 L
s
.86167 .55145 m
.86168 .55145 L
s
.86168 .55145 m
.86168 .55146 L
s
1 .001 0 r
.65705 .50051 m
.65706 .50048 L
s
.65706 .50048 m
.65707 .50049 L
s
.65705 .50049 m
.65706 .50048 L
s
.65706 .50048 m
.65706 .50048 L
s
.65707 .50049 m
.65706 .50049 L
s
.65706 .50048 m
.65707 .50049 L
s
.65706 .50049 m
.65705 .50049 L
s
.65705 .50049 m
.65706 .50048 L
s
.65706 .50048 m
.65706 .50049 L
s
1 .02 0 r
.49485 .72894 m
.49567 .7283 L
s
1 .048 0 r
.34882 .70353 m
.34846 .70375 L
s
.3485 .70288 m
.34882 .70353 L
s
.34901 .70307 m
.34882 .70353 L
s
.34814 .7031 m
.3485 .70288 L
s
.3485 .70288 m
.34901 .70307 L
s
1 .001 0 r
.95724 .70347 m
.95728 .70341 L
s
1 .002 0 r
.4524 .44955 m
.45241 .44948 L
s
1 .001 0 r
.95727 .70341 m
.95728 .70343 L
s
.95725 .70342 m
.95727 .70341 L
s
.95727 .70341 m
.95728 .70341 L
s
.95728 .70343 m
.95727 .70344 L
s
.95728 .70341 m
.95728 .70343 L
s
.95727 .70344 m
.95725 .70342 L
s
.95725 .70342 m
.95728 .70341 L
s
.95728 .70341 m
.95727 .70344 L
s
1 .002 0 r
.45241 .44948 m
.45243 .44949 L
s
.45239 .44949 m
.45241 .44948 L
s
.45241 .44948 m
.45241 .44948 L
s
.45243 .44949 m
.45241 .44951 L
s
.45241 .44948 m
.45243 .44949 L
s
.45241 .44951 m
.45239 .44949 L
s
.45239 .44949 m
.45241 .44948 L
s
.45241 .44948 m
.45241 .44951 L
s
1 .069 0 r
.29017 .67799 m
.29439 .67661 L
s
1 .108 0 r
.2568 .55101 m
.25607 .55137 L
s
.2562 .54951 m
.2568 .55101 L
s
.25744 .54996 m
.2568 .55101 L
s
1 .023 0 r
.40002 .57605 m
.40023 .57633 L
s
.39979 .57618 m
.40002 .57605 L
s
.40002 .57605 m
.40018 .57608 L
s
1 .003 0 r
.75259 .65252 m
.75266 .65241 L
s
1 .024 0 r
.2477 .39858 m
.24808 .39751 L
s
1 .023 0 r
.40023 .57633 m
.40001 .57646 L
s
.40018 .57608 m
.40023 .57633 L
s
1 .108 0 r
.25547 .54987 m
.2562 .54951 L
s
.2562 .54951 m
.25744 .54996 L
s
1 .003 0 r
.75264 .65241 m
.75267 .65244 L
s
.75262 .65243 m
.75264 .65241 L
s
.75264 .65241 m
.75266 .65241 L
s
.75267 .65244 m
.75265 .65246 L
s
.75266 .65241 m
.75267 .65244 L
s
.75265 .65246 m
.75262 .65243 L
s
.75262 .65243 m
.75266 .65241 L
s
1 0 0 r
.71015 .37309 m
.71015 .37309 L
s
.71015 .37309 m
.71015 .37309 L
s
.71015 .37309 m
.71015 .37309 L
s
.71015 .37309 m
.71015 .37309 L
s
.71015 .37309 m
.71015 .37309 L
s
.71015 .37309 m
.71015 .37309 L
s
.71015 .37309 m
.71015 .37309 L
s
.71015 .37309 m
.71015 .37309 L
s
.71015 .37309 m
.71015 .37309 L
s
1 .003 0 r
.75266 .65241 m
.75265 .65246 L
s
1 .023 0 r
.40001 .57646 m
.39979 .57618 L
s
.39979 .57618 m
.40018 .57608 L
s
1 .007 0 r
.54791 .60156 m
.5481 .60128 L
s
1 .023 0 r
.40018 .57608 m
.40001 .57646 L
s
1 .048 0 r
.34846 .70375 m
.34814 .7031 L
s
.34901 .70307 m
.34846 .70375 L
s
1 .02 0 r
.49551 .72825 m
.49568 .72849 L
s
.49533 .72836 m
.49551 .72825 L
s
.49551 .72825 m
.49567 .7283 L
s
1 .048 0 r
.34814 .7031 m
.34901 .70307 L
s
1 .02 0 r
.49568 .72849 m
.4955 .7286 L
s
.49567 .7283 m
.49568 .72849 L
s
1 .039 0 r
.34319 .55059 m
.34468 .5492 L
s
1 .02 0 r
.4955 .7286 m
.49533 .72836 L
s
.49533 .72836 m
.49567 .7283 L
s
1 .007 0 r
.54806 .60127 m
.54813 .60135 L
s
.54799 .60132 m
.54806 .60127 L
s
.54806 .60127 m
.5481 .60128 L
s
1 .02 0 r
.49567 .7283 m
.4955 .7286 L
s
1 .007 0 r
.54813 .60135 m
.54806 .6014 L
s
.5481 .60128 m
.54813 .60135 L
s
.54806 .6014 m
.54799 .60132 L
s
.54799 .60132 m
.5481 .60128 L
s
.5481 .60128 m
.54806 .6014 L
s
1 0 0 r
.80572 .5251 m
.80572 .52508 L
s
.80572 .52508 m
.80573 .52509 L
s
.80572 .52509 m
.80572 .52508 L
s
.80572 .52508 m
.80572 .52508 L
s
.80573 .52509 m
.80572 .52509 L
s
.80572 .52508 m
.80573 .52509 L
s
.80572 .52509 m
.80572 .52509 L
s
.80572 .52509 m
.80572 .52508 L
s
.80572 .52508 m
.80572 .52509 L
s
1 .001 0 r
.60099 .47412 m
.601 .47409 L
s
.601 .47409 m
.60101 .4741 L
s
.60099 .4741 m
.601 .47409 L
s
.601 .47409 m
.601 .47409 L
s
.60101 .4741 m
.601 .4741 L
s
.601 .47409 m
.60101 .4741 L
s
.601 .4741 m
.60099 .4741 L
s
.60099 .4741 m
.601 .47409 L
s
.601 .47409 m
.601 .4741 L
s
1 .024 0 r
.24802 .39752 m
.24825 .39777 L
s
.24775 .39767 m
.24802 .39752 L
s
.24802 .39752 m
.24808 .39751 L
s
1 .027 0 r
.43871 .70265 m
.4399 .7018 L
s
1 .069 0 r
.29395 .67723 m
.29351 .67749 L
s
.29358 .67628 m
.29395 .67723 L
s
.29439 .67661 m
.29395 .67723 L
s
1 .024 0 r
.24825 .39777 m
.24799 .39792 L
s
.24808 .39751 m
.24825 .39777 L
s
1 .069 0 r
.29314 .67654 m
.29358 .67628 L
s
.29358 .67628 m
.29439 .67661 L
s
1 .001 0 r
.90132 .67717 m
.90136 .67711 L
s
.39624 .42313 m
.39625 .42306 L
s
1 .238 0 r
.22409 .4231 m
.22229 .42381 L
s
.22261 .41986 m
.22409 .4231 L
s
.22514 .42057 m
.22409 .4231 L
s
1 .001 0 r
.90135 .67711 m
.90136 .67712 L
s
.90133 .67712 m
.90135 .67711 L
s
.90135 .67711 m
.90136 .67711 L
s
.90136 .67712 m
.90135 .67713 L
s
.90136 .67711 m
.90136 .67712 L
s
.90135 .67713 m
.90133 .67712 L
s
.90133 .67712 m
.90136 .67711 L
s
.39625 .42306 m
.39626 .42308 L
s
.39623 .42308 m
.39625 .42306 L
s
.39625 .42306 m
.39625 .42306 L
s
.90136 .67711 m
.90135 .67713 L
s
1 .024 0 r
.24799 .39792 m
.24775 .39767 L
s
.24775 .39767 m
.24808 .39751 L
s
1 .001 0 r
.39626 .42308 m
.39625 .42309 L
s
.39625 .42306 m
.39626 .42308 L
s
.39625 .42309 m
.39623 .42308 L
s
.39623 .42308 m
.39625 .42306 L
s
.39625 .42306 m
.39625 .42309 L
s
1 0 0 r
.85886 .39763 m
.85886 .39763 L
s
.85886 .39763 m
.85886 .39763 L
s
.85886 .39763 m
.85886 .39763 L
s
.85886 .39763 m
.85886 .39763 L
s
.85886 .39763 m
.85886 .39763 L
s
.85886 .39763 m
.85886 .39763 L
s
.85886 .39763 m
.85886 .39763 L
s
.85886 .39763 m
.85886 .39763 L
s
.85886 .39763 m
.85886 .39763 L
s
1 .024 0 r
.24808 .39751 m
.24799 .39792 L
s
1 .238 0 r
.22082 .42057 m
.22261 .41986 L
s
.22261 .41986 m
.22514 .42057 L
s
1 .003 0 r
.69657 .62619 m
.69664 .62607 L
s
1 .763 0 r
.19144 .37213 m
.2025 .33748 L
s
1 .108 0 r
.25744 .54996 m
.25607 .55137 L
s
.25547 .54987 m
.25744 .54996 L
s
.25607 .55137 m
.25547 .54987 L
s
1 .003 0 r
.69663 .62607 m
.69666 .6261 L
s
.6966 .62609 m
.69663 .62607 L
s
.69663 .62607 m
.69664 .62607 L
s
.69666 .6261 m
.69663 .62612 L
s
.69664 .62607 m
.69666 .6261 L
s
.69663 .62612 m
.6966 .62609 L
s
.6966 .62609 m
.69664 .62607 L
s
.69664 .62607 m
.69663 .62612 L
s
1 .009 0 r
.49179 .5752 m
.49203 .57483 L
s
1 .039 0 r
.3444 .54915 m
.34474 .54962 L
s
.34403 .54935 m
.3444 .54915 L
s
.3444 .54915 m
.34468 .5492 L
s
1 .027 0 r
.43967 .70172 m
.4399 .70206 L
s
.43943 .70187 m
.43967 .70172 L
s
.43967 .70172 m
.4399 .7018 L
s
1 .075 0 r
.28697 .52421 m
.29037 .52176 L
s
1 .039 0 r
.34474 .54962 m
.34437 .54982 L
s
.34468 .5492 m
.34474 .54962 L
s
1 .027 0 r
.4399 .70206 m
.43966 .70221 L
s
.4399 .7018 m
.4399 .70206 L
s
1 .069 0 r
.29439 .67661 m
.29351 .67749 L
s
.29314 .67654 m
.29439 .67661 L
s
.29351 .67749 m
.29314 .67654 L
s
1 .009 0 r
.49199 .57483 m
.49208 .57493 L
s
.49189 .57489 m
.49199 .57483 L
s
.49199 .57483 m
.49203 .57483 L
s
1 0 0 r
.74971 .49871 m
.74971 .49869 L
s
.74971 .49869 m
.74972 .4987 L
s
.74971 .4987 m
.74971 .49869 L
s
.74971 .49869 m
.74971 .49869 L
s
1 .009 0 r
.49208 .57493 m
.49198 .57499 L
s
.49203 .57483 m
.49208 .57493 L
s
1 0 0 r
.74972 .4987 m
.74971 .4987 L
s
.74971 .49869 m
.74972 .4987 L
s
.74971 .4987 m
.74971 .4987 L
s
.74971 .4987 m
.74971 .49869 L
s
.74971 .49869 m
.74971 .4987 L
s
1 .009 0 r
.49198 .57499 m
.49189 .57489 L
s
.49189 .57489 m
.49203 .57483 L
s
.49203 .57483 m
.49198 .57499 L
s
1 .011 0 r
.58737 .72733 m
.58777 .72693 L
s
1 .027 0 r
.43966 .70221 m
.43943 .70187 L
s
.43943 .70187 m
.4399 .7018 L
s
.4399 .7018 m
.43966 .70221 L
s
1 .001 0 r
.54488 .4477 m
.54489 .44768 L
s
1 .039 0 r
.34437 .54982 m
.34403 .54935 L
s
.34403 .54935 m
.34468 .5492 L
s
1 .001 0 r
.54489 .44768 m
.54489 .44768 L
s
.54488 .44768 m
.54489 .44768 L
s
.54489 .44768 m
.54489 .44768 L
s
.54489 .44768 m
.54489 .44769 L
s
.54489 .44768 m
.54489 .44768 L
s
.54489 .44769 m
.54488 .44768 L
s
.54488 .44768 m
.54489 .44768 L
s
.54489 .44768 m
.54489 .44769 L
s
1 .039 0 r
.34468 .5492 m
.34437 .54982 L
s
.38252 .67634 m
.38437 .67518 L
s
1 .002 0 r
.84535 .65084 m
.84538 .65078 L
s
1 .001 0 r
.34003 .39668 m
.34003 .39664 L
s
1 .011 0 r
.58769 .72691 m
.58779 .72704 L
s
.58758 .72698 m
.58769 .72691 L
s
.58769 .72691 m
.58777 .72693 L
s
1 .001 0 r
.34003 .39664 m
.34004 .39665 L
s
.34002 .39665 m
.34003 .39664 L
s
.34003 .39664 m
.34003 .39664 L
s
.34004 .39665 m
.34003 .39666 L
s
.34003 .39664 m
.34004 .39665 L
s
.34003 .39666 m
.34002 .39665 L
s
.34002 .39665 m
.34003 .39664 L
s
.34003 .39664 m
.34003 .39666 L
s
1 .002 0 r
.84538 .65078 m
.84539 .65079 L
s
.84536 .65079 m
.84538 .65078 L
s
.84538 .65078 m
.84538 .65078 L
s
1 .011 0 r
.58779 .72704 m
.58769 .72711 L
s
.58777 .72693 m
.58779 .72704 L
s
1 .002 0 r
.84539 .65079 m
.84538 .6508 L
s
.84538 .65078 m
.84539 .65079 L
s
.84538 .6508 m
.84536 .65079 L
s
.84536 .65079 m
.84538 .65078 L
s
.84538 .65078 m
.84538 .6508 L
s
1 0 0 r
.80287 .37117 m
.80287 .37117 L
s
.80287 .37117 m
.80287 .37117 L
s
.80287 .37117 m
.80287 .37117 L
s
.80287 .37117 m
.80287 .37117 L
s
.80287 .37117 m
.80287 .37117 L
s
.80287 .37117 m
.80287 .37117 L
s
.80287 .37117 m
.80287 .37117 L
s
.80287 .37117 m
.80287 .37117 L
s
.80287 .37117 m
.80287 .37117 L
s
1 .011 0 r
.58769 .72711 m
.58758 .72698 L
s
.58758 .72698 m
.58777 .72693 L
s
.58777 .72693 m
.58769 .72711 L
s
1 .004 0 r
.6405 .59984 m
.64058 .5997 L
s
.64056 .59969 m
.6406 .59973 L
s
.64053 .59972 m
.64056 .59969 L
s
.64056 .59969 m
.64058 .5997 L
s
.6406 .59973 m
.64056 .59975 L
s
.64058 .5997 m
.6406 .59973 L
s
.64056 .59975 m
.64053 .59972 L
s
.64053 .59972 m
.64058 .5997 L
s
.64058 .5997 m
.64056 .59975 L
s
1 .013 0 r
.43561 .54883 m
.43596 .5483 L
s
1 0 0 r
.89854 .52332 m
.89854 .52331 L
s
.89854 .52331 m
.89854 .52331 L
s
.89854 .52331 m
.89854 .52331 L
s
.89854 .52331 m
.89854 .52331 L
s
.89854 .52331 m
.89854 .52331 L
s
.89854 .52331 m
.89854 .52331 L
s
.89854 .52331 m
.89854 .52331 L
s
.89854 .52331 m
.89854 .52331 L
s
.89854 .52331 m
.89854 .52331 L
s
1 .171 0 r
.23069 .4978 m
.24082 .49378 L
s
1 0 0 r
.69365 .47229 m
.69365 .47228 L
s
.69365 .47228 m
.69365 .47228 L
s
.69365 .47228 m
.69365 .47228 L
s
.69365 .47228 m
.69365 .47228 L
s
.69365 .47228 m
.69365 .47228 L
s
.69365 .47228 m
.69365 .47228 L
s
.69365 .47228 m
.69365 .47228 L
s
.69365 .47228 m
.69365 .47228 L
s
.69365 .47228 m
.69365 .47228 L
s
1 .015 0 r
.53123 .70102 m
.53176 .7005 L
s
1 .013 0 r
.4359 .54829 m
.43602 .54844 L
s
.43576 .54837 m
.4359 .54829 L
s
.4359 .54829 m
.43596 .5483 L
s
1 .039 0 r
.38401 .67507 m
.38431 .67556 L
s
.38368 .67526 m
.38401 .67507 L
s
.38401 .67507 m
.38437 .67518 L
s
.38431 .67556 m
.38399 .67576 L
s
.38437 .67518 m
.38431 .67556 L
s
1 .013 0 r
.43602 .54844 m
.43589 .54852 L
s
.43596 .5483 m
.43602 .54844 L
s
1 0 0 r
.48872 .42126 m
.48872 .42124 L
s
1 .013 0 r
.43589 .54852 m
.43576 .54837 L
s
.43576 .54837 m
.43596 .5483 L
s
1 0 0 r
.48872 .42124 m
.48873 .42124 L
s
.48872 .42124 m
.48872 .42124 L
s
.48872 .42124 m
.48872 .42124 L
s
.48873 .42124 m
.48872 .42125 L
s
.48872 .42124 m
.48873 .42124 L
s
.48872 .42125 m
.48872 .42124 L
s
.48872 .42124 m
.48872 .42124 L
s
.48872 .42124 m
.48872 .42125 L
s
1 .013 0 r
.43596 .5483 m
.43589 .54852 L
s
1 .058 0 r
.32628 .65 m
.32936 .64845 L
s
1 .002 0 r
.78932 .62449 m
.78936 .62442 L
s
1 0 0 r
.28376 .37021 m
.28376 .37021 L
s
.28376 .37021 m
.28376 .37021 L
s
.28376 .37021 m
.28376 .37021 L
s
.28376 .37021 m
.28376 .37021 L
s
.28376 .37021 m
.28376 .37021 L
s
.28376 .37021 m
.28376 .37021 L
s
.28376 .37021 m
.28376 .37021 L
s
.28376 .37021 m
.28376 .37021 L
s
.28376 .37021 m
.28376 .37021 L
s
1 .002 0 r
.78935 .62442 m
.78937 .62444 L
s
.78933 .62443 m
.78935 .62442 L
s
.78935 .62442 m
.78936 .62442 L
s
.78937 .62444 m
.78935 .62445 L
s
.78936 .62442 m
.78937 .62444 L
s
.78935 .62445 m
.78933 .62443 L
s
.78933 .62443 m
.78936 .62442 L
s
.78936 .62442 m
.78935 .62445 L
s
1 .039 0 r
.38399 .67576 m
.38368 .67526 L
s
.38368 .67526 m
.38437 .67518 L
s
.38437 .67518 m
.38399 .67576 L
s
1 .015 0 r
.53166 .70047 m
.53179 .70065 L
s
.53152 .70057 m
.53166 .70047 L
s
.53166 .70047 m
.53176 .7005 L
s
.53179 .70065 m
.53166 .70074 L
s
.53176 .7005 m
.53179 .70065 L
s
1 .004 0 r
.58437 .57346 m
.58446 .57329 L
s
1 .075 0 r
.28973 .52161 m
.29032 .52256 L
s
.28906 .52194 m
.28973 .52161 L
s
.28973 .52161 m
.29037 .52176 L
s
.29032 .52256 m
.28965 .5229 L
s
.29037 .52176 m
.29032 .52256 L
s
1 .015 0 r
.53166 .70074 m
.53152 .70057 L
s
.53152 .70057 m
.53176 .7005 L
s
.53176 .7005 m
.53166 .70074 L
s
1 .004 0 r
.58444 .57329 m
.58449 .57333 L
s
.5844 .57332 m
.58444 .57329 L
s
.58444 .57329 m
.58446 .57329 L
s
.58449 .57333 m
.58444 .57336 L
s
.58446 .57329 m
.58449 .57333 L
s
.58444 .57336 m
.5844 .57332 L
s
.5844 .57332 m
.58446 .57329 L
s
.58446 .57329 m
.58444 .57336 L
s
1 .238 0 r
.22229 .42381 m
.22082 .42057 L
s
.22514 .42057 m
.22229 .42381 L
s
1 .021 0 r
.37938 .52242 m
.37995 .5216 L
s
1 0 0 r
.84252 .4969 m
.84253 .49689 L
s
.84253 .49689 m
.84253 .49689 L
s
.84252 .49689 m
.84253 .49689 L
s
.84253 .49689 m
.84253 .49689 L
s
.84253 .49689 m
.84253 .49689 L
s
.84253 .49689 m
.84253 .49689 L
s
.84253 .49689 m
.84252 .49689 L
s
.84252 .49689 m
.84253 .49689 L
s
.84253 .49689 m
.84253 .49689 L
s
1 .238 0 r
.22082 .42057 m
.22514 .42057 L
s
1 .007 0 r
.68005 .72572 m
.68026 .72547 L
s
1 0 0 r
.63753 .44585 m
.63753 .44584 L
s
.63753 .44584 m
.63754 .44584 L
s
.63753 .44584 m
.63753 .44584 L
s
.63753 .44584 m
.63753 .44584 L
s
.63754 .44584 m
.63753 .44584 L
s
.63753 .44584 m
.63754 .44584 L
s
.63753 .44584 m
.63753 .44584 L
s
.63753 .44584 m
.63753 .44584 L
s
.63753 .44584 m
.63753 .44584 L
s
1 .02 0 r
.47504 .67468 m
.47579 .67399 L
s
1 .007 0 r
.68021 .72546 m
.68028 .72554 L
s
.68015 .72551 m
.68021 .72546 L
s
.68021 .72546 m
.68026 .72547 L
s
.68028 .72554 m
.68022 .72558 L
s
.68026 .72547 m
.68028 .72554 L
s
.68022 .72558 m
.68015 .72551 L
s
.68015 .72551 m
.68026 .72547 L
s
.68026 .72547 m
.68022 .72558 L
s
1 .001 0 r
.93826 .64916 m
.93828 .64912 L
s
1 0 0 r
.43251 .39479 m
.43251 .39478 L
s
.43251 .39478 m
.43251 .39478 L
s
.43251 .39478 m
.43251 .39478 L
s
.43251 .39478 m
.43251 .39478 L
s
.43251 .39478 m
.43251 .39478 L
s
.43251 .39478 m
.43251 .39478 L
s
.43251 .39478 m
.43251 .39478 L
s
.43251 .39478 m
.43251 .39478 L
s
.43251 .39478 m
.43251 .39478 L
s
1 .001 0 r
.93828 .64912 m
.93829 .64913 L
s
.93827 .64913 m
.93828 .64912 L
s
.93828 .64912 m
.93828 .64912 L
s
.93829 .64913 m
.93828 .64914 L
s
.93828 .64912 m
.93829 .64913 L
s
1 .075 0 r
.28965 .5229 m
.28906 .52194 L
s
.28906 .52194 m
.29037 .52176 L
s
1 .001 0 r
.93828 .64914 m
.93827 .64913 L
s
.93827 .64913 m
.93828 .64912 L
s
.93828 .64912 m
.93828 .64914 L
s
1 .075 0 r
.29037 .52176 m
.28965 .5229 L
s
1 .089 0 r
.26999 .62364 m
.27545 .62176 L
s
1 .021 0 r
.37985 .52159 m
.38004 .52182 L
s
.37964 .52171 m
.37985 .52159 L
s
.37985 .52159 m
.37995 .5216 L
s
1 .058 0 r
.32917 .64901 m
.32872 .64927 L
s
.32877 .64824 m
.32917 .64901 L
s
.32936 .64845 m
.32917 .64901 L
s
1 .021 0 r
.38004 .52182 m
.37983 .52194 L
s
.37995 .5216 m
.38004 .52182 L
s
1 .058 0 r
.32832 .6485 m
.32877 .64824 L
s
.32877 .64824 m
.32936 .64845 L
s
1 .002 0 r
.73324 .59811 m
.73328 .59804 L
s
.73327 .59804 m
.73329 .59806 L
s
.73325 .59805 m
.73327 .59804 L
s
.73327 .59804 m
.73328 .59804 L
s
.73329 .59806 m
.73327 .59807 L
s
.73328 .59804 m
.73329 .59806 L
s
.73327 .59807 m
.73325 .59805 L
s
.73325 .59805 m
.73328 .59804 L
s
.73328 .59804 m
.73327 .59807 L
s
1 .021 0 r
.37983 .52194 m
.37964 .52171 L
s
.37964 .52171 m
.37995 .5216 L
s
.37995 .5216 m
.37983 .52194 L
s
1 .005 0 r
.52819 .54706 m
.5283 .54685 L
s
1 .02 0 r
.47564 .67395 m
.47582 .67419 L
s
.47546 .67407 m
.47564 .67395 L
s
.47564 .67395 m
.47579 .67399 L
s
.47582 .67419 m
.47564 .67431 L
s
.47579 .67399 m
.47582 .67419 L
s
1 .005 0 r
.52828 .54684 m
.52833 .5469 L
s
.52822 .54688 m
.52828 .54684 L
s
.52828 .54684 m
.5283 .54685 L
s
.52833 .5469 m
.52828 .54693 L
s
.5283 .54685 m
.52833 .5469 L
s
1 .038 0 r
.3231 .49599 m
.32424 .4945 L
s
1 .005 0 r
.52828 .54693 m
.52822 .54688 L
s
.52822 .54688 m
.5283 .54685 L
s
.5283 .54685 m
.52828 .54693 L
s
1 .02 0 r
.47564 .67431 m
.47546 .67407 L
s
.47546 .67407 m
.47579 .67399 L
s
.47579 .67399 m
.47564 .67431 L
s
1 0 0 r
.78646 .47046 m
.78646 .47045 L
s
.78646 .47045 m
.78646 .47045 L
s
.78646 .47045 m
.78646 .47045 L
s
.78646 .47045 m
.78646 .47045 L
s
.78646 .47045 m
.78646 .47045 L
s
.78646 .47045 m
.78646 .47045 L
s
.78646 .47045 m
.78646 .47045 L
s
.78646 .47045 m
.78646 .47045 L
s
.78646 .47045 m
.78646 .47045 L
s
1 .058 0 r
.32872 .64927 m
.32832 .6485 L
s
.32936 .64845 m
.32872 .64927 L
s
.32832 .6485 m
.32936 .64845 L
s
1 .008 0 r
.6239 .69938 m
.62416 .69908 L
s
1 0 0 r
.58137 .41938 m
.58137 .41938 L
s
.58137 .41938 m
.58137 .41938 L
s
.58137 .41938 m
.58137 .41938 L
s
.58137 .41938 m
.58137 .41938 L
s
.58137 .41938 m
.58137 .41938 L
s
.58137 .41938 m
.58137 .41938 L
s
.58137 .41938 m
.58137 .41938 L
s
.58137 .41938 m
.58137 .41938 L
s
.58137 .41938 m
.58137 .41938 L
s
1 .029 0 r
.41879 .64832 m
.41994 .64735 L
s
1 .008 0 r
.62411 .69907 m
.62419 .69916 L
s
.62403 .69912 m
.62411 .69907 L
s
.62411 .69907 m
.62416 .69908 L
s
.62419 .69916 m
.62411 .69921 L
s
.62416 .69908 m
.62419 .69916 L
s
1 .001 0 r
.88223 .62279 m
.88225 .62275 L
s
1 0 0 r
.37624 .36829 m
.37624 .36829 L
s
.37624 .36829 m
.37624 .36829 L
s
.37624 .36829 m
.37624 .36829 L
s
.37624 .36829 m
.37624 .36829 L
s
.37624 .36829 m
.37624 .36829 L
s
.37624 .36829 m
.37624 .36829 L
s
.37624 .36829 m
.37624 .36829 L
s
.37624 .36829 m
.37624 .36829 L
s
.37624 .36829 m
.37624 .36829 L
s
1 .008 0 r
.62411 .69921 m
.62403 .69912 L
s
.62403 .69912 m
.62416 .69908 L
s
.62416 .69908 m
.62411 .69921 L
s
1 .001 0 r
.88225 .62274 m
.88226 .62276 L
s
.88224 .62275 m
.88225 .62274 L
s
.88225 .62274 m
.88225 .62275 L
s
.88226 .62276 m
.88225 .62276 L
s
.88225 .62275 m
.88226 .62276 L
s
.88225 .62276 m
.88224 .62275 L
s
.88224 .62275 m
.88225 .62275 L
s
.88225 .62275 m
.88225 .62276 L
s
1 .171 0 r
.23988 .4955 m
.23869 .49604 L
s
.2389 .49314 m
.23988 .4955 L
s
.24082 .49378 m
.23988 .4955 L
s
.2377 .49368 m
.2389 .49314 L
s
.2389 .49314 m
.24082 .49378 L
s
1 .002 0 r
.67711 .57171 m
.67715 .57163 L
s
1 .089 0 r
.27489 .6226 m
.2743 .62292 L
s
.2744 .62136 m
.27489 .6226 L
s
.27545 .62176 m
.27489 .6226 L
s
1 .002 0 r
.67714 .57163 m
.67716 .57165 L
s
.67712 .57164 m
.67714 .57163 L
s
.67714 .57163 m
.67715 .57163 L
s
.67716 .57165 m
.67714 .57166 L
s
.67715 .57163 m
.67716 .57165 L
s
.67714 .57166 m
.67712 .57164 L
s
.67712 .57164 m
.67715 .57163 L
s
.67715 .57163 m
.67714 .57166 L
s
1 .089 0 r
.27382 .62168 m
.2744 .62136 L
s
.2744 .62136 m
.27545 .62176 L
s
1 .007 0 r
.47196 .52063 m
.47209 .52035 L
s
1 .004 0 r
.77289 .7241 m
.773 .72395 L
s
1 .093 0 r
.26677 .46954 m
.27015 .46606 L
s
1 .007 0 r
.47206 .52035 m
.47213 .52042 L
s
.47199 .5204 m
.47206 .52035 L
s
.47206 .52035 m
.47209 .52035 L
s
1 .038 0 r
.32403 .49448 m
.32438 .49491 L
s
.32365 .49469 m
.32403 .49448 L
s
.32403 .49448 m
.32424 .4945 L
s
1 .007 0 r
.47213 .52042 m
.47206 .52047 L
s
.47209 .52035 m
.47213 .52042 L
s
.47206 .52047 m
.47199 .5204 L
s
.47199 .5204 m
.47209 .52035 L
s
1 .029 0 r
.41971 .64729 m
.41996 .64764 L
s
.41945 .64745 m
.41971 .64729 L
s
.41971 .64729 m
.41994 .64735 L
s
1 .007 0 r
.47209 .52035 m
.47206 .52047 L
s
1 .038 0 r
.32438 .49491 m
.324 .49512 L
s
.32424 .4945 m
.32438 .49491 L
s
1 .029 0 r
.41996 .64764 m
.4197 .6478 L
s
.41994 .64735 m
.41996 .64764 L
s
1 0 0 r
.73034 .44399 m
.73034 .44399 L
s
.73034 .44399 m
.73034 .44399 L
s
.73034 .44399 m
.73034 .44399 L
s
.73034 .44399 m
.73034 .44399 L
s
.73034 .44399 m
.73034 .44399 L
s
.73034 .44399 m
.73034 .44399 L
s
.73034 .44399 m
.73034 .44399 L
s
.73034 .44399 m
.73034 .44399 L
s
.73034 .44399 m
.73034 .44399 L
s
1 .004 0 r
.77298 .72394 m
.77302 .72399 L
s
.77294 .72397 m
.77298 .72394 L
s
.77298 .72394 m
.773 .72395 L
s
.77302 .72399 m
.77298 .72402 L
s
.773 .72395 m
.77302 .72399 L
s
.77298 .72402 m
.77294 .72397 L
s
.77294 .72397 m
.773 .72395 L
s
.773 .72395 m
.77298 .72402 L
s
1 .01 0 r
.56771 .67302 m
.56803 .67264 L
s
1 0 0 r
.52515 .39289 m
.52515 .39289 L
s
.52515 .39289 m
.52515 .39289 L
s
.52515 .39289 m
.52515 .39289 L
s
.52515 .39289 m
.52515 .39289 L
s
.52515 .39289 m
.52515 .39289 L
s
.52515 .39289 m
.52515 .39289 L
s
.52515 .39289 m
.52515 .39289 L
s
.52515 .39289 m
.52515 .39289 L
s
.52515 .39289 m
.52515 .39289 L
s
1 .029 0 r
.4197 .6478 m
.41945 .64745 L
s
.41945 .64745 m
.41994 .64735 L
s
1 .038 0 r
.324 .49512 m
.32365 .49469 L
s
.32365 .49469 m
.32424 .4945 L
s
1 .029 0 r
.41994 .64735 m
.4197 .6478 L
s
1 .044 0 r
.36249 .62194 m
.36441 .62052 L
s
1 .038 0 r
.32424 .4945 m
.324 .49512 L
s
1 .001 0 r
.82615 .59639 m
.82617 .59634 L
s
1 .01 0 r
.56797 .67262 m
.56807 .67274 L
s
.56787 .67269 m
.56797 .67262 L
s
.56797 .67262 m
.56803 .67264 L
s
1 .001 0 r
.82616 .59634 m
.82617 .59635 L
s
.82615 .59635 m
.82616 .59634 L
s
.82616 .59634 m
.82617 .59634 L
s
1 .01 0 r
.56807 .67274 m
.56797 .67281 L
s
.56803 .67264 m
.56807 .67274 L
s
1 .001 0 r
.82617 .59635 m
.82616 .59636 L
s
.82617 .59634 m
.82617 .59635 L
s
.82616 .59636 m
.82615 .59635 L
s
.82615 .59635 m
.82617 .59634 L
s
.82617 .59634 m
.82616 .59636 L
s
1 .01 0 r
.56797 .67281 m
.56787 .67269 L
s
.56787 .67269 m
.56803 .67264 L
s
1 .089 0 r
.27545 .62176 m
.2743 .62292 L
s
.27382 .62168 m
.27545 .62176 L
s
.2743 .62292 m
.27382 .62168 L
s
1 .01 0 r
.56803 .67264 m
.56797 .67281 L
s
1 .002 0 r
.62093 .54529 m
.62097 .54519 L
s
.62096 .54519 m
.62098 .54522 L
s
.62094 .54521 m
.62096 .54519 L
s
.62096 .54519 m
.62097 .54519 L
s
.62098 .54522 m
.62096 .54523 L
s
.62097 .54519 m
.62098 .54522 L
s
.62096 .54523 m
.62094 .54521 L
s
.62094 .54521 m
.62097 .54519 L
s
.62097 .54519 m
.62096 .54523 L
s
1 .009 0 r
.41567 .49418 m
.41584 .49379 L
s
1 0 0 r
.87943 .46862 m
.87943 .46862 L
s
.87943 .46862 m
.87943 .46862 L
s
.87943 .46862 m
.87943 .46862 L
s
.87943 .46862 m
.87943 .46862 L
s
.87943 .46862 m
.87943 .46862 L
s
.87943 .46862 m
.87943 .46862 L
s
.87943 .46862 m
.87943 .46862 L
s
.87943 .46862 m
.87943 .46862 L
s
.87943 .46862 m
.87943 .46862 L
s
1 .005 0 r
.71674 .69774 m
.71687 .69756 L
s
1 .375 0 r
.21038 .44306 m
.23165 .43315 L
s
1 .009 0 r
.41581 .49379 m
.4159 .49389 L
s
.41571 .49385 m
.41581 .49379 L
s
.41581 .49379 m
.41584 .49379 L
s
1 0 0 r
.67417 .4175 m
.67417 .4175 L
s
.67417 .4175 m
.67417 .4175 L
s
.67417 .4175 m
.67417 .4175 L
s
.67417 .4175 m
.67417 .4175 L
s
.67417 .4175 m
.67417 .4175 L
s
.67417 .4175 m
.67417 .4175 L
s
.67417 .4175 m
.67417 .4175 L
s
.67417 .4175 m
.67417 .4175 L
s
.67417 .4175 m
.67417 .4175 L
s
1 .009 0 r
.4159 .49389 m
.41581 .49395 L
s
.41584 .49379 m
.4159 .49389 L
s
1 .005 0 r
.71684 .69756 m
.71689 .69761 L
s
.7168 .69759 m
.71684 .69756 L
s
.71684 .69756 m
.71687 .69756 L
s
.71689 .69761 m
.71685 .69764 L
s
.71687 .69756 m
.71689 .69761 L
s
1 .009 0 r
.41581 .49395 m
.41571 .49385 L
s
.41571 .49385 m
.41584 .49379 L
s
1 .005 0 r
.71685 .69764 m
.7168 .69759 L
s
.7168 .69759 m
.71687 .69756 L
s
1 .009 0 r
.41584 .49379 m
.41581 .49395 L
s
1 .005 0 r
.71687 .69756 m
.71685 .69764 L
s
1 .014 0 r
.51146 .64664 m
.5119 .64613 L
s
1 .171 0 r
.23869 .49604 m
.2377 .49368 L
s
.24082 .49378 m
.23869 .49604 L
s
.2377 .49368 m
.24082 .49378 L
s
1 0 0 r
.46887 .36637 m
.46887 .36637 L
s
.46887 .36637 m
.46887 .36637 L
s
.46887 .36637 m
.46887 .36637 L
s
.46887 .36637 m
.46887 .36637 L
s
.46887 .36637 m
.46887 .36637 L
s
.46887 .36637 m
.46887 .36637 L
s
.46887 .36637 m
.46887 .36637 L
s
.46887 .36637 m
.46887 .36637 L
s
.46887 .36637 m
.46887 .36637 L
s
1 .072 0 r
.30614 .59553 m
.30976 .59342 L
s
1 .044 0 r
.36404 .62042 m
.3644 .62097 L
s
.36365 .62064 m
.36404 .62042 L
s
.36404 .62042 m
.36441 .62052 L
s
.3644 .62097 m
.36401 .62119 L
s
.36441 .62052 m
.3644 .62097 L
s
1 .001 0 r
.77001 .56997 m
.77003 .56992 L
s
.77003 .56992 m
.77004 .56993 L
s
.77002 .56993 m
.77003 .56992 L
s
.77003 .56992 m
.77003 .56992 L
s
.77004 .56993 m
.77003 .56994 L
s
.77003 .56992 m
.77004 .56993 L
s
.77003 .56994 m
.77002 .56993 L
s
.77002 .56993 m
.77003 .56992 L
s
.77003 .56992 m
.77003 .56994 L
s
1 .014 0 r
.51181 .64611 m
.51194 .64626 L
s
.51168 .64619 m
.51181 .64611 L
s
.51181 .64611 m
.5119 .64613 L
s
.51194 .64626 m
.51181 .64635 L
s
.5119 .64613 m
.51194 .64626 L
s
1 .003 0 r
.56469 .51884 m
.56473 .51873 L
s
1 .014 0 r
.51181 .64635 m
.51168 .64619 L
s
.51168 .64619 m
.5119 .64613 L
s
.5119 .64613 m
.51181 .64635 L
s
1 .003 0 r
.56472 .51873 m
.56475 .51875 L
s
.5647 .51875 m
.56472 .51873 L
s
.56472 .51873 m
.56473 .51873 L
s
.56475 .51875 m
.56472 .51877 L
s
.56473 .51873 m
.56475 .51875 L
s
.56472 .51877 m
.5647 .51875 L
s
.5647 .51875 m
.56473 .51873 L
s
.56473 .51873 m
.56472 .51877 L
s
1 .044 0 r
.36401 .62119 m
.36365 .62064 L
s
.36365 .62064 m
.36441 .62052 L
s
.36441 .62052 m
.36401 .62119 L
s
1 .003 0 r
.86588 .72248 m
.86595 .72238 L
s
1 .014 0 r
.35933 .46771 m
.35958 .46709 L
s
1 .003 0 r
.86594 .72238 m
.86597 .72241 L
s
.86592 .7224 m
.86594 .72238 L
s
.86594 .72238 m
.86595 .72238 L
s
.86597 .72241 m
.86594 .72243 L
s
.86595 .72238 m
.86597 .72241 L
s
.86594 .72243 m
.86592 .7224 L
s
.86592 .7224 m
.86595 .72238 L
s
.86595 .72238 m
.86594 .72243 L
s
1 0 0 r
.8233 .44213 m
.82331 .44213 L
s
.82331 .44213 m
.82331 .44213 L
s
.8233 .44213 m
.82331 .44213 L
s
.82331 .44213 m
.82331 .44213 L
s
.82331 .44213 m
.82331 .44213 L
s
.82331 .44213 m
.82331 .44213 L
s
.82331 .44213 m
.8233 .44213 L
s
.8233 .44213 m
.82331 .44213 L
s
.82331 .44213 m
.82331 .44213 L
s
1 .006 0 r
.66054 .67136 m
.66069 .67114 L
s
1 0 0 r
.61794 .39099 m
.61794 .39099 L
s
.61794 .39099 m
.61794 .39099 L
s
.61794 .39099 m
.61794 .39099 L
s
.61794 .39099 m
.61794 .39099 L
s
.61794 .39099 m
.61794 .39099 L
s
.61794 .39099 m
.61794 .39099 L
s
.61794 .39099 m
.61794 .39099 L
s
.61794 .39099 m
.61794 .39099 L
s
.61794 .39099 m
.61794 .39099 L
s
1 .006 0 r
.66066 .67113 m
.66072 .6712 L
s
.66061 .67117 m
.66066 .67113 L
s
.66066 .67113 m
.66069 .67114 L
s
.66072 .6712 m
.66066 .67124 L
s
.66069 .67114 m
.66072 .6712 L
s
1 .019 0 r
.45515 .62023 m
.45579 .61951 L
s
1 .006 0 r
.66066 .67124 m
.66061 .67117 L
s
.66061 .67117 m
.66069 .67114 L
s
.66069 .67114 m
.66066 .67124 L
s
1 .014 0 r
.35954 .46709 m
.35968 .46724 L
s
.35939 .46719 m
.35954 .46709 L
s
.35954 .46709 m
.35958 .46709 L
s
1 .001 0 r
.91921 .59466 m
.91922 .59463 L
s
1 .014 0 r
.35968 .46724 m
.35953 .46734 L
s
.35958 .46709 m
.35968 .46724 L
s
1 .001 0 r
.91922 .59463 m
.91923 .59464 L
s
.91921 .59464 m
.91922 .59463 L
s
.91922 .59463 m
.91922 .59463 L
s
.91923 .59464 m
.91922 .59464 L
s
.91922 .59463 m
.91923 .59464 L
s
.91922 .59464 m
.91921 .59464 L
s
.91921 .59464 m
.91922 .59463 L
s
.91922 .59463 m
.91922 .59464 L
s
1 .093 0 r
.26953 .46597 m
.27034 .46709 L
s
.26861 .46643 m
.26953 .46597 L
s
.26953 .46597 m
.27015 .46606 L
s
1 .014 0 r
.35953 .46734 m
.35939 .46719 L
s
.35939 .46719 m
.35958 .46709 L
s
1 .126 0 r
.24974 .56909 m
.25737 .56631 L
s
1 .014 0 r
.35958 .46709 m
.35953 .46734 L
s
1 .093 0 r
.27034 .46709 m
.26942 .46755 L
s
.27015 .46606 m
.27034 .46709 L
s
1 .001 0 r
.71382 .54352 m
.71384 .54347 L
s
.71384 .54347 m
.71385 .54348 L
s
.71383 .54348 m
.71384 .54347 L
s
.71384 .54347 m
.71384 .54347 L
s
.71385 .54348 m
.71384 .54349 L
s
.71384 .54347 m
.71385 .54348 L
s
.71384 .54349 m
.71383 .54348 L
s
.71383 .54348 m
.71384 .54347 L
s
.71384 .54347 m
.71384 .54349 L
s
1 .003 0 r
.5084 .49237 m
.50844 .49224 L
s
1 .019 0 r
.45567 .61948 m
.45585 .61971 L
s
.45548 .6196 m
.45567 .61948 L
s
.45567 .61948 m
.45579 .61951 L
s
1 .053 0 r
.34556 .72167 m
.34851 .72034 L
s
1 .003 0 r
.50843 .49224 m
.50846 .49227 L
s
.5084 .49226 m
.50843 .49224 L
s
.50843 .49224 m
.50844 .49224 L
s
1 .019 0 r
.45585 .61971 m
.45566 .61983 L
s
.45579 .61951 m
.45585 .61971 L
s
1 .003 0 r
.50846 .49227 m
.50843 .49229 L
s
.50844 .49224 m
.50846 .49227 L
s
.50843 .49229 m
.5084 .49226 L
s
.5084 .49226 m
.50844 .49224 L
s
.50844 .49224 m
.50843 .49229 L
s
1 .072 0 r
.30907 .59322 m
.30959 .59416 L
s
.30847 .59353 m
.30907 .59322 L
s
.30907 .59322 m
.30976 .59342 L
s
.30959 .59416 m
.309 .59447 L
s
.30976 .59342 m
.30959 .59416 L
s
1 .003 0 r
.80973 .6961 m
.80981 .69599 L
s
1 .028 0 r
.30294 .4412 m
.3034 .44 L
s
1 .019 0 r
.45566 .61983 m
.45548 .6196 L
s
.45548 .6196 m
.45579 .61951 L
s
.45579 .61951 m
.45566 .61983 L
s
1 .003 0 r
.80979 .69599 m
.80982 .69602 L
s
.80976 .69601 m
.80979 .69599 L
s
.80979 .69599 m
.80981 .69599 L
s
.80982 .69602 m
.80979 .69604 L
s
.80981 .69599 m
.80982 .69602 L
s
1 0 0 r
.76713 .41562 m
.76713 .41562 L
s
.76713 .41562 m
.76713 .41562 L
s
.76713 .41562 m
.76713 .41562 L
s
.76713 .41562 m
.76713 .41562 L
s
.76713 .41562 m
.76713 .41562 L
s
.76713 .41562 m
.76713 .41562 L
s
.76713 .41562 m
.76713 .41562 L
s
.76713 .41562 m
.76713 .41562 L
s
.76713 .41562 m
.76713 .41562 L
s
1 .003 0 r
.80979 .69604 m
.80976 .69601 L
s
.80976 .69601 m
.80981 .69599 L
s
.80981 .69599 m
.80979 .69604 L
s
1 .007 0 r
.60428 .64495 m
.60447 .64468 L
s
1 .093 0 r
.26942 .46755 m
.26861 .46643 L
s
.26861 .46643 m
.27015 .46606 L
s
1 0 0 r
.56167 .36445 m
.56167 .36445 L
s
.56167 .36445 m
.56167 .36445 L
s
.56167 .36445 m
.56167 .36445 L
s
.56167 .36445 m
.56167 .36445 L
s
.56167 .36445 m
.56167 .36445 L
s
.56167 .36445 m
.56167 .36445 L
s
.56167 .36445 m
.56167 .36445 L
s
.56167 .36445 m
.56167 .36445 L
s
.56167 .36445 m
.56167 .36445 L
s
1 .029 0 r
.3988 .5938 m
.39982 .59272 L
s
1 .093 0 r
.27015 .46606 m
.26942 .46755 L
s
1 .007 0 r
.60443 .64467 m
.6045 .64475 L
s
.60437 .64472 m
.60443 .64467 L
s
.60443 .64467 m
.60447 .64468 L
s
.6045 .64475 m
.60444 .6448 L
s
.60447 .64468 m
.6045 .64475 L
s
.60444 .6448 m
.60437 .64472 L
s
.60437 .64472 m
.60447 .64468 L
s
.60447 .64468 m
.60444 .6448 L
s
1 .001 0 r
.86307 .56821 m
.86308 .56819 L
s
.86308 .56819 m
.86309 .56819 L
s
.86307 .56819 m
.86308 .56819 L
s
.86308 .56819 m
.86308 .56819 L
s
.86309 .56819 m
.86308 .5682 L
s
.86308 .56819 m
.86309 .56819 L
s
.86308 .5682 m
.86307 .56819 L
s
.86307 .56819 m
.86308 .56819 L
s
.86308 .56819 m
.86308 .5682 L
s
.65758 .51704 m
.6576 .51699 L
s
1 .072 0 r
.309 .59447 m
.30847 .59353 L
s
.30847 .59353 m
.30976 .59342 L
s
.30976 .59342 m
.309 .59447 L
s
1 .001 0 r
.65759 .51699 m
.65761 .517 L
s
.65758 .517 m
.65759 .51699 L
s
.65759 .51699 m
.6576 .51699 L
s
.65761 .517 m
.65759 .51701 L
s
.6576 .51699 m
.65761 .517 L
s
.65759 .51701 m
.65758 .517 L
s
.65758 .517 m
.6576 .51699 L
s
.6576 .51699 m
.65759 .51701 L
s
1 .002 0 r
.95904 .72086 m
.95909 .7208 L
s
1 .028 0 r
.30332 .44001 m
.30359 .44029 L
s
.30302 .44019 m
.30332 .44001 L
s
.30332 .44001 m
.3034 .44 L
s
1 .003 0 r
.45206 .46587 m
.4521 .46571 L
s
1 .053 0 r
.3483 .72084 m
.3479 .72109 L
s
.34795 .72013 m
.3483 .72084 L
s
.34851 .72034 m
.3483 .72084 L
s
.34754 .72037 m
.34795 .72013 L
s
.34795 .72013 m
.34851 .72034 L
s
1 .002 0 r
.95908 .72079 m
.95909 .72081 L
s
.95906 .72081 m
.95908 .72079 L
s
.95908 .72079 m
.95909 .7208 L
s
.95909 .72081 m
.95908 .72082 L
s
.95909 .7208 m
.95909 .72081 L
s
.95908 .72082 m
.95906 .72081 L
s
.95906 .72081 m
.95909 .7208 L
s
.95909 .7208 m
.95908 .72082 L
s
1 .028 0 r
.30359 .44029 m
.30329 .44047 L
s
.3034 .44 m
.30359 .44029 L
s
1 .075 0 r
.28914 .69528 m
.29379 .69377 L
s
1 .003 0 r
.45209 .46572 m
.45212 .46575 L
s
.45205 .46574 m
.45209 .46572 L
s
.45209 .46572 m
.4521 .46571 L
s
.45212 .46575 m
.45209 .46577 L
s
.4521 .46571 m
.45212 .46575 L
s
.45209 .46577 m
.45205 .46574 L
s
.45205 .46574 m
.4521 .46571 L
s
.4521 .46571 m
.45209 .46577 L
s
.75353 .66969 m
.75361 .66957 L
s
1 .028 0 r
.30329 .44047 m
.30302 .44019 L
s
.30302 .44019 m
.3034 .44 L
s
1 .093 0 r
.2465 .41468 m
.24793 .41058 L
s
1 .028 0 r
.3034 .44 m
.30329 .44047 L
s
1 .003 0 r
.75359 .66956 m
.75363 .6696 L
s
.75356 .66959 m
.75359 .66956 L
s
.75359 .66956 m
.75361 .66957 L
s
1 0 0 r
.7109 .38908 m
.7109 .38908 L
s
.7109 .38908 m
.7109 .38908 L
s
.7109 .38908 m
.7109 .38908 L
s
.7109 .38908 m
.7109 .38908 L
s
.7109 .38908 m
.7109 .38908 L
s
.7109 .38908 m
.7109 .38908 L
s
.7109 .38908 m
.7109 .38908 L
s
.7109 .38908 m
.7109 .38908 L
s
.7109 .38908 m
.7109 .38908 L
s
1 .003 0 r
.75363 .6696 m
.75359 .66962 L
s
.75361 .66957 m
.75363 .6696 L
s
.75359 .66962 m
.75356 .66959 L
s
.75356 .66959 m
.75361 .66957 L
s
.75361 .66957 m
.75359 .66962 L
s
1 .029 0 r
.39962 .59268 m
.39989 .59303 L
s
.39934 .59285 m
.39962 .59268 L
s
.39962 .59268 m
.39982 .59272 L
s
1 .126 0 r
.25662 .56753 m
.25577 .56796 L
s
.25592 .56578 m
.25662 .56753 L
s
.25737 .56631 m
.25662 .56753 L
s
1 .029 0 r
.39989 .59303 m
.39961 .59319 L
s
.39982 .59272 m
.39989 .59303 L
s
1 .009 0 r
.54797 .61852 m
.54822 .61817 L
s
1 .126 0 r
.25506 .56621 m
.25592 .56578 L
s
.25592 .56578 m
.25737 .56631 L
s
1 .053 0 r
.3479 .72109 m
.34754 .72037 L
s
.34851 .72034 m
.3479 .72109 L
s
1 .029 0 r
.39961 .59319 m
.39934 .59285 L
s
.39934 .59285 m
.39982 .59272 L
s
1 .053 0 r
.34754 .72037 m
.34851 .72034 L
s
1 .049 0 r
.34239 .56734 m
.34427 .5656 L
s
1 .029 0 r
.39982 .59272 m
.39961 .59319 L
s
1 .009 0 r
.54817 .61816 m
.54826 .61826 L
s
.54808 .61822 m
.54817 .61816 L
s
.54817 .61816 m
.54822 .61817 L
s
1 .001 0 r
.80688 .54174 m
.80689 .54171 L
s
1 .009 0 r
.54826 .61826 m
.54817 .61832 L
s
.54822 .61817 m
.54826 .61826 L
s
1 .001 0 r
.80688 .54171 m
.80689 .54172 L
s
.80688 .54172 m
.80688 .54171 L
s
.80688 .54171 m
.80689 .54171 L
s
.80689 .54172 m
.80688 .54173 L
s
.80689 .54171 m
.80689 .54172 L
s
.80688 .54173 m
.80688 .54172 L
s
.80688 .54172 m
.80689 .54171 L
s
.80689 .54171 m
.80688 .54173 L
s
1 .009 0 r
.54817 .61832 m
.54808 .61822 L
s
.54808 .61822 m
.54822 .61817 L
s
.54822 .61817 m
.54817 .61832 L
s
1 .001 0 r
.60129 .49055 m
.6013 .49049 L
s
.6013 .49049 m
.60131 .49051 L
s
.60128 .4905 m
.6013 .49049 L
s
.6013 .49049 m
.6013 .49049 L
s
.60131 .49051 m
.6013 .49051 L
s
.6013 .49049 m
.60131 .49051 L
s
.6013 .49051 m
.60128 .4905 L
s
.60128 .4905 m
.6013 .49049 L
s
.6013 .49049 m
.6013 .49051 L
s
1 .031 0 r
.43831 .72005 m
.43967 .71909 L
s
1 .002 0 r
.90288 .69446 m
.90293 .69438 L
s
1 .004 0 r
.39566 .43934 m
.39569 .43916 L
s
1 .075 0 r
.29331 .69444 m
.29282 .69474 L
s
.2929 .69339 m
.29331 .69444 L
s
.29379 .69377 m
.29331 .69444 L
s
1 .002 0 r
.90292 .69438 m
.90294 .6944 L
s
.9029 .6944 m
.90292 .69438 L
s
.90292 .69438 m
.90293 .69438 L
s
.90294 .6944 m
.90292 .69442 L
s
.90293 .69438 m
.90294 .6944 L
s
.90292 .69442 m
.9029 .6944 L
s
.9029 .6944 m
.90293 .69438 L
s
.90293 .69438 m
.90292 .69442 L
s
1 .075 0 r
.29242 .69369 m
.2929 .69339 L
s
.2929 .69339 m
.29379 .69377 L
s
1 0 0 r
.86025 .41373 m
.86025 .41373 L
s
.86025 .41373 m
.86025 .41373 L
s
.86025 .41373 m
.86025 .41373 L
s
.86025 .41373 m
.86025 .41373 L
s
.86025 .41373 m
.86025 .41373 L
s
.86025 .41373 m
.86025 .41373 L
s
.86025 .41373 m
.86025 .41373 L
s
.86025 .41373 m
.86025 .41373 L
s
.86025 .41373 m
.86025 .41373 L
s
1 .004 0 r
.39569 .43916 m
.39573 .4392 L
s
.39564 .43919 m
.39569 .43916 L
s
.39569 .43916 m
.39569 .43916 L
s
.39573 .4392 m
.39569 .43923 L
s
.39569 .43916 m
.39573 .4392 L
s
.39569 .43923 m
.39564 .43919 L
s
.39564 .43919 m
.39569 .43916 L
s
.39569 .43916 m
.39569 .43923 L
s
.69727 .64326 m
.69736 .64311 L
s
0 .558 1 r
.19 .38813 m
.24285 .22326 L
s
1 0 0 r
.65462 .36252 m
.65462 .36252 L
s
.65462 .36252 m
.65462 .36252 L
s
.65462 .36252 m
.65462 .36252 L
s
.65462 .36252 m
.65462 .36252 L
s
.65462 .36252 m
.65462 .36252 L
s
.65462 .36252 m
.65462 .36252 L
s
.65462 .36252 m
.65462 .36252 L
s
.65462 .36252 m
.65462 .36252 L
s
.65462 .36252 m
.65462 .36252 L
s
1 .004 0 r
.69734 .64311 m
.69738 .64315 L
s
.6973 .64314 m
.69734 .64311 L
s
.69734 .64311 m
.69736 .64311 L
s
.69738 .64315 m
.69734 .64318 L
s
.69736 .64311 m
.69738 .64315 L
s
.69734 .64318 m
.6973 .64314 L
s
.6973 .64314 m
.69736 .64311 L
s
.69736 .64311 m
.69734 .64318 L
s
1 .012 0 r
.49161 .59206 m
.49194 .59158 L
s
1 .094 0 r
.28593 .54085 m
.29018 .53782 L
s
1 .126 0 r
.25737 .56631 m
.25577 .56796 L
s
.25506 .56621 m
.25737 .56631 L
s
.25577 .56796 m
.25506 .56621 L
s
1 .031 0 r
.4394 .719 m
.43966 .71938 L
s
.43913 .71917 m
.4394 .719 L
s
.4394 .719 m
.43967 .71909 L
s
1 .001 0 r
.75063 .51525 m
.75064 .51522 L
s
1 .031 0 r
.43966 .71938 m
.43939 .71955 L
s
.43967 .71909 m
.43966 .71938 L
s
1 .001 0 r
.75064 .51522 m
.75064 .51522 L
s
.75063 .51522 m
.75064 .51522 L
s
.75064 .51522 m
.75064 .51522 L
s
.75064 .51522 m
.75064 .51523 L
s
.75064 .51522 m
.75064 .51522 L
s
.75064 .51523 m
.75063 .51522 L
s
.75063 .51522 m
.75064 .51522 L
s
.75064 .51522 m
.75064 .51523 L
s
1 .012 0 r
.49187 .59157 m
.49199 .59171 L
s
.49175 .59165 m
.49187 .59157 L
s
.49187 .59157 m
.49194 .59158 L
s
.49199 .59171 m
.49187 .59179 L
s
.49194 .59158 m
.49199 .59171 L
s
1 .049 0 r
.34392 .56553 m
.34434 .56612 L
s
.34345 .56578 m
.34392 .56553 L
s
.34392 .56553 m
.34427 .5656 L
s
1 .075 0 r
.29379 .69377 m
.29282 .69474 L
s
.29242 .69369 m
.29379 .69377 L
s
.29282 .69474 m
.29242 .69369 L
s
1 .012 0 r
.49187 .59179 m
.49175 .59165 L
s
.49175 .59165 m
.49194 .59158 L
s
1 .049 0 r
.34434 .56612 m
.34388 .56638 L
s
.34427 .5656 m
.34434 .56612 L
s
1 .012 0 r
.49194 .59158 m
.49187 .59179 L
s
1 .001 0 r
.54494 .46402 m
.54495 .46397 L
s
.54495 .46397 m
.54496 .46398 L
s
.54493 .46398 m
.54495 .46397 L
s
.54495 .46397 m
.54495 .46397 L
s
.54496 .46398 m
.54495 .46399 L
s
.54495 .46397 m
.54496 .46398 L
s
.54495 .46399 m
.54493 .46398 L
s
.54493 .46398 m
.54495 .46397 L
s
.54495 .46397 m
.54495 .46399 L
s
1 .031 0 r
.43939 .71955 m
.43913 .71917 L
s
.43913 .71917 m
.43967 .71909 L
s
1 .044 0 r
.38189 .69363 m
.38398 .69233 L
s
1 .031 0 r
.43967 .71909 m
.43939 .71955 L
s
1 .002 0 r
.84667 .66803 m
.84672 .66795 L
s
1 .005 0 r
.33921 .41279 m
.33923 .41257 L
s
1 .002 0 r
.84671 .66795 m
.84673 .66797 L
s
.84669 .66796 m
.84671 .66795 L
s
.84671 .66795 m
.84672 .66795 L
s
.84673 .66797 m
.84671 .66798 L
s
.84672 .66795 m
.84673 .66797 L
s
.84671 .66798 m
.84669 .66796 L
s
.84669 .66796 m
.84672 .66795 L
s
.84672 .66795 m
.84671 .66798 L
s
1 0 0 r
.80402 .38717 m
.80402 .38717 L
s
.80402 .38717 m
.80402 .38717 L
s
.80402 .38717 m
.80402 .38717 L
s
.80402 .38717 m
.80402 .38717 L
s
.80402 .38717 m
.80402 .38717 L
s
.80402 .38717 m
.80402 .38717 L
s
.80402 .38717 m
.80402 .38717 L
s
.80402 .38717 m
.80402 .38717 L
s
.80402 .38717 m
.80402 .38717 L
s
1 .005 0 r
.33922 .41257 m
.33927 .41262 L
s
.33917 .41261 m
.33922 .41257 L
s
.33922 .41257 m
.33923 .41257 L
s
1 .049 0 r
.34388 .56638 m
.34345 .56578 L
s
.34345 .56578 m
.34427 .5656 L
s
1 .005 0 r
.33927 .41262 m
.33922 .41265 L
s
.33923 .41257 m
.33927 .41262 L
s
.33922 .41265 m
.33917 .41261 L
s
.33917 .41261 m
.33923 .41257 L
s
.64095 .61681 m
.64106 .61663 L
s
.33923 .41257 m
.33922 .41265 L
s
1 .049 0 r
.34427 .5656 m
.34388 .56638 L
s
1 .005 0 r
.64104 .61662 m
.64109 .61667 L
s
.64099 .61665 m
.64104 .61662 L
s
.64104 .61662 m
.64106 .61663 L
s
.64109 .61667 m
.64104 .6167 L
s
.64106 .61663 m
.64109 .61667 L
s
.64104 .6167 m
.64099 .61665 L
s
.64099 .61665 m
.64106 .61663 L
s
.64106 .61663 m
.64104 .6167 L
s
1 .018 0 r
.4352 .56558 m
.43567 .56488 L
s
1 0 0 r
.90009 .53996 m
.9001 .53995 L
s
.9001 .53995 m
.9001 .53995 L
s
.90009 .53995 m
.9001 .53995 L
s
.9001 .53995 m
.9001 .53995 L
s
.9001 .53995 m
.9001 .53995 L
s
.9001 .53995 m
.9001 .53995 L
s
.9001 .53995 m
.90009 .53995 L
s
.90009 .53995 m
.9001 .53995 L
s
.9001 .53995 m
.9001 .53995 L
s
1 .206 0 r
.22941 .51434 m
.24169 .50951 L
s
1 .001 0 r
.69433 .48872 m
.69434 .4887 L
s
.69434 .4887 m
.69434 .4887 L
s
.69433 .4887 m
.69434 .4887 L
s
.69434 .4887 m
.69434 .4887 L
s
.69434 .4887 m
.69434 .48871 L
s
.69434 .4887 m
.69434 .4887 L
s
.69434 .48871 m
.69433 .4887 L
s
.69433 .4887 m
.69434 .4887 L
s
.69434 .4887 m
.69434 .48871 L
s
1 .017 0 r
.53122 .71842 m
.53184 .71783 L
s
1 .001 0 r
.48854 .43747 m
.48854 .43743 L
s
1 .044 0 r
.38357 .6922 m
.38392 .69276 L
s
.3832 .69242 m
.38357 .6922 L
s
.38357 .6922 m
.38398 .69233 L
s
1 .001 0 r
.48854 .43743 m
.48855 .43744 L
s
.48853 .43744 m
.48854 .43743 L
s
.48854 .43743 m
.48854 .43743 L
s
1 .018 0 r
.43558 .56487 m
.43575 .56506 L
s
.4354 .56498 m
.43558 .56487 L
s
.43558 .56487 m
.43567 .56488 L
s
1 .001 0 r
.48855 .43744 m
.48854 .43744 L
s
.48854 .43743 m
.48855 .43744 L
s
.48854 .43744 m
.48853 .43744 L
s
.48853 .43744 m
.48854 .43743 L
s
.48854 .43743 m
.48854 .43744 L
s
1 .044 0 r
.38392 .69276 m
.38354 .69298 L
s
.38398 .69233 m
.38392 .69276 L
s
1 .018 0 r
.43575 .56506 m
.43557 .56518 L
s
.43567 .56488 m
.43575 .56506 L
s
1 .065 0 r
.32541 .66719 m
.32887 .66545 L
s
1 .093 0 r
.2477 .41063 m
.24861 .41158 L
s
.24668 .41123 m
.2477 .41063 L
s
.2477 .41063 m
.24793 .41058 L
s
1 .018 0 r
.43557 .56518 m
.4354 .56498 L
s
.4354 .56498 m
.43567 .56488 L
s
1 .002 0 r
.79041 .64157 m
.79046 .64148 L
s
1 .005 0 r
.28271 .38622 m
.28268 .38597 L
s
1 .018 0 r
.43567 .56488 m
.43557 .56518 L
s
1 .002 0 r
.79045 .64148 m
.79047 .6415 L
s
.79043 .6415 m
.79045 .64148 L
s
.79045 .64148 m
.79046 .64148 L
s
.79047 .6415 m
.79045 .64152 L
s
.79046 .64148 m
.79047 .6415 L
s
.79045 .64152 m
.79043 .6415 L
s
.79043 .6415 m
.79046 .64148 L
s
.79046 .64148 m
.79045 .64152 L
s
1 0 0 r
.74773 .36058 m
.74773 .36058 L
s
.74773 .36058 m
.74773 .36058 L
s
.74773 .36058 m
.74773 .36058 L
s
.74773 .36058 m
.74773 .36058 L
s
.74773 .36058 m
.74773 .36058 L
s
.74773 .36058 m
.74773 .36058 L
s
.74773 .36058 m
.74773 .36058 L
s
.74773 .36058 m
.74773 .36058 L
s
.74773 .36058 m
.74773 .36058 L
s
1 .375 0 r
.22997 .43713 m
.22713 .43829 L
s
.22763 .43199 m
.22997 .43713 L
s
.23165 .43315 m
.22997 .43713 L
s
1 .017 0 r
.53172 .7178 m
.53188 .718 L
s
.53156 .7179 m
.53172 .7178 L
s
.53172 .7178 m
.53184 .71783 L
s
1 .005 0 r
.28268 .38597 m
.28274 .38602 L
s
.28263 .38602 m
.28268 .38597 L
s
.28268 .38597 m
.28268 .38597 L
s
1 .093 0 r
.24861 .41158 m
.24758 .41218 L
s
.24793 .41058 m
.24861 .41158 L
s
1 .006 0 r
.58459 .59033 m
.58471 .5901 L
s
1 .005 0 r
.28268 .38606 m
.28263 .38602 L
s
.28263 .38602 m
.28268 .38597 L
s
.28274 .38602 m
.28268 .38606 L
s
.28268 .38597 m
.28274 .38602 L
s
1 .017 0 r
.53188 .718 m
.53172 .7181 L
s
.53184 .71783 m
.53188 .718 L
s
1 .005 0 r
.28268 .38597 m
.28268 .38606 L
s
1 .044 0 r
.38354 .69298 m
.3832 .69242 L
s
.3832 .69242 m
.38398 .69233 L
s
.38398 .69233 m
.38354 .69298 L
s
1 .017 0 r
.53172 .7181 m
.53156 .7179 L
s
.53156 .7179 m
.53184 .71783 L
s
.53184 .71783 m
.53172 .7181 L
s
1 .006 0 r
.58469 .5901 m
.58475 .59016 L
s
.58463 .59014 m
.58469 .5901 L
s
.58469 .5901 m
.58471 .5901 L
s
1 .375 0 r
.22478 .43315 m
.22763 .43199 L
s
.22763 .43199 m
.23165 .43315 L
s
1 .006 0 r
.58475 .59016 m
.58469 .59019 L
s
.58471 .5901 m
.58475 .59016 L
s
1 .028 0 r
.37873 .53907 m
.37952 .53796 L
s
1 .006 0 r
.58469 .59019 m
.58463 .59014 L
s
.58463 .59014 m
.58471 .5901 L
s
.58471 .5901 m
.58469 .59019 L
s
1 0 0 r
.84384 .51344 m
.84385 .51343 L
s
.84384 .51343 m
.84385 .51343 L
s
.84384 .51343 m
.84384 .51343 L
s
.84384 .51343 m
.84385 .51343 L
s
.84385 .51343 m
.84384 .51343 L
s
.84385 .51343 m
.84385 .51343 L
s
.84384 .51343 m
.84384 .51343 L
s
.84384 .51343 m
.84385 .51343 L
s
.84385 .51343 m
.84384 .51343 L
s
1 .093 0 r
.24758 .41218 m
.24668 .41123 L
s
.24668 .41123 m
.24793 .41058 L
s
1 .094 0 r
.28938 .53762 m
.29012 .53881 L
s
.28854 .53804 m
.28938 .53762 L
s
.28938 .53762 m
.29018 .53782 L
s
.29012 .53881 m
.28928 .53923 L
s
.29018 .53782 m
.29012 .53881 L
s
1 0 0 r
.63798 .46218 m
.63798 .46215 L
s
.63798 .46215 m
.63799 .46216 L
s
.63798 .46216 m
.63798 .46215 L
s
.63798 .46215 m
.63798 .46215 L
s
.63799 .46216 m
.63798 .46216 L
s
.63798 .46215 m
.63799 .46216 L
s
.63798 .46216 m
.63798 .46216 L
s
.63798 .46216 m
.63798 .46215 L
s
.63798 .46215 m
.63798 .46216 L
s
1 .023 0 r
.47479 .69198 m
.47567 .69119 L
s
1 .093 0 r
.24793 .41058 m
.24758 .41218 L
s
1 .001 0 r
.93998 .66636 m
.94001 .6663 L
s
.43208 .4109 m
.43208 .41086 L
s
.43208 .41086 m
.43209 .41087 L
s
.43207 .41087 m
.43208 .41086 L
s
.43208 .41086 m
.43208 .41086 L
s
.94001 .6663 m
.94002 .66632 L
s
.93999 .66631 m
.94001 .6663 L
s
.94001 .6663 m
.94001 .6663 L
s
.43209 .41087 m
.43208 .41088 L
s
.43208 .41086 m
.43209 .41087 L
s
.43208 .41088 m
.43207 .41087 L
s
.43207 .41087 m
.43208 .41086 L
s
.94002 .66632 m
.94001 .66633 L
s
.94001 .6663 m
.94002 .66632 L
s
.43208 .41086 m
.43208 .41088 L
s
.94001 .66633 m
.93999 .66631 L
s
.93999 .66631 m
.94001 .6663 L
s
.94001 .6663 m
.94001 .66633 L
s
1 .099 0 r
.26887 .64073 m
.27496 .63865 L
s
1 .002 0 r
.73409 .61509 m
.73415 .61499 L
s
1 .001 0 r
.22615 .35962 m
.22611 .35956 L
s
.22612 .35956 m
.22613 .35957 L
s
.2261 .35958 m
.22612 .35956 L
s
.22612 .35956 m
.22611 .35956 L
s
.22612 .35958 m
.2261 .35958 L
s
.2261 .35958 m
.22611 .35956 L
s
.22613 .35957 m
.22612 .35958 L
s
.22611 .35956 m
.22613 .35957 L
s
.22611 .35956 m
.22612 .35958 L
s
1 .002 0 r
.73414 .61499 m
.73416 .61502 L
s
.73411 .61501 m
.73414 .61499 L
s
.73414 .61499 m
.73415 .61499 L
s
.73416 .61502 m
.73414 .61503 L
s
.73415 .61499 m
.73416 .61502 L
s
.73414 .61503 m
.73411 .61501 L
s
.73411 .61501 m
.73415 .61499 L
s
.73415 .61499 m
.73414 .61503 L
s
1 .065 0 r
.32866 .66609 m
.32815 .66638 L
s
.32821 .66522 m
.32866 .66609 L
s
.32887 .66545 m
.32866 .66609 L
s
.3277 .66552 m
.32821 .66522 L
s
.32821 .66522 m
.32887 .66545 L
s
1 .028 0 r
.37937 .53794 m
.37964 .53825 L
s
.37908 .53811 m
.37937 .53794 L
s
.37937 .53794 m
.37952 .53796 L
s
1 .007 0 r
.52817 .56382 m
.52832 .56353 L
s
1 .028 0 r
.37964 .53825 m
.37935 .53842 L
s
.37952 .53796 m
.37964 .53825 L
s
1 .023 0 r
.4755 .69114 m
.47571 .69141 L
s
.47528 .69128 m
.4755 .69114 L
s
.4755 .69114 m
.47567 .69119 L
s
.47571 .69141 m
.47549 .69155 L
s
.47567 .69119 m
.47571 .69141 L
s
1 .028 0 r
.37935 .53842 m
.37908 .53811 L
s
.37908 .53811 m
.37952 .53796 L
s
1 .053 0 r
.32221 .51254 m
.32381 .51047 L
s
1 .007 0 r
.52829 .56353 m
.52836 .5636 L
s
.52822 .56358 m
.52829 .56353 L
s
.52829 .56353 m
.52832 .56353 L
s
1 .028 0 r
.37952 .53796 m
.37935 .53842 L
s
1 .007 0 r
.52836 .5636 m
.52829 .56365 L
s
.52832 .56353 m
.52836 .5636 L
s
1 .094 0 r
.28928 .53923 m
.28854 .53804 L
s
.28854 .53804 m
.29018 .53782 L
s
1 .007 0 r
.52829 .56365 m
.52822 .56358 L
s
.52822 .56358 m
.52832 .56353 L
s
.52832 .56353 m
.52829 .56365 L
s
1 0 0 r
.78754 .4869 m
.78754 .48688 L
s
1 .094 0 r
.29018 .53782 m
.28928 .53923 L
s
1 0 0 r
.78754 .48688 m
.78754 .48689 L
s
.78754 .48689 m
.78754 .48688 L
s
.78754 .48688 m
.78754 .48688 L
s
.78754 .48689 m
.78754 .48689 L
s
.78754 .48688 m
.78754 .48689 L
s
.78754 .48689 m
.78754 .48689 L
s
.78754 .48689 m
.78754 .48688 L
s
.78754 .48688 m
.78754 .48689 L
s
1 .023 0 r
.47549 .69155 m
.47528 .69128 L
s
.47528 .69128 m
.47567 .69119 L
s
.47567 .69119 m
.47549 .69155 L
s
1 .01 0 r
.62429 .71679 m
.6246 .71644 L
s
1 0 0 r
.58157 .4356 m
.58158 .43559 L
s
.58158 .43559 m
.58158 .43559 L
s
.58157 .43559 m
.58158 .43559 L
s
.58158 .43559 m
.58158 .43559 L
s
.58158 .43559 m
.58158 .43559 L
s
.58158 .43559 m
.58158 .43559 L
s
.58158 .43559 m
.58157 .43559 L
s
.58157 .43559 m
.58158 .43559 L
s
.58158 .43559 m
.58158 .43559 L
s
1 .065 0 r
.32815 .66638 m
.3277 .66552 L
s
.32887 .66545 m
.32815 .66638 L
s
1 .033 0 r
.41831 .66552 m
.41964 .6644 L
s
1 .065 0 r
.3277 .66552 m
.32887 .66545 L
s
1 .01 0 r
.62453 .71643 m
.62463 .71654 L
s
.62444 .71649 m
.62453 .71643 L
s
.62453 .71643 m
.6246 .71644 L
s
1 .001 0 r
.88371 .63988 m
.88375 .63982 L
s
1 0 0 r
.37557 .3843 m
.37557 .38428 L
s
1 .01 0 r
.62463 .71654 m
.62454 .7166 L
s
.6246 .71644 m
.62463 .71654 L
s
1 0 0 r
.37557 .38428 m
.37558 .38429 L
s
.37557 .38429 m
.37557 .38428 L
s
.37557 .38428 m
.37557 .38428 L
s
.37557 .38429 m
.37557 .38429 L
s
.37557 .38429 m
.37557 .38428 L
s
.37558 .38429 m
.37557 .38429 L
s
.37557 .38428 m
.37558 .38429 L
s
.37557 .38428 m
.37557 .38429 L
s
1 .001 0 r
.88374 .63982 m
.88375 .63984 L
s
.88373 .63983 m
.88374 .63982 L
s
.88374 .63982 m
.88375 .63982 L
s
.88375 .63984 m
.88374 .63985 L
s
.88375 .63982 m
.88375 .63984 L
s
.88374 .63985 m
.88373 .63983 L
s
.88373 .63983 m
.88375 .63982 L
s
.88375 .63982 m
.88374 .63985 L
s
1 .01 0 r
.62454 .7166 m
.62444 .71649 L
s
.62444 .71649 m
.6246 .71644 L
s
.6246 .71644 m
.62454 .7166 L
s
1 0 0 r
.841 .35865 m
.841 .35865 L
s
.841 .35865 m
.841 .35865 L
s
.841 .35865 m
.841 .35865 L
s
.841 .35865 m
.841 .35865 L
s
.841 .35865 m
.841 .35865 L
s
.841 .35865 m
.841 .35865 L
s
.841 .35865 m
.841 .35865 L
s
.841 .35865 m
.841 .35865 L
s
.841 .35865 m
.841 .35865 L
s
1 .003 0 r
.67772 .58859 m
.67778 .58847 L
s
.67777 .58847 m
.6778 .5885 L
s
.67774 .58849 m
.67777 .58847 L
s
.67777 .58847 m
.67778 .58847 L
s
.6778 .5885 m
.67777 .58852 L
s
.67778 .58847 m
.6778 .5885 L
s
.67777 .58852 m
.67774 .58849 L
s
.67774 .58849 m
.67778 .58847 L
s
.67778 .58847 m
.67777 .58852 L
s
1 .099 0 r
.27434 .63957 m
.27368 .63994 L
s
.2738 .63819 m
.27434 .63957 L
s
.27496 .63865 m
.27434 .63957 L
s
1 .01 0 r
.4717 .53729 m
.47189 .53689 L
s
1 .099 0 r
.27314 .63856 m
.2738 .63819 L
s
.2738 .63819 m
.27496 .63865 L
s
1 .206 0 r
.24055 .51158 m
.2391 .51224 L
s
.23936 .50871 m
.24055 .51158 L
s
.24169 .50951 m
.24055 .51158 L
s
1 .129 0 r
.26564 .48598 m
.27034 .48119 L
s
1 0 0 r
.73118 .46033 m
.73118 .46032 L
s
1 .01 0 r
.47185 .53689 m
.47195 .53699 L
s
.47175 .53695 m
.47185 .53689 L
s
.47185 .53689 m
.47189 .53689 L
s
1 0 0 r
.73118 .46032 m
.73118 .46032 L
s
.73118 .46032 m
.73118 .46032 L
s
.73118 .46032 m
.73118 .46032 L
s
.73118 .46032 m
.73118 .46032 L
s
.73118 .46032 m
.73118 .46032 L
s
.73118 .46032 m
.73118 .46032 L
s
.73118 .46032 m
.73118 .46032 L
s
.73118 .46032 m
.73118 .46032 L
s
1 .206 0 r
.23791 .50938 m
.23936 .50871 L
s
.23936 .50871 m
.24169 .50951 L
s
1 .01 0 r
.47195 .53699 m
.47185 .53705 L
s
.47189 .53689 m
.47195 .53699 L
s
.47185 .53705 m
.47175 .53695 L
s
.47175 .53695 m
.47189 .53689 L
s
1 .033 0 r
.41938 .66433 m
.41967 .66473 L
s
.41908 .66451 m
.41938 .66433 L
s
.41938 .66433 m
.41964 .6644 L
s
1 .012 0 r
.56786 .69033 m
.56825 .68988 L
s
1 .01 0 r
.47189 .53689 m
.47185 .53705 L
s
1 .033 0 r
.41967 .66473 m
.41937 .66492 L
s
.41964 .6644 m
.41967 .66473 L
s
1 0 0 r
.52511 .40901 m
.52512 .409 L
s
.52512 .409 m
.52512 .409 L
s
.52511 .409 m
.52512 .409 L
s
.52512 .409 m
.52512 .409 L
s
.52512 .409 m
.52512 .409 L
s
.52512 .409 m
.52512 .409 L
s
.52512 .409 m
.52511 .409 L
s
.52511 .409 m
.52512 .409 L
s
.52512 .409 m
.52512 .409 L
s
1 .051 0 r
.36177 .63903 m
.36399 .6374 L
s
1 .053 0 r
.32352 .51043 m
.32401 .51104 L
s
.32298 .51073 m
.32352 .51043 L
s
.32352 .51043 m
.32381 .51047 L
s
1 .033 0 r
.41937 .66492 m
.41908 .66451 L
s
.41908 .66451 m
.41964 .6644 L
s
1 .001 0 r
.82739 .61337 m
.82742 .61332 L
s
1 0 0 r
.31901 .35768 m
.31901 .35768 L
s
.31901 .35768 m
.31901 .35768 L
s
.31901 .35768 m
.31901 .35768 L
s
.31901 .35768 m
.31901 .35768 L
s
.31901 .35768 m
.31901 .35768 L
s
.31901 .35768 m
.31901 .35768 L
s
.31901 .35768 m
.31901 .35768 L
s
.31901 .35768 m
.31901 .35768 L
s
.31901 .35768 m
.31901 .35768 L
s
1 .033 0 r
.41964 .6644 m
.41937 .66492 L
s
1 .001 0 r
.82742 .61331 m
.82743 .61333 L
s
.8274 .61333 m
.82742 .61331 L
s
.82742 .61331 m
.82742 .61332 L
s
.82743 .61333 m
.82742 .61334 L
s
.82742 .61332 m
.82743 .61333 L
s
.82742 .61334 m
.8274 .61333 L
s
.8274 .61333 m
.82742 .61332 L
s
.82742 .61332 m
.82742 .61334 L
s
1 .053 0 r
.32401 .51104 m
.32347 .51134 L
s
.32381 .51047 m
.32401 .51104 L
s
1 .012 0 r
.56817 .68986 m
.56829 .69 L
s
.56805 .68994 m
.56817 .68986 L
s
.56817 .68986 m
.56825 .68988 L
s
.56829 .69 m
.56817 .69008 L
s
.56825 .68988 m
.56829 .69 L
s
.56817 .69008 m
.56805 .68994 L
s
.56805 .68994 m
.56825 .68988 L
s
.56825 .68988 m
.56817 .69008 L
s
1 .003 0 r
.6213 .56206 m
.62136 .56192 L
s
.62135 .56192 m
.62138 .56195 L
s
.62132 .56195 m
.62135 .56192 L
s
.62135 .56192 m
.62136 .56192 L
s
.62138 .56195 m
.62135 .56198 L
s
.62136 .56192 m
.62138 .56195 L
s
.62135 .56198 m
.62132 .56195 L
s
.62132 .56195 m
.62136 .56192 L
s
.62136 .56192 m
.62135 .56198 L
s
1 .099 0 r
.27496 .63865 m
.27368 .63994 L
s
.27314 .63856 m
.27496 .63865 L
s
.27368 .63994 m
.27314 .63856 L
s
1 .014 0 r
.41517 .51073 m
.41544 .51014 L
s
1 .053 0 r
.32347 .51134 m
.32298 .51073 L
s
.32298 .51073 m
.32381 .51047 L
s
1 0 0 r
.8809 .48507 m
.88091 .48506 L
s
1 .053 0 r
.32381 .51047 m
.32347 .51134 L
s
1 0 0 r
.8809 .48506 m
.88091 .48506 L
s
.8809 .48506 m
.8809 .48506 L
s
.8809 .48506 m
.88091 .48506 L
s
.88091 .48506 m
.88091 .48506 L
s
.88091 .48506 m
.88091 .48506 L
s
.88091 .48506 m
.8809 .48506 L
s
.8809 .48506 m
.88091 .48506 L
s
.88091 .48506 m
.88091 .48506 L
s
1 .006 0 r
.71752 .71516 m
.71768 .71495 L
s
1 .468 0 r
.20901 .4594 m
.23569 .44705 L
s
1 0 0 r
.67477 .43373 m
.67477 .43372 L
s
.67477 .43372 m
.67477 .43373 L
s
.67477 .43373 m
.67477 .43372 L
s
.67477 .43372 m
.67477 .43372 L
s
.67477 .43373 m
.67477 .43373 L
s
.67477 .43372 m
.67477 .43373 L
s
.67477 .43373 m
.67477 .43373 L
s
.67477 .43373 m
.67477 .43372 L
s
.67477 .43372 m
.67477 .43373 L
s
1 .006 0 r
.71765 .71494 m
.71771 .715 L
s
.71759 .71498 m
.71765 .71494 L
s
.71765 .71494 m
.71768 .71495 L
s
.71771 .715 m
.71765 .71504 L
s
.71768 .71495 m
.71771 .715 L
s
1 .017 0 r
.51137 .66384 m
.5119 .66323 L
s
1 .006 0 r
.71765 .71504 m
.71759 .71498 L
s
.71759 .71498 m
.71768 .71495 L
s
.71768 .71495 m
.71765 .71504 L
s
1 .014 0 r
.41539 .51014 m
.41553 .51029 L
s
.41524 .51024 m
.41539 .51014 L
s
.41539 .51014 m
.41544 .51014 L
s
.41553 .51029 m
.41538 .51038 L
s
.41544 .51014 m
.41553 .51029 L
s
1 0 0 r
.4686 .38238 m
.4686 .38238 L
s
.4686 .38238 m
.4686 .38238 L
s
.4686 .38238 m
.4686 .38238 L
s
.4686 .38238 m
.4686 .38238 L
s
.4686 .38238 m
.4686 .38238 L
s
.4686 .38238 m
.4686 .38238 L
s
.4686 .38238 m
.4686 .38238 L
s
.4686 .38238 m
.4686 .38238 L
s
.4686 .38238 m
.4686 .38238 L
s
1 .014 0 r
.41538 .51038 m
.41524 .51024 L
s
.41524 .51024 m
.41544 .51014 L
s
.41544 .51014 m
.41538 .51038 L
s
1 .082 0 r
.30518 .61251 m
.30933 .61012 L
s
1 .002 0 r
.77102 .58685 m
.77105 .58678 L
s
1 .375 0 r
.22713 .43829 m
.22478 .43315 L
s
.23165 .43315 m
.22713 .43829 L
s
1 .002 0 r
.77104 .58678 m
.77106 .5868 L
s
.77103 .58679 m
.77104 .58678 L
s
.77104 .58678 m
.77105 .58678 L
s
.77106 .5868 m
.77104 .58681 L
s
.77105 .58678 m
.77106 .5868 L
s
.77104 .58681 m
.77103 .58679 L
s
.77103 .58679 m
.77105 .58678 L
s
.77105 .58678 m
.77104 .58681 L
s
1 .051 0 r
.36357 .63728 m
.36398 .63792 L
s
.36311 .63754 m
.36357 .63728 L
s
.36357 .63728 m
.36399 .6374 L
s
.36398 .63792 m
.36353 .63817 L
s
.36399 .6374 m
.36398 .63792 L
s
1 .017 0 r
.51179 .66321 m
.51195 .6634 L
s
.51163 .66331 m
.51179 .66321 L
s
.51179 .66321 m
.5119 .66323 L
s
1 .004 0 r
.56483 .5355 m
.56489 .53534 L
s
1 .375 0 r
.22478 .43315 m
.23165 .43315 L
s
1 .017 0 r
.51195 .6634 m
.51179 .6635 L
s
.5119 .66323 m
.51195 .6634 L
s
.51179 .6635 m
.51163 .66331 L
s
.51163 .66331 m
.5119 .66323 L
s
1 .004 0 r
.56488 .53534 m
.56492 .53538 L
s
.56484 .53537 m
.56488 .53534 L
s
.56488 .53534 m
.56489 .53534 L
s
.56492 .53538 m
.56488 .53541 L
s
.56489 .53534 m
.56492 .53538 L
s
.56488 .53541 m
.56484 .53537 L
s
.56484 .53537 m
.56489 .53534 L
s
1 .017 0 r
.5119 .66323 m
.51179 .6635 L
s
1 .004 0 r
.56489 .53534 m
.56488 .53541 L
s
1 .023 0 r
.3586 .48415 m
.35901 .48316 L
s
1 0 0 r
.82454 .45847 m
.82454 .45847 L
s
.82454 .45847 m
.82454 .45847 L
s
.82454 .45847 m
.82454 .45847 L
s
.82454 .45847 m
.82454 .45847 L
s
.82454 .45847 m
.82454 .45847 L
s
.82454 .45847 m
.82454 .45847 L
s
.82454 .45847 m
.82454 .45847 L
s
.82454 .45847 m
.82454 .45847 L
s
.82454 .45847 m
.82454 .45847 L
s
1 .051 0 r
.36353 .63817 m
.36311 .63754 L
s
.36311 .63754 m
.36399 .6374 L
s
.36399 .6374 m
.36353 .63817 L
s
1 .007 0 r
.66108 .68868 m
.66127 .68842 L
s
1 .206 0 r
.2391 .51224 m
.23791 .50938 L
s
.24169 .50951 m
.2391 .51224 L
s
.23791 .50938 m
.24169 .50951 L
s
1 0 0 r
.61831 .40711 m
.61831 .40711 L
s
.61831 .40711 m
.61831 .40711 L
s
.61831 .40711 m
.61831 .40711 L
s
.61831 .40711 m
.61831 .40711 L
s
.61831 .40711 m
.61831 .40711 L
s
.61831 .40711 m
.61831 .40711 L
s
.61831 .40711 m
.61831 .40711 L
s
.61831 .40711 m
.61831 .40711 L
s
.61831 .40711 m
.61831 .40711 L
s
1 .023 0 r
.45482 .63733 m
.4556 .63647 L
s
1 .007 0 r
.66123 .68841 m
.6613 .68848 L
s
.66117 .68845 m
.66123 .68841 L
s
.66123 .68841 m
.66127 .68842 L
s
.6613 .68848 m
.66124 .68853 L
s
.66127 .68842 m
.6613 .68848 L
s
.66124 .68853 m
.66117 .68845 L
s
.66117 .68845 m
.66127 .68842 L
s
.66127 .68842 m
.66124 .68853 L
s
1 .001 0 r
.92085 .61165 m
.92087 .61162 L
s
1 0 0 r
.41204 .35574 m
.41204 .35574 L
s
.41204 .35574 m
.41204 .35574 L
s
.41204 .35574 m
.41204 .35574 L
s
.41204 .35574 m
.41204 .35574 L
s
.41204 .35574 m
.41204 .35574 L
s
.41204 .35574 m
.41204 .35574 L
s
.41204 .35574 m
.41204 .35574 L
s
.41204 .35574 m
.41204 .35574 L
s
.41204 .35574 m
.41204 .35574 L
s
1 .001 0 r
.92087 .61162 m
.92088 .61163 L
s
.92086 .61162 m
.92087 .61162 L
s
.92087 .61162 m
.92087 .61162 L
s
.92088 .61163 m
.92087 .61163 L
s
.92087 .61162 m
.92088 .61163 L
s
.92087 .61163 m
.92086 .61162 L
s
.92086 .61162 m
.92087 .61162 L
s
.92087 .61162 m
.92087 .61163 L
s
1 .142 0 r
.24853 .58597 m
.25716 .58286 L
s
1 .002 0 r
.71459 .56029 m
.71462 .56022 L
s
.71462 .56022 m
.71463 .56024 L
s
.7146 .56024 m
.71462 .56022 L
s
.71462 .56022 m
.71462 .56022 L
s
1 .023 0 r
.35893 .48316 m
.35917 .4834 L
s
.35868 .48331 m
.35893 .48316 L
s
.35893 .48316 m
.35901 .48316 L
s
1 .002 0 r
.71463 .56024 m
.71462 .56025 L
s
.71462 .56022 m
.71463 .56024 L
s
.71462 .56025 m
.7146 .56024 L
s
.7146 .56024 m
.71462 .56022 L
s
.71462 .56022 m
.71462 .56025 L
s
1 .023 0 r
.35917 .4834 m
.35892 .48355 L
s
.35901 .48316 m
.35917 .4834 L
s
1 .005 0 r
.5083 .50893 m
.50836 .50872 L
s
1 .023 0 r
.35892 .48355 m
.35868 .48331 L
s
.35868 .48331 m
.35901 .48316 L
s
.35901 .48316 m
.35892 .48355 L
s
1 .005 0 r
.50835 .50872 m
.5084 .50877 L
s
.5083 .50876 m
.50835 .50872 L
s
.50835 .50872 m
.50836 .50872 L
s
.5084 .50877 m
.50835 .5088 L
s
.50836 .50872 m
.5084 .50877 L
s
1 .023 0 r
.45545 .63644 m
.45566 .63671 L
s
.45522 .63658 m
.45545 .63644 L
s
.45545 .63644 m
.4556 .63647 L
s
1 .005 0 r
.50835 .5088 m
.5083 .50876 L
s
.5083 .50876 m
.50836 .50872 L
s
1 .003 0 r
.81091 .71353 m
.811 .7134 L
s
1 .049 0 r
.30196 .45755 m
.30278 .4554 L
s
1 .005 0 r
.50836 .50872 m
.50835 .5088 L
s
1 .023 0 r
.45566 .63671 m
.45544 .63685 L
s
.4556 .63647 m
.45566 .63671 L
s
1 0 0 r
.76813 .43186 m
.76813 .43185 L
s
1 .003 0 r
.81098 .71339 m
.81102 .71343 L
s
.81095 .71342 m
.81098 .71339 L
s
.81098 .71339 m
.811 .7134 L
s
1 0 0 r
.76813 .43185 m
.76813 .43185 L
s
.76813 .43185 m
.76813 .43185 L
s
.76813 .43185 m
.76813 .43185 L
s
.76813 .43185 m
.76813 .43185 L
s
.76813 .43185 m
.76813 .43185 L
s
.76813 .43185 m
.76813 .43185 L
s
.76813 .43185 m
.76813 .43185 L
s
.76813 .43185 m
.76813 .43185 L
s
1 .003 0 r
.81102 .71343 m
.81099 .71345 L
s
.811 .7134 m
.81102 .71343 L
s
.81099 .71345 m
.81095 .71342 L
s
.81095 .71342 m
.811 .7134 L
s
.811 .7134 m
.81099 .71345 L
s
1 .023 0 r
.45544 .63685 m
.45522 .63658 L
s
.45522 .63658 m
.4556 .63647 L
s
1 .009 0 r
.60459 .66216 m
.60482 .66183 L
s
1 .082 0 r
.30854 .60987 m
.30915 .61095 L
s
.30785 .61024 m
.30854 .60987 L
s
.30854 .60987 m
.30933 .61012 L
s
.30915 .61095 m
.30846 .61132 L
s
.30933 .61012 m
.30915 .61095 L
s
1 .023 0 r
.4556 .63647 m
.45544 .63685 L
s
1 0 0 r
.56179 .38046 m
.56179 .38046 L
s
.56179 .38046 m
.56179 .38046 L
s
.56179 .38046 m
.56179 .38046 L
s
.56179 .38046 m
.56179 .38046 L
s
.56179 .38046 m
.56179 .38046 L
s
.56179 .38046 m
.56179 .38046 L
s
.56179 .38046 m
.56179 .38046 L
s
.56179 .38046 m
.56179 .38046 L
s
.56179 .38046 m
.56179 .38046 L
s
1 .035 0 r
.39823 .61079 m
.39947 .60951 L
s
1 .129 0 r
.26947 .48105 m
.27059 .4826 L
s
.26819 .48169 m
.26947 .48105 L
s
.26947 .48105 m
.27034 .48119 L
s
1 .009 0 r
.60477 .66182 m
.60486 .66192 L
s
.60469 .66188 m
.60477 .66182 L
s
.60477 .66182 m
.60482 .66183 L
s
.60486 .66192 m
.60478 .66198 L
s
.60482 .66183 m
.60486 .66192 L
s
1 .001 0 r
.86448 .5851 m
.86449 .58506 L
s
.86449 .58506 m
.8645 .58507 L
s
.86448 .58507 m
.86449 .58506 L
s
.86449 .58506 m
.86449 .58506 L
s
1 .009 0 r
.60478 .66198 m
.60469 .66188 L
s
.60469 .66188 m
.60482 .66183 L
s
1 .001 0 r
.8645 .58507 m
.86449 .58508 L
s
.86449 .58506 m
.8645 .58507 L
s
.86449 .58508 m
.86448 .58507 L
s
.86448 .58507 m
.86449 .58506 L
s
.86449 .58506 m
.86449 .58508 L
s
1 .009 0 r
.60482 .66183 m
.60478 .66198 L
s
1 .129 0 r
.27059 .4826 m
.26932 .48325 L
s
.27034 .48119 m
.27059 .4826 L
s
1 .002 0 r
.65811 .53372 m
.65814 .53364 L
s
.65813 .53364 m
.65815 .53366 L
s
.65812 .53365 m
.65813 .53364 L
s
.65813 .53364 m
.65814 .53364 L
s
.65815 .53366 m
.65813 .53367 L
s
.65814 .53364 m
.65815 .53366 L
s
.65813 .53367 m
.65812 .53365 L
s
.65812 .53365 m
.65814 .53364 L
s
.65814 .53364 m
.65813 .53367 L
s
1 .006 0 r
.45171 .48232 m
.45178 .48206 L
s
1 .082 0 r
.2881 .71271 m
.29316 .71108 L
s
.30846 .61132 m
.30785 .61024 L
s
.30785 .61024 m
.30933 .61012 L
s
.30933 .61012 m
.30846 .61132 L
s
1 .004 0 r
.75447 .68702 m
.75457 .68686 L
s
1 .006 0 r
.45177 .48206 m
.45183 .48212 L
s
.45171 .4821 m
.45177 .48206 L
s
.45177 .48206 m
.45178 .48206 L
s
1 .176 0 r
.24528 .43092 m
.248 .42318 L
s
1 .006 0 r
.45183 .48212 m
.45177 .48216 L
s
.45178 .48206 m
.45183 .48212 L
s
.45177 .48216 m
.45171 .4821 L
s
.45171 .4821 m
.45178 .48206 L
s
.45178 .48206 m
.45177 .48216 L
s
1 0 0 r
.71166 .40521 m
.71166 .40521 L
s
.71166 .40521 m
.71166 .40521 L
s
.71166 .40521 m
.71166 .40521 L
s
.71166 .40521 m
.71166 .40521 L
s
.71166 .40521 m
.71166 .40521 L
s
.71166 .40521 m
.71166 .40521 L
s
.71166 .40521 m
.71166 .40521 L
s
.71166 .40521 m
.71166 .40521 L
s
.71166 .40521 m
.71166 .40521 L
s
1 .004 0 r
.75455 .68686 m
.75459 .6869 L
s
.75451 .68689 m
.75455 .68686 L
s
.75455 .68686 m
.75457 .68686 L
s
.75459 .6869 m
.75455 .68693 L
s
.75457 .68686 m
.75459 .6869 L
s
.75455 .68693 m
.75451 .68689 L
s
.75451 .68689 m
.75457 .68686 L
s
.75457 .68686 m
.75455 .68693 L
s
1 .011 0 r
.54804 .63563 m
.54834 .63519 L
s
1 0 0 r
.50522 .35379 m
.50522 .35379 L
s
.50522 .35379 m
.50522 .35379 L
s
.50522 .35379 m
.50522 .35379 L
s
.50522 .35379 m
.50522 .35379 L
s
.50522 .35379 m
.50522 .35379 L
s
.50522 .35379 m
.50522 .35379 L
s
.50522 .35379 m
.50522 .35379 L
s
.50522 .35379 m
.50522 .35379 L
s
.50522 .35379 m
.50522 .35379 L
s
1 .035 0 r
.39923 .60945 m
.39955 .60987 L
s
.39888 .60966 m
.39923 .60945 L
s
.39923 .60945 m
.39947 .60951 L
s
.39955 .60987 m
.39921 .61007 L
s
.39947 .60951 m
.39955 .60987 L
s
1 .059 0 r
.34158 .58423 m
.34385 .58215 L
s
1 .142 0 r
.25631 .58423 m
.25534 .58473 L
s
.25551 .58225 m
.25631 .58423 L
s
.25716 .58286 m
.25631 .58423 L
s
1 .129 0 r
.26932 .48325 m
.26819 .48169 L
s
.26819 .48169 m
.27034 .48119 L
s
1 .049 0 r
.30264 .45541 m
.30313 .45592 L
s
.30211 .45574 m
.30264 .45541 L
s
.30264 .45541 m
.30278 .4554 L
s
1 .001 0 r
.80805 .55853 m
.80806 .55849 L
s
1 .142 0 r
.25455 .58275 m
.25551 .58225 L
s
.25551 .58225 m
.25716 .58286 L
s
1 .001 0 r
.80806 .55849 m
.80807 .55849 L
s
.80805 .55849 m
.80806 .55849 L
s
.80806 .55849 m
.80806 .55849 L
s
.80807 .55849 m
.80806 .5585 L
s
.80806 .55849 m
.80807 .55849 L
s
.80806 .5585 m
.80805 .55849 L
s
.80805 .55849 m
.80806 .55849 L
s
.80806 .55849 m
.80806 .5585 L
s
1 .011 0 r
.54828 .63518 m
.54839 .63531 L
s
.54817 .63526 m
.54828 .63518 L
s
.54828 .63518 m
.54834 .63519 L
s
.54839 .63531 m
.54828 .63538 L
s
.54834 .63519 m
.54839 .63531 L
s
1 .035 0 r
.39921 .61007 m
.39888 .60966 L
s
.39888 .60966 m
.39947 .60951 L
s
1 .011 0 r
.54828 .63538 m
.54817 .63526 L
s
.54817 .63526 m
.54834 .63519 L
s
1 .129 0 r
.27034 .48119 m
.26932 .48325 L
s
1 .049 0 r
.30313 .45592 m
.30259 .45625 L
s
.30278 .4554 m
.30313 .45592 L
s
1 .011 0 r
.54834 .63519 m
.54828 .63538 L
s
1 .035 0 r
.39947 .60951 m
.39921 .61007 L
s
1 .002 0 r
.60158 .50711 m
.6016 .50703 L
s
.6016 .50703 m
.60162 .50705 L
s
.60158 .50704 m
.6016 .50703 L
s
.6016 .50703 m
.6016 .50703 L
s
.60162 .50705 m
.6016 .50706 L
s
.6016 .50703 m
.60162 .50705 L
s
.6016 .50706 m
.60158 .50704 L
s
.60158 .50704 m
.6016 .50703 L
s
.6016 .50703 m
.6016 .50706 L
s
1 .049 0 r
.30259 .45625 m
.30211 .45574 L
s
.30211 .45574 m
.30278 .4554 L
s
1 .002 0 r
.90446 .71189 m
.90452 .71181 L
s
1 .008 0 r
.39508 .45569 m
.39515 .45532 L
s
1 .002 0 r
.90451 .7118 m
.90453 .71183 L
s
.90449 .71182 m
.90451 .7118 L
s
.90451 .7118 m
.90452 .71181 L
s
.90453 .71183 m
.90451 .71184 L
s
.90452 .71181 m
.90453 .71183 L
s
.90451 .71184 m
.90449 .71182 L
s
.90449 .71182 m
.90452 .71181 L
s
.90452 .71181 m
.90451 .71184 L
s
1 .082 0 r
.29263 .71181 m
.2921 .71214 L
s
.29219 .71067 m
.29263 .71181 L
s
.29316 .71108 m
.29263 .71181 L
s
1 .049 0 r
.30278 .4554 m
.30259 .45625 L
s
1 0 0 r
.86165 .42998 m
.86165 .42997 L
s
.86165 .42997 m
.86165 .42997 L
s
.86165 .42997 m
.86165 .42997 L
s
.86165 .42997 m
.86165 .42997 L
s
.86165 .42997 m
.86165 .42997 L
s
.86165 .42997 m
.86165 .42997 L
s
.86165 .42997 m
.86165 .42997 L
s
.86165 .42997 m
.86165 .42997 L
s
.86165 .42997 m
.86165 .42997 L
s
1 .082 0 r
.29166 .71101 m
.29219 .71067 L
s
.29219 .71067 m
.29316 .71108 L
s
1 .005 0 r
.69797 .66048 m
.69808 .6603 L
s
0 .214 1 r
.18854 .40426 m
.24725 .22208 L
s
1 .008 0 r
.39513 .45533 m
.39522 .4554 L
s
.39504 .45539 m
.39513 .45533 L
s
.39513 .45533 m
.39515 .45532 L
s
1 0 0 r
.65514 .37854 m
.65514 .37854 L
s
.65514 .37854 m
.65514 .37854 L
s
.65514 .37854 m
.65514 .37854 L
s
.65514 .37854 m
.65514 .37854 L
s
.65514 .37854 m
.65514 .37854 L
s
.65514 .37854 m
.65514 .37854 L
s
.65514 .37854 m
.65514 .37854 L
s
.65514 .37854 m
.65514 .37854 L
s
.65514 .37854 m
.65514 .37854 L
s
1 .008 0 r
.39522 .4554 m
.39513 .45547 L
s
.39515 .45532 m
.39522 .4554 L
s
.39513 .45547 m
.39504 .45539 L
s
.39504 .45539 m
.39515 .45532 L
s
1 .005 0 r
.69806 .66029 m
.69811 .66034 L
s
.69801 .66033 m
.69806 .66029 L
s
.69806 .66029 m
.69808 .6603 L
s
1 .008 0 r
.39515 .45532 m
.39513 .45547 L
s
1 .005 0 r
.69811 .66034 m
.69806 .66038 L
s
.69808 .6603 m
.69811 .66034 L
s
.69806 .66038 m
.69801 .66033 L
s
.69801 .66033 m
.69808 .6603 L
s
.69808 .6603 m
.69806 .66038 L
s
1 .015 0 r
.49144 .60907 m
.49185 .60847 L
s
1 .11 0 r
.28487 .55764 m
.28992 .55407 L
s
1 .001 0 r
.75156 .53192 m
.75157 .53188 L
s
.75157 .53188 m
.75158 .53189 L
s
.75156 .53189 m
.75157 .53188 L
s
.75157 .53188 m
.75157 .53188 L
s
.75158 .53189 m
.75157 .5319 L
s
.75157 .53188 m
.75158 .53189 L
s
.75157 .5319 m
.75156 .53189 L
s
.75156 .53189 m
.75157 .53188 L
s
.75157 .53188 m
.75157 .5319 L
s
1 .015 0 r
.49177 .60845 m
.49192 .60862 L
s
.49161 .60855 m
.49177 .60845 L
s
.49177 .60845 m
.49185 .60847 L
s
1 .002 0 r
.54499 .48048 m
.54501 .48039 L
s
1 .015 0 r
.49192 .60862 m
.49176 .60872 L
s
.49185 .60847 m
.49192 .60862 L
s
1 .002 0 r
.54501 .48039 m
.54503 .48041 L
s
.54498 .48041 m
.54501 .48039 L
s
.54501 .48039 m
.54501 .48039 L
s
1 .082 0 r
.29316 .71108 m
.2921 .71214 L
s
.29166 .71101 m
.29316 .71108 L
s
1 .002 0 r
.54503 .48041 m
.54501 .48043 L
s
.54501 .48039 m
.54503 .48041 L
s
.54501 .48043 m
.54498 .48041 L
s
.54498 .48041 m
.54501 .48039 L
s
1 .015 0 r
.49176 .60872 m
.49161 .60855 L
s
.49161 .60855 m
.49185 .60847 L
s
1 .049 0 r
.38124 .71107 m
.38357 .70964 L
s
1 .002 0 r
.54501 .48039 m
.54501 .48043 L
s
1 .082 0 r
.2921 .71214 m
.29166 .71101 L
s
1 .015 0 r
.49185 .60847 m
.49176 .60872 L
s
1 .142 0 r
.25716 .58286 m
.25534 .58473 L
s
.25455 .58275 m
.25716 .58286 L
s
.25534 .58473 m
.25455 .58275 L
s
1 .002 0 r
.84801 .68536 m
.84807 .68526 L
s
1 .059 0 r
.34342 .58205 m
.34393 .58277 L
s
.34286 .58237 m
.34342 .58205 L
s
.34342 .58205 m
.34385 .58215 L
s
1 .013 0 r
.33838 .42904 m
.33843 .42846 L
s
1 .059 0 r
.34393 .58277 m
.34337 .58308 L
s
.34385 .58215 m
.34393 .58277 L
s
1 .002 0 r
.84806 .68526 m
.84809 .68529 L
s
.84804 .68528 m
.84806 .68526 L
s
.84806 .68526 m
.84807 .68526 L
s
.84809 .68529 m
.84806 .6853 L
s
.84807 .68526 m
.84809 .68529 L
s
.84806 .6853 m
.84804 .68528 L
s
.84804 .68528 m
.84807 .68526 L
s
.84807 .68526 m
.84806 .6853 L
s
1 0 0 r
.80517 .40331 m
.80517 .40331 L
s
.80517 .40331 m
.80518 .40331 L
s
.80517 .40331 m
.80517 .40331 L
s
.80517 .40331 m
.80517 .40331 L
s
.80518 .40331 m
.80517 .40331 L
s
.80517 .40331 m
.80518 .40331 L
s
.80517 .40331 m
.80517 .40331 L
s
.80517 .40331 m
.80517 .40331 L
s
.80517 .40331 m
.80517 .40331 L
s
1 .006 0 r
.64142 .63392 m
.64155 .6337 L
s
1 0 0 r
.59856 .35185 m
.59856 .35185 L
s
.59856 .35185 m
.59856 .35185 L
s
.59856 .35185 m
.59856 .35185 L
s
.59856 .35185 m
.59856 .35185 L
s
.59856 .35185 m
.59856 .35185 L
s
.59856 .35185 m
.59856 .35185 L
s
.59856 .35185 m
.59856 .35185 L
s
.59856 .35185 m
.59856 .35185 L
s
.59856 .35185 m
.59856 .35185 L
s
1 .006 0 r
.64152 .63369 m
.64158 .63375 L
s
.64147 .63373 m
.64152 .63369 L
s
.64152 .63369 m
.64155 .6337 L
s
1 .022 0 r
.43478 .58248 m
.43539 .5816 L
s
1 .006 0 r
.64158 .63375 m
.64153 .63379 L
s
.64155 .6337 m
.64158 .63375 L
s
.64153 .63379 m
.64147 .63373 L
s
.64147 .63373 m
.64155 .6337 L
s
1 .013 0 r
.33843 .42847 m
.33856 .42858 L
s
.33829 .42856 m
.33843 .42847 L
s
.33843 .42847 m
.33843 .42846 L
s
1 .006 0 r
.64155 .6337 m
.64153 .63379 L
s
1 .013 0 r
.33856 .42858 m
.33842 .42868 L
s
.33843 .42846 m
.33856 .42858 L
s
1 .001 0 r
.90166 .55675 m
.90167 .55673 L
s
1 .013 0 r
.33842 .42868 m
.33829 .42856 L
s
.33829 .42856 m
.33843 .42846 L
s
1 .001 0 r
.90167 .55673 m
.90167 .55674 L
s
.90166 .55673 m
.90167 .55673 L
s
.90167 .55673 m
.90167 .55673 L
s
.90167 .55674 m
.90167 .55674 L
s
.90167 .55673 m
.90167 .55674 L
s
.90167 .55674 m
.90166 .55673 L
s
.90166 .55673 m
.90167 .55673 L
s
.90167 .55673 m
.90167 .55674 L
s
1 .059 0 r
.34337 .58308 m
.34286 .58237 L
s
.34286 .58237 m
.34385 .58215 L
s
1 .013 0 r
.33843 .42846 m
.33842 .42868 L
s
1 .059 0 r
.34385 .58215 m
.34337 .58308 L
s
1 .234 0 r
.22812 .53103 m
.24215 .52554 L
s
1 .001 0 r
.69502 .5053 m
.69503 .50526 L
s
.69503 .50526 m
.69504 .50526 L
s
.69502 .50526 m
.69503 .50526 L
s
.69503 .50526 m
.69503 .50526 L
s
.69504 .50526 m
.69503 .50527 L
s
.69503 .50526 m
.69504 .50526 L
s
.69503 .50527 m
.69502 .50526 L
s
.69502 .50526 m
.69503 .50526 L
s
.69503 .50526 m
.69503 .50527 L
s
1 .002 0 r
.48835 .45383 m
.48836 .45373 L
s
.48836 .45373 m
.48838 .45375 L
s
.48834 .45375 m
.48836 .45373 L
s
.48836 .45373 m
.48836 .45373 L
s
.48838 .45375 m
.48836 .45377 L
s
.48836 .45373 m
.48838 .45375 L
s
.48836 .45377 m
.48834 .45375 L
s
.48834 .45375 m
.48836 .45373 L
s
1 .072 0 r
.32452 .68453 m
.32836 .68262 L
s
1 .002 0 r
.48836 .45373 m
.48836 .45377 L
s
1 .049 0 r
.38312 .70948 m
.3835 .71011 L
s
.38271 .70974 m
.38312 .70948 L
s
.38312 .70948 m
.38357 .70964 L
s
.3835 .71011 m
.38309 .71036 L
s
.38357 .70964 m
.3835 .71011 L
s
1 .022 0 r
.43527 .58158 m
.43549 .58183 L
s
.43504 .58172 m
.43527 .58158 L
s
.43527 .58158 m
.43539 .5816 L
s
1 .003 0 r
.79151 .6588 m
.79157 .65869 L
s
1 .025 0 r
.28164 .40235 m
.2815 .40121 L
s
1 .022 0 r
.43549 .58183 m
.43526 .58197 L
s
.43539 .5816 m
.43549 .58183 L
s
1 .003 0 r
.79156 .65869 m
.79159 .65872 L
s
.79153 .65871 m
.79156 .65869 L
s
.79156 .65869 m
.79157 .65869 L
s
.79159 .65872 m
.79156 .65874 L
s
.79157 .65869 m
.79159 .65872 L
s
.79156 .65874 m
.79153 .65871 L
s
.79153 .65871 m
.79157 .65869 L
s
1 0 0 r
.74865 .37661 m
.74865 .37661 L
s
.74865 .37661 m
.74865 .37661 L
s
.74865 .37661 m
.74865 .37661 L
s
.74865 .37661 m
.74865 .37661 L
s
.74865 .37661 m
.74865 .37661 L
s
.74865 .37661 m
.74865 .37661 L
s
.74865 .37661 m
.74865 .37661 L
s
.74865 .37661 m
.74865 .37661 L
s
.74865 .37661 m
.74865 .37661 L
s
1 .003 0 r
.79157 .65869 m
.79156 .65874 L
s
1 .022 0 r
.43526 .58197 m
.43504 .58172 L
s
.43504 .58172 m
.43539 .5816 L
s
1 .007 0 r
.58481 .60734 m
.58497 .60705 L
s
1 .022 0 r
.43539 .5816 m
.43526 .58197 L
s
1 .036 0 r
.37808 .55587 m
.37909 .55444 L
s
1 .049 0 r
.38309 .71036 m
.38271 .70974 L
s
.38271 .70974 m
.38357 .70964 L
s
1 .007 0 r
.58494 .60704 m
.58501 .60712 L
s
.58487 .60709 m
.58494 .60704 L
s
.58494 .60704 m
.58497 .60705 L
s
1 .049 0 r
.38357 .70964 m
.38309 .71036 L
s
1 .007 0 r
.58501 .60712 m
.58494 .60717 L
s
.58497 .60705 m
.58501 .60712 L
s
.58494 .60717 m
.58487 .60709 L
s
.58487 .60709 m
.58497 .60705 L
s
1 .001 0 r
.84517 .53013 m
.84518 .53011 L
s
1 .007 0 r
.58497 .60705 m
.58494 .60717 L
s
1 .001 0 r
.84517 .53011 m
.84518 .53011 L
s
.84517 .53011 m
.84517 .53011 L
s
.84517 .53011 m
.84518 .53011 L
s
.84518 .53011 m
.84518 .53011 L
s
.84518 .53011 m
.84518 .53011 L
s
.84518 .53011 m
.84517 .53011 L
s
.84517 .53011 m
.84518 .53011 L
s
.84518 .53011 m
.84518 .53011 L
s
.63843 .47864 m
.63844 .4786 L
s
.63844 .4786 m
.63845 .47861 L
s
.63843 .47861 m
.63844 .4786 L
s
.63844 .4786 m
.63844 .4786 L
s
.63845 .47861 m
.63844 .47862 L
s
.63844 .4786 m
.63845 .47861 L
s
.63844 .47862 m
.63843 .47861 L
s
.63843 .47861 m
.63844 .4786 L
s
.63844 .4786 m
.63844 .47862 L
s
1 .026 0 r
.47455 .70943 m
.47555 .70853 L
s
1 .025 0 r
.28154 .40123 m
.28179 .40144 L
s
.28126 .40144 m
.28154 .40123 L
s
.28154 .40123 m
.2815 .40121 L
s
1 .002 0 r
.94172 .6837 m
.94176 .68363 L
s
.43165 .42715 m
.43166 .42704 L
s
.94175 .68363 m
.94177 .68365 L
s
.94174 .68364 m
.94175 .68363 L
s
.94175 .68363 m
.94176 .68363 L
s
.94177 .68365 m
.94175 .68366 L
s
.94176 .68363 m
.94177 .68365 L
s
.94175 .68366 m
.94174 .68364 L
s
.94174 .68364 m
.94176 .68363 L
s
.94176 .68363 m
.94175 .68366 L
s
1 .025 0 r
.28151 .40164 m
.28126 .40144 L
s
.28126 .40144 m
.2815 .40121 L
s
.28179 .40144 m
.28151 .40164 L
s
.2815 .40121 m
.28179 .40144 L
s
1 .002 0 r
.43166 .42705 m
.43168 .42707 L
s
.43163 .42706 m
.43166 .42705 L
s
.43166 .42705 m
.43166 .42704 L
s
.43168 .42707 m
.43166 .42708 L
s
.43166 .42704 m
.43168 .42707 L
s
1 .108 0 r
.26775 .65796 m
.2744 .65571 L
s
1 .002 0 r
.43166 .42708 m
.43163 .42706 L
s
.43163 .42706 m
.43166 .42704 L
s
.43166 .42704 m
.43166 .42708 L
s
1 .11 0 r
.28897 .55382 m
.28985 .55524 L
s
.28798 .55433 m
.28897 .55382 L
s
.28897 .55382 m
.28992 .55407 L
s
1 .025 0 r
.2815 .40121 m
.28151 .40164 L
s
1 .003 0 r
.73495 .63222 m
.73502 .63209 L
s
1 .078 0 r
.22484 .37565 m
.22224 .37222 L
s
1 .11 0 r
.28985 .55524 m
.28885 .55574 L
s
.28992 .55407 m
.28985 .55524 L
s
1 .003 0 r
.73501 .63209 m
.73504 .63212 L
s
.73498 .63211 m
.73501 .63209 L
s
.73501 .63209 m
.73502 .63209 L
s
1 0 0 r
.69207 .34989 m
.69207 .34989 L
s
.69207 .34989 m
.69207 .34989 L
s
.69207 .34989 m
.69207 .34989 L
s
.69207 .34989 m
.69207 .34989 L
s
.69207 .34989 m
.69207 .34989 L
s
.69207 .34989 m
.69207 .34989 L
s
.69207 .34989 m
.69207 .34989 L
s
.69207 .34989 m
.69207 .34989 L
s
.69207 .34989 m
.69207 .34989 L
s
1 .003 0 r
.73504 .63212 m
.73501 .63214 L
s
.73502 .63209 m
.73504 .63212 L
s
.73501 .63214 m
.73498 .63211 L
s
.73498 .63211 m
.73502 .63209 L
s
.73502 .63209 m
.73501 .63214 L
s
1 .009 0 r
.52815 .58073 m
.52835 .58034 L
s
1 .072 0 r
.32812 .68332 m
.32756 .68365 L
s
.32762 .68236 m
.32812 .68332 L
s
.32836 .68262 m
.32812 .68332 L
s
.32705 .68269 m
.32762 .68236 L
s
.32762 .68236 m
.32836 .68262 L
s
1 .068 0 r
.32131 .52923 m
.32337 .52658 L
s
1 .036 0 r
.3789 .55441 m
.37924 .55482 L
s
.37853 .55463 m
.3789 .55441 L
s
.3789 .55441 m
.37909 .55444 L
s
1 .026 0 r
.47535 .70847 m
.47559 .70879 L
s
.4751 .70863 m
.47535 .70847 L
s
.47535 .70847 m
.47555 .70853 L
s
.47559 .70879 m
.47534 .70895 L
s
.47555 .70853 m
.47559 .70879 L
s
1 .036 0 r
.37924 .55482 m
.37887 .55504 L
s
.37909 .55444 m
.37924 .55482 L
s
1 .009 0 r
.52831 .58034 m
.52841 .58044 L
s
.52822 .5804 m
.52831 .58034 L
s
.52831 .58034 m
.52835 .58034 L
s
1 0 0 r
.78863 .50348 m
.78863 .50346 L
s
.78863 .50346 m
.78864 .50346 L
s
.78863 .50346 m
.78863 .50346 L
s
.78863 .50346 m
.78863 .50346 L
s
.78864 .50346 m
.78863 .50346 L
s
.78863 .50346 m
.78864 .50346 L
s
.78863 .50346 m
.78863 .50346 L
s
.78863 .50346 m
.78863 .50346 L
s
.78863 .50346 m
.78863 .50346 L
s
1 .009 0 r
.52841 .58044 m
.52831 .5805 L
s
.52835 .58034 m
.52841 .58044 L
s
.52831 .5805 m
.52822 .5804 L
s
.52822 .5804 m
.52835 .58034 L
s
.52835 .58034 m
.52831 .5805 L
s
1 .468 0 r
.23358 .45201 m
.23002 .45351 L
s
.23064 .44557 m
.23358 .45201 L
s
.23569 .44705 m
.23358 .45201 L
s
1 .026 0 r
.47534 .70895 m
.4751 .70863 L
s
.4751 .70863 m
.47555 .70853 L
s
1 .036 0 r
.37887 .55504 m
.37853 .55463 L
s
.37853 .55463 m
.37909 .55444 L
s
1 .001 0 r
.58178 .45197 m
.58179 .45193 L
s
1 .026 0 r
.47555 .70853 m
.47534 .70895 L
s
1 .001 0 r
.58179 .45193 m
.5818 .45194 L
s
.58178 .45194 m
.58179 .45193 L
s
.58179 .45193 m
.58179 .45193 L
s
.5818 .45194 m
.58179 .45194 L
s
.58179 .45193 m
.5818 .45194 L
s
.58179 .45194 m
.58178 .45194 L
s
.58178 .45194 m
.58179 .45193 L
s
.58179 .45193 m
.58179 .45194 L
s
1 .036 0 r
.37909 .55444 m
.37887 .55504 L
s
1 .038 0 r
.41782 .68286 m
.41934 .6816 L
s
1 .002 0 r
.88521 .65711 m
.88525 .65704 L
s
.3749 .40045 m
.37489 .40034 L
s
1 .468 0 r
.22708 .44705 m
.23064 .44557 L
s
.23064 .44557 m
.23569 .44705 L
s
1 .002 0 r
.88524 .65704 m
.88526 .65706 L
s
.88523 .65706 m
.88524 .65704 L
s
.88524 .65704 m
.88525 .65704 L
s
.88526 .65706 m
.88525 .65707 L
s
.88525 .65704 m
.88526 .65706 L
s
.88525 .65707 m
.88523 .65706 L
s
.88523 .65706 m
.88525 .65704 L
s
.88525 .65704 m
.88525 .65707 L
s
.3749 .40034 m
.37492 .40036 L
s
.37487 .40036 m
.3749 .40034 L
s
.3749 .40034 m
.37489 .40034 L
s
1 .072 0 r
.32756 .68365 m
.32705 .68269 L
s
.32836 .68262 m
.32756 .68365 L
s
1 .002 0 r
.3749 .40038 m
.37487 .40036 L
s
.37487 .40036 m
.37489 .40034 L
s
.37492 .40036 m
.3749 .40038 L
s
.37489 .40034 m
.37492 .40036 L
s
1 .072 0 r
.32705 .68269 m
.32836 .68262 L
s
1 .002 0 r
.37489 .40034 m
.3749 .40038 L
s
1 0 0 r
.84232 .37468 m
.84232 .37468 L
s
.84232 .37468 m
.84232 .37468 L
s
.84232 .37468 m
.84232 .37468 L
s
.84232 .37468 m
.84232 .37468 L
s
.84232 .37468 m
.84232 .37468 L
s
.84232 .37468 m
.84232 .37468 L
s
.84232 .37468 m
.84232 .37468 L
s
.84232 .37468 m
.84232 .37468 L
s
.84232 .37468 m
.84232 .37468 L
s
1 .11 0 r
.28885 .55574 m
.28798 .55433 L
s
.28798 .55433 m
.28992 .55407 L
s
.28992 .55407 m
.28885 .55574 L
s
1 .004 0 r
.67834 .60561 m
.67842 .60546 L
s
.6784 .60545 m
.67844 .60549 L
s
.67837 .60548 m
.6784 .60545 L
s
.6784 .60545 m
.67842 .60546 L
s
.67844 .60549 m
.67841 .60552 L
s
.67842 .60546 m
.67844 .60549 L
s
.67841 .60552 m
.67837 .60548 L
s
.67837 .60548 m
.67842 .60546 L
s
.67842 .60546 m
.67841 .60552 L
s
1 .013 0 r
.47144 .55409 m
.4717 .55355 L
s
1 .108 0 r
.27373 .65671 m
.27301 .65712 L
s
.27313 .65519 m
.27373 .65671 L
s
.2744 .65571 m
.27373 .65671 L
s
1 .176 0 r
.24757 .42325 m
.24929 .42506 L
s
.24561 .4244 m
.24757 .42325 L
s
.24757 .42325 m
.248 .42318 L
s
1 .108 0 r
.27241 .65561 m
.27313 .65519 L
s
.27313 .65519 m
.2744 .65571 L
s
1 .16 0 r
.2645 .50257 m
.27037 .49662 L
s
1 0 0 r
.73203 .4768 m
.73203 .47678 L
s
.73203 .47678 m
.73204 .47679 L
s
.73203 .47679 m
.73203 .47678 L
s
.73203 .47678 m
.73203 .47678 L
s
.73204 .47679 m
.73203 .47679 L
s
.73203 .47678 m
.73204 .47679 L
s
.73203 .47679 m
.73203 .47679 L
s
.73203 .47679 m
.73203 .47678 L
s
.73203 .47678 m
.73203 .47679 L
s
1 .014 0 r
.56801 .70779 m
.56846 .70726 L
s
1 .013 0 r
.47165 .55355 m
.47178 .55368 L
s
.47151 .55364 m
.47165 .55355 L
s
.47165 .55355 m
.4717 .55355 L
s
1 .763 0 r
.20082 .33821 m
.20829 .34598 L
s
.19222 .34301 m
.20082 .33821 L
s
.20082 .33821 m
.2025 .33748 L
s
1 .013 0 r
.47178 .55368 m
.47165 .55377 L
s
.4717 .55355 m
.47178 .55368 L
s
1 .001 0 r
.52508 .42526 m
.52508 .42523 L
s
1 .013 0 r
.47165 .55377 m
.47151 .55364 L
s
.47151 .55364 m
.4717 .55355 L
s
1 .038 0 r
.41905 .68151 m
.41938 .68198 L
s
.4187 .68173 m
.41905 .68151 L
s
.41905 .68151 m
.41934 .6816 L
s
1 .001 0 r
.52508 .42523 m
.52509 .42524 L
s
.52508 .42524 m
.52508 .42523 L
s
.52508 .42523 m
.52508 .42523 L
s
.52509 .42524 m
.52508 .42524 L
s
.52508 .42523 m
.52509 .42524 L
s
.52508 .42524 m
.52508 .42524 L
s
.52508 .42524 m
.52508 .42523 L
s
.52508 .42523 m
.52508 .42524 L
s
1 .013 0 r
.4717 .55355 m
.47165 .55377 L
s
1 .038 0 r
.41938 .68198 m
.41903 .68219 L
s
.41934 .6816 m
.41938 .68198 L
s
1 .234 0 r
.24085 .52789 m
.23919 .52867 L
s
.23949 .52462 m
.24085 .52789 L
s
.24215 .52554 m
.24085 .52789 L
s
1 .057 0 r
.36104 .65627 m
.36356 .65444 L
s
1 .002 0 r
.82865 .6305 m
.82869 .63043 L
s
.3181 .37372 m
.31808 .37364 L
s
1 .176 0 r
.24929 .42506 m
.24734 .42621 L
s
.248 .42318 m
.24929 .42506 L
s
1 .002 0 r
.82868 .63043 m
.8287 .63045 L
s
.82867 .63044 m
.82868 .63043 L
s
.82868 .63043 m
.82869 .63043 L
s
.31808 .37365 m
.3181 .37366 L
s
.31807 .37366 m
.31808 .37365 L
s
.31808 .37365 m
.31808 .37364 L
s
.8287 .63045 m
.82869 .63046 L
s
.82869 .63043 m
.8287 .63045 L
s
.31808 .37367 m
.31807 .37366 L
s
.31807 .37366 m
.31808 .37364 L
s
.3181 .37366 m
.31808 .37367 L
s
.31808 .37364 m
.3181 .37366 L
s
.82869 .63046 m
.82867 .63044 L
s
.82867 .63044 m
.82869 .63043 L
s
.31808 .37364 m
.31808 .37367 L
s
.82869 .63043 m
.82869 .63046 L
s
1 .234 0 r
.23783 .5254 m
.23949 .52462 L
s
.23949 .52462 m
.24215 .52554 L
s
1 0 0 r
.78574 .34794 m
.78574 .34794 L
s
.78574 .34794 m
.78574 .34794 L
s
.78574 .34794 m
.78574 .34794 L
s
.78574 .34794 m
.78574 .34794 L
s
.78574 .34794 m
.78574 .34794 L
s
.78574 .34794 m
.78574 .34794 L
s
.78574 .34794 m
.78574 .34794 L
s
.78574 .34794 m
.78574 .34794 L
s
.78574 .34794 m
.78574 .34794 L
s
1 .014 0 r
.56837 .70724 m
.56851 .7074 L
s
.56823 .70733 m
.56837 .70724 L
s
.56837 .70724 m
.56846 .70726 L
s
1 .038 0 r
.41903 .68219 m
.4187 .68173 L
s
.4187 .68173 m
.41934 .6816 L
s
1 .014 0 r
.56851 .7074 m
.56837 .7075 L
s
.56846 .70726 m
.56851 .7074 L
s
1 .004 0 r
.62168 .57897 m
.62176 .57879 L
s
1 .038 0 r
.41934 .6816 m
.41903 .68219 L
s
1 .014 0 r
.56837 .7075 m
.56823 .70733 L
s
.56823 .70733 m
.56846 .70726 L
s
.56846 .70726 m
.56837 .7075 L
s
1 .004 0 r
.62174 .57879 m
.62179 .57883 L
s
.6217 .57882 m
.62174 .57879 L
s
.62174 .57879 m
.62176 .57879 L
s
.62179 .57883 m
.62175 .57886 L
s
.62176 .57879 m
.62179 .57883 L
s
.62175 .57886 m
.6217 .57882 L
s
.6217 .57882 m
.62176 .57879 L
s
.62176 .57879 m
.62175 .57886 L
s
1 .02 0 r
.41467 .52743 m
.41504 .52661 L
s
1 .068 0 r
.32299 .52652 m
.32363 .5273 L
s
.3223 .52691 m
.32299 .52652 L
s
.32299 .52652 m
.32337 .52658 L
s
1 .078 0 r
.22281 .37225 m
.22351 .37271 L
s
.22201 .3731 m
.22281 .37225 L
s
.22281 .37225 m
.22224 .37222 L
s
1 0 0 r
.88239 .50166 m
.8824 .50164 L
s
.88239 .50164 m
.8824 .50165 L
s
.88239 .50164 m
.88239 .50164 L
s
.88239 .50164 m
.8824 .50164 L
s
.8824 .50165 m
.88239 .50165 L
s
.8824 .50164 m
.8824 .50165 L
s
.88239 .50165 m
.88239 .50164 L
s
.88239 .50164 m
.8824 .50164 L
s
.8824 .50164 m
.88239 .50165 L
s
1 .068 0 r
.32363 .5273 m
.32293 .5277 L
s
.32337 .52658 m
.32363 .5273 L
s
1 .108 0 r
.2744 .65571 m
.27301 .65712 L
s
.27241 .65561 m
.2744 .65571 L
s
.27301 .65712 m
.27241 .65561 L
s
1 .529 0 r
.20763 .47588 m
.2379 .46197 L
s
1 .078 0 r
.22271 .37355 m
.22201 .3731 L
s
.22201 .3731 m
.22224 .37222 L
s
1 0 0 r
.67538 .4501 m
.67538 .45008 L
s
1 .176 0 r
.24734 .42621 m
.24561 .4244 L
s
.24561 .4244 m
.248 .42318 L
s
1 0 0 r
.67538 .45008 m
.67538 .45009 L
s
.67538 .45009 m
.67538 .45008 L
s
.67538 .45008 m
.67538 .45008 L
s
.67538 .45009 m
.67538 .45009 L
s
.67538 .45008 m
.67538 .45009 L
s
.67538 .45009 m
.67538 .45009 L
s
.67538 .45009 m
.67538 .45008 L
s
.67538 .45008 m
.67538 .45009 L
s
1 .019 0 r
.51128 .6812 m
.5119 .68049 L
s
1 0 0 r
.46833 .39853 m
.46833 .39851 L
s
.46833 .39851 m
.46833 .39852 L
s
.46832 .39852 m
.46833 .39851 L
s
.46833 .39851 m
.46833 .39851 L
s
.46833 .39852 m
.46832 .39852 L
s
.46832 .39852 m
.46833 .39851 L
s
.46833 .39852 m
.46833 .39852 L
s
.46833 .39851 m
.46833 .39852 L
s
.46833 .39851 m
.46833 .39852 L
s
1 .068 0 r
.32293 .5277 m
.3223 .52691 L
s
.3223 .52691 m
.32337 .52658 L
s
1 .092 0 r
.3042 .62965 m
.30886 .62699 L
s
1 .02 0 r
.41497 .5266 m
.41517 .52681 L
s
.41477 .52674 m
.41497 .5266 L
s
.41497 .5266 m
.41504 .52661 L
s
1 .078 0 r
.22351 .37271 m
.22271 .37355 L
s
.22224 .37222 m
.22351 .37271 L
s
1 .02 0 r
.41517 .52681 m
.41496 .52694 L
s
.41504 .52661 m
.41517 .52681 L
s
1 .002 0 r
.77204 .60387 m
.77208 .60379 L
s
1 .068 0 r
.32337 .52658 m
.32293 .5277 L
s
1 0 0 r
.26124 .34696 m
.26124 .34696 L
s
.26124 .34696 m
.26124 .34696 L
s
.26124 .34696 m
.26124 .34696 L
s
.26124 .34696 m
.26124 .34696 L
s
.26124 .34696 m
.26124 .34696 L
s
.26124 .34696 m
.26124 .34696 L
s
.26124 .34696 m
.26124 .34696 L
s
.26124 .34696 m
.26124 .34696 L
s
.26124 .34696 m
.26124 .34696 L
s
1 .002 0 r
.77207 .60379 m
.77209 .60381 L
s
.77205 .6038 m
.77207 .60379 L
s
.77207 .60379 m
.77208 .60379 L
s
1 .02 0 r
.41496 .52694 m
.41477 .52674 L
s
.41477 .52674 m
.41504 .52661 L
s
1 .002 0 r
.77209 .60381 m
.77207 .60382 L
s
.77208 .60379 m
.77209 .60381 L
s
.77207 .60382 m
.77205 .6038 L
s
.77205 .6038 m
.77208 .60379 L
s
.77208 .60379 m
.77207 .60382 L
s
1 .02 0 r
.41504 .52661 m
.41496 .52694 L
s
1 .078 0 r
.22224 .37222 m
.22271 .37355 L
s
1 .176 0 r
.248 .42318 m
.24734 .42621 L
s
1 .005 0 r
.56496 .55231 m
.56505 .55208 L
s
1 .057 0 r
.36308 .65429 m
.36355 .65502 L
s
.36256 .65459 m
.36308 .65429 L
s
.36308 .65429 m
.36356 .65444 L
s
1 .019 0 r
.51177 .68046 m
.51196 .68068 L
s
.51159 .68058 m
.51177 .68046 L
s
.51177 .68046 m
.5119 .68049 L
s
1 .057 0 r
.36355 .65502 m
.36304 .65531 L
s
.36356 .65444 m
.36355 .65502 L
s
1 .019 0 r
.51196 .68068 m
.51177 .6808 L
s
.5119 .68049 m
.51196 .68068 L
s
1 .005 0 r
.56503 .55208 m
.56509 .55214 L
s
.56498 .55212 m
.56503 .55208 L
s
.56503 .55208 m
.56505 .55208 L
s
.56509 .55214 m
.56504 .55218 L
s
.56505 .55208 m
.56509 .55214 L
s
1 .034 0 r
.35785 .50074 m
.35845 .49931 L
s
1 .005 0 r
.56504 .55218 m
.56498 .55212 L
s
.56498 .55212 m
.56505 .55208 L
s
.56505 .55208 m
.56504 .55218 L
s
1 .019 0 r
.51177 .6808 m
.51159 .68058 L
s
.51159 .68058 m
.5119 .68049 L
s
.5119 .68049 m
.51177 .6808 L
s
1 0 0 r
.82579 .47495 m
.82579 .47494 L
s
.82579 .47494 m
.8258 .47495 L
s
.82579 .47495 m
.82579 .47494 L
s
.82579 .47494 m
.82579 .47494 L
s
.8258 .47495 m
.82579 .47495 L
s
.82579 .47494 m
.8258 .47495 L
s
.82579 .47495 m
.82579 .47495 L
s
.82579 .47495 m
.82579 .47494 L
s
.82579 .47494 m
.82579 .47495 L
s
1 .008 0 r
.66163 .70614 m
.66186 .70584 L
s
1 0 0 r
.61867 .42337 m
.61868 .42336 L
s
.61867 .42336 m
.61868 .42336 L
s
.61867 .42336 m
.61867 .42336 L
s
.61867 .42336 m
.61868 .42336 L
s
.61868 .42336 m
.61868 .42336 L
s
.61868 .42336 m
.61868 .42336 L
s
.61868 .42336 m
.61867 .42336 L
s
.61867 .42336 m
.61868 .42336 L
s
.61868 .42336 m
.61868 .42336 L
s
1 .057 0 r
.36304 .65531 m
.36256 .65459 L
s
.36256 .65459 m
.36356 .65444 L
s
1 .027 0 r
.45449 .65458 m
.4554 .65358 L
s
1 .057 0 r
.36356 .65444 m
.36304 .65531 L
s
1 .008 0 r
.66181 .70582 m
.66189 .70591 L
s
.66173 .70588 m
.66181 .70582 L
s
.66181 .70582 m
.66186 .70584 L
s
.66189 .70591 m
.66181 .70597 L
s
.66186 .70584 m
.66189 .70591 L
s
1 .001 0 r
.92252 .62879 m
.92254 .62874 L
s
1 0 0 r
.41152 .37178 m
.41152 .37177 L
s
1 .008 0 r
.66181 .70597 m
.66173 .70588 L
s
.66173 .70588 m
.66186 .70584 L
s
1 0 0 r
.41152 .37177 m
.41152 .37177 L
s
.41152 .37177 m
.41152 .37177 L
s
.41152 .37177 m
.41152 .37177 L
s
.41152 .37177 m
.41152 .37177 L
s
.41152 .37177 m
.41152 .37177 L
s
.41152 .37177 m
.41152 .37177 L
s
.41152 .37177 m
.41152 .37177 L
s
.41152 .37177 m
.41152 .37177 L
s
1 .008 0 r
.66186 .70584 m
.66181 .70597 L
s
1 .001 0 r
.92253 .62874 m
.92255 .62875 L
s
.92252 .62875 m
.92253 .62874 L
s
.92253 .62874 m
.92254 .62874 L
s
.92255 .62875 m
.92254 .62876 L
s
.92254 .62874 m
.92255 .62875 L
s
.92254 .62876 m
.92252 .62875 L
s
.92252 .62875 m
.92254 .62874 L
s
.92254 .62874 m
.92254 .62876 L
s
1 .155 0 r
.24732 .603 m
.2568 .59961 L
s
1 .763 0 r
.20829 .34598 m
.1997 .3508 L
s
.2025 .33748 m
.20829 .34598 L
s
1 .002 0 r
.71537 .57721 m
.71541 .57712 L
s
.7154 .57712 m
.71543 .57714 L
s
.71538 .57713 m
.7154 .57712 L
s
.7154 .57712 m
.71541 .57712 L
s
.71543 .57714 m
.7154 .57716 L
s
.71541 .57712 m
.71543 .57714 L
s
.7154 .57716 m
.71538 .57713 L
s
.71538 .57713 m
.71541 .57712 L
s
.71541 .57712 m
.7154 .57716 L
s
1 .007 0 r
.50819 .52563 m
.50829 .52533 L
s
1 .234 0 r
.23919 .52867 m
.23783 .5254 L
s
.24215 .52554 m
.23919 .52867 L
s
.23783 .5254 m
.24215 .52554 L
s
1 .034 0 r
.35834 .4993 m
.35868 .49965 L
s
.35798 .49953 m
.35834 .4993 L
s
.35834 .4993 m
.35845 .49931 L
s
1 .073 0 r
.30098 .47403 m
.3022 .47087 L
s
1 .007 0 r
.50827 .52533 m
.50834 .5254 L
s
.5082 .52538 m
.50827 .52533 L
s
.50827 .52533 m
.50829 .52533 L
s
.50834 .5254 m
.50827 .52545 L
s
.50829 .52533 m
.50834 .5254 L
s
.50827 .52545 m
.5082 .52538 L
s
.5082 .52538 m
.50829 .52533 L
s
1 .034 0 r
.35868 .49965 m
.35832 .49988 L
s
.35845 .49931 m
.35868 .49965 L
s
1 .007 0 r
.50829 .52533 m
.50827 .52545 L
s
1 .027 0 r
.45522 .65353 m
.45548 .65385 L
s
.45496 .6537 m
.45522 .65353 L
s
.45522 .65353 m
.4554 .65358 L
s
1 0 0 r
.76914 .44823 m
.76914 .44822 L
s
.76914 .44822 m
.76914 .44822 L
s
.76914 .44822 m
.76914 .44822 L
s
.76914 .44822 m
.76914 .44822 L
s
.76914 .44822 m
.76914 .44822 L
s
.76914 .44822 m
.76914 .44822 L
s
.76914 .44822 m
.76914 .44822 L
s
.76914 .44822 m
.76914 .44822 L
s
.76914 .44822 m
.76914 .44822 L
s
1 .027 0 r
.45548 .65385 m
.45521 .65402 L
s
.4554 .65358 m
.45548 .65385 L
s
1 .01 0 r
.6049 .67952 m
.60518 .67913 L
s
1 .034 0 r
.35832 .49988 m
.35798 .49953 L
s
.35798 .49953 m
.35845 .49931 L
s
1 0 0 r
.56192 .39662 m
.56192 .39661 L
s
.56192 .39661 m
.56192 .39661 L
s
.56191 .39661 m
.56192 .39661 L
s
.56192 .39661 m
.56192 .39661 L
s
.56192 .39662 m
.56191 .39661 L
s
.56191 .39661 m
.56192 .39661 L
s
.56192 .39661 m
.56192 .39662 L
s
.56192 .39661 m
.56192 .39661 L
s
.56192 .39661 m
.56192 .39662 L
s
1 .027 0 r
.45521 .65402 m
.45496 .6537 L
s
.45496 .6537 m
.4554 .65358 L
s
1 .034 0 r
.35845 .49931 m
.35832 .49988 L
s
1 .027 0 r
.4554 .65358 m
.45521 .65402 L
s
1 .041 0 r
.39765 .62793 m
.39911 .62644 L
s
1 .092 0 r
.30797 .6267 m
.30865 .62791 L
s
.3072 .62712 m
.30797 .6267 L
s
.30797 .6267 m
.30886 .62699 L
s
.30865 .62791 m
.30788 .62833 L
s
.30886 .62699 m
.30865 .62791 L
s
1 .001 0 r
.8659 .60213 m
.86592 .60208 L
s
1 0 0 r
.35466 .345 m
.35466 .345 L
s
.35466 .345 m
.35466 .345 L
s
.35466 .345 m
.35466 .345 L
s
.35466 .345 m
.35466 .345 L
s
.35466 .345 m
.35466 .345 L
s
.35466 .345 m
.35466 .345 L
s
.35466 .345 m
.35466 .345 L
s
.35466 .345 m
.35466 .345 L
s
.35466 .345 m
.35466 .345 L
s
1 .01 0 r
.60512 .67912 m
.60522 .67923 L
s
.60502 .67919 m
.60512 .67912 L
s
.60512 .67912 m
.60518 .67913 L
s
1 .001 0 r
.86591 .60208 m
.86593 .6021 L
s
.8659 .60209 m
.86591 .60208 L
s
.86591 .60208 m
.86592 .60208 L
s
.86593 .6021 m
.86592 .6021 L
s
.86592 .60208 m
.86593 .6021 L
s
1 .01 0 r
.60522 .67923 m
.60512 .6793 L
s
.60518 .67913 m
.60522 .67923 L
s
1 .001 0 r
.86592 .6021 m
.8659 .60209 L
s
.8659 .60209 m
.86592 .60208 L
s
.86592 .60208 m
.86592 .6021 L
s
1 .01 0 r
.60512 .6793 m
.60502 .67919 L
s
.60502 .67919 m
.60518 .67913 L
s
.60518 .67913 m
.60512 .6793 L
s
1 .003 0 r
.65865 .55053 m
.65869 .55042 L
s
.65868 .55042 m
.65871 .55045 L
s
.65865 .55044 m
.65868 .55042 L
s
.65868 .55042 m
.65869 .55042 L
s
.65871 .55045 m
.65868 .55046 L
s
.65869 .55042 m
.65871 .55045 L
s
.65868 .55046 m
.65865 .55044 L
s
.65865 .55044 m
.65869 .55042 L
s
.65869 .55042 m
.65868 .55046 L
s
1 .009 0 r
.45137 .49892 m
.45148 .49851 L
s
1 .005 0 r
.75542 .70449 m
.75554 .70431 L
s
1 .468 0 r
.23002 .45351 m
.22708 .44705 L
s
.23569 .44705 m
.23002 .45351 L
s
1 .248 0 r
.24405 .44729 m
.2479 .43641 L
s
1 0 0 r
.71243 .42148 m
.71243 .42147 L
s
.71243 .42147 m
.71243 .42147 L
s
.71243 .42147 m
.71243 .42147 L
s
.71243 .42147 m
.71243 .42147 L
s
.71243 .42147 m
.71243 .42147 L
s
.71243 .42147 m
.71243 .42147 L
s
.71243 .42147 m
.71243 .42147 L
s
.71243 .42147 m
.71243 .42147 L
s
.71243 .42147 m
.71243 .42147 L
s
1 .009 0 r
.45146 .49851 m
.45155 .4986 L
s
.45136 .49858 m
.45146 .49851 L
s
.45146 .49851 m
.45148 .49851 L
s
.45155 .4986 m
.45145 .49867 L
s
.45148 .49851 m
.45155 .4986 L
s
1 .005 0 r
.75551 .7043 m
.75556 .70435 L
s
.75547 .70434 m
.75551 .7043 L
s
.75551 .7043 m
.75554 .70431 L
s
.75556 .70435 m
.75552 .70439 L
s
.75554 .70431 m
.75556 .70435 L
s
1 .009 0 r
.45145 .49867 m
.45136 .49858 L
s
.45136 .49858 m
.45148 .49851 L
s
1 .005 0 r
.75552 .70439 m
.75547 .70434 L
s
.75547 .70434 m
.75554 .70431 L
s
1 .16 0 r
.26928 .49643 m
.27069 .49837 L
s
.26769 .49725 m
.26928 .49643 L
s
.26928 .49643 m
.27037 .49662 L
s
1 .013 0 r
.54811 .65288 m
.54847 .65236 L
s
1 .005 0 r
.75554 .70431 m
.75552 .70439 L
s
1 .009 0 r
.45148 .49851 m
.45145 .49867 L
s
1 .092 0 r
.30788 .62833 m
.3072 .62712 L
s
.3072 .62712 m
.30886 .62699 L
s
.30886 .62699 m
.30788 .62833 L
s
1 .468 0 r
.22708 .44705 m
.23569 .44705 L
s
1 0 0 r
.5051 .36984 m
.5051 .36984 L
s
.5051 .36984 m
.5051 .36984 L
s
.5051 .36984 m
.5051 .36984 L
s
.5051 .36984 m
.5051 .36984 L
s
.5051 .36984 m
.5051 .36984 L
s
.5051 .36984 m
.5051 .36984 L
s
.5051 .36984 m
.5051 .36984 L
s
.5051 .36984 m
.5051 .36984 L
s
.5051 .36984 m
.5051 .36984 L
s
1 .16 0 r
.27069 .49837 m
.2691 .49919 L
s
.27037 .49662 m
.27069 .49837 L
s
1 .068 0 r
.34076 .60126 m
.34341 .59887 L
s
1 .041 0 r
.39883 .62637 m
.39921 .62686 L
s
.39842 .62661 m
.39883 .62637 L
s
.39883 .62637 m
.39911 .62644 L
s
1 .001 0 r
.80922 .57545 m
.80925 .5754 L
s
.80924 .5754 m
.80925 .57541 L
s
.80923 .57541 m
.80924 .5754 L
s
.80924 .5754 m
.80925 .5754 L
s
.80925 .57541 m
.80924 .57542 L
s
.80925 .5754 m
.80925 .57541 L
s
1 .041 0 r
.39921 .62686 m
.3988 .6271 L
s
.39911 .62644 m
.39921 .62686 L
s
1 .001 0 r
.80924 .57542 m
.80923 .57541 L
s
.80923 .57541 m
.80925 .5754 L
s
.80925 .5754 m
.80924 .57542 L
s
1 .155 0 r
.25587 .6011 m
.25481 .60166 L
s
.255 .59892 m
.25587 .6011 L
s
.2568 .59961 m
.25587 .6011 L
s
1 .013 0 r
.5484 .65235 m
.54853 .6525 L
s
.54826 .65244 m
.5484 .65235 L
s
.5484 .65235 m
.54847 .65236 L
s
.54853 .6525 m
.5484 .65259 L
s
.54847 .65236 m
.54853 .6525 L
s
1 .003 0 r
.60187 .52382 m
.60191 .5237 L
s
1 .013 0 r
.5484 .65259 m
.54826 .65244 L
s
.54826 .65244 m
.54847 .65236 L
s
1 .155 0 r
.25394 .59948 m
.255 .59892 L
s
.255 .59892 m
.2568 .59961 L
s
1 .013 0 r
.54847 .65236 m
.5484 .65259 L
s
1 .003 0 r
.6019 .5237 m
.60193 .52372 L
s
.60187 .52372 m
.6019 .5237 L
s
.6019 .5237 m
.60191 .5237 L
s
.60193 .52372 m
.6019 .52375 L
s
.60191 .5237 m
.60193 .52372 L
s
.6019 .52375 m
.60187 .52372 L
s
.60187 .52372 m
.60191 .5237 L
s
.60191 .5237 m
.6019 .52375 L
s
1 .041 0 r
.3988 .6271 m
.39842 .62661 L
s
.39842 .62661 m
.39911 .62644 L
s
.39911 .62644 m
.3988 .6271 L
s
1 .014 0 r
.39449 .47218 m
.39461 .47156 L
s
1 0 0 r
.86306 .44636 m
.86306 .44635 L
s
.86306 .44635 m
.86306 .44635 L
s
.86306 .44635 m
.86306 .44635 L
s
.86306 .44635 m
.86306 .44635 L
s
.86306 .44635 m
.86306 .44635 L
s
.86306 .44635 m
.86306 .44635 L
s
.86306 .44635 m
.86306 .44635 L
s
.86306 .44635 m
.86306 .44635 L
s
.86306 .44635 m
.86306 .44635 L
s
1 .006 0 r
.69868 .67785 m
.69882 .67763 L
s
0 .124 1 r
.18706 .42053 m
.24745 .23414 L
s
1 0 0 r
.65566 .3947 m
.65566 .3947 L
s
.65566 .3947 m
.65567 .3947 L
s
.65566 .3947 m
.65566 .3947 L
s
.65566 .3947 m
.65566 .3947 L
s
.65566 .3947 m
.65566 .3947 L
s
.65566 .3947 m
.65566 .3947 L
s
.65567 .3947 m
.65566 .3947 L
s
.65566 .3947 m
.65567 .3947 L
s
.65566 .3947 m
.65566 .3947 L
s
1 .073 0 r
.30199 .47088 m
.30272 .47163 L
s
.30119 .47137 m
.30199 .47088 L
s
.30199 .47088 m
.3022 .47087 L
s
1 .006 0 r
.69879 .67762 m
.69885 .67768 L
s
.69873 .67766 m
.69879 .67762 L
s
.69879 .67762 m
.69882 .67763 L
s
1 .019 0 r
.49126 .62622 m
.49176 .62549 L
s
1 .006 0 r
.69885 .67768 m
.69879 .67772 L
s
.69882 .67763 m
.69885 .67768 L
s
.69879 .67772 m
.69873 .67766 L
s
.69873 .67766 m
.69882 .67763 L
s
.69882 .67763 m
.69879 .67772 L
s
1 .014 0 r
.39459 .47157 m
.39473 .4717 L
s
.39443 .47167 m
.39459 .47157 L
s
.39459 .47157 m
.39461 .47156 L
s
1 0 0 r
.44824 .34304 m
.44824 .34304 L
s
.44824 .34304 m
.44824 .34304 L
s
.44824 .34304 m
.44824 .34304 L
s
.44824 .34304 m
.44824 .34304 L
s
.44824 .34304 m
.44824 .34304 L
s
.44824 .34304 m
.44824 .34304 L
s
.44824 .34304 m
.44824 .34304 L
s
.44824 .34304 m
.44824 .34304 L
s
.44824 .34304 m
.44824 .34304 L
s
1 .014 0 r
.39473 .4717 m
.39458 .4718 L
s
.39461 .47156 m
.39473 .4717 L
s
1 .763 0 r
.1997 .3508 m
.19222 .34301 L
s
.19222 .34301 m
.2025 .33748 L
s
1 .014 0 r
.39458 .4718 m
.39443 .47167 L
s
.39443 .47167 m
.39461 .47156 L
s
1 .073 0 r
.30272 .47163 m
.30191 .47212 L
s
.3022 .47087 m
.30272 .47163 L
s
1 .125 0 r
.28381 .57457 m
.28957 .57053 L
s
1 .014 0 r
.39461 .47156 m
.39458 .4718 L
s
1 .001 0 r
.7525 .54874 m
.75252 .54869 L
s
1 .16 0 r
.2691 .49919 m
.26769 .49725 L
s
.26769 .49725 m
.27037 .49662 L
s
1 .001 0 r
.75251 .54869 m
.75253 .5487 L
s
.7525 .5487 m
.75251 .54869 L
s
.75251 .54869 m
.75252 .54869 L
s
.75253 .5487 m
.75251 .54871 L
s
.75252 .54869 m
.75253 .5487 L
s
.75251 .54871 m
.7525 .5487 L
s
.7525 .5487 m
.75252 .54869 L
s
.75252 .54869 m
.75251 .54871 L
s
1 .073 0 r
.30191 .47212 m
.30119 .47137 L
s
.30119 .47137 m
.3022 .47087 L
s
1 .003 0 r
.54504 .49709 m
.54508 .49694 L
s
1 .16 0 r
.27037 .49662 m
.2691 .49919 L
s
1 .019 0 r
.49166 .62547 m
.49185 .62568 L
s
.49148 .6256 m
.49166 .62547 L
s
.49166 .62547 m
.49176 .62549 L
s
1 .003 0 r
.54507 .49694 m
.54511 .49697 L
s
.54503 .49696 m
.54507 .49694 L
s
.54507 .49694 m
.54508 .49694 L
s
1 .019 0 r
.49185 .62568 m
.49166 .6258 L
s
.49176 .62549 m
.49185 .62568 L
s
1 .003 0 r
.54511 .49697 m
.54507 .497 L
s
.54508 .49694 m
.54511 .49697 L
s
.54507 .497 m
.54503 .49696 L
s
.54503 .49696 m
.54508 .49694 L
s
.54508 .49694 m
.54507 .497 L
s
.84936 .70284 m
.84944 .70272 L
s
1 .024 0 r
.33755 .44542 m
.33764 .44432 L
s
1 .073 0 r
.3022 .47087 m
.30191 .47212 L
s
1 .019 0 r
.49166 .6258 m
.49148 .6256 L
s
.49148 .6256 m
.49176 .62549 L
s
.49176 .62549 m
.49166 .6258 L
s
1 .003 0 r
.84942 .70272 m
.84945 .70275 L
s
.84939 .70274 m
.84942 .70272 L
s
.84942 .70272 m
.84944 .70272 L
s
.84945 .70275 m
.84942 .70277 L
s
.84944 .70272 m
.84945 .70275 L
s
1 0 0 r
.80634 .41958 m
.80634 .41958 L
s
.80634 .41958 m
.80634 .41958 L
s
.80634 .41958 m
.80634 .41958 L
s
.80634 .41958 m
.80634 .41958 L
s
.80634 .41958 m
.80634 .41958 L
s
.80634 .41958 m
.80634 .41958 L
s
.80634 .41958 m
.80634 .41958 L
s
.80634 .41958 m
.80634 .41958 L
s
.80634 .41958 m
.80634 .41958 L
s
1 .003 0 r
.84942 .70277 m
.84939 .70274 L
s
.84939 .70274 m
.84944 .70272 L
s
.84944 .70272 m
.84942 .70277 L
s
1 .007 0 r
.64188 .65119 m
.64205 .65091 L
s
1 .068 0 r
.34291 .59875 m
.3435 .59958 L
s
.34225 .59912 m
.34291 .59875 L
s
.34291 .59875 m
.34341 .59887 L
s
1 .155 0 r
.2568 .59961 m
.25481 .60166 L
s
.25394 .59948 m
.2568 .59961 L
s
1 0 0 r
.59885 .3679 m
.59885 .3679 L
s
.59885 .3679 m
.59885 .3679 L
s
.59885 .3679 m
.59885 .3679 L
s
.59885 .3679 m
.59885 .3679 L
s
.59885 .3679 m
.59885 .3679 L
s
.59885 .3679 m
.59885 .3679 L
s
.59885 .3679 m
.59885 .3679 L
s
.59885 .3679 m
.59885 .3679 L
s
.59885 .3679 m
.59885 .3679 L
s
1 .155 0 r
.25481 .60166 m
.25394 .59948 L
s
1 .068 0 r
.3435 .59958 m
.34285 .59995 L
s
.34341 .59887 m
.3435 .59958 L
s
1 .027 0 r
.43437 .59952 m
.43511 .59845 L
s
1 .007 0 r
.64201 .6509 m
.64209 .65097 L
s
.64194 .65095 m
.64201 .6509 L
s
.64201 .6509 m
.64205 .65091 L
s
.64209 .65097 m
.64202 .65103 L
s
.64205 .65091 m
.64209 .65097 L
s
.64202 .65103 m
.64194 .65095 L
s
.64194 .65095 m
.64205 .65091 L
s
.64205 .65091 m
.64202 .65103 L
s
1 .001 0 r
.90324 .57369 m
.90325 .57366 L
s
.90325 .57366 m
.90326 .57366 L
s
.90324 .57366 m
.90325 .57366 L
s
.90325 .57366 m
.90325 .57366 L
s
.90326 .57366 m
.90325 .57367 L
s
.90325 .57366 m
.90326 .57366 L
s
.90325 .57367 m
.90324 .57366 L
s
.90324 .57366 m
.90325 .57366 L
s
.90325 .57366 m
.90325 .57367 L
s
1 .257 0 r
.22681 .54785 m
.24226 .54186 L
s
1 .001 0 r
.69572 .52201 m
.69573 .52195 L
s
.69573 .52195 m
.69575 .52196 L
s
.69572 .52196 m
.69573 .52195 L
s
.69573 .52195 m
.69573 .52195 L
s
.69575 .52196 m
.69573 .52197 L
s
.69573 .52195 m
.69575 .52196 L
s
.69573 .52197 m
.69572 .52196 L
s
.69572 .52196 m
.69573 .52195 L
s
.69573 .52195 m
.69573 .52197 L
s
1 .024 0 r
.33763 .44434 m
.33788 .44456 L
s
.33736 .44452 m
.33763 .44434 L
s
.33763 .44434 m
.33764 .44432 L
s
1 .068 0 r
.34285 .59995 m
.34225 .59912 L
s
.34225 .59912 m
.34341 .59887 L
s
1 .004 0 r
.48816 .47033 m
.48818 .47015 L
s
1 .024 0 r
.33788 .44456 m
.33761 .44474 L
s
.33764 .44432 m
.33788 .44456 L
s
1 .068 0 r
.34341 .59887 m
.34285 .59995 L
s
1 .024 0 r
.33761 .44474 m
.33736 .44452 L
s
.33736 .44452 m
.33764 .44432 L
s
1 .078 0 r
.32363 .70201 m
.32781 .69996 L
s
1 .004 0 r
.48818 .47015 m
.48822 .47019 L
s
.48814 .47018 m
.48818 .47015 L
s
.48818 .47015 m
.48818 .47015 L
s
.48822 .47019 m
.48818 .47022 L
s
.48818 .47015 m
.48822 .47019 L
s
.48818 .47022 m
.48814 .47018 L
s
.48814 .47018 m
.48818 .47015 L
s
1 .024 0 r
.33764 .44432 m
.33761 .44474 L
s
1 .004 0 r
.48818 .47015 m
.48818 .47022 L
s
1 .003 0 r
.79262 .67618 m
.7927 .67604 L
s
1 .056 0 r
.28057 .41863 m
.28024 .41602 L
s
1 .003 0 r
.79268 .67604 m
.79272 .67607 L
s
.79265 .67606 m
.79268 .67604 L
s
.79268 .67604 m
.7927 .67604 L
s
1 0 0 r
.74958 .39278 m
.74958 .39278 L
s
.74958 .39278 m
.74958 .39278 L
s
.74958 .39278 m
.74958 .39278 L
s
.74958 .39278 m
.74958 .39278 L
s
.74958 .39278 m
.74958 .39278 L
s
.74958 .39278 m
.74958 .39278 L
s
.74958 .39278 m
.74958 .39278 L
s
.74958 .39278 m
.74958 .39278 L
s
.74958 .39278 m
.74958 .39278 L
s
1 .003 0 r
.79272 .67607 m
.79269 .6761 L
s
.7927 .67604 m
.79272 .67607 L
s
.79269 .6761 m
.79265 .67606 L
s
.79265 .67606 m
.7927 .67604 L
s
.7927 .67604 m
.79269 .6761 L
s
1 .027 0 r
.43496 .59842 m
.43523 .59873 L
s
.43468 .5986 m
.43496 .59842 L
s
.43496 .59842 m
.43511 .59845 L
s
1 .009 0 r
.58504 .62449 m
.58524 .62414 L
s
1 .027 0 r
.43523 .59873 m
.43495 .59891 L
s
.43511 .59845 m
.43523 .59873 L
s
1 0 0 r
.54198 .34107 m
.54198 .34107 L
s
.54198 .34107 m
.54198 .34107 L
s
.54198 .34107 m
.54198 .34107 L
s
.54198 .34107 m
.54198 .34107 L
s
.54198 .34107 m
.54198 .34107 L
s
.54198 .34107 m
.54198 .34107 L
s
.54198 .34107 m
.54198 .34107 L
s
.54198 .34107 m
.54198 .34107 L
s
.54198 .34107 m
.54198 .34107 L
s
1 .027 0 r
.43495 .59891 m
.43468 .5986 L
s
.43468 .5986 m
.43511 .59845 L
s
1 .044 0 r
.37741 .5728 m
.37865 .57106 L
s
1 .027 0 r
.43511 .59845 m
.43495 .59891 L
s
1 .009 0 r
.58519 .62413 m
.58529 .62422 L
s
.5851 .62419 m
.58519 .62413 L
s
.58519 .62413 m
.58524 .62414 L
s
1 .001 0 r
.84651 .54696 m
.84652 .54692 L
s
1 .009 0 r
.58529 .62422 m
.5852 .62429 L
s
.58524 .62414 m
.58529 .62422 L
s
1 .001 0 r
.84652 .54692 m
.84653 .54693 L
s
.84651 .54693 m
.84652 .54692 L
s
.84652 .54692 m
.84652 .54692 L
s
.84653 .54693 m
.84652 .54694 L
s
.84652 .54692 m
.84653 .54693 L
s
.84652 .54694 m
.84651 .54693 L
s
.84651 .54693 m
.84652 .54692 L
s
.84652 .54692 m
.84652 .54694 L
s
1 .009 0 r
.5852 .62429 m
.5851 .62419 L
s
.5851 .62419 m
.58524 .62414 L
s
.58524 .62414 m
.5852 .62429 L
s
1 .001 0 r
.63888 .49525 m
.6389 .49519 L
s
1 .763 0 r
.2025 .33748 m
.1997 .3508 L
s
1 .001 0 r
.63889 .49519 m
.63891 .4952 L
s
.63888 .4952 m
.63889 .49519 L
s
.63889 .49519 m
.6389 .49519 L
s
.63891 .4952 m
.63889 .49521 L
s
.6389 .49519 m
.63891 .4952 L
s
.63889 .49521 m
.63888 .4952 L
s
.63888 .4952 m
.6389 .49519 L
s
.6389 .49519 m
.63889 .49521 L
s
1 .002 0 r
.94347 .70118 m
.94352 .70111 L
s
1 .005 0 r
.43122 .44354 m
.43123 .44332 L
s
1 .002 0 r
.94351 .70111 m
.94353 .70113 L
s
.94349 .70112 m
.94351 .70111 L
s
.94351 .70111 m
.94352 .70111 L
s
.94353 .70113 m
.94351 .70114 L
s
.94352 .70111 m
.94353 .70113 L
s
.94351 .70114 m
.94349 .70112 L
s
.94349 .70112 m
.94352 .70111 L
s
.94352 .70111 m
.94351 .70114 L
s
1 .116 0 r
.26661 .67534 m
.27378 .67293 L
s
1 .005 0 r
.43123 .44332 m
.43128 .44337 L
s
.43118 .44336 m
.43123 .44332 L
s
.43123 .44332 m
.43123 .44332 L
s
.43128 .44337 m
.43123 .4434 L
s
.43123 .44332 m
.43128 .44337 L
s
.43123 .4434 m
.43118 .44336 L
s
.43118 .44336 m
.43123 .44332 L
s
1 .004 0 r
.73582 .64949 m
.73591 .64933 L
s
1 .238 0 r
.22352 .39182 m
.21554 .38139 L
s
1 .005 0 r
.43123 .44332 m
.43123 .4434 L
s
1 0 0 r
.69275 .36595 m
.69275 .36595 L
s
.69275 .36595 m
.69275 .36595 L
s
.69275 .36595 m
.69275 .36595 L
s
.69275 .36595 m
.69275 .36595 L
s
.69275 .36595 m
.69275 .36595 L
s
.69275 .36595 m
.69275 .36595 L
s
.69275 .36595 m
.69275 .36595 L
s
.69275 .36595 m
.69275 .36595 L
s
.69275 .36595 m
.69275 .36595 L
s
1 .004 0 r
.73589 .64932 m
.73593 .64936 L
s
.73585 .64935 m
.73589 .64932 L
s
.73589 .64932 m
.73591 .64933 L
s
.73593 .64936 m
.73589 .64939 L
s
.73591 .64933 m
.73593 .64936 L
s
.73589 .64939 m
.73585 .64935 L
s
.73585 .64935 m
.73591 .64933 L
s
.73591 .64933 m
.73589 .64939 L
s
1 .012 0 r
.52813 .59778 m
.52838 .5973 L
s
1 .125 0 r
.28849 .57024 m
.28948 .57185 L
s
.28735 .57082 m
.28849 .57024 L
s
.28849 .57024 m
.28957 .57053 L
s
1 .078 0 r
.32755 .70071 m
.32694 .70107 L
s
.32701 .69967 m
.32755 .70071 L
s
.32781 .69996 m
.32755 .70071 L
s
1 .125 0 r
.28948 .57185 m
.28835 .57244 L
s
.28957 .57053 m
.28948 .57185 L
s
1 .078 0 r
.32639 .70003 m
.32701 .69967 L
s
.32701 .69967 m
.32781 .69996 L
s
1 .082 0 r
.32041 .54606 m
.32291 .54286 L
s
1 .001 0 r
.78972 .5202 m
.78973 .52017 L
s
.78973 .52017 m
.78974 .52017 L
s
.78972 .52017 m
.78973 .52017 L
s
.78973 .52017 m
.78973 .52017 L
s
.78974 .52017 m
.78973 .52018 L
s
.78973 .52017 m
.78974 .52017 L
s
.78973 .52018 m
.78972 .52017 L
s
.78972 .52017 m
.78973 .52017 L
s
.78973 .52017 m
.78973 .52018 L
s
1 .012 0 r
.52833 .59729 m
.52846 .59741 L
s
.52821 .59737 m
.52833 .59729 L
s
.52833 .59729 m
.52838 .5973 L
s
.52846 .59741 m
.52833 .5975 L
s
.52838 .5973 m
.52846 .59741 L
s
1 .044 0 r
.37842 .57102 m
.37885 .57152 L
s
.37797 .5713 m
.37842 .57102 L
s
.37842 .57102 m
.37865 .57106 L
s
1 .012 0 r
.52833 .5975 m
.52821 .59737 L
s
.52821 .59737 m
.52838 .5973 L
s
.52838 .5973 m
.52833 .5975 L
s
1 .001 0 r
.58199 .46847 m
.582 .4684 L
s
1 .044 0 r
.37885 .57152 m
.37839 .5718 L
s
.37865 .57106 m
.37885 .57152 L
s
1 .001 0 r
.582 .4684 m
.58202 .46842 L
s
.58199 .46841 m
.582 .4684 L
s
.582 .4684 m
.582 .4684 L
s
.58202 .46842 m
.582 .46843 L
s
.582 .4684 m
.58202 .46842 L
s
.582 .46843 m
.58199 .46841 L
s
.58199 .46841 m
.582 .4684 L
s
.582 .4684 m
.582 .46843 L
s
1 .042 0 r
.41733 .70036 m
.41903 .69895 L
s
1 .056 0 r
.28033 .41607 m
.28091 .41654 L
s
.2797 .41654 m
.28033 .41607 L
s
.28033 .41607 m
.28024 .41602 L
s
1 .002 0 r
.88673 .6745 m
.88677 .67441 L
s
1 .006 0 r
.37423 .41673 m
.3742 .41645 L
s
1 .002 0 r
.88676 .67441 m
.88679 .67443 L
s
.88674 .67443 m
.88676 .67441 L
s
.88676 .67441 m
.88677 .67441 L
s
.88679 .67443 m
.88677 .67445 L
s
.88677 .67441 m
.88679 .67443 L
s
.88677 .67445 m
.88674 .67443 L
s
.88674 .67443 m
.88677 .67441 L
s
.88677 .67441 m
.88677 .67445 L
s
1 .044 0 r
.37839 .5718 m
.37797 .5713 L
s
.37797 .5713 m
.37865 .57106 L
s
1 0 0 r
.84365 .39086 m
.84365 .39085 L
s
.84365 .39085 m
.84365 .39086 L
s
.84365 .39086 m
.84365 .39085 L
s
.84365 .39085 m
.84365 .39085 L
s
.84365 .39086 m
.84365 .39086 L
s
.84365 .39086 m
.84365 .39085 L
s
.84365 .39086 m
.84365 .39086 L
s
.84365 .39085 m
.84365 .39086 L
s
.84365 .39085 m
.84365 .39086 L
s
1 .005 0 r
.67897 .62277 m
.67906 .62258 L
s
1 .044 0 r
.37865 .57106 m
.37839 .5718 L
s
1 .056 0 r
.28027 .41702 m
.2797 .41654 L
s
.2797 .41654 m
.28024 .41602 L
s
.28091 .41654 m
.28027 .41702 L
s
.28024 .41602 m
.28091 .41654 L
s
1 .006 0 r
.37421 .41645 m
.37427 .4165 L
s
.37414 .4165 m
.37421 .41645 L
s
.37421 .41645 m
.3742 .41645 L
s
.3742 .41655 m
.37414 .4165 L
s
.37414 .4165 m
.3742 .41645 L
s
.37427 .4165 m
.3742 .41655 L
s
.3742 .41645 m
.37427 .4165 L
s
.3742 .41645 m
.3742 .41655 L
s
1 .078 0 r
.32694 .70107 m
.32639 .70003 L
s
.32781 .69996 m
.32694 .70107 L
s
.32639 .70003 m
.32781 .69996 L
s
1 0 0 r
.63588 .3391 m
.63588 .3391 L
s
.63588 .3391 m
.63588 .3391 L
s
.63588 .3391 m
.63588 .3391 L
s
.63588 .3391 m
.63588 .3391 L
s
.63588 .3391 m
.63588 .3391 L
s
.63588 .3391 m
.63588 .3391 L
s
.63588 .3391 m
.63588 .3391 L
s
.63588 .3391 m
.63588 .3391 L
s
.63588 .3391 m
.63588 .3391 L
s
1 .005 0 r
.67904 .62258 m
.67909 .62262 L
s
.679 .62261 m
.67904 .62258 L
s
.67904 .62258 m
.67906 .62258 L
s
.67909 .62262 m
.67905 .62266 L
s
.67906 .62258 m
.67909 .62262 L
s
.67905 .62266 m
.679 .62261 L
s
.679 .62261 m
.67906 .62258 L
s
.67906 .62258 m
.67905 .62266 L
s
1 .017 0 r
.47118 .57104 m
.47151 .57035 L
s
1 .056 0 r
.28024 .41602 m
.28027 .41702 L
s
1 .116 0 r
.27306 .674 m
.27228 .67446 L
s
.27242 .67237 m
.27306 .674 L
s
.27378 .67293 m
.27306 .674 L
s
1 .187 0 r
.26335 .51929 m
.27021 .51239 L
s
1 .125 0 r
.28835 .57244 m
.28735 .57082 L
s
.28735 .57082 m
.28957 .57053 L
s
1 .116 0 r
.27164 .67283 m
.27242 .67237 L
s
.27242 .67237 m
.27378 .67293 L
s
1 .125 0 r
.28957 .57053 m
.28835 .57244 L
s
1 .001 0 r
.73289 .49342 m
.73289 .49338 L
s
.73289 .49338 m
.7329 .49339 L
s
.73288 .49339 m
.73289 .49338 L
s
.73289 .49338 m
.73289 .49338 L
s
.7329 .49339 m
.73289 .4934 L
s
.73289 .49338 m
.7329 .49339 L
s
.73289 .4934 m
.73288 .49339 L
s
.73288 .49339 m
.73289 .49338 L
s
.73289 .49338 m
.73289 .4934 L
s
1 .529 0 r
.2355 .46756 m
.23146 .46929 L
s
.23217 .46025 m
.2355 .46756 L
s
.2379 .46197 m
.2355 .46756 L
s
1 .001 0 r
.52505 .44166 m
.52505 .44159 L
s
1 .017 0 r
.47145 .57034 m
.47162 .57051 L
s
.47127 .57046 m
.47145 .57034 L
s
.47145 .57034 m
.47151 .57035 L
s
1 .001 0 r
.52505 .44159 m
.52507 .4416 L
s
.52504 .4416 m
.52505 .44159 L
s
.52505 .44159 m
.52505 .44159 L
s
.52507 .4416 m
.52505 .44162 L
s
.52505 .44159 m
.52507 .4416 L
s
.52505 .44162 m
.52504 .4416 L
s
.52504 .4416 m
.52505 .44159 L
s
.52505 .44159 m
.52505 .44162 L
s
1 .017 0 r
.47162 .57051 m
.47144 .57063 L
s
.47151 .57035 m
.47162 .57051 L
s
1 .063 0 r
.3603 .67366 m
.36311 .67164 L
s
1 .042 0 r
.4187 .69885 m
.41907 .69937 L
s
.41831 .69909 m
.4187 .69885 L
s
.4187 .69885 m
.41903 .69895 L
s
1 .017 0 r
.47144 .57063 m
.47127 .57046 L
s
.47127 .57046 m
.47151 .57035 L
s
1 .529 0 r
.22812 .46197 m
.23217 .46025 L
s
.23217 .46025 m
.2379 .46197 L
s
1 .042 0 r
.41907 .69937 m
.41868 .69961 L
s
.41903 .69895 m
.41907 .69937 L
s
1 .002 0 r
.82992 .64778 m
.82997 .64769 L
s
1 .017 0 r
.47151 .57035 m
.47144 .57063 L
s
1 .008 0 r
.31718 .38989 m
.31706 .38953 L
s
1 .002 0 r
.82996 .64769 m
.82999 .64771 L
s
.82994 .6477 m
.82996 .64769 L
s
.82996 .64769 m
.82997 .64769 L
s
.82999 .64771 m
.82996 .64773 L
s
.82997 .64769 m
.82999 .64771 L
s
.82996 .64773 m
.82994 .6477 L
s
.82994 .6477 m
.82997 .64769 L
s
.82997 .64769 m
.82996 .64773 L
s
1 0 0 r
.78682 .36401 m
.78682 .36401 L
s
.78682 .36401 m
.78682 .36401 L
s
.78682 .36401 m
.78682 .36401 L
s
.78682 .36401 m
.78682 .36401 L
s
.78682 .36401 m
.78682 .36401 L
s
.78682 .36401 m
.78682 .36401 L
s
.78682 .36401 m
.78682 .36401 L
s
.78682 .36401 m
.78682 .36401 L
s
.78682 .36401 m
.78682 .36401 L
s
1 .006 0 r
.62206 .59603 m
.62217 .5958 L
s
1 .257 0 r
.24083 .54442 m
.239 .5453 L
s
.23933 .54082 m
.24083 .54442 L
s
.24226 .54186 m
.24083 .54442 L
s
1 .008 0 r
.31709 .38954 m
.31717 .38959 L
s
.317 .38961 m
.31709 .38954 L
s
.31709 .38954 m
.31706 .38953 L
s
.31708 .38967 m
.317 .38961 L
s
.317 .38961 m
.31706 .38953 L
s
1 .042 0 r
.41868 .69961 m
.41831 .69909 L
s
.41831 .69909 m
.41903 .69895 L
s
1 .008 0 r
.31717 .38959 m
.31708 .38967 L
s
.31706 .38953 m
.31717 .38959 L
s
.31706 .38953 m
.31708 .38967 L
s
1 .042 0 r
.41903 .69895 m
.41868 .69961 L
s
1 .006 0 r
.62215 .59579 m
.62221 .59585 L
s
.62209 .59583 m
.62215 .59579 L
s
.62215 .59579 m
.62217 .5958 L
s
1 .026 0 r
.41417 .54427 m
.41465 .5432 L
s
1 .006 0 r
.62221 .59585 m
.62215 .59589 L
s
.62217 .5958 m
.62221 .59585 L
s
.62215 .59589 m
.62209 .59583 L
s
.62209 .59583 m
.62217 .5958 L
s
1 .257 0 r
.2375 .5417 m
.23933 .54082 L
s
.23933 .54082 m
.24226 .54186 L
s
1 .006 0 r
.62217 .5958 m
.62215 .59589 L
s
1 0 0 r
.88389 .51838 m
.8839 .51836 L
s
.8839 .51836 m
.8839 .51837 L
s
.88389 .51837 m
.8839 .51836 L
s
.8839 .51836 m
.8839 .51836 L
s
.8839 .51837 m
.8839 .51837 L
s
.8839 .51836 m
.8839 .51837 L
s
.8839 .51837 m
.88389 .51837 L
s
.88389 .51837 m
.8839 .51836 L
s
.8839 .51836 m
.8839 .51837 L
s
1 .569 0 r
.20623 .4925 m
.23895 .47758 L
s
1 .001 0 r
.67599 .46661 m
.676 .46658 L
s
.676 .46658 m
.676 .46658 L
s
.67599 .46658 m
.676 .46658 L
s
.676 .46658 m
.676 .46658 L
s
.676 .46658 m
.676 .46659 L
s
.676 .46658 m
.676 .46658 L
s
.676 .46659 m
.67599 .46658 L
s
.67599 .46658 m
.676 .46658 L
s
.676 .46658 m
.676 .46659 L
s
1 .116 0 r
.27378 .67293 m
.27228 .67446 L
s
.27164 .67283 m
.27378 .67293 L
s
.27228 .67446 m
.27164 .67283 L
s
1 .022 0 r
.51119 .6987 m
.5119 .69789 L
s
1 .082 0 r
.32245 .54279 m
.32322 .54374 L
s
.3216 .54327 m
.32245 .54279 L
s
.32245 .54279 m
.32291 .54286 L
s
1 .001 0 r
.46805 .41482 m
.46805 .41476 L
s
.46805 .41476 m
.46807 .41477 L
s
.46804 .41477 m
.46805 .41476 L
s
.46805 .41476 m
.46805 .41476 L
s
.46805 .41478 m
.46804 .41477 L
s
.46804 .41477 m
.46805 .41476 L
s
.46807 .41477 m
.46805 .41478 L
s
.46805 .41476 m
.46807 .41477 L
s
.46805 .41476 m
.46805 .41478 L
s
1 .082 0 r
.32322 .54374 m
.32237 .54422 L
s
.32291 .54286 m
.32322 .54374 L
s
1 .101 0 r
.30323 .64693 m
.30834 .64403 L
s
1 .003 0 r
.77307 .62104 m
.77312 .62094 L
s
1 .008 0 r
.26008 .36303 m
.25977 .36266 L
s
1 .003 0 r
.77311 .62093 m
.77313 .62096 L
s
.77308 .62095 m
.77311 .62093 L
s
.77311 .62093 m
.77312 .62094 L
s
.77313 .62096 m
.77311 .62098 L
s
.77312 .62094 m
.77313 .62096 L
s
.77311 .62098 m
.77308 .62095 L
s
.77308 .62095 m
.77312 .62094 L
s
1 0 0 r
.72994 .33713 m
.72994 .33713 L
s
.72994 .33713 m
.72994 .33713 L
s
.72994 .33713 m
.72994 .33713 L
s
.72994 .33713 m
.72994 .33713 L
s
.72994 .33713 m
.72994 .33713 L
s
.72994 .33713 m
.72994 .33713 L
s
.72994 .33713 m
.72994 .33713 L
s
.72994 .33713 m
.72994 .33713 L
s
.72994 .33713 m
.72994 .33713 L
s
1 .003 0 r
.77312 .62094 m
.77311 .62098 L
s
1 .026 0 r
.41456 .54319 m
.41482 .54346 L
s
.41429 .54337 m
.41456 .54319 L
s
.41456 .54319 m
.41465 .5432 L
s
1 .007 0 r
.5651 .56926 m
.56522 .56896 L
s
1 .026 0 r
.41482 .54346 m
.41455 .54363 L
s
.41465 .5432 m
.41482 .54346 L
s
1 .008 0 r
.25984 .36267 m
.25991 .36271 L
s
.25975 .36276 m
.25984 .36267 L
s
.25984 .36267 m
.25977 .36266 L
s
.25983 .36281 m
.25975 .36276 L
s
.25975 .36276 m
.25977 .36266 L
s
1 .026 0 r
.41455 .54363 m
.41429 .54337 L
s
.41429 .54337 m
.41465 .5432 L
s
1 .008 0 r
.25991 .36271 m
.25983 .36281 L
s
.25977 .36266 m
.25991 .36271 L
s
.25977 .36266 m
.25983 .36281 L
s
1 .022 0 r
.51176 .69785 m
.51197 .69811 L
s
.51154 .69799 m
.51176 .69785 L
s
.51176 .69785 m
.5119 .69789 L
s
1 .026 0 r
.41465 .5432 m
.41455 .54363 L
s
1 .063 0 r
.36257 .67147 m
.3631 .67227 L
s
.362 .67181 m
.36257 .67147 L
s
.36257 .67147 m
.36311 .67164 L
s
1 .045 0 r
.3571 .51747 m
.3579 .51557 L
s
1 .022 0 r
.51197 .69811 m
.51176 .69825 L
s
.5119 .69789 m
.51197 .69811 L
s
1 .082 0 r
.32237 .54422 m
.3216 .54327 L
s
.3216 .54327 m
.32291 .54286 L
s
1 .007 0 r
.5652 .56896 m
.56527 .56903 L
s
.56512 .56901 m
.5652 .56896 L
s
.5652 .56896 m
.56522 .56896 L
s
1 .063 0 r
.3631 .67227 m
.36253 .67261 L
s
.36311 .67164 m
.3631 .67227 L
s
1 .007 0 r
.56527 .56903 m
.5652 .56909 L
s
.56522 .56896 m
.56527 .56903 L
s
.5652 .56909 m
.56512 .56901 L
s
.56512 .56901 m
.56522 .56896 L
s
1 0 0 r
.82705 .49158 m
.82705 .49156 L
s
1 .007 0 r
.56522 .56896 m
.5652 .56909 L
s
1 0 0 r
.82705 .49156 m
.82706 .49156 L
s
.82705 .49156 m
.82705 .49156 L
s
.82705 .49156 m
.82705 .49156 L
s
.82706 .49156 m
.82705 .49157 L
s
.82705 .49156 m
.82706 .49156 L
s
.82705 .49157 m
.82705 .49156 L
s
.82705 .49156 m
.82705 .49156 L
s
.82705 .49156 m
.82705 .49157 L
s
1 .022 0 r
.51176 .69825 m
.51154 .69799 L
s
.51154 .69799 m
.5119 .69789 L
s
1 .082 0 r
.32291 .54286 m
.32237 .54422 L
s
1 .022 0 r
.5119 .69789 m
.51176 .69825 L
s
1 .248 0 r
.24729 .43649 m
.24974 .43906 L
s
.24452 .43813 m
.24729 .43649 L
s
.24729 .43649 m
.2479 .43641 L
s
1 .001 0 r
.61904 .43977 m
.61905 .43975 L
s
.61905 .43975 m
.61905 .43975 L
s
.61904 .43975 m
.61905 .43975 L
s
.61905 .43975 m
.61905 .43975 L
s
.61905 .43975 m
.61905 .43976 L
s
.61905 .43975 m
.61905 .43975 L
s
.61905 .43976 m
.61904 .43975 L
s
.61904 .43975 m
.61905 .43975 L
s
.61905 .43975 m
.61905 .43976 L
s
1 .031 0 r
.45416 .67197 m
.4552 .67083 L
s
1 .001 0 r
.92419 .64608 m
.92422 .64602 L
s
.411 .38796 m
.41099 .38791 L
s
.41099 .38791 m
.411 .38792 L
s
.41098 .38792 m
.41099 .38791 L
s
.41099 .38791 m
.41099 .38791 L
s
.92421 .64602 m
.92423 .64603 L
s
.9242 .64603 m
.92421 .64602 L
s
.92421 .64602 m
.92422 .64602 L
s
.41099 .38793 m
.41098 .38792 L
s
.41098 .38792 m
.41099 .38791 L
s
.92423 .64603 m
.92422 .64604 L
s
.92422 .64602 m
.92423 .64603 L
s
.411 .38792 m
.41099 .38793 L
s
.41099 .38791 m
.411 .38792 L
s
.92422 .64604 m
.9242 .64603 L
s
.9242 .64603 m
.92422 .64602 L
s
.41099 .38791 m
.41099 .38793 L
s
.92422 .64602 m
.92422 .64604 L
s
1 .063 0 r
.36253 .67261 m
.362 .67181 L
s
.362 .67181 m
.36311 .67164 L
s
1 .167 0 r
.24609 .62018 m
.25633 .61655 L
s
1 .063 0 r
.36311 .67164 m
.36253 .67261 L
s
1 .003 0 r
.71616 .59428 m
.71621 .59415 L
s
.7162 .59415 m
.71623 .59418 L
s
.71617 .59418 m
.7162 .59415 L
s
.7162 .59415 m
.71621 .59415 L
s
.71623 .59418 m
.7162 .59421 L
s
.71621 .59415 m
.71623 .59418 L
s
.7162 .59421 m
.71617 .59418 L
s
.71617 .59418 m
.71621 .59415 L
s
.71621 .59415 m
.7162 .59421 L
s
1 .009 0 r
.50809 .54247 m
.50822 .54207 L
s
1 .248 0 r
.24974 .43906 m
.24697 .4407 L
s
.2479 .43641 m
.24974 .43906 L
s
1 .096 0 r
.29998 .49066 m
.30159 .4865 L
s
1 0 0 r
.77015 .46474 m
.77016 .46473 L
s
1 .009 0 r
.5082 .54207 m
.5083 .54216 L
s
.5081 .54214 m
.5082 .54207 L
s
.5082 .54207 m
.50822 .54207 L
s
1 0 0 r
.77015 .46473 m
.77016 .46473 L
s
.77015 .46473 m
.77015 .46473 L
s
.77015 .46473 m
.77016 .46473 L
s
.77016 .46473 m
.77015 .46473 L
s
.77016 .46473 m
.77016 .46473 L
s
.77015 .46473 m
.77015 .46473 L
s
.77015 .46473 m
.77016 .46473 L
s
.77016 .46473 m
.77015 .46473 L
s
1 .009 0 r
.5083 .54216 m
.5082 .54223 L
s
.50822 .54207 m
.5083 .54216 L
s
.5082 .54223 m
.5081 .54214 L
s
.5081 .54214 m
.50822 .54207 L
s
1 .012 0 r
.60521 .69703 m
.60554 .69658 L
s
1 .009 0 r
.50822 .54207 m
.5082 .54223 L
s
1 .031 0 r
.455 .67078 m
.45529 .67114 L
s
.45469 .67097 m
.455 .67078 L
s
.455 .67078 m
.4552 .67083 L
s
.45529 .67114 m
.45499 .67134 L
s
.4552 .67083 m
.45529 .67114 L
s
1 0 0 r
.56204 .41291 m
.56204 .41289 L
s
.56204 .41289 m
.56205 .4129 L
s
.56204 .4129 m
.56204 .41289 L
s
.56204 .41289 m
.56204 .41289 L
s
.56204 .4129 m
.56204 .4129 L
s
.56204 .4129 m
.56204 .41289 L
s
.56205 .4129 m
.56204 .4129 L
s
.56204 .41289 m
.56205 .4129 L
s
.56204 .41289 m
.56204 .4129 L
s
1 .045 0 r
.35776 .51557 m
.35821 .51604 L
s
.35727 .51587 m
.35776 .51557 L
s
.35776 .51557 m
.3579 .51557 L
s
1 .047 0 r
.39707 .64522 m
.39874 .64352 L
s
1 .257 0 r
.239 .5453 m
.2375 .5417 L
s
.24226 .54186 m
.239 .5453 L
s
.2375 .5417 m
.24226 .54186 L
s
1 .031 0 r
.45499 .67134 m
.45469 .67097 L
s
.45469 .67097 m
.4552 .67083 L
s
1 .045 0 r
.35821 .51604 m
.35772 .51634 L
s
.3579 .51557 m
.35821 .51604 L
s
1 .002 0 r
.86733 .61931 m
.86736 .61925 L
s
1 .001 0 r
.3539 .36108 m
.35388 .36105 L
s
.35389 .36105 m
.35389 .36105 L
s
.35388 .36106 m
.35389 .36105 L
s
.35389 .36105 m
.35388 .36105 L
s
.35389 .36106 m
.35388 .36106 L
s
.35388 .36106 m
.35388 .36105 L
s
.35389 .36105 m
.35389 .36106 L
s
.35388 .36105 m
.35389 .36105 L
s
.35388 .36105 m
.35389 .36106 L
s
1 .031 0 r
.4552 .67083 m
.45499 .67134 L
s
1 .002 0 r
.86735 .61925 m
.86737 .61926 L
s
.86734 .61926 m
.86735 .61925 L
s
.86735 .61925 m
.86736 .61925 L
s
.86737 .61926 m
.86735 .61928 L
s
.86736 .61925 m
.86737 .61926 L
s
.86735 .61928 m
.86734 .61926 L
s
.86734 .61926 m
.86736 .61925 L
s
.86736 .61925 m
.86735 .61928 L
s
1 .012 0 r
.60547 .69656 m
.60559 .69669 L
s
.60535 .69665 m
.60547 .69656 L
s
.60547 .69656 m
.60554 .69658 L
s
1 .101 0 r
.30737 .64371 m
.30811 .64504 L
s
.30652 .64418 m
.30737 .64371 L
s
.30737 .64371 m
.30834 .64403 L
s
1 .012 0 r
.60559 .69669 m
.60547 .69678 L
s
.60554 .69658 m
.60559 .69669 L
s
1 .101 0 r
.30811 .64504 m
.30727 .64551 L
s
.30834 .64403 m
.30811 .64504 L
s
1 0 0 r
.82417 .33515 m
.82417 .33515 L
s
.82417 .33515 m
.82417 .33515 L
s
.82417 .33515 m
.82417 .33515 L
s
.82417 .33515 m
.82417 .33515 L
s
.82417 .33515 m
.82417 .33515 L
s
.82417 .33515 m
.82417 .33515 L
s
.82417 .33515 m
.82417 .33515 L
s
.82417 .33515 m
.82417 .33515 L
s
.82417 .33515 m
.82417 .33515 L
s
1 .045 0 r
.35772 .51634 m
.35727 .51587 L
s
.35727 .51587 m
.3579 .51557 L
s
1 .012 0 r
.60547 .69678 m
.60535 .69665 L
s
.60535 .69665 m
.60554 .69658 L
s
.60554 .69658 m
.60547 .69678 L
s
1 .003 0 r
.65919 .56749 m
.65924 .56734 L
s
1 .045 0 r
.3579 .51557 m
.35772 .51634 L
s
1 .003 0 r
.65923 .56734 m
.65927 .56738 L
s
.6592 .56737 m
.65923 .56734 L
s
.65923 .56734 m
.65924 .56734 L
s
.65927 .56738 m
.65923 .5674 L
s
.65924 .56734 m
.65927 .56738 L
s
.65923 .5674 m
.6592 .56737 L
s
.6592 .56737 m
.65924 .56734 L
s
.65924 .56734 m
.65923 .5674 L
s
1 .013 0 r
.45102 .51565 m
.45118 .51508 L
s
1 .248 0 r
.24697 .4407 m
.24452 .43813 L
s
.24452 .43813 m
.2479 .43641 L
s
1 .303 0 r
.24281 .46381 m
.24754 .45053 L
s
1 0 0 r
.7132 .43789 m
.7132 .43787 L
s
.7132 .43787 m
.7132 .43788 L
s
.7132 .43788 m
.7132 .43787 L
s
.7132 .43787 m
.7132 .43787 L
s
.7132 .43788 m
.7132 .43788 L
s
.7132 .43787 m
.7132 .43788 L
s
.7132 .43788 m
.7132 .43788 L
s
.7132 .43788 m
.7132 .43787 L
s
.7132 .43787 m
.7132 .43788 L
s
1 .016 0 r
.54817 .67029 m
.5486 .66968 L
s
1 .013 0 r
.45115 .51508 m
.45128 .51521 L
s
.451 .51518 m
.45115 .51508 L
s
.45115 .51508 m
.45118 .51508 L
s
.45128 .51521 m
.45114 .51531 L
s
.45118 .51508 m
.45128 .51521 L
s
1 0 0 r
.50499 .38603 m
.50498 .38602 L
s
.50498 .38602 m
.50499 .38602 L
s
.50498 .38602 m
.50498 .38602 L
s
.50498 .38602 m
.50498 .38602 L
s
.50498 .38602 m
.50498 .38602 L
s
.50498 .38602 m
.50498 .38602 L
s
.50499 .38602 m
.50498 .38602 L
s
.50498 .38602 m
.50499 .38602 L
s
.50498 .38602 m
.50498 .38602 L
s
1 .013 0 r
.45114 .51531 m
.451 .51518 L
s
.451 .51518 m
.45118 .51508 L
s
.45118 .51508 m
.45114 .51531 L
s
1 .077 0 r
.33994 .61845 m
.34293 .61576 L
s
1 .002 0 r
.81041 .59252 m
.81044 .59245 L
s
1 0 0 r
.29673 .33416 m
.29673 .33416 L
s
.29673 .33416 m
.29673 .33416 L
s
.29673 .33416 m
.29673 .33416 L
s
.29673 .33416 m
.29673 .33416 L
s
.29673 .33416 m
.29673 .33416 L
s
.29673 .33416 m
.29673 .33416 L
s
.29673 .33416 m
.29673 .33416 L
s
.29673 .33416 m
.29673 .33416 L
s
.29673 .33416 m
.29673 .33416 L
s
1 .101 0 r
.30727 .64551 m
.30652 .64418 L
s
.30652 .64418 m
.30834 .64403 L
s
.30834 .64403 m
.30727 .64551 L
s
1 .002 0 r
.81044 .59245 m
.81045 .59247 L
s
.81042 .59247 m
.81044 .59245 L
s
.81044 .59245 m
.81044 .59245 L
s
.81045 .59247 m
.81044 .59248 L
s
.81044 .59245 m
.81045 .59247 L
s
.81044 .59248 m
.81042 .59247 L
s
.81042 .59247 m
.81044 .59245 L
s
.81044 .59245 m
.81044 .59248 L
s
1 .248 0 r
.2479 .43641 m
.24697 .4407 L
s
1 .047 0 r
.39842 .64344 m
.39885 .644 L
s
.39796 .64372 m
.39842 .64344 L
s
.39842 .64344 m
.39874 .64352 L
s
1 .016 0 r
.54852 .66966 m
.54867 .66983 L
s
.54836 .66977 m
.54852 .66966 L
s
.54852 .66966 m
.5486 .66968 L
s
1 .004 0 r
.60217 .54067 m
.60222 .5405 L
s
1 .047 0 r
.39885 .644 m
.39839 .64428 L
s
.39874 .64352 m
.39885 .644 L
s
1 .016 0 r
.54867 .66983 m
.54852 .66994 L
s
.5486 .66968 m
.54867 .66983 L
s
1 .167 0 r
.25532 .61814 m
.25418 .61876 L
s
.25438 .61579 m
.25532 .61814 L
s
.25633 .61655 m
.25532 .61814 L
s
1 .016 0 r
.54852 .66994 m
.54836 .66977 L
s
.54836 .66977 m
.5486 .66968 L
s
1 .004 0 r
.60221 .5405 m
.60226 .54054 L
s
.60217 .54053 m
.60221 .5405 L
s
.60221 .5405 m
.60222 .5405 L
s
1 .016 0 r
.5486 .66968 m
.54852 .66994 L
s
1 .004 0 r
.60226 .54054 m
.60221 .54057 L
s
.60222 .5405 m
.60226 .54054 L
s
.60221 .54057 m
.60217 .54053 L
s
.60217 .54053 m
.60222 .5405 L
s
.60222 .5405 m
.60221 .54057 L
s
1 .167 0 r
.25323 .61641 m
.25438 .61579 L
s
.25438 .61579 m
.25633 .61655 L
s
1 .021 0 r
.39389 .48881 m
.39407 .48789 L
s
1 .187 0 r
.26895 .51215 m
.27059 .51442 L
s
.26708 .51312 m
.26895 .51215 L
s
.26895 .51215 m
.27021 .51239 L
s
1 0 0 r
.86448 .46288 m
.86448 .46287 L
s
.86448 .46287 m
.86448 .46287 L
s
.86448 .46287 m
.86448 .46287 L
s
.86448 .46287 m
.86448 .46287 L
s
.86448 .46287 m
.86448 .46287 L
s
.86448 .46287 m
.86448 .46287 L
s
.86448 .46287 m
.86448 .46287 L
s
.86448 .46287 m
.86448 .46287 L
s
.86448 .46287 m
.86448 .46287 L
s
1 .047 0 r
.39839 .64428 m
.39796 .64372 L
s
.39796 .64372 m
.39874 .64352 L
s
1 .007 0 r
.69939 .69537 m
.69956 .6951 L
s
0 .088 1 r
.18558 .43694 m
.24673 .24921 L
s
1 .047 0 r
.39874 .64352 m
.39839 .64428 L
s
1 .187 0 r
.27059 .51442 m
.26873 .51539 L
s
.27021 .51239 m
.27059 .51442 L
s
1 0 0 r
.65619 .411 m
.65619 .41099 L
s
.65619 .41099 m
.6562 .41099 L
s
.65619 .41099 m
.65619 .41099 L
s
.65619 .41099 m
.65619 .41099 L
s
.65619 .411 m
.65619 .41099 L
s
.65619 .41099 m
.65619 .41099 L
s
.6562 .41099 m
.65619 .411 L
s
.65619 .41099 m
.6562 .41099 L
s
.65619 .41099 m
.65619 .411 L
s
1 .022 0 r
.49109 .64351 m
.49168 .64266 L
s
1 .007 0 r
.69952 .6951 m
.69959 .69517 L
s
.69946 .69515 m
.69952 .6951 L
s
.69952 .6951 m
.69956 .6951 L
s
.69959 .69517 m
.69953 .69522 L
s
.69956 .6951 m
.69959 .69517 L
s
.69953 .69522 m
.69946 .69515 L
s
.69946 .69515 m
.69956 .6951 L
s
.69956 .6951 m
.69953 .69522 L
s
1 0 0 r
.44787 .35912 m
.44787 .35911 L
s
.44787 .35911 m
.44787 .35911 L
s
.44787 .35911 m
.44787 .35911 L
s
.44787 .35911 m
.44787 .35911 L
s
.44787 .35912 m
.44787 .35911 L
s
.44787 .35911 m
.44787 .35911 L
s
.44787 .35911 m
.44787 .35912 L
s
.44787 .35911 m
.44787 .35911 L
s
.44787 .35911 m
.44787 .35912 L
s
1 .139 0 r
.28274 .59165 m
.28913 .5872 L
s
1 .021 0 r
.39404 .4879 m
.39426 .4881 L
s
.39381 .48806 m
.39404 .4879 L
s
.39404 .4879 m
.39407 .48789 L
s
1 .002 0 r
.75344 .56571 m
.75347 .56563 L
s
.75346 .56563 m
.75348 .56565 L
s
.75345 .56565 m
.75346 .56563 L
s
.75346 .56563 m
.75347 .56563 L
s
.75348 .56565 m
.75347 .56566 L
s
.75347 .56563 m
.75348 .56565 L
s
.75347 .56566 m
.75345 .56565 L
s
.75345 .56565 m
.75347 .56563 L
s
1 .021 0 r
.39426 .4881 m
.39403 .48825 L
s
.39407 .48789 m
.39426 .4881 L
s
1 .529 0 r
.23146 .46929 m
.22812 .46197 L
s
.2379 .46197 m
.23146 .46929 L
s
1 .002 0 r
.75347 .56563 m
.75347 .56566 L
s
1 .021 0 r
.39403 .48825 m
.39381 .48806 L
s
.39381 .48806 m
.39407 .48789 L
s
1 .238 0 r
.21731 .38149 m
.21944 .3829 L
s
.21485 .38407 m
.21731 .38149 L
s
.21731 .38149 m
.21554 .38139 L
s
1 .005 0 r
.5451 .51383 m
.54515 .51361 L
s
1 .021 0 r
.39407 .48789 m
.39403 .48825 L
s
1 .005 0 r
.54514 .51361 m
.54519 .51366 L
s
.54508 .51365 m
.54514 .51361 L
s
.54514 .51361 m
.54515 .51361 L
s
1 .529 0 r
.22812 .46197 m
.2379 .46197 L
s
1 .022 0 r
.49156 .64264 m
.49178 .64288 L
s
.49134 .64278 m
.49156 .64264 L
s
.49156 .64264 m
.49168 .64266 L
s
1 .005 0 r
.54519 .51366 m
.54514 .5137 L
s
.54515 .51361 m
.54519 .51366 L
s
.54514 .5137 m
.54508 .51365 L
s
.54508 .51365 m
.54515 .51361 L
s
1 .038 0 r
.33671 .46194 m
.33685 .46022 L
s
1 .096 0 r
.30132 .4865 m
.30228 .48751 L
s
.30026 .48716 m
.30132 .4865 L
s
.30132 .4865 m
.30159 .4865 L
s
1 .005 0 r
.54515 .51361 m
.54514 .5137 L
s
1 .022 0 r
.49178 .64288 m
.49156 .64303 L
s
.49168 .64266 m
.49178 .64288 L
s
1 0 0 r
.80752 .43599 m
.80752 .43599 L
s
.80752 .43599 m
.80752 .43599 L
s
.80752 .43599 m
.80752 .43599 L
s
.80752 .43599 m
.80752 .43599 L
s
.80752 .43599 m
.80752 .43599 L
s
.80752 .43599 m
.80752 .43599 L
s
.80752 .43599 m
.80752 .43599 L
s
.80752 .43599 m
.80752 .43599 L
s
.80752 .43599 m
.80752 .43599 L
s
1 .022 0 r
.49156 .64303 m
.49134 .64278 L
s
.49134 .64278 m
.49168 .64266 L
s
1 .008 0 r
.64235 .6686 m
.64255 .66826 L
s
1 .022 0 r
.49168 .64266 m
.49156 .64303 L
s
1 0 0 r
.59913 .38409 m
.59913 .38409 L
s
.59913 .38409 m
.59913 .38409 L
s
.59913 .38409 m
.59913 .38409 L
s
.59913 .38409 m
.59913 .38409 L
s
.59913 .38409 m
.59913 .38409 L
s
.59913 .38409 m
.59913 .38409 L
s
.59913 .38409 m
.59913 .38409 L
s
.59913 .38409 m
.59913 .38409 L
s
.59913 .38409 m
.59913 .38409 L
s
1 .096 0 r
.30228 .48751 m
.30122 .48816 L
s
.30159 .4865 m
.30228 .48751 L
s
1 .238 0 r
.21698 .38547 m
.21485 .38407 L
s
.21485 .38407 m
.21554 .38139 L
s
1 .032 0 r
.43394 .61671 m
.43482 .61545 L
s
1 .008 0 r
.64251 .66825 m
.6426 .66834 L
s
.64243 .66832 m
.64251 .66825 L
s
.64251 .66825 m
.64255 .66826 L
s
1 .077 0 r
.34237 .61561 m
.34304 .61656 L
s
.34162 .61603 m
.34237 .61561 L
s
.34237 .61561 m
.34293 .61576 L
s
1 .008 0 r
.6426 .66834 m
.64251 .66841 L
s
.64255 .66826 m
.6426 .66834 L
s
1 .001 0 r
.90483 .59077 m
.90485 .59072 L
s
1 0 0 r
.39071 .33218 m
.39071 .33218 L
s
.39071 .33218 m
.39071 .33218 L
s
.39071 .33218 m
.39071 .33218 L
s
.39071 .33218 m
.39071 .33218 L
s
.39071 .33218 m
.39071 .33218 L
s
.39071 .33218 m
.39071 .33218 L
s
.39071 .33218 m
.39071 .33218 L
s
.39071 .33218 m
.39071 .33218 L
s
.39071 .33218 m
.39071 .33218 L
s
1 .008 0 r
.64251 .66841 m
.64243 .66832 L
s
.64243 .66832 m
.64255 .66826 L
s
1 .001 0 r
.90485 .59072 m
.90486 .59073 L
s
.90484 .59073 m
.90485 .59072 L
s
.90485 .59072 m
.90485 .59072 L
s
.90486 .59073 m
.90485 .59074 L
s
.90485 .59072 m
.90486 .59073 L
s
.90485 .59074 m
.90484 .59073 L
s
.90484 .59073 m
.90485 .59072 L
s
.90485 .59072 m
.90485 .59074 L
s
1 .008 0 r
.64255 .66826 m
.64251 .66841 L
s
1 .077 0 r
.34304 .61656 m
.3423 .61698 L
s
.34293 .61576 m
.34304 .61656 L
s
1 .187 0 r
.26873 .51539 m
.26708 .51312 L
s
.26708 .51312 m
.27021 .51239 L
s
1 .167 0 r
.25633 .61655 m
.25418 .61876 L
s
.25323 .61641 m
.25633 .61655 L
s
1 .275 0 r
.2255 .56482 m
.24209 .55844 L
s
1 .167 0 r
.25418 .61876 m
.25323 .61641 L
s
1 .096 0 r
.30122 .48816 m
.30026 .48716 L
s
.30026 .48716 m
.30159 .4865 L
s
1 .002 0 r
.69642 .53887 m
.69644 .53878 L
s
.69644 .53878 m
.69646 .5388 L
s
.69642 .5388 m
.69644 .53878 L
s
.69644 .53878 m
.69644 .53878 L
s
.69646 .5388 m
.69644 .53882 L
s
.69644 .53878 m
.69646 .5388 L
s
.69644 .53882 m
.69642 .5388 L
s
.69642 .5388 m
.69644 .53878 L
s
.69644 .53878 m
.69644 .53882 L
s
1 .187 0 r
.27021 .51239 m
.26873 .51539 L
s
1 .006 0 r
.48797 .48696 m
.48801 .48668 L
s
1 .096 0 r
.30159 .4865 m
.30122 .48816 L
s
1 .004 0 r
.79374 .6937 m
.79383 .69354 L
s
1 .093 0 r
.27948 .43505 m
.27893 .43074 L
s
1 .006 0 r
.488 .48669 m
.48807 .48674 L
s
.48793 .48674 m
.488 .48669 L
s
.488 .48669 m
.48801 .48668 L
s
.48807 .48674 m
.488 .48679 L
s
.48801 .48668 m
.48807 .48674 L
s
.488 .48679 m
.48793 .48674 L
s
.48793 .48674 m
.48801 .48668 L
s
.48801 .48668 m
.488 .48679 L
s
1 .077 0 r
.3423 .61698 m
.34162 .61603 L
s
.34162 .61603 m
.34293 .61576 L
s
1 0 0 r
.75051 .40909 m
.75051 .40908 L
s
.75051 .40908 m
.75051 .40908 L
s
.75051 .40908 m
.75051 .40908 L
s
.75051 .40908 m
.75051 .40908 L
s
.75051 .40908 m
.75051 .40908 L
s
.75051 .40908 m
.75051 .40908 L
s
.75051 .40908 m
.75051 .40908 L
s
.75051 .40908 m
.75051 .40908 L
s
.75051 .40908 m
.75051 .40908 L
s
1 .004 0 r
.79381 .69354 m
.79386 .69358 L
s
.79377 .69357 m
.79381 .69354 L
s
.79381 .69354 m
.79383 .69354 L
s
.79386 .69358 m
.79382 .69361 L
s
.79383 .69354 m
.79386 .69358 L
s
.79382 .69361 m
.79377 .69357 L
s
.79377 .69357 m
.79383 .69354 L
s
.79383 .69354 m
.79382 .69361 L
s
1 .077 0 r
.34293 .61576 m
.3423 .61698 L
s
1 .038 0 r
.33684 .46024 m
.33723 .46059 L
s
.33641 .46054 m
.33684 .46024 L
s
.33684 .46024 m
.33685 .46022 L
s
1 .011 0 r
.58526 .6418 m
.5855 .64137 L
s
1 .032 0 r
.43465 .61541 m
.43497 .61578 L
s
.43432 .61563 m
.43465 .61541 L
s
.43465 .61541 m
.43482 .61545 L
s
1 0 0 r
.54202 .35716 m
.54202 .35716 L
s
.54202 .35716 m
.54202 .35716 L
s
.54202 .35716 m
.54202 .35716 L
s
.54202 .35716 m
.54202 .35716 L
s
.54202 .35716 m
.54202 .35716 L
s
.54202 .35716 m
.54202 .35716 L
s
.54202 .35716 m
.54202 .35716 L
s
.54202 .35716 m
.54202 .35716 L
s
.54202 .35716 m
.54202 .35716 L
s
1 .038 0 r
.33723 .46059 m
.33681 .46089 L
s
.33685 .46022 m
.33723 .46059 L
s
1 .032 0 r
.43497 .61578 m
.43464 .61599 L
s
.43482 .61545 m
.43497 .61578 L
s
1 .052 0 r
.37675 .58989 m
.37821 .58784 L
s
1 .038 0 r
.33681 .46089 m
.33641 .46054 L
s
.33641 .46054 m
.33685 .46022 L
s
1 .238 0 r
.21944 .3829 m
.21698 .38547 L
s
.21554 .38139 m
.21944 .3829 L
s
1 .001 0 r
.84786 .56393 m
.84788 .56388 L
s
.84787 .56388 m
.84788 .56389 L
s
.84786 .56389 m
.84787 .56388 L
s
.84787 .56388 m
.84788 .56388 L
s
.84788 .56389 m
.84787 .5639 L
s
.84788 .56388 m
.84788 .56389 L
s
.84787 .5639 m
.84786 .56389 L
s
.84786 .56389 m
.84788 .56388 L
s
1 .011 0 r
.58545 .64136 m
.58557 .64147 L
s
.58535 .64143 m
.58545 .64136 L
s
.58545 .64136 m
.5855 .64137 L
s
1 .001 0 r
.84788 .56388 m
.84787 .5639 L
s
1 .032 0 r
.43464 .61599 m
.43432 .61563 L
s
.43432 .61563 m
.43482 .61545 L
s
1 .038 0 r
.33685 .46022 m
.33681 .46089 L
s
1 .011 0 r
.58557 .64147 m
.58546 .64155 L
s
.5855 .64137 m
.58557 .64147 L
s
.58546 .64155 m
.58535 .64143 L
s
.58535 .64143 m
.5855 .64137 L
s
1 .032 0 r
.43482 .61545 m
.43464 .61599 L
s
1 .011 0 r
.5855 .64137 m
.58546 .64155 L
s
1 .002 0 r
.63934 .512 m
.63936 .51191 L
s
.63936 .51191 m
.63938 .51193 L
s
.63933 .51193 m
.63936 .51191 L
s
.63936 .51191 m
.63936 .51191 L
s
.63938 .51193 m
.63936 .51195 L
s
.63936 .51191 m
.63938 .51193 L
s
.63936 .51195 m
.63933 .51193 L
s
.63933 .51193 m
.63936 .51191 L
s
.63936 .51191 m
.63936 .51195 L
s
1 .008 0 r
.43079 .46007 m
.4308 .45969 L
s
1 .123 0 r
.26547 .69286 m
.27311 .69033 L
s
1 .238 0 r
.21554 .38139 m
.21698 .38547 L
s
1 .005 0 r
.7367 .6669 m
.7368 .66671 L
s
1 .375 0 r
.22219 .40813 m
.2095 .39167 L
s
1 .008 0 r
.4308 .4597 m
.43089 .45977 L
s
.43071 .45976 m
.4308 .4597 L
s
.4308 .4597 m
.4308 .45969 L
s
1 0 0 r
.69344 .38215 m
.69344 .38215 L
s
.69344 .38215 m
.69344 .38215 L
s
.69344 .38215 m
.69344 .38215 L
s
.69344 .38215 m
.69344 .38215 L
s
.69344 .38215 m
.69344 .38215 L
s
.69344 .38215 m
.69344 .38215 L
s
.69344 .38215 m
.69344 .38215 L
s
.69344 .38215 m
.69344 .38215 L
s
.69344 .38215 m
.69344 .38215 L
s
1 .008 0 r
.43089 .45977 m
.4308 .45984 L
s
.4308 .45969 m
.43089 .45977 L
s
.4308 .45984 m
.43071 .45976 L
s
.43071 .45976 m
.4308 .45969 L
s
1 .005 0 r
.73678 .66671 m
.73683 .66676 L
s
.73673 .66674 m
.73678 .66671 L
s
.73678 .66671 m
.7368 .66671 L
s
.73683 .66676 m
.73678 .66679 L
s
.7368 .66671 m
.73683 .66676 L
s
1 .008 0 r
.4308 .45969 m
.4308 .45984 L
s
1 .005 0 r
.73678 .66679 m
.73673 .66674 L
s
.73673 .66674 m
.7368 .66671 L
s
1 .014 0 r
.52811 .61497 m
.52842 .61439 L
s
1 .005 0 r
.7368 .66671 m
.73678 .66679 L
s
1 0 0 r
.48485 .3302 m
.48485 .3302 L
s
.48485 .3302 m
.48485 .3302 L
s
.48485 .3302 m
.48485 .3302 L
s
.48485 .3302 m
.48485 .3302 L
s
.48485 .3302 m
.48485 .3302 L
s
.48485 .3302 m
.48485 .3302 L
s
.48485 .3302 m
.48485 .3302 L
s
.48485 .3302 m
.48485 .3302 L
s
.48485 .3302 m
.48485 .3302 L
s
1 .095 0 r
.3195 .56304 m
.32241 .55934 L
s
1 .001 0 r
.79083 .53706 m
.79084 .53702 L
s
.79084 .53702 m
.79085 .53703 L
s
.79083 .53703 m
.79084 .53702 L
s
.79084 .53702 m
.79084 .53702 L
s
.79085 .53703 m
.79084 .53704 L
s
.79084 .53702 m
.79085 .53703 L
s
.79084 .53704 m
.79083 .53703 L
s
.79083 .53703 m
.79084 .53702 L
s
.79084 .53702 m
.79084 .53704 L
s
1 .139 0 r
.28792 .58686 m
.28903 .58865 L
s
.28667 .58752 m
.28792 .58686 L
s
.28792 .58686 m
.28913 .5872 L
s
1 .014 0 r
.52836 .61438 m
.52851 .61453 L
s
.52821 .61448 m
.52836 .61438 L
s
.52836 .61438 m
.52842 .61439 L
s
1 .139 0 r
.28903 .58865 m
.28777 .58932 L
s
.28913 .5872 m
.28903 .58865 L
s
1 .002 0 r
.58221 .48511 m
.58222 .485 L
s
1 .014 0 r
.52851 .61453 m
.52836 .61463 L
s
.52842 .61439 m
.52851 .61453 L
s
.52836 .61463 m
.52821 .61448 L
s
.52821 .61448 m
.52842 .61439 L
s
1 .002 0 r
.58222 .48501 m
.58224 .48503 L
s
.58219 .48503 m
.58222 .48501 L
s
.58222 .48501 m
.58222 .485 L
s
.58224 .48503 m
.58222 .48505 L
s
.58222 .485 m
.58224 .48503 L
s
.58222 .48505 m
.58219 .48503 L
s
.58219 .48503 m
.58222 .485 L
s
.58222 .485 m
.58222 .48505 L
s
1 .014 0 r
.52842 .61439 m
.52836 .61463 L
s
1 .052 0 r
.37794 .58779 m
.37844 .58839 L
s
.3774 .58812 m
.37794 .58779 L
s
.37794 .58779 m
.37821 .58784 L
s
1 .003 0 r
.88825 .69203 m
.88831 .69193 L
s
1 .012 0 r
.37355 .43315 m
.37349 .43259 L
s
1 .003 0 r
.8883 .69193 m
.88832 .69195 L
s
.88827 .69195 m
.8883 .69193 L
s
.8883 .69193 m
.88831 .69193 L
s
.88832 .69195 m
.8883 .69197 L
s
.88831 .69193 m
.88832 .69195 L
s
.8883 .69197 m
.88827 .69195 L
s
.88827 .69195 m
.88831 .69193 L
s
.88831 .69193 m
.8883 .69197 L
s
1 .052 0 r
.37844 .58839 m
.3779 .58872 L
s
.37821 .58784 m
.37844 .58839 L
s
1 0 0 r
.84499 .40717 m
.84499 .40717 L
s
.84499 .40717 m
.84499 .40717 L
s
.84499 .40717 m
.84499 .40717 L
s
.84499 .40717 m
.84499 .40717 L
s
.84499 .40717 m
.84499 .40717 L
s
.84499 .40717 m
.84499 .40717 L
s
.84499 .40717 m
.84499 .40717 L
s
.84499 .40717 m
.84499 .40717 L
s
.84499 .40717 m
.84499 .40717 L
s
1 .006 0 r
.6796 .64008 m
.67972 .63985 L
s
1 0 0 r
.63632 .35519 m
.63632 .35519 L
s
.63632 .35519 m
.63632 .35519 L
s
.63632 .35519 m
.63632 .35519 L
s
.63632 .35519 m
.63632 .35519 L
s
.63632 .35519 m
.63632 .35519 L
s
.63632 .35519 m
.63632 .35519 L
s
.63632 .35519 m
.63632 .35519 L
s
.63632 .35519 m
.63632 .35519 L
s
.63632 .35519 m
.63632 .35519 L
s
1 .006 0 r
.67969 .63984 m
.67975 .6399 L
s
.67963 .63989 m
.67969 .63984 L
s
.67969 .63984 m
.67972 .63985 L
s
1 .021 0 r
.47091 .58813 m
.47133 .58728 L
s
1 .006 0 r
.67975 .6399 m
.6797 .63995 L
s
.67972 .63985 m
.67975 .6399 L
s
1 .052 0 r
.3779 .58872 m
.3774 .58812 L
s
.3774 .58812 m
.37821 .58784 L
s
1 .012 0 r
.3735 .4326 m
.37363 .4327 L
s
.37337 .43271 m
.3735 .4326 L
s
.3735 .4326 m
.37349 .43259 L
s
1 .006 0 r
.6797 .63995 m
.67963 .63989 L
s
.67963 .63989 m
.67972 .63985 L
s
.67972 .63985 m
.6797 .63995 L
s
1 .012 0 r
.3735 .43281 m
.37337 .43271 L
s
.37337 .43271 m
.37349 .43259 L
s
.37363 .4327 m
.3735 .43281 L
s
.37349 .43259 m
.37363 .4327 L
s
1 .052 0 r
.37821 .58784 m
.3779 .58872 L
s
1 .012 0 r
.37349 .43259 m
.3735 .43281 L
s
1 .208 0 r
.26219 .53616 m
.26988 .52848 L
s
1 .123 0 r
.27233 .69145 m
.27151 .69195 L
s
.27165 .68972 m
.27233 .69145 L
s
.27311 .69033 m
.27233 .69145 L
s
1 .001 0 r
.73375 .51017 m
.73376 .51013 L
s
.73376 .51013 m
.73377 .51014 L
s
.73375 .51014 m
.73376 .51013 L
s
.73376 .51013 m
.73376 .51013 L
s
.73377 .51014 m
.73376 .51015 L
s
.73376 .51013 m
.73377 .51014 L
s
.73376 .51015 m
.73375 .51014 L
s
.73375 .51014 m
.73376 .51013 L
s
.73376 .51013 m
.73376 .51015 L
s
1 .123 0 r
.27082 .69022 m
.27165 .68972 L
s
.27165 .68972 m
.27311 .69033 L
s
1 .003 0 r
.52502 .4582 m
.52502 .45807 L
s
.52502 .45808 m
.52505 .4581 L
s
.525 .4581 m
.52502 .45808 L
s
.52502 .45808 m
.52502 .45807 L
s
1 .069 0 r
.35956 .69119 m
.36264 .689 L
s
1 .003 0 r
.52505 .4581 m
.52502 .45812 L
s
.52502 .45807 m
.52505 .4581 L
s
.52502 .45812 m
.525 .4581 L
s
.525 .4581 m
.52502 .45807 L
s
.52502 .45807 m
.52502 .45812 L
s
1 .021 0 r
.47125 .58727 m
.47146 .58748 L
s
.47103 .58741 m
.47125 .58727 L
s
.47125 .58727 m
.47133 .58728 L
s
1 .139 0 r
.28777 .58932 m
.28667 .58752 L
s
.28667 .58752 m
.28913 .5872 L
s
1 .003 0 r
.83121 .66521 m
.83127 .66509 L
s
1 .02 0 r
.31625 .40621 m
.31594 .40529 L
s
1 .021 0 r
.47146 .58748 m
.47124 .58763 L
s
.47133 .58728 m
.47146 .58748 L
s
1 .139 0 r
.28913 .5872 m
.28777 .58932 L
s
1 .093 0 r
.2791 .43081 m
.28005 .4316 L
s
.27804 .43161 m
.2791 .43081 L
s
.2791 .43081 m
.27893 .43074 L
s
1 .003 0 r
.83125 .66509 m
.83128 .66512 L
s
.83122 .66511 m
.83125 .66509 L
s
.83125 .66509 m
.83127 .66509 L
s
.83128 .66512 m
.83126 .66514 L
s
.83127 .66509 m
.83128 .66512 L
s
1 0 0 r
.78792 .38021 m
.78792 .38021 L
s
.78792 .38021 m
.78792 .38021 L
s
.78792 .38021 m
.78792 .38021 L
s
.78792 .38021 m
.78792 .38021 L
s
.78792 .38021 m
.78792 .38021 L
s
.78792 .38021 m
.78792 .38021 L
s
.78792 .38021 m
.78792 .38021 L
s
.78792 .38021 m
.78792 .38021 L
s
1 .003 0 r
.83126 .66514 m
.83122 .66511 L
s
.83122 .66511 m
.83127 .66509 L
s
1 0 0 r
.78792 .38021 m
.78792 .38021 L
s
1 .021 0 r
.47124 .58763 m
.47103 .58741 L
s
.47103 .58741 m
.47133 .58728 L
s
1 .003 0 r
.83127 .66509 m
.83126 .66514 L
s
1 .021 0 r
.47133 .58728 m
.47124 .58763 L
s
1 .007 0 r
.62245 .61323 m
.62258 .61294 L
s
1 0 0 r
.57915 .32821 m
.57915 .32821 L
s
.57915 .32821 m
.57915 .32821 L
s
.57915 .32821 m
.57915 .32821 L
s
.57915 .32821 m
.57915 .32821 L
s
.57915 .32821 m
.57915 .32821 L
s
.57915 .32821 m
.57915 .32821 L
s
.57915 .32821 m
.57915 .32821 L
s
.57915 .32821 m
.57915 .32821 L
s
.57915 .32821 m
.57915 .32821 L
s
1 .569 0 r
.23635 .48358 m
.23199 .48549 L
s
.23275 .47568 m
.23635 .48358 L
s
.23895 .47758 m
.23635 .48358 L
s
1 .032 0 r
.41366 .56125 m
.41426 .55992 L
s
1 .007 0 r
.62255 .61294 m
.62263 .61301 L
s
.62248 .61299 m
.62255 .61294 L
s
.62255 .61294 m
.62258 .61294 L
s
.62263 .61301 m
.62256 .61306 L
s
.62258 .61294 m
.62263 .61301 L
s
.62256 .61306 m
.62248 .61299 L
s
.62248 .61299 m
.62258 .61294 L
s
1 .275 0 r
.24055 .56117 m
.23859 .56214 L
s
.23894 .5573 m
.24055 .56117 L
s
.24209 .55844 m
.24055 .56117 L
s
1 .001 0 r
.88541 .53526 m
.88542 .53523 L
s
1 .007 0 r
.62258 .61294 m
.62256 .61306 L
s
1 .001 0 r
.88541 .53523 m
.88542 .53523 L
s
.88541 .53523 m
.88541 .53523 L
s
.88541 .53523 m
.88542 .53523 L
s
.88542 .53523 m
.88541 .53524 L
s
.88542 .53523 m
.88542 .53523 L
s
.88541 .53524 m
.88541 .53523 L
s
.88541 .53523 m
.88542 .53523 L
s
.88542 .53523 m
.88541 .53524 L
s
1 .093 0 r
.27899 .43239 m
.27804 .43161 L
s
.27804 .43161 m
.27893 .43074 L
s
.28005 .4316 m
.27899 .43239 L
s
.27893 .43074 m
.28005 .4316 L
s
1 .596 0 r
.20483 .50926 m
.23926 .49368 L
s
1 .02 0 r
.31601 .4053 m
.31621 .40545 L
s
.3158 .40549 m
.31601 .4053 L
s
.31601 .4053 m
.31594 .40529 L
s
1 .569 0 r
.22838 .47758 m
.23275 .47568 L
s
.23275 .47568 m
.23895 .47758 L
s
1 .001 0 r
.67661 .48326 m
.67662 .48321 L
s
1 .275 0 r
.23698 .55827 m
.23894 .5573 L
s
.23894 .5573 m
.24209 .55844 L
s
1 .001 0 r
.67662 .48321 m
.67663 .48322 L
s
.6766 .48322 m
.67662 .48321 L
s
.67662 .48321 m
.67662 .48321 L
s
.67663 .48322 m
.67662 .48323 L
s
.67662 .48321 m
.67663 .48322 L
s
.67662 .48323 m
.6766 .48322 L
s
.6766 .48322 m
.67662 .48321 L
s
.67662 .48321 m
.67662 .48323 L
s
1 .02 0 r
.316 .40564 m
.3158 .40549 L
s
.3158 .40549 m
.31594 .40529 L
s
.31621 .40545 m
.316 .40564 L
s
.31594 .40529 m
.31621 .40545 L
s
.31594 .40529 m
.316 .40564 L
s
1 .003 0 r
.46778 .43125 m
.46777 .43112 L
s
1 .123 0 r
.27311 .69033 m
.27151 .69195 L
s
.27082 .69022 m
.27311 .69033 L
s
.27151 .69195 m
.27082 .69022 L
s
1 .108 0 r
.30224 .66436 m
.30777 .66125 L
s
1 .003 0 r
.46777 .43112 m
.4678 .43114 L
s
.46774 .43114 m
.46777 .43112 L
s
.46777 .43112 m
.46777 .43112 L
s
1 .093 0 r
.27893 .43074 m
.27899 .43239 L
s
1 .003 0 r
.46777 .43117 m
.46774 .43114 L
s
.46774 .43114 m
.46777 .43112 L
s
.4678 .43114 m
.46777 .43117 L
s
.46777 .43112 m
.4678 .43114 L
s
.46777 .43112 m
.46777 .43117 L
s
.7741 .63836 m
.77417 .63823 L
s
1 .037 0 r
.25891 .37924 m
.25753 .37762 L
s
1 .003 0 r
.77415 .63823 m
.77419 .63826 L
s
.77412 .63825 m
.77415 .63823 L
s
.77415 .63823 m
.77417 .63823 L
s
1 0 0 r
.73079 .35323 m
.73079 .35323 L
s
.73079 .35323 m
.73079 .35323 L
s
.73079 .35323 m
.73079 .35323 L
s
.73079 .35323 m
.73079 .35323 L
s
.73079 .35323 m
.73079 .35323 L
s
.73079 .35323 m
.73079 .35323 L
s
.73079 .35323 m
.73079 .35323 L
s
.73079 .35323 m
.73079 .35323 L
s
.73079 .35323 m
.73079 .35323 L
s
1 .003 0 r
.77419 .63826 m
.77416 .63829 L
s
.77417 .63823 m
.77419 .63826 L
s
1 .095 0 r
.32187 .55924 m
.32277 .56036 L
s
.32088 .55981 m
.32187 .55924 L
s
.32187 .55924 m
.32241 .55934 L
s
1 .003 0 r
.77416 .63829 m
.77412 .63825 L
s
.77412 .63825 m
.77417 .63823 L
s
.77417 .63823 m
.77416 .63829 L
s
1 .009 0 r
.56524 .58636 m
.56539 .58598 L
s
1 .095 0 r
.32277 .56036 m
.32178 .56092 L
s
.32241 .55934 m
.32277 .56036 L
s
1 .032 0 r
.41415 .55991 m
.41447 .56024 L
s
.41381 .56013 m
.41415 .55991 L
s
.41415 .55991 m
.41426 .55992 L
s
1 .056 0 r
.35635 .53435 m
.35734 .53199 L
s
1 .032 0 r
.41447 .56024 m
.41413 .56047 L
s
.41426 .55992 m
.41447 .56024 L
s
1 .009 0 r
.56536 .58598 m
.56546 .58607 L
s
.56527 .58604 m
.56536 .58598 L
s
.56536 .58598 m
.56539 .58598 L
s
1 .001 0 r
.82832 .50834 m
.82833 .50831 L
s
.82832 .50831 m
.82833 .50832 L
s
.82832 .50832 m
.82832 .50831 L
s
.82832 .50831 m
.82833 .50831 L
s
.82833 .50832 m
.82833 .50833 L
s
.82833 .50831 m
.82833 .50832 L
s
.82833 .50833 m
.82832 .50832 L
s
.82832 .50832 m
.82833 .50831 L
s
.82833 .50831 m
.82833 .50833 L
s
1 .009 0 r
.56546 .58607 m
.56537 .58614 L
s
.56539 .58598 m
.56546 .58607 L
s
1 .069 0 r
.36205 .68881 m
.36262 .68969 L
s
.36142 .68919 m
.36205 .68881 L
s
.36205 .68881 m
.36264 .689 L
s
1 .032 0 r
.41413 .56047 m
.41381 .56013 L
s
.41381 .56013 m
.41426 .55992 L
s
1 .009 0 r
.56537 .58614 m
.56527 .58604 L
s
.56527 .58604 m
.56539 .58598 L
s
1 .069 0 r
.36262 .68969 m
.362 .69007 L
s
.36264 .689 m
.36262 .68969 L
s
1 .009 0 r
.56539 .58598 m
.56537 .58614 L
s
1 .032 0 r
.41426 .55992 m
.41413 .56047 L
s
1 .001 0 r
.61942 .45632 m
.61942 .45627 L
s
.61942 .45627 m
.61943 .45628 L
s
.61941 .45628 m
.61942 .45627 L
s
.61942 .45627 m
.61942 .45627 L
s
.61943 .45628 m
.61942 .45629 L
s
.61942 .45627 m
.61943 .45628 L
s
.61942 .45629 m
.61941 .45628 L
s
.61941 .45628 m
.61942 .45627 L
s
.61942 .45627 m
.61942 .45629 L
s
1 .035 0 r
.45382 .68952 m
.455 .68824 L
s
1 .002 0 r
.92588 .66351 m
.92592 .66344 L
s
1 .003 0 r
.41048 .40428 m
.41045 .40414 L
s
1 .095 0 r
.32178 .56092 m
.32088 .55981 L
s
.32088 .55981 m
.32241 .55934 L
s
1 .002 0 r
.92591 .66344 m
.92593 .66345 L
s
.92589 .66345 m
.92591 .66344 L
s
.92591 .66344 m
.92592 .66344 L
s
.92593 .66345 m
.92591 .66347 L
s
.92592 .66344 m
.92593 .66345 L
s
.92591 .66347 m
.92589 .66345 L
s
.92589 .66345 m
.92592 .66344 L
s
.92592 .66344 m
.92591 .66347 L
s
1 .177 0 r
.24486 .6375 m
.25575 .63367 L
s
1 .003 0 r
.41045 .40414 m
.41049 .40416 L
s
.41042 .40417 m
.41045 .40414 L
s
.41045 .40414 m
.41045 .40414 L
s
.41045 .40419 m
.41042 .40417 L
s
.41042 .40417 m
.41045 .40414 L
s
.41049 .40416 m
.41045 .40419 L
s
.41045 .40414 m
.41049 .40416 L
s
.41045 .40414 m
.41045 .40419 L
s
1 .095 0 r
.32241 .55934 m
.32178 .56092 L
s
1 .004 0 r
.71695 .61149 m
.71701 .61133 L
s
1 .037 0 r
.25783 .37763 m
.25816 .37784 L
s
.25745 .37805 m
.25783 .37763 L
s
.25783 .37763 m
.25753 .37762 L
s
1 .069 0 r
.362 .69007 m
.36142 .68919 L
s
.36142 .68919 m
.36264 .689 L
s
1 0 0 r
.67362 .32622 m
.67362 .32622 L
s
.67362 .32622 m
.67362 .32622 L
s
.67362 .32622 m
.67362 .32622 L
s
.67362 .32622 m
.67362 .32622 L
s
.67362 .32622 m
.67362 .32622 L
s
.67362 .32622 m
.67362 .32622 L
s
.67362 .32622 m
.67362 .32622 L
s
.67362 .32622 m
.67362 .32622 L
s
.67362 .32622 m
.67362 .32622 L
s
1 .004 0 r
.717 .61133 m
.71704 .61137 L
s
.71696 .61136 m
.717 .61133 L
s
.717 .61133 m
.71701 .61133 L
s
1 .037 0 r
.25778 .37826 m
.25745 .37805 L
s
.25745 .37805 m
.25753 .37762 L
s
1 .004 0 r
.71704 .61137 m
.717 .6114 L
s
.71701 .61133 m
.71704 .61137 L
s
1 .069 0 r
.36264 .689 m
.362 .69007 L
s
1 .004 0 r
.717 .6114 m
.71696 .61136 L
s
.71696 .61136 m
.71701 .61133 L
s
.71701 .61133 m
.717 .6114 L
s
1 .012 0 r
.50798 .55946 m
.50816 .55894 L
s
1 .037 0 r
.25816 .37784 m
.25778 .37826 L
s
.25753 .37762 m
.25816 .37784 L
s
1 .118 0 r
.29898 .50742 m
.30095 .50237 L
s
1 .037 0 r
.25753 .37762 m
.25778 .37826 L
s
1 .001 0 r
.77118 .4814 m
.77118 .48138 L
s
.77118 .48138 m
.77119 .48138 L
s
.77117 .48138 m
.77118 .48138 L
s
.77118 .48138 m
.77118 .48138 L
s
.77119 .48138 m
.77118 .48139 L
s
.77118 .48138 m
.77119 .48138 L
s
.77118 .48139 m
.77117 .48138 L
s
.77117 .48138 m
.77118 .48138 L
s
.77118 .48138 m
.77118 .48139 L
s
1 .012 0 r
.50812 .55894 m
.50825 .55906 L
s
.508 .55903 m
.50812 .55894 L
s
.50812 .55894 m
.50816 .55894 L
s
.50825 .55906 m
.50812 .55915 L
s
.50816 .55894 m
.50825 .55906 L
s
.50812 .55915 m
.508 .55903 L
s
.508 .55903 m
.50816 .55894 L
s
1 .001 0 r
.56217 .42935 m
.56217 .4293 L
s
1 .012 0 r
.50816 .55894 m
.50812 .55915 L
s
1 .035 0 r
.45477 .68818 m
.4551 .68859 L
s
.45442 .6884 m
.45477 .68818 L
s
.45477 .68818 m
.455 .68824 L
s
1 .001 0 r
.56217 .4293 m
.56218 .42931 L
s
.56216 .42931 m
.56217 .4293 L
s
.56217 .4293 m
.56217 .4293 L
s
.56217 .42932 m
.56216 .42931 L
s
.56216 .42931 m
.56217 .4293 L
s
.56218 .42931 m
.56217 .42932 L
s
.56217 .4293 m
.56218 .42931 L
s
.56217 .4293 m
.56217 .42932 L
s
1 .053 0 r
.39649 .66266 m
.39836 .66077 L
s
1 .035 0 r
.4551 .68859 m
.45476 .68882 L
s
.455 .68824 m
.4551 .68859 L
s
1 .002 0 r
.86877 .63664 m
.86881 .63656 L
s
1 .003 0 r
.35313 .37729 m
.35306 .37715 L
s
1 .002 0 r
.8688 .63656 m
.86882 .63658 L
s
.86878 .63657 m
.8688 .63656 L
s
.8688 .63656 m
.86881 .63656 L
s
.86882 .63658 m
.8688 .63659 L
s
.86881 .63656 m
.86882 .63658 L
s
.8688 .63659 m
.86878 .63657 L
s
.86878 .63657 m
.86881 .63656 L
s
.86881 .63656 m
.8688 .63659 L
s
1 .003 0 r
.35308 .37715 m
.35311 .37717 L
s
.35304 .37718 m
.35308 .37715 L
s
.35308 .37715 m
.35306 .37715 L
s
1 0 0 r
.82543 .35125 m
.82543 .35125 L
s
.82543 .35125 m
.82543 .35125 L
s
.82543 .35125 m
.82543 .35125 L
s
.82543 .35125 m
.82543 .35125 L
s
.82543 .35125 m
.82543 .35125 L
s
.82543 .35125 m
.82543 .35125 L
s
.82543 .35125 m
.82543 .35125 L
s
.82543 .35125 m
.82543 .35125 L
s
.82543 .35125 m
.82543 .35125 L
s
1 .003 0 r
.35307 .3772 m
.35304 .37718 L
s
.35304 .37718 m
.35306 .37715 L
s
1 .035 0 r
.45476 .68882 m
.45442 .6884 L
s
.45442 .6884 m
.455 .68824 L
s
1 .003 0 r
.35311 .37717 m
.35307 .3772 L
s
.35306 .37715 m
.35311 .37717 L
s
.35306 .37715 m
.35307 .3772 L
s
1 .035 0 r
.455 .68824 m
.45476 .68882 L
s
1 .056 0 r
.35717 .53198 m
.35773 .53256 L
s
.35656 .53236 m
.35717 .53198 L
s
.35717 .53198 m
.35734 .53199 L
s
1 .004 0 r
.65974 .58459 m
.65981 .5844 L
s
1 .108 0 r
.30671 .6609 m
.30752 .66234 L
s
.3058 .66141 m
.30671 .6609 L
s
.30671 .6609 m
.30777 .66125 L
s
.30752 .66234 m
.30661 .66285 L
s
.30777 .66125 m
.30752 .66234 L
s
1 .004 0 r
.65979 .5844 m
.65984 .58445 L
s
.65975 .58444 m
.65979 .5844 L
s
.65979 .5844 m
.65981 .5844 L
s
.65984 .58445 m
.65979 .58448 L
s
.65981 .5844 m
.65984 .58445 L
s
1 .056 0 r
.35773 .53256 m
.35712 .53295 L
s
.35734 .53199 m
.35773 .53256 L
s
1 .004 0 r
.65979 .58448 m
.65975 .58444 L
s
.65975 .58444 m
.65981 .5844 L
s
.65981 .5844 m
.65979 .58448 L
s
1 .018 0 r
.45067 .53254 m
.45088 .53177 L
s
1 .275 0 r
.23859 .56214 m
.23698 .55827 L
s
.24209 .55844 m
.23859 .56214 L
s
.23698 .55827 m
.24209 .55844 L
s
1 .303 0 r
.24678 .4506 m
.2498 .45376 L
s
.24338 .45263 m
.24678 .4506 L
s
.24678 .4506 m
.24754 .45053 L
s
1 .056 0 r
.35712 .53295 m
.35656 .53236 L
s
.35656 .53236 m
.35734 .53199 L
s
1 .344 0 r
.24156 .48047 m
.24695 .46544 L
s
1 .001 0 r
.71398 .45444 m
.71398 .45441 L
s
.71398 .45441 m
.71399 .45442 L
s
.71398 .45442 m
.71398 .45441 L
s
.71398 .45441 m
.71398 .45441 L
s
.71399 .45442 m
.71398 .45442 L
s
.71398 .45441 m
.71399 .45442 L
s
.71398 .45442 m
.71398 .45442 L
s
.71398 .45442 m
.71398 .45441 L
s
.71398 .45441 m
.71398 .45442 L
s
1 .056 0 r
.35734 .53199 m
.35712 .53295 L
s
1 .018 0 r
.54824 .68784 m
.54874 .68714 L
s
1 .001 0 r
.50487 .40236 m
.50486 .40232 L
s
.50486 .40232 m
.50487 .40232 L
s
.50485 .40232 m
.50486 .40232 L
s
.50486 .40232 m
.50486 .40232 L
s
.50486 .40233 m
.50485 .40232 L
s
.50485 .40232 m
.50486 .40232 L
s
.50487 .40232 m
.50486 .40233 L
s
.50486 .40232 m
.50487 .40232 L
s
.50486 .40232 m
.50486 .40233 L
s
1 .018 0 r
.45084 .53177 m
.45102 .53194 L
s
.45065 .5319 m
.45084 .53177 L
s
.45084 .53177 m
.45088 .53177 L
s
1 .085 0 r
.33911 .63578 m
.34243 .63282 L
s
1 .018 0 r
.45102 .53194 m
.45083 .53208 L
s
.45088 .53177 m
.45102 .53194 L
s
1 .002 0 r
.81161 .60974 m
.81165 .60965 L
s
1 .018 0 r
.45083 .53208 m
.45065 .5319 L
s
.45065 .5319 m
.45088 .53177 L
s
1 .002 0 r
.29572 .35027 m
.29564 .35018 L
s
.29566 .35018 m
.29568 .35019 L
s
.29564 .35021 m
.29566 .35018 L
s
.29566 .35018 m
.29564 .35018 L
s
1 .018 0 r
.45088 .53177 m
.45083 .53208 L
s
1 .002 0 r
.81164 .60965 m
.81167 .60967 L
s
.81162 .60967 m
.81164 .60965 L
s
.81164 .60965 m
.81165 .60965 L
s
.29566 .35022 m
.29564 .35021 L
s
.29564 .35021 m
.29564 .35018 L
s
.81167 .60967 m
.81164 .60969 L
s
.81165 .60965 m
.81167 .60967 L
s
.81164 .60969 m
.81162 .60967 L
s
.81162 .60967 m
.81165 .60965 L
s
.29568 .35019 m
.29566 .35022 L
s
.29564 .35018 m
.29568 .35019 L
s
.29564 .35018 m
.29566 .35022 L
s
.81165 .60965 m
.81164 .60969 L
s
1 0 0 r
.76825 .32422 m
.76825 .32422 L
s
.76825 .32422 m
.76825 .32422 L
s
.76825 .32422 m
.76825 .32422 L
s
.76825 .32422 m
.76825 .32422 L
s
.76825 .32422 m
.76825 .32422 L
s
.76825 .32422 m
.76825 .32422 L
s
.76825 .32422 m
.76825 .32422 L
s
.76825 .32422 m
.76825 .32422 L
s
.76825 .32422 m
.76825 .32422 L
s
1 .005 0 r
.60247 .55767 m
.60254 .55744 L
s
1 .108 0 r
.30661 .66285 m
.3058 .66141 L
s
.3058 .66141 m
.30777 .66125 L
s
1 .018 0 r
.54864 .68712 m
.54882 .68732 L
s
.54845 .68724 m
.54864 .68712 L
s
.54864 .68712 m
.54874 .68714 L
s
1 .108 0 r
.30777 .66125 m
.30661 .66285 L
s
1 .053 0 r
.398 .66067 m
.39849 .6613 L
s
.39748 .66099 m
.398 .66067 L
s
.398 .66067 m
.39836 .66077 L
s
1 .018 0 r
.54882 .68732 m
.54864 .68745 L
s
.54874 .68714 m
.54882 .68732 L
s
1 .303 0 r
.2498 .45376 m
.2464 .45579 L
s
.24754 .45053 m
.2498 .45376 L
s
1 .005 0 r
.60253 .55744 m
.60259 .55749 L
s
.60247 .55748 m
.60253 .55744 L
s
.60253 .55744 m
.60254 .55744 L
s
1 .053 0 r
.39849 .6613 m
.39797 .66162 L
s
.39836 .66077 m
.39849 .6613 L
s
1 .177 0 r
.25468 .63535 m
.25345 .63603 L
s
.25367 .63285 m
.25468 .63535 L
s
.25575 .63367 m
.25468 .63535 L
s
1 .028 0 r
.3933 .50559 m
.39354 .50433 L
s
1 .005 0 r
.60259 .55749 m
.60253 .55753 L
s
.60254 .55744 m
.60259 .55749 L
s
1 .018 0 r
.54864 .68745 m
.54845 .68724 L
s
.54845 .68724 m
.54874 .68714 L
s
1 .005 0 r
.60253 .55753 m
.60247 .55748 L
s
.60247 .55748 m
.60254 .55744 L
s
.60254 .55744 m
.60253 .55753 L
s
1 .018 0 r
.54874 .68714 m
.54864 .68745 L
s
1 0 0 r
.86591 .47954 m
.86591 .47953 L
s
.86591 .47953 m
.86592 .47953 L
s
.86591 .47953 m
.86591 .47953 L
s
.86591 .47953 m
.86591 .47953 L
s
.86592 .47953 m
.86591 .47953 L
s
.86591 .47953 m
.86592 .47953 L
s
.86591 .47953 m
.86591 .47953 L
s
.86591 .47953 m
.86591 .47953 L
s
.86591 .47953 m
.86591 .47953 L
s
1 .177 0 r
.25245 .63353 m
.25367 .63285 L
s
.25367 .63285 m
.25575 .63367 L
s
0 .07 1 r
.18408 .45349 m
.2457 .26539 L
s
1 0 0 r
.65673 .42744 m
.65673 .42742 L
s
.65673 .42742 m
.65673 .42743 L
s
.65672 .42743 m
.65673 .42742 L
s
.65673 .42742 m
.65673 .42742 L
s
.65673 .42743 m
.65672 .42743 L
s
.65672 .42743 m
.65673 .42742 L
s
.65673 .42743 m
.65673 .42743 L
s
.65673 .42742 m
.65673 .42743 L
s
.65673 .42742 m
.65673 .42743 L
s
1 .053 0 r
.39797 .66162 m
.39748 .66099 L
s
.39748 .66099 m
.39836 .66077 L
s
1 .025 0 r
.49091 .66096 m
.49159 .65998 L
s
1 .053 0 r
.39836 .66077 m
.39797 .66162 L
s
1 .001 0 r
.44751 .37534 m
.4475 .37531 L
s
.4475 .37531 m
.44751 .37531 L
s
.4475 .37531 m
.4475 .37531 L
s
.4475 .37531 m
.4475 .37531 L
s
.4475 .37532 m
.4475 .37531 L
s
.4475 .37531 m
.4475 .37531 L
s
.44751 .37531 m
.4475 .37532 L
s
.4475 .37531 m
.44751 .37531 L
s
.4475 .37531 m
.4475 .37532 L
s
1 .15 0 r
.28167 .60887 m
.2886 .60408 L
s
1 .208 0 r
.26846 .5282 m
.27031 .53075 L
s
.26637 .52929 m
.26846 .5282 L
s
.26846 .5282 m
.26988 .52848 L
s
1 .002 0 r
.7544 .58282 m
.75443 .58272 L
s
.75443 .58272 m
.75445 .58274 L
s
.7544 .58274 m
.75443 .58272 L
s
.75443 .58272 m
.75443 .58272 L
s
.75445 .58274 m
.75443 .58276 L
s
.75443 .58272 m
.75445 .58274 L
s
.75443 .58276 m
.7544 .58274 L
s
.7544 .58274 m
.75443 .58272 L
s
.75443 .58272 m
.75443 .58276 L
s
1 .208 0 r
.27031 .53075 m
.26822 .53184 L
s
.26988 .52848 m
.27031 .53075 L
s
1 .007 0 r
.54515 .53072 m
.54522 .53042 L
s
1 .028 0 r
.3935 .50434 m
.39379 .50461 L
s
.39319 .50456 m
.3935 .50434 L
s
.3935 .50434 m
.39354 .50433 L
s
.39379 .50461 m
.39348 .50483 L
s
.39354 .50433 m
.39379 .50461 L
s
1 .053 0 r
.33587 .47861 m
.33606 .47621 L
s
1 .303 0 r
.2464 .45579 m
.24338 .45263 L
s
.24338 .45263 m
.24754 .45053 L
s
1 .028 0 r
.39348 .50483 m
.39319 .50456 L
s
.39319 .50456 m
.39354 .50433 L
s
1 .007 0 r
.54521 .53042 m
.54528 .53049 L
s
.54513 .53048 m
.54521 .53042 L
s
.54521 .53042 m
.54522 .53042 L
s
.54528 .53049 m
.54521 .53054 L
s
.54522 .53042 m
.54528 .53049 L
s
.54521 .53054 m
.54513 .53048 L
s
.54513 .53048 m
.54522 .53042 L
s
1 .025 0 r
.49146 .65995 m
.49171 .66023 L
s
.4912 .66012 m
.49146 .65995 L
s
.49146 .65995 m
.49159 .65998 L
s
1 .007 0 r
.54522 .53042 m
.54521 .53054 L
s
1 0 0 r
.80871 .45255 m
.80871 .45254 L
s
.80871 .45254 m
.80871 .45254 L
s
.80871 .45254 m
.80871 .45254 L
s
.80871 .45254 m
.80871 .45254 L
s
.80871 .45254 m
.80871 .45254 L
s
.80871 .45254 m
.80871 .45254 L
s
.80871 .45254 m
.80871 .45254 L
s
.80871 .45254 m
.80871 .45254 L
s
.80871 .45254 m
.80871 .45254 L
s
1 .028 0 r
.39354 .50433 m
.39348 .50483 L
s
1 .025 0 r
.49171 .66023 m
.49145 .6604 L
s
.49159 .65998 m
.49171 .66023 L
s
1 .01 0 r
.64283 .68616 m
.64306 .68577 L
s
1 .025 0 r
.49145 .6604 m
.4912 .66012 L
s
.4912 .66012 m
.49159 .65998 L
s
1 0 0 r
.59942 .40043 m
.59942 .40041 L
s
.59942 .40041 m
.59942 .40041 L
s
.59942 .40041 m
.59942 .40041 L
s
.59942 .40041 m
.59942 .40041 L
s
.59942 .40042 m
.59942 .40041 L
s
.59942 .40041 m
.59942 .40041 L
s
.59942 .40041 m
.59942 .40042 L
s
.59942 .40041 m
.59942 .40041 L
s
.59942 .40041 m
.59942 .40042 L
s
1 .025 0 r
.49159 .65998 m
.49145 .6604 L
s
1 .037 0 r
.43352 .63405 m
.43454 .6326 L
s
1 .001 0 r
.90644 .60799 m
.90647 .60794 L
s
1 0 0 r
.3901 .34829 m
.39009 .34828 L
s
1 .01 0 r
.64301 .68576 m
.64312 .68586 L
s
.64291 .68583 m
.64301 .68576 L
s
.64301 .68576 m
.64306 .68577 L
s
1 0 0 r
.39009 .34828 m
.39009 .34828 L
s
.39009 .34828 m
.39009 .34828 L
s
.39009 .34828 m
.39009 .34828 L
s
.39009 .34828 m
.39009 .34828 L
s
.39009 .34828 m
.39009 .34828 L
s
.39009 .34828 m
.39009 .34828 L
s
.39009 .34828 m
.39009 .34828 L
s
.39009 .34828 m
.39009 .34828 L
s
1 .001 0 r
.90646 .60794 m
.90647 .60795 L
s
.90645 .60795 m
.90646 .60794 L
s
.90646 .60794 m
.90647 .60794 L
s
1 .01 0 r
.64312 .68586 m
.64302 .68594 L
s
.64306 .68577 m
.64312 .68586 L
s
1 .001 0 r
.90647 .60795 m
.90646 .60796 L
s
.90647 .60794 m
.90647 .60795 L
s
.90646 .60796 m
.90645 .60795 L
s
.90645 .60795 m
.90647 .60794 L
s
.90647 .60794 m
.90646 .60796 L
s
1 .01 0 r
.64302 .68594 m
.64291 .68583 L
s
.64291 .68583 m
.64306 .68577 L
s
1 .289 0 r
.22417 .58194 m
.2417 .57525 L
s
1 .01 0 r
.64306 .68577 m
.64302 .68594 L
s
1 .118 0 r
.30062 .50236 m
.3018 .5036 L
s
.29932 .50317 m
.30062 .50236 L
s
.30062 .50236 m
.30095 .50237 L
s
1 .003 0 r
.69713 .55587 m
.69716 .55576 L
s
1 .085 0 r
.3418 .63265 m
.34255 .6337 L
s
.34098 .63312 m
.3418 .63265 L
s
.3418 .63265 m
.34243 .63282 L
s
1 .569 0 r
.23199 .48549 m
.22838 .47758 L
s
.23895 .47758 m
.23199 .48549 L
s
1 .003 0 r
.69715 .55576 m
.69718 .55578 L
s
.69713 .55578 m
.69715 .55576 L
s
.69715 .55576 m
.69716 .55576 L
s
.69718 .55578 m
.69716 .5558 L
s
.69716 .55576 m
.69718 .55578 L
s
1 .085 0 r
.34255 .6337 m
.34173 .63417 L
s
.34243 .63282 m
.34255 .6337 L
s
1 .003 0 r
.69716 .5558 m
.69713 .55578 L
s
.69713 .55578 m
.69716 .55576 L
s
.69716 .55576 m
.69716 .5558 L
s
1 .177 0 r
.25575 .63367 m
.25345 .63603 L
s
.25245 .63353 m
.25575 .63367 L
s
.25345 .63603 m
.25245 .63353 L
s
1 .009 0 r
.48778 .50375 m
.48783 .50334 L
s
1 .303 0 r
.24754 .45053 m
.2464 .45579 L
s
1 .118 0 r
.3018 .5036 m
.3005 .5044 L
s
.30095 .50237 m
.3018 .5036 L
s
1 .129 0 r
.27839 .45161 m
.27762 .44567 L
s
1 .569 0 r
.22838 .47758 m
.23895 .47758 L
s
1 .009 0 r
.48782 .50335 m
.48792 .50343 L
s
.48773 .50342 m
.48782 .50335 L
s
.48782 .50335 m
.48783 .50334 L
s
1 0 0 r
.75145 .42553 m
.75145 .42552 L
s
.75145 .42552 m
.75145 .42553 L
s
.75145 .42553 m
.75145 .42552 L
s
.75145 .42552 m
.75145 .42552 L
s
.75145 .42553 m
.75145 .42553 L
s
.75145 .42553 m
.75145 .42552 L
s
.75145 .42553 m
.75145 .42553 L
s
.75145 .42552 m
.75145 .42553 L
s
.75145 .42552 m
.75145 .42553 L
s
1 .009 0 r
.48792 .50343 m
.48782 .5035 L
s
.48783 .50334 m
.48792 .50343 L
s
.48782 .5035 m
.48773 .50342 L
s
.48773 .50342 m
.48783 .50334 L
s
1 .013 0 r
.58549 .65925 m
.58578 .65874 L
s
1 .009 0 r
.48783 .50334 m
.48782 .5035 L
s
1 .208 0 r
.26822 .53184 m
.26637 .52929 L
s
.26637 .52929 m
.26988 .52848 L
s
1 0 0 r
.54206 .37338 m
.54206 .37337 L
s
.54206 .37337 m
.54206 .37337 L
s
.54206 .37337 m
.54206 .37337 L
s
.54206 .37337 m
.54206 .37337 L
s
.54206 .37338 m
.54206 .37337 L
s
.54206 .37337 m
.54206 .37337 L
s
.54206 .37337 m
.54206 .37338 L
s
.54206 .37337 m
.54206 .37337 L
s
.54206 .37337 m
.54206 .37338 L
s
1 .085 0 r
.34173 .63417 m
.34098 .63312 L
s
.34098 .63312 m
.34243 .63282 L
s
1 .06 0 r
.37607 .60712 m
.37776 .60479 L
s
1 .118 0 r
.3005 .5044 m
.29932 .50317 L
s
.29932 .50317 m
.30095 .50237 L
s
1 .037 0 r
.43434 .63255 m
.43471 .63298 L
s
.43396 .6328 m
.43434 .63255 L
s
.43434 .63255 m
.43454 .6326 L
s
1 .085 0 r
.34243 .63282 m
.34173 .63417 L
s
1 .001 0 r
.84922 .58105 m
.84924 .58099 L
s
1 0 0 r
.33263 .32122 m
.33263 .32122 L
s
.33263 .32122 m
.33263 .32122 L
s
.33263 .32122 m
.33263 .32122 L
s
.33263 .32122 m
.33263 .32122 L
s
.33263 .32122 m
.33263 .32122 L
s
.33263 .32122 m
.33263 .32122 L
s
.33263 .32122 m
.33263 .32122 L
s
.33263 .32122 m
.33263 .32122 L
s
.33263 .32122 m
.33263 .32122 L
s
1 .208 0 r
.26988 .52848 m
.26822 .53184 L
s
1 .037 0 r
.43471 .63298 m
.43432 .63322 L
s
.43454 .6326 m
.43471 .63298 L
s
1 .001 0 r
.84924 .58099 m
.84925 .581 L
s
.84923 .581 m
.84924 .58099 L
s
.84924 .58099 m
.84924 .58099 L
s
.84925 .581 m
.84924 .58101 L
s
.84924 .58099 m
.84925 .581 L
s
.84924 .58101 m
.84923 .581 L
s
.84923 .581 m
.84924 .58099 L
s
.84924 .58099 m
.84924 .58101 L
s
1 .013 0 r
.58572 .65873 m
.58585 .65887 L
s
.58559 .65882 m
.58572 .65873 L
s
.58572 .65873 m
.58578 .65874 L
s
.58585 .65887 m
.58572 .65896 L
s
.58578 .65874 m
.58585 .65887 L
s
1 .053 0 r
.33604 .47624 m
.33659 .47673 L
s
.33545 .47666 m
.33604 .47624 L
s
.33604 .47624 m
.33606 .47621 L
s
1 .013 0 r
.58572 .65896 m
.58559 .65882 L
s
.58559 .65882 m
.58578 .65874 L
s
1 .003 0 r
.6398 .5289 m
.63983 .52877 L
s
1 .013 0 r
.58578 .65874 m
.58572 .65896 L
s
1 .037 0 r
.43432 .63322 m
.43396 .6328 L
s
.43396 .6328 m
.43454 .6326 L
s
1 .118 0 r
.30095 .50237 m
.3005 .5044 L
s
1 .003 0 r
.63983 .52877 m
.63986 .52879 L
s
.63979 .52879 m
.63983 .52877 L
s
.63983 .52877 m
.63983 .52877 L
s
.63986 .52879 m
.63983 .52882 L
s
.63983 .52877 m
.63986 .52879 L
s
.63983 .52882 m
.63979 .52879 L
s
.63979 .52879 m
.63983 .52877 L
s
1 .037 0 r
.43454 .6326 m
.43432 .63322 L
s
1 .003 0 r
.63983 .52877 m
.63983 .52882 L
s
1 .013 0 r
.43035 .47674 m
.43037 .47617 L
s
1 .053 0 r
.33659 .47673 m
.336 .47715 L
s
.33606 .47621 m
.33659 .47673 L
s
.336 .47715 m
.33545 .47666 L
s
.33545 .47666 m
.33606 .47621 L
s
1 .006 0 r
.73758 .68447 m
.7377 .68425 L
s
1 .468 0 r
.22085 .42458 m
.2049 .40406 L
s
1 0 0 r
.69414 .39849 m
.69414 .39848 L
s
.69414 .39848 m
.69414 .39849 L
s
.69414 .39849 m
.69414 .39848 L
s
.69414 .39848 m
.69414 .39848 L
s
.69414 .39849 m
.69414 .39849 L
s
.69414 .39849 m
.69414 .39848 L
s
.69414 .39849 m
.69414 .39849 L
s
.69414 .39848 m
.69414 .39849 L
s
.69414 .39848 m
.69414 .39849 L
s
1 .053 0 r
.33606 .47621 m
.336 .47715 L
s
1 .006 0 r
.73768 .68424 m
.73774 .6843 L
s
.73762 .68428 m
.73768 .68424 L
s
.73768 .68424 m
.7377 .68425 L
s
1 .017 0 r
.5281 .63232 m
.52847 .63162 L
s
1 .006 0 r
.73774 .6843 m
.73768 .68434 L
s
.7377 .68425 m
.73774 .6843 L
s
.73768 .68434 m
.73762 .68428 L
s
.73762 .68428 m
.7377 .68425 L
s
1 .013 0 r
.43037 .47617 m
.4305 .47629 L
s
.43023 .47628 m
.43037 .47617 L
s
.43037 .47617 m
.43037 .47617 L
s
1 .006 0 r
.7377 .68425 m
.73768 .68434 L
s
1 .013 0 r
.4305 .47629 m
.43036 .47639 L
s
.43037 .47617 m
.4305 .47629 L
s
.43036 .47639 m
.43023 .47628 L
s
.43023 .47628 m
.43037 .47617 L
s
1 0 0 r
.48464 .34631 m
.48464 .34631 L
s
.48464 .34631 m
.48464 .34631 L
s
.48464 .34631 m
.48464 .34631 L
s
.48464 .34631 m
.48464 .34631 L
s
.48464 .34631 m
.48464 .34631 L
s
.48464 .34631 m
.48464 .34631 L
s
.48464 .34631 m
.48464 .34631 L
s
.48464 .34631 m
.48464 .34631 L
s
.48464 .34631 m
.48464 .34631 L
s
1 .013 0 r
.43037 .47617 m
.43036 .47639 L
s
1 .107 0 r
.31857 .58016 m
.32186 .57602 L
s
1 .001 0 r
.79195 .55408 m
.79197 .55401 L
s
.79196 .55401 m
.79198 .55403 L
s
.79195 .55402 m
.79196 .55401 L
s
.79196 .55401 m
.79197 .55401 L
s
.79198 .55403 m
.79196 .55404 L
s
.79197 .55401 m
.79198 .55403 L
s
.79196 .55404 m
.79195 .55402 L
s
.79195 .55402 m
.79197 .55401 L
s
.79197 .55401 m
.79196 .55404 L
s
1 .004 0 r
.58242 .5019 m
.58244 .50174 L
s
1 .017 0 r
.52839 .63161 m
.52857 .63179 L
s
.52821 .63173 m
.52839 .63161 L
s
.52839 .63161 m
.52847 .63162 L
s
.52857 .63179 m
.52839 .63192 L
s
.52847 .63162 m
.52857 .63179 L
s
1 .004 0 r
.58244 .50174 m
.58248 .50177 L
s
.5824 .50177 m
.58244 .50174 L
s
.58244 .50174 m
.58244 .50174 L
s
.58248 .50177 m
.58244 .5018 L
s
.58244 .50174 m
.58248 .50177 L
s
.58244 .5018 m
.5824 .50177 L
s
.5824 .50177 m
.58244 .50174 L
s
.58244 .50174 m
.58244 .5018 L
s
1 .017 0 r
.52839 .63192 m
.52821 .63173 L
s
.52821 .63173 m
.52847 .63162 L
s
1 .02 0 r
.37286 .44972 m
.37276 .4488 L
s
1 .15 0 r
.28729 .6037 m
.2885 .60565 L
s
.28592 .60443 m
.28729 .6037 L
s
.28729 .6037 m
.2886 .60408 L
s
1 .017 0 r
.52847 .63162 m
.52839 .63192 L
s
1 .15 0 r
.2885 .60565 m
.28713 .60638 L
s
.2886 .60408 m
.2885 .60565 L
s
1 0 0 r
.84634 .42362 m
.84634 .42362 L
s
.84634 .42362 m
.84634 .42362 L
s
.84634 .42362 m
.84634 .42362 L
s
.84634 .42362 m
.84634 .42362 L
s
.84634 .42362 m
.84634 .42362 L
s
.84634 .42362 m
.84634 .42362 L
s
.84634 .42362 m
.84634 .42362 L
s
.84634 .42362 m
.84634 .42362 L
s
.84634 .42362 m
.84634 .42362 L
s
1 .007 0 r
.68024 .65754 m
.68038 .65726 L
s
1 .06 0 r
.37744 .60472 m
.37802 .60541 L
s
.37682 .6051 m
.37744 .60472 L
s
.37744 .60472 m
.37776 .60479 L
s
1 0 0 r
.63677 .37142 m
.63677 .37142 L
s
.63677 .37142 m
.63677 .37142 L
s
.63677 .37142 m
.63677 .37142 L
s
.63677 .37142 m
.63677 .37142 L
s
.63677 .37142 m
.63677 .37142 L
s
.63677 .37142 m
.63677 .37142 L
s
.63677 .37142 m
.63677 .37142 L
s
.63677 .37142 m
.63677 .37142 L
s
.63677 .37142 m
.63677 .37142 L
s
1 .06 0 r
.37802 .60541 m
.3774 .60579 L
s
.37776 .60479 m
.37802 .60541 L
s
1 .025 0 r
.47065 .60536 m
.47115 .60435 L
s
1 .007 0 r
.68035 .65726 m
.68042 .65733 L
s
.68028 .65731 m
.68035 .65726 L
s
.68035 .65726 m
.68038 .65726 L
s
.68042 .65733 m
.68035 .65738 L
s
.68038 .65726 m
.68042 .65733 L
s
.68035 .65738 m
.68028 .65731 L
s
.68028 .65731 m
.68038 .65726 L
s
.68038 .65726 m
.68035 .65738 L
s
1 0 0 r
.42717 .31922 m
.42717 .31922 L
s
.42717 .31922 m
.42717 .31922 L
s
.42717 .31922 m
.42717 .31922 L
s
.42717 .31922 m
.42717 .31922 L
s
.42717 .31922 m
.42717 .31922 L
s
.42717 .31922 m
.42717 .31922 L
s
.42717 .31922 m
.42717 .31922 L
s
.42717 .31922 m
.42717 .31922 L
s
.42717 .31922 m
.42717 .31922 L
s
1 .226 0 r
.26102 .55318 m
.2694 .54487 L
s
1 .02 0 r
.37279 .44881 m
.373 .44898 L
s
.37257 .44898 m
.37279 .44881 L
s
.37279 .44881 m
.37276 .4488 L
s
1 .06 0 r
.3774 .60579 m
.37682 .6051 L
s
.37682 .6051 m
.37776 .60479 L
s
1 .002 0 r
.73462 .52708 m
.73463 .52701 L
s
.73463 .52701 m
.73465 .52702 L
s
.73461 .52702 m
.73463 .52701 L
s
.73463 .52701 m
.73463 .52701 L
s
.73465 .52702 m
.73463 .52704 L
s
.73463 .52701 m
.73465 .52702 L
s
.73463 .52704 m
.73461 .52702 L
s
.73461 .52702 m
.73463 .52701 L
s
.73463 .52701 m
.73463 .52704 L
s
1 .02 0 r
.37277 .44915 m
.37257 .44898 L
s
.37257 .44898 m
.37276 .4488 L
s
.373 .44898 m
.37277 .44915 L
s
.37276 .4488 m
.373 .44898 L
s
1 .06 0 r
.37776 .60479 m
.3774 .60579 L
s
1 .02 0 r
.37276 .4488 m
.37277 .44915 L
s
1 .004 0 r
.52499 .47488 m
.525 .47468 L
s
1 .375 0 r
.21232 .39181 m
.2157 .39406 L
s
.20841 .39591 m
.21232 .39181 L
s
.21232 .39181 m
.2095 .39167 L
s
1 .004 0 r
.52499 .47469 m
.52504 .47472 L
s
.52495 .47472 m
.52499 .47469 L
s
.52499 .47469 m
.525 .47468 L
s
.52504 .47472 m
.52499 .47476 L
s
.525 .47468 m
.52504 .47472 L
s
.52499 .47476 m
.52495 .47472 L
s
.52495 .47472 m
.525 .47468 L
s
.525 .47468 m
.52499 .47476 L
s
1 .003 0 r
.8325 .68279 m
.83257 .68265 L
s
1 .036 0 r
.31532 .42266 m
.31474 .42098 L
s
1 .025 0 r
.47105 .60433 m
.4713 .6046 L
s
.47079 .60451 m
.47105 .60433 L
s
.47105 .60433 m
.47115 .60435 L
s
1 0 0 r
.78902 .39655 m
.78902 .39655 L
s
1 .003 0 r
.83255 .68264 m
.83259 .68268 L
s
.83252 .68267 m
.83255 .68264 L
s
.83255 .68264 m
.83257 .68265 L
s
1 0 0 r
.78902 .39655 m
.78903 .39655 L
s
.78902 .39655 m
.78902 .39655 L
s
.78902 .39655 m
.78902 .39655 L
s
.78902 .39655 m
.78902 .39655 L
s
.78902 .39655 m
.78902 .39655 L
s
.78903 .39655 m
.78902 .39655 L
s
.78902 .39655 m
.78903 .39655 L
s
.78902 .39655 m
.78902 .39655 L
s
1 .003 0 r
.83259 .68268 m
.83256 .68271 L
s
.83257 .68265 m
.83259 .68268 L
s
.83256 .68271 m
.83252 .68267 L
s
.83252 .68267 m
.83257 .68265 L
s
.83257 .68265 m
.83256 .68271 L
s
1 .025 0 r
.4713 .6046 m
.47104 .60477 L
s
.47115 .60435 m
.4713 .6046 L
s
1 .009 0 r
.62284 .63059 m
.623 .63023 L
s
1 .025 0 r
.47104 .60477 m
.47079 .60451 L
s
.47079 .60451 m
.47115 .60435 L
s
1 0 0 r
.57935 .34433 m
.57935 .34433 L
s
.57935 .34433 m
.57935 .34433 L
s
.57935 .34433 m
.57935 .34433 L
s
.57935 .34433 m
.57935 .34433 L
s
.57935 .34433 m
.57935 .34433 L
s
.57935 .34433 m
.57935 .34433 L
s
.57935 .34433 m
.57935 .34433 L
s
.57935 .34433 m
.57935 .34433 L
s
.57935 .34433 m
.57935 .34433 L
s
1 .025 0 r
.47115 .60435 m
.47104 .60477 L
s
1 .15 0 r
.28713 .60638 m
.28592 .60443 L
s
.28592 .60443 m
.2886 .60408 L
s
1 .038 0 r
.41314 .57838 m
.41387 .57679 L
s
1 .15 0 r
.2886 .60408 m
.28713 .60638 L
s
1 .009 0 r
.62297 .63023 m
.62306 .63032 L
s
.62288 .63029 m
.62297 .63023 L
s
.62297 .63023 m
.623 .63023 L
s
1 .001 0 r
.88694 .55227 m
.88695 .55224 L
s
1 .009 0 r
.62306 .63032 m
.62297 .63038 L
s
.623 .63023 m
.62306 .63032 L
s
1 .001 0 r
.88694 .55224 m
.88695 .55224 L
s
.88694 .55224 m
.88694 .55224 L
s
.88694 .55224 m
.88695 .55224 L
s
.88695 .55224 m
.88694 .55225 L
s
.88695 .55224 m
.88695 .55224 L
s
.88694 .55225 m
.88694 .55224 L
s
.88694 .55224 m
.88695 .55224 L
s
1 .009 0 r
.62297 .63038 m
.62288 .63029 L
s
.62288 .63029 m
.623 .63023 L
s
1 .001 0 r
.88695 .55224 m
.88694 .55225 L
s
1 .009 0 r
.623 .63023 m
.62297 .63038 L
s
1 .615 0 r
.20341 .52617 m
.2391 .51014 L
s
1 .002 0 r
.67723 .50005 m
.67725 .49998 L
s
1 .289 0 r
.24007 .57811 m
.23799 .57916 L
s
.23837 .57403 m
.24007 .57811 L
s
.2417 .57525 m
.24007 .57811 L
s
1 .002 0 r
.67724 .49998 m
.67726 .49999 L
s
.67723 .49999 m
.67724 .49998 L
s
.67724 .49998 m
.67725 .49998 L
s
.67726 .49999 m
.67724 .50001 L
s
.67725 .49998 m
.67726 .49999 L
s
.67724 .50001 m
.67723 .49999 L
s
.67723 .49999 m
.67725 .49998 L
s
.67725 .49998 m
.67724 .50001 L
s
1 .375 0 r
.21179 .39816 m
.20841 .39591 L
s
.20841 .39591 m
.2095 .39167 L
s
1 .596 0 r
.23652 .49994 m
.23193 .50201 L
s
.23273 .49163 m
.23652 .49994 L
s
.23926 .49368 m
.23652 .49994 L
s
1 .005 0 r
.4675 .44782 m
.46748 .44759 L
s
1 .289 0 r
.2363 .57507 m
.23837 .57403 L
s
.23837 .57403 m
.2417 .57525 L
s
1 .115 0 r
.30124 .68194 m
.30715 .67865 L
s
1 .005 0 r
.46748 .44759 m
.46754 .44763 L
s
.46743 .44764 m
.46748 .44759 L
s
.46748 .44759 m
.46748 .44759 L
s
1 .004 0 r
.77515 .65583 m
.77523 .65567 L
s
1 .005 0 r
.46748 .44768 m
.46743 .44764 L
s
.46743 .44764 m
.46748 .44759 L
s
.46754 .44763 m
.46748 .44768 L
s
.46748 .44759 m
.46754 .44763 L
s
1 .081 0 r
.25772 .39558 m
.25471 .39208 L
s
1 .005 0 r
.46748 .44759 m
.46748 .44768 L
s
1 .596 0 r
.22813 .49368 m
.23273 .49163 L
s
.23273 .49163 m
.23926 .49368 L
s
1 0 0 r
.73165 .36946 m
.73165 .36946 L
s
.73165 .36946 m
.73165 .36946 L
s
.73165 .36946 m
.73165 .36946 L
s
.73165 .36946 m
.73165 .36946 L
s
.73165 .36946 m
.73165 .36946 L
s
.73165 .36946 m
.73165 .36946 L
s
.73165 .36946 m
.73165 .36946 L
s
.73165 .36946 m
.73165 .36946 L
s
.73165 .36946 m
.73165 .36946 L
s
1 .036 0 r
.31488 .421 m
.31525 .42128 L
s
.31447 .42135 m
.31488 .421 L
s
.31488 .421 m
.31474 .42098 L
s
1 .004 0 r
.77521 .65567 m
.77525 .65571 L
s
.77517 .6557 m
.77521 .65567 L
s
.77521 .65567 m
.77523 .65567 L
s
.77525 .65571 m
.77521 .65574 L
s
.77523 .65567 m
.77525 .65571 L
s
.77521 .65574 m
.77517 .6557 L
s
.77517 .6557 m
.77523 .65567 L
s
.77523 .65567 m
.77521 .65574 L
s
1 .129 0 r
.27785 .44575 m
.27917 .44685 L
s
.27638 .44686 m
.27785 .44575 L
s
.27785 .44575 m
.27762 .44567 L
s
1 .011 0 r
.56539 .60361 m
.56557 .60314 L
s
1 .036 0 r
.31484 .42163 m
.31447 .42135 L
s
.31447 .42135 m
.31474 .42098 L
s
1 0 0 r
.52187 .31721 m
.52187 .31721 L
s
.52187 .31721 m
.52187 .31721 L
s
.52187 .31721 m
.52187 .31721 L
s
.52187 .31721 m
.52187 .31721 L
s
.52187 .31721 m
.52187 .31721 L
s
.52187 .31721 m
.52187 .31721 L
s
.52187 .31721 m
.52187 .31721 L
s
.52187 .31721 m
.52187 .31721 L
s
.52187 .31721 m
.52187 .31721 L
s
1 .036 0 r
.31525 .42128 m
.31484 .42163 L
s
.31474 .42098 m
.31525 .42128 L
s
1 .066 0 r
.35558 .55137 m
.35678 .54857 L
s
1 .107 0 r
.32126 .5759 m
.32227 .57716 L
s
.32014 .57655 m
.32126 .5759 L
s
.32126 .5759 m
.32186 .57602 L
s
1 .036 0 r
.31474 .42098 m
.31484 .42163 L
s
1 .001 0 r
.8296 .52525 m
.82961 .52521 L
s
.82961 .52521 m
.82962 .52522 L
s
.8296 .52522 m
.82961 .52521 L
s
.82961 .52521 m
.82961 .52521 L
s
1 .038 0 r
.41374 .57677 m
.41413 .57718 L
s
.41333 .57704 m
.41374 .57677 L
s
.41374 .57677 m
.41387 .57679 L
s
1 .001 0 r
.82962 .52522 m
.82961 .52523 L
s
.82961 .52521 m
.82962 .52522 L
s
.82961 .52523 m
.8296 .52522 L
s
.8296 .52522 m
.82961 .52521 L
s
.82961 .52521 m
.82961 .52523 L
s
1 .011 0 r
.56553 .60313 m
.56565 .60325 L
s
.56542 .60322 m
.56553 .60313 L
s
.56553 .60313 m
.56557 .60314 L
s
.56565 .60325 m
.56554 .60333 L
s
.56557 .60314 m
.56565 .60325 L
s
.56554 .60333 m
.56542 .60322 L
s
.56542 .60322 m
.56557 .60314 L
s
1 .038 0 r
.41413 .57718 m
.41372 .57745 L
s
.41387 .57679 m
.41413 .57718 L
s
1 .107 0 r
.32227 .57716 m
.32116 .5778 L
s
.32186 .57602 m
.32227 .57716 L
s
1 .011 0 r
.56557 .60314 m
.56554 .60333 L
s
1 .002 0 r
.61979 .473 m
.6198 .47292 L
s
.6198 .47292 m
.61982 .47294 L
s
.61978 .47294 m
.6198 .47292 L
s
.6198 .47292 m
.6198 .47292 L
s
.61982 .47294 m
.6198 .47295 L
s
.6198 .47292 m
.61982 .47294 L
s
.6198 .47295 m
.61978 .47294 L
s
.61978 .47294 m
.6198 .47292 L
s
.6198 .47292 m
.6198 .47295 L
s
1 .038 0 r
.41372 .57745 m
.41333 .57704 L
s
.41333 .57704 m
.41387 .57679 L
s
1 .129 0 r
.2777 .44796 m
.27638 .44686 L
s
.27638 .44686 m
.27762 .44567 L
s
.27917 .44685 m
.2777 .44796 L
s
.27762 .44567 m
.27917 .44685 L
s
1 .002 0 r
.92758 .6811 m
.92763 .68101 L
s
1 .006 0 r
.40995 .42075 m
.40988 .42045 L
s
1 .038 0 r
.41387 .57679 m
.41372 .57745 L
s
1 .002 0 r
.92762 .68101 m
.92764 .68103 L
s
.9276 .68102 m
.92762 .68101 L
s
.92762 .68101 m
.92763 .68101 L
s
.92764 .68103 m
.92762 .68105 L
s
.92763 .68101 m
.92764 .68103 L
s
.92762 .68105 m
.9276 .68102 L
s
.9276 .68102 m
.92763 .68101 L
s
.92763 .68101 m
.92762 .68105 L
s
1 .185 0 r
.24361 .65497 m
.25507 .65098 L
s
1 .005 0 r
.71775 .62885 m
.71783 .62866 L
s
1 .006 0 r
.4099 .42045 m
.40997 .4205 L
s
.40983 .42051 m
.4099 .42045 L
s
.4099 .42045 m
.40988 .42045 L
s
.40989 .42056 m
.40983 .42051 L
s
.40983 .42051 m
.40988 .42045 L
s
.40997 .4205 m
.40989 .42056 L
s
.40988 .42045 m
.40997 .4205 L
s
.40988 .42045 m
.40989 .42056 L
s
1 0 0 r
.67423 .34234 m
.67423 .34234 L
s
.67423 .34234 m
.67423 .34234 L
s
.67423 .34234 m
.67423 .34234 L
s
.67423 .34234 m
.67423 .34234 L
s
.67423 .34234 m
.67423 .34234 L
s
.67423 .34234 m
.67423 .34234 L
s
.67423 .34234 m
.67423 .34234 L
s
.67423 .34234 m
.67423 .34234 L
s
.67423 .34234 m
.67423 .34234 L
s
1 .005 0 r
.71781 .62866 m
.71786 .6287 L
s
.71776 .62869 m
.71781 .62866 L
s
.71781 .62866 m
.71783 .62866 L
s
.71786 .6287 m
.71781 .62874 L
s
.71783 .62866 m
.71786 .6287 L
s
.71781 .62874 m
.71776 .62869 L
s
.71776 .62869 m
.71783 .62866 L
s
.71783 .62866 m
.71781 .62874 L
s
1 .015 0 r
.50788 .5766 m
.5081 .57595 L
s
1 .107 0 r
.32116 .5778 m
.32014 .57655 L
s
.32014 .57655 m
.32186 .57602 L
s
1 .129 0 r
.27762 .44567 m
.2777 .44796 L
s
1 .136 0 r
.29797 .52434 m
.30026 .5185 L
s
1 .107 0 r
.32186 .57602 m
.32116 .5778 L
s
1 .375 0 r
.2157 .39406 m
.21179 .39816 L
s
.2095 .39167 m
.2157 .39406 L
s
1 .001 0 r
.77221 .4982 m
.77222 .49816 L
s
.77222 .49816 m
.77223 .49817 L
s
.77221 .49817 m
.77222 .49816 L
s
.77222 .49816 m
.77222 .49816 L
s
.77223 .49817 m
.77222 .49818 L
s
.77222 .49816 m
.77223 .49817 L
s
.77222 .49818 m
.77221 .49817 L
s
.77221 .49817 m
.77222 .49816 L
s
.77222 .49816 m
.77222 .49818 L
s
1 .002 0 r
.5623 .44593 m
.5623 .44584 L
s
1 .015 0 r
.50806 .57594 m
.50822 .5761 L
s
.50789 .57606 m
.50806 .57594 L
s
.50806 .57594 m
.5081 .57595 L
s
.50822 .5761 m
.50805 .57621 L
s
.5081 .57595 m
.50822 .5761 L
s
1 .002 0 r
.5623 .44584 m
.56232 .44586 L
s
.56228 .44586 m
.5623 .44584 L
s
.5623 .44584 m
.5623 .44584 L
s
.5623 .44588 m
.56228 .44586 L
s
.56228 .44586 m
.5623 .44584 L
s
.56232 .44586 m
.5623 .44588 L
s
.5623 .44584 m
.56232 .44586 L
s
.5623 .44584 m
.5623 .44588 L
s
1 .058 0 r
.3959 .68025 m
.39796 .67818 L
s
1 .015 0 r
.50805 .57621 m
.50789 .57606 L
s
.50789 .57606 m
.5081 .57595 L
s
.5081 .57595 m
.50805 .57621 L
s
1 .002 0 r
.87023 .65412 m
.87028 .65402 L
s
1 .008 0 r
.35235 .39364 m
.35218 .39326 L
s
1 .002 0 r
.87027 .65402 m
.87029 .65404 L
s
.87024 .65404 m
.87027 .65402 L
s
.87027 .65402 m
.87028 .65402 L
s
.87029 .65404 m
.87027 .65406 L
s
.87028 .65402 m
.87029 .65404 L
s
.87027 .65406 m
.87024 .65404 L
s
.87024 .65404 m
.87028 .65402 L
s
.87028 .65402 m
.87027 .65406 L
s
1 0 0 r
.8267 .3675 m
.8267 .36749 L
s
.8267 .36749 m
.8267 .3675 L
s
.8267 .3675 m
.8267 .36749 L
s
.8267 .36749 m
.8267 .36749 L
s
.8267 .3675 m
.8267 .3675 L
s
.8267 .3675 m
.8267 .36749 L
s
.8267 .3675 m
.8267 .3675 L
s
.8267 .36749 m
.8267 .3675 L
s
.8267 .36749 m
.8267 .3675 L
s
1 .006 0 r
.66029 .60185 m
.66037 .60161 L
s
1 .008 0 r
.35221 .39327 m
.3523 .39333 L
s
.35213 .39335 m
.35221 .39327 L
s
.35221 .39327 m
.35218 .39326 L
s
.35221 .39341 m
.35213 .39335 L
s
.35213 .39335 m
.35218 .39326 L
s
1 0 0 r
.61674 .3152 m
.61674 .3152 L
s
.61674 .3152 m
.61674 .3152 L
s
.61674 .3152 m
.61674 .3152 L
s
.61674 .3152 m
.61674 .3152 L
s
.61674 .3152 m
.61674 .3152 L
s
.61674 .3152 m
.61674 .3152 L
s
.61674 .3152 m
.61674 .3152 L
s
.61674 .3152 m
.61674 .3152 L
s
.61674 .3152 m
.61674 .3152 L
s
1 .008 0 r
.3523 .39333 m
.35221 .39341 L
s
.35218 .39326 m
.3523 .39333 L
s
.35218 .39326 m
.35221 .39341 L
s
1 .006 0 r
.66036 .60161 m
.66042 .60166 L
s
.6603 .60165 m
.66036 .60161 L
s
.66036 .60161 m
.66037 .60161 L
s
1 .022 0 r
.45031 .54957 m
.45058 .54859 L
s
1 .006 0 r
.66042 .60166 m
.66036 .60171 L
s
.66037 .60161 m
.66042 .60166 L
s
.66036 .60171 m
.6603 .60165 L
s
.6603 .60165 m
.66037 .60161 L
s
1 .115 0 r
.30602 .67826 m
.30689 .6798 L
s
.30504 .67882 m
.30602 .67826 L
s
.30602 .67826 m
.30715 .67865 L
s
.30689 .6798 m
.30591 .68036 L
s
.30715 .67865 m
.30689 .6798 L
s
1 .006 0 r
.66037 .60161 m
.66036 .60171 L
s
1 .081 0 r
.25536 .39209 m
.25609 .39255 L
s
.25454 .39301 m
.25536 .39209 L
s
.25536 .39209 m
.25471 .39208 L
s
1 .066 0 r
.35656 .54855 m
.35724 .54925 L
s
.35584 .54901 m
.35656 .54855 L
s
.35656 .54855 m
.35678 .54857 L
s
1 .375 0 r
.2095 .39167 m
.21179 .39816 L
s
1 .373 0 r
.2403 .49728 m
.24618 .48098 L
s
1 .081 0 r
.25526 .39347 m
.25454 .39301 L
s
.25454 .39301 m
.25471 .39208 L
s
1 .001 0 r
.71477 .47113 m
.71477 .47109 L
s
.71477 .47109 m
.71478 .4711 L
s
.71476 .4711 m
.71477 .47109 L
s
.71477 .47109 m
.71477 .47109 L
s
.71478 .4711 m
.71477 .4711 L
s
.71477 .47109 m
.71478 .4711 L
s
.71477 .4711 m
.71476 .4711 L
s
.71476 .4711 m
.71477 .47109 L
s
.71477 .47109 m
.71477 .4711 L
s
1 .066 0 r
.35724 .54925 m
.35651 .54972 L
s
.35678 .54857 m
.35724 .54925 L
s
1 .289 0 r
.23799 .57916 m
.2363 .57507 L
s
.2417 .57525 m
.23799 .57916 L
s
.2363 .57507 m
.2417 .57525 L
s
1 .002 0 r
.50475 .41882 m
.50473 .41874 L
s
.50474 .41874 m
.50476 .41876 L
s
.50472 .41876 m
.50474 .41874 L
s
.50474 .41874 m
.50473 .41874 L
s
.50474 .41877 m
.50472 .41876 L
s
.50472 .41876 m
.50473 .41874 L
s
.50476 .41876 m
.50474 .41877 L
s
.50473 .41874 m
.50476 .41876 L
s
.50473 .41874 m
.50474 .41877 L
s
1 .092 0 r
.33827 .65326 m
.34189 .65006 L
s
1 .066 0 r
.35651 .54972 m
.35584 .54901 L
s
.35584 .54901 m
.35678 .54857 L
s
1 .003 0 r
.81282 .62711 m
.81287 .627 L
s
1 .01 0 r
.29469 .36651 m
.29432 .36609 L
s
1 .081 0 r
.25609 .39255 m
.25526 .39347 L
s
.25471 .39208 m
.25609 .39255 L
s
1 .022 0 r
.45053 .54859 m
.45077 .54881 L
s
.45029 .54876 m
.45053 .54859 L
s
.45053 .54859 m
.45058 .54859 L
s
1 .003 0 r
.81286 .627 m
.81289 .62703 L
s
.81283 .62702 m
.81286 .627 L
s
.81286 .627 m
.81287 .627 L
s
.81289 .62703 m
.81286 .62705 L
s
.81287 .627 m
.81289 .62703 L
s
.81286 .62705 m
.81283 .62702 L
s
.81283 .62702 m
.81287 .627 L
s
1 0 0 r
.76927 .34035 m
.76927 .34035 L
s
.76927 .34035 m
.76927 .34035 L
s
.76927 .34035 m
.76927 .34035 L
s
.76927 .34035 m
.76927 .34035 L
s
.76927 .34035 m
.76927 .34035 L
s
.76927 .34035 m
.76927 .34035 L
s
.76927 .34035 m
.76927 .34035 L
s
.76927 .34035 m
.76927 .34035 L
s
.76927 .34035 m
.76927 .34035 L
s
1 .003 0 r
.81287 .627 m
.81286 .62705 L
s
1 .066 0 r
.35678 .54857 m
.35651 .54972 L
s
1 .022 0 r
.45077 .54881 m
.45052 .54899 L
s
.45058 .54859 m
.45077 .54881 L
s
.45052 .54899 m
.45029 .54876 L
s
.45029 .54876 m
.45058 .54859 L
s
1 .007 0 r
.60278 .57481 m
.60286 .57452 L
s
1 .081 0 r
.25471 .39208 m
.25526 .39347 L
s
1 .022 0 r
.45058 .54859 m
.45052 .54899 L
s
1 .01 0 r
.2944 .36609 m
.29449 .36614 L
s
.2943 .3662 m
.2944 .36609 L
s
.2944 .36609 m
.29432 .36609 L
s
.29439 .36626 m
.2943 .3662 L
s
.2943 .3662 m
.29432 .36609 L
s
.29449 .36614 m
.29439 .36626 L
s
.29432 .36609 m
.29449 .36614 L
s
.29432 .36609 m
.29439 .36626 L
s
1 .036 0 r
.39269 .52251 m
.393 .52091 L
s
1 .007 0 r
.60285 .57451 m
.60292 .57458 L
s
.60277 .57457 m
.60285 .57451 L
s
.60285 .57451 m
.60286 .57452 L
s
1 .058 0 r
.39757 .67806 m
.39811 .67876 L
s
.39699 .67842 m
.39757 .67806 L
s
.39757 .67806 m
.39796 .67818 L
s
1 .007 0 r
.60292 .57458 m
.60285 .57464 L
s
.60286 .57452 m
.60292 .57458 L
s
.60285 .57464 m
.60277 .57457 L
s
.60277 .57457 m
.60286 .57452 L
s
1 .115 0 r
.30591 .68036 m
.30504 .67882 L
s
.30504 .67882 m
.30715 .67865 L
s
.30715 .67865 m
.30591 .68036 L
s
1 .007 0 r
.60286 .57452 m
.60285 .57464 L
s
1 0 0 r
.86736 .49635 m
.86736 .49633 L
s
1 .185 0 r
.25394 .65273 m
.25266 .65346 L
s
.25289 .65011 m
.25394 .65273 L
s
.25507 .65098 m
.25394 .65273 L
s
1 0 0 r
.86736 .49633 m
.86736 .49633 L
s
.86735 .49633 m
.86736 .49633 L
s
.86736 .49633 m
.86736 .49633 L
s
.86736 .49633 m
.86736 .49634 L
s
.86736 .49633 m
.86736 .49633 L
s
.86736 .49634 m
.86735 .49633 L
s
.86735 .49633 m
.86736 .49633 L
s
.86736 .49633 m
.86736 .49634 L
s
1 .058 0 r
.39811 .67876 m
.39753 .67912 L
s
.39796 .67818 m
.39811 .67876 L
s
0 .06 1 r
.18257 .47019 m
.24452 .28214 L
s
1 .185 0 r
.2516 .65083 m
.25289 .65011 L
s
.25289 .65011 m
.25507 .65098 L
s
1 .344 0 r
.24609 .46549 m
.24952 .4691 L
s
.24221 .46782 m
.24609 .46549 L
s
.24609 .46549 m
.24695 .46544 L
s
1 .001 0 r
.65727 .44403 m
.65727 .44399 L
s
.65727 .44399 m
.65728 .444 L
s
.65726 .444 m
.65727 .44399 L
s
.65727 .44399 m
.65727 .44399 L
s
.65727 .444 m
.65726 .444 L
s
.65726 .444 m
.65727 .44399 L
s
.65728 .444 m
.65727 .444 L
s
.65727 .44399 m
.65728 .444 L
s
.65727 .44399 m
.65727 .444 L
s
1 .029 0 r
.49073 .67855 m
.49151 .67745 L
s
1 .002 0 r
.44714 .3917 m
.44712 .39161 L
s
1 .058 0 r
.39753 .67912 m
.39699 .67842 L
s
.39699 .67842 m
.39796 .67818 L
s
1 .002 0 r
.44712 .39162 m
.44714 .39163 L
s
.4471 .39163 m
.44712 .39162 L
s
.44712 .39162 m
.44712 .39161 L
s
.44712 .39165 m
.4471 .39163 L
s
.4471 .39163 m
.44712 .39161 L
s
.44714 .39163 m
.44712 .39165 L
s
.44712 .39161 m
.44714 .39163 L
s
.44712 .39161 m
.44712 .39165 L
s
1 .16 0 r
.28058 .62624 m
.28799 .62116 L
s
1 .058 0 r
.39796 .67818 m
.39753 .67912 L
s
1 .003 0 r
.75536 .60008 m
.75541 .59995 L
s
.7554 .59995 m
.75543 .59998 L
s
.75536 .59998 m
.7554 .59995 L
s
.7554 .59995 m
.75541 .59995 L
s
1 0 0 r
.71178 .31318 m
.71178 .31318 L
s
.71178 .31318 m
.71178 .31318 L
s
.71178 .31318 m
.71178 .31318 L
s
.71178 .31318 m
.71178 .31318 L
s
.71178 .31318 m
.71178 .31318 L
s
.71178 .31318 m
.71178 .31318 L
s
.71178 .31318 m
.71178 .31318 L
s
.71178 .31318 m
.71178 .31318 L
s
.71178 .31318 m
.71178 .31318 L
s
1 .003 0 r
.75543 .59998 m
.7554 .60001 L
s
.75541 .59995 m
.75543 .59998 L
s
.7554 .60001 m
.75536 .59998 L
s
.75536 .59998 m
.75541 .59995 L
s
.75541 .59995 m
.7554 .60001 L
s
1 .009 0 r
.54521 .54776 m
.5453 .54736 L
s
1 .226 0 r
.26785 .54454 m
.26986 .54732 L
s
.26557 .54575 m
.26785 .54454 L
s
.26785 .54454 m
.2694 .54487 L
s
1 .068 0 r
.33502 .49542 m
.33526 .49236 L
s
1 .009 0 r
.54528 .54736 m
.54537 .54745 L
s
.54518 .54744 m
.54528 .54736 L
s
.54528 .54736 m
.5453 .54736 L
s
1 0 0 r
.80991 .46925 m
.80991 .46923 L
s
1 .036 0 r
.39295 .52091 m
.39333 .52126 L
s
.39255 .52119 m
.39295 .52091 L
s
.39295 .52091 m
.393 .52091 L
s
1 0 0 r
.80991 .46923 m
.80991 .46923 L
s
.8099 .46923 m
.80991 .46923 L
s
.80991 .46923 m
.80991 .46923 L
s
.80991 .46923 m
.80991 .46924 L
s
.80991 .46923 m
.80991 .46923 L
s
.80991 .46924 m
.8099 .46923 L
s
.8099 .46923 m
.80991 .46923 L
s
.80991 .46923 m
.80991 .46924 L
s
1 .009 0 r
.54537 .54745 m
.54528 .54752 L
s
.5453 .54736 m
.54537 .54745 L
s
.54528 .54752 m
.54518 .54744 L
s
.54518 .54744 m
.5453 .54736 L
s
1 .029 0 r
.49135 .67741 m
.49164 .67773 L
s
.49106 .67761 m
.49135 .67741 L
s
.49135 .67741 m
.49151 .67745 L
s
1 .009 0 r
.5453 .54736 m
.54528 .54752 L
s
1 .036 0 r
.39333 .52126 m
.39293 .52154 L
s
.393 .52091 m
.39333 .52126 L
s
1 .344 0 r
.24952 .4691 m
.24564 .47143 L
s
.24695 .46544 m
.24952 .4691 L
s
1 .029 0 r
.49164 .67773 m
.49135 .67793 L
s
.49151 .67745 m
.49164 .67773 L
s
1 .226 0 r
.26986 .54732 m
.26758 .54853 L
s
.2694 .54487 m
.26986 .54732 L
s
1 .001 0 r
.59971 .4169 m
.59971 .41687 L
s
.59971 .41687 m
.59972 .41687 L
s
.5997 .41687 m
.59971 .41687 L
s
.59971 .41687 m
.59971 .41687 L
s
.59971 .41688 m
.5997 .41687 L
s
.5997 .41687 m
.59971 .41687 L
s
.59972 .41687 m
.59971 .41688 L
s
.59971 .41687 m
.59972 .41687 L
s
.59971 .41687 m
.59971 .41688 L
s
1 .036 0 r
.39293 .52154 m
.39255 .52119 L
s
.39255 .52119 m
.393 .52091 L
s
1 .042 0 r
.43309 .65154 m
.43424 .64991 L
s
1 .029 0 r
.49135 .67793 m
.49106 .67761 L
s
.49106 .67761 m
.49151 .67745 L
s
.49151 .67745 m
.49135 .67793 L
s
1 .036 0 r
.393 .52091 m
.39293 .52154 L
s
1 .002 0 r
.90807 .62537 m
.90809 .6253 L
s
1 .001 0 r
.38948 .36454 m
.38945 .36448 L
s
1 .002 0 r
.90809 .6253 m
.90811 .62532 L
s
.90807 .62531 m
.90809 .6253 L
s
.90809 .6253 m
.90809 .6253 L
s
1 .001 0 r
.38945 .36448 m
.38947 .36449 L
s
.38944 .36449 m
.38945 .36448 L
s
.38945 .36448 m
.38945 .36448 L
s
.38945 .3645 m
.38944 .36449 L
s
.38944 .36449 m
.38945 .36448 L
s
1 .002 0 r
.90811 .62532 m
.90809 .62533 L
s
.90809 .6253 m
.90811 .62532 L
s
.90809 .62533 m
.90807 .62531 L
s
.90807 .62531 m
.90809 .6253 L
s
1 .001 0 r
.38947 .36449 m
.38945 .3645 L
s
.38945 .36448 m
.38947 .36449 L
s
.38945 .36448 m
.38945 .3645 L
s
1 .002 0 r
.90809 .6253 m
.90809 .62533 L
s
1 .301 0 r
.22283 .5992 m
.24113 .59228 L
s
1 .003 0 r
.69784 .57303 m
.69789 .57287 L
s
.69788 .57287 m
.69791 .57291 L
s
.69784 .5729 m
.69788 .57287 L
s
.69788 .57287 m
.69789 .57287 L
s
.69791 .57291 m
.69788 .57294 L
s
.69789 .57287 m
.69791 .57291 L
s
.69788 .57294 m
.69784 .5729 L
s
.69784 .5729 m
.69789 .57287 L
s
.69789 .57287 m
.69788 .57294 L
s
1 .012 0 r
.48758 .52067 m
.48766 .52013 L
s
1 .092 0 r
.34121 .64986 m
.34202 .65101 L
s
.34031 .65039 m
.34121 .64986 L
s
.34121 .64986 m
.34189 .65006 L
s
.34202 .65101 m
.34113 .65154 L
s
.34189 .65006 m
.34202 .65101 L
s
1 .185 0 r
.25507 .65098 m
.25266 .65346 L
s
.2516 .65083 m
.25507 .65098 L
s
.25266 .65346 m
.2516 .65083 L
s
1 .16 0 r
.27728 .46831 m
.27633 .46094 L
s
1 0 0 r
.7524 .44212 m
.7524 .44211 L
s
.7524 .44211 m
.75241 .44211 L
s
.7524 .44211 m
.7524 .44211 L
s
.7524 .44211 m
.7524 .44211 L
s
.7524 .44211 m
.7524 .44211 L
s
.7524 .44211 m
.7524 .44211 L
s
.75241 .44211 m
.7524 .44211 L
s
.7524 .44211 m
.75241 .44211 L
s
.7524 .44211 m
.7524 .44211 L
s
1 .015 0 r
.58572 .67686 m
.58606 .67627 L
s
1 .136 0 r
.29987 .51847 m
.30125 .51992 L
s
.29836 .51942 m
.29987 .51847 L
s
.29987 .51847 m
.30026 .5185 L
s
1 .012 0 r
.48765 .52013 m
.48778 .52025 L
s
.48751 .52023 m
.48765 .52013 L
s
.48765 .52013 m
.48766 .52013 L
s
.48778 .52025 m
.48764 .52035 L
s
.48766 .52013 m
.48778 .52025 L
s
.48764 .52035 m
.48751 .52023 L
s
.48751 .52023 m
.48766 .52013 L
s
1 .001 0 r
.5421 .38975 m
.54209 .38972 L
s
.5421 .38972 m
.5421 .38973 L
s
.54209 .38973 m
.5421 .38972 L
s
.5421 .38972 m
.54209 .38972 L
s
.5421 .38973 m
.54209 .38973 L
s
.54209 .38973 m
.54209 .38972 L
s
.5421 .38973 m
.5421 .38973 L
s
.54209 .38972 m
.5421 .38973 L
s
.54209 .38972 m
.5421 .38973 L
s
1 .012 0 r
.48766 .52013 m
.48764 .52035 L
s
1 .067 0 r
.37539 .6245 m
.37729 .6219 L
s
1 .596 0 r
.23193 .50201 m
.22813 .49368 L
s
.23926 .49368 m
.23193 .50201 L
s
1 .002 0 r
.8506 .59832 m
.85063 .59824 L
s
1 .001 0 r
.33176 .33736 m
.33174 .33733 L
s
1 .344 0 r
.24564 .47143 m
.24221 .46782 L
s
.24221 .46782 m
.24695 .46544 L
s
1 .001 0 r
.33174 .33733 m
.33175 .33734 L
s
.33173 .33734 m
.33174 .33733 L
s
.33174 .33733 m
.33174 .33733 L
s
.33174 .33734 m
.33173 .33734 L
s
.33173 .33734 m
.33174 .33733 L
s
.33175 .33734 m
.33174 .33734 L
s
.33174 .33733 m
.33175 .33734 L
s
.33174 .33733 m
.33174 .33734 L
s
1 .002 0 r
.85062 .59824 m
.85064 .59826 L
s
.8506 .59825 m
.85062 .59824 L
s
.85062 .59824 m
.85063 .59824 L
s
.85064 .59826 m
.85062 .59827 L
s
.85063 .59824 m
.85064 .59826 L
s
.85062 .59827 m
.8506 .59825 L
s
.8506 .59825 m
.85063 .59824 L
s
.85063 .59824 m
.85062 .59827 L
s
1 .042 0 r
.43402 .64985 m
.43444 .65033 L
s
.43358 .65014 m
.43402 .64985 L
s
.43402 .64985 m
.43424 .64991 L
s
1 0 0 r
.80699 .31116 m
.80699 .31116 L
s
.80699 .31116 m
.80699 .31116 L
s
.80699 .31116 m
.80699 .31116 L
s
.80699 .31116 m
.80699 .31116 L
s
.80699 .31116 m
.80699 .31116 L
s
.80699 .31116 m
.80699 .31116 L
s
.80699 .31116 m
.80699 .31116 L
s
.80699 .31116 m
.80699 .31116 L
s
.80699 .31116 m
.80699 .31116 L
s
1 .136 0 r
.30125 .51992 m
.29973 .52086 L
s
.30026 .5185 m
.30125 .51992 L
s
1 .092 0 r
.34113 .65154 m
.34031 .65039 L
s
.34031 .65039 m
.34189 .65006 L
s
1 .015 0 r
.58599 .67625 m
.58614 .67641 L
s
.58584 .67636 m
.58599 .67625 L
s
.58599 .67625 m
.58606 .67627 L
s
1 .004 0 r
.64027 .54594 m
.64031 .54576 L
s
1 .042 0 r
.43444 .65033 m
.434 .65062 L
s
.43424 .64991 m
.43444 .65033 L
s
1 .015 0 r
.58614 .67641 m
.58599 .67652 L
s
.58606 .67627 m
.58614 .67641 L
s
1 .092 0 r
.34189 .65006 m
.34113 .65154 L
s
1 .596 0 r
.22813 .49368 m
.23926 .49368 L
s
1 .015 0 r
.58599 .67652 m
.58584 .67636 L
s
.58584 .67636 m
.58606 .67627 L
s
.58606 .67627 m
.58599 .67652 L
s
1 .004 0 r
.6403 .54576 m
.64034 .5458 L
s
.64026 .5458 m
.6403 .54576 L
s
.6403 .54576 m
.64031 .54576 L
s
.64034 .5458 m
.6403 .54584 L
s
.64031 .54576 m
.64034 .5458 L
s
.6403 .54584 m
.64026 .5458 L
s
.64026 .5458 m
.64031 .54576 L
s
.64031 .54576 m
.6403 .54584 L
s
1 .018 0 r
.4299 .49356 m
.42993 .49275 L
s
1 .226 0 r
.26758 .54853 m
.26557 .54575 L
s
.26557 .54575 m
.2694 .54487 L
s
1 .042 0 r
.434 .65062 m
.43358 .65014 L
s
.43358 .65014 m
.43424 .64991 L
s
.43424 .64991 m
.434 .65062 L
s
1 .529 0 r
.2195 .44117 m
.20137 .41805 L
s
1 .136 0 r
.29973 .52086 m
.29836 .51942 L
s
.29836 .51942 m
.30026 .5185 L
s
1 .068 0 r
.33524 .49238 m
.33595 .49301 L
s
.33447 .49293 m
.33524 .49238 L
s
.33524 .49238 m
.33526 .49236 L
s
1 .226 0 r
.2694 .54487 m
.26758 .54853 L
s
1 0 0 r
.69484 .41497 m
.69484 .41496 L
s
.69484 .41496 m
.69484 .41496 L
s
.69484 .41496 m
.69484 .41496 L
s
.69484 .41496 m
.69484 .41496 L
s
.69484 .41496 m
.69484 .41496 L
s
.69484 .41496 m
.69484 .41496 L
s
.69484 .41496 m
.69484 .41496 L
s
.69484 .41496 m
.69484 .41496 L
s
.69484 .41496 m
.69484 .41496 L
s
1 .02 0 r
.52808 .64982 m
.52851 .64901 L
s
1 0 0 r
.48443 .36257 m
.48443 .36255 L
s
.48443 .36255 m
.48443 .36255 L
s
.48442 .36255 m
.48443 .36255 L
s
.48443 .36255 m
.48443 .36255 L
s
.48443 .36256 m
.48442 .36255 L
s
.48442 .36255 m
.48443 .36255 L
s
.48443 .36255 m
.48443 .36256 L
s
.48443 .36255 m
.48443 .36255 L
s
.48443 .36255 m
.48443 .36256 L
s
1 .068 0 r
.33595 .49301 m
.33518 .49356 L
s
.33526 .49236 m
.33595 .49301 L
s
1 .118 0 r
.31764 .59743 m
.32127 .59291 L
s
1 .018 0 r
.42993 .49276 m
.43012 .49292 L
s
.42973 .49291 m
.42993 .49276 L
s
.42993 .49276 m
.42993 .49275 L
s
1 .068 0 r
.33518 .49356 m
.33447 .49293 L
s
.33447 .49293 m
.33526 .49236 L
s
1 .018 0 r
.43012 .49292 m
.42992 .49307 L
s
.42993 .49275 m
.43012 .49292 L
s
1 .136 0 r
.30026 .5185 m
.29973 .52086 L
s
1 .344 0 r
.24695 .46544 m
.24564 .47143 L
s
1 .002 0 r
.79308 .57124 m
.7931 .57115 L
s
1 .018 0 r
.42992 .49307 m
.42973 .49291 L
s
.42973 .49291 m
.42993 .49275 L
s
1 .002 0 r
.79309 .57115 m
.79312 .57117 L
s
.79307 .57117 m
.79309 .57115 L
s
.79309 .57115 m
.7931 .57115 L
s
.79312 .57117 m
.7931 .57119 L
s
.7931 .57115 m
.79312 .57117 L
s
.7931 .57119 m
.79307 .57117 L
s
.79307 .57117 m
.7931 .57115 L
s
.7931 .57115 m
.7931 .57119 L
s
1 .018 0 r
.42993 .49275 m
.42992 .49307 L
s
1 .005 0 r
.58264 .51883 m
.58267 .51861 L
s
1 .068 0 r
.33526 .49236 m
.33518 .49356 L
s
1 .02 0 r
.52842 .64899 m
.52863 .64921 L
s
.52821 .64914 m
.52842 .64899 L
s
.52842 .64899 m
.52851 .64901 L
s
1 .005 0 r
.58266 .51861 m
.58272 .51866 L
s
.58261 .51866 m
.58266 .51861 L
s
.58266 .51861 m
.58267 .51861 L
s
.58272 .51866 m
.58266 .5187 L
s
.58267 .51861 m
.58272 .51866 L
s
.58266 .5187 m
.58261 .51866 L
s
.58261 .51866 m
.58267 .51861 L
s
1 .029 0 r
.37217 .46643 m
.37202 .46509 L
s
1 .02 0 r
.52863 .64921 m
.52842 .64935 L
s
.52851 .64901 m
.52863 .64921 L
s
1 .005 0 r
.58267 .51861 m
.58266 .5187 L
s
1 .02 0 r
.52842 .64935 m
.52821 .64914 L
s
.52821 .64914 m
.52851 .64901 L
s
1 0 0 r
.8477 .44022 m
.8477 .44021 L
s
.8477 .44021 m
.84771 .44021 L
s
.8477 .44021 m
.8477 .44021 L
s
.8477 .44021 m
.8477 .44021 L
s
.8477 .44021 m
.8477 .44021 L
s
.8477 .44021 m
.8477 .44021 L
s
.84771 .44021 m
.8477 .44021 L
s
.8477 .44021 m
.84771 .44021 L
s
.8477 .44021 m
.8477 .44021 L
s
1 .02 0 r
.52851 .64901 m
.52842 .64935 L
s
1 .008 0 r
.68088 .67516 m
.68105 .67483 L
s
1 .16 0 r
.2866 .62074 m
.28788 .62282 L
s
.28513 .62153 m
.2866 .62074 L
s
.2866 .62074 m
.28799 .62116 L
s
1 0 0 r
.63723 .38779 m
.63722 .38778 L
s
.63722 .38778 m
.63723 .38779 L
s
.63722 .38779 m
.63722 .38778 L
s
.63722 .38778 m
.63722 .38778 L
s
.63722 .38779 m
.63722 .38779 L
s
.63722 .38779 m
.63722 .38778 L
s
1 .16 0 r
.28788 .62282 m
.28642 .62362 L
s
.28799 .62116 m
.28788 .62282 L
s
1 0 0 r
.63723 .38779 m
.63722 .38779 L
s
.63722 .38778 m
.63723 .38779 L
s
.63722 .38778 m
.63722 .38779 L
s
1 .029 0 r
.47038 .62275 m
.47097 .62158 L
s
1 .067 0 r
.37694 .62182 m
.37759 .62259 L
s
.37624 .62225 m
.37694 .62182 L
s
.37694 .62182 m
.37729 .6219 L
s
1 .008 0 r
.68101 .67482 m
.6811 .67491 L
s
.68093 .67488 m
.68101 .67482 L
s
.68101 .67482 m
.68105 .67483 L
s
.6811 .67491 m
.68101 .67497 L
s
.68105 .67483 m
.6811 .67491 L
s
1 0 0 r
.42671 .33536 m
.42671 .33536 L
s
.42671 .33536 m
.42671 .33536 L
s
.42671 .33536 m
.42671 .33536 L
s
.42671 .33536 m
.42671 .33536 L
s
.42671 .33536 m
.42671 .33536 L
s
.42671 .33536 m
.42671 .33536 L
s
.42671 .33536 m
.42671 .33536 L
s
.42671 .33536 m
.42671 .33536 L
s
.42671 .33536 m
.42671 .33536 L
s
1 .008 0 r
.68101 .67497 m
.68093 .67488 L
s
.68093 .67488 m
.68105 .67483 L
s
.68105 .67483 m
.68101 .67497 L
s
1 .067 0 r
.37759 .62259 m
.37689 .62302 L
s
.37729 .6219 m
.37759 .62259 L
s
1 .24 0 r
.25984 .57034 m
.26879 .56154 L
s
1 .002 0 r
.7355 .54413 m
.73552 .54403 L
s
.73551 .54403 m
.73554 .54405 L
s
.73549 .54405 m
.73551 .54403 L
s
.73551 .54403 m
.73552 .54403 L
s
.73554 .54405 m
.73551 .54407 L
s
.73552 .54403 m
.73554 .54405 L
s
.73551 .54407 m
.73549 .54405 L
s
.73549 .54405 m
.73552 .54403 L
s
.73552 .54403 m
.73551 .54407 L
s
1 .006 0 r
.52495 .4917 m
.52497 .49142 L
s
1 .067 0 r
.37689 .62302 m
.37624 .62225 L
s
.37624 .62225 m
.37729 .6219 L
s
1 .029 0 r
.37206 .4651 m
.37237 .46535 L
s
.37174 .46536 m
.37206 .4651 L
s
.37206 .4651 m
.37202 .46509 L
s
1 .056 0 r
.31437 .43926 m
.31349 .4367 L
s
1 .006 0 r
.52496 .49142 m
.52503 .49148 L
s
.5249 .49148 m
.52496 .49142 L
s
.52496 .49142 m
.52497 .49142 L
s
1 .067 0 r
.37729 .6219 m
.37689 .62302 L
s
1 .029 0 r
.37204 .46561 m
.37174 .46536 L
s
.37174 .46536 m
.37202 .46509 L
s
.37237 .46535 m
.37204 .46561 L
s
.37202 .46509 m
.37237 .46535 L
s
1 .006 0 r
.52503 .49148 m
.52496 .49153 L
s
.52497 .49142 m
.52503 .49148 L
s
.52496 .49153 m
.5249 .49148 L
s
.5249 .49148 m
.52497 .49142 L
s
.52497 .49142 m
.52496 .49153 L
s
1 0 0 r
.79014 .41304 m
.79014 .41303 L
s
.79014 .41303 m
.79014 .41303 L
s
.79014 .41303 m
.79014 .41303 L
s
.79014 .41303 m
.79014 .41303 L
s
.79014 .41304 m
.79014 .41303 L
s
.79014 .41303 m
.79014 .41303 L
s
.79014 .41303 m
.79014 .41304 L
s
.79014 .41303 m
.79014 .41303 L
s
.79014 .41303 m
.79014 .41304 L
s
1 .029 0 r
.37202 .46509 m
.37204 .46561 L
s
1 .01 0 r
.62323 .64809 m
.62342 .64767 L
s
1 .029 0 r
.47085 .62155 m
.47115 .62186 L
s
.47055 .62176 m
.47085 .62155 L
s
.47085 .62155 m
.47097 .62158 L
s
1 0 0 r
.57955 .36059 m
.57955 .36058 L
s
.57955 .36058 m
.57955 .36058 L
s
.57955 .36059 m
.57955 .36058 L
s
.57955 .36058 m
.57955 .36058 L
s
.57955 .36059 m
.57955 .36059 L
s
.57955 .36059 m
.57955 .36058 L
s
.57955 .36058 m
.57955 .36059 L
s
.57955 .36058 m
.57955 .36058 L
s
.57955 .36058 m
.57955 .36059 L
s
1 .029 0 r
.47115 .62186 m
.47084 .62207 L
s
.47097 .62158 m
.47115 .62186 L
s
1 .045 0 r
.41262 .59566 m
.41348 .59382 L
s
1 .029 0 r
.47084 .62207 m
.47055 .62176 L
s
.47055 .62176 m
.47097 .62158 L
s
1 .001 0 r
.88848 .56944 m
.88849 .56939 L
s
1 0 0 r
.36893 .30813 m
.36893 .30813 L
s
.36893 .30813 m
.36893 .30813 L
s
.36893 .30813 m
.36893 .30813 L
s
.36893 .30813 m
.36893 .30813 L
s
.36893 .30813 m
.36893 .30813 L
s
.36893 .30813 m
.36893 .30813 L
s
.36893 .30813 m
.36893 .30813 L
s
.36893 .30813 m
.36893 .30813 L
s
.36893 .30813 m
.36893 .30813 L
s
1 .029 0 r
.47097 .62158 m
.47084 .62207 L
s
1 .01 0 r
.62338 .64766 m
.62349 .64777 L
s
.62328 .64774 m
.62338 .64766 L
s
.62338 .64766 m
.62342 .64767 L
s
1 .001 0 r
.88849 .56939 m
.8885 .5694 L
s
.88848 .5694 m
.88849 .56939 L
s
.88849 .56939 m
.88849 .56939 L
s
.8885 .5694 m
.88849 .56941 L
s
.88849 .56939 m
.8885 .5694 L
s
.88849 .56941 m
.88848 .5694 L
s
.88848 .5694 m
.88849 .56939 L
s
.88849 .56939 m
.88849 .56941 L
s
1 .01 0 r
.62349 .64777 m
.62339 .64785 L
s
.62342 .64767 m
.62349 .64777 L
s
1 .629 0 r
.20198 .54322 m
.23864 .52689 L
s
1 .01 0 r
.62339 .64785 m
.62328 .64774 L
s
.62328 .64774 m
.62342 .64767 L
s
.62342 .64767 m
.62339 .64785 L
s
1 .16 0 r
.28642 .62362 m
.28513 .62153 L
s
.28513 .62153 m
.28799 .62116 L
s
1 .002 0 r
.67786 .51699 m
.67788 .51689 L
s
1 .16 0 r
.28799 .62116 m
.28642 .62362 L
s
1 .002 0 r
.67788 .51689 m
.6779 .51691 L
s
.67785 .51691 m
.67788 .51689 L
s
.67788 .51689 m
.67788 .51689 L
s
.6779 .51691 m
.67788 .51693 L
s
.67788 .51689 m
.6779 .51691 L
s
.67788 .51693 m
.67785 .51691 L
s
.67785 .51691 m
.67788 .51689 L
s
.67788 .51689 m
.67788 .51693 L
s
1 .301 0 r
.23943 .59524 m
.23726 .59636 L
s
.23766 .59098 m
.23943 .59524 L
s
.24113 .59228 m
.23943 .59524 L
s
1 .008 0 r
.46721 .46454 m
.46719 .46417 L
s
1 .005 0 r
.77621 .67345 m
.7763 .67326 L
s
1 .128 0 r
.25653 .41207 m
.25175 .40656 L
s
1 .301 0 r
.23549 .59209 m
.23766 .59098 L
s
.23766 .59098 m
.24113 .59228 L
s
1 .615 0 r
.23626 .51658 m
.2315 .51877 L
s
.23233 .50797 m
.23626 .51658 L
s
.2391 .51014 m
.23626 .51658 L
s
1 .008 0 r
.46719 .46418 m
.46728 .46424 L
s
.46711 .46425 m
.46719 .46418 L
s
.46719 .46418 m
.46719 .46417 L
s
1 0 0 r
.73252 .38584 m
.73252 .38583 L
s
.73252 .38583 m
.73252 .38583 L
s
.73252 .38583 m
.73252 .38583 L
s
.73252 .38583 m
.73252 .38583 L
s
.73252 .38583 m
.73252 .38583 L
s
.73252 .38583 m
.73252 .38583 L
s
.73252 .38583 m
.73252 .38583 L
s
.73252 .38583 m
.73252 .38583 L
s
.73252 .38583 m
.73252 .38583 L
s
1 .008 0 r
.46719 .46431 m
.46711 .46425 L
s
.46711 .46425 m
.46719 .46417 L
s
.46728 .46424 m
.46719 .46431 L
s
.46719 .46417 m
.46728 .46424 L
s
1 .005 0 r
.77628 .67326 m
.77633 .6733 L
s
.77623 .67329 m
.77628 .67326 L
s
.77628 .67326 m
.7763 .67326 L
s
1 .008 0 r
.46719 .46417 m
.46719 .46431 L
s
1 .005 0 r
.77633 .6733 m
.77628 .67334 L
s
.7763 .67326 m
.77633 .6733 L
s
.77628 .67334 m
.77623 .67329 L
s
.77623 .67329 m
.7763 .67326 L
s
1 .013 0 r
.56553 .621 m
.56575 .62044 L
s
1 .005 0 r
.7763 .67326 m
.77628 .67334 L
s
1 0 0 r
.52183 .33336 m
.52183 .33336 L
s
.52183 .33336 m
.52183 .33336 L
s
.52183 .33336 m
.52183 .33336 L
s
.52183 .33336 m
.52183 .33336 L
s
.52183 .33336 m
.52183 .33336 L
s
.52183 .33336 m
.52183 .33336 L
s
.52183 .33336 m
.52183 .33336 L
s
.52183 .33336 m
.52183 .33336 L
s
.52183 .33336 m
.52183 .33336 L
s
1 .615 0 r
.22756 .51014 m
.23233 .50797 L
s
.23233 .50797 m
.2391 .51014 L
s
1 .076 0 r
.35481 .56854 m
.35619 .56533 L
s
1 .001 0 r
.83089 .54231 m
.83091 .54226 L
s
.8309 .54226 m
.83092 .54227 L
s
.83089 .54227 m
.8309 .54226 L
s
.8309 .54226 m
.83091 .54226 L
s
.83092 .54227 m
.8309 .54228 L
s
.83091 .54226 m
.83092 .54227 L
s
.8309 .54228 m
.83089 .54227 L
s
.83089 .54227 m
.83091 .54226 L
s
.83091 .54226 m
.8309 .54228 L
s
1 .013 0 r
.56571 .62043 m
.56585 .62057 L
s
.56557 .62054 m
.56571 .62043 L
s
.56571 .62043 m
.56575 .62044 L
s
.56585 .62057 m
.56571 .62068 L
s
.56575 .62044 m
.56585 .62057 L
s
1 .003 0 r
.62017 .48983 m
.62018 .48972 L
s
1 .013 0 r
.56571 .62068 m
.56557 .62054 L
s
.56557 .62054 m
.56575 .62044 L
s
1 .045 0 r
.41332 .59379 m
.41378 .59426 L
s
.41284 .59411 m
.41332 .59379 L
s
.41332 .59379 m
.41348 .59382 L
s
1 .056 0 r
.3137 .43674 m
.31426 .43716 L
s
.31308 .43727 m
.3137 .43674 L
s
.3137 .43674 m
.31349 .4367 L
s
1 .013 0 r
.56575 .62044 m
.56571 .62068 L
s
1 .118 0 r
.3206 .59276 m
.32172 .59415 L
s
.31937 .59348 m
.3206 .59276 L
s
.3206 .59276 m
.32127 .59291 L
s
1 .003 0 r
.62018 .48972 m
.62021 .48974 L
s
.62015 .48974 m
.62018 .48972 L
s
.62018 .48972 m
.62018 .48972 L
s
.62021 .48974 m
.62018 .48976 L
s
.62018 .48972 m
.62021 .48974 L
s
.62018 .48976 m
.62015 .48974 L
s
.62015 .48974 m
.62018 .48972 L
s
.62018 .48972 m
.62018 .48976 L
s
1 .045 0 r
.41378 .59426 m
.4133 .59458 L
s
.41348 .59382 m
.41378 .59426 L
s
1 .011 0 r
.40942 .43735 m
.4093 .43684 L
s
1 .056 0 r
.31364 .43769 m
.31308 .43727 L
s
.31308 .43727 m
.31349 .4367 L
s
1 .192 0 r
.24235 .6726 m
.25431 .66847 L
s
1 .118 0 r
.32172 .59415 m
.32049 .59487 L
s
.32127 .59291 m
.32172 .59415 L
s
1 .045 0 r
.4133 .59458 m
.41284 .59411 L
s
.41284 .59411 m
.41348 .59382 L
s
1 .006 0 r
.71855 .64636 m
.71865 .64613 L
s
1 .056 0 r
.31426 .43716 m
.31364 .43769 L
s
.31349 .4367 m
.31426 .43716 L
s
1 .045 0 r
.41348 .59382 m
.4133 .59458 L
s
1 0 0 r
.67484 .35861 m
.67484 .35861 L
s
.67484 .35861 m
.67484 .35861 L
s
.67484 .35861 m
.67484 .35861 L
s
.67484 .35861 m
.67484 .35861 L
s
.67484 .35861 m
.67484 .35861 L
s
.67484 .35861 m
.67484 .35861 L
s
.67484 .35861 m
.67484 .35861 L
s
.67484 .35861 m
.67484 .35861 L
s
.67484 .35861 m
.67484 .35861 L
s
1 .16 0 r
.27661 .46103 m
.27826 .46241 L
s
.27478 .46242 m
.27661 .46103 L
s
.27661 .46103 m
.27633 .46094 L
s
1 .011 0 r
.40933 .43685 m
.40944 .43694 L
s
.40921 .43695 m
.40933 .43685 L
s
.40933 .43685 m
.4093 .43684 L
s
1 .006 0 r
.71863 .64613 m
.71869 .64618 L
s
.71857 .64617 m
.71863 .64613 L
s
.71863 .64613 m
.71865 .64613 L
s
1 .019 0 r
.50777 .59389 m
.50804 .5931 L
s
1 .006 0 r
.71869 .64618 m
.71863 .64623 L
s
.71865 .64613 m
.71869 .64618 L
s
.71863 .64623 m
.71857 .64617 L
s
.71857 .64617 m
.71865 .64613 L
s
1 .011 0 r
.40932 .43704 m
.40921 .43695 L
s
.40921 .43695 m
.4093 .43684 L
s
1 .056 0 r
.31349 .4367 m
.31364 .43769 L
s
1 .011 0 r
.40944 .43694 m
.40932 .43704 L
s
.4093 .43684 m
.40944 .43694 L
s
1 .006 0 r
.71865 .64613 m
.71863 .64623 L
s
1 .011 0 r
.4093 .43684 m
.40932 .43704 L
s
1 0 0 r
.46404 .3061 m
.46404 .3061 L
s
.46404 .3061 m
.46404 .3061 L
s
.46404 .3061 m
.46404 .3061 L
s
.46404 .3061 m
.46404 .3061 L
s
.46404 .3061 m
.46404 .3061 L
s
.46404 .3061 m
.46404 .3061 L
s
.46404 .3061 m
.46404 .3061 L
s
.46404 .3061 m
.46404 .3061 L
s
.46404 .3061 m
.46404 .3061 L
s
1 .152 0 r
.29695 .5414 m
.29952 .53489 L
s
1 .001 0 r
.77325 .51515 m
.77326 .5151 L
s
1 .468 0 r
.20845 .4042 m
.21269 .40704 L
s
.20354 .40935 m
.20845 .4042 L
s
.20845 .4042 m
.2049 .40406 L
s
1 .001 0 r
.77326 .5151 m
.77328 .51511 L
s
.77325 .51511 m
.77326 .5151 L
s
.77326 .5151 m
.77326 .5151 L
s
.77328 .51511 m
.77326 .51512 L
s
.77326 .5151 m
.77328 .51511 L
s
.77326 .51512 m
.77325 .51511 L
s
.77325 .51511 m
.77326 .5151 L
s
.77326 .5151 m
.77326 .51512 L
s
1 .118 0 r
.32049 .59487 m
.31937 .59348 L
s
.31937 .59348 m
.32127 .59291 L
s
1 .003 0 r
.56243 .46265 m
.56242 .46251 L
s
.56242 .46252 m
.56246 .46254 L
s
.56239 .46254 m
.56242 .46252 L
s
.56242 .46252 m
.56242 .46251 L
s
1 .019 0 r
.50799 .59309 m
.50818 .59328 L
s
.50779 .59323 m
.50799 .59309 L
s
.50799 .59309 m
.50804 .5931 L
s
1 .003 0 r
.56242 .46257 m
.56239 .46254 L
s
.56239 .46254 m
.56242 .46251 L
s
.56246 .46254 m
.56242 .46257 L
s
.56242 .46251 m
.56246 .46254 L
s
.56242 .46251 m
.56242 .46257 L
s
1 .019 0 r
.50818 .59328 m
.50799 .59342 L
s
.50804 .5931 m
.50818 .59328 L
s
1 .118 0 r
.32127 .59291 m
.32049 .59487 L
s
1 .003 0 r
.8717 .67175 m
.87176 .67163 L
s
1 .016 0 r
.35156 .41014 m
.35123 .4094 L
s
1 .019 0 r
.50799 .59342 m
.50779 .59323 L
s
.50779 .59323 m
.50804 .5931 L
s
1 .16 0 r
.27643 .4638 m
.27478 .46242 L
s
.27478 .46242 m
.27633 .46094 L
s
.27826 .46241 m
.27643 .4638 L
s
.27633 .46094 m
.27826 .46241 L
s
1 .003 0 r
.87174 .67163 m
.87178 .67165 L
s
.87171 .67165 m
.87174 .67163 L
s
.87174 .67163 m
.87176 .67163 L
s
1 .019 0 r
.50804 .5931 m
.50799 .59342 L
s
1 .003 0 r
.87178 .67165 m
.87175 .67168 L
s
.87176 .67163 m
.87178 .67165 L
s
1 0 0 r
.82798 .38388 m
.82798 .38388 L
s
.82798 .38388 m
.82798 .38388 L
s
.82798 .38388 m
.82798 .38388 L
s
.82798 .38388 m
.82798 .38388 L
s
.82798 .38388 m
.82798 .38388 L
s
.82798 .38388 m
.82798 .38388 L
s
.82798 .38388 m
.82798 .38388 L
s
.82798 .38388 m
.82798 .38388 L
s
.82798 .38388 m
.82798 .38388 L
s
1 .003 0 r
.87175 .67168 m
.87171 .67165 L
s
.87171 .67165 m
.87176 .67163 L
s
.87176 .67163 m
.87175 .67168 L
s
1 .007 0 r
.66085 .61925 m
.66095 .61896 L
s
1 0 0 r
.61711 .33135 m
.61711 .33135 L
s
.61711 .33135 m
.61711 .33135 L
s
.61711 .33135 m
.61711 .33135 L
s
.61711 .33135 m
.61711 .33135 L
s
.61711 .33135 m
.61711 .33135 L
s
.61711 .33135 m
.61711 .33135 L
s
.61711 .33135 m
.61711 .33135 L
s
.61711 .33135 m
.61711 .33135 L
s
.61711 .33135 m
.61711 .33135 L
s
1 .027 0 r
.44995 .56674 m
.45028 .56556 L
s
1 .007 0 r
.66093 .61896 m
.661 .61903 L
s
.66086 .61901 m
.66093 .61896 L
s
.66093 .61896 m
.66095 .61896 L
s
.661 .61903 m
.66093 .61908 L
s
.66095 .61896 m
.661 .61903 L
s
.66093 .61908 m
.66086 .61901 L
s
.66086 .61901 m
.66095 .61896 L
s
.66095 .61896 m
.66093 .61908 L
s
1 .016 0 r
.3513 .40941 m
.35146 .40952 L
s
.35113 .40957 m
.3513 .40941 L
s
.3513 .40941 m
.35123 .4094 L
s
.35129 .40968 m
.35113 .40957 L
s
.35113 .40957 m
.35123 .4094 L
s
1 .396 0 r
.23902 .51423 m
.24528 .49701 L
s
1 .016 0 r
.35146 .40952 m
.35129 .40968 L
s
.35123 .4094 m
.35146 .40952 L
s
.35123 .4094 m
.35129 .40968 L
s
1 .001 0 r
.71556 .48797 m
.71557 .48791 L
s
.71556 .48791 m
.71558 .48792 L
s
.71555 .48792 m
.71556 .48791 L
s
.71556 .48791 m
.71557 .48791 L
s
.71558 .48792 m
.71557 .48793 L
s
.71557 .48791 m
.71558 .48792 L
s
.71557 .48793 m
.71555 .48792 L
s
.71555 .48792 m
.71557 .48791 L
s
.71557 .48791 m
.71557 .48793 L
s
1 .468 0 r
.20777 .4122 m
.20354 .40935 L
s
.20354 .40935 m
.2049 .40406 L
s
1 .076 0 r
.35595 .5653 m
.35672 .56611 L
s
.35511 .56584 m
.35595 .5653 L
s
.35595 .5653 m
.35619 .56533 L
s
1 .16 0 r
.27633 .46094 m
.27643 .4638 L
s
1 .003 0 r
.50463 .43544 m
.5046 .43528 L
s
1 .099 0 r
.33742 .67089 m
.34132 .66748 L
s
1 .003 0 r
.50461 .43529 m
.50464 .43531 L
s
.50457 .43532 m
.50461 .43529 L
s
.50461 .43529 m
.5046 .43528 L
s
.50461 .43534 m
.50457 .43532 L
s
.50457 .43532 m
.5046 .43528 L
s
.50464 .43531 m
.50461 .43534 L
s
.5046 .43528 m
.50464 .43531 L
s
.5046 .43528 m
.50461 .43534 L
s
1 .301 0 r
.23726 .59636 m
.23549 .59209 L
s
.24113 .59228 m
.23726 .59636 L
s
1 .003 0 r
.81404 .64463 m
.8141 .6445 L
s
1 .076 0 r
.35672 .56611 m
.35589 .56665 L
s
.35619 .56533 m
.35672 .56611 L
s
1 .024 0 r
.29365 .3829 m
.29273 .38184 L
s
1 .301 0 r
.23549 .59209 m
.24113 .59228 L
s
1 .003 0 r
.81409 .64449 m
.81412 .64453 L
s
.81405 .64452 m
.81409 .64449 L
s
.81409 .64449 m
.8141 .6445 L
s
1 0 0 r
.7703 .35662 m
.7703 .35662 L
s
.7703 .35662 m
.7703 .35662 L
s
.7703 .35662 m
.7703 .35662 L
s
.7703 .35662 m
.7703 .35662 L
s
.7703 .35662 m
.7703 .35662 L
s
.7703 .35662 m
.7703 .35662 L
s
.7703 .35662 m
.7703 .35662 L
s
.7703 .35662 m
.7703 .35662 L
s
.7703 .35662 m
.7703 .35662 L
s
1 .003 0 r
.81412 .64453 m
.81409 .64455 L
s
.8141 .6445 m
.81412 .64453 L
s
.81409 .64455 m
.81405 .64452 L
s
.81405 .64452 m
.8141 .6445 L
s
.8141 .6445 m
.81409 .64455 L
s
1 .009 0 r
.60308 .59211 m
.60319 .59174 L
s
1 .027 0 r
.45022 .56556 m
.45051 .56583 L
s
.44992 .56577 m
.45022 .56556 L
s
.45022 .56556 m
.45028 .56556 L
s
1 .076 0 r
.35589 .56665 m
.35511 .56584 L
s
.35511 .56584 m
.35619 .56533 L
s
1 0 0 r
.55932 .30407 m
.55932 .30407 L
s
.55932 .30407 m
.55932 .30407 L
s
.55932 .30407 m
.55932 .30407 L
s
.55932 .30407 m
.55932 .30407 L
s
.55932 .30407 m
.55932 .30407 L
s
.55932 .30407 m
.55932 .30407 L
s
.55932 .30407 m
.55932 .30407 L
s
.55932 .30407 m
.55932 .30407 L
s
.55932 .30407 m
.55932 .30407 L
s
1 .027 0 r
.45051 .56583 m
.45021 .56604 L
s
.45028 .56556 m
.45051 .56583 L
s
.45021 .56604 m
.44992 .56577 L
s
.44992 .56577 m
.45028 .56556 L
s
1 .044 0 r
.39208 .53957 m
.39246 .53762 L
s
1 .009 0 r
.60317 .59174 m
.60326 .59182 L
s
.60308 .5918 m
.60317 .59174 L
s
.60317 .59174 m
.60319 .59174 L
s
1 .027 0 r
.45028 .56556 m
.45021 .56604 L
s
1 .001 0 r
.86881 .5133 m
.86882 .51327 L
s
1 .009 0 r
.60326 .59182 m
.60317 .59189 L
s
.60319 .59174 m
.60326 .59182 L
s
1 .001 0 r
.86882 .51327 m
.86883 .51328 L
s
.86881 .51328 m
.86882 .51327 L
s
.86882 .51327 m
.86882 .51327 L
s
.86883 .51328 m
.86882 .51328 L
s
.86882 .51327 m
.86883 .51328 L
s
.86882 .51328 m
.86881 .51328 L
s
.86881 .51328 m
.86882 .51327 L
s
.86882 .51327 m
.86882 .51328 L
s
1 .009 0 r
.60317 .59189 m
.60308 .5918 L
s
.60308 .5918 m
.60319 .59174 L
s
1 .076 0 r
.35619 .56533 m
.35589 .56665 L
s
1 .009 0 r
.60319 .59174 m
.60317 .59189 L
s
0 .053 1 r
.18105 .48703 m
.24326 .29925 L
s
1 .192 0 r
.25313 .67028 m
.25179 .67105 L
s
.25203 .66754 m
.25313 .67028 L
s
.25431 .66847 m
.25313 .67028 L
s
1 .001 0 r
.65781 .46076 m
.65781 .4607 L
s
1 .024 0 r
.29293 .38185 m
.29315 .38198 L
s
.29268 .38213 m
.29293 .38185 L
s
.29293 .38185 m
.29273 .38184 L
s
1 .001 0 r
.65781 .4607 m
.65782 .46071 L
s
.6578 .46071 m
.65781 .4607 L
s
.65781 .4607 m
.65781 .4607 L
s
.65781 .46072 m
.6578 .46071 L
s
.6578 .46071 m
.65781 .4607 L
s
.65782 .46071 m
.65781 .46072 L
s
.65781 .4607 m
.65782 .46071 L
s
.65781 .4607 m
.65781 .46072 L
s
1 .192 0 r
.25069 .66831 m
.25203 .66754 L
s
.25203 .66754 m
.25431 .66847 L
s
1 .024 0 r
.2929 .38226 m
.29268 .38213 L
s
.29268 .38213 m
.29273 .38184 L
s
1 .128 0 r
.25279 .40657 m
.25393 .4073 L
s
.25148 .40803 m
.25279 .40657 L
s
.25279 .40657 m
.25175 .40656 L
s
1 .004 0 r
.44677 .4082 m
.44672 .40803 L
s
1 .024 0 r
.29315 .38198 m
.2929 .38226 L
s
.29273 .38184 m
.29315 .38198 L
s
.29273 .38184 m
.2929 .38226 L
s
1 .168 0 r
.27948 .64377 m
.28732 .63844 L
s
1 .004 0 r
.44673 .40803 m
.44677 .40806 L
s
.44669 .40807 m
.44673 .40803 L
s
.44673 .40803 m
.44672 .40803 L
s
.44673 .40809 m
.44669 .40807 L
s
.44669 .40807 m
.44672 .40803 L
s
.44677 .40806 m
.44673 .40809 L
s
.44672 .40803 m
.44677 .40806 L
s
.44672 .40803 m
.44673 .40809 L
s
1 .128 0 r
.25263 .40876 m
.25148 .40803 L
s
.25148 .40803 m
.25175 .40656 L
s
1 .004 0 r
.75633 .61749 m
.75639 .61733 L
s
1 0 0 r
.71256 .32934 m
.71256 .32934 L
s
.71256 .32934 m
.71256 .32934 L
s
.71256 .32934 m
.71256 .32934 L
s
.71256 .32934 m
.71256 .32934 L
s
.71256 .32934 m
.71256 .32934 L
s
.71256 .32934 m
.71256 .32934 L
s
.71256 .32934 m
.71256 .32934 L
s
.71256 .32934 m
.71256 .32934 L
s
.71256 .32934 m
.71256 .32934 L
s
1 .004 0 r
.75637 .61733 m
.75642 .61737 L
s
.75634 .61736 m
.75637 .61733 L
s
.75637 .61733 m
.75639 .61733 L
s
.75642 .61737 m
.75638 .6174 L
s
.75639 .61733 m
.75642 .61737 L
s
.75638 .6174 m
.75634 .61736 L
s
.75634 .61736 m
.75639 .61733 L
s
.75639 .61733 m
.75638 .6174 L
s
1 .011 0 r
.54526 .56494 m
.54537 .56445 L
s
1 .082 0 r
.33416 .51238 m
.33445 .50868 L
s
1 .001 0 r
.81112 .48609 m
.81112 .48606 L
s
.81112 .48606 m
.81113 .48607 L
s
.81111 .48607 m
.81112 .48606 L
s
.81112 .48606 m
.81112 .48606 L
s
.81113 .48607 m
.81112 .48608 L
s
.81112 .48606 m
.81113 .48607 L
s
.81112 .48608 m
.81111 .48607 L
s
.81111 .48607 m
.81112 .48606 L
s
.81112 .48606 m
.81112 .48608 L
s
1 .373 0 r
.24524 .481 m
.24899 .48495 L
s
.241 .48356 m
.24524 .481 L
s
.24524 .481 m
.24618 .48098 L
s
1 .011 0 r
.54535 .56445 m
.54547 .56456 L
s
.54523 .56454 m
.54535 .56445 L
s
.54535 .56445 m
.54537 .56445 L
s
.54547 .56456 m
.54535 .56465 L
s
.54537 .56445 m
.54547 .56456 L
s
.54535 .56465 m
.54523 .56454 L
s
.54523 .56454 m
.54537 .56445 L
s
.54537 .56445 m
.54535 .56465 L
s
1 .001 0 r
.6 .43352 m
.6 .43346 L
s
1 .128 0 r
.25393 .4073 m
.25263 .40876 L
s
.25175 .40656 m
.25393 .4073 L
s
1 .001 0 r
.6 .43346 m
.60001 .43347 L
s
.59999 .43347 m
.6 .43346 L
s
.6 .43346 m
.6 .43346 L
s
.6 .43348 m
.59999 .43347 L
s
.59999 .43347 m
.6 .43346 L
s
.60001 .43347 m
.6 .43348 L
s
.6 .43346 m
.60001 .43347 L
s
.6 .43346 m
.6 .43348 L
s
1 .044 0 r
.3924 .53762 m
.39287 .53806 L
s
.39191 .53797 m
.3924 .53762 L
s
.3924 .53762 m
.39246 .53762 L
s
1 .24 0 r
.26714 .56117 m
.26928 .56414 L
s
.2647 .56247 m
.26714 .56117 L
s
.26714 .56117 m
.26879 .56154 L
s
1 .047 0 r
.43266 .66918 m
.43394 .66737 L
s
1 .002 0 r
.9097 .6429 m
.90974 .64281 L
s
1 .004 0 r
.38886 .38093 m
.38876 .38075 L
s
1 .044 0 r
.39287 .53806 m
.39237 .53841 L
s
.39246 .53762 m
.39287 .53806 L
s
1 .002 0 r
.90973 .64281 m
.90975 .64283 L
s
.90971 .64283 m
.90973 .64281 L
s
.90973 .64281 m
.90974 .64281 L
s
.90975 .64283 m
.90973 .64285 L
s
.90974 .64281 m
.90975 .64283 L
s
.90973 .64285 m
.90971 .64283 L
s
.90971 .64283 m
.90974 .64281 L
s
.90974 .64281 m
.90973 .64285 L
s
1 .31 0 r
.22148 .61661 m
.24043 .60951 L
s
1 .468 0 r
.21269 .40704 m
.20777 .4122 L
s
.2049 .40406 m
.21269 .40704 L
s
1 .128 0 r
.25175 .40656 m
.25263 .40876 L
s
1 .004 0 r
.38878 .38076 m
.38882 .38078 L
s
.38874 .3808 m
.38878 .38076 L
s
.38878 .38076 m
.38876 .38075 L
s
.38878 .38082 m
.38874 .3808 L
s
.38874 .3808 m
.38876 .38075 L
s
1 .044 0 r
.39237 .53841 m
.39191 .53797 L
s
.39191 .53797 m
.39246 .53762 L
s
1 .004 0 r
.38882 .38078 m
.38878 .38082 L
s
.38876 .38075 m
.38882 .38078 L
s
.38876 .38075 m
.38878 .38082 L
s
1 .24 0 r
.26928 .56414 m
.26685 .56544 L
s
.26879 .56154 m
.26928 .56414 L
s
1 .004 0 r
.69856 .59033 m
.69862 .59014 L
s
1 0 0 r
.65477 .30204 m
.65477 .30204 L
s
.65477 .30204 m
.65477 .30204 L
s
.65477 .30204 m
.65477 .30204 L
s
.65477 .30204 m
.65477 .30204 L
s
.65477 .30204 m
.65477 .30204 L
s
.65477 .30204 m
.65477 .30204 L
s
.65477 .30204 m
.65477 .30204 L
s
.65477 .30204 m
.65477 .30204 L
s
.65477 .30204 m
.65477 .30204 L
s
1 .044 0 r
.39246 .53762 m
.39237 .53841 L
s
1 .004 0 r
.69861 .59014 m
.69865 .59018 L
s
.69856 .59017 m
.69861 .59014 L
s
.69861 .59014 m
.69862 .59014 L
s
.69865 .59018 m
.69861 .59021 L
s
.69862 .59014 m
.69865 .59018 L
s
.69861 .59021 m
.69856 .59017 L
s
.69856 .59017 m
.69862 .59014 L
s
.69862 .59014 m
.69861 .59021 L
s
1 .016 0 r
.48739 .53775 m
.48749 .53705 L
s
1 .099 0 r
.34058 .66726 m
.34147 .66849 L
s
.33962 .66783 m
.34058 .66726 L
s
.34058 .66726 m
.34132 .66748 L
s
1 .187 0 r
.27617 .48516 m
.27505 .4766 L
s
1 .099 0 r
.34147 .66849 m
.3405 .66907 L
s
.34132 .66748 m
.34147 .66849 L
s
1 .001 0 r
.75336 .45886 m
.75336 .45883 L
s
.75336 .45883 m
.75337 .45883 L
s
.75335 .45883 m
.75336 .45883 L
s
.75336 .45883 m
.75336 .45883 L
s
1 .192 0 r
.25431 .66847 m
.25179 .67105 L
s
.25069 .66831 m
.25431 .66847 L
s
1 .001 0 r
.75336 .45884 m
.75335 .45883 L
s
.75335 .45883 m
.75336 .45883 L
s
.75337 .45883 m
.75336 .45884 L
s
.75336 .45883 m
.75337 .45883 L
s
.75336 .45883 m
.75336 .45884 L
s
1 .192 0 r
.25179 .67105 m
.25069 .66831 L
s
1 .373 0 r
.24899 .48495 m
.24475 .48752 L
s
.24618 .48098 m
.24899 .48495 L
s
1 .001 0 r
.54214 .40625 m
.54213 .4062 L
s
1 .016 0 r
.48747 .53705 m
.48764 .5372 L
s
.4873 .53718 m
.48747 .53705 L
s
.48747 .53705 m
.48749 .53705 L
s
1 .001 0 r
.54213 .4062 m
.54215 .40621 L
s
.54212 .40621 m
.54213 .4062 L
s
.54213 .4062 m
.54213 .4062 L
s
.54213 .40622 m
.54212 .40621 L
s
.54212 .40621 m
.54213 .4062 L
s
.54215 .40621 m
.54213 .40622 L
s
.54213 .4062 m
.54215 .40621 L
s
.54213 .4062 m
.54213 .40622 L
s
1 .074 0 r
.37471 .64203 m
.3768 .63919 L
s
1 .016 0 r
.48764 .5372 m
.48747 .53733 L
s
.48749 .53705 m
.48764 .5372 L
s
.48747 .53733 m
.4873 .53718 L
s
.4873 .53718 m
.48749 .53705 L
s
.48749 .53705 m
.48747 .53733 L
s
1 .002 0 r
.85199 .61573 m
.85202 .61564 L
s
1 .003 0 r
.33089 .35364 m
.33075 .35349 L
s
1 .002 0 r
.85201 .61564 m
.85204 .61566 L
s
.85199 .61566 m
.85201 .61564 L
s
.85201 .61564 m
.85202 .61564 L
s
.85204 .61566 m
.85201 .61568 L
s
.85202 .61564 m
.85204 .61566 L
s
.85201 .61568 m
.85199 .61566 L
s
.85199 .61566 m
.85202 .61564 L
s
.85202 .61564 m
.85201 .61568 L
s
1 0 0 r
.80818 .32733 m
.80818 .32733 L
s
.80818 .32733 m
.80818 .32733 L
s
.80818 .32733 m
.80818 .32733 L
s
.80818 .32733 m
.80818 .32733 L
s
.80818 .32733 m
.80818 .32733 L
s
.80818 .32733 m
.80818 .32733 L
s
.80818 .32733 m
.80818 .32733 L
s
.80818 .32733 m
.80818 .32733 L
s
.80818 .32733 m
.80818 .32733 L
s
1 .003 0 r
.33078 .35349 m
.33081 .35351 L
s
.33075 .35353 m
.33078 .35349 L
s
.33078 .35349 m
.33075 .35349 L
s
.33078 .35355 m
.33075 .35353 L
s
.33075 .35353 m
.33075 .35349 L
s
.33081 .35351 m
.33078 .35355 L
s
.33075 .35349 m
.33081 .35351 L
s
.33075 .35349 m
.33078 .35355 L
s
1 .468 0 r
.2049 .40406 m
.20777 .4122 L
s
1 .005 0 r
.64074 .56314 m
.64079 .5629 L
s
1 .152 0 r
.29909 .53485 m
.30063 .53647 L
s
.29738 .53592 m
.29909 .53485 L
s
.29909 .53485 m
.29952 .53489 L
s
1 .047 0 r
.4337 .66731 m
.43416 .66784 L
s
.43321 .66763 m
.4337 .66731 L
s
.4337 .66731 m
.43394 .66737 L
s
.43416 .66784 m
.43368 .66816 L
s
.43394 .66737 m
.43416 .66784 L
s
1 .099 0 r
.3405 .66907 m
.33962 .66783 L
s
.33962 .66783 m
.34132 .66748 L
s
1 .005 0 r
.64078 .5629 m
.64084 .56295 L
s
.64072 .56295 m
.64078 .5629 L
s
.64078 .5629 m
.64079 .5629 L
s
1 .023 0 r
.42945 .51053 m
.4295 .50947 L
s
1 .005 0 r
.64084 .56295 m
.64078 .563 L
s
.64079 .5629 m
.64084 .56295 L
s
.64078 .563 m
.64072 .56295 L
s
.64072 .56295 m
.64079 .5629 L
s
.64079 .5629 m
.64078 .563 L
s
1 .615 0 r
.2315 .51877 m
.22756 .51014 L
s
.2391 .51014 m
.2315 .51877 L
s
1 .099 0 r
.34132 .66748 m
.3405 .66907 L
s
1 .569 0 r
.21813 .45791 m
.19851 .4331 L
s
1 .047 0 r
.43368 .66816 m
.43321 .66763 L
s
.43321 .66763 m
.43394 .66737 L
s
1 .152 0 r
.30063 .53647 m
.29893 .53754 L
s
.29952 .53489 m
.30063 .53647 L
s
1 .001 0 r
.69555 .4316 m
.69555 .43157 L
s
1 .047 0 r
.43394 .66737 m
.43368 .66816 L
s
1 .001 0 r
.69555 .43157 m
.69556 .43157 L
s
.69554 .43157 m
.69555 .43157 L
s
.69555 .43157 m
.69555 .43157 L
s
.69555 .43158 m
.69554 .43157 L
s
.69554 .43157 m
.69555 .43157 L
s
.69556 .43157 m
.69555 .43158 L
s
.69555 .43157 m
.69556 .43157 L
s
.69555 .43157 m
.69555 .43158 L
s
1 .023 0 r
.52806 .66747 m
.52855 .66655 L
s
1 .615 0 r
.22756 .51014 m
.2391 .51014 L
s
1 .001 0 r
.48422 .37896 m
.48421 .37892 L
s
1 .24 0 r
.26685 .56544 m
.2647 .56247 L
s
.2647 .56247 m
.26879 .56154 L
s
1 .001 0 r
.48421 .37892 m
.48422 .37892 L
s
.4842 .37893 m
.48421 .37892 L
s
.48421 .37892 m
.48421 .37892 L
s
.48421 .37893 m
.4842 .37893 L
s
.4842 .37893 m
.48421 .37892 L
s
.48422 .37892 m
.48421 .37893 L
s
.48421 .37892 m
.48422 .37892 L
s
.48421 .37892 m
.48421 .37893 L
s
1 .127 0 r
.31671 .61485 m
.32064 .60999 L
s
1 .002 0 r
.79421 .58854 m
.79424 .58844 L
s
1 .082 0 r
.33442 .5087 m
.33528 .50948 L
s
.33349 .50937 m
.33442 .5087 L
s
.33442 .5087 m
.33445 .50868 L
s
1 .002 0 r
.79424 .58844 m
.79426 .58846 L
s
.79421 .58846 m
.79424 .58844 L
s
.79424 .58844 m
.79424 .58844 L
s
.79426 .58846 m
.79424 .58848 L
s
.79424 .58844 m
.79426 .58846 L
s
1 .023 0 r
.42949 .50947 m
.42974 .50969 L
s
.42923 .50967 m
.42949 .50947 L
s
.42949 .50947 m
.4295 .50947 L
s
1 .002 0 r
.79424 .58848 m
.79421 .58846 L
s
.79421 .58846 m
.79424 .58844 L
s
1 .373 0 r
.24475 .48752 m
.241 .48356 L
s
.241 .48356 m
.24618 .48098 L
s
1 .002 0 r
.79424 .58844 m
.79424 .58848 L
s
1 0 0 r
.75039 .3 m
.75039 .3 L
s
.75039 .3 m
.75039 .3 L
s
.75039 .3 m
.75039 .3 L
s
.75039 .3 m
.75039 .3 L
s
.75039 .3 m
.75039 .3 L
s
.75039 .3 m
.75039 .3 L
s
.75039 .3 m
.75039 .3 L
s
.75039 .3 m
.75039 .3 L
s
.75039 .3 m
.75039 .3 L
s
1 .24 0 r
.26879 .56154 m
.26685 .56544 L
s
1 .152 0 r
.29893 .53754 m
.29738 .53592 L
s
.29738 .53592 m
.29952 .53489 L
s
1 .007 0 r
.58286 .53592 m
.5829 .53562 L
s
1 .023 0 r
.42974 .50969 m
.42948 .50989 L
s
.4295 .50947 m
.42974 .50969 L
s
.42948 .50989 m
.42923 .50967 L
s
.42923 .50967 m
.4295 .50947 L
s
.4295 .50947 m
.42948 .50989 L
s
1 .039 0 r
.37147 .48328 m
.37127 .4815 L
s
1 .007 0 r
.58289 .53562 m
.58296 .53569 L
s
.58282 .53568 m
.58289 .53562 L
s
.58289 .53562 m
.5829 .53562 L
s
1 .082 0 r
.33528 .50948 m
.33435 .51015 L
s
.33445 .50868 m
.33528 .50948 L
s
1 .023 0 r
.52846 .66652 m
.5287 .66677 L
s
.52822 .66669 m
.52846 .66652 L
s
.52846 .66652 m
.52855 .66655 L
s
1 .007 0 r
.58296 .53569 m
.58289 .53574 L
s
.5829 .53562 m
.58296 .53569 L
s
.58289 .53574 m
.58282 .53568 L
s
.58282 .53568 m
.5829 .53562 L
s
.5829 .53562 m
.58289 .53574 L
s
1 0 0 r
.84908 .45696 m
.84908 .45694 L
s
1 .023 0 r
.5287 .66677 m
.52846 .66694 L
s
.52855 .66655 m
.5287 .66677 L
s
1 0 0 r
.84908 .45694 m
.84908 .45695 L
s
.84908 .45695 m
.84908 .45694 L
s
.84908 .45694 m
.84908 .45694 L
s
.84908 .45695 m
.84908 .45695 L
s
.84908 .45695 m
.84908 .45694 L
s
.84908 .45695 m
.84908 .45695 L
s
.84908 .45694 m
.84908 .45695 L
s
.84908 .45694 m
.84908 .45695 L
s
1 .082 0 r
.33435 .51015 m
.33349 .50937 L
s
.33349 .50937 m
.33445 .50868 L
s
1 .023 0 r
.52846 .66694 m
.52822 .66669 L
s
.52822 .66669 m
.52855 .66655 L
s
.52855 .66655 m
.52846 .66694 L
s
1 .152 0 r
.29952 .53489 m
.29893 .53754 L
s
1 0 0 r
.63768 .40431 m
.63768 .40428 L
s
.63768 .40428 m
.63769 .40429 L
s
.63768 .40429 m
.63768 .40428 L
s
.63768 .40428 m
.63768 .40428 L
s
.63768 .40429 m
.63768 .40429 L
s
.63768 .40429 m
.63768 .40428 L
s
.63769 .40429 m
.63768 .40429 L
s
.63768 .40428 m
.63769 .40429 L
s
.63768 .40428 m
.63768 .40429 L
s
1 .033 0 r
.47011 .64029 m
.47078 .63895 L
s
1 .168 0 r
.28584 .63798 m
.2872 .64018 L
s
.28429 .63883 m
.28584 .63798 L
s
.28584 .63798 m
.28732 .63844 L
s
1 .001 0 r
.42625 .35165 m
.42623 .35161 L
s
1 .082 0 r
.33445 .50868 m
.33435 .51015 L
s
1 .168 0 r
.2872 .64018 m
.28565 .64103 L
s
.28732 .63844 m
.2872 .64018 L
s
1 .001 0 r
.42623 .35162 m
.42624 .35162 L
s
.42623 .35162 m
.42623 .35162 L
s
.42623 .35162 m
.42623 .35161 L
s
.42623 .35163 m
.42623 .35162 L
s
.42623 .35162 m
.42623 .35161 L
s
.42624 .35162 m
.42623 .35163 L
s
.42623 .35161 m
.42624 .35162 L
s
.42623 .35161 m
.42623 .35163 L
s
1 .252 0 r
.25865 .58765 m
.26808 .57845 L
s
1 .074 0 r
.37641 .63909 m
.37713 .63994 L
s
.37564 .63957 m
.37641 .63909 L
s
.37641 .63909 m
.3768 .63919 L
s
1 .003 0 r
.73638 .56133 m
.73641 .5612 L
s
.7364 .5612 m
.73644 .56123 L
s
.73638 .56123 m
.7364 .5612 L
s
.7364 .5612 m
.73641 .5612 L
s
1 .074 0 r
.37713 .63994 m
.37636 .64043 L
s
.3768 .63919 m
.37713 .63994 L
s
1 .003 0 r
.73644 .56123 m
.73641 .56125 L
s
.73641 .5612 m
.73644 .56123 L
s
.73641 .56125 m
.73638 .56123 L
s
.73638 .56123 m
.73641 .5612 L
s
.73641 .5612 m
.73641 .56125 L
s
1 .373 0 r
.24618 .48098 m
.24475 .48752 L
s
1 .008 0 r
.52492 .50867 m
.52494 .50829 L
s
1 .075 0 r
.31342 .45601 m
.31223 .45256 L
s
1 .008 0 r
.52494 .50829 m
.52503 .50837 L
s
.52484 .50836 m
.52494 .50829 L
s
.52494 .50829 m
.52494 .50829 L
s
1 0 0 r
.79126 .42967 m
.79126 .42966 L
s
.79126 .42966 m
.79127 .42966 L
s
.79126 .42966 m
.79126 .42966 L
s
.79126 .42966 m
.79126 .42966 L
s
.79126 .42966 m
.79126 .42966 L
s
.79126 .42966 m
.79126 .42966 L
s
.79127 .42966 m
.79126 .42966 L
s
.79126 .42966 m
.79127 .42966 L
s
.79126 .42966 m
.79126 .42966 L
s
1 .074 0 r
.37636 .64043 m
.37564 .63957 L
s
.37564 .63957 m
.3768 .63919 L
s
1 .008 0 r
.52503 .50837 m
.52493 .50844 L
s
.52494 .50829 m
.52503 .50837 L
s
.52493 .50844 m
.52484 .50836 L
s
.52484 .50836 m
.52494 .50829 L
s
.52494 .50829 m
.52493 .50844 L
s
1 .012 0 r
.62363 .66575 m
.62385 .66526 L
s
1 .039 0 r
.37133 .48151 m
.37174 .48185 L
s
.37089 .48186 m
.37133 .48151 L
s
.37133 .48151 m
.37127 .4815 L
s
1 .074 0 r
.3768 .63919 m
.37636 .64043 L
s
1 0 0 r
.57976 .37699 m
.57976 .37698 L
s
.57976 .37698 m
.57976 .37698 L
s
.57975 .37698 m
.57976 .37698 L
s
.57976 .37698 m
.57976 .37698 L
s
.57976 .37698 m
.57975 .37698 L
s
.57975 .37698 m
.57976 .37698 L
s
.57976 .37698 m
.57976 .37698 L
s
.57976 .37698 m
.57976 .37698 L
s
.57976 .37698 m
.57976 .37698 L
s
1 .033 0 r
.47065 .63892 m
.47099 .63928 L
s
.4703 .63916 m
.47065 .63892 L
s
.47065 .63892 m
.47078 .63895 L
s
1 .051 0 r
.4121 .61309 m
.41308 .611 L
s
1 .039 0 r
.3713 .48219 m
.37089 .48186 L
s
.37089 .48186 m
.37127 .4815 L
s
.37174 .48185 m
.3713 .48219 L
s
.37127 .4815 m
.37174 .48185 L
s
1 .033 0 r
.47099 .63928 m
.47064 .63952 L
s
.47078 .63895 m
.47099 .63928 L
s
1 .001 0 r
.89003 .58676 m
.89005 .58669 L
s
1 0 0 r
.36822 .3243 m
.36821 .32429 L
s
.36821 .32429 m
.36821 .32429 L
s
.36821 .3243 m
.36821 .32429 L
s
.36821 .32429 m
.36821 .32429 L
s
.36821 .3243 m
.36821 .3243 L
s
.36821 .3243 m
.36821 .32429 L
s
.36821 .32429 m
.36821 .3243 L
s
.36821 .32429 m
.36821 .32429 L
s
.36821 .32429 m
.36821 .3243 L
s
1 .001 0 r
.89004 .58669 m
.89006 .58671 L
s
.89003 .58671 m
.89004 .58669 L
s
.89004 .58669 m
.89005 .58669 L
s
.89006 .58671 m
.89005 .58672 L
s
.89005 .58669 m
.89006 .58671 L
s
.89005 .58672 m
.89003 .58671 L
s
.89003 .58671 m
.89005 .58669 L
s
.89005 .58669 m
.89005 .58672 L
s
1 .012 0 r
.62381 .66525 m
.62393 .66538 L
s
.62368 .66534 m
.62381 .66525 L
s
.62381 .66525 m
.62385 .66526 L
s
1 .033 0 r
.47064 .63952 m
.4703 .63916 L
s
.4703 .63916 m
.47078 .63895 L
s
1 .64 0 r
.20053 .56042 m
.23796 .54388 L
s
1 .039 0 r
.37127 .4815 m
.3713 .48219 L
s
1 .012 0 r
.62393 .66538 m
.62381 .66547 L
s
.62385 .66526 m
.62393 .66538 L
s
.62381 .66547 m
.62368 .66534 L
s
.62368 .66534 m
.62385 .66526 L
s
1 .033 0 r
.47078 .63895 m
.47064 .63952 L
s
1 .003 0 r
.6785 .53408 m
.67852 .53394 L
s
1 .012 0 r
.62385 .66526 m
.62381 .66547 L
s
1 .003 0 r
.67851 .53394 m
.67855 .53397 L
s
.67848 .53397 m
.67851 .53394 L
s
.67851 .53394 m
.67852 .53394 L
s
.67855 .53397 m
.67852 .534 L
s
.67852 .53394 m
.67855 .53397 L
s
.67852 .534 m
.67848 .53397 L
s
.67848 .53397 m
.67852 .53394 L
s
.67852 .53394 m
.67852 .534 L
s
1 .011 0 r
.46693 .4814 m
.46689 .48088 L
s
1 .168 0 r
.28565 .64103 m
.28429 .63883 L
s
.28429 .63883 m
.28732 .63844 L
s
1 .31 0 r
.23867 .61255 m
.23642 .61373 L
s
.23683 .60814 m
.23867 .61255 L
s
.24043 .60951 m
.23867 .61255 L
s
1 .168 0 r
.28732 .63844 m
.28565 .64103 L
s
1 .171 0 r
.25532 .42871 m
.24893 .42139 L
s
1 0 0 r
.73339 .40236 m
.73339 .40235 L
s
.73339 .40235 m
.73339 .40235 L
s
.73339 .40235 m
.73339 .40235 L
s
.73339 .40235 m
.73339 .40235 L
s
.73339 .40235 m
.73339 .40235 L
s
.73339 .40235 m
.73339 .40235 L
s
.73339 .40235 m
.73339 .40235 L
s
.73339 .40235 m
.73339 .40235 L
s
.73339 .40235 m
.73339 .40235 L
s
1 .31 0 r
.23458 .60932 m
.23683 .60814 L
s
.23683 .60814 m
.24043 .60951 L
s
1 .011 0 r
.4669 .48088 m
.46702 .48098 L
s
.46677 .48098 m
.4669 .48088 L
s
.4669 .48088 m
.46689 .48088 L
s
1 .016 0 r
.56567 .63855 m
.56594 .63789 L
s
1 .011 0 r
.4669 .48108 m
.46677 .48098 L
s
.46677 .48098 m
.46689 .48088 L
s
.46702 .48098 m
.4669 .48108 L
s
.46689 .48088 m
.46702 .48098 L
s
1 .629 0 r
.23572 .53346 m
.23083 .53575 L
s
.23169 .52461 m
.23572 .53346 L
s
.23864 .52689 m
.23572 .53346 L
s
1 .011 0 r
.46689 .48088 m
.4669 .48108 L
s
1 0 0 r
.52178 .34965 m
.52178 .34964 L
s
.52178 .34964 m
.52178 .34964 L
s
.52177 .34964 m
.52178 .34964 L
s
.52178 .34964 m
.52178 .34964 L
s
.52178 .34964 m
.52177 .34964 L
s
.52177 .34964 m
.52178 .34964 L
s
.52178 .34964 m
.52178 .34964 L
s
.52178 .34964 m
.52178 .34964 L
s
.52178 .34964 m
.52178 .34964 L
s
1 .086 0 r
.35404 .58586 m
.35559 .58228 L
s
1 .002 0 r
.8322 .55952 m
.83221 .55945 L
s
.83221 .55945 m
.83223 .55946 L
s
.83219 .55946 m
.83221 .55945 L
s
.83221 .55945 m
.83221 .55945 L
s
.83223 .55946 m
.83221 .55947 L
s
.83221 .55945 m
.83223 .55946 L
s
.83221 .55947 m
.83219 .55946 L
s
.83219 .55946 m
.83221 .55945 L
s
.83221 .55945 m
.83221 .55947 L
s
1 .629 0 r
.22678 .52688 m
.23169 .52461 L
s
.23169 .52461 m
.23864 .52689 L
s
1 .004 0 r
.62056 .50681 m
.62057 .50665 L
s
1 .016 0 r
.56588 .63788 m
.56605 .63805 L
s
.56572 .63801 m
.56588 .63788 L
s
.56588 .63788 m
.56594 .63789 L
s
.56605 .63805 m
.56589 .63817 L
s
.56594 .63789 m
.56605 .63805 L
s
.56589 .63817 m
.56572 .63801 L
s
.56572 .63801 m
.56594 .63789 L
s
1 .004 0 r
.62056 .50665 m
.62061 .50668 L
s
.62053 .50668 m
.62056 .50665 L
s
.62056 .50665 m
.62057 .50665 L
s
.62061 .50668 m
.62057 .50671 L
s
.62057 .50665 m
.62061 .50668 L
s
.62057 .50671 m
.62053 .50668 L
s
.62053 .50668 m
.62057 .50665 L
s
.62057 .50665 m
.62057 .50671 L
s
1 .016 0 r
.56594 .63789 m
.56589 .63817 L
s
1 .017 0 r
.40888 .4541 m
.40871 .45334 L
s
1 .051 0 r
.41289 .61096 m
.41342 .61151 L
s
.41235 .61133 m
.41289 .61096 L
s
.41289 .61096 m
.41308 .611 L
s
1 .127 0 r
.31991 .60982 m
.32112 .61132 L
s
.31858 .61061 m
.31991 .60982 L
s
.31991 .60982 m
.32064 .60999 L
s
1 .051 0 r
.41342 .61151 m
.41287 .61188 L
s
.41308 .611 m
.41342 .61151 L
s
1 .007 0 r
.71937 .66403 m
.71948 .66376 L
s
1 0 0 r
.67546 .37502 m
.67546 .37501 L
s
.67546 .37501 m
.67547 .37501 L
s
.67546 .37501 m
.67546 .37501 L
s
.67546 .37501 m
.67546 .37501 L
s
.67546 .37501 m
.67546 .37501 L
s
.67546 .37501 m
.67546 .37501 L
s
.67547 .37501 m
.67546 .37501 L
s
.67546 .37501 m
.67547 .37501 L
s
.67546 .37501 m
.67546 .37501 L
s
1 .051 0 r
.41287 .61188 m
.41235 .61133 L
s
.41235 .61133 m
.41308 .611 L
s
1 .022 0 r
.50766 .61132 m
.50798 .6104 L
s
1 .127 0 r
.32112 .61132 m
.31979 .61211 L
s
.32064 .60999 m
.32112 .61132 L
s
1 .007 0 r
.71946 .66375 m
.71953 .66382 L
s
.71939 .6638 m
.71946 .66375 L
s
.71946 .66375 m
.71948 .66376 L
s
.71953 .66382 m
.71946 .66387 L
s
.71948 .66376 m
.71953 .66382 L
s
.71946 .66387 m
.71939 .6638 L
s
.71939 .6638 m
.71948 .66376 L
s
.71948 .66376 m
.71946 .66387 L
s
1 0 0 r
.46374 .32228 m
.46374 .32228 L
s
.46374 .32228 m
.46374 .32228 L
s
.46374 .32228 m
.46374 .32228 L
s
.46374 .32228 m
.46374 .32228 L
s
.46374 .32228 m
.46374 .32228 L
s
.46374 .32228 m
.46374 .32228 L
s
.46374 .32228 m
.46374 .32228 L
s
.46374 .32228 m
.46374 .32228 L
s
.46374 .32228 m
.46374 .32228 L
s
1 .075 0 r
.3125 .4526 m
.31327 .45318 L
s
.31166 .45332 m
.3125 .4526 L
s
.3125 .4526 m
.31223 .45256 L
s
1 .051 0 r
.41308 .611 m
.41287 .61188 L
s
1 .017 0 r
.40875 .45335 m
.40892 .45348 L
s
.40856 .4535 m
.40875 .45335 L
s
.40875 .45335 m
.40871 .45334 L
s
1 .166 0 r
.29592 .55861 m
.29874 .55154 L
s
1 .017 0 r
.40874 .45363 m
.40856 .4535 L
s
.40856 .4535 m
.40871 .45334 L
s
.40892 .45348 m
.40874 .45363 L
s
.40871 .45334 m
.40892 .45348 L
s
1 .002 0 r
.77431 .53225 m
.77432 .53217 L
s
1 .017 0 r
.40871 .45334 m
.40874 .45363 L
s
1 .002 0 r
.77432 .53217 m
.77434 .53219 L
s
.7743 .53219 m
.77432 .53217 L
s
.77432 .53217 m
.77432 .53217 L
s
.77434 .53219 m
.77432 .5322 L
s
.77432 .53217 m
.77434 .53219 L
s
.77432 .5322 m
.7743 .53219 L
s
.7743 .53219 m
.77432 .53217 L
s
.77432 .53217 m
.77432 .5322 L
s
1 .075 0 r
.31243 .4539 m
.31166 .45332 L
s
.31166 .45332 m
.31223 .45256 L
s
1 .004 0 r
.56256 .47952 m
.56255 .47932 L
s
1 .075 0 r
.31327 .45318 m
.31243 .4539 L
s
.31223 .45256 m
.31327 .45318 L
s
1 .004 0 r
.56255 .47932 m
.5626 .47936 L
s
.56251 .47936 m
.56255 .47932 L
s
.56255 .47932 m
.56255 .47932 L
s
.56255 .4794 m
.56251 .47936 L
s
.56251 .47936 m
.56255 .47932 L
s
.5626 .47936 m
.56255 .4794 L
s
.56255 .47932 m
.5626 .47936 L
s
.56255 .47932 m
.56255 .4794 L
s
1 .026 0 r
.35077 .42678 m
.35023 .42559 L
s
1 .022 0 r
.50792 .61039 m
.50815 .61061 L
s
.50768 .61056 m
.50792 .61039 L
s
.50792 .61039 m
.50798 .6104 L
s
.50815 .61061 m
.50792 .61078 L
s
.50798 .6104 m
.50815 .61061 L
s
1 0 0 r
.82927 .4004 m
.82927 .4004 L
s
1 .127 0 r
.31979 .61211 m
.31858 .61061 L
s
.31858 .61061 m
.32064 .60999 L
s
1 0 0 r
.82927 .4004 m
.82927 .4004 L
s
.82927 .4004 m
.82927 .4004 L
s
.82927 .4004 m
.82927 .4004 L
s
.82927 .4004 m
.82927 .4004 L
s
.82927 .4004 m
.82927 .4004 L
s
.82927 .4004 m
.82927 .4004 L
s
.82927 .4004 m
.82927 .4004 L
s
.82927 .4004 m
.82927 .4004 L
s
1 .187 0 r
.27538 .47669 m
.27731 .47831 L
s
.27323 .47832 m
.27538 .47669 L
s
.27538 .47669 m
.27505 .4766 L
s
1 .022 0 r
.50792 .61078 m
.50768 .61056 L
s
.50768 .61056 m
.50798 .6104 L
s
1 .075 0 r
.31223 .45256 m
.31243 .4539 L
s
1 .008 0 r
.66141 .63681 m
.66153 .63646 L
s
1 .022 0 r
.50798 .6104 m
.50792 .61078 L
s
1 0 0 r
.61748 .34765 m
.61748 .34765 L
s
.61748 .34765 m
.61748 .34765 L
s
.61748 .34765 m
.61748 .34765 L
s
.61748 .34765 m
.61748 .34765 L
s
.61748 .34765 m
.61748 .34765 L
s
.61748 .34765 m
.61748 .34765 L
s
.61748 .34765 m
.61748 .34765 L
s
.61748 .34765 m
.61748 .34765 L
s
.61748 .34765 m
.61748 .34765 L
s
1 .127 0 r
.32064 .60999 m
.31979 .61211 L
s
1 .032 0 r
.44959 .58407 m
.44998 .58268 L
s
1 .008 0 r
.66151 .63646 m
.6616 .63654 L
s
.66142 .63652 m
.66151 .63646 L
s
.66151 .63646 m
.66153 .63646 L
s
.6616 .63654 m
.66151 .6366 L
s
.66153 .63646 m
.6616 .63654 L
s
1 0 0 r
.40565 .29489 m
.40565 .29489 L
s
.40565 .29489 m
.40565 .29489 L
s
.40565 .29489 m
.40565 .29489 L
s
.40565 .29489 m
.40565 .29489 L
s
.40565 .29489 m
.40565 .29489 L
s
.40565 .29489 m
.40565 .29489 L
s
.40565 .29489 m
.40565 .29489 L
s
.40565 .29489 m
.40565 .29489 L
s
.40565 .29489 m
.40565 .29489 L
s
1 .008 0 r
.66151 .6366 m
.66142 .63652 L
s
.66142 .63652 m
.66153 .63646 L
s
.66153 .63646 m
.66151 .6366 L
s
1 .413 0 r
.23774 .53133 m
.24428 .51344 L
s
1 .002 0 r
.71636 .50495 m
.71637 .50487 L
s
.71637 .50487 m
.71639 .50489 L
s
.71635 .50489 m
.71637 .50487 L
s
.71637 .50487 m
.71637 .50487 L
s
.71639 .50489 m
.71637 .5049 L
s
.71637 .50487 m
.71639 .50489 L
s
.71637 .5049 m
.71635 .50489 L
s
.71635 .50489 m
.71637 .50487 L
s
.71637 .50487 m
.71637 .5049 L
s
1 .026 0 r
.35035 .4256 m
.35061 .42578 L
s
.35006 .42586 m
.35035 .4256 L
s
.35035 .4256 m
.35023 .42559 L
s
1 .005 0 r
.5045 .45219 m
.50447 .45195 L
s
1 .026 0 r
.35032 .42605 m
.35006 .42586 L
s
.35006 .42586 m
.35023 .42559 L
s
.35061 .42578 m
.35032 .42605 L
s
.35023 .42559 m
.35061 .42578 L
s
1 .187 0 r
.27516 .47994 m
.27323 .47832 L
s
.27323 .47832 m
.27505 .4766 L
s
1 .005 0 r
.50448 .45196 m
.50453 .452 L
s
.50442 .452 m
.50448 .45196 L
s
.50448 .45196 m
.50447 .45195 L
s
1 .187 0 r
.27731 .47831 m
.27516 .47994 L
s
.27505 .4766 m
.27731 .47831 L
s
1 .004 0 r
.81528 .66231 m
.81534 .66214 L
s
1 .005 0 r
.50448 .45205 m
.50442 .452 L
s
.50442 .452 m
.50447 .45195 L
s
1 .044 0 r
.29261 .39943 m
.29093 .39753 L
s
1 .005 0 r
.50453 .452 m
.50448 .45205 L
s
.50447 .45195 m
.50453 .452 L
s
1 .026 0 r
.35023 .42559 m
.35032 .42605 L
s
1 .005 0 r
.50447 .45195 m
.50448 .45205 L
s
1 .086 0 r
.35531 .58223 m
.35619 .58315 L
s
.35437 .58284 m
.35531 .58223 L
s
.35531 .58223 m
.35559 .58228 L
s
1 0 0 r
.77134 .37304 m
.77134 .37304 L
s
.77134 .37304 m
.77134 .37304 L
s
.77134 .37304 m
.77134 .37304 L
s
.77134 .37304 m
.77134 .37304 L
s
.77134 .37304 m
.77134 .37304 L
s
.77134 .37304 m
.77134 .37304 L
s
.77134 .37304 m
.77134 .37304 L
s
.77134 .37304 m
.77134 .37304 L
s
.77134 .37304 m
.77134 .37304 L
s
1 .004 0 r
.81533 .66214 m
.81537 .66218 L
s
.81529 .66217 m
.81533 .66214 L
s
.81533 .66214 m
.81534 .66214 L
s
.81537 .66218 m
.81533 .66221 L
s
.81534 .66214 m
.81537 .66218 L
s
.81533 .66221 m
.81529 .66217 L
s
.81529 .66217 m
.81534 .66214 L
s
.81534 .66214 m
.81533 .66221 L
s
1 .01 0 r
.60339 .60955 m
.60353 .60911 L
s
1 .31 0 r
.23642 .61373 m
.23458 .60932 L
s
.24043 .60951 m
.23642 .61373 L
s
.23458 .60932 m
.24043 .60951 L
s
1 0 0 r
.55944 .32026 m
.55944 .32026 L
s
.55944 .32026 m
.55944 .32026 L
s
.55944 .32026 m
.55944 .32026 L
s
.55944 .32026 m
.55944 .32026 L
s
.55944 .32026 m
.55944 .32026 L
s
.55944 .32026 m
.55944 .32026 L
s
.55944 .32026 m
.55944 .32026 L
s
.55944 .32026 m
.55944 .32026 L
s
.55944 .32026 m
.55944 .32026 L
s
1 .086 0 r
.35619 .58315 m
.35524 .58376 L
s
.35559 .58228 m
.35619 .58315 L
s
1 .032 0 r
.44991 .58267 m
.45025 .58299 L
s
.44956 .58292 m
.44991 .58267 L
s
.44991 .58267 m
.44998 .58268 L
s
1 .052 0 r
.39147 .55679 m
.39192 .5545 L
s
1 .529 0 r
.20541 .41816 m
.21022 .42141 L
s
.19983 .42401 m
.20541 .41816 L
s
.20541 .41816 m
.20137 .41805 L
s
1 .032 0 r
.45025 .58299 m
.4499 .58325 L
s
.44998 .58268 m
.45025 .58299 L
s
1 .001 0 r
.87029 .53041 m
.87029 .53036 L
s
.87029 .53036 m
.8703 .53037 L
s
.87028 .53037 m
.87029 .53036 L
s
.87029 .53036 m
.87029 .53036 L
s
.8703 .53037 m
.87029 .53038 L
s
.87029 .53036 m
.8703 .53037 L
s
.87029 .53038 m
.87028 .53037 L
s
.87028 .53037 m
.87029 .53036 L
s
.87029 .53036 m
.87029 .53038 L
s
1 .01 0 r
.6035 .6091 m
.60361 .60921 L
s
.60339 .60919 m
.6035 .6091 L
s
.6035 .6091 m
.60353 .60911 L
s
1 .032 0 r
.4499 .58325 m
.44956 .58292 L
s
.44956 .58292 m
.44998 .58268 L
s
1 .01 0 r
.60361 .60921 m
.6035 .60929 L
s
.60353 .60911 m
.60361 .60921 L
s
0 .049 1 r
.17951 .50402 m
.24195 .31664 L
s
1 .01 0 r
.6035 .60929 m
.60339 .60919 L
s
.60339 .60919 m
.60353 .60911 L
s
.60353 .60911 m
.6035 .60929 L
s
1 .086 0 r
.35524 .58376 m
.35437 .58284 L
s
.35437 .58284 m
.35559 .58228 L
s
1 .002 0 r
.65836 .47763 m
.65836 .47754 L
s
1 .032 0 r
.44998 .58268 m
.4499 .58325 L
s
1 .002 0 r
.65836 .47754 m
.65838 .47756 L
s
.65834 .47756 m
.65836 .47754 L
s
.65836 .47754 m
.65836 .47754 L
s
.65836 .47758 m
.65834 .47756 L
s
.65834 .47756 m
.65836 .47754 L
s
.65838 .47756 m
.65836 .47758 L
s
.65836 .47754 m
.65838 .47756 L
s
.65836 .47754 m
.65836 .47758 L
s
1 .006 0 r
.44639 .42484 m
.4463 .42455 L
s
1 .187 0 r
.27505 .4766 m
.27516 .47994 L
s
1 .086 0 r
.35559 .58228 m
.35524 .58376 L
s
1 .175 0 r
.27837 .66144 m
.28658 .65591 L
s
1 .005 0 r
.75731 .63506 m
.75738 .63486 L
s
1 .006 0 r
.44632 .42455 m
.44639 .4246 L
s
.44625 .42461 m
.44632 .42455 L
s
.44632 .42455 m
.4463 .42455 L
s
.44632 .42466 m
.44625 .42461 L
s
.44625 .42461 m
.4463 .42455 L
s
.44639 .4246 m
.44632 .42466 L
s
.4463 .42455 m
.44639 .4246 L
s
.4463 .42455 m
.44632 .42466 L
s
1 0 0 r
.71335 .34565 m
.71335 .34565 L
s
.71335 .34565 m
.71335 .34565 L
s
.71335 .34565 m
.71335 .34565 L
s
.71335 .34565 m
.71335 .34565 L
s
.71335 .34565 m
.71335 .34565 L
s
.71335 .34565 m
.71335 .34565 L
s
.71335 .34565 m
.71335 .34565 L
s
.71335 .34565 m
.71335 .34565 L
s
.71335 .34565 m
.71335 .34565 L
s
1 .005 0 r
.75736 .63486 m
.75741 .63491 L
s
.75732 .6349 m
.75736 .63486 L
s
.75736 .63486 m
.75738 .63486 L
s
.75741 .63491 m
.75737 .63494 L
s
.75738 .63486 m
.75741 .63491 L
s
.75737 .63494 m
.75732 .6349 L
s
.75732 .6349 m
.75738 .63486 L
s
.75738 .63486 m
.75737 .63494 L
s
1 .014 0 r
.54532 .58228 m
.54546 .58167 L
s
1 .044 0 r
.29129 .39753 m
.29169 .39778 L
s
.29085 .39804 m
.29129 .39753 L
s
.29129 .39753 m
.29093 .39753 L
s
1 0 0 r
.50134 .29284 m
.50134 .29284 L
s
.50134 .29284 m
.50134 .29284 L
s
.50134 .29284 m
.50134 .29284 L
s
.50134 .29284 m
.50134 .29284 L
s
.50134 .29284 m
.50134 .29284 L
s
.50134 .29284 m
.50134 .29284 L
s
.50134 .29284 m
.50134 .29284 L
s
.50134 .29284 m
.50134 .29284 L
s
.50134 .29284 m
.50134 .29284 L
s
1 .044 0 r
.29124 .39829 m
.29085 .39804 L
s
.29085 .39804 m
.29093 .39753 L
s
1 .095 0 r
.33329 .52949 m
.33362 .52521 L
s
1 .001 0 r
.81233 .50309 m
.81234 .50304 L
s
.81234 .50304 m
.81235 .50305 L
s
.81233 .50305 m
.81234 .50304 L
s
.81234 .50304 m
.81234 .50304 L
s
.81235 .50305 m
.81234 .50306 L
s
.81234 .50304 m
.81235 .50305 L
s
.81234 .50306 m
.81233 .50305 L
s
.81233 .50305 m
.81234 .50304 L
s
.81234 .50304 m
.81234 .50306 L
s
1 .044 0 r
.29169 .39778 m
.29124 .39829 L
s
.29093 .39753 m
.29169 .39778 L
s
1 .529 0 r
.20463 .42728 m
.19983 .42401 L
s
.19983 .42401 m
.20137 .41805 L
s
1 .014 0 r
.54543 .58167 m
.54558 .58181 L
s
.54528 .58178 m
.54543 .58167 L
s
.54543 .58167 m
.54546 .58167 L
s
1 .044 0 r
.29093 .39753 m
.29124 .39829 L
s
1 .002 0 r
.6003 .45028 m
.60029 .45019 L
s
1 .014 0 r
.54558 .58181 m
.54543 .58192 L
s
.54546 .58167 m
.54558 .58181 L
s
.54543 .58192 m
.54528 .58178 L
s
.54528 .58178 m
.54546 .58167 L
s
1 .002 0 r
.60029 .45019 m
.60032 .4502 L
s
.60027 .45021 m
.60029 .45019 L
s
.60029 .45019 m
.60029 .45019 L
s
.60029 .45022 m
.60027 .45021 L
s
.60027 .45021 m
.60029 .45019 L
s
.60032 .4502 m
.60029 .45022 L
s
.60029 .45019 m
.60032 .4502 L
s
.60029 .45019 m
.60029 .45022 L
s
1 .014 0 r
.54546 .58167 m
.54543 .58192 L
s
1 .002 0 r
.91135 .66058 m
.9114 .66048 L
s
1 .008 0 r
.38823 .39747 m
.38804 .39711 L
s
1 .002 0 r
.91139 .66048 m
.91141 .6605 L
s
.91136 .6605 m
.91139 .66048 L
s
.91139 .66048 m
.9114 .66048 L
s
1 .171 0 r
.25032 .42139 m
.25185 .42238 L
s
.24858 .42334 m
.25032 .42139 L
s
.25032 .42139 m
.24893 .42139 L
s
1 .002 0 r
.91141 .6605 m
.91139 .66052 L
s
.9114 .66048 m
.91141 .6605 L
s
.91139 .66052 m
.91136 .6605 L
s
.91136 .6605 m
.9114 .66048 L
s
1 .317 0 r
.22012 .63418 m
.23961 .62693 L
s
1 .002 0 r
.9114 .66048 m
.91139 .66052 L
s
1 .052 0 r
.39185 .55449 m
.3924 .55501 L
s
.39126 .55491 m
.39185 .55449 L
s
.39185 .55449 m
.39192 .5545 L
s
1 .005 0 r
.69929 .60778 m
.69936 .60755 L
s
1 .252 0 r
.26634 .57804 m
.2686 .58117 L
s
.26377 .57943 m
.26634 .57804 L
s
.26634 .57804 m
.26808 .57845 L
s
1 .008 0 r
.38808 .39711 m
.38816 .39716 L
s
.38799 .39719 m
.38808 .39711 L
s
.38808 .39711 m
.38804 .39711 L
s
.38807 .39725 m
.38799 .39719 L
s
.38799 .39719 m
.38804 .39711 L
s
1 0 0 r
.65531 .31823 m
.65531 .31823 L
s
.65531 .31823 m
.65531 .31823 L
s
.65531 .31823 m
.65531 .31823 L
s
.65531 .31823 m
.65531 .31823 L
s
.65531 .31823 m
.65531 .31823 L
s
.65531 .31823 m
.65531 .31823 L
s
.65531 .31823 m
.65531 .31823 L
s
.65531 .31823 m
.65531 .31823 L
s
.65531 .31823 m
.65531 .31823 L
s
1 .008 0 r
.38816 .39716 m
.38807 .39725 L
s
.38804 .39711 m
.38816 .39716 L
s
.38804 .39711 m
.38807 .39725 L
s
1 .052 0 r
.3924 .55501 m
.39181 .55542 L
s
.39192 .5545 m
.3924 .55501 L
s
1 .396 0 r
.24428 .497 m
.24827 .50121 L
s
.23976 .49974 m
.24428 .497 L
s
.24428 .497 m
.24528 .49701 L
s
1 .005 0 r
.69934 .60754 m
.6994 .6076 L
s
.69929 .60759 m
.69934 .60754 L
s
.69934 .60754 m
.69936 .60755 L
s
1 .019 0 r
.48719 .55497 m
.48731 .55411 L
s
1 .005 0 r
.6994 .6076 m
.69935 .60764 L
s
.69936 .60755 m
.6994 .6076 L
s
.69935 .60764 m
.69929 .60759 L
s
.69929 .60759 m
.69936 .60755 L
s
.69936 .60755 m
.69935 .60764 L
s
1 .171 0 r
.2501 .42433 m
.24858 .42334 L
s
.24858 .42334 m
.24893 .42139 L
s
1 .052 0 r
.39181 .55542 m
.39126 .55491 L
s
.39126 .55491 m
.39192 .5545 L
s
1 .252 0 r
.2686 .58117 m
.26603 .58257 L
s
.26808 .57845 m
.2686 .58117 L
s
1 .208 0 r
.27505 .50215 m
.27378 .49263 L
s
1 .052 0 r
.39192 .5545 m
.39181 .55542 L
s
1 .001 0 r
.75433 .47574 m
.75433 .47569 L
s
.75433 .4757 m
.75434 .4757 L
s
.75432 .4757 m
.75433 .4757 L
s
.75433 .4757 m
.75433 .47569 L
s
.75433 .47571 m
.75432 .4757 L
s
.75432 .4757 m
.75433 .47569 L
s
.75434 .4757 m
.75433 .47571 L
s
.75433 .47569 m
.75434 .4757 L
s
.75433 .47569 m
.75433 .47571 L
s
1 .002 0 r
.54218 .42291 m
.54216 .42281 L
s
.54217 .42281 m
.54219 .42282 L
s
.54214 .42283 m
.54217 .42281 L
s
.54217 .42281 m
.54216 .42281 L
s
.54217 .42284 m
.54214 .42283 L
s
.54214 .42283 m
.54216 .42281 L
s
.54219 .42282 m
.54217 .42284 L
s
.54216 .42281 m
.54219 .42282 L
s
1 .08 0 r
.37402 .65972 m
.3763 .65665 L
s
1 .002 0 r
.54216 .42281 m
.54217 .42284 L
s
1 .019 0 r
.48729 .55411 m
.4875 .5543 L
s
.48708 .55427 m
.48729 .55411 L
s
.48729 .55411 m
.48731 .55411 L
s
1 .003 0 r
.85338 .63331 m
.85343 .63319 L
s
1 .009 0 r
.33 .37006 m
.32965 .36966 L
s
1 .019 0 r
.4875 .5543 m
.48729 .55446 L
s
.48731 .55411 m
.4875 .5543 L
s
.48729 .55446 m
.48708 .55427 L
s
.48708 .55427 m
.48731 .55411 L
s
1 .003 0 r
.85342 .63319 m
.85345 .63322 L
s
.85339 .63321 m
.85342 .63319 L
s
.85342 .63319 m
.85343 .63319 L
s
.85345 .63322 m
.85342 .63324 L
s
.85343 .63319 m
.85345 .63322 L
s
.85342 .63324 m
.85339 .63321 L
s
.85339 .63321 m
.85343 .63319 L
s
1 0 0 r
.80939 .34364 m
.80939 .34364 L
s
.80939 .34364 m
.80939 .34364 L
s
.80939 .34364 m
.80939 .34364 L
s
.80939 .34364 m
.80939 .34364 L
s
.80939 .34364 m
.80939 .34364 L
s
.80939 .34364 m
.80939 .34364 L
s
.80939 .34364 m
.80939 .34364 L
s
.80939 .34364 m
.80939 .34364 L
s
.80939 .34364 m
.80939 .34364 L
s
1 .003 0 r
.85343 .63319 m
.85342 .63324 L
s
1 .019 0 r
.48731 .55411 m
.48729 .55446 L
s
1 .007 0 r
.64121 .58048 m
.64128 .58019 L
s
1 .009 0 r
.32972 .36966 m
.32981 .36971 L
s
.32963 .36977 m
.32972 .36966 L
s
.32972 .36966 m
.32965 .36966 L
s
.32971 .36982 m
.32963 .36977 L
s
.32963 .36977 m
.32965 .36966 L
s
1 0 0 r
.5972 .29078 m
.5972 .29078 L
s
.5972 .29078 m
.5972 .29078 L
s
.5972 .29078 m
.5972 .29078 L
s
.5972 .29078 m
.5972 .29078 L
s
.5972 .29078 m
.5972 .29078 L
s
.5972 .29078 m
.5972 .29078 L
s
.5972 .29078 m
.5972 .29078 L
s
.5972 .29078 m
.5972 .29078 L
s
.5972 .29078 m
.5972 .29078 L
s
1 .171 0 r
.25185 .42238 m
.2501 .42433 L
s
.24893 .42139 m
.25185 .42238 L
s
1 .009 0 r
.32981 .36971 m
.32971 .36982 L
s
.32965 .36966 m
.32981 .36971 L
s
.32965 .36966 m
.32971 .36982 L
s
1 .029 0 r
.429 .52764 m
.42905 .52632 L
s
1 .007 0 r
.64126 .58019 m
.64134 .58025 L
s
.64119 .58024 m
.64126 .58019 L
s
.64126 .58019 m
.64128 .58019 L
s
.64134 .58025 m
.64127 .5803 L
s
.64128 .58019 m
.64134 .58025 L
s
.64127 .5803 m
.64119 .58024 L
s
.64119 .58024 m
.64128 .58019 L
s
.64128 .58019 m
.64127 .5803 L
s
1 .396 0 r
.24827 .50121 m
.24376 .50396 L
s
.24528 .49701 m
.24827 .50121 L
s
1 .596 0 r
.21676 .47479 m
.19608 .44887 L
s
1 .166 0 r
.29826 .55147 m
.29995 .55326 L
s
.29639 .55265 m
.29826 .55147 L
s
.29826 .55147 m
.29874 .55154 L
s
1 .001 0 r
.69626 .44837 m
.69626 .44832 L
s
1 .171 0 r
.24893 .42139 m
.2501 .42433 L
s
1 .001 0 r
.69626 .44832 m
.69627 .44833 L
s
.69625 .44833 m
.69626 .44832 L
s
.69626 .44832 m
.69626 .44832 L
s
.69626 .44834 m
.69625 .44833 L
s
.69625 .44833 m
.69626 .44832 L
s
.69627 .44833 m
.69626 .44834 L
s
.69626 .44832 m
.69627 .44833 L
s
.69626 .44832 m
.69626 .44834 L
s
1 .629 0 r
.23083 .53575 m
.22678 .52688 L
s
.23864 .52689 m
.23083 .53575 L
s
1 .002 0 r
.48401 .39551 m
.48398 .3954 L
s
.48398 .39541 m
.48401 .39542 L
s
.48396 .39543 m
.48398 .39541 L
s
.48398 .39541 m
.48398 .3954 L
s
.48398 .39544 m
.48396 .39543 L
s
.48396 .39543 m
.48398 .3954 L
s
.48401 .39542 m
.48398 .39544 L
s
.48398 .3954 m
.48401 .39542 L
s
1 .135 0 r
.31576 .63243 m
.31996 .62727 L
s
1 .002 0 r
.48398 .3954 m
.48398 .39544 L
s
1 .003 0 r
.79536 .606 m
.7954 .60587 L
s
1 .166 0 r
.29995 .55326 m
.29808 .55444 L
s
.29874 .55154 m
.29995 .55326 L
s
1 .003 0 r
.79539 .60587 m
.79542 .6059 L
s
.79536 .6059 m
.79539 .60587 L
s
.79539 .60587 m
.7954 .60587 L
s
1 0 0 r
.75134 .3162 m
.75134 .3162 L
s
.75134 .3162 m
.75134 .3162 L
s
.75134 .3162 m
.75134 .3162 L
s
.75134 .3162 m
.75134 .3162 L
s
.75134 .3162 m
.75134 .3162 L
s
.75134 .3162 m
.75134 .3162 L
s
.75134 .3162 m
.75134 .3162 L
s
.75134 .3162 m
.75134 .3162 L
s
.75134 .3162 m
.75134 .3162 L
s
1 .629 0 r
.22678 .52688 m
.23864 .52689 L
s
1 .003 0 r
.79542 .6059 m
.79539 .60593 L
s
.7954 .60587 m
.79542 .6059 L
s
.79539 .60593 m
.79536 .6059 L
s
.79536 .6059 m
.7954 .60587 L
s
.7954 .60587 m
.79539 .60593 L
s
1 .008 0 r
.58308 .55315 m
.58313 .55278 L
s
1 .529 0 r
.21022 .42141 m
.20463 .42728 L
s
.20137 .41805 m
.21022 .42141 L
s
1 .252 0 r
.26603 .58257 m
.26377 .57943 L
s
.26377 .57943 m
.26808 .57845 L
s
1 .029 0 r
.42905 .52632 m
.42937 .52659 L
s
.42872 .52657 m
.42905 .52632 L
s
.42905 .52632 m
.42905 .52632 L
s
1 .049 0 r
.37076 .50028 m
.37052 .49805 L
s
1 .029 0 r
.42937 .52659 m
.42904 .52684 L
s
.42905 .52632 m
.42937 .52659 L
s
.42904 .52684 m
.42872 .52657 L
s
.42872 .52657 m
.42905 .52632 L
s
1 .008 0 r
.58312 .55277 m
.58321 .55285 L
s
.58303 .55285 m
.58312 .55277 L
s
.58312 .55277 m
.58313 .55278 L
s
1 .001 0 r
.85047 .47385 m
.85047 .47382 L
s
1 .095 0 r
.3336 .52522 m
.3346 .52613 L
s
.33251 .52601 m
.3336 .52522 L
s
.3336 .52522 m
.33362 .52521 L
s
1 .001 0 r
.85047 .47382 m
.85047 .47383 L
s
.85046 .47383 m
.85047 .47382 L
s
.85047 .47382 m
.85047 .47382 L
s
1 .008 0 r
.58321 .55285 m
.58312 .55292 L
s
.58313 .55278 m
.58321 .55285 L
s
1 .001 0 r
.85047 .47383 m
.85046 .47383 L
s
.85046 .47383 m
.85047 .47382 L
s
.85047 .47383 m
.85047 .47383 L
s
.85047 .47382 m
.85047 .47383 L
s
.85047 .47382 m
.85047 .47383 L
s
1 .008 0 r
.58312 .55292 m
.58303 .55285 L
s
.58303 .55285 m
.58313 .55278 L
s
.58313 .55278 m
.58312 .55292 L
s
1 .252 0 r
.26808 .57845 m
.26603 .58257 L
s
1 .029 0 r
.42905 .52632 m
.42904 .52684 L
s
1 .001 0 r
.63814 .42097 m
.63814 .42092 L
s
.63814 .42092 m
.63815 .42093 L
s
.63813 .42093 m
.63814 .42092 L
s
.63814 .42092 m
.63814 .42092 L
s
.63814 .42094 m
.63813 .42093 L
s
.63813 .42093 m
.63814 .42092 L
s
.63815 .42093 m
.63814 .42094 L
s
.63814 .42092 m
.63815 .42093 L
s
1 .166 0 r
.29808 .55444 m
.29639 .55265 L
s
.29639 .55265 m
.29874 .55154 L
s
1 .001 0 r
.63814 .42092 m
.63814 .42094 L
s
1 .037 0 r
.46983 .65799 m
.47059 .65649 L
s
1 .002 0 r
.42578 .36808 m
.42573 .36798 L
s
1 .095 0 r
.3346 .52613 m
.33351 .52691 L
s
.33362 .52521 m
.3346 .52613 L
s
1 .002 0 r
.42574 .36799 m
.42576 .368 L
s
.42572 .36801 m
.42574 .36799 L
s
.42574 .36799 m
.42573 .36798 L
s
1 .396 0 r
.24376 .50396 m
.23976 .49974 L
s
.23976 .49974 m
.24528 .49701 L
s
1 .002 0 r
.42574 .36802 m
.42572 .36801 L
s
.42572 .36801 m
.42573 .36798 L
s
.42576 .368 m
.42574 .36802 L
s
.42573 .36798 m
.42576 .368 L
s
.42573 .36798 m
.42574 .36802 L
s
1 .262 0 r
.25745 .60512 m
.26728 .59561 L
s
1 .175 0 r
.28504 .65542 m
.28646 .65772 L
s
.28341 .65632 m
.28504 .65542 L
s
.28504 .65542 m
.28658 .65591 L
s
1 .095 0 r
.33351 .52691 m
.33251 .52601 L
s
.33251 .52601 m
.33362 .52521 L
s
1 .175 0 r
.28646 .65772 m
.28484 .65863 L
s
.28658 .65591 m
.28646 .65772 L
s
1 .004 0 r
.73728 .57868 m
.73731 .57852 L
s
1 0 0 r
.69323 .28873 m
.69323 .28873 L
s
.69323 .28873 m
.69323 .28873 L
s
.69323 .28873 m
.69323 .28873 L
s
.69323 .28873 m
.69323 .28873 L
s
.69323 .28873 m
.69323 .28873 L
s
.69323 .28873 m
.69323 .28873 L
s
.69323 .28873 m
.69323 .28873 L
s
.69323 .28873 m
.69323 .28873 L
s
.69323 .28873 m
.69323 .28873 L
s
1 .004 0 r
.7373 .57852 m
.73734 .57855 L
s
.73727 .57855 m
.7373 .57852 L
s
.7373 .57852 m
.73731 .57852 L
s
1 .08 0 r
.37587 .65653 m
.37665 .65746 L
s
.37503 .65706 m
.37587 .65653 L
s
.37587 .65653 m
.3763 .65665 L
s
1 .004 0 r
.73734 .57855 m
.73731 .57858 L
s
.73731 .57852 m
.73734 .57855 L
s
.73731 .57858 m
.73727 .57855 L
s
.73727 .57855 m
.73731 .57852 L
s
.73731 .57852 m
.73731 .57858 L
s
1 .166 0 r
.29874 .55154 m
.29808 .55444 L
s
1 .011 0 r
.52489 .52579 m
.52491 .52529 L
s
1 .08 0 r
.37665 .65746 m
.37581 .65799 L
s
.3763 .65665 m
.37665 .65746 L
s
1 .095 0 r
.33362 .52521 m
.33351 .52691 L
s
1 .094 0 r
.31246 .4729 m
.31096 .46861 L
s
1 .001 0 r
.7924 .44645 m
.7924 .44642 L
s
1 .529 0 r
.20137 .41805 m
.20463 .42728 L
s
1 .001 0 r
.7924 .44642 m
.7924 .44643 L
s
.79239 .44643 m
.7924 .44642 L
s
.7924 .44642 m
.7924 .44642 L
s
.7924 .44643 m
.79239 .44643 L
s
.79239 .44643 m
.7924 .44642 L
s
.7924 .44643 m
.7924 .44643 L
s
.7924 .44642 m
.7924 .44643 L
s
.7924 .44642 m
.7924 .44643 L
s
1 .011 0 r
.52491 .5253 m
.52503 .5254 L
s
.52478 .52539 m
.52491 .5253 L
s
.52491 .5253 m
.52491 .52529 L
s
.52503 .5254 m
.52491 .52549 L
s
.52491 .52529 m
.52503 .5254 L
s
.52491 .52549 m
.52478 .52539 L
s
.52478 .52539 m
.52491 .52529 L
s
.52491 .52529 m
.52491 .52549 L
s
1 .001 0 r
.57997 .39354 m
.57996 .3935 L
s
.57996 .3935 m
.57997 .39351 L
s
.57995 .39351 m
.57996 .3935 L
s
.57996 .3935 m
.57996 .3935 L
s
.57996 .39352 m
.57995 .39351 L
s
.57995 .39351 m
.57996 .3935 L
s
.57997 .39351 m
.57996 .39352 L
s
.57996 .3935 m
.57997 .39351 L
s
.57996 .3935 m
.57996 .39352 L
s
1 .08 0 r
.37581 .65799 m
.37503 .65706 L
s
.37503 .65706 m
.3763 .65665 L
s
1 .056 0 r
.41157 .63067 m
.41266 .62836 L
s
1 .037 0 r
.47045 .65645 m
.47083 .65685 L
s
.47005 .65673 m
.47045 .65645 L
s
.47045 .65645 m
.47059 .65649 L
s
1 .002 0 r
.8916 .60423 m
.89162 .60415 L
s
.3675 .34062 m
.36744 .34056 L
s
1 .08 0 r
.3763 .65665 m
.37581 .65799 L
s
1 .002 0 r
.36745 .34056 m
.36747 .34056 L
s
.36744 .34057 m
.36745 .34056 L
s
.36745 .34056 m
.36744 .34056 L
s
.36745 .34058 m
.36744 .34057 L
s
.36744 .34057 m
.36744 .34056 L
s
.89162 .60414 m
.89164 .60416 L
s
.8916 .60416 m
.89162 .60414 L
s
.89162 .60414 m
.89162 .60415 L
s
1 .049 0 r
.37058 .49806 m
.3711 .49849 L
s
.37003 .4985 m
.37058 .49806 L
s
.37058 .49806 m
.37052 .49805 L
s
1 .002 0 r
.36747 .34056 m
.36745 .34058 L
s
.36744 .34056 m
.36747 .34056 L
s
.89164 .60416 m
.89162 .60418 L
s
.89162 .60415 m
.89164 .60416 L
s
.36744 .34056 m
.36745 .34058 L
s
.89162 .60418 m
.8916 .60416 L
s
.8916 .60416 m
.89162 .60415 L
s
.89162 .60415 m
.89162 .60418 L
s
1 .648 0 r
.19908 .57777 m
.23713 .5611 L
s
1 .037 0 r
.47083 .65685 m
.47044 .65713 L
s
.47059 .65649 m
.47083 .65685 L
s
1 .004 0 r
.67914 .55132 m
.67917 .55114 L
s
1 .396 0 r
.24528 .49701 m
.24376 .50396 L
s
1 .037 0 r
.47044 .65713 m
.47005 .65673 L
s
.47005 .65673 m
.47059 .65649 L
s
1 .049 0 r
.37055 .49893 m
.37003 .4985 L
s
.37003 .4985 m
.37052 .49805 L
s
.3711 .49849 m
.37055 .49893 L
s
.37052 .49805 m
.3711 .49849 L
s
1 .004 0 r
.67916 .55114 m
.67921 .55118 L
s
.67912 .55117 m
.67916 .55114 L
s
.67916 .55114 m
.67917 .55114 L
s
.67921 .55118 m
.67916 .55121 L
s
.67917 .55114 m
.67921 .55118 L
s
.67916 .55121 m
.67912 .55117 L
s
.67912 .55117 m
.67917 .55114 L
s
1 .037 0 r
.47059 .65649 m
.47044 .65713 L
s
1 .004 0 r
.67917 .55114 m
.67916 .55121 L
s
1 .015 0 r
.46664 .49841 m
.46659 .49771 L
s
1 .049 0 r
.37052 .49805 m
.37055 .49893 L
s
1 .206 0 r
.2541 .44549 m
.24635 .43668 L
s
1 .317 0 r
.23781 .63003 m
.23549 .63128 L
s
.23592 .6255 m
.23781 .63003 L
s
.23961 .62693 m
.23781 .63003 L
s
1 0 0 r
.73427 .41902 m
.73427 .419 L
s
1 .175 0 r
.28484 .65863 m
.28341 .65632 L
s
.28341 .65632 m
.28658 .65591 L
s
1 0 0 r
.73427 .419 m
.73428 .41901 L
s
.73427 .41901 m
.73427 .419 L
s
.73427 .419 m
.73427 .419 L
s
.73427 .41901 m
.73427 .41901 L
s
.73427 .41901 m
.73427 .419 L
s
.73428 .41901 m
.73427 .41901 L
s
.73427 .419 m
.73428 .41901 L
s
.73427 .419 m
.73427 .41901 L
s
1 .018 0 r
.56582 .65625 m
.56613 .6555 L
s
1 .175 0 r
.28658 .65591 m
.28484 .65863 L
s
1 .317 0 r
.2336 .62674 m
.23592 .6255 L
s
.23592 .6255 m
.23961 .62693 L
s
1 .001 0 r
.52173 .36609 m
.52172 .36606 L
s
1 .015 0 r
.4666 .49771 m
.46677 .49785 L
s
.46643 .49785 m
.4666 .49771 L
s
.4666 .49771 m
.46659 .49771 L
s
1 .001 0 r
.52172 .36606 m
.52173 .36606 L
s
.52172 .36606 m
.52172 .36606 L
s
.52172 .36606 m
.52172 .36606 L
s
.52172 .36607 m
.52172 .36606 L
s
.52172 .36606 m
.52172 .36606 L
s
.52173 .36606 m
.52172 .36607 L
s
.52172 .36606 m
.52173 .36606 L
s
.52172 .36606 m
.52172 .36607 L
s
1 .015 0 r
.4666 .49798 m
.46643 .49785 L
s
.46643 .49785 m
.46659 .49771 L
s
1 .094 0 r
.35325 .60333 m
.35496 .59941 L
s
1 .015 0 r
.46677 .49785 m
.4666 .49798 L
s
.46659 .49771 m
.46677 .49785 L
s
1 .64 0 r
.23499 .55053 m
.22999 .55294 L
s
.23086 .54151 m
.23499 .55053 L
s
.23796 .54388 m
.23499 .55053 L
s
1 .015 0 r
.46659 .49771 m
.4666 .49798 L
s
1 .002 0 r
.83351 .57687 m
.83353 .57678 L
s
.83353 .57678 m
.83355 .5768 L
s
.83351 .5768 m
.83353 .57678 L
s
.83353 .57678 m
.83353 .57678 L
s
.83355 .5768 m
.83353 .57682 L
s
.83353 .57678 m
.83355 .5768 L
s
.83353 .57682 m
.83351 .5768 L
s
.83351 .5768 m
.83353 .57678 L
s
.83353 .57678 m
.83353 .57682 L
s
1 0 0 r
.78943 .28666 m
.78943 .28666 L
s
.78943 .28666 m
.78943 .28666 L
s
.78943 .28666 m
.78943 .28666 L
s
.78943 .28666 m
.78943 .28666 L
s
.78943 .28666 m
.78943 .28666 L
s
.78943 .28666 m
.78943 .28666 L
s
.78943 .28666 m
.78943 .28666 L
s
.78943 .28666 m
.78943 .28666 L
s
.78943 .28666 m
.78943 .28666 L
s
1 .005 0 r
.62094 .52394 m
.62096 .52372 L
s
1 .018 0 r
.56606 .65548 m
.56626 .65567 L
s
.56587 .65563 m
.56606 .65548 L
s
.56606 .65548 m
.56613 .6555 L
s
1 .64 0 r
.22585 .54388 m
.23086 .54151 L
s
.23086 .54151 m
.23796 .54388 L
s
1 .018 0 r
.56626 .65567 m
.56607 .65582 L
s
.56613 .6555 m
.56626 .65567 L
s
1 .005 0 r
.62095 .52372 m
.62101 .52376 L
s
.6209 .52376 m
.62095 .52372 L
s
.62095 .52372 m
.62096 .52372 L
s
.62101 .52376 m
.62096 .52381 L
s
.62096 .52372 m
.62101 .52376 L
s
.62096 .52381 m
.6209 .52376 L
s
.6209 .52376 m
.62096 .52372 L
s
1 .023 0 r
.40834 .471 m
.4081 .46995 L
s
1 .005 0 r
.62096 .52372 m
.62096 .52381 L
s
1 .018 0 r
.56607 .65582 m
.56587 .65563 L
s
.56587 .65563 m
.56613 .6555 L
s
.56613 .6555 m
.56607 .65582 L
s
1 .056 0 r
.41246 .62831 m
.41304 .62892 L
s
.41185 .62872 m
.41246 .62831 L
s
.41246 .62831 m
.41266 .62836 L
s
1 0 0 r
.67609 .39157 m
.67609 .39155 L
s
.67609 .39155 m
.67609 .39156 L
s
.67609 .39156 m
.67609 .39155 L
s
.67609 .39155 m
.67609 .39155 L
s
.67609 .39156 m
.67609 .39156 L
s
.67609 .39156 m
.67609 .39155 L
s
.67609 .39156 m
.67609 .39156 L
s
.67609 .39155 m
.67609 .39156 L
s
.67609 .39155 m
.67609 .39156 L
s
1 .056 0 r
.41304 .62892 m
.41243 .62933 L
s
.41266 .62836 m
.41304 .62892 L
s
1 .135 0 r
.31919 .62708 m
.32048 .62869 L
s
.31776 .62793 m
.31919 .62708 L
s
.31919 .62708 m
.31996 .62727 L
s
1 .025 0 r
.50755 .62891 m
.50793 .62785 L
s
1 0 0 r
.46344 .33861 m
.46343 .33859 L
s
.46343 .33859 m
.46344 .33859 L
s
.46343 .33859 m
.46343 .33859 L
s
.46343 .33859 m
.46343 .33859 L
s
.46343 .33859 m
.46343 .33859 L
s
.46343 .33859 m
.46343 .33859 L
s
.46344 .33859 m
.46343 .33859 L
s
.46343 .33859 m
.46344 .33859 L
s
.46343 .33859 m
.46343 .33859 L
s
1 .178 0 r
.29488 .57597 m
.29791 .56843 L
s
1 .056 0 r
.41243 .62933 m
.41185 .62872 L
s
.41185 .62872 m
.41266 .62836 L
s
1 .135 0 r
.32048 .62869 m
.31906 .62954 L
s
.31996 .62727 m
.32048 .62869 L
s
1 .002 0 r
.77537 .54949 m
.77539 .54939 L
s
1 .023 0 r
.40815 .46996 m
.40839 .47014 L
s
.4079 .47017 m
.40815 .46996 L
s
.40815 .46996 m
.4081 .46995 L
s
1 .002 0 r
.77538 .54939 m
.77541 .54941 L
s
.77536 .54941 m
.77538 .54939 L
s
.77538 .54939 m
.77539 .54939 L
s
.77541 .54941 m
.77538 .54943 L
s
.77539 .54939 m
.77541 .54941 L
s
.77538 .54943 m
.77536 .54941 L
s
.77536 .54941 m
.77539 .54939 L
s
1 .056 0 r
.41266 .62836 m
.41243 .62933 L
s
1 .002 0 r
.77539 .54939 m
.77538 .54943 L
s
1 .023 0 r
.40814 .47036 m
.4079 .47017 L
s
.4079 .47017 m
.4081 .46995 L
s
1 .006 0 r
.56269 .49653 m
.56268 .49626 L
s
1 .023 0 r
.40839 .47014 m
.40814 .47036 L
s
.4081 .46995 m
.40839 .47014 L
s
.4081 .46995 m
.40814 .47036 L
s
1 .037 0 r
.34997 .44356 m
.34919 .44186 L
s
1 .006 0 r
.56268 .49626 m
.56275 .49631 L
s
.56262 .49632 m
.56268 .49626 L
s
.56268 .49626 m
.56268 .49626 L
s
.56268 .49637 m
.56262 .49632 L
s
.56262 .49632 m
.56268 .49626 L
s
1 .094 0 r
.31131 .46865 m
.31227 .46938 L
s
.31025 .46956 m
.31131 .46865 L
s
.31131 .46865 m
.31096 .46861 L
s
1 .006 0 r
.56275 .49631 m
.56268 .49637 L
s
.56268 .49626 m
.56275 .49631 L
s
.56268 .49626 m
.56268 .49637 L
s
1 0 0 r
.83057 .41708 m
.83057 .41706 L
s
.83057 .41706 m
.83058 .41707 L
s
.83057 .41707 m
.83057 .41706 L
s
.83057 .41706 m
.83057 .41706 L
s
.83057 .41707 m
.83057 .41707 L
s
.83057 .41707 m
.83057 .41706 L
s
.83058 .41707 m
.83057 .41707 L
s
.83057 .41706 m
.83058 .41707 L
s
.83057 .41706 m
.83057 .41707 L
s
1 .025 0 r
.50785 .62783 m
.50812 .62809 L
s
.50758 .62803 m
.50785 .62783 L
s
.50785 .62783 m
.50793 .62785 L
s
1 .01 0 r
.66197 .65451 m
.66212 .65411 L
s
1 .025 0 r
.50812 .62809 m
.50785 .62829 L
s
.50793 .62785 m
.50812 .62809 L
s
.50785 .62829 m
.50758 .62803 L
s
.50758 .62803 m
.50793 .62785 L
s
1 0 0 r
.61785 .36409 m
.61785 .36408 L
s
.61785 .36408 m
.61785 .36408 L
s
.61785 .36408 m
.61785 .36408 L
s
.61785 .36408 m
.61785 .36408 L
s
.61785 .36408 m
.61785 .36408 L
s
.61785 .36408 m
.61785 .36408 L
s
.61785 .36408 m
.61785 .36408 L
s
.61785 .36408 m
.61785 .36408 L
s
.61785 .36408 m
.61785 .36408 L
s
1 .025 0 r
.50793 .62785 m
.50785 .62829 L
s
1 .037 0 r
.44923 .60155 m
.44968 .59995 L
s
1 .094 0 r
.31121 .47029 m
.31025 .46956 L
s
.31025 .46956 m
.31096 .46861 L
s
1 .135 0 r
.31906 .62954 m
.31776 .62793 L
s
.31776 .62793 m
.31996 .62727 L
s
1 0 0 r
.4051 .3111 m
.40509 .31109 L
s
.40509 .31109 m
.40509 .31109 L
s
.40509 .31109 m
.40509 .31109 L
s
.40509 .31109 m
.40509 .31109 L
s
.40509 .3111 m
.40509 .31109 L
s
.40509 .31109 m
.40509 .31109 L
s
.40509 .31109 m
.40509 .3111 L
s
.40509 .31109 m
.40509 .31109 L
s
.40509 .31109 m
.40509 .3111 L
s
1 .01 0 r
.66209 .6541 m
.6622 .6542 L
s
.66199 .65418 m
.66209 .6541 L
s
.66209 .6541 m
.66212 .65411 L
s
.6622 .6542 m
.6621 .65428 L
s
.66212 .65411 m
.6622 .6542 L
s
.6621 .65428 m
.66199 .65418 L
s
.66199 .65418 m
.66212 .65411 L
s
1 .425 0 r
.23645 .54858 m
.24321 .5302 L
s
1 .094 0 r
.31227 .46938 m
.31121 .47029 L
s
.31096 .46861 m
.31227 .46938 L
s
1 .01 0 r
.66212 .65411 m
.6621 .65428 L
s
1 .135 0 r
.31996 .62727 m
.31906 .62954 L
s
1 .002 0 r
.71717 .52209 m
.71718 .52198 L
s
.71718 .52198 m
.7172 .522 L
s
.71715 .522 m
.71718 .52198 L
s
.71718 .52198 m
.71718 .52198 L
s
.7172 .522 m
.71718 .52202 L
s
.71718 .52198 m
.7172 .522 L
s
.71718 .52202 m
.71715 .522 L
s
.71715 .522 m
.71718 .52198 L
s
.71718 .52198 m
.71718 .52202 L
s
1 .208 0 r
.27416 .4927 m
.27632 .49453 L
s
.27175 .49455 m
.27416 .4927 L
s
.27416 .4927 m
.27378 .49263 L
s
1 .008 0 r
.50438 .4691 m
.50433 .46875 L
s
1 .094 0 r
.31096 .46861 m
.31121 .47029 L
s
1 .066 0 r
.29156 .4161 m
.28903 .41328 L
s
1 .008 0 r
.50434 .46875 m
.50442 .46882 L
s
.50426 .46882 m
.50434 .46875 L
s
.50434 .46875 m
.50433 .46875 L
s
.50434 .46889 m
.50426 .46882 L
s
.50426 .46882 m
.50433 .46875 L
s
.50442 .46882 m
.50434 .46889 L
s
.50433 .46875 m
.50442 .46882 L
s
1 0 0 r
.77239 .3896 m
.77239 .38959 L
s
.77239 .38959 m
.77239 .38959 L
s
.77239 .38959 m
.77239 .38959 L
s
.77239 .38959 m
.77239 .38959 L
s
.77239 .38959 m
.77239 .38959 L
s
.77239 .38959 m
.77239 .38959 L
s
.77239 .38959 m
.77239 .38959 L
s
.77239 .38959 m
.77239 .38959 L
s
.77239 .38959 m
.77239 .38959 L
s
1 .037 0 r
.34936 .44188 m
.34974 .44214 L
s
.34895 .44226 m
.34936 .44188 L
s
.34936 .44188 m
.34919 .44186 L
s
1 .008 0 r
.50433 .46875 m
.50434 .46889 L
s
1 .012 0 r
.6037 .62715 m
.60386 .62663 L
s
1 .037 0 r
.34933 .44252 m
.34895 .44226 L
s
.34895 .44226 m
.34919 .44186 L
s
1 0 0 r
.55956 .33659 m
.55956 .33658 L
s
.55956 .33658 m
.55956 .33658 L
s
.55955 .33658 m
.55956 .33658 L
s
.55956 .33658 m
.55956 .33658 L
s
.55956 .33658 m
.55955 .33658 L
s
.55955 .33658 m
.55956 .33658 L
s
.55956 .33658 m
.55956 .33658 L
s
.55956 .33658 m
.55956 .33658 L
s
.55956 .33658 m
.55956 .33658 L
s
1 .094 0 r
.35466 .59935 m
.35562 .60037 L
s
.35362 .60003 m
.35466 .59935 L
s
.35466 .59935 m
.35496 .59941 L
s
1 .037 0 r
.34974 .44214 m
.34933 .44252 L
s
.34919 .44186 m
.34974 .44214 L
s
1 .06 0 r
.39085 .57416 m
.39137 .57155 L
s
1 .317 0 r
.23549 .63128 m
.2336 .62674 L
s
.23961 .62693 m
.23549 .63128 L
s
.2336 .62674 m
.23961 .62693 L
s
1 .001 0 r
.87177 .54766 m
.87178 .5476 L
s
1 .037 0 r
.34919 .44186 m
.34933 .44252 L
s
.4496 .59993 m
.45 .60031 L
s
.44919 .60023 m
.4496 .59993 L
s
.4496 .59993 m
.44968 .59995 L
s
1 .001 0 r
.87178 .5476 m
.87179 .54761 L
s
.87176 .54761 m
.87178 .5476 L
s
.87178 .5476 m
.87178 .5476 L
s
.87179 .54761 m
.87178 .54763 L
s
.87178 .5476 m
.87179 .54761 L
s
.87178 .54763 m
.87176 .54761 L
s
.87176 .54761 m
.87178 .5476 L
s
.87178 .5476 m
.87178 .54763 L
s
0 .046 1 r
.17796 .52116 m
.24061 .33426 L
s
1 .012 0 r
.60383 .62662 m
.60396 .62674 L
s
.6037 .62672 m
.60383 .62662 L
s
.60383 .62662 m
.60386 .62663 L
s
1 .094 0 r
.35562 .60037 m
.35458 .60105 L
s
.35496 .59941 m
.35562 .60037 L
s
1 .012 0 r
.60396 .62674 m
.60383 .62684 L
s
.60386 .62663 m
.60396 .62674 L
s
1 .037 0 r
.45 .60031 m
.44958 .60061 L
s
.44968 .59995 m
.45 .60031 L
s
1 .012 0 r
.60383 .62684 m
.6037 .62672 L
s
.6037 .62672 m
.60386 .62663 L
s
1 .003 0 r
.65891 .49465 m
.65891 .49453 L
s
1 .012 0 r
.60386 .62663 m
.60383 .62684 L
s
1 .037 0 r
.44958 .60061 m
.44919 .60023 L
s
.44919 .60023 m
.44968 .59995 L
s
1 .003 0 r
.65891 .49453 m
.65894 .49455 L
s
.65888 .49455 m
.65891 .49453 L
s
.65891 .49453 m
.65891 .49453 L
s
.65891 .49458 m
.65888 .49455 L
s
.65888 .49455 m
.65891 .49453 L
s
.65894 .49455 m
.65891 .49458 L
s
.65891 .49453 m
.65894 .49455 L
s
1 .208 0 r
.27391 .49638 m
.27175 .49455 L
s
.27175 .49455 m
.27378 .49263 L
s
1 .003 0 r
.65891 .49453 m
.65891 .49458 L
s
1 .208 0 r
.27632 .49453 m
.27391 .49638 L
s
.27378 .49263 m
.27632 .49453 L
s
1 .01 0 r
.44602 .44164 m
.44588 .44118 L
s
1 .037 0 r
.44968 .59995 m
.44958 .60061 L
s
1 .094 0 r
.35458 .60105 m
.35362 .60003 L
s
.35362 .60003 m
.35496 .59941 L
s
1 .005 0 r
.7583 .65277 m
.75838 .65255 L
s
1 0 0 r
.71415 .36209 m
.71414 .36209 L
s
.71414 .36209 m
.71415 .36209 L
s
.71414 .36209 m
.71414 .36209 L
s
.71414 .36209 m
.71414 .36209 L
s
.71414 .36209 m
.71414 .36209 L
s
.71414 .36209 m
.71414 .36209 L
s
.71415 .36209 m
.71414 .36209 L
s
.71414 .36209 m
.71415 .36209 L
s
.71414 .36209 m
.71414 .36209 L
s
1 .01 0 r
.44591 .44119 m
.44601 .44126 L
s
.4458 .44128 m
.44591 .44119 L
s
.44591 .44119 m
.44588 .44118 L
s
.4459 .44136 m
.4458 .44128 L
s
.4458 .44128 m
.44588 .44118 L
s
1 .005 0 r
.75836 .65254 m
.75842 .6526 L
s
.75831 .65259 m
.75836 .65254 L
s
.75836 .65254 m
.75838 .65255 L
s
1 .094 0 r
.35496 .59941 m
.35458 .60105 L
s
1 .01 0 r
.44601 .44126 m
.4459 .44136 L
s
.44588 .44118 m
.44601 .44126 L
s
1 .017 0 r
.54537 .59976 m
.54554 .59905 L
s
1 .005 0 r
.75842 .6526 m
.75837 .65264 L
s
.75838 .65255 m
.75842 .6526 L
s
.75837 .65264 m
.75831 .65259 L
s
.75831 .65259 m
.75838 .65255 L
s
1 .01 0 r
.44588 .44118 m
.4459 .44136 L
s
1 .005 0 r
.75838 .65255 m
.75837 .65264 L
s
1 0 0 r
.50121 .30905 m
.50121 .30905 L
s
.50121 .30905 m
.50121 .30905 L
s
.5012 .30905 m
.50121 .30905 L
s
.50121 .30905 m
.50121 .30905 L
s
.50121 .30905 m
.5012 .30905 L
s
.5012 .30905 m
.50121 .30905 L
s
.50121 .30905 m
.50121 .30905 L
s
.50121 .30905 m
.50121 .30905 L
s
.50121 .30905 m
.50121 .30905 L
s
1 .107 0 r
.33241 .54674 m
.33279 .54196 L
s
1 .001 0 r
.81356 .52023 m
.81357 .52017 L
s
.81357 .52017 m
.81359 .52018 L
s
.81356 .52018 m
.81357 .52017 L
s
.81357 .52017 m
.81357 .52017 L
s
.81359 .52018 m
.81357 .52019 L
s
.81357 .52017 m
.81359 .52018 L
s
.81357 .52019 m
.81356 .52018 L
s
.81356 .52018 m
.81357 .52017 L
s
1 .569 0 r
.2029 .43317 m
.20809 .43671 L
s
.19686 .4395 m
.2029 .43317 L
s
.2029 .43317 m
.19851 .4331 L
s
1 .001 0 r
.81357 .52017 m
.81357 .52019 L
s
1 .003 0 r
.6006 .46719 m
.60059 .46705 L
s
1 .017 0 r
.54551 .59904 m
.54569 .5992 L
s
.54533 .59918 m
.54551 .59904 L
s
.54551 .59904 m
.54554 .59905 L
s
1 .208 0 r
.27378 .49263 m
.27391 .49638 L
s
1 .003 0 r
.60059 .46705 m
.60062 .46708 L
s
.60055 .46708 m
.60059 .46705 L
s
.60059 .46705 m
.60059 .46705 L
s
.60059 .46711 m
.60055 .46708 L
s
.60055 .46708 m
.60059 .46705 L
s
.60062 .46708 m
.60059 .46711 L
s
.60059 .46705 m
.60062 .46708 L
s
1 .017 0 r
.54569 .5992 m
.54551 .59934 L
s
.54554 .59905 m
.54569 .5992 L
s
1 .003 0 r
.60059 .46705 m
.60059 .46711 L
s
1 .017 0 r
.54551 .59934 m
.54533 .59918 L
s
.54533 .59918 m
.54554 .59905 L
s
1 .066 0 r
.28957 .41327 m
.29017 .41365 L
s
.28891 .41404 m
.28957 .41327 L
s
.28957 .41327 m
.28903 .41328 L
s
1 .013 0 r
.38759 .41415 m
.38727 .41354 L
s
1 .017 0 r
.54554 .59905 m
.54551 .59934 L
s
1 .324 0 r
.21875 .6519 m
.23871 .64454 L
s
1 .066 0 r
.2895 .41441 m
.28891 .41404 L
s
.28891 .41404 m
.28903 .41328 L
s
1 .007 0 r
.70002 .62539 m
.70011 .62511 L
s
1 0 0 r
.65585 .33456 m
.65584 .33456 L
s
.65584 .33456 m
.65585 .33456 L
s
.65584 .33456 m
.65584 .33456 L
s
.65584 .33456 m
.65584 .33456 L
s
.65584 .33456 m
.65584 .33456 L
s
.65584 .33456 m
.65584 .33456 L
s
.65585 .33456 m
.65584 .33456 L
s
.65584 .33456 m
.65585 .33456 L
s
.65584 .33456 m
.65584 .33456 L
s
1 .023 0 r
.48699 .57235 m
.48714 .57132 L
s
1 .06 0 r
.39128 .57153 m
.39192 .57213 L
s
.39061 .57201 m
.39128 .57153 L
s
.39128 .57153 m
.39137 .57155 L
s
1 .007 0 r
.70009 .6251 m
.70016 .62517 L
s
.70002 .62516 m
.70009 .6251 L
s
.70009 .6251 m
.70011 .62511 L
s
1 .013 0 r
.38734 .41355 m
.38747 .41364 L
s
.3872 .41369 m
.38734 .41355 L
s
.38734 .41355 m
.38727 .41354 L
s
1 .007 0 r
.70016 .62517 m
.70009 .62522 L
s
.70011 .62511 m
.70016 .62517 L
s
.70009 .62522 m
.70002 .62516 L
s
.70002 .62516 m
.70011 .62511 L
s
1 .262 0 r
.26546 .59514 m
.26782 .59842 L
s
.26278 .59661 m
.26546 .59514 L
s
.26546 .59514 m
.26728 .59561 L
s
1 .013 0 r
.38733 .41378 m
.3872 .41369 L
s
.3872 .41369 m
.38727 .41354 L
s
1 .007 0 r
.70011 .62511 m
.70009 .62522 L
s
1 0 0 r
.4428 .28149 m
.4428 .28149 L
s
.4428 .28149 m
.4428 .28149 L
s
.4428 .28149 m
.4428 .28149 L
s
.4428 .28149 m
.4428 .28149 L
s
.4428 .28149 m
.4428 .28149 L
s
.4428 .28149 m
.4428 .28149 L
s
.4428 .28149 m
.4428 .28149 L
s
.4428 .28149 m
.4428 .28149 L
s
.4428 .28149 m
.4428 .28149 L
s
1 .066 0 r
.29017 .41365 m
.2895 .41441 L
s
.28903 .41328 m
.29017 .41365 L
s
1 .013 0 r
.38747 .41364 m
.38733 .41378 L
s
.38727 .41354 m
.38747 .41364 L
s
.38727 .41354 m
.38733 .41378 L
s
1 .226 0 r
.27392 .5193 m
.27253 .509 L
s
1 .06 0 r
.39192 .57213 m
.39124 .57261 L
s
.39137 .57155 m
.39192 .57213 L
s
1 .066 0 r
.28903 .41328 m
.2895 .41441 L
s
1 .001 0 r
.7553 .49277 m
.75531 .49271 L
s
.75531 .49271 m
.75532 .49272 L
s
.75529 .49272 m
.75531 .49271 L
s
.75531 .49271 m
.75531 .49271 L
s
.75531 .49273 m
.75529 .49272 L
s
.75529 .49272 m
.75531 .49271 L
s
.75532 .49272 m
.75531 .49273 L
s
.75531 .49271 m
.75532 .49272 L
s
.75531 .49271 m
.75531 .49273 L
s
1 .06 0 r
.39124 .57261 m
.39061 .57201 L
s
.39061 .57201 m
.39137 .57155 L
s
1 .262 0 r
.26782 .59842 m
.26515 .59989 L
s
.26728 .59561 m
.26782 .59842 L
s
1 .003 0 r
.54223 .43971 m
.54219 .43955 L
s
1 .413 0 r
.24323 .51339 m
.24742 .51781 L
s
.2385 .51628 m
.24323 .51339 L
s
.24323 .51339 m
.24428 .51344 L
s
1 .06 0 r
.39137 .57155 m
.39124 .57261 L
s
1 .003 0 r
.5422 .43955 m
.54224 .43957 L
s
.54216 .43958 m
.5422 .43955 L
s
.5422 .43955 m
.54219 .43955 L
s
.5422 .43961 m
.54216 .43958 L
s
.54216 .43958 m
.54219 .43955 L
s
.54224 .43957 m
.5422 .43961 L
s
.54219 .43955 m
.54224 .43957 L
s
.54219 .43955 m
.5422 .43961 L
s
.8548 .65103 m
.85485 .65089 L
s
1 .018 0 r
.32911 .38663 m
.32842 .38585 L
s
1 .569 0 r
.20205 .44306 m
.19686 .4395 L
s
.19686 .4395 m
.19851 .4331 L
s
1 .206 0 r
.24804 .43666 m
.24989 .43787 L
s
.24592 .43903 m
.24804 .43666 L
s
.24804 .43666 m
.24635 .43668 L
s
1 .023 0 r
.48711 .57131 m
.48737 .57154 L
s
.48685 .57151 m
.48711 .57131 L
s
.48711 .57131 m
.48714 .57132 L
s
1 .003 0 r
.85483 .65089 m
.85487 .65092 L
s
.8548 .65092 m
.85483 .65089 L
s
.85483 .65089 m
.85485 .65089 L
s
1 0 0 r
.81061 .36009 m
.81061 .36009 L
s
.81061 .36009 m
.81061 .36009 L
s
.81061 .36009 m
.81061 .36009 L
s
.81061 .36009 m
.81061 .36009 L
s
.81061 .36009 m
.81061 .36009 L
s
.81061 .36009 m
.81061 .36009 L
s
.81061 .36009 m
.81061 .36009 L
s
.81061 .36009 m
.81061 .36009 L
s
.81061 .36009 m
.81061 .36009 L
s
1 .003 0 r
.85487 .65092 m
.85484 .65095 L
s
.85485 .65089 m
.85487 .65092 L
s
.85484 .65095 m
.8548 .65092 L
s
.8548 .65092 m
.85485 .65089 L
s
.85485 .65089 m
.85484 .65095 L
s
1 .023 0 r
.48737 .57154 m
.48711 .57173 L
s
.48714 .57132 m
.48737 .57154 L
s
1 .008 0 r
.64169 .59797 m
.64177 .59762 L
s
1 .023 0 r
.48711 .57173 m
.48685 .57151 L
s
.48685 .57151 m
.48714 .57132 L
s
1 0 0 r
.59749 .307 m
.59749 .307 L
s
.59749 .307 m
.59749 .307 L
s
.59749 .307 m
.59749 .307 L
s
.59749 .307 m
.59749 .307 L
s
.59749 .307 m
.59749 .307 L
s
.59749 .307 m
.59749 .307 L
s
.59749 .307 m
.59749 .307 L
s
.59749 .307 m
.59749 .307 L
s
.59749 .307 m
.59749 .307 L
s
1 .023 0 r
.48714 .57132 m
.48711 .57173 L
s
1 .035 0 r
.42855 .5449 m
.42861 .54332 L
s
1 .008 0 r
.64175 .59762 m
.64184 .59769 L
s
.64166 .59769 m
.64175 .59762 L
s
.64175 .59762 m
.64177 .59762 L
s
1 .206 0 r
.24777 .44024 m
.24592 .43903 L
s
.24592 .43903 m
.24635 .43668 L
s
1 .008 0 r
.64184 .59769 m
.64176 .59776 L
s
.64177 .59762 m
.64184 .59769 L
s
.64176 .59776 m
.64166 .59769 L
s
.64166 .59769 m
.64177 .59762 L
s
1 .018 0 r
.32857 .38585 m
.32873 .38595 L
s
.32838 .38606 m
.32857 .38585 L
s
.32857 .38585 m
.32842 .38585 L
s
1 .008 0 r
.64177 .59762 m
.64176 .59776 L
s
1 .018 0 r
.32855 .38616 m
.32838 .38606 L
s
.32838 .38606 m
.32842 .38585 L
s
1 .615 0 r
.21537 .49183 m
.1939 .46515 L
s
1 .018 0 r
.32873 .38595 m
.32855 .38616 L
s
.32842 .38585 m
.32873 .38595 L
s
1 .001 0 r
.69698 .46528 m
.69698 .46522 L
s
1 .018 0 r
.32842 .38585 m
.32855 .38616 L
s
1 .001 0 r
.69698 .46522 m
.697 .46523 L
s
.69697 .46523 m
.69698 .46522 L
s
.69698 .46522 m
.69698 .46522 L
s
.69698 .46524 m
.69697 .46523 L
s
.69697 .46523 m
.69698 .46522 L
s
.697 .46523 m
.69698 .46524 L
s
.69698 .46522 m
.697 .46523 L
s
.69698 .46522 m
.69698 .46524 L
s
1 .004 0 r
.4838 .41219 m
.48373 .41201 L
s
1 .142 0 r
.31481 .65016 m
.31925 .64475 L
s
1 .004 0 r
.48375 .41201 m
.48379 .41204 L
s
.48371 .41205 m
.48375 .41201 L
s
.48375 .41201 m
.48373 .41201 L
s
1 .178 0 r
.29739 .56834 m
.29921 .57026 L
s
.29539 .56962 m
.29739 .56834 L
s
.29739 .56834 m
.29791 .56843 L
s
1 .004 0 r
.48375 .41208 m
.48371 .41205 L
s
.48371 .41205 m
.48373 .41201 L
s
.48379 .41204 m
.48375 .41208 L
s
.48373 .41201 m
.48379 .41204 L
s
.48373 .41201 m
.48375 .41208 L
s
.79652 .62362 m
.79656 .62346 L
s
1 .413 0 r
.24742 .51781 m
.24269 .52071 L
s
.24428 .51344 m
.24742 .51781 L
s
1 .64 0 r
.22999 .55294 m
.22585 .54388 L
s
.23796 .54388 m
.22999 .55294 L
s
1 0 0 r
.7523 .33254 m
.7523 .33253 L
s
.7523 .33253 m
.7523 .33253 L
s
.7523 .33253 m
.7523 .33253 L
s
.7523 .33253 m
.7523 .33253 L
s
.7523 .33253 m
.7523 .33253 L
s
.7523 .33253 m
.7523 .33253 L
s
.7523 .33253 m
.7523 .33253 L
s
.7523 .33253 m
.7523 .33253 L
s
.7523 .33253 m
.7523 .33253 L
s
1 .004 0 r
.79655 .62346 m
.79659 .62349 L
s
.79651 .62349 m
.79655 .62346 L
s
.79655 .62346 m
.79656 .62346 L
s
.79659 .62349 m
.79656 .62352 L
s
.79656 .62346 m
.79659 .62349 L
s
.79656 .62352 m
.79651 .62349 L
s
.79651 .62349 m
.79656 .62346 L
s
.79656 .62346 m
.79656 .62352 L
s
1 .01 0 r
.5833 .57053 m
.58337 .57007 L
s
1 0 0 r
.53907 .27942 m
.53907 .27942 L
s
.53907 .27942 m
.53907 .27942 L
s
.53907 .27942 m
.53907 .27942 L
s
.53907 .27942 m
.53907 .27942 L
s
.53907 .27942 m
.53907 .27942 L
s
.53907 .27942 m
.53907 .27942 L
s
.53907 .27942 m
.53907 .27942 L
s
.53907 .27942 m
.53907 .27942 L
s
.53907 .27942 m
.53907 .27942 L
s
1 .059 0 r
.37005 .51743 m
.36975 .51476 L
s
1 .64 0 r
.22585 .54388 m
.23796 .54388 L
s
1 .178 0 r
.29921 .57026 m
.2972 .57154 L
s
.29791 .56843 m
.29921 .57026 L
s
1 .035 0 r
.42861 .54332 m
.42899 .54365 L
s
.42821 .54363 m
.42861 .54332 L
s
.42861 .54332 m
.42861 .54332 L
s
1 .001 0 r
.85187 .49088 m
.85187 .49085 L
s
.85187 .49085 m
.85188 .49085 L
s
.85186 .49085 m
.85187 .49085 L
s
.85187 .49085 m
.85187 .49085 L
s
.85187 .49086 m
.85186 .49085 L
s
.85186 .49085 m
.85187 .49085 L
s
.85188 .49085 m
.85187 .49086 L
s
.85187 .49085 m
.85188 .49085 L
s
.85187 .49085 m
.85187 .49086 L
s
1 .01 0 r
.58335 .57007 m
.58347 .57017 L
s
.58324 .57016 m
.58335 .57007 L
s
.58335 .57007 m
.58337 .57007 L
s
.58347 .57017 m
.58335 .57026 L
s
.58337 .57007 m
.58347 .57017 L
s
1 .206 0 r
.24989 .43787 m
.24777 .44024 L
s
.24635 .43668 m
.24989 .43787 L
s
1 .01 0 r
.58335 .57026 m
.58324 .57016 L
s
.58324 .57016 m
.58337 .57007 L
s
1 .262 0 r
.26515 .59989 m
.26278 .59661 L
s
.26278 .59661 m
.26728 .59561 L
s
1 .01 0 r
.58337 .57007 m
.58335 .57026 L
s
1 .035 0 r
.42899 .54365 m
.42859 .54395 L
s
.42861 .54332 m
.42899 .54365 L
s
.42859 .54395 m
.42821 .54363 L
s
.42821 .54363 m
.42861 .54332 L
s
1 .001 0 r
.63861 .43777 m
.6386 .4377 L
s
.6386 .4377 m
.63862 .43772 L
s
.63859 .43772 m
.6386 .4377 L
s
.6386 .4377 m
.6386 .4377 L
s
.6386 .43773 m
.63859 .43772 L
s
.63859 .43772 m
.6386 .4377 L
s
.63862 .43772 m
.6386 .43773 L
s
.6386 .4377 m
.63862 .43772 L
s
.6386 .4377 m
.6386 .43773 L
s
1 .035 0 r
.42861 .54332 m
.42859 .54395 L
s
1 .004 0 r
.42531 .38465 m
.4252 .38446 L
s
1 .107 0 r
.33276 .54196 m
.33389 .54299 L
s
.33153 .54285 m
.33276 .54196 L
s
.33276 .54196 m
.33279 .54196 L
s
1 .262 0 r
.26728 .59561 m
.26515 .59989 L
s
1 .27 0 r
.25624 .62273 m
.26641 .61297 L
s
1 .004 0 r
.42523 .38446 m
.42527 .38449 L
s
.42518 .3845 m
.42523 .38446 L
s
.42523 .38446 m
.4252 .38446 L
s
.42522 .38453 m
.42518 .3845 L
s
.42518 .3845 m
.4252 .38446 L
s
1 .206 0 r
.24635 .43668 m
.24777 .44024 L
s
1 .004 0 r
.42527 .38449 m
.42522 .38453 L
s
.4252 .38446 m
.42527 .38449 L
s
.4252 .38446 m
.42522 .38453 L
s
.73818 .59618 m
.73822 .59599 L
s
1 .178 0 r
.2972 .57154 m
.29539 .56962 L
s
.29539 .56962 m
.29791 .56843 L
s
1 0 0 r
.69394 .30495 m
.69394 .30495 L
s
.69394 .30495 m
.69394 .30495 L
s
.69394 .30495 m
.69394 .30495 L
s
.69394 .30495 m
.69394 .30495 L
s
.69394 .30495 m
.69394 .30495 L
s
.69394 .30495 m
.69394 .30495 L
s
.69394 .30495 m
.69394 .30495 L
s
.69394 .30495 m
.69394 .30495 L
s
.69394 .30495 m
.69394 .30495 L
s
1 .004 0 r
.73821 .59599 m
.73826 .59603 L
s
.73817 .59603 m
.73821 .59599 L
s
.73821 .59599 m
.73822 .59599 L
s
.73826 .59603 m
.73822 .59607 L
s
.73822 .59599 m
.73826 .59603 L
s
.73822 .59607 m
.73817 .59603 L
s
.73817 .59603 m
.73822 .59599 L
s
.73822 .59599 m
.73822 .59607 L
s
1 .014 0 r
.52485 .54306 m
.52488 .54244 L
s
1 .107 0 r
.33389 .54299 m
.33266 .54387 L
s
.33279 .54196 m
.33389 .54299 L
s
1 .11 0 r
.31149 .48994 m
.30971 .48489 L
s
1 .107 0 r
.33266 .54387 m
.33153 .54285 L
s
.33153 .54285 m
.33279 .54196 L
s
1 .001 0 r
.79354 .46337 m
.79354 .46334 L
s
.79354 .46334 m
.79355 .46334 L
s
.79354 .46334 m
.79354 .46334 L
s
.79354 .46334 m
.79354 .46334 L
s
.79354 .46335 m
.79354 .46334 L
s
.79354 .46334 m
.79354 .46334 L
s
.79355 .46334 m
.79354 .46335 L
s
.79354 .46334 m
.79355 .46334 L
s
.79354 .46334 m
.79354 .46335 L
s
1 .413 0 r
.24269 .52071 m
.2385 .51628 L
s
.2385 .51628 m
.24428 .51344 L
s
1 .178 0 r
.29791 .56843 m
.2972 .57154 L
s
1 .014 0 r
.52488 .54244 m
.52503 .54257 L
s
.52472 .54256 m
.52488 .54244 L
s
.52488 .54244 m
.52488 .54244 L
s
1 .569 0 r
.20809 .43671 m
.20205 .44306 L
s
.19851 .4331 m
.20809 .43671 L
s
1 .001 0 r
.58018 .41023 m
.58016 .41016 L
s
1 .014 0 r
.52503 .54257 m
.52488 .54269 L
s
.52488 .54244 m
.52503 .54257 L
s
.52488 .54269 m
.52472 .54256 L
s
.52472 .54256 m
.52488 .54244 L
s
1 .001 0 r
.58016 .41016 m
.58018 .41018 L
s
.58015 .41018 m
.58016 .41016 L
s
.58016 .41016 m
.58016 .41016 L
s
.58016 .41019 m
.58015 .41018 L
s
.58015 .41018 m
.58016 .41016 L
s
.58018 .41018 m
.58016 .41019 L
s
.58016 .41016 m
.58018 .41018 L
s
.58016 .41016 m
.58016 .41019 L
s
1 .062 0 r
.41104 .64841 m
.41224 .64588 L
s
1 .014 0 r
.52488 .54244 m
.52488 .54269 L
s
1 .002 0 r
.89318 .62185 m
.89321 .62175 L
s
1 .004 0 r
.36677 .35708 m
.36661 .3569 L
s
1 .107 0 r
.33279 .54196 m
.33266 .54387 L
s
1 .002 0 r
.8932 .62175 m
.89323 .62177 L
s
.89318 .62177 m
.8932 .62175 L
s
.8932 .62175 m
.89321 .62175 L
s
.89323 .62177 m
.89321 .62179 L
s
.89321 .62175 m
.89323 .62177 L
s
.89321 .62179 m
.89318 .62177 L
s
.89318 .62177 m
.89321 .62175 L
s
.89321 .62175 m
.89321 .62179 L
s
1 .654 0 r
.19761 .59528 m
.23619 .57851 L
s
1 .004 0 r
.36664 .3569 m
.36668 .35692 L
s
.3666 .35695 m
.36664 .3569 L
s
.36664 .3569 m
.36661 .3569 L
s
.36664 .35697 m
.3666 .35695 L
s
.3666 .35695 m
.36661 .3569 L
s
.36668 .35692 m
.36664 .35697 L
s
.36661 .3569 m
.36668 .35692 L
s
.36661 .3569 m
.36664 .35697 L
s
1 .005 0 r
.67978 .56871 m
.67982 .56848 L
s
1 0 0 r
.63552 .27734 m
.63552 .27734 L
s
.63552 .27734 m
.63552 .27734 L
s
.63552 .27734 m
.63552 .27734 L
s
.63552 .27734 m
.63552 .27734 L
s
.63552 .27734 m
.63552 .27734 L
s
.63552 .27734 m
.63552 .27734 L
s
.63552 .27734 m
.63552 .27734 L
s
.63552 .27734 m
.63552 .27734 L
s
.63552 .27734 m
.63552 .27734 L
s
1 .005 0 r
.67981 .56848 m
.67987 .56853 L
s
.67976 .56853 m
.67981 .56848 L
s
.67981 .56848 m
.67982 .56848 L
s
1 .059 0 r
.36983 .51477 m
.37046 .51529 L
s
.36917 .5153 m
.36983 .51477 L
s
.36983 .51477 m
.36975 .51476 L
s
1 .005 0 r
.67987 .56853 m
.67981 .56858 L
s
.67982 .56848 m
.67987 .56853 L
s
1 .02 0 r
.46635 .51557 m
.46629 .51468 L
s
1 .005 0 r
.67981 .56858 m
.67976 .56853 L
s
.67976 .56853 m
.67982 .56848 L
s
.67982 .56848 m
.67981 .56858 L
s
1 .234 0 r
.25288 .46241 m
.244 .45242 L
s
1 .059 0 r
.36979 .51582 m
.36917 .5153 L
s
.36917 .5153 m
.36975 .51476 L
s
.37046 .51529 m
.36979 .51582 L
s
.36975 .51476 m
.37046 .51529 L
s
1 .001 0 r
.73516 .43583 m
.73516 .4358 L
s
1 .324 0 r
.23686 .64769 m
.23449 .649 L
s
.23493 .64305 m
.23686 .64769 L
s
.23871 .64454 m
.23686 .64769 L
s
1 .001 0 r
.73516 .4358 m
.73517 .43581 L
s
.73515 .43581 m
.73516 .4358 L
s
.73516 .4358 m
.73516 .4358 L
s
.73516 .43581 m
.73515 .43581 L
s
.73515 .43581 m
.73516 .4358 L
s
.73517 .43581 m
.73516 .43581 L
s
.73516 .4358 m
.73517 .43581 L
s
.73516 .4358 m
.73516 .43581 L
s
.52169 .38267 m
.52166 .3826 L
s
1 .413 0 r
.24428 .51344 m
.24269 .52071 L
s
1 .001 0 r
.52167 .3826 m
.52168 .38261 L
s
.52165 .38262 m
.52167 .3826 L
s
.52167 .3826 m
.52166 .3826 L
s
.52167 .38263 m
.52165 .38262 L
s
.52165 .38262 m
.52166 .3826 L
s
.52168 .38261 m
.52167 .38263 L
s
.52166 .3826 m
.52168 .38261 L
s
.52166 .3826 m
.52167 .38263 L
s
1 .324 0 r
.23255 .64435 m
.23493 .64305 L
s
.23493 .64305 m
.23871 .64454 L
s
1 .059 0 r
.36975 .51476 m
.36979 .51582 L
s
1 .102 0 r
.35246 .62096 m
.35432 .61674 L
s
1 .02 0 r
.4663 .51468 m
.46651 .51485 L
s
.46608 .51486 m
.4663 .51468 L
s
.4663 .51468 m
.46629 .51468 L
s
1 .003 0 r
.83484 .59438 m
.83487 .59427 L
s
1 .02 0 r
.4663 .51503 m
.46608 .51486 L
s
.46608 .51486 m
.46629 .51468 L
s
.46651 .51485 m
.4663 .51503 L
s
.46629 .51468 m
.46651 .51485 L
s
1 .003 0 r
.83486 .59427 m
.83489 .5943 L
s
.83483 .59429 m
.83486 .59427 L
s
.83486 .59427 m
.83487 .59427 L
s
.83489 .5943 m
.83486 .59432 L
s
.83487 .59427 m
.83489 .5943 L
s
1 .648 0 r
.23411 .56781 m
.22902 .5703 L
s
.22991 .55863 m
.23411 .56781 L
s
.23713 .5611 m
.23411 .56781 L
s
1 .003 0 r
.83486 .59432 m
.83483 .59429 L
s
.83483 .59429 m
.83487 .59427 L
s
.83487 .59427 m
.83486 .59432 L
s
1 0 0 r
.79057 .3029 m
.79057 .3029 L
s
.79057 .3029 m
.79057 .3029 L
s
.79057 .3029 m
.79057 .3029 L
s
.79057 .3029 m
.79057 .3029 L
s
.79057 .3029 m
.79057 .3029 L
s
.79057 .3029 m
.79057 .3029 L
s
.79057 .3029 m
.79057 .3029 L
s
.79057 .3029 m
.79057 .3029 L
s
.79057 .3029 m
.79057 .3029 L
s
1 .569 0 r
.19851 .4331 m
.20205 .44306 L
s
1 .02 0 r
.46629 .51468 m
.4663 .51503 L
s
1 .006 0 r
.62133 .54122 m
.62135 .54094 L
s
1 .03 0 r
.40779 .48805 m
.40748 .48668 L
s
1 .006 0 r
.62135 .54094 m
.62142 .54099 L
s
.62128 .54099 m
.62135 .54094 L
s
.62135 .54094 m
.62135 .54094 L
s
.62142 .54099 m
.62135 .54105 L
s
.62135 .54094 m
.62142 .54099 L
s
.62135 .54105 m
.62128 .54099 L
s
.62128 .54099 m
.62135 .54094 L
s
1 .648 0 r
.22482 .56109 m
.22991 .55863 L
s
.22991 .55863 m
.23713 .5611 L
s
1 .006 0 r
.62135 .54094 m
.62135 .54105 L
s
1 .001 0 r
.67673 .40827 m
.67672 .40824 L
s
.67672 .40824 m
.67673 .40824 L
s
.67671 .40825 m
.67672 .40824 L
s
.67672 .40824 m
.67672 .40824 L
s
.67672 .40825 m
.67671 .40825 L
s
.67671 .40825 m
.67672 .40824 L
s
.67673 .40824 m
.67672 .40825 L
s
.67672 .40824 m
.67673 .40824 L
s
.67672 .40824 m
.67672 .40825 L
s
1 .062 0 r
.41202 .64582 m
.41266 .6465 L
s
.41134 .64628 m
.41202 .64582 L
s
.41202 .64582 m
.41224 .64588 L
s
1 .029 0 r
.50744 .64666 m
.50787 .64546 L
s
1 .001 0 r
.46314 .35507 m
.46311 .35502 L
s
.46311 .35502 m
.46313 .35503 L
s
.4631 .35503 m
.46311 .35502 L
s
.46311 .35502 m
.46311 .35502 L
s
.46311 .35504 m
.4631 .35503 L
s
.4631 .35503 m
.46311 .35502 L
s
.46313 .35503 m
.46311 .35504 L
s
.46311 .35502 m
.46313 .35503 L
s
.46311 .35502 m
.46311 .35504 L
s
1 .062 0 r
.41266 .6465 m
.41198 .64696 L
s
.41224 .64588 m
.41266 .6465 L
s
1 .188 0 r
.29383 .59348 m
.29704 .58556 L
s
1 .142 0 r
.31843 .64453 m
.3198 .64624 L
s
.31692 .64544 m
.31843 .64453 L
s
.31843 .64453 m
.31925 .64475 L
s
1 .003 0 r
.77644 .56689 m
.77646 .56677 L
s
.77646 .56677 m
.77649 .56679 L
s
.77643 .56679 m
.77646 .56677 L
s
.77646 .56677 m
.77646 .56677 L
s
.77649 .56679 m
.77646 .56682 L
s
.77646 .56677 m
.77649 .56679 L
s
.77646 .56682 m
.77643 .56679 L
s
.77643 .56679 m
.77646 .56677 L
s
1 0 0 r
.73214 .27526 m
.73214 .27526 L
s
.73214 .27526 m
.73214 .27526 L
s
.73214 .27526 m
.73214 .27526 L
s
.73214 .27526 m
.73214 .27526 L
s
.73214 .27526 m
.73214 .27526 L
s
.73214 .27526 m
.73214 .27526 L
s
.73214 .27526 m
.73214 .27526 L
s
.73214 .27526 m
.73214 .27526 L
s
.73214 .27526 m
.73214 .27526 L
s
1 .003 0 r
.77646 .56677 m
.77646 .56682 L
s
1 .062 0 r
.41198 .64696 m
.41134 .64628 L
s
.41134 .64628 m
.41224 .64588 L
s
1 .142 0 r
.3198 .64624 m
.31829 .64715 L
s
.31925 .64475 m
.3198 .64624 L
s
1 .008 0 r
.56282 .5137 m
.56281 .51334 L
s
1 .03 0 r
.40755 .48669 m
.40786 .48694 L
s
.40721 .48698 m
.40755 .48669 L
s
.40755 .48669 m
.40748 .48668 L
s
1 .062 0 r
.41224 .64588 m
.41198 .64696 L
s
1 .049 0 r
.34917 .4605 m
.34813 .45826 L
s
1 .03 0 r
.40753 .48722 m
.40721 .48698 L
s
.40721 .48698 m
.40748 .48668 L
s
1 .008 0 r
.56281 .51334 m
.5629 .51341 L
s
.56273 .51341 m
.56281 .51334 L
s
.56281 .51334 m
.56281 .51334 L
s
1 .03 0 r
.40786 .48694 m
.40753 .48722 L
s
.40748 .48668 m
.40786 .48694 L
s
1 0 0 r
.83189 .43389 m
.83189 .43387 L
s
1 .008 0 r
.56282 .51348 m
.56273 .51341 L
s
.56273 .51341 m
.56281 .51334 L
s
.5629 .51341 m
.56282 .51348 L
s
.56281 .51334 m
.5629 .51341 L
s
1 0 0 r
.83189 .43387 m
.83189 .43388 L
s
.83188 .43388 m
.83189 .43387 L
s
.83189 .43387 m
.83189 .43387 L
s
.83189 .43388 m
.83188 .43388 L
s
.83188 .43388 m
.83189 .43387 L
s
.83189 .43388 m
.83189 .43388 L
s
.83189 .43387 m
.83189 .43388 L
s
.83189 .43387 m
.83189 .43388 L
s
1 .008 0 r
.56281 .51334 m
.56282 .51348 L
s
1 .03 0 r
.40748 .48668 m
.40753 .48722 L
s
1 .029 0 r
.50778 .64544 m
.50809 .64573 L
s
.50747 .64566 m
.50778 .64544 L
s
.50778 .64544 m
.50787 .64546 L
s
1 .001 0 r
.61823 .38068 m
.61822 .38065 L
s
.61822 .38065 m
.61823 .38066 L
s
.61822 .38066 m
.61822 .38065 L
s
.61822 .38065 m
.61822 .38065 L
s
.61822 .38066 m
.61822 .38066 L
s
.61822 .38066 m
.61822 .38065 L
s
.61823 .38066 m
.61822 .38066 L
s
.61822 .38065 m
.61823 .38066 L
s
.61822 .38065 m
.61822 .38066 L
s
1 .029 0 r
.50809 .64573 m
.50778 .64596 L
s
.50787 .64546 m
.50809 .64573 L
s
1 .042 0 r
.44886 .61918 m
.44937 .61738 L
s
1 .029 0 r
.50778 .64596 m
.50747 .64566 L
s
.50747 .64566 m
.50787 .64546 L
s
1 .001 0 r
.40453 .32745 m
.4045 .32742 L
s
.40451 .32742 m
.40452 .32742 L
s
.4045 .32743 m
.40451 .32742 L
s
.40451 .32742 m
.4045 .32742 L
s
.40451 .32743 m
.4045 .32743 L
s
.4045 .32743 m
.4045 .32742 L
s
.40452 .32742 m
.40451 .32743 L
s
.4045 .32742 m
.40452 .32742 L
s
.4045 .32742 m
.40451 .32743 L
s
1 .029 0 r
.50787 .64546 m
.50778 .64596 L
s
1 .436 0 r
.23514 .56598 m
.24208 .54724 L
s
1 .11 0 r
.31012 .48493 m
.31126 .4858 L
s
.30887 .48601 m
.31012 .48493 L
s
.31012 .48493 m
.30971 .48489 L
s
1 .142 0 r
.31829 .64715 m
.31692 .64544 L
s
.31692 .64544 m
.31925 .64475 L
s
1 .003 0 r
.71798 .53937 m
.718 .53923 L
s
.71799 .53923 m
.71803 .53926 L
s
.71796 .53926 m
.71799 .53923 L
s
.71799 .53923 m
.718 .53923 L
s
.71803 .53926 m
.718 .53929 L
s
.718 .53923 m
.71803 .53926 L
s
.718 .53929 m
.71796 .53926 L
s
.71796 .53926 m
.718 .53923 L
s
.718 .53923 m
.718 .53929 L
s
1 .01 0 r
.50426 .48615 m
.50419 .48568 L
s
1 .142 0 r
.31925 .64475 m
.31829 .64715 L
s
1 .11 0 r
.31001 .48688 m
.30887 .48601 L
s
.30887 .48601 m
.30971 .48489 L
s
1 .088 0 r
.29049 .43292 m
.28712 .42918 L
s
1 0 0 r
.77345 .4063 m
.77345 .40629 L
s
.77345 .40629 m
.77345 .40629 L
s
.77344 .40629 m
.77345 .40629 L
s
.77345 .40629 m
.77345 .40629 L
s
.77345 .40629 m
.77344 .40629 L
s
.77344 .40629 m
.77345 .40629 L
s
.77345 .40629 m
.77345 .40629 L
s
.77345 .40629 m
.77345 .40629 L
s
.77345 .40629 m
.77345 .40629 L
s
1 .01 0 r
.5042 .48568 m
.50431 .48577 L
s
.50409 .48578 m
.5042 .48568 L
s
.5042 .48568 m
.50419 .48568 L
s
1 .11 0 r
.31126 .4858 m
.31001 .48688 L
s
.30971 .48489 m
.31126 .4858 L
s
1 .01 0 r
.5042 .48586 m
.50409 .48578 L
s
.50409 .48578 m
.50419 .48568 L
s
1 .014 0 r
.60402 .64491 m
.6042 .6443 L
s
1 .01 0 r
.50431 .48577 m
.5042 .48586 L
s
.50419 .48568 m
.50431 .48577 L
s
.50419 .48568 m
.5042 .48586 L
s
1 0 0 r
.55968 .35306 m
.55967 .35304 L
s
.55967 .35304 m
.55968 .35304 L
s
.55967 .35304 m
.55967 .35304 L
s
.55967 .35304 m
.55967 .35304 L
s
.55967 .35305 m
.55967 .35304 L
s
.55967 .35304 m
.55967 .35304 L
s
.55968 .35304 m
.55967 .35305 L
s
.55967 .35304 m
.55968 .35304 L
s
.55967 .35304 m
.55967 .35305 L
s
1 .226 0 r
.27294 .50906 m
.2753 .51106 L
s
.27032 .51108 m
.27294 .50906 L
s
.27294 .50906 m
.27253 .509 L
s
1 .067 0 r
.39022 .59168 m
.39081 .58877 L
s
1 .002 0 r
.87327 .56507 m
.87328 .56499 L
s
1 .049 0 r
.34835 .45828 m
.34885 .45863 L
s
.34781 .45878 m
.34835 .45828 L
s
.34835 .45828 m
.34813 .45826 L
s
1 .002 0 r
.87328 .56499 m
.8733 .56501 L
s
.87326 .56501 m
.87328 .56499 L
s
.87328 .56499 m
.87328 .56499 L
s
.8733 .56501 m
.87328 .56502 L
s
.87328 .56499 m
.8733 .56501 L
s
.87328 .56502 m
.87326 .56501 L
s
.87326 .56501 m
.87328 .56499 L
s
.87328 .56499 m
.87328 .56502 L
s
1 .102 0 r
.35399 .61666 m
.35504 .61777 L
s
.35286 .61741 m
.35399 .61666 L
s
.35399 .61666 m
.35432 .61674 L
s
1 .324 0 r
.23449 .649 m
.23255 .64435 L
s
.23871 .64454 m
.23449 .649 L
s
0 .044 1 r
.17639 .53845 m
.23924 .35209 L
s
1 .324 0 r
.23255 .64435 m
.23871 .64454 L
s
1 .11 0 r
.30971 .48489 m
.31001 .48688 L
s
1 .014 0 r
.60416 .64429 m
.60432 .64443 L
s
.60401 .64441 m
.60416 .64429 L
s
.60416 .64429 m
.6042 .6443 L
s
1 .049 0 r
.34831 .45914 m
.34781 .45878 L
s
.34781 .45878 m
.34813 .45826 L
s
1 .042 0 r
.44928 .61736 m
.44973 .61779 L
s
.44881 .6177 m
.44928 .61736 L
s
.44928 .61736 m
.44937 .61738 L
s
1 .004 0 r
.65947 .51183 m
.65947 .51166 L
s
1 .014 0 r
.60432 .64443 m
.60417 .64455 L
s
.6042 .6443 m
.60432 .64443 L
s
.60417 .64455 m
.60401 .64441 L
s
.60401 .64441 m
.6042 .6443 L
s
.6042 .6443 m
.60417 .64455 L
s
1 .004 0 r
.65947 .51166 m
.65951 .51169 L
s
.65943 .51169 m
.65947 .51166 L
s
.65947 .51166 m
.65947 .51166 L
s
.65947 .51172 m
.65943 .51169 L
s
.65943 .51169 m
.65947 .51166 L
s
1 .049 0 r
.34885 .45863 m
.34831 .45914 L
s
.34813 .45826 m
.34885 .45863 L
s
1 .004 0 r
.65951 .51169 m
.65947 .51172 L
s
.65947 .51166 m
.65951 .51169 L
s
1 .042 0 r
.44973 .61779 m
.44926 .61813 L
s
.44937 .61738 m
.44973 .61779 L
s
1 .004 0 r
.65947 .51166 m
.65947 .51172 L
s
1 .102 0 r
.35504 .61777 m
.35391 .61852 L
s
.35432 .61674 m
.35504 .61777 L
s
1 .014 0 r
.44563 .45858 m
.44544 .45793 L
s
1 .042 0 r
.44926 .61813 m
.44881 .6177 L
s
.44881 .6177 m
.44937 .61738 L
s
1 .049 0 r
.34813 .45826 m
.34831 .45914 L
s
1 .042 0 r
.44937 .61738 m
.44926 .61813 L
s
1 0 0 r
.71495 .37869 m
.71494 .37867 L
s
.71494 .37867 m
.71495 .37868 L
s
.71494 .37868 m
.71494 .37867 L
s
.71494 .37867 m
.71494 .37867 L
s
.71495 .37868 m
.71494 .37868 L
s
.71494 .37868 m
.71494 .37867 L
s
.71495 .37868 m
.71495 .37868 L
s
.71494 .37867 m
.71495 .37868 L
s
.71494 .37867 m
.71495 .37868 L
s
1 .102 0 r
.35391 .61852 m
.35286 .61741 L
s
.35286 .61741 m
.35432 .61674 L
s
1 .019 0 r
.54543 .6174 m
.54563 .61657 L
s
1 .014 0 r
.44548 .45794 m
.44563 .45805 L
s
.44532 .45808 m
.44548 .45794 L
s
.44548 .45794 m
.44544 .45793 L
s
1 0 0 r
.50107 .32541 m
.50106 .3254 L
s
.50106 .3254 m
.50107 .3254 L
s
.50106 .3254 m
.50106 .3254 L
s
.50106 .3254 m
.50106 .3254 L
s
.50106 .32541 m
.50106 .3254 L
s
.50106 .3254 m
.50106 .3254 L
s
.50107 .3254 m
.50106 .32541 L
s
.50106 .3254 m
.50107 .3254 L
s
.50106 .3254 m
.50106 .32541 L
s
1 .014 0 r
.44547 .45818 m
.44532 .45808 L
s
.44532 .45808 m
.44544 .45793 L
s
.44563 .45805 m
.44547 .45818 L
s
.44544 .45793 m
.44563 .45805 L
s
1 .118 0 r
.33153 .56415 m
.33194 .55891 L
s
1 .226 0 r
.27267 .51308 m
.27032 .51108 L
s
.27032 .51108 m
.27253 .509 L
s
1 .014 0 r
.44544 .45793 m
.44547 .45818 L
s
1 .226 0 r
.2753 .51106 m
.27267 .51308 L
s
.27253 .509 m
.2753 .51106 L
s
1 .002 0 r
.81481 .53752 m
.81482 .53744 L
s
1 .102 0 r
.35432 .61674 m
.35391 .61852 L
s
1 .002 0 r
.81481 .53744 m
.81483 .53746 L
s
.81479 .53746 m
.81481 .53744 L
s
.81481 .53744 m
.81482 .53744 L
s
.81483 .53746 m
.81482 .53747 L
s
.81482 .53744 m
.81483 .53746 L
s
.81482 .53747 m
.81479 .53746 L
s
.81479 .53746 m
.81482 .53744 L
s
.81482 .53744 m
.81482 .53747 L
s
1 .004 0 r
.6009 .48425 m
.60088 .48406 L
s
1 .019 0 r
.54559 .61656 m
.5458 .61675 L
s
.54538 .61672 m
.54559 .61656 L
s
.54559 .61656 m
.54563 .61657 L
s
1 .004 0 r
.60088 .48406 m
.60093 .48409 L
s
.60084 .4841 m
.60088 .48406 L
s
.60088 .48406 m
.60088 .48406 L
s
.60088 .48413 m
.60084 .4841 L
s
.60084 .4841 m
.60088 .48406 L
s
.60093 .48409 m
.60088 .48413 L
s
.60088 .48406 m
.60093 .48409 L
s
.60088 .48406 m
.60088 .48413 L
s
1 .02 0 r
.38695 .43098 m
.38647 .43007 L
s
1 .019 0 r
.5458 .61675 m
.54559 .61692 L
s
.54563 .61657 m
.5458 .61675 L
s
.54559 .61692 m
.54538 .61672 L
s
.54538 .61672 m
.54563 .61657 L
s
.54563 .61657 m
.54559 .61692 L
s
1 .008 0 r
.70076 .64315 m
.70086 .64282 L
s
1 0 0 r
.65639 .35104 m
.65639 .35103 L
s
.65639 .35103 m
.65639 .35103 L
s
.65639 .35103 m
.65639 .35103 L
s
.65639 .35103 m
.65639 .35103 L
s
.65639 .35104 m
.65639 .35103 L
s
.65639 .35103 m
.65639 .35103 L
s
.65639 .35103 m
.65639 .35104 L
s
.65639 .35103 m
.65639 .35103 L
s
.65639 .35103 m
.65639 .35104 L
s
1 .027 0 r
.48679 .58988 m
.48697 .58868 L
s
1 .008 0 r
.70084 .64281 m
.70093 .64289 L
s
.70076 .64288 m
.70084 .64281 L
s
.70084 .64281 m
.70086 .64282 L
s
.70093 .64289 m
.70084 .64296 L
s
.70086 .64282 m
.70093 .64289 L
s
.70084 .64296 m
.70076 .64288 L
s
.70076 .64288 m
.70086 .64282 L
s
1 .596 0 r
.2007 .44888 m
.20617 .45264 L
s
.19434 .45556 m
.2007 .44888 L
s
.2007 .44888 m
.19608 .44887 L
s
1 0 0 r
.4424 .29774 m
.4424 .29774 L
s
.4424 .29774 m
.4424 .29774 L
s
.4424 .29774 m
.4424 .29774 L
s
.4424 .29774 m
.4424 .29774 L
s
.4424 .29774 m
.4424 .29774 L
s
.4424 .29774 m
.4424 .29774 L
s
.4424 .29774 m
.4424 .29774 L
s
.4424 .29774 m
.4424 .29774 L
s
.4424 .29774 m
.4424 .29774 L
s
1 .008 0 r
.70086 .64282 m
.70084 .64296 L
s
1 .24 0 r
.27278 .53659 m
.27129 .52568 L
s
1 .088 0 r
.28784 .42916 m
.28864 .42967 L
s
.28695 .43019 m
.28784 .42916 L
s
.28784 .42916 m
.28712 .42918 L
s
1 .067 0 r
.39071 .58874 m
.39142 .58942 L
s
.38995 .58929 m
.39071 .58874 L
s
.39071 .58874 m
.39081 .58877 L
s
1 .02 0 r
.38657 .43008 m
.38678 .43022 L
s
.38636 .43029 m
.38657 .43008 L
s
.38657 .43008 m
.38647 .43007 L
s
1 .226 0 r
.27253 .509 m
.27267 .51308 L
s
1 .27 0 r
.26453 .61247 m
.26697 .61586 L
s
.26176 .61401 m
.26453 .61247 L
s
.26453 .61247 m
.26641 .61297 L
s
1 .002 0 r
.75629 .50995 m
.75629 .50986 L
s
1 .02 0 r
.38656 .43042 m
.38636 .43029 L
s
.38636 .43029 m
.38647 .43007 L
s
1 .002 0 r
.75629 .50986 m
.75631 .50988 L
s
.75627 .50988 m
.75629 .50986 L
s
.75629 .50986 m
.75629 .50986 L
s
.75629 .5099 m
.75627 .50988 L
s
.75627 .50988 m
.75629 .50986 L
s
.75631 .50988 m
.75629 .5099 L
s
.75629 .50986 m
.75631 .50988 L
s
1 .02 0 r
.38678 .43022 m
.38656 .43042 L
s
.38647 .43007 m
.38678 .43022 L
s
1 .002 0 r
.75629 .50986 m
.75629 .5099 L
s
1 .088 0 r
.28775 .43069 m
.28695 .43019 L
s
.28695 .43019 m
.28712 .42918 L
s
1 .02 0 r
.38647 .43007 m
.38656 .43042 L
s
1 .005 0 r
.54227 .45665 m
.54222 .45642 L
s
1 .067 0 r
.39142 .58942 m
.39067 .58996 L
s
.39081 .58877 m
.39142 .58942 L
s
1 .27 0 r
.26697 .61586 m
.2642 .6174 L
s
.26641 .61297 m
.26697 .61586 L
s
1 .067 0 r
.39067 .58996 m
.38995 .58929 L
s
.38995 .58929 m
.39081 .58877 L
s
1 .005 0 r
.54223 .45642 m
.54229 .45646 L
s
.54217 .45647 m
.54223 .45642 L
s
.54223 .45642 m
.54222 .45642 L
s
.54223 .45651 m
.54217 .45647 L
s
.54217 .45647 m
.54222 .45642 L
s
.54229 .45646 m
.54223 .45651 L
s
.54222 .45642 m
.54229 .45646 L
s
1 .029 0 r
.32821 .40335 m
.32709 .40209 L
s
1 .005 0 r
.54222 .45642 m
.54223 .45651 L
s
1 0 0 r
.81184 .37669 m
.81184 .37668 L
s
.81184 .37668 m
.81184 .37668 L
s
.81183 .37668 m
.81184 .37668 L
s
.81184 .37668 m
.81184 .37668 L
s
.81184 .37669 m
.81183 .37668 L
s
.81183 .37668 m
.81184 .37668 L
s
.81184 .37668 m
.81184 .37669 L
s
.81184 .37668 m
.81184 .37668 L
s
.81184 .37668 m
.81184 .37669 L
s
1 .01 0 r
.64217 .61562 m
.64227 .6152 L
s
1 .027 0 r
.48693 .58867 m
.48723 .58893 L
s
.48663 .5889 m
.48693 .58867 L
s
.48693 .58867 m
.48697 .58868 L
s
1 .067 0 r
.39081 .58877 m
.39067 .58996 L
s
1 .425 0 r
.24213 .53009 m
.24646 .53469 L
s
.23723 .53312 m
.24213 .53009 L
s
.24213 .53009 m
.24321 .5302 L
s
1 .088 0 r
.28864 .42967 m
.28775 .43069 L
s
.28712 .42918 m
.28864 .42967 L
s
1 0 0 r
.59778 .32337 m
.59777 .32336 L
s
.59777 .32337 m
.59777 .32337 L
s
.59777 .32337 m
.59777 .32337 L
s
.59777 .32337 m
.59777 .32336 L
s
.59777 .32337 m
.59777 .32337 L
s
.59777 .32337 m
.59777 .32336 L
s
.59777 .32337 m
.59777 .32337 L
s
.59777 .32336 m
.59777 .32337 L
s
.59777 .32336 m
.59777 .32337 L
s
1 .027 0 r
.48723 .58893 m
.48693 .58917 L
s
.48697 .58868 m
.48723 .58893 L
s
.48693 .58917 m
.48663 .5889 L
s
.48663 .5889 m
.48697 .58868 L
s
1 .041 0 r
.42809 .56232 m
.42816 .56048 L
s
1 .088 0 r
.28712 .42918 m
.28775 .43069 L
s
1 .027 0 r
.48697 .58868 m
.48693 .58917 L
s
1 .01 0 r
.64225 .6152 m
.64235 .61529 L
s
.64214 .61528 m
.64225 .6152 L
s
.64225 .6152 m
.64227 .6152 L
s
.64235 .61529 m
.64225 .61538 L
s
.64227 .6152 m
.64235 .61529 L
s
.64225 .61538 m
.64214 .61528 L
s
.64214 .61528 m
.64227 .6152 L
s
1 .629 0 r
.21396 .50901 m
.19189 .48182 L
s
1 .01 0 r
.64227 .6152 m
.64225 .61538 L
s
1 .002 0 r
.69771 .48235 m
.69771 .48226 L
s
.69771 .48226 m
.69773 .48227 L
s
.69769 .48228 m
.69771 .48226 L
s
.69771 .48226 m
.69771 .48226 L
s
.69771 .48229 m
.69769 .48228 L
s
.69769 .48228 m
.69771 .48226 L
s
.69773 .48227 m
.69771 .48229 L
s
.69771 .48226 m
.69773 .48227 L
s
.69771 .48226 m
.69771 .48229 L
s
1 .029 0 r
.32733 .40209 m
.3276 .40225 L
s
.32704 .40243 m
.32733 .40209 L
s
.32733 .40209 m
.32709 .40209 L
s
1 .006 0 r
.48358 .42903 m
.48348 .42874 L
s
1 .234 0 r
.24594 .45237 m
.24805 .45377 L
s
.24352 .45509 m
.24594 .45237 L
s
.24594 .45237 m
.244 .45242 L
s
1 .029 0 r
.3273 .4026 m
.32704 .40243 L
s
.32704 .40243 m
.32709 .40209 L
s
1 .596 0 r
.1998 .45934 m
.19434 .45556 L
s
.19434 .45556 m
.19608 .44887 L
s
1 .004 0 r
.79768 .64139 m
.79774 .6412 L
s
1 .006 0 r
.4835 .42875 m
.48357 .42879 L
s
.48344 .42881 m
.4835 .42875 L
s
.4835 .42875 m
.48348 .42874 L
s
1 .029 0 r
.3276 .40225 m
.3273 .4026 L
s
.32709 .40209 m
.3276 .40225 L
s
1 .006 0 r
.4835 .42885 m
.48344 .42881 L
s
.48344 .42881 m
.48348 .42874 L
s
.48357 .42879 m
.4835 .42885 L
s
.48348 .42874 m
.48357 .42879 L
s
.48348 .42874 m
.4835 .42885 L
s
1 .029 0 r
.32709 .40209 m
.3273 .4026 L
s
1 0 0 r
.75327 .34902 m
.75327 .34902 L
s
.75327 .34902 m
.75327 .34902 L
s
.75327 .34902 m
.75327 .34902 L
s
.75327 .34902 m
.75327 .34902 L
s
.75327 .34902 m
.75327 .34902 L
s
.75327 .34902 m
.75327 .34902 L
s
.75327 .34902 m
.75327 .34902 L
s
.75327 .34902 m
.75327 .34902 L
s
.75327 .34902 m
.75327 .34902 L
s
1 .004 0 r
.79773 .64119 m
.79778 .64124 L
s
.79768 .64123 m
.79773 .64119 L
s
.79773 .64119 m
.79774 .6412 L
s
.79778 .64124 m
.79773 .64128 L
s
.79774 .6412 m
.79778 .64124 L
s
.79773 .64128 m
.79768 .64123 L
s
.79768 .64123 m
.79774 .6412 L
s
.79774 .6412 m
.79773 .64128 L
s
1 .013 0 r
.58353 .58807 m
.5836 .58752 L
s
1 .188 0 r
.2965 .58544 m
.29842 .58748 L
s
.29437 .58681 m
.2965 .58544 L
s
.2965 .58544 m
.29704 .58556 L
s
1 .648 0 r
.22902 .5703 m
.22482 .56109 L
s
.23713 .5611 m
.22902 .5703 L
s
1 0 0 r
.5391 .29567 m
.5391 .29567 L
s
.5391 .29567 m
.5391 .29567 L
s
.5391 .29567 m
.5391 .29567 L
s
.5391 .29567 m
.5391 .29567 L
s
.5391 .29567 m
.5391 .29567 L
s
.5391 .29567 m
.5391 .29567 L
s
.5391 .29567 m
.5391 .29567 L
s
.5391 .29567 m
.5391 .29567 L
s
.5391 .29567 m
.5391 .29567 L
s
1 .234 0 r
.24563 .45649 m
.24352 .45509 L
s
.24352 .45509 m
.244 .45242 L
s
1 .068 0 r
.36933 .53474 m
.36899 .53165 L
s
1 .425 0 r
.24646 .53469 m
.24156 .53772 L
s
.24321 .5302 m
.24646 .53469 L
s
1 .001 0 r
.85328 .50807 m
.85328 .50802 L
s
.85328 .50802 m
.85329 .50803 L
s
.85327 .50803 m
.85328 .50802 L
s
.85328 .50802 m
.85328 .50802 L
s
.85328 .50804 m
.85327 .50803 L
s
.85327 .50803 m
.85328 .50802 L
s
.85329 .50803 m
.85328 .50804 L
s
.85328 .50802 m
.85329 .50803 L
s
.85328 .50802 m
.85328 .50804 L
s
1 .013 0 r
.58359 .58751 m
.58373 .58763 L
s
.58345 .58762 m
.58359 .58751 L
s
.58359 .58751 m
.5836 .58752 L
s
1 .648 0 r
.22482 .56109 m
.23713 .5611 L
s
1 .013 0 r
.58373 .58763 m
.58359 .58774 L
s
.5836 .58752 m
.58373 .58763 L
s
.58359 .58774 m
.58345 .58762 L
s
.58345 .58762 m
.5836 .58752 L
s
1 .041 0 r
.42816 .56047 m
.4286 .56086 L
s
.42769 .56083 m
.42816 .56047 L
s
.42816 .56047 m
.42816 .56048 L
s
1 .002 0 r
.63908 .45473 m
.63906 .45462 L
s
1 .013 0 r
.5836 .58752 m
.58359 .58774 L
s
1 .002 0 r
.63907 .45462 m
.63909 .45464 L
s
.63904 .45464 m
.63907 .45462 L
s
.63907 .45462 m
.63906 .45462 L
s
.63907 .45466 m
.63904 .45464 L
s
.63904 .45464 m
.63906 .45462 L
s
.63909 .45464 m
.63907 .45466 L
s
.63906 .45462 m
.63909 .45464 L
s
.63906 .45462 m
.63907 .45466 L
s
1 .188 0 r
.29842 .58748 m
.29629 .58885 L
s
.29704 .58556 m
.29842 .58748 L
s
1 .041 0 r
.4286 .56086 m
.42814 .56122 L
s
.42816 .56048 m
.4286 .56086 L
s
1 .007 0 r
.42484 .40137 m
.42465 .40104 L
s
1 .27 0 r
.2642 .6174 m
.26176 .61401 L
s
.26176 .61401 m
.26641 .61297 L
s
1 .041 0 r
.42814 .56122 m
.42769 .56083 L
s
.42769 .56083 m
.42816 .56048 L
s
1 .276 0 r
.25502 .64051 m
.26548 .63055 L
s
1 .005 0 r
.73909 .61384 m
.73914 .61361 L
s
1 .041 0 r
.42816 .56048 m
.42814 .56122 L
s
1 .007 0 r
.42469 .40104 m
.42476 .40109 L
s
.42461 .40112 m
.42469 .40104 L
s
.42469 .40104 m
.42465 .40104 L
s
.42468 .40117 m
.42461 .40112 L
s
.42461 .40112 m
.42465 .40104 L
s
.42476 .40109 m
.42468 .40117 L
s
.42465 .40104 m
.42476 .40109 L
s
1 0 0 r
.69466 .32132 m
.69465 .32132 L
s
.69465 .32132 m
.69466 .32132 L
s
.69465 .32132 m
.69465 .32132 L
s
.69465 .32132 m
.69465 .32132 L
s
.69465 .32132 m
.69465 .32132 L
s
.69465 .32132 m
.69465 .32132 L
s
.69466 .32132 m
.69465 .32132 L
s
.69465 .32132 m
.69466 .32132 L
s
.69465 .32132 m
.69465 .32132 L
s
1 .007 0 r
.42465 .40104 m
.42468 .40117 L
s
1 .27 0 r
.26641 .61297 m
.2642 .6174 L
s
1 .118 0 r
.33191 .5589 m
.33316 .56004 L
s
.33056 .55989 m
.33191 .5589 L
s
.33191 .5589 m
.33194 .55891 L
s
1 .005 0 r
.73913 .6136 m
.73919 .61366 L
s
.73907 .61365 m
.73913 .6136 L
s
.73913 .6136 m
.73914 .61361 L
s
1 .017 0 r
.52482 .56049 m
.52486 .55973 L
s
1 .005 0 r
.73919 .61366 m
.73913 .6137 L
s
.73914 .61361 m
.73919 .61366 L
s
.73913 .6137 m
.73907 .61365 L
s
.73907 .61365 m
.73914 .61361 L
s
.73914 .61361 m
.73913 .6137 L
s
1 0 0 r
.48037 .26794 m
.48037 .26794 L
s
.48037 .26794 m
.48037 .26794 L
s
.48037 .26794 m
.48037 .26794 L
s
.48037 .26794 m
.48037 .26794 L
s
.48037 .26794 m
.48037 .26794 L
s
.48037 .26794 m
.48037 .26794 L
s
.48037 .26794 m
.48037 .26794 L
s
.48037 .26794 m
.48037 .26794 L
s
.48037 .26794 m
.48037 .26794 L
s
1 .125 0 r
.31051 .50713 m
.30848 .50142 L
s
1 .188 0 r
.29629 .58885 m
.29437 .58681 L
s
.29437 .58681 m
.29704 .58556 L
s
1 .001 0 r
.7947 .48045 m
.7947 .48039 L
s
.7947 .4804 m
.79471 .4804 L
s
.79469 .48041 m
.7947 .4804 L
s
.7947 .4804 m
.7947 .48039 L
s
.7947 .48041 m
.79469 .48041 L
s
.79469 .48041 m
.7947 .48039 L
s
.79471 .4804 m
.7947 .48041 L
s
.7947 .48039 m
.79471 .4804 L
s
.7947 .48039 m
.7947 .48041 L
s
1 .234 0 r
.24805 .45377 m
.24563 .45649 L
s
.244 .45242 m
.24805 .45377 L
s
1 .118 0 r
.33316 .56004 m
.33181 .56103 L
s
.33194 .55891 m
.33316 .56004 L
s
1 .002 0 r
.58039 .42707 m
.58036 .42696 L
s
1 .017 0 r
.52485 .55973 m
.52504 .55989 L
s
.52466 .55988 m
.52485 .55973 L
s
.52485 .55973 m
.52486 .55973 L
s
1 .002 0 r
.58036 .42696 m
.58039 .42698 L
s
.58034 .42699 m
.58036 .42696 L
s
.58036 .42696 m
.58036 .42696 L
s
.58036 .427 m
.58034 .42699 L
s
.58034 .42699 m
.58036 .42696 L
s
.58039 .42698 m
.58036 .427 L
s
.58036 .42696 m
.58039 .42698 L
s
.58036 .42696 m
.58036 .427 L
s
1 .118 0 r
.33181 .56103 m
.33056 .55989 L
s
.33056 .55989 m
.33194 .55891 L
s
1 .017 0 r
.52504 .55989 m
.52485 .56004 L
s
.52486 .55973 m
.52504 .55989 L
s
.52485 .56004 m
.52466 .55988 L
s
.52466 .55988 m
.52486 .55973 L
s
1 .003 0 r
.89478 .63963 m
.89481 .63951 L
s
1 .009 0 r
.36604 .37369 m
.36571 .37332 L
s
1 .017 0 r
.52486 .55973 m
.52485 .56004 L
s
1 .003 0 r
.8948 .63951 m
.89484 .63953 L
s
.89478 .63953 m
.8948 .63951 L
s
.8948 .63951 m
.89481 .63951 L
s
1 .659 0 r
.19613 .61294 m
.23516 .59612 L
s
1 .003 0 r
.89484 .63953 m
.89481 .63956 L
s
.89481 .63951 m
.89484 .63953 L
s
.89481 .63956 m
.89478 .63953 L
s
.89478 .63953 m
.89481 .63951 L
s
.89481 .63951 m
.89481 .63956 L
s
1 .425 0 r
.24156 .53772 m
.23723 .53312 L
s
.23723 .53312 m
.24321 .5302 L
s
1 .188 0 r
.29704 .58556 m
.29629 .58885 L
s
1 .006 0 r
.68044 .58626 m
.68048 .58598 L
s
1 .234 0 r
.244 .45242 m
.24563 .45649 L
s
1 .009 0 r
.36578 .37332 m
.36586 .37337 L
s
.36569 .37342 m
.36578 .37332 L
s
.36578 .37332 m
.36571 .37332 L
s
.36577 .37347 m
.36569 .37342 L
s
.36569 .37342 m
.36571 .37332 L
s
1 0 0 r
.63598 .2936 m
.63598 .2936 L
s
.63598 .2936 m
.63598 .2936 L
s
.63598 .2936 m
.63598 .2936 L
s
.63598 .2936 m
.63598 .2936 L
s
.63598 .2936 m
.63598 .2936 L
s
.63598 .2936 m
.63598 .2936 L
s
.63598 .2936 m
.63598 .2936 L
s
.63598 .2936 m
.63598 .2936 L
s
.63598 .2936 m
.63598 .2936 L
s
1 .009 0 r
.36586 .37337 m
.36577 .37347 L
s
.36571 .37332 m
.36586 .37337 L
s
.36571 .37332 m
.36577 .37347 L
s
1 .024 0 r
.46606 .53288 m
.46598 .53179 L
s
1 .006 0 r
.68047 .58598 m
.68054 .58603 L
s
.6804 .58603 m
.68047 .58598 L
s
.68047 .58598 m
.68048 .58598 L
s
.68054 .58603 m
.68047 .58609 L
s
.68048 .58598 m
.68054 .58603 L
s
.68047 .58609 m
.6804 .58603 L
s
.6804 .58603 m
.68048 .58598 L
s
1 .118 0 r
.33194 .55891 m
.33181 .56103 L
s
1 .006 0 r
.68048 .58598 m
.68047 .58609 L
s
1 .257 0 r
.25164 .47949 m
.24186 .46857 L
s
1 .001 0 r
.73606 .45279 m
.73606 .45274 L
s
1 .068 0 r
.36908 .53166 m
.36981 .53226 L
s
.3683 .53227 m
.36908 .53166 L
s
.36908 .53166 m
.36899 .53165 L
s
1 .001 0 r
.73606 .45274 m
.73607 .45275 L
s
.73604 .45275 m
.73606 .45274 L
s
.73606 .45274 m
.73606 .45274 L
s
.73606 .45276 m
.73604 .45275 L
s
.73604 .45275 m
.73606 .45274 L
s
.73607 .45275 m
.73606 .45276 L
s
.73606 .45274 m
.73607 .45275 L
s
.73606 .45274 m
.73606 .45276 L
s
1 .596 0 r
.20617 .45264 m
.1998 .45934 L
s
.19608 .44887 m
.20617 .45264 L
s
1 .002 0 r
.52164 .39939 m
.52159 .39928 L
s
.5216 .39928 m
.52163 .3993 L
s
.52157 .3993 m
.5216 .39928 L
s
.5216 .39928 m
.52159 .39928 L
s
.5216 .39932 m
.52157 .3993 L
s
.52157 .3993 m
.52159 .39928 L
s
1 .108 0 r
.35167 .63874 m
.35365 .63426 L
s
1 .002 0 r
.52163 .3993 m
.5216 .39932 L
s
.52159 .39928 m
.52163 .3993 L
s
.52159 .39928 m
.5216 .39932 L
s
1 .068 0 r
.36903 .53288 m
.3683 .53227 L
s
.3683 .53227 m
.36899 .53165 L
s
.36981 .53226 m
.36903 .53288 L
s
.36899 .53165 m
.36981 .53226 L
s
1 .003 0 r
.83618 .61205 m
.83621 .61191 L
s
.8362 .61191 m
.83624 .61194 L
s
.83617 .61194 m
.8362 .61191 L
s
.8362 .61191 m
.83621 .61191 L
s
1 0 0 r
.79171 .31927 m
.79171 .31927 L
s
.79171 .31927 m
.79171 .31927 L
s
.79171 .31927 m
.79171 .31927 L
s
.79171 .31927 m
.79171 .31927 L
s
.79171 .31927 m
.79171 .31927 L
s
.79171 .31927 m
.79171 .31927 L
s
.79171 .31927 m
.79171 .31927 L
s
.79171 .31927 m
.79171 .31927 L
s
.79171 .31927 m
.79171 .31927 L
s
1 .024 0 r
.466 .53179 m
.46626 .532 L
s
.46573 .53201 m
.466 .53179 L
s
.466 .53179 m
.46598 .53179 L
s
1 .003 0 r
.83624 .61194 m
.83621 .61197 L
s
.83621 .61191 m
.83624 .61194 L
s
.83621 .61197 m
.83617 .61194 L
s
.83617 .61194 m
.83621 .61191 L
s
.83621 .61191 m
.83621 .61197 L
s
1 .008 0 r
.62173 .55865 m
.62175 .5583 L
s
1 .654 0 r
.23313 .58526 m
.22797 .58784 L
s
.22887 .57595 m
.23313 .58526 L
s
.23619 .57851 m
.23313 .58526 L
s
1 .024 0 r
.46599 .53222 m
.46573 .53201 L
s
.46573 .53201 m
.46598 .53179 L
s
.46626 .532 m
.46599 .53222 L
s
.46598 .53179 m
.46626 .532 L
s
1 .068 0 r
.36899 .53165 m
.36903 .53288 L
s
1 0 0 r
.57724 .26585 m
.57724 .26585 L
s
.57724 .26585 m
.57724 .26585 L
s
.57724 .26585 m
.57724 .26585 L
s
.57724 .26585 m
.57724 .26585 L
s
.57724 .26585 m
.57724 .26585 L
s
.57724 .26585 m
.57724 .26585 L
s
.57724 .26585 m
.57724 .26585 L
s
.57724 .26585 m
.57724 .26585 L
s
.57724 .26585 m
.57724 .26585 L
s
1 .024 0 r
.46598 .53179 m
.46599 .53222 L
s
1 .425 0 r
.24321 .5302 m
.24156 .53772 L
s
1 .037 0 r
.40724 .50524 m
.40685 .50356 L
s
1 .008 0 r
.62174 .5583 m
.62183 .55837 L
s
.62166 .55837 m
.62174 .5583 L
s
.62174 .5583 m
.62175 .5583 L
s
.62183 .55837 m
.62175 .55844 L
s
.62175 .5583 m
.62183 .55837 L
s
.62175 .55844 m
.62166 .55837 L
s
.62166 .55837 m
.62175 .5583 L
s
.62175 .5583 m
.62175 .55844 L
s
1 .654 0 r
.2237 .57851 m
.22887 .57595 L
s
.22887 .57595 m
.23619 .57851 L
s
1 .001 0 r
.67736 .42512 m
.67736 .42507 L
s
.67736 .42507 m
.67737 .42507 L
s
.67735 .42508 m
.67736 .42507 L
s
.67736 .42507 m
.67736 .42507 L
s
.67736 .42508 m
.67735 .42508 L
s
.67735 .42508 m
.67736 .42507 L
s
.67737 .42507 m
.67736 .42508 L
s
.67736 .42507 m
.67737 .42507 L
s
.67736 .42507 m
.67736 .42508 L
s
1 .002 0 r
.46283 .37169 m
.46276 .37157 L
s
.46278 .37157 m
.4628 .37159 L
s
.46275 .3716 m
.46278 .37157 L
s
.46278 .37157 m
.46276 .37157 L
s
.46278 .37162 m
.46275 .3716 L
s
.46275 .3716 m
.46276 .37157 L
s
1 .196 0 r
.29277 .61115 m
.29614 .60291 L
s
1 .002 0 r
.4628 .37159 m
.46278 .37162 L
s
.46276 .37157 m
.4628 .37159 L
s
.46276 .37157 m
.46278 .37162 L
s
1 .004 0 r
.77752 .58444 m
.77755 .58429 L
s
1 0 0 r
.73303 .29152 m
.73303 .29152 L
s
.73303 .29152 m
.73303 .29152 L
s
.73303 .29152 m
.73303 .29152 L
s
.73303 .29152 m
.73303 .29152 L
s
.73303 .29152 m
.73303 .29152 L
s
.73303 .29152 m
.73303 .29152 L
s
.73303 .29152 m
.73303 .29152 L
s
.73303 .29152 m
.73303 .29152 L
s
.73303 .29152 m
.73303 .29152 L
s
1 .004 0 r
.77754 .58429 m
.77758 .58432 L
s
.7775 .58432 m
.77754 .58429 L
s
.77754 .58429 m
.77755 .58429 L
s
.77758 .58432 m
.77754 .58435 L
s
.77755 .58429 m
.77758 .58432 L
s
.77754 .58435 m
.7775 .58432 L
s
.7775 .58432 m
.77755 .58429 L
s
.77755 .58429 m
.77754 .58435 L
s
1 .596 0 r
.19608 .44887 m
.1998 .45934 L
s
1 .01 0 r
.56296 .53102 m
.56294 .53056 L
s
1 .061 0 r
.34836 .47758 m
.34706 .47482 L
s
1 .001 0 r
.83321 .45086 m
.83321 .45083 L
s
.83321 .45083 m
.83322 .45084 L
s
.83321 .45084 m
.83321 .45083 L
s
.83321 .45083 m
.83321 .45083 L
s
.83322 .45084 m
.83321 .45084 L
s
.83321 .45084 m
.83321 .45083 L
s
.83322 .45084 m
.83322 .45084 L
s
.83321 .45083 m
.83322 .45084 L
s
.83321 .45083 m
.83322 .45084 L
s
1 .037 0 r
.40694 .50357 m
.40733 .50388 L
s
.40652 .50393 m
.40694 .50357 L
s
.40694 .50357 m
.40685 .50356 L
s
1 .01 0 r
.56295 .53056 m
.56306 .53065 L
s
.56284 .53065 m
.56295 .53056 L
s
.56295 .53056 m
.56294 .53056 L
s
.56295 .53074 m
.56284 .53065 L
s
.56284 .53065 m
.56294 .53056 L
s
.56306 .53065 m
.56295 .53074 L
s
.56294 .53056 m
.56306 .53065 L
s
.56294 .53056 m
.56295 .53074 L
s
1 .037 0 r
.40691 .50423 m
.40652 .50393 L
s
.40652 .50393 m
.40685 .50356 L
s
1 .001 0 r
.61861 .39741 m
.6186 .39736 L
s
.6186 .39736 m
.61861 .39737 L
s
.61859 .39737 m
.6186 .39736 L
s
.6186 .39736 m
.6186 .39736 L
s
.6186 .39738 m
.61859 .39737 L
s
.61859 .39737 m
.6186 .39736 L
s
.61861 .39737 m
.6186 .39738 L
s
.6186 .39736 m
.61861 .39737 L
s
.6186 .39736 m
.6186 .39738 L
s
1 .037 0 r
.40733 .50388 m
.40691 .50423 L
s
.40685 .50356 m
.40733 .50388 L
s
1 .047 0 r
.44849 .63697 m
.44906 .63498 L
s
1 .002 0 r
.40397 .34395 m
.40388 .34386 L
s
1 .037 0 r
.40685 .50356 m
.40691 .50423 L
s
1 .002 0 r
.4039 .34386 m
.40392 .34387 L
s
.40388 .34388 m
.4039 .34386 L
s
.4039 .34386 m
.40388 .34386 L
s
.4039 .34389 m
.40388 .34388 L
s
.40388 .34388 m
.40388 .34386 L
s
.40392 .34387 m
.4039 .34389 L
s
.40388 .34386 m
.40392 .34387 L
s
.40388 .34386 m
.4039 .34389 L
s
1 .444 0 r
.23382 .58353 m
.24091 .56453 L
s
1 .004 0 r
.7188 .55681 m
.71882 .55663 L
s
1 0 0 r
.67429 .26374 m
.67429 .26374 L
s
.67429 .26374 m
.67429 .26374 L
s
.67429 .26374 m
.67429 .26374 L
s
.67429 .26374 m
.67429 .26374 L
s
.67429 .26374 m
.67429 .26374 L
s
.67429 .26374 m
.67429 .26374 L
s
.67429 .26374 m
.67429 .26374 L
s
.67429 .26374 m
.67429 .26374 L
s
.67429 .26374 m
.67429 .26374 L
s
1 .004 0 r
.71882 .55663 m
.71886 .55667 L
s
.71877 .55667 m
.71882 .55663 L
s
.71882 .55663 m
.71882 .55663 L
s
.71886 .55667 m
.71882 .5567 L
s
.71882 .55663 m
.71886 .55667 L
s
.71882 .5567 m
.71877 .55667 L
s
.71877 .55667 m
.71882 .55663 L
s
.71882 .55663 m
.71882 .5567 L
s
1 .013 0 r
.50413 .50336 m
.50404 .50275 L
s
1 .125 0 r
.30895 .50145 m
.31025 .50244 L
s
.30752 .50268 m
.30895 .50145 L
s
.30895 .50145 m
.30848 .50142 L
s
1 .108 0 r
.28942 .44989 m
.28525 .4453 L
s
1 .001 0 r
.77451 .42316 m
.77451 .42313 L
s
.77451 .42313 m
.77452 .42313 L
s
.77451 .42314 m
.77451 .42313 L
s
.77451 .42313 m
.77451 .42313 L
s
.77451 .42314 m
.77451 .42314 L
s
.77451 .42314 m
.77451 .42313 L
s
.77452 .42313 m
.77451 .42314 L
s
.77451 .42313 m
.77452 .42313 L
s
.77451 .42313 m
.77451 .42314 L
s
1 .013 0 r
.50406 .50275 m
.5042 .50286 L
s
.50391 .50288 m
.50406 .50275 L
s
.50406 .50275 m
.50404 .50275 L
s
1 .001 0 r
.5598 .36968 m
.55978 .36963 L
s
1 .013 0 r
.50406 .50299 m
.50391 .50288 L
s
.50391 .50288 m
.50404 .50275 L
s
.5042 .50286 m
.50406 .50299 L
s
.50404 .50275 m
.5042 .50286 L
s
1 .001 0 r
.55978 .36964 m
.55979 .36964 L
s
.55977 .36965 m
.55978 .36964 L
s
.55978 .36964 m
.55978 .36963 L
s
.55978 .36965 m
.55977 .36965 L
s
.55977 .36965 m
.55978 .36963 L
s
.55979 .36964 m
.55978 .36965 L
s
.55978 .36963 m
.55979 .36964 L
s
.55978 .36963 m
.55978 .36965 L
s
1 .013 0 r
.50404 .50275 m
.50406 .50299 L
s
1 .074 0 r
.38959 .60936 m
.39023 .60617 L
s
1 .002 0 r
.87478 .58263 m
.8748 .58253 L
s
1 .125 0 r
.30882 .50368 m
.30752 .50268 L
s
.30752 .50268 m
.30848 .50142 L
s
1 .002 0 r
.87479 .58253 m
.87482 .58255 L
s
.87477 .58255 m
.87479 .58253 L
s
.87479 .58253 m
.8748 .58253 L
s
.87482 .58255 m
.87479 .58257 L
s
.8748 .58253 m
.87482 .58255 L
s
.87479 .58257 m
.87477 .58255 L
s
.87477 .58255 m
.8748 .58253 L
s
.8748 .58253 m
.87479 .58257 L
s
0 .043 1 r
.17481 .55589 m
.23785 .37013 L
s
1 .005 0 r
.66003 .52915 m
.66004 .52893 L
s
1 .125 0 r
.31025 .50244 m
.30882 .50368 L
s
.30848 .50142 m
.31025 .50244 L
s
1 .108 0 r
.3533 .63416 m
.35442 .63535 L
s
.35209 .63497 m
.3533 .63416 L
s
.3533 .63416 m
.35365 .63426 L
s
1 .24 0 r
.27173 .52572 m
.27425 .52786 L
s
.26892 .52788 m
.27173 .52572 L
s
.27173 .52572 m
.27129 .52568 L
s
1 .047 0 r
.44896 .63495 m
.44946 .63543 L
s
.44844 .63533 m
.44896 .63495 L
s
.44896 .63495 m
.44906 .63498 L
s
1 .005 0 r
.66003 .52894 m
.66009 .52898 L
s
.65998 .52898 m
.66003 .52894 L
s
.66003 .52894 m
.66004 .52893 L
s
.66004 .52902 m
.65998 .52898 L
s
.65998 .52898 m
.66004 .52893 L
s
.66009 .52898 m
.66004 .52902 L
s
.66004 .52893 m
.66009 .52898 L
s
1 .061 0 r
.34734 .47484 m
.34796 .47528 L
s
.34667 .47546 m
.34734 .47484 L
s
.34734 .47484 m
.34706 .47482 L
s
1 .018 0 r
.44525 .47567 m
.44498 .47482 L
s
1 .005 0 r
.66004 .52893 m
.66004 .52902 L
s
1 .047 0 r
.44946 .63543 m
.44894 .63581 L
s
.44906 .63498 m
.44946 .63543 L
s
1 .061 0 r
.34729 .47591 m
.34667 .47546 L
s
.34667 .47546 m
.34706 .47482 L
s
1 .108 0 r
.35442 .63535 m
.35321 .63616 L
s
.35365 .63426 m
.35442 .63535 L
s
1 .047 0 r
.44894 .63581 m
.44844 .63533 L
s
.44844 .63533 m
.44906 .63498 L
s
1 0 0 r
.71576 .39542 m
.71575 .3954 L
s
.71575 .3954 m
.71576 .39541 L
s
.71575 .39541 m
.71575 .3954 L
s
.71575 .3954 m
.71575 .3954 L
s
.71575 .39541 m
.71575 .39541 L
s
.71575 .39541 m
.71575 .3954 L
s
.71576 .39541 m
.71575 .39541 L
s
.71575 .3954 m
.71576 .39541 L
s
.71575 .3954 m
.71575 .39541 L
s
1 .125 0 r
.30848 .50142 m
.30882 .50368 L
s
1 .022 0 r
.54549 .6352 m
.54571 .63425 L
s
1 .061 0 r
.34796 .47528 m
.34729 .47591 L
s
.34706 .47482 m
.34796 .47528 L
s
1 .047 0 r
.44906 .63498 m
.44894 .63581 L
s
1 .001 0 r
.50093 .34192 m
.50091 .34188 L
s
.50091 .34188 m
.50092 .34189 L
s
.50091 .34189 m
.50091 .34188 L
s
.50091 .34188 m
.50091 .34188 L
s
.50091 .3419 m
.50091 .34189 L
s
.50091 .34189 m
.50091 .34188 L
s
.50092 .34189 m
.50091 .3419 L
s
.50091 .34188 m
.50092 .34189 L
s
.50091 .34188 m
.50091 .3419 L
s
1 .127 0 r
.33064 .58171 m
.33108 .57609 L
s
1 .018 0 r
.44504 .47482 m
.44524 .47497 L
s
.44483 .47501 m
.44504 .47482 L
s
.44504 .47482 m
.44498 .47482 L
s
1 .061 0 r
.34706 .47482 m
.34729 .47591 L
s
1 .108 0 r
.35321 .63616 m
.35209 .63497 L
s
.35209 .63497 m
.35365 .63426 L
s
1 .018 0 r
.44503 .47515 m
.44483 .47501 L
s
.44483 .47501 m
.44498 .47482 L
s
1 .002 0 r
.81606 .55497 m
.81607 .55487 L
s
1 .018 0 r
.44524 .47497 m
.44503 .47515 L
s
.44498 .47482 m
.44524 .47497 L
s
1 .002 0 r
.81607 .55487 m
.81609 .55489 L
s
.81604 .55489 m
.81607 .55487 L
s
.81607 .55487 m
.81607 .55487 L
s
.81609 .55489 m
.81607 .55491 L
s
.81607 .55487 m
.81609 .55489 L
s
.81607 .55491 m
.81604 .55489 L
s
.81604 .55489 m
.81607 .55487 L
s
.81607 .55487 m
.81607 .55491 L
s
1 .018 0 r
.44498 .47482 m
.44503 .47515 L
s
1 0 0 r
.77151 .26164 m
.77151 .26164 L
s
.77151 .26164 m
.77151 .26164 L
s
.77151 .26164 m
.77151 .26164 L
s
.77151 .26164 m
.77151 .26164 L
s
.77151 .26164 m
.77151 .26164 L
s
.77151 .26164 m
.77151 .26164 L
s
.77151 .26164 m
.77151 .26164 L
s
.77151 .26164 m
.77151 .26164 L
s
.77151 .26164 m
.77151 .26164 L
s
1 .006 0 r
.6012 .50146 m
.60118 .5012 L
s
1 .108 0 r
.35365 .63426 m
.35321 .63616 L
s
1 .006 0 r
.60118 .5012 m
.60125 .50125 L
s
.60112 .50126 m
.60118 .5012 L
s
.60118 .5012 m
.60118 .5012 L
s
1 .027 0 r
.38631 .44795 m
.38564 .44672 L
s
1 .006 0 r
.60118 .50131 m
.60112 .50126 L
s
.60112 .50126 m
.60118 .5012 L
s
.60125 .50125 m
.60118 .50131 L
s
.60118 .5012 m
.60125 .50125 L
s
1 .022 0 r
.54567 .63424 m
.54591 .63446 L
s
.54542 .63443 m
.54567 .63424 L
s
.54567 .63424 m
.54571 .63425 L
s
1 .006 0 r
.60118 .5012 m
.60118 .50131 L
s
1 .24 0 r
.27144 .53003 m
.26892 .52788 L
s
.26892 .52788 m
.27129 .52568 L
s
.27425 .52786 m
.27144 .53003 L
s
.27129 .52568 m
.27425 .52786 L
s
1 .022 0 r
.54591 .63446 m
.54567 .63465 L
s
.54571 .63425 m
.54591 .63446 L
s
.54567 .63465 m
.54542 .63443 L
s
.54542 .63443 m
.54571 .63425 L
s
.54571 .63425 m
.54567 .63465 L
s
1 0 0 r
.65694 .36767 m
.65693 .36765 L
s
.65693 .36765 m
.65694 .36765 L
s
.65693 .36765 m
.65693 .36765 L
s
.65693 .36765 m
.65693 .36765 L
s
.65693 .36765 m
.65693 .36765 L
s
.65693 .36765 m
.65693 .36765 L
s
.65694 .36765 m
.65693 .36765 L
s
.65693 .36765 m
.65694 .36765 L
s
.65693 .36765 m
.65693 .36765 L
s
1 .031 0 r
.48659 .60756 m
.48679 .60619 L
s
1 0 0 r
.442 .31413 m
.44199 .31411 L
s
.44199 .31411 m
.44199 .31411 L
s
.44198 .31412 m
.44199 .31411 L
s
.44199 .31411 m
.44199 .31411 L
s
.44199 .31412 m
.44198 .31412 L
s
.44198 .31412 m
.44199 .31411 L
s
.44199 .31411 m
.44199 .31412 L
s
.44199 .31411 m
.44199 .31411 L
s
.44199 .31411 m
.44199 .31412 L
s
1 .252 0 r
.27162 .55404 m
.27005 .54264 L
s
1 .003 0 r
.75728 .52728 m
.75729 .52717 L
s
.75728 .52717 m
.75731 .52719 L
s
.75726 .52719 m
.75728 .52717 L
s
.75728 .52717 m
.75729 .52717 L
s
.75729 .52721 m
.75726 .52719 L
s
.75726 .52719 m
.75729 .52717 L
s
.75731 .52719 m
.75729 .52721 L
s
.75729 .52717 m
.75731 .52719 L
s
.75729 .52717 m
.75729 .52721 L
s
1 .074 0 r
.39013 .60613 m
.39092 .60688 L
s
.38929 .60674 m
.39013 .60613 L
s
.39013 .60613 m
.39023 .60617 L
s
1 .276 0 r
.26355 .63 m
.26606 .63349 L
s
.26069 .6316 m
.26355 .63 L
s
.26355 .63 m
.26548 .63055 L
s
1 .027 0 r
.38579 .44673 m
.38606 .44691 L
s
.38549 .44701 m
.38579 .44673 L
s
.38579 .44673 m
.38564 .44672 L
s
1 .007 0 r
.54231 .47375 m
.54224 .47343 L
s
1 .027 0 r
.38577 .4472 m
.38549 .44701 L
s
.38549 .44701 m
.38564 .44672 L
s
.38606 .44691 m
.38577 .4472 L
s
.38564 .44672 m
.38606 .44691 L
s
1 .041 0 r
.32731 .42021 m
.32571 .41843 L
s
1 .615 0 r
.19871 .4651 m
.20437 .46904 L
s
.19211 .47204 m
.19871 .4651 L
s
.19871 .4651 m
.1939 .46515 L
s
1 .007 0 r
.54226 .47343 m
.54234 .47349 L
s
.54218 .4735 m
.54226 .47343 L
s
.54226 .47343 m
.54224 .47343 L
s
1 .074 0 r
.39092 .60688 m
.39008 .60748 L
s
.39023 .60617 m
.39092 .60688 L
s
1 .027 0 r
.38564 .44672 m
.38577 .4472 L
s
1 .007 0 r
.54226 .47355 m
.54218 .4735 L
s
.54218 .4735 m
.54224 .47343 L
s
.54234 .47349 m
.54226 .47355 L
s
.54224 .47343 m
.54234 .47349 L
s
1 0 0 r
.81308 .39344 m
.81307 .39342 L
s
1 .007 0 r
.54224 .47343 m
.54226 .47355 L
s
1 0 0 r
.81307 .39342 m
.81308 .39342 L
s
.81307 .39343 m
.81307 .39342 L
s
.81307 .39342 m
.81307 .39342 L
s
.81308 .39343 m
.81307 .39343 L
s
.81307 .39343 m
.81307 .39342 L
s
.81308 .39342 m
.81308 .39343 L
s
.81307 .39342 m
.81308 .39342 L
s
.81307 .39342 m
.81308 .39343 L
s
1 .276 0 r
.26606 .63349 m
.26321 .6351 L
s
.26548 .63055 m
.26606 .63349 L
s
1 .108 0 r
.28614 .44527 m
.28712 .4459 L
s
.28504 .44654 m
.28614 .44527 L
s
.28614 .44527 m
.28525 .4453 L
s
1 .011 0 r
.64266 .63343 m
.64277 .63294 L
s
1 .24 0 r
.27129 .52568 m
.27144 .53003 L
s
1 .074 0 r
.39008 .60748 m
.38929 .60674 L
s
.38929 .60674 m
.39023 .60617 L
s
1 0 0 r
.59806 .33988 m
.59806 .33987 L
s
.59806 .33987 m
.59806 .33987 L
s
.59806 .33987 m
.59806 .33987 L
s
.59806 .33987 m
.59806 .33987 L
s
.59806 .33987 m
.59806 .33987 L
s
.59806 .33987 m
.59806 .33987 L
s
.59806 .33987 m
.59806 .33987 L
s
.59806 .33987 m
.59806 .33987 L
s
.59806 .33987 m
.59806 .33987 L
s
1 .031 0 r
.48675 .60618 m
.48709 .60649 L
s
.4864 .60645 m
.48675 .60618 L
s
.48675 .60618 m
.48679 .60619 L
s
1 .108 0 r
.28602 .44717 m
.28504 .44654 L
s
.28504 .44654 m
.28525 .4453 L
s
1 .047 0 r
.42762 .57989 m
.42771 .5778 L
s
1 .031 0 r
.48709 .60649 m
.48675 .60675 L
s
.48679 .60619 m
.48709 .60649 L
s
1 .074 0 r
.39023 .60617 m
.39008 .60748 L
s
1 .031 0 r
.48675 .60675 m
.4864 .60645 L
s
.4864 .60645 m
.48679 .60619 L
s
1 .436 0 r
.24098 .54708 m
.24543 .55181 L
s
.23593 .55021 m
.24098 .54708 L
s
.24098 .54708 m
.24208 .54724 L
s
1 .011 0 r
.64275 .63293 m
.64287 .63304 L
s
.64262 .63303 m
.64275 .63293 L
s
.64275 .63293 m
.64277 .63294 L
s
1 .64 0 r
.21255 .52635 m
.18998 .4988 L
s
1 .011 0 r
.64287 .63304 m
.64275 .63314 L
s
.64277 .63294 m
.64287 .63304 L
s
.64275 .63314 m
.64262 .63303 L
s
.64262 .63303 m
.64277 .63294 L
s
1 .031 0 r
.48679 .60619 m
.48675 .60675 L
s
1 .011 0 r
.64277 .63294 m
.64275 .63314 L
s
1 .003 0 r
.69844 .49957 m
.69844 .49944 L
s
.69844 .49944 m
.69847 .49947 L
s
.69841 .49947 m
.69844 .49944 L
s
.69844 .49944 m
.69844 .49944 L
s
.69844 .49949 m
.69841 .49947 L
s
.69841 .49947 m
.69844 .49944 L
s
.69847 .49947 m
.69844 .49949 L
s
.69844 .49944 m
.69847 .49947 L
s
.69844 .49944 m
.69844 .49949 L
s
1 .009 0 r
.48337 .44601 m
.48322 .4456 L
s
1 .108 0 r
.28712 .4459 m
.28602 .44717 L
s
.28525 .4453 m
.28712 .4459 L
s
1 .009 0 r
.48325 .44561 m
.48334 .44567 L
s
.48315 .4457 m
.48325 .44561 L
s
.48325 .44561 m
.48322 .4456 L
s
1 0 0 r
.75425 .36565 m
.75425 .36564 L
s
.75425 .36564 m
.75426 .36564 L
s
.75425 .36564 m
.75425 .36564 L
s
.75425 .36564 m
.75425 .36564 L
s
.75425 .36564 m
.75425 .36564 L
s
.75425 .36564 m
.75425 .36564 L
s
.75426 .36564 m
.75425 .36564 L
s
.75425 .36564 m
.75426 .36564 L
s
.75425 .36564 m
.75425 .36564 L
s
1 .009 0 r
.48325 .44576 m
.48315 .4457 L
s
.48315 .4457 m
.48322 .4456 L
s
1 .041 0 r
.32605 .41843 m
.32642 .41866 L
s
.32563 .41891 m
.32605 .41843 L
s
.32605 .41843 m
.32571 .41843 L
s
1 .108 0 r
.28525 .4453 m
.28602 .44717 L
s
1 .009 0 r
.48334 .44567 m
.48325 .44576 L
s
.48322 .4456 m
.48334 .44567 L
s
.48322 .4456 m
.48325 .44576 L
s
1 .015 0 r
.58375 .60576 m
.58385 .60511 L
s
1 .041 0 r
.32601 .41915 m
.32563 .41891 L
s
.32563 .41891 m
.32571 .41843 L
s
1 0 0 r
.53913 .31207 m
.53913 .31206 L
s
.53913 .31206 m
.53913 .31206 L
s
.53913 .31206 m
.53913 .31206 L
s
.53913 .31206 m
.53913 .31206 L
s
.53913 .31206 m
.53913 .31206 L
s
.53913 .31206 m
.53913 .31206 L
s
.53913 .31206 m
.53913 .31206 L
s
.53913 .31206 m
.53913 .31206 L
s
.53913 .31206 m
.53913 .31206 L
s
1 .077 0 r
.36861 .5522 m
.36821 .54872 L
s
1 .654 0 r
.22797 .58784 m
.2237 .57851 L
s
.23619 .57851 m
.22797 .58784 L
s
1 .041 0 r
.32642 .41866 m
.32601 .41915 L
s
.32571 .41843 m
.32642 .41866 L
s
1 .615 0 r
.19776 .476 m
.19211 .47204 L
s
.19211 .47204 m
.1939 .46515 L
s
1 .257 0 r
.24399 .46849 m
.24632 .47005 L
s
.24133 .47149 m
.24399 .46849 L
s
.24399 .46849 m
.24186 .46857 L
s
1 .001 0 r
.8547 .52541 m
.85471 .52534 L
s
1 .196 0 r
.29557 .60276 m
.29759 .60491 L
s
.29333 .60421 m
.29557 .60276 L
s
.29557 .60276 m
.29614 .60291 L
s
1 .001 0 r
.85471 .52534 m
.85472 .52536 L
s
.85469 .52536 m
.85471 .52534 L
s
.85471 .52534 m
.85471 .52534 L
s
.85471 .52537 m
.85469 .52536 L
s
.85469 .52536 m
.85471 .52534 L
s
.85472 .52536 m
.85471 .52537 L
s
.85471 .52534 m
.85472 .52536 L
s
1 .041 0 r
.32571 .41843 m
.32601 .41915 L
s
1 .001 0 r
.85471 .52534 m
.85471 .52537 L
s
1 .015 0 r
.58382 .60511 m
.58399 .60525 L
s
.58366 .60524 m
.58382 .60511 L
s
.58382 .60511 m
.58385 .60511 L
s
1 .003 0 r
.63955 .47183 m
.63953 .47168 L
s
1 .015 0 r
.58399 .60525 m
.58383 .60538 L
s
.58385 .60511 m
.58399 .60525 L
s
.58383 .60538 m
.58366 .60524 L
s
.58366 .60524 m
.58385 .60511 L
s
1 .003 0 r
.63954 .47169 m
.63957 .47171 L
s
.6395 .47172 m
.63954 .47169 L
s
.63954 .47169 m
.63953 .47168 L
s
1 .654 0 r
.2237 .57851 m
.23619 .57851 L
s
1 .436 0 r
.24543 .55181 m
.24039 .55496 L
s
.24208 .54724 m
.24543 .55181 L
s
1 .003 0 r
.63954 .47174 m
.6395 .47172 L
s
.6395 .47172 m
.63953 .47168 L
s
.63957 .47171 m
.63954 .47174 L
s
.63953 .47168 m
.63957 .47171 L
s
.63953 .47168 m
.63954 .47174 L
s
1 .015 0 r
.58385 .60511 m
.58383 .60538 L
s
1 .047 0 r
.4277 .57779 m
.42821 .57823 L
s
.42717 .5782 m
.4277 .57779 L
s
.4277 .57779 m
.42771 .5778 L
s
1 .011 0 r
.42436 .41824 m
.42407 .41773 L
s
1 .257 0 r
.24365 .47304 m
.24133 .47149 L
s
.24133 .47149 m
.24186 .46857 L
s
1 .006 0 r
.74001 .63165 m
.74007 .63138 L
s
1 .047 0 r
.42821 .57823 m
.42768 .57865 L
s
.42771 .5778 m
.42821 .57823 L
s
1 .196 0 r
.29759 .60491 m
.29535 .60636 L
s
.29614 .60291 m
.29759 .60491 L
s
1 .276 0 r
.26321 .6351 m
.26069 .6316 L
s
.26069 .6316 m
.26548 .63055 L
s
1 .047 0 r
.42768 .57865 m
.42717 .5782 L
s
.42717 .5782 m
.42771 .5778 L
s
1 0 0 r
.69538 .33784 m
.69537 .33783 L
s
.69537 .33783 m
.69538 .33783 L
s
.69537 .33783 m
.69537 .33783 L
s
.69537 .33783 m
.69537 .33783 L
s
.69537 .33783 m
.69537 .33783 L
s
.69537 .33783 m
.69537 .33783 L
s
.69538 .33783 m
.69537 .33783 L
s
.69537 .33783 m
.69538 .33783 L
s
.69537 .33783 m
.69537 .33783 L
s
1 .011 0 r
.42413 .41773 m
.42424 .41781 L
s
.42401 .41785 m
.42413 .41773 L
s
.42413 .41773 m
.42407 .41773 L
s
.42412 .41793 m
.42401 .41785 L
s
.42401 .41785 m
.42407 .41773 L
s
1 .02 0 r
.52479 .57807 m
.52483 .57717 L
s
1 .006 0 r
.74005 .63138 m
.74013 .63144 L
s
.73999 .63143 m
.74005 .63138 L
s
.74005 .63138 m
.74007 .63138 L
s
.74013 .63144 m
.74006 .63149 L
s
.74007 .63138 m
.74013 .63144 L
s
.74006 .63149 m
.73999 .63143 L
s
.73999 .63143 m
.74007 .63138 L
s
1 .011 0 r
.42424 .41781 m
.42412 .41793 L
s
.42407 .41773 m
.42424 .41781 L
s
1 .006 0 r
.74007 .63138 m
.74006 .63149 L
s
1 .047 0 r
.42771 .5778 m
.42768 .57865 L
s
1 .011 0 r
.42407 .41773 m
.42412 .41793 L
s
1 0 0 r
.48014 .28422 m
.48014 .28422 L
s
.48014 .28422 m
.48014 .28422 L
s
.48014 .28422 m
.48014 .28422 L
s
.48014 .28422 m
.48014 .28422 L
s
.48014 .28422 m
.48014 .28422 L
s
.48014 .28422 m
.48014 .28422 L
s
.48014 .28422 m
.48014 .28422 L
s
.48014 .28422 m
.48014 .28422 L
s
.48014 .28422 m
.48014 .28422 L
s
1 .276 0 r
.26548 .63055 m
.26321 .6351 L
s
1 .139 0 r
.30953 .52447 m
.30727 .51819 L
s
1 .127 0 r
.33105 .57606 m
.33241 .5773 L
s
.32958 .57713 m
.33105 .57606 L
s
.33105 .57606 m
.33108 .57609 L
s
1 .002 0 r
.79586 .49767 m
.79586 .4976 L
s
.79586 .4976 m
.79588 .49762 L
s
.79585 .49762 m
.79586 .4976 L
s
.79586 .4976 m
.79586 .4976 L
s
.79586 .49763 m
.79585 .49762 L
s
.79585 .49762 m
.79586 .4976 L
s
.79588 .49762 m
.79586 .49763 L
s
.79586 .4976 m
.79588 .49762 L
s
.79586 .4976 m
.79586 .49763 L
s
1 .004 0 r
.5806 .44406 m
.58056 .4439 L
s
1 .196 0 r
.29535 .60636 m
.29333 .60421 L
s
.29333 .60421 m
.29614 .60291 L
s
1 .004 0 r
.58057 .4439 m
.5806 .44393 L
s
.58053 .44394 m
.58057 .4439 L
s
.58057 .4439 m
.58056 .4439 L
s
.58057 .44396 m
.58053 .44394 L
s
.58053 .44394 m
.58056 .4439 L
s
.5806 .44393 m
.58057 .44396 L
s
.58056 .4439 m
.5806 .44393 L
s
.58056 .4439 m
.58057 .44396 L
s
1 .02 0 r
.52482 .57717 m
.52504 .57736 L
s
.5246 .57735 m
.52482 .57717 L
s
.52482 .57717 m
.52483 .57717 L
s
1 .014 0 r
.3653 .39044 m
.36475 .38982 L
s
1 .02 0 r
.52504 .57736 m
.52482 .57754 L
s
.52483 .57717 m
.52504 .57736 L
s
.52482 .57754 m
.5246 .57735 L
s
.5246 .57735 m
.52483 .57717 L
s
1 .663 0 r
.19463 .63076 m
.23407 .61391 L
s
1 .127 0 r
.33241 .5773 m
.33094 .57837 L
s
.33108 .57609 m
.33241 .5773 L
s
1 .02 0 r
.52483 .57717 m
.52482 .57754 L
s
1 .008 0 r
.68109 .60396 m
.68115 .60362 L
s
1 0 0 r
.63644 .31 m
.63644 .31 L
s
.63644 .31 m
.63644 .31 L
s
.63644 .31 m
.63644 .31 L
s
.63644 .31 m
.63644 .31 L
s
.63644 .31 m
.63644 .31 L
s
.63644 .31 m
.63644 .31 L
s
.63644 .31 m
.63644 .31 L
s
.63644 .31 m
.63644 .31 L
s
.63644 .31 m
.63644 .31 L
s
1 .127 0 r
.33094 .57837 m
.32958 .57713 L
s
.32958 .57713 m
.33108 .57609 L
s
1 .029 0 r
.46576 .55034 m
.46567 .54905 L
s
1 .014 0 r
.36486 .38982 m
.36499 .3899 L
s
.36472 .38999 m
.36486 .38982 L
s
.36486 .38982 m
.36475 .38982 L
s
1 .008 0 r
.68113 .60362 m
.68122 .60369 L
s
.68105 .60369 m
.68113 .60362 L
s
.68113 .60362 m
.68115 .60362 L
s
1 .014 0 r
.36485 .39007 m
.36472 .38999 L
s
.36472 .38999 m
.36475 .38982 L
s
1 .008 0 r
.68122 .60369 m
.68114 .60376 L
s
.68115 .60362 m
.68122 .60369 L
s
.68114 .60376 m
.68105 .60369 L
s
.68105 .60369 m
.68115 .60362 L
s
1 .196 0 r
.29614 .60291 m
.29535 .60636 L
s
1 .008 0 r
.68115 .60362 m
.68114 .60376 L
s
1 .436 0 r
.24039 .55496 m
.23593 .55021 L
s
.23593 .55021 m
.24208 .54724 L
s
1 .014 0 r
.36499 .3899 m
.36485 .39007 L
s
.36475 .38982 m
.36499 .3899 L
s
1 .257 0 r
.24632 .47005 m
.24365 .47304 L
s
.24186 .46857 m
.24632 .47005 L
s
1 .014 0 r
.36475 .38982 m
.36485 .39007 L
s
1 .275 0 r
.25039 .49672 m
.23987 .48508 L
s
1 .002 0 r
.73696 .46991 m
.73696 .46983 L
s
.73696 .46983 m
.73698 .46985 L
s
.73694 .46985 m
.73696 .46983 L
s
.73696 .46983 m
.73696 .46983 L
s
.73696 .46986 m
.73694 .46985 L
s
.73694 .46985 m
.73696 .46983 L
s
.73698 .46985 m
.73696 .46986 L
s
.73696 .46983 m
.73698 .46985 L
s
.73696 .46983 m
.73696 .46986 L
s
1 .127 0 r
.33108 .57609 m
.33094 .57837 L
s
1 .004 0 r
.52159 .41627 m
.52152 .41608 L
s
1 .077 0 r
.36832 .54872 m
.36915 .54941 L
s
.36744 .54943 m
.36832 .54872 L
s
.36832 .54872 m
.36821 .54872 L
s
1 .004 0 r
.52153 .41609 m
.52157 .41612 L
s
.52149 .41613 m
.52153 .41609 L
s
.52153 .41609 m
.52152 .41608 L
s
.52153 .41616 m
.52149 .41613 L
s
.52149 .41613 m
.52152 .41608 L
s
.52157 .41612 m
.52153 .41616 L
s
.52152 .41608 m
.52157 .41612 L
s
.52152 .41608 m
.52153 .41616 L
s
.83753 .62987 m
.83757 .62971 L
s
1 .257 0 r
.24186 .46857 m
.24365 .47304 L
s
1 0 0 r
.79286 .33579 m
.79286 .33579 L
s
.79286 .33579 m
.79286 .33579 L
s
.79286 .33579 m
.79286 .33579 L
s
.79286 .33579 m
.79286 .33579 L
s
.79286 .33579 m
.79286 .33579 L
s
.79286 .33579 m
.79286 .33579 L
s
.79286 .33579 m
.79286 .33579 L
s
.79286 .33579 m
.79286 .33579 L
s
.79286 .33579 m
.79286 .33579 L
s
1 .004 0 r
.83756 .62971 m
.8376 .62974 L
s
.83752 .62974 m
.83756 .62971 L
s
.83756 .62971 m
.83757 .62971 L
s
.8376 .62974 m
.83756 .62978 L
s
.83757 .62971 m
.8376 .62974 L
s
.83756 .62978 m
.83752 .62974 L
s
.83752 .62974 m
.83757 .62971 L
s
.83757 .62971 m
.83756 .62978 L
s
1 .01 0 r
.62212 .57624 m
.62215 .57581 L
s
1 .029 0 r
.46569 .54905 m
.466 .5493 L
s
.46537 .54931 m
.46569 .54905 L
s
.46569 .54905 m
.46567 .54905 L
s
1 .659 0 r
.23207 .60289 m
.22684 .60556 L
s
.22776 .59347 m
.23207 .60289 L
s
.23516 .59612 m
.23207 .60289 L
s
1 .077 0 r
.36826 .55011 m
.36744 .54943 L
s
.36744 .54943 m
.36821 .54872 L
s
.36915 .54941 m
.36826 .55011 L
s
.36821 .54872 m
.36915 .54941 L
s
1 0 0 r
.57744 .28213 m
.57744 .28213 L
s
.57744 .28213 m
.57744 .28213 L
s
.57744 .28213 m
.57744 .28213 L
s
.57744 .28213 m
.57744 .28213 L
s
.57744 .28213 m
.57744 .28213 L
s
.57744 .28213 m
.57744 .28213 L
s
.57744 .28213 m
.57744 .28213 L
s
.57744 .28213 m
.57744 .28213 L
s
.57744 .28213 m
.57744 .28213 L
s
1 .044 0 r
.40668 .52259 m
.40621 .5206 L
s
1 .029 0 r
.46568 .54957 m
.46537 .54931 L
s
.46537 .54931 m
.46567 .54905 L
s
.466 .5493 m
.46568 .54957 L
s
.46567 .54905 m
.466 .5493 L
s
1 .615 0 r
.20437 .46904 m
.19776 .476 L
s
.1939 .46515 m
.20437 .46904 L
s
1 .01 0 r
.62214 .57581 m
.62225 .5759 L
s
.62204 .5759 m
.62214 .57581 L
s
.62214 .57581 m
.62215 .57581 L
s
1 .029 0 r
.46567 .54905 m
.46568 .54957 L
s
1 .01 0 r
.62225 .5759 m
.62215 .57598 L
s
.62215 .57581 m
.62225 .5759 L
s
.62215 .57598 m
.62204 .5759 L
s
.62204 .5759 m
.62215 .57581 L
s
.62215 .57581 m
.62215 .57598 L
s
1 .659 0 r
.22252 .59612 m
.22776 .59347 L
s
.22776 .59347 m
.23516 .59612 L
s
1 .077 0 r
.36821 .54872 m
.36826 .55011 L
s
1 .002 0 r
.67801 .44211 m
.678 .44204 L
s
.678 .44204 m
.67802 .44205 L
s
.67798 .44205 m
.678 .44204 L
s
.678 .44204 m
.678 .44204 L
s
.678 .44207 m
.67798 .44205 L
s
.67798 .44205 m
.678 .44204 L
s
.67802 .44205 m
.678 .44207 L
s
.678 .44204 m
.67802 .44205 L
s
.678 .44204 m
.678 .44207 L
s
1 .436 0 r
.24208 .54724 m
.24039 .55496 L
s
1 .004 0 r
.46252 .38845 m
.4624 .38825 L
s
1 .203 0 r
.29171 .62898 m
.2952 .62047 L
s
1 .004 0 r
.46243 .38825 m
.46247 .38828 L
s
.46238 .3883 m
.46243 .38825 L
s
.46243 .38825 m
.4624 .38825 L
s
.46243 .38832 m
.46238 .3883 L
s
.46238 .3883 m
.4624 .38825 L
s
.46247 .38828 m
.46243 .38832 L
s
.4624 .38825 m
.46247 .38828 L
s
.4624 .38825 m
.46243 .38832 L
s
.77861 .60215 m
.77864 .60196 L
s
1 0 0 r
.73392 .30793 m
.73392 .30793 L
s
.73392 .30793 m
.73392 .30793 L
s
.73392 .30793 m
.73392 .30793 L
s
.73392 .30793 m
.73392 .30793 L
s
.73392 .30793 m
.73392 .30793 L
s
.73392 .30793 m
.73392 .30793 L
s
.73392 .30793 m
.73392 .30793 L
s
.73392 .30793 m
.73392 .30793 L
s
.73392 .30793 m
.73392 .30793 L
s
1 .004 0 r
.77863 .60196 m
.77868 .602 L
s
.77859 .602 m
.77863 .60196 L
s
.77863 .60196 m
.77864 .60196 L
s
.77868 .602 m
.77864 .60204 L
s
.77864 .60196 m
.77868 .602 L
s
.77864 .60204 m
.77859 .602 L
s
.77859 .602 m
.77864 .60196 L
s
.77864 .60196 m
.77864 .60204 L
s
1 .012 0 r
.56309 .54849 m
.56308 .54793 L
s
1 0 0 r
.51839 .25424 m
.51839 .25424 L
s
.51839 .25424 m
.51839 .25424 L
s
.51839 .25424 m
.51839 .25424 L
s
.51839 .25424 m
.51839 .25424 L
s
.51839 .25424 m
.51839 .25424 L
s
.51839 .25424 m
.51839 .25424 L
s
.51839 .25424 m
.51839 .25424 L
s
.51839 .25424 m
.51839 .25424 L
s
.51839 .25424 m
.51839 .25424 L
s
1 .072 0 r
.34754 .49482 m
.34599 .49156 L
s
1 .001 0 r
.83455 .46798 m
.83455 .46794 L
s
.83455 .46794 m
.83456 .46795 L
s
.83454 .46795 m
.83455 .46794 L
s
.83455 .46794 m
.83455 .46794 L
s
.83455 .46795 m
.83454 .46795 L
s
.83454 .46795 m
.83455 .46794 L
s
.83456 .46795 m
.83455 .46795 L
s
.83455 .46794 m
.83456 .46795 L
s
.83455 .46794 m
.83455 .46795 L
s
1 .012 0 r
.56308 .54793 m
.56322 .54804 L
s
.56294 .54805 m
.56308 .54793 L
s
.56308 .54793 m
.56308 .54793 L
s
.56308 .54815 m
.56294 .54805 L
s
.56294 .54805 m
.56308 .54793 L
s
.56322 .54804 m
.56308 .54815 L
s
.56308 .54793 m
.56322 .54804 L
s
1 .002 0 r
.61899 .41429 m
.61897 .41421 L
s
1 .012 0 r
.56308 .54793 m
.56308 .54815 L
s
1 .002 0 r
.61898 .41422 m
.61899 .41423 L
s
.61896 .41423 m
.61898 .41422 L
s
.61898 .41422 m
.61897 .41421 L
s
.61898 .41424 m
.61896 .41423 L
s
.61896 .41423 m
.61897 .41421 L
s
.61899 .41423 m
.61898 .41424 L
s
.61897 .41421 m
.61899 .41423 L
s
1 .044 0 r
.40632 .52061 m
.40679 .52097 L
s
.40582 .52103 m
.40632 .52061 L
s
.40632 .52061 m
.40621 .5206 L
s
1 .002 0 r
.61897 .41421 m
.61898 .41424 L
s
1 .004 0 r
.40339 .3606 m
.40322 .3604 L
s
1 .044 0 r
.40629 .52139 m
.40582 .52103 L
s
.40582 .52103 m
.40621 .5206 L
s
1 .615 0 r
.1939 .46515 m
.19776 .476 L
s
1 .45 0 r
.23249 .60125 m
.23971 .58204 L
s
1 .044 0 r
.40679 .52097 m
.40629 .52139 L
s
.40621 .5206 m
.40679 .52097 L
s
1 .004 0 r
.40326 .3604 m
.4033 .36042 L
s
.40321 .36045 m
.40326 .3604 L
s
.40326 .3604 m
.40322 .3604 L
s
.40326 .36048 m
.40321 .36045 L
s
.40321 .36045 m
.40322 .3604 L
s
.4033 .36042 m
.40326 .36048 L
s
.40322 .3604 m
.4033 .36042 L
s
.40322 .3604 m
.40326 .36048 L
s
1 .005 0 r
.71963 .5744 m
.71966 .57418 L
s
1 0 0 r
.67492 .28003 m
.67492 .28003 L
s
.67492 .28003 m
.67492 .28003 L
s
.67492 .28003 m
.67492 .28003 L
s
.67492 .28003 m
.67492 .28003 L
s
.67492 .28003 m
.67492 .28003 L
s
.67492 .28003 m
.67492 .28003 L
s
.67492 .28003 m
.67492 .28003 L
s
.67492 .28003 m
.67492 .28003 L
s
.67492 .28003 m
.67492 .28003 L
s
1 .044 0 r
.40621 .5206 m
.40629 .52139 L
s
1 .005 0 r
.71965 .57418 m
.71971 .57423 L
s
.7196 .57423 m
.71965 .57418 L
s
.71965 .57418 m
.71966 .57418 L
s
.71971 .57423 m
.71965 .57427 L
s
.71966 .57418 m
.71971 .57423 L
s
.71965 .57427 m
.7196 .57423 L
s
.7196 .57423 m
.71966 .57418 L
s
1 .017 0 r
.50401 .52071 m
.50389 .51996 L
s
1 .005 0 r
.71966 .57418 m
.71965 .57427 L
s
1 .126 0 r
.28834 .46701 m
.28344 .46166 L
s
1 .001 0 r
.77559 .44016 m
.77559 .44012 L
s
.77559 .44012 m
.7756 .44013 L
s
.77558 .44013 m
.77559 .44012 L
s
.77559 .44012 m
.77559 .44012 L
s
.77559 .44013 m
.77558 .44013 L
s
.77558 .44013 m
.77559 .44012 L
s
.7756 .44013 m
.77559 .44013 L
s
.77559 .44012 m
.7756 .44013 L
s
.77559 .44012 m
.77559 .44013 L
s
1 .002 0 r
.55992 .38644 m
.55989 .38637 L
s
.55989 .38637 m
.55991 .38638 L
s
.55988 .38639 m
.55989 .38637 L
s
.55989 .38637 m
.55989 .38637 L
s
1 .017 0 r
.50391 .51996 m
.5041 .5201 L
s
.50373 .52012 m
.50391 .51996 L
s
.50391 .51996 m
.50389 .51996 L
s
1 .002 0 r
.55989 .3864 m
.55988 .38639 L
s
.55988 .38639 m
.55989 .38637 L
s
.55991 .38638 m
.55989 .3864 L
s
.55989 .38637 m
.55991 .38638 L
s
.55989 .38637 m
.55989 .3864 L
s
1 .08 0 r
.38896 .62719 m
.38965 .62375 L
s
1 .017 0 r
.50391 .52026 m
.50373 .52012 L
s
.50373 .52012 m
.50389 .51996 L
s
1 .139 0 r
.30779 .5182 m
.30923 .51931 L
s
.30621 .51958 m
.30779 .5182 L
s
.30779 .5182 m
.30727 .51819 L
s
1 .017 0 r
.5041 .5201 m
.50391 .52026 L
s
.50389 .51996 m
.5041 .5201 L
s
1 .003 0 r
.8763 .60034 m
.87632 .60023 L
s
1 .017 0 r
.50389 .51996 m
.50391 .52026 L
s
1 .003 0 r
.87632 .60023 m
.87635 .60025 L
s
.87629 .60025 m
.87632 .60023 L
s
.87632 .60023 m
.87632 .60023 L
s
.87635 .60025 m
.87632 .60027 L
s
.87632 .60023 m
.87635 .60025 L
s
.87632 .60027 m
.87629 .60025 L
s
.87629 .60025 m
.87632 .60023 L
s
0 .042 1 r
.17322 .57349 m
.23644 .38836 L
s
1 .003 0 r
.87632 .60023 m
.87632 .60027 L
s
1 .006 0 r
.6606 .54663 m
.6606 .54636 L
s
1 0 0 r
.61586 .25211 m
.61586 .25211 L
s
.61586 .25211 m
.61586 .25211 L
s
.61586 .25211 m
.61586 .25211 L
s
.61586 .25211 m
.61586 .25211 L
s
.61586 .25211 m
.61586 .25211 L
s
.61586 .25211 m
.61586 .25211 L
s
.61586 .25211 m
.61586 .25211 L
s
.61586 .25211 m
.61586 .25211 L
s
.61586 .25211 m
.61586 .25211 L
s
1 .023 0 r
.44486 .49291 m
.44452 .49183 L
s
1 .006 0 r
.6606 .54636 m
.66067 .54641 L
s
.66054 .54642 m
.6606 .54636 L
s
.6606 .54636 m
.6606 .54636 L
s
.6606 .54647 m
.66054 .54642 L
s
.66054 .54642 m
.6606 .54636 L
s
.66067 .54641 m
.6606 .54647 L
s
.6606 .54636 m
.66067 .54641 L
s
.6606 .54636 m
.6606 .54647 L
s
1 .139 0 r
.30765 .52069 m
.30621 .51958 L
s
.30621 .51958 m
.30727 .51819 L
s
1 .001 0 r
.71657 .41231 m
.71656 .41227 L
s
.71657 .41227 m
.71658 .41228 L
s
.71656 .41228 m
.71657 .41227 L
s
.71657 .41227 m
.71656 .41227 L
s
.71657 .41229 m
.71656 .41228 L
s
.71656 .41228 m
.71656 .41227 L
s
.71658 .41228 m
.71657 .41229 L
s
.71656 .41227 m
.71658 .41228 L
s
.71656 .41227 m
.71657 .41229 L
s
1 .252 0 r
.27051 .54265 m
.27317 .54492 L
s
.26756 .54494 m
.27051 .54265 L
s
.27051 .54265 m
.27005 .54264 L
s
1 .072 0 r
.34633 .49157 m
.34707 .4921 L
s
.34553 .49232 m
.34633 .49157 L
s
.34633 .49157 m
.34599 .49156 L
s
1 .139 0 r
.30923 .51931 m
.30765 .52069 L
s
.30727 .51819 m
.30923 .51931 L
s
1 .002 0 r
.50079 .35857 m
.50075 .3585 L
s
.50075 .3585 m
.50077 .35851 L
s
.50074 .35852 m
.50075 .3585 L
s
.50075 .3585 m
.50075 .3585 L
s
.50075 .35853 m
.50074 .35852 L
s
.50074 .35852 m
.50075 .3585 L
s
.50077 .35851 m
.50075 .35853 L
s
.50075 .3585 m
.50077 .35851 L
s
.50075 .3585 m
.50075 .35853 L
s
1 .135 0 r
.32974 .59944 m
.33021 .59347 L
s
1 .072 0 r
.34627 .49285 m
.34553 .49232 L
s
.34553 .49232 m
.34599 .49156 L
s
1 .003 0 r
.81732 .57257 m
.81734 .57244 L
s
1 .023 0 r
.44459 .49184 m
.44485 .49203 L
s
.44433 .49208 m
.44459 .49184 L
s
.44459 .49184 m
.44452 .49183 L
s
1 .003 0 r
.81733 .57244 m
.81737 .57247 L
s
.8173 .57247 m
.81733 .57244 L
s
.81733 .57244 m
.81734 .57244 L
s
.81737 .57247 m
.81734 .57249 L
s
.81734 .57244 m
.81737 .57247 L
s
.81734 .57249 m
.8173 .57247 L
s
.8173 .57247 m
.81734 .57244 L
s
1 0 0 r
.77257 .27793 m
.77257 .27793 L
s
.77257 .27793 m
.77257 .27793 L
s
.77257 .27793 m
.77257 .27793 L
s
.77257 .27793 m
.77257 .27793 L
s
.77257 .27793 m
.77257 .27793 L
s
.77257 .27793 m
.77257 .27793 L
s
.77257 .27793 m
.77257 .27793 L
s
.77257 .27793 m
.77257 .27793 L
s
.77257 .27793 m
.77257 .27793 L
s
1 .003 0 r
.81734 .57244 m
.81734 .57249 L
s
1 .072 0 r
.34707 .4921 m
.34627 .49285 L
s
.34599 .49156 m
.34707 .4921 L
s
1 .023 0 r
.44459 .49226 m
.44433 .49208 L
s
.44433 .49208 m
.44452 .49183 L
s
1 .007 0 r
.60151 .51883 m
.60148 .51849 L
s
1 .023 0 r
.44485 .49203 m
.44459 .49226 L
s
.44452 .49183 m
.44485 .49203 L
s
1 .139 0 r
.30727 .51819 m
.30765 .52069 L
s
1 .023 0 r
.44452 .49183 m
.44459 .49226 L
s
1 .072 0 r
.34599 .49156 m
.34627 .49285 L
s
1 .035 0 r
.38565 .46508 m
.3848 .4635 L
s
1 .007 0 r
.60148 .5185 m
.60157 .51856 L
s
.6014 .51856 m
.60148 .5185 L
s
.60148 .5185 m
.60148 .51849 L
s
.60148 .51863 m
.6014 .51856 L
s
.6014 .51856 m
.60148 .51849 L
s
.60157 .51856 m
.60148 .51863 L
s
.60148 .51849 m
.60157 .51856 L
s
.60148 .51849 m
.60148 .51863 L
s
1 .001 0 r
.65749 .38444 m
.65748 .3844 L
s
.65749 .3844 m
.65749 .38441 L
s
.65748 .38441 m
.65749 .3844 L
s
.65749 .3844 m
.65748 .3844 L
s
.65749 .38442 m
.65748 .38441 L
s
.65748 .38441 m
.65748 .3844 L
s
.65749 .38441 m
.65749 .38442 L
s
.65748 .3844 m
.65749 .38441 L
s
.65748 .3844 m
.65749 .38442 L
s
1 .035 0 r
.48638 .6254 m
.48661 .62387 L
s
1 .001 0 r
.4416 .33067 m
.44155 .33061 L
s
1 .252 0 r
.27021 .54721 m
.26756 .54494 L
s
.26756 .54494 m
.27005 .54264 L
s
.27317 .54492 m
.27021 .54721 L
s
.27005 .54264 m
.27317 .54492 L
s
1 .001 0 r
.44156 .33061 m
.44157 .33062 L
s
.44155 .33063 m
.44156 .33061 L
s
.44156 .33061 m
.44155 .33061 L
s
.44156 .33063 m
.44155 .33063 L
s
.44155 .33063 m
.44155 .33061 L
s
.44157 .33062 m
.44156 .33063 L
s
.44155 .33061 m
.44157 .33062 L
s
.44155 .33061 m
.44156 .33063 L
s
1 .262 0 r
.27046 .57165 m
.26881 .55985 L
s
1 .003 0 r
.75828 .54477 m
.75829 .54462 L
s
0 .558 1 r
.23404 .22927 m
.26952 .26544 L
s
.19357 .25084 m
.23404 .22927 L
s
.23404 .22927 m
.24285 .22326 L
s
1 .003 0 r
.75829 .54462 m
.75832 .54465 L
s
.75825 .54465 m
.75829 .54462 L
s
.75829 .54462 m
.75829 .54462 L
s
1 0 0 r
.71351 .24999 m
.71351 .24999 L
s
.71351 .24999 m
.71351 .24999 L
s
.71351 .24999 m
.71351 .24999 L
s
.71351 .24999 m
.71351 .24999 L
s
.71351 .24999 m
.71351 .24999 L
s
.71351 .24999 m
.71351 .24999 L
s
.71351 .24999 m
.71351 .24999 L
s
.71351 .24999 m
.71351 .24999 L
s
.71351 .24999 m
.71351 .24999 L
s
1 .003 0 r
.75829 .54468 m
.75825 .54465 L
s
.75825 .54465 m
.75829 .54462 L
s
.75832 .54465 m
.75829 .54468 L
s
.75829 .54462 m
.75832 .54465 L
s
.75829 .54462 m
.75829 .54468 L
s
1 .009 0 r
.54236 .491 m
.54227 .49058 L
s
1 .08 0 r
.38954 .6237 m
.3904 .62452 L
s
.38863 .62437 m
.38954 .6237 L
s
.38954 .6237 m
.38965 .62375 L
s
1 .054 0 r
.32639 .43722 m
.32429 .43491 L
s
1 .035 0 r
.38498 .4635 m
.38534 .46375 L
s
.3846 .46388 m
.38498 .4635 L
s
.38498 .4635 m
.3848 .4635 L
s
1 0 0 r
.81433 .41033 m
.81432 .41031 L
s
1 .009 0 r
.54228 .49058 m
.54239 .49065 L
s
.54218 .49067 m
.54228 .49058 L
s
.54228 .49058 m
.54227 .49058 L
s
1 0 0 r
.81432 .41031 m
.81433 .41031 L
s
.81432 .41031 m
.81432 .41031 L
s
.81432 .41031 m
.81432 .41031 L
s
.81433 .41032 m
.81432 .41031 L
s
.81432 .41031 m
.81432 .41031 L
s
.81433 .41031 m
.81433 .41032 L
s
.81432 .41031 m
.81433 .41031 L
s
.81432 .41031 m
.81433 .41032 L
s
1 .035 0 r
.38496 .46412 m
.3846 .46388 L
s
.3846 .46388 m
.3848 .4635 L
s
1 .009 0 r
.54228 .49074 m
.54218 .49067 L
s
.54218 .49067 m
.54227 .49058 L
s
.54239 .49065 m
.54228 .49074 L
s
.54227 .49058 m
.54239 .49065 L
s
.54227 .49058 m
.54228 .49074 L
s
1 .035 0 r
.38534 .46375 m
.38496 .46412 L
s
.3848 .4635 m
.38534 .46375 L
s
1 .08 0 r
.3904 .62452 m
.38949 .62518 L
s
.38965 .62375 m
.3904 .62452 L
s
1 .001 0 r
.59836 .35654 m
.59834 .35651 L
s
.59835 .35651 m
.59835 .35651 L
s
.59834 .35651 m
.59835 .35651 L
s
.59835 .35651 m
.59834 .35651 L
s
.59835 .35652 m
.59834 .35651 L
s
.59834 .35651 m
.59834 .35651 L
s
.59835 .35651 m
.59835 .35652 L
s
.59834 .35651 m
.59835 .35651 L
s
.59834 .35651 m
.59835 .35652 L
s
1 .035 0 r
.3848 .4635 m
.38496 .46412 L
s
1 .053 0 r
.42716 .59762 m
.42725 .59529 L
s
1 .629 0 r
.19683 .4817 m
.20265 .48578 L
s
.19006 .48885 m
.19683 .4817 L
s
.19683 .4817 m
.19189 .48182 L
s
1 .08 0 r
.38949 .62518 m
.38863 .62437 L
s
.38863 .62437 m
.38965 .62375 L
s
1 .035 0 r
.48657 .62385 m
.48696 .6242 L
s
.48617 .62416 m
.48657 .62385 L
s
.48657 .62385 m
.48661 .62387 L
s
1 .648 0 r
.21112 .54384 m
.18815 .51606 L
s
1 .035 0 r
.48696 .6242 m
.48656 .6245 L
s
.48661 .62387 m
.48696 .6242 L
s
1 .126 0 r
.28449 .46162 m
.28564 .46237 L
s
.2832 .46311 m
.28449 .46162 L
s
.28449 .46162 m
.28344 .46166 L
s
1 .035 0 r
.48656 .6245 m
.48617 .62416 L
s
.48617 .62416 m
.48661 .62387 L
s
1 .004 0 r
.69918 .51694 m
.69918 .51677 L
s
1 .252 0 r
.27005 .54264 m
.27021 .54721 L
s
1 .08 0 r
.38965 .62375 m
.38949 .62518 L
s
1 .444 0 r
.23978 .56432 m
.24434 .56917 L
s
.23462 .56755 m
.23978 .56432 L
s
.23978 .56432 m
.24091 .56453 L
s
1 .004 0 r
.69918 .51678 m
.69922 .51681 L
s
.69914 .51681 m
.69918 .51678 L
s
.69918 .51678 m
.69918 .51677 L
s
.69918 .51684 m
.69914 .51681 L
s
.69914 .51681 m
.69918 .51677 L
s
.69922 .51681 m
.69918 .51684 L
s
.69918 .51677 m
.69922 .51681 L
s
1 .035 0 r
.48661 .62387 m
.48656 .6245 L
s
1 .004 0 r
.69918 .51677 m
.69918 .51684 L
s
1 .012 0 r
.48315 .46314 m
.48294 .46259 L
s
1 .126 0 r
.28435 .46385 m
.2832 .46311 L
s
.2832 .46311 m
.28344 .46166 L
s
1 0 0 r
.75524 .38243 m
.75524 .38241 L
s
.75524 .38241 m
.75524 .38241 L
s
.75524 .38242 m
.75524 .38241 L
s
.75524 .38241 m
.75524 .38241 L
s
.75524 .38242 m
.75524 .38242 L
s
.75524 .38242 m
.75524 .38241 L
s
.75524 .38241 m
.75524 .38242 L
s
.75524 .38241 m
.75524 .38241 L
s
.75524 .38241 m
.75524 .38242 L
s
1 .012 0 r
.48299 .4626 m
.48311 .46269 L
s
.48286 .46272 m
.48299 .4626 L
s
.48299 .4626 m
.48294 .46259 L
s
1 .017 0 r
.58398 .62361 m
.58409 .62287 L
s
1 .012 0 r
.48298 .46281 m
.48286 .46272 L
s
.48286 .46272 m
.48294 .46259 L
s
.48311 .46269 m
.48298 .46281 L
s
.48294 .46259 m
.48311 .46269 L
s
1 0 0 r
.53916 .32861 m
.53915 .32859 L
s
1 .012 0 r
.48294 .46259 m
.48298 .46281 L
s
1 0 0 r
.53915 .32859 m
.53916 .32859 L
s
.53915 .32859 m
.53915 .32859 L
s
.53915 .32859 m
.53915 .32859 L
s
.53915 .32859 m
.53915 .32859 L
s
.53915 .32859 m
.53915 .32859 L
s
.53916 .32859 m
.53915 .32859 L
s
.53915 .32859 m
.53916 .32859 L
s
.53915 .32859 m
.53915 .32859 L
s
1 .085 0 r
.36787 .56981 m
.36744 .56599 L
s
1 .002 0 r
.85614 .5429 m
.85615 .54282 L
s
1 .054 0 r
.32473 .43489 m
.32523 .4352 L
s
.32418 .43553 m
.32473 .43489 L
s
.32473 .43489 m
.32429 .43491 L
s
1 .002 0 r
.85615 .54282 m
.85617 .54284 L
s
.85613 .54284 m
.85615 .54282 L
s
.85615 .54282 m
.85615 .54282 L
s
.85615 .54285 m
.85613 .54284 L
s
.85613 .54284 m
.85615 .54282 L
s
.85617 .54284 m
.85615 .54285 L
s
.85615 .54282 m
.85617 .54284 L
s
1 .659 0 r
.22684 .60556 m
.22252 .59612 L
s
.23516 .59612 m
.22684 .60556 L
s
1 .002 0 r
.85615 .54282 m
.85615 .54285 L
s
1 .126 0 r
.28564 .46237 m
.28435 .46385 L
s
.28344 .46166 m
.28564 .46237 L
s
1 .054 0 r
.32468 .43585 m
.32418 .43553 L
s
.32418 .43553 m
.32429 .43491 L
s
1 .004 0 r
.64003 .48909 m
.64 .48889 L
s
1 .203 0 r
.29461 .6203 m
.29672 .62254 L
s
.29228 .62181 m
.29461 .6203 L
s
.29461 .6203 m
.2952 .62047 L
s
1 .017 0 r
.58407 .62286 m
.58426 .62302 L
s
.58388 .62301 m
.58407 .62286 L
s
.58407 .62286 m
.58409 .62287 L
s
1 .004 0 r
.64001 .48889 m
.64005 .48893 L
s
.63996 .48893 m
.64001 .48889 L
s
.64001 .48889 m
.64 .48889 L
s
1 .017 0 r
.58426 .62302 m
.58407 .62317 L
s
.58409 .62287 m
.58426 .62302 L
s
1 .004 0 r
.64001 .48897 m
.63996 .48893 L
s
.63996 .48893 m
.64 .48889 L
s
1 .126 0 r
.28344 .46166 m
.28435 .46385 L
s
1 .004 0 r
.64005 .48893 m
.64001 .48897 L
s
.64 .48889 m
.64005 .48893 L
s
1 .017 0 r
.58407 .62317 m
.58388 .62301 L
s
.58388 .62301 m
.58409 .62287 L
s
1 .004 0 r
.64 .48889 m
.64001 .48897 L
s
1 .016 0 r
.42388 .43526 m
.42346 .43454 L
s
1 .017 0 r
.58409 .62287 m
.58407 .62317 L
s
1 .659 0 r
.22252 .59612 m
.23516 .59612 L
s
1 .629 0 r
.19586 .49295 m
.19006 .48885 L
s
.19006 .48885 m
.19189 .48182 L
s
1 .054 0 r
.32523 .4352 m
.32468 .43585 L
s
.32429 .43491 m
.32523 .4352 L
s
1 .275 0 r
.24217 .48497 m
.24467 .48666 L
s
.23931 .48819 m
.24217 .48497 L
s
.24217 .48497 m
.23987 .48508 L
s
1 .054 0 r
.32429 .43491 m
.32468 .43585 L
s
1 .053 0 r
.42724 .59527 m
.42782 .59577 L
s
.42664 .59574 m
.42724 .59527 L
s
.42724 .59527 m
.42725 .59529 L
s
1 .444 0 r
.24434 .56917 m
.23919 .57241 L
s
.24091 .56453 m
.24434 .56917 L
s
1 0 0 r
.6961 .3545 m
.6961 .35449 L
s
.6961 .35449 m
.6961 .35449 L
s
.6961 .35449 m
.6961 .35449 L
s
.6961 .35449 m
.6961 .35449 L
s
.6961 .35449 m
.6961 .35449 L
s
.6961 .35449 m
.6961 .35449 L
s
.6961 .35449 m
.6961 .35449 L
s
.6961 .35449 m
.6961 .35449 L
s
.6961 .35449 m
.6961 .35449 L
s
1 .023 0 r
.52475 .5958 m
.5248 .59477 L
s
1 .053 0 r
.42782 .59577 m
.42722 .59624 L
s
.42725 .59529 m
.42782 .59577 L
s
.42722 .59624 m
.42664 .59574 L
s
.42664 .59574 m
.42725 .59529 L
s
1 .203 0 r
.29672 .62254 m
.29439 .62406 L
s
.2952 .62047 m
.29672 .62254 L
s
1 0 0 r
.47991 .30065 m
.4799 .30064 L
s
1 .016 0 r
.42355 .43454 m
.42371 .43465 L
s
.42338 .43472 m
.42355 .43454 L
s
.42355 .43454 m
.42346 .43454 L
s
1 0 0 r
.4799 .30064 m
.4799 .30064 L
s
.4799 .30064 m
.4799 .30064 L
s
.4799 .30064 m
.4799 .30064 L
s
.4799 .30064 m
.4799 .30064 L
s
.4799 .30064 m
.4799 .30064 L
s
.4799 .30064 m
.4799 .30064 L
s
.4799 .30064 m
.4799 .30064 L
s
.4799 .30064 m
.4799 .30064 L
s
1 .016 0 r
.42354 .43482 m
.42338 .43472 L
s
.42338 .43472 m
.42346 .43454 L
s
1 .15 0 r
.30853 .54197 m
.30607 .5352 L
s
1 .016 0 r
.42371 .43465 m
.42354 .43482 L
s
.42346 .43454 m
.42371 .43465 L
s
.42346 .43454 m
.42354 .43482 L
s
1 .002 0 r
.79704 .51505 m
.79704 .51496 L
s
1 .053 0 r
.42725 .59529 m
.42722 .59624 L
s
1 .275 0 r
.2418 .48988 m
.23931 .48819 L
s
.23931 .48819 m
.23987 .48508 L
s
1 .002 0 r
.79704 .51496 m
.79706 .51498 L
s
.79702 .51498 m
.79704 .51496 L
s
.79704 .51496 m
.79704 .51496 L
s
.79704 .515 m
.79702 .51498 L
s
.79702 .51498 m
.79704 .51496 L
s
.79706 .51498 m
.79704 .515 L
s
.79704 .51496 m
.79706 .51498 L
s
.79704 .51496 m
.79704 .515 L
s
1 .005 0 r
.58081 .4612 m
.58076 .46098 L
s
1 .135 0 r
.33018 .59342 m
.33163 .59475 L
s
.32861 .59458 m
.33018 .59342 L
s
.33018 .59342 m
.33021 .59347 L
s
1 .005 0 r
.58077 .46098 m
.58082 .46102 L
s
.58071 .46103 m
.58077 .46098 L
s
.58077 .46098 m
.58076 .46098 L
s
.58077 .46107 m
.58071 .46103 L
s
.58071 .46103 m
.58076 .46098 L
s
.58082 .46102 m
.58077 .46107 L
s
.58076 .46098 m
.58082 .46102 L
s
1 .021 0 r
.36455 .40735 m
.36373 .40642 L
s
1 .005 0 r
.58076 .46098 m
.58077 .46107 L
s
1 .023 0 r
.52479 .59476 m
.52505 .59498 L
s
.52453 .59497 m
.52479 .59476 L
s
.52479 .59476 m
.5248 .59477 L
s
1 .009 0 r
.68176 .62182 m
.68182 .62142 L
s
1 .023 0 r
.52505 .59498 m
.52479 .59519 L
s
.5248 .59477 m
.52505 .59498 L
s
1 .203 0 r
.29439 .62406 m
.29228 .62181 L
s
.29228 .62181 m
.2952 .62047 L
s
1 .023 0 r
.52479 .59519 m
.52453 .59497 L
s
.52453 .59497 m
.5248 .59477 L
s
1 0 0 r
.6369 .32655 m
.6369 .32654 L
s
.6369 .32654 m
.6369 .32654 L
s
.6369 .32654 m
.6369 .32654 L
s
.6369 .32654 m
.6369 .32654 L
s
.6369 .32654 m
.6369 .32654 L
s
.6369 .32654 m
.6369 .32654 L
s
.6369 .32654 m
.6369 .32654 L
s
.6369 .32654 m
.6369 .32654 L
s
.6369 .32654 m
.6369 .32654 L
s
1 .023 0 r
.5248 .59477 m
.52479 .59519 L
s
1 .033 0 r
.46546 .56797 m
.46535 .56647 L
s
1 .135 0 r
.33163 .59475 m
.33005 .59591 L
s
.33021 .59347 m
.33163 .59475 L
s
1 .009 0 r
.6818 .62142 m
.68191 .6215 L
s
.68171 .6215 m
.6818 .62142 L
s
.6818 .62142 m
.68182 .62142 L
s
.68191 .6215 m
.68181 .62158 L
s
.68182 .62142 m
.68191 .6215 L
s
.68181 .62158 m
.68171 .6215 L
s
.68171 .6215 m
.68182 .62142 L
s
.68182 .62142 m
.68181 .62158 L
s
1 .289 0 r
.24913 .5141 m
.23801 .50191 L
s
1 .021 0 r
.3639 .40642 m
.3641 .40654 L
s
.36368 .40668 m
.3639 .40642 L
s
.3639 .40642 m
.36373 .40642 L
s
1 .135 0 r
.33005 .59591 m
.32861 .59458 L
s
.32861 .59458 m
.33021 .59347 L
s
1 .021 0 r
.36388 .4068 m
.36368 .40668 L
s
.36368 .40668 m
.36373 .40642 L
s
1 .002 0 r
.73788 .48717 m
.73787 .48707 L
s
.73787 .48707 m
.7379 .48709 L
s
.73785 .48709 m
.73787 .48707 L
s
.73787 .48707 m
.73787 .48707 L
s
.73787 .48711 m
.73785 .48709 L
s
.73785 .48709 m
.73787 .48707 L
s
.7379 .48709 m
.73787 .48711 L
s
.73787 .48707 m
.7379 .48709 L
s
.73787 .48707 m
.73787 .48711 L
s
1 .021 0 r
.3641 .40654 m
.36388 .4068 L
s
.36373 .40642 m
.3641 .40654 L
s
1 .203 0 r
.2952 .62047 m
.29439 .62406 L
s
1 .444 0 r
.23919 .57241 m
.23462 .56755 L
s
.23462 .56755 m
.24091 .56453 L
s
1 .021 0 r
.36373 .40642 m
.36388 .4068 L
s
1 .006 0 r
.52154 .43329 m
.52143 .43303 L
s
.52145 .43303 m
.52152 .43307 L
s
.52139 .43309 m
.52145 .43303 L
s
.52145 .43303 m
.52143 .43303 L
s
.52145 .43313 m
.52139 .43309 L
s
.52139 .43309 m
.52143 .43303 L
s
.52152 .43307 m
.52145 .43313 L
s
.52143 .43303 m
.52152 .43307 L
s
.52143 .43303 m
.52145 .43313 L
s
1 0 0 r
.79402 .35246 m
.79402 .35245 L
s
.79402 .35246 m
.79402 .35246 L
s
.79402 .35246 m
.79402 .35246 L
s
.79402 .35246 m
.79402 .35245 L
s
.79402 .35246 m
.79402 .35246 L
s
.79402 .35246 m
.79402 .35245 L
s
.79402 .35246 m
.79402 .35246 L
s
.79402 .35245 m
.79402 .35246 L
s
.79402 .35245 m
.79402 .35246 L
s
1 .135 0 r
.33021 .59347 m
.33005 .59591 L
s
1 .275 0 r
.24467 .48666 m
.2418 .48988 L
s
.23987 .48508 m
.24467 .48666 L
s
1 .085 0 r
.36756 .56598 m
.36847 .56674 L
s
.36658 .56676 m
.36756 .56598 L
s
.36756 .56598 m
.36744 .56599 L
s
1 .011 0 r
.62252 .59398 m
.62256 .59348 L
s
1 0 0 r
.57764 .29856 m
.57764 .29856 L
s
.57764 .29856 m
.57764 .29856 L
s
.57764 .29856 m
.57764 .29856 L
s
.57764 .29856 m
.57764 .29856 L
s
.57764 .29856 m
.57764 .29856 L
s
.57764 .29856 m
.57764 .29856 L
s
.57764 .29856 m
.57764 .29856 L
s
.57764 .29856 m
.57764 .29856 L
s
.57764 .29856 m
.57764 .29856 L
s
1 .663 0 r
.23094 .62069 m
.22566 .62345 L
s
.22659 .61118 m
.23094 .62069 L
s
.23407 .61391 m
.23094 .62069 L
s
1 .051 0 r
.40612 .5401 m
.40558 .5378 L
s
1 .033 0 r
.46538 .56647 m
.46575 .56676 L
s
.465 .56677 m
.46538 .56647 L
s
.46538 .56647 m
.46535 .56647 L
s
1 .011 0 r
.62255 .59347 m
.62268 .59358 L
s
.62243 .59358 m
.62255 .59347 L
s
.62255 .59347 m
.62256 .59348 L
s
1 .033 0 r
.46537 .56707 m
.465 .56677 L
s
.465 .56677 m
.46535 .56647 L
s
.46575 .56676 m
.46537 .56707 L
s
.46535 .56647 m
.46575 .56676 L
s
1 .085 0 r
.36749 .56753 m
.36658 .56676 L
s
.36658 .56676 m
.36744 .56599 L
s
.36847 .56674 m
.36749 .56753 L
s
.36744 .56599 m
.36847 .56674 L
s
1 .011 0 r
.62268 .59358 m
.62255 .59368 L
s
.62256 .59348 m
.62268 .59358 L
s
.62255 .59368 m
.62243 .59358 L
s
.62243 .59358 m
.62256 .59348 L
s
.62256 .59348 m
.62255 .59368 L
s
1 .002 0 r
.67866 .45926 m
.67864 .45915 L
s
1 .663 0 r
.22129 .61391 m
.22659 .61118 L
s
.22659 .61118 m
.23407 .61391 L
s
1 .275 0 r
.23987 .48508 m
.2418 .48988 L
s
1 .033 0 r
.46535 .56647 m
.46537 .56707 L
s
1 .002 0 r
.67864 .45915 m
.67867 .45917 L
s
.67862 .45918 m
.67864 .45915 L
s
.67864 .45915 m
.67864 .45915 L
s
.67864 .4592 m
.67862 .45918 L
s
.67862 .45918 m
.67864 .45915 L
s
.67867 .45917 m
.67864 .4592 L
s
.67864 .45915 m
.67867 .45917 L
s
.67864 .45915 m
.67864 .4592 L
s
1 .007 0 r
.46221 .40536 m
.46202 .40505 L
s
1 .085 0 r
.36744 .56599 m
.36749 .56753 L
s
1 .629 0 r
.20265 .48578 m
.19586 .49295 L
s
.19189 .48182 m
.20265 .48578 L
s
1 .005 0 r
.77971 .62002 m
.77975 .61979 L
s
1 .007 0 r
.46206 .40505 m
.46213 .40509 L
s
.46199 .40512 m
.46206 .40505 L
s
.46206 .40505 m
.46202 .40505 L
s
1 .444 0 r
.24091 .56453 m
.23919 .57241 L
s
1 .007 0 r
.46206 .40517 m
.46199 .40512 L
s
.46199 .40512 m
.46202 .40505 L
s
.46213 .40509 m
.46206 .40517 L
s
.46202 .40505 m
.46213 .40509 L
s
.46202 .40505 m
.46206 .40517 L
s
1 0 0 r
.73482 .32448 m
.73482 .32448 L
s
.73482 .32448 m
.73482 .32448 L
s
.73482 .32448 m
.73482 .32448 L
s
.73482 .32448 m
.73482 .32448 L
s
.73482 .32448 m
.73482 .32448 L
s
.73482 .32448 m
.73482 .32448 L
s
.73482 .32448 m
.73482 .32448 L
s
.73482 .32448 m
.73482 .32448 L
s
.73482 .32448 m
.73482 .32448 L
s
1 .005 0 r
.77974 .61979 m
.7798 .61984 L
s
.77969 .61984 m
.77974 .61979 L
s
.77974 .61979 m
.77975 .61979 L
s
.7798 .61984 m
.77974 .61989 L
s
.77975 .61979 m
.7798 .61984 L
s
.77974 .61989 m
.77969 .61984 L
s
.77969 .61984 m
.77975 .61979 L
s
1 .015 0 r
.56323 .56612 m
.56321 .56545 L
s
1 .005 0 r
.77975 .61979 m
.77974 .61989 L
s
1 0 0 r
.51833 .27055 m
.51832 .27055 L
s
.51832 .27055 m
.51832 .27055 L
s
.51832 .27055 m
.51832 .27055 L
s
.51832 .27055 m
.51832 .27055 L
s
.51832 .27055 m
.51832 .27055 L
s
.51832 .27055 m
.51832 .27055 L
s
.51832 .27055 m
.51832 .27055 L
s
.51832 .27055 m
.51832 .27055 L
s
.51832 .27055 m
.51832 .27055 L
s
1 .082 0 r
.34671 .51221 m
.34493 .50849 L
s
1 .001 0 r
.8359 .48525 m
.8359 .48519 L
s
.8359 .48519 m
.83592 .4852 L
s
.83589 .48521 m
.8359 .48519 L
s
.8359 .48519 m
.8359 .48519 L
s
.8359 .48522 m
.83589 .48521 L
s
.83589 .48521 m
.8359 .48519 L
s
.83592 .4852 m
.8359 .48522 L
s
.8359 .48519 m
.83592 .4852 L
s
.8359 .48519 m
.8359 .48522 L
s
1 .015 0 r
.56321 .56545 m
.56338 .56558 L
s
.56305 .56559 m
.56321 .56545 L
s
.56321 .56545 m
.56321 .56545 L
s
1 .002 0 r
.61938 .43132 m
.61935 .43121 L
s
1 .015 0 r
.56321 .56572 m
.56305 .56559 L
s
.56305 .56559 m
.56321 .56545 L
s
.56338 .56558 m
.56321 .56572 L
s
.56321 .56545 m
.56338 .56558 L
s
1 .002 0 r
.61935 .43121 m
.61938 .43123 L
s
.61933 .43123 m
.61935 .43121 L
s
.61935 .43121 m
.61935 .43121 L
s
.61935 .43125 m
.61933 .43123 L
s
.61933 .43123 m
.61935 .43121 L
s
.61938 .43123 m
.61935 .43125 L
s
.61935 .43121 m
.61938 .43123 L
s
.61935 .43121 m
.61935 .43125 L
s
1 .015 0 r
.56321 .56545 m
.56321 .56572 L
s
1 .008 0 r
.40282 .37739 m
.40252 .37705 L
s
1 .455 0 r
.23115 .61912 m
.23847 .59978 L
s
1 .051 0 r
.4057 .53781 m
.40624 .53823 L
s
.40512 .5383 m
.4057 .53781 L
s
.4057 .53781 m
.40558 .5378 L
s
1 .006 0 r
.72047 .59216 m
.7205 .59189 L
s
1 .008 0 r
.40258 .37705 m
.40266 .37709 L
s
.4025 .37714 m
.40258 .37705 L
s
.40258 .37705 m
.40252 .37705 L
s
.40258 .37719 m
.4025 .37714 L
s
.4025 .37714 m
.40252 .37705 L
s
.40266 .37709 m
.40258 .37719 L
s
.40252 .37705 m
.40266 .37709 L
s
1 0 0 r
.67555 .29647 m
.67555 .29647 L
s
.67555 .29647 m
.67555 .29647 L
s
.67555 .29647 m
.67555 .29647 L
s
.67555 .29647 m
.67555 .29647 L
s
.67555 .29647 m
.67555 .29647 L
s
.67555 .29647 m
.67555 .29647 L
s
.67555 .29647 m
.67555 .29647 L
s
.67555 .29647 m
.67555 .29647 L
s
.67555 .29647 m
.67555 .29647 L
s
1 .008 0 r
.40252 .37705 m
.40258 .37719 L
s
1 .051 0 r
.40567 .53872 m
.40512 .5383 L
s
.40512 .5383 m
.40558 .5378 L
s
.40624 .53823 m
.40567 .53872 L
s
.40558 .5378 m
.40624 .53823 L
s
1 .02 0 r
.50388 .53823 m
.50374 .53731 L
s
1 .006 0 r
.72049 .59189 m
.72056 .59194 L
s
.72043 .59194 m
.72049 .59189 L
s
.72049 .59189 m
.7205 .59189 L
s
.72056 .59194 m
.7205 .592 L
s
.7205 .59189 m
.72056 .59194 L
s
.7205 .592 m
.72043 .59194 L
s
.72043 .59194 m
.7205 .59189 L
s
.7205 .59189 m
.7205 .592 L
s
1 .142 0 r
.28725 .48429 m
.28171 .47829 L
s
1 .051 0 r
.40558 .5378 m
.40567 .53872 L
s
1 .629 0 r
.19189 .48182 m
.19586 .49295 L
s
1 .001 0 r
.77668 .45731 m
.77667 .45726 L
s
.77667 .45726 m
.77669 .45727 L
s
.77666 .45727 m
.77667 .45726 L
s
.77667 .45726 m
.77667 .45726 L
s
.77667 .45728 m
.77666 .45727 L
s
.77666 .45727 m
.77667 .45726 L
s
.77669 .45727 m
.77667 .45728 L
s
.77667 .45726 m
.77669 .45727 L
s
.77667 .45726 m
.77667 .45728 L
s
1 .003 0 r
.56004 .40336 m
.55999 .40324 L
s
.56 .40324 m
.56003 .40326 L
s
.55997 .40327 m
.56 .40324 L
s
.56 .40324 m
.55999 .40324 L
s
.56 .40329 m
.55997 .40327 L
s
.55997 .40327 m
.55999 .40324 L
s
.56003 .40326 m
.56 .40329 L
s
.55999 .40324 m
.56003 .40326 L
s
.55999 .40324 m
.56 .40329 L
s
1 .02 0 r
.50377 .53731 m
.50399 .53749 L
s
.50354 .53751 m
.50377 .53731 L
s
.50377 .53731 m
.50374 .53731 L
s
1 .003 0 r
.87784 .61822 m
.87787 .61808 L
s
1 .02 0 r
.50376 .53768 m
.50354 .53751 L
s
.50354 .53751 m
.50374 .53731 L
s
.50399 .53749 m
.50376 .53768 L
s
.50374 .53731 m
.50399 .53749 L
s
0 .041 1 r
.17161 .59124 m
.23501 .40679 L
s
1 .003 0 r
.87786 .61808 m
.8779 .61811 L
s
.87783 .61811 m
.87786 .61808 L
s
.87786 .61808 m
.87787 .61808 L
s
.8779 .61811 m
.87786 .61814 L
s
.87787 .61808 m
.8779 .61811 L
s
.87786 .61814 m
.87783 .61811 L
s
.87783 .61811 m
.87787 .61808 L
s
.87787 .61808 m
.87786 .61814 L
s
1 .02 0 r
.50374 .53731 m
.50376 .53768 L
s
1 .007 0 r
.66117 .56427 m
.66118 .56394 L
s
1 0 0 r
.61623 .26843 m
.61623 .26843 L
s
.61623 .26843 m
.61623 .26843 L
s
.61623 .26843 m
.61623 .26843 L
s
.61623 .26843 m
.61623 .26843 L
s
.61623 .26843 m
.61623 .26843 L
s
.61623 .26843 m
.61623 .26843 L
s
.61623 .26843 m
.61623 .26843 L
s
.61623 .26843 m
.61623 .26843 L
s
.61623 .26843 m
.61623 .26843 L
s
1 .15 0 r
.30664 .5352 m
.30821 .53641 L
s
.30492 .5367 m
.30664 .5352 L
s
.30664 .5352 m
.30607 .5352 L
s
1 .029 0 r
.44447 .51031 m
.44405 .509 L
s
1 .007 0 r
.66117 .56394 m
.66126 .564 L
s
.66109 .564 m
.66117 .56394 L
s
.66117 .56394 m
.66118 .56394 L
s
.66118 .56407 m
.66109 .564 L
s
.66109 .564 m
.66118 .56394 L
s
.66126 .564 m
.66118 .56407 L
s
.66118 .56394 m
.66126 .564 L
s
.66118 .56394 m
.66118 .56407 L
s
1 .001 0 r
.7174 .42935 m
.71738 .42929 L
s
.71739 .42929 m
.7174 .4293 L
s
.71737 .42931 m
.71739 .42929 L
s
.71739 .42929 m
.71738 .42929 L
s
.71739 .42932 m
.71737 .42931 L
s
.71737 .42931 m
.71738 .42929 L
s
.7174 .4293 m
.71739 .42932 L
s
.71738 .42929 m
.7174 .4293 L
s
.71738 .42929 m
.71739 .42932 L
s
1 .003 0 r
.50065 .37537 m
.50057 .37524 L
s
1 .15 0 r
.30649 .53792 m
.30492 .5367 L
s
.30492 .5367 m
.30607 .5352 L
s
1 .003 0 r
.50059 .37525 m
.50061 .37526 L
s
.50056 .37528 m
.50059 .37525 L
s
.50059 .37525 m
.50057 .37524 L
s
1 .142 0 r
.32883 .61731 m
.32933 .61106 L
s
1 .003 0 r
.50059 .37529 m
.50056 .37528 L
s
.50056 .37528 m
.50057 .37524 L
s
.50061 .37526 m
.50059 .37529 L
s
.50057 .37524 m
.50061 .37526 L
s
.50057 .37524 m
.50059 .37529 L
s
1 .262 0 r
.2693 .55983 m
.27207 .56221 L
s
.26621 .56223 m
.2693 .55983 L
s
.2693 .55983 m
.26881 .55985 L
s
1 .003 0 r
.81859 .59033 m
.81862 .59017 L
s
1 .082 0 r
.34532 .50849 m
.34617 .50911 L
s
.3444 .50936 m
.34532 .50849 L
s
.34532 .50849 m
.34493 .50849 L
s
1 0 0 r
.77364 .29438 m
.77364 .29437 L
s
.77364 .29437 m
.77364 .29437 L
s
.77364 .29437 m
.77364 .29437 L
s
.77364 .29437 m
.77364 .29437 L
s
.77364 .29437 m
.77364 .29437 L
s
.77364 .29437 m
.77364 .29437 L
s
.77364 .29437 m
.77364 .29437 L
s
.77364 .29437 m
.77364 .29437 L
s
.77364 .29437 m
.77364 .29437 L
s
1 .003 0 r
.81861 .59017 m
.81865 .59021 L
s
.81857 .59021 m
.81861 .59017 L
s
.81861 .59017 m
.81862 .59017 L
s
.81865 .59021 m
.81861 .59024 L
s
.81862 .59017 m
.81865 .59021 L
s
.81861 .59024 m
.81857 .59021 L
s
.81857 .59021 m
.81862 .59017 L
s
1 .15 0 r
.30821 .53641 m
.30649 .53792 L
s
.30607 .5352 m
.30821 .53641 L
s
1 .003 0 r
.81862 .59017 m
.81861 .59024 L
s
1 .009 0 r
.60182 .53635 m
.60178 .53594 L
s
1 .029 0 r
.44414 .50901 m
.44445 .50923 L
s
.44382 .50929 m
.44414 .50901 L
s
.44414 .50901 m
.44405 .509 L
s
1 .082 0 r
.34525 .50998 m
.3444 .50936 L
s
.3444 .50936 m
.34493 .50849 L
s
1 0 0 r
.55685 .24037 m
.55685 .24037 L
s
.55685 .24037 m
.55685 .24037 L
s
.55685 .24037 m
.55685 .24037 L
s
.55685 .24037 m
.55685 .24037 L
s
.55685 .24037 m
.55685 .24037 L
s
.55685 .24037 m
.55685 .24037 L
s
.55685 .24037 m
.55685 .24037 L
s
.55685 .24037 m
.55685 .24037 L
s
.55685 .24037 m
.55685 .24037 L
s
1 .029 0 r
.44413 .50952 m
.44382 .50929 L
s
.44382 .50929 m
.44405 .509 L
s
1 .043 0 r
.385 .48236 m
.38394 .48043 L
s
1 .029 0 r
.44445 .50923 m
.44413 .50952 L
s
.44405 .509 m
.44445 .50923 L
s
1 .009 0 r
.60179 .53594 m
.60189 .53601 L
s
.60169 .53602 m
.60179 .53594 L
s
.60179 .53594 m
.60178 .53594 L
s
1 .029 0 r
.44405 .509 m
.44413 .50952 L
s
1 .009 0 r
.60179 .5361 m
.60169 .53602 L
s
.60169 .53602 m
.60178 .53594 L
s
.60189 .53601 m
.60179 .5361 L
s
.60178 .53594 m
.60189 .53601 L
s
1 .082 0 r
.34617 .50911 m
.34525 .50998 L
s
.34493 .50849 m
.34617 .50911 L
s
1 .009 0 r
.60178 .53594 m
.60179 .5361 L
s
1 .001 0 r
.65805 .40136 m
.65804 .4013 L
s
.65804 .40131 m
.65805 .40131 L
s
.65803 .40132 m
.65804 .40131 L
s
.65804 .40131 m
.65804 .4013 L
s
1 .15 0 r
.30607 .5352 m
.30649 .53792 L
s
1 .001 0 r
.65804 .40133 m
.65803 .40132 L
s
.65803 .40132 m
.65804 .4013 L
s
.65805 .40131 m
.65804 .40133 L
s
.65804 .4013 m
.65805 .40131 L
s
.65804 .4013 m
.65804 .40133 L
s
1 .082 0 r
.34493 .50849 m
.34525 .50998 L
s
1 .003 0 r
.44119 .34735 m
.44109 .34724 L
s
.44111 .34724 m
.44114 .34725 L
s
.44109 .34727 m
.44111 .34724 L
s
.44111 .34724 m
.44109 .34724 L
s
.44111 .34728 m
.44109 .34727 L
s
.44109 .34727 m
.44109 .34724 L
s
1 .27 0 r
.26929 .58941 m
.26757 .5773 L
s
1 .003 0 r
.44114 .34725 m
.44111 .34728 L
s
.44109 .34724 m
.44114 .34725 L
s
.44109 .34724 m
.44111 .34728 L
s
1 .004 0 r
.75929 .56241 m
.7593 .56223 L
s
1 0 0 r
.71432 .26631 m
.71432 .26631 L
s
.71432 .26631 m
.71432 .26631 L
s
.71432 .26631 m
.71432 .26631 L
s
.71432 .26631 m
.71432 .26631 L
s
.71432 .26631 m
.71432 .26631 L
s
.71432 .26631 m
.71432 .26631 L
s
.71432 .26631 m
.71432 .26631 L
s
.71432 .26631 m
.71432 .26631 L
s
.71432 .26631 m
.71432 .26631 L
s
1 .004 0 r
.7593 .56223 m
.75935 .56227 L
s
.75926 .56227 m
.7593 .56223 L
s
.7593 .56223 m
.7593 .56223 L
s
.7593 .56231 m
.75926 .56227 L
s
.75926 .56227 m
.7593 .56223 L
s
.75935 .56227 m
.7593 .56231 L
s
.7593 .56223 m
.75935 .56227 L
s
.7593 .56223 m
.7593 .56231 L
s
1 .262 0 r
.26898 .56461 m
.26621 .56223 L
s
.26621 .56223 m
.26881 .55985 L
s
1 .012 0 r
.5424 .50841 m
.54229 .50787 L
s
1 .262 0 r
.27207 .56221 m
.26898 .56461 L
s
.26881 .55985 m
.27207 .56221 L
s
1 .067 0 r
.32547 .45439 m
.32287 .45155 L
s
1 .001 0 r
.81559 .42738 m
.81558 .42734 L
s
.81559 .42734 m
.81559 .42735 L
s
.81558 .42735 m
.81559 .42734 L
s
.81559 .42734 m
.81558 .42734 L
s
.81559 .42736 m
.81558 .42735 L
s
.81558 .42735 m
.81558 .42734 L
s
.81559 .42735 m
.81559 .42736 L
s
.81558 .42734 m
.81559 .42735 L
s
.81558 .42734 m
.81559 .42736 L
s
1 .012 0 r
.54231 .50787 m
.54244 .50797 L
s
.54218 .50799 m
.54231 .50787 L
s
.54231 .50787 m
.54229 .50787 L
s
.54231 .50808 m
.54218 .50799 L
s
.54218 .50799 m
.54229 .50787 L
s
.54244 .50797 m
.54231 .50808 L
s
.54229 .50787 m
.54244 .50797 L
s
1 .043 0 r
.38417 .48043 m
.38461 .48074 L
s
.3837 .48089 m
.38417 .48043 L
s
.38417 .48043 m
.38394 .48043 L
s
1 .001 0 r
.59865 .37334 m
.59863 .37329 L
s
1 .012 0 r
.54229 .50787 m
.54231 .50808 L
s
1 .001 0 r
.59863 .37329 m
.59865 .3733 L
s
.59862 .3733 m
.59863 .37329 L
s
.59863 .37329 m
.59863 .37329 L
s
.59863 .37331 m
.59862 .3733 L
s
.59862 .3733 m
.59863 .37329 L
s
.59865 .3733 m
.59863 .37331 L
s
.59863 .37329 m
.59865 .3733 L
s
.59863 .37329 m
.59863 .37331 L
s
1 .058 0 r
.42668 .61551 m
.42679 .61295 L
s
1 .043 0 r
.38414 .4812 m
.3837 .48089 L
s
.3837 .48089 m
.38394 .48043 L
s
0 .558 1 r
.26952 .26544 m
.22925 .28752 L
s
.24285 .22326 m
.26952 .26544 L
s
1 .043 0 r
.38461 .48074 m
.38414 .4812 L
s
.38394 .48043 m
.38461 .48074 L
s
1 .654 0 r
.20968 .56148 m
.18636 .53355 L
s
1 .005 0 r
.69993 .53447 m
.69992 .53426 L
s
1 .043 0 r
.38394 .48043 m
.38414 .4812 L
s
1 .64 0 r
.19504 .49861 m
.20098 .50282 L
s
.18812 .50592 m
.19504 .49861 L
s
.19504 .49861 m
.18998 .4988 L
s
1 0 0 r
.65493 .23822 m
.65493 .23822 L
s
.65493 .23822 m
.65493 .23822 L
s
.65493 .23822 m
.65493 .23822 L
s
.65493 .23822 m
.65493 .23822 L
s
.65493 .23822 m
.65493 .23822 L
s
.65493 .23822 m
.65493 .23822 L
s
.65493 .23822 m
.65493 .23822 L
s
.65493 .23822 m
.65493 .23822 L
s
.65493 .23822 m
.65493 .23822 L
s
1 .005 0 r
.69992 .53426 m
.69998 .5343 L
s
.69987 .5343 m
.69992 .53426 L
s
.69992 .53426 m
.69992 .53426 L
s
.69993 .53434 m
.69987 .5343 L
s
.69987 .5343 m
.69992 .53426 L
s
.69998 .5343 m
.69993 .53434 L
s
.69992 .53426 m
.69998 .5343 L
s
1 .015 0 r
.48293 .48043 m
.48266 .47972 L
s
1 .005 0 r
.69992 .53426 m
.69993 .53434 L
s
1 .45 0 r
.23856 .58178 m
.2432 .58673 L
s
.2333 .58509 m
.23856 .58178 L
s
.23856 .58178 m
.23971 .58204 L
s
1 .262 0 r
.26881 .55985 m
.26898 .56461 L
s
1 .142 0 r
.2829 .47822 m
.2842 .47908 L
s
.28144 .47991 m
.2829 .47822 L
s
.2829 .47822 m
.28171 .47829 L
s
1 .001 0 r
.75624 .39936 m
.75624 .39933 L
s
.75624 .39933 m
.75624 .39933 L
s
.75623 .39934 m
.75624 .39933 L
s
.75624 .39933 m
.75624 .39933 L
s
.75624 .39934 m
.75623 .39934 L
s
.75623 .39934 m
.75624 .39933 L
s
.75624 .39933 m
.75624 .39934 L
s
.75624 .39933 m
.75624 .39933 L
s
.75624 .39933 m
.75624 .39934 L
s
.53919 .3453 m
.53916 .34525 L
s
1 .015 0 r
.48272 .47973 m
.48288 .47985 L
s
.48255 .47989 m
.48272 .47973 L
s
.48272 .47973 m
.48266 .47972 L
s
1 .001 0 r
.53917 .34525 m
.53918 .34526 L
s
.53916 .34526 m
.53917 .34525 L
s
.53917 .34525 m
.53916 .34525 L
s
.53917 .34527 m
.53916 .34526 L
s
.53916 .34526 m
.53916 .34525 L
s
1 .142 0 r
.28274 .48076 m
.28144 .47991 L
s
.28144 .47991 m
.28171 .47829 L
s
1 .001 0 r
.53918 .34526 m
.53917 .34527 L
s
.53916 .34525 m
.53918 .34526 L
s
.53916 .34525 m
.53917 .34527 L
s
1 .015 0 r
.48271 .48 m
.48255 .47989 L
s
.48255 .47989 m
.48266 .47972 L
s
1 .092 0 r
.36714 .58758 m
.36666 .58345 L
s
1 .015 0 r
.48288 .47985 m
.48271 .48 L
s
.48266 .47972 m
.48288 .47985 L
s
.48266 .47972 m
.48271 .48 L
s
1 .002 0 r
.85759 .56056 m
.8576 .56045 L
s
.8576 .56045 m
.85762 .56047 L
s
.85757 .56047 m
.8576 .56045 L
s
.8576 .56045 m
.8576 .56045 L
s
.8576 .56049 m
.85757 .56047 L
s
.85757 .56047 m
.8576 .56045 L
s
.85762 .56047 m
.8576 .56049 L
s
.8576 .56045 m
.85762 .56047 L
s
.8576 .56045 m
.8576 .56049 L
s
1 .663 0 r
.22566 .62345 m
.22129 .61391 L
s
.23407 .61391 m
.22566 .62345 L
s
1 .005 0 r
.64051 .5065 m
.64048 .50625 L
s
.64048 .50625 m
.64054 .50629 L
s
.64042 .5063 m
.64048 .50625 L
s
.64048 .50625 m
.64048 .50625 L
s
1 .067 0 r
.32342 .45152 m
.32404 .45191 L
s
.32274 .45232 m
.32342 .45152 L
s
.32342 .45152 m
.32287 .45155 L
s
1 .021 0 r
.42339 .45243 m
.42284 .45148 L
s
1 .005 0 r
.64049 .50635 m
.64042 .5063 L
s
.64042 .5063 m
.64048 .50625 L
s
.64054 .50629 m
.64049 .50635 L
s
.64048 .50625 m
.64054 .50629 L
s
.64048 .50625 m
.64049 .50635 L
s
1 .067 0 r
.32336 .45271 m
.32274 .45232 L
s
.32274 .45232 m
.32287 .45155 L
s
1 .663 0 r
.22129 .61391 m
.23407 .61391 L
s
1 .142 0 r
.2842 .47908 m
.28274 .48076 L
s
.28171 .47829 m
.2842 .47908 L
s
1 .001 0 r
.69684 .37131 m
.69683 .37129 L
s
.69683 .37129 m
.69683 .37129 L
s
.69682 .37129 m
.69683 .37129 L
s
.69683 .37129 m
.69683 .37129 L
s
.69683 .3713 m
.69682 .37129 L
s
.69682 .37129 m
.69683 .37129 L
s
.69683 .37129 m
.69683 .3713 L
s
.69683 .37129 m
.69683 .37129 L
s
.69683 .37129 m
.69683 .3713 L
s
1 .058 0 r
.42678 .61292 m
.42742 .61348 L
s
.42612 .61344 m
.42678 .61292 L
s
.42678 .61292 m
.42679 .61295 L
s
1 .026 0 r
.52472 .6137 m
.52477 .61253 L
s
1 .64 0 r
.19404 .51015 m
.18812 .50592 L
s
.18812 .50592 m
.18998 .4988 L
s
1 .45 0 r
.2432 .58673 m
.23795 .59006 L
s
.23971 .58204 m
.2432 .58673 L
s
1 .001 0 r
.47967 .31722 m
.47964 .31719 L
s
.47965 .31719 m
.47966 .31719 L
s
.47964 .3172 m
.47965 .31719 L
s
.47965 .31719 m
.47964 .31719 L
s
.47965 .3172 m
.47964 .3172 L
s
.47964 .3172 m
.47964 .31719 L
s
1 .067 0 r
.32404 .45191 m
.32336 .45271 L
s
.32287 .45155 m
.32404 .45191 L
s
1 .001 0 r
.47966 .31719 m
.47965 .3172 L
s
.47964 .31719 m
.47966 .31719 L
s
.47964 .31719 m
.47965 .3172 L
s
1 .289 0 r
.24044 .50175 m
.24308 .50355 L
s
.23741 .50516 m
.24044 .50175 L
s
.24044 .50175 m
.23801 .50191 L
s
1 .142 0 r
.28171 .47829 m
.28274 .48076 L
s
1 .16 0 r
.30753 .55963 m
.30489 .55244 L
s
1 .058 0 r
.42742 .61348 m
.42675 .614 L
s
.42679 .61295 m
.42742 .61348 L
s
1 .067 0 r
.32287 .45155 m
.32336 .45271 L
s
1 .021 0 r
.42295 .45148 m
.42317 .45163 L
s
.42273 .45171 m
.42295 .45148 L
s
.42295 .45148 m
.42284 .45148 L
s
1 .058 0 r
.42675 .614 m
.42612 .61344 L
s
.42612 .61344 m
.42679 .61295 L
s
1 .003 0 r
.79822 .53259 m
.79823 .53247 L
s
1 .021 0 r
.42294 .45186 m
.42273 .45171 L
s
.42273 .45171 m
.42284 .45148 L
s
1 .003 0 r
.79822 .53247 m
.79825 .53249 L
s
.7982 .53249 m
.79822 .53247 L
s
.79822 .53247 m
.79823 .53247 L
s
.79823 .53252 m
.7982 .53249 L
s
.7982 .53249 m
.79823 .53247 L
s
.79825 .53249 m
.79823 .53252 L
s
.79823 .53247 m
.79825 .53249 L
s
1 0 0 r
.75319 .23607 m
.75319 .23607 L
s
.75319 .23607 m
.75319 .23607 L
s
.75319 .23607 m
.75319 .23607 L
s
.75319 .23607 m
.75319 .23607 L
s
.75319 .23607 m
.75319 .23607 L
s
.75319 .23607 m
.75319 .23607 L
s
.75319 .23607 m
.75319 .23607 L
s
.75319 .23607 m
.75319 .23607 L
s
.75319 .23607 m
.75319 .23607 L
s
1 .003 0 r
.79823 .53247 m
.79823 .53252 L
s
1 .021 0 r
.42317 .45163 m
.42294 .45186 L
s
.42284 .45148 m
.42317 .45163 L
s
.42284 .45148 m
.42294 .45186 L
s
1 .006 0 r
.58103 .4785 m
.58095 .4782 L
s
1 .058 0 r
.42679 .61295 m
.42675 .614 L
s
1 .029 0 r
.3638 .4244 m
.36267 .42315 L
s
1 .006 0 r
.58097 .4782 m
.58104 .47825 L
s
.5809 .47827 m
.58097 .4782 L
s
.58097 .4782 m
.58095 .4782 L
s
.58097 .47832 m
.5809 .47827 L
s
.5809 .47827 m
.58095 .4782 L
s
.58104 .47825 m
.58097 .47832 L
s
.58095 .4782 m
.58104 .47825 L
s
.58095 .4782 m
.58097 .47832 L
s
1 .142 0 r
.3293 .61099 m
.33083 .6124 L
s
.32763 .61222 m
.3293 .61099 L
s
.3293 .61099 m
.32933 .61106 L
s
1 .289 0 r
.24005 .50697 m
.23741 .50516 L
s
.23741 .50516 m
.23801 .50191 L
s
1 .026 0 r
.52476 .61252 m
.52506 .61277 L
s
.52447 .61276 m
.52476 .61252 L
s
.52476 .61252 m
.52477 .61253 L
s
1 0 0 r
.63737 .34324 m
.63736 .34322 L
s
.63736 .34322 m
.63737 .34322 L
s
.63736 .34323 m
.63736 .34322 L
s
.63736 .34322 m
.63736 .34322 L
s
1 .026 0 r
.52506 .61277 m
.52476 .61301 L
s
.52477 .61253 m
.52506 .61277 L
s
1 0 0 r
.63736 .34323 m
.63736 .34323 L
s
.63736 .34323 m
.63736 .34322 L
s
.63737 .34322 m
.63736 .34323 L
s
.63736 .34322 m
.63737 .34322 L
s
.63736 .34322 m
.63736 .34323 L
s
1 .026 0 r
.52476 .61301 m
.52447 .61276 L
s
.52447 .61276 m
.52477 .61253 L
s
1 .038 0 r
.46516 .58574 m
.46504 .58405 L
s
1 .026 0 r
.52477 .61253 m
.52476 .61301 L
s
1 .301 0 r
.24786 .53164 m
.23624 .51901 L
s
1 .003 0 r
.7388 .50459 m
.73879 .50446 L
s
1 .142 0 r
.33083 .6124 m
.32916 .61363 L
s
.32933 .61106 m
.33083 .6124 L
s
1 .003 0 r
.73879 .50446 m
.73882 .50448 L
s
.73876 .50449 m
.73879 .50446 L
s
.73879 .50446 m
.73879 .50446 L
s
.73879 .50451 m
.73876 .50449 L
s
.73876 .50449 m
.73879 .50446 L
s
.73882 .50448 m
.73879 .50451 L
s
.73879 .50446 m
.73882 .50448 L
s
.73879 .50446 m
.73879 .50451 L
s
1 .029 0 r
.3629 .42314 m
.36318 .42331 L
s
.36261 .42349 m
.3629 .42314 L
s
.3629 .42314 m
.36267 .42315 L
s
1 .008 0 r
.52149 .45047 m
.52134 .45011 L
s
1 .142 0 r
.32916 .61363 m
.32763 .61222 L
s
.32763 .61222 m
.32933 .61106 L
s
1 .029 0 r
.36288 .42365 m
.36261 .42349 L
s
.36261 .42349 m
.36267 .42315 L
s
1 .45 0 r
.23795 .59006 m
.2333 .58509 L
s
.2333 .58509 m
.23971 .58204 L
s
1 .029 0 r
.36318 .42331 m
.36288 .42365 L
s
.36267 .42315 m
.36318 .42331 L
s
1 .008 0 r
.52137 .45011 m
.52146 .45017 L
s
.52129 .45019 m
.52137 .45011 L
s
.52137 .45011 m
.52134 .45011 L
s
1 .029 0 r
.36267 .42315 m
.36288 .42365 L
s
1 .008 0 r
.52137 .45025 m
.52129 .45019 L
s
.52129 .45019 m
.52134 .45011 L
s
1 0 0 r
.7952 .36928 m
.79519 .36927 L
s
.79519 .36927 m
.7952 .36927 L
s
.79519 .36927 m
.79519 .36927 L
s
.79519 .36927 m
.79519 .36927 L
s
1 .008 0 r
.52146 .45017 m
.52137 .45025 L
s
.52134 .45011 m
.52146 .45017 L
s
1 0 0 r
.79519 .36927 m
.79519 .36927 L
s
.79519 .36927 m
.79519 .36927 L
s
.7952 .36927 m
.79519 .36927 L
s
.79519 .36927 m
.7952 .36927 L
s
.79519 .36927 m
.79519 .36927 L
s
1 .008 0 r
.52134 .45011 m
.52137 .45025 L
s
1 .013 0 r
.62293 .61188 m
.62297 .6113 L
s
1 0 0 r
.57785 .31514 m
.57784 .31513 L
s
.57784 .31513 m
.57784 .31513 L
s
.57784 .31513 m
.57784 .31513 L
s
.57784 .31513 m
.57784 .31513 L
s
.57784 .31513 m
.57784 .31513 L
s
.57784 .31513 m
.57784 .31513 L
s
.57784 .31513 m
.57784 .31513 L
s
.57784 .31513 m
.57784 .31513 L
s
.57784 .31513 m
.57784 .31513 L
s
1 .057 0 r
.40555 .55776 m
.40493 .55518 L
s
1 .092 0 r
.36679 .58342 m
.36779 .58426 L
s
.36572 .58428 m
.36679 .58342 L
s
.36679 .58342 m
.36666 .58345 L
s
1 .142 0 r
.32933 .61106 m
.32916 .61363 L
s
1 .038 0 r
.46507 .58404 m
.46549 .58438 L
s
.46464 .5844 m
.46507 .58404 L
s
.46507 .58404 m
.46504 .58405 L
s
1 .013 0 r
.62296 .61129 m
.62311 .61142 L
s
.62281 .61142 m
.62296 .61129 L
s
.62296 .61129 m
.62297 .6113 L
s
1 .289 0 r
.24308 .50355 m
.24005 .50697 L
s
.23801 .50191 m
.24308 .50355 L
s
1 .003 0 r
.67931 .47656 m
.67929 .47642 L
s
1 .013 0 r
.62311 .61142 m
.62296 .61154 L
s
.62297 .6113 m
.62311 .61142 L
s
.62296 .61154 m
.62281 .61142 L
s
.62281 .61142 m
.62297 .6113 L
s
1 .038 0 r
.46506 .58474 m
.46464 .5844 L
s
.46464 .5844 m
.46504 .58405 L
s
.46549 .58438 m
.46506 .58474 L
s
.46504 .58405 m
.46549 .58438 L
s
1 .013 0 r
.62297 .6113 m
.62296 .61154 L
s
1 .003 0 r
.67929 .47642 m
.67933 .47644 L
s
.67926 .47645 m
.67929 .47642 L
s
.67929 .47642 m
.67929 .47642 L
s
.6793 .47647 m
.67926 .47645 L
s
.67926 .47645 m
.67929 .47642 L
s
.67933 .47644 m
.6793 .47647 L
s
.67929 .47642 m
.67933 .47644 L
s
.67929 .47642 m
.6793 .47647 L
s
1 .092 0 r
.36672 .58512 m
.36572 .58428 L
s
.36572 .58428 m
.36666 .58345 L
s
1 .01 0 r
.46189 .42242 m
.46162 .42197 L
s
1 .092 0 r
.36779 .58426 m
.36672 .58512 L
s
.36666 .58345 m
.36779 .58426 L
s
1 .038 0 r
.46504 .58405 m
.46506 .58474 L
s
1 0 0 r
.73573 .34118 m
.73572 .34117 L
s
1 .01 0 r
.46168 .42198 m
.46178 .42204 L
s
.46158 .42208 m
.46168 .42198 L
s
.46168 .42198 m
.46162 .42197 L
s
1 0 0 r
.73572 .34117 m
.73573 .34117 L
s
.73572 .34117 m
.73572 .34117 L
s
.73572 .34117 m
.73572 .34117 L
s
.73572 .34118 m
.73572 .34117 L
s
.73572 .34117 m
.73572 .34117 L
s
.73573 .34117 m
.73572 .34118 L
s
.73572 .34117 m
.73573 .34117 L
s
.73572 .34117 m
.73572 .34118 L
s
1 .01 0 r
.46168 .42215 m
.46158 .42208 L
s
.46158 .42208 m
.46162 .42197 L
s
.46178 .42204 m
.46168 .42215 L
s
.46162 .42197 m
.46178 .42204 L
s
1 .017 0 r
.56337 .5839 m
.56334 .58313 L
s
1 .01 0 r
.46162 .42197 m
.46168 .42215 L
s
1 .289 0 r
.23801 .50191 m
.24005 .50697 L
s
1 .092 0 r
.36666 .58345 m
.36672 .58512 L
s
1 .45 0 r
.23971 .58204 m
.23795 .59006 L
s
1 0 0 r
.51826 .28701 m
.51826 .287 L
s
.51826 .287 m
.51826 .28701 L
s
.51826 .28701 m
.51826 .287 L
s
.51826 .287 m
.51826 .287 L
s
.51826 .28701 m
.51826 .28701 L
s
.51826 .28701 m
.51826 .287 L
s
.51826 .28701 m
.51826 .28701 L
s
.51826 .287 m
.51826 .28701 L
s
.51826 .287 m
.51826 .28701 L
s
1 .64 0 r
.20098 .50282 m
.19404 .51015 L
s
.18998 .4988 m
.20098 .50282 L
s
1 .092 0 r
.34588 .52975 m
.34388 .52562 L
s
1 .002 0 r
.83726 .50268 m
.83726 .5026 L
s
.83726 .5026 m
.83728 .50262 L
s
.83725 .50262 m
.83726 .5026 L
s
.83726 .5026 m
.83726 .5026 L
s
.83727 .50263 m
.83725 .50262 L
s
.83725 .50262 m
.83726 .5026 L
s
.83728 .50262 m
.83727 .50263 L
s
.83726 .5026 m
.83728 .50262 L
s
.83726 .5026 m
.83727 .50263 L
s
1 .003 0 r
.61977 .44851 m
.61972 .44835 L
s
1 .017 0 r
.56335 .58312 m
.56354 .58328 L
s
.56315 .58329 m
.56335 .58312 L
s
.56335 .58312 m
.56334 .58313 L
s
1 .003 0 r
.61973 .44835 m
.61977 .44837 L
s
.61969 .44838 m
.61973 .44835 L
s
.61973 .44835 m
.61972 .44835 L
s
.61973 .44841 m
.61969 .44838 L
s
.61969 .44838 m
.61972 .44835 L
s
.61977 .44837 m
.61973 .44841 L
s
.61972 .44835 m
.61977 .44837 L
s
.61972 .44835 m
.61973 .44841 L
s
1 .017 0 r
.56335 .58344 m
.56315 .58329 L
s
.56315 .58329 m
.56334 .58313 L
s
.56354 .58328 m
.56335 .58344 L
s
.56334 .58313 m
.56354 .58328 L
s
1 .012 0 r
.40223 .39434 m
.40178 .39382 L
s
1 .017 0 r
.56334 .58313 m
.56335 .58344 L
s
1 .007 0 r
.72131 .61007 m
.72135 .60975 L
s
1 0 0 r
.6762 .31305 m
.67619 .31305 L
s
.67619 .31305 m
.6762 .31305 L
s
.67619 .31305 m
.67619 .31305 L
s
.67619 .31305 m
.67619 .31305 L
s
.67619 .31305 m
.67619 .31305 L
s
.67619 .31305 m
.67619 .31305 L
s
.6762 .31305 m
.67619 .31305 L
s
.67619 .31305 m
.6762 .31305 L
s
.67619 .31305 m
.67619 .31305 L
s
1 .057 0 r
.40507 .55517 m
.40569 .55566 L
s
.40442 .55573 m
.40507 .55517 L
s
.40507 .55517 m
.40493 .55518 L
s
1 .012 0 r
.40187 .39382 m
.40199 .39388 L
s
.40175 .39396 m
.40187 .39382 L
s
.40187 .39382 m
.40178 .39382 L
s
.40187 .39402 m
.40175 .39396 L
s
.40175 .39396 m
.40178 .39382 L
s
1 .024 0 r
.50375 .5559 m
.50358 .55483 L
s
1 .007 0 r
.72134 .60975 m
.72142 .60981 L
s
.72126 .60981 m
.72134 .60975 L
s
.72134 .60975 m
.72135 .60975 L
s
1 .012 0 r
.40199 .39388 m
.40187 .39402 L
s
.40178 .39382 m
.40199 .39388 L
s
1 .007 0 r
.72142 .60981 m
.72134 .60988 L
s
.72135 .60975 m
.72142 .60981 L
s
.72134 .60988 m
.72126 .60981 L
s
.72126 .60981 m
.72135 .60975 L
s
1 .012 0 r
.40178 .39382 m
.40187 .39402 L
s
1 .007 0 r
.72135 .60975 m
.72134 .60988 L
s
1 .057 0 r
.40504 .55622 m
.40442 .55573 L
s
.40442 .55573 m
.40493 .55518 L
s
1 .155 0 r
.28615 .50172 m
.28004 .49517 L
s
1 .057 0 r
.40569 .55566 m
.40504 .55622 L
s
.40493 .55518 m
.40569 .55566 L
s
1 .002 0 r
.77778 .47462 m
.77777 .47455 L
s
.77777 .47455 m
.77779 .47456 L
s
.77775 .47456 m
.77777 .47455 L
s
.77777 .47455 m
.77777 .47455 L
s
.77777 .47458 m
.77775 .47456 L
s
.77775 .47456 m
.77777 .47455 L
s
.77779 .47456 m
.77777 .47458 L
s
.77777 .47455 m
.77779 .47456 L
s
.77777 .47455 m
.77777 .47458 L
s
1 .004 0 r
.56017 .42043 m
.56009 .42025 L
s
1 .057 0 r
.40493 .55518 m
.40504 .55622 L
s
1 .004 0 r
.5601 .42025 m
.56015 .42028 L
s
.56006 .42029 m
.5601 .42025 L
s
.5601 .42025 m
.56009 .42025 L
s
.5601 .42032 m
.56006 .42029 L
s
.56006 .42029 m
.56009 .42025 L
s
.56015 .42028 m
.5601 .42032 L
s
.56009 .42025 m
.56015 .42028 L
s
.56009 .42025 m
.5601 .42032 L
s
1 .64 0 r
.18998 .4988 m
.19404 .51015 L
s
1 .024 0 r
.50362 .55482 m
.50388 .55503 L
s
.50335 .55505 m
.50362 .55482 L
s
.50362 .55482 m
.50358 .55483 L
s
0 .04 1 r
.16999 .60916 m
.23357 .4254 L
s
1 .009 0 r
.66175 .58206 m
.66176 .58167 L
s
1 .024 0 r
.50361 .55526 m
.50335 .55505 L
s
.50335 .55505 m
.50358 .55483 L
s
.50388 .55503 m
.50361 .55526 L
s
.50358 .55483 m
.50388 .55503 L
s
1 0 0 r
.61661 .2849 m
.61661 .2849 L
s
.61661 .2849 m
.61661 .2849 L
s
.61661 .2849 m
.61661 .2849 L
s
.61661 .2849 m
.61661 .2849 L
s
.61661 .2849 m
.61661 .2849 L
s
.61661 .2849 m
.61661 .2849 L
s
.61661 .2849 m
.61661 .2849 L
s
.61661 .2849 m
.61661 .2849 L
s
.61661 .2849 m
.61661 .2849 L
s
1 .024 0 r
.50358 .55483 m
.50361 .55526 L
s
1 .034 0 r
.44407 .52786 m
.44358 .52633 L
s
1 .009 0 r
.66175 .58167 m
.66185 .58175 L
s
.66166 .58175 m
.66175 .58167 L
s
.66175 .58167 m
.66176 .58167 L
s
.66176 .58183 m
.66166 .58175 L
s
.66166 .58175 m
.66176 .58167 L
s
.66185 .58175 m
.66176 .58183 L
s
.66176 .58167 m
.66185 .58175 L
s
.66176 .58167 m
.66176 .58183 L
s
1 .16 0 r
.3055 .55242 m
.30718 .55373 L
s
.30366 .55403 m
.3055 .55242 L
s
.3055 .55242 m
.30489 .55244 L
s
1 .002 0 r
.71823 .44654 m
.71821 .44646 L
s
.71821 .44646 m
.71823 .44648 L
s
.71819 .44648 m
.71821 .44646 L
s
.71821 .44646 m
.71821 .44646 L
s
.71821 .44649 m
.71819 .44648 L
s
.71819 .44648 m
.71821 .44646 L
s
.71823 .44648 m
.71821 .44649 L
s
.71821 .44646 m
.71823 .44648 L
s
.71821 .44646 m
.71821 .44649 L
s
1 .004 0 r
.5005 .39232 m
.50038 .39212 L
s
.50041 .39212 m
.50045 .39215 L
s
.50036 .39217 m
.50041 .39212 L
s
.50041 .39212 m
.50038 .39212 L
s
.50041 .3922 m
.50036 .39217 L
s
.50036 .39217 m
.50038 .39212 L
s
.50045 .39215 m
.50041 .3922 L
s
.50038 .39212 m
.50045 .39215 L
s
.50038 .39212 m
.50041 .3922 L
s
.81988 .60825 m
.81991 .60806 L
s
1 0 0 r
.77473 .31096 m
.77473 .31096 L
s
.77473 .31096 m
.77473 .31096 L
s
.77473 .31096 m
.77473 .31096 L
s
.77473 .31096 m
.77473 .31096 L
s
.77473 .31096 m
.77473 .31096 L
s
.77473 .31096 m
.77473 .31096 L
s
.77473 .31096 m
.77473 .31096 L
s
.77473 .31096 m
.77473 .31096 L
s
.77473 .31096 m
.77473 .31096 L
s
1 .004 0 r
.8199 .60806 m
.81995 .6081 L
s
.81986 .6081 m
.8199 .60806 L
s
.8199 .60806 m
.81991 .60806 L
s
.81995 .6081 m
.8199 .60814 L
s
.81991 .60806 m
.81995 .6081 L
s
.8199 .60814 m
.81986 .6081 L
s
.81986 .6081 m
.81991 .60806 L
s
.81991 .60806 m
.8199 .60814 L
s
1 .16 0 r
.30534 .55534 m
.30366 .55403 L
s
.30366 .55403 m
.30489 .55244 L
s
1 .011 0 r
.60213 .55403 m
.60208 .55353 L
s
1 .27 0 r
.26808 .57725 m
.27095 .57972 L
s
.26488 .57975 m
.26808 .57725 L
s
.26808 .57725 m
.26757 .5773 L
s
1 0 0 r
.55696 .25672 m
.55696 .25671 L
s
.55696 .25671 m
.55696 .25671 L
s
.55696 .25672 m
.55696 .25671 L
s
.55696 .25671 m
.55696 .25671 L
s
.55696 .25672 m
.55696 .25672 L
s
.55696 .25672 m
.55696 .25671 L
s
.55696 .25671 m
.55696 .25672 L
s
.55696 .25671 m
.55696 .25671 L
s
.55696 .25671 m
.55696 .25672 L
s
1 .092 0 r
.34432 .52561 m
.34527 .52631 L
s
.34328 .52659 m
.34432 .52561 L
s
.34432 .52561 m
.34388 .52562 L
s
1 .051 0 r
.38433 .4998 m
.38308 .49752 L
s
1 .034 0 r
.44369 .52633 m
.44405 .5266 L
s
.44331 .52667 m
.44369 .52633 L
s
.44369 .52633 m
.44358 .52633 L
s
1 .16 0 r
.30718 .55373 m
.30534 .55534 L
s
.30489 .55244 m
.30718 .55373 L
s
1 .034 0 r
.44367 .52694 m
.44331 .52667 L
s
.44331 .52667 m
.44358 .52633 L
s
1 .011 0 r
.60209 .55353 m
.60222 .55362 L
s
.60197 .55363 m
.60209 .55353 L
s
.60209 .55353 m
.60208 .55353 L
s
.60209 .55373 m
.60197 .55363 L
s
.60197 .55363 m
.60208 .55353 L
s
.60222 .55362 m
.60209 .55373 L
s
.60208 .55353 m
.60222 .55362 L
s
1 .034 0 r
.44405 .5266 m
.44367 .52694 L
s
.44358 .52633 m
.44405 .5266 L
s
1 .092 0 r
.34424 .52728 m
.34328 .52659 L
s
.34328 .52659 m
.34388 .52562 L
s
1 .011 0 r
.60208 .55353 m
.60209 .55373 L
s
1 .002 0 r
.65862 .41844 m
.65859 .41835 L
s
.6586 .41835 m
.65862 .41837 L
s
.65858 .41837 m
.6586 .41835 L
s
.6586 .41835 m
.65859 .41835 L
s
1 .034 0 r
.44358 .52633 m
.44367 .52694 L
s
1 .002 0 r
.6586 .41838 m
.65858 .41837 L
s
.65858 .41837 m
.65859 .41835 L
s
.65862 .41837 m
.6586 .41838 L
s
.65859 .41835 m
.65862 .41837 L
s
.65859 .41835 m
.6586 .41838 L
s
1 .005 0 r
.44078 .36418 m
.44061 .36398 L
s
1 .092 0 r
.34527 .52631 m
.34424 .52728 L
s
.34388 .52562 m
.34527 .52631 L
s
1 .276 0 r
.2681 .60734 m
.26633 .59498 L
s
1 .005 0 r
.44064 .36398 m
.44069 .36401 L
s
.4406 .36404 m
.44064 .36398 L
s
.44064 .36398 m
.44061 .36398 L
s
.44064 .36406 m
.4406 .36404 L
s
.4406 .36404 m
.44061 .36398 L
s
.44069 .36401 m
.44064 .36406 L
s
.44061 .36398 m
.44069 .36401 L
s
.44061 .36398 m
.44064 .36406 L
s
.76031 .58022 m
.76033 .58 L
s
1 .16 0 r
.30489 .55244 m
.30534 .55534 L
s
1 0 0 r
.71513 .28278 m
.71513 .28278 L
s
.71513 .28278 m
.71513 .28278 L
s
.71513 .28278 m
.71513 .28278 L
s
.71513 .28278 m
.71513 .28278 L
s
.71513 .28278 m
.71513 .28278 L
s
.71513 .28278 m
.71513 .28278 L
s
.71513 .28278 m
.71513 .28278 L
s
.71513 .28278 m
.71513 .28278 L
s
.71513 .28278 m
.71513 .28278 L
s
1 .005 0 r
.76032 .58 m
.76038 .58004 L
s
.76027 .58004 m
.76032 .58 L
s
.76032 .58 m
.76033 .58 L
s
1 .092 0 r
.34388 .52562 m
.34424 .52728 L
s
1 .005 0 r
.76033 .58009 m
.76027 .58004 L
s
.76027 .58004 m
.76033 .58 L
s
.76038 .58004 m
.76033 .58009 L
s
.76033 .58 m
.76038 .58004 L
s
1 .014 0 r
.54244 .52597 m
.5423 .52531 L
s
1 .005 0 r
.76033 .58 m
.76033 .58009 L
s
1 .078 0 r
.32454 .47171 m
.32146 .46837 L
s
1 .001 0 r
.81686 .44457 m
.81686 .44453 L
s
1 .27 0 r
.26775 .58222 m
.26488 .57975 L
s
.26488 .57975 m
.26757 .5773 L
s
.27095 .57972 m
.26775 .58222 L
s
.26757 .5773 m
.27095 .57972 L
s
1 .001 0 r
.81686 .44453 m
.81687 .44454 L
s
.81685 .44454 m
.81686 .44453 L
s
.81686 .44453 m
.81686 .44453 L
s
.81686 .44455 m
.81685 .44454 L
s
.81685 .44454 m
.81686 .44453 L
s
.81687 .44454 m
.81686 .44455 L
s
.81686 .44453 m
.81687 .44454 L
s
.81686 .44453 m
.81686 .44455 L
s
1 .014 0 r
.54233 .52531 m
.54249 .52543 L
s
.54217 .52546 m
.54233 .52531 L
s
.54233 .52531 m
.5423 .52531 L
s
1 .002 0 r
.59895 .3903 m
.59891 .39021 L
s
1 .014 0 r
.54233 .52557 m
.54217 .52546 L
s
.54217 .52546 m
.5423 .52531 L
s
.54249 .52543 m
.54233 .52557 L
s
.5423 .52531 m
.54249 .52543 L
s
1 .002 0 r
.59892 .39022 m
.59894 .39023 L
s
.5989 .39024 m
.59892 .39022 L
s
.59892 .39022 m
.59891 .39021 L
s
.59892 .39025 m
.5989 .39024 L
s
.5989 .39024 m
.59891 .39021 L
s
.59894 .39023 m
.59892 .39025 L
s
.59891 .39021 m
.59894 .39023 L
s
.59891 .39021 m
.59892 .39025 L
s
1 .014 0 r
.5423 .52531 m
.54233 .52557 L
s
1 .051 0 r
.38335 .49752 m
.38387 .49788 L
s
.38279 .49807 m
.38335 .49752 L
s
.38335 .49752 m
.38308 .49752 L
s
1 .659 0 r
.20823 .57929 m
.1846 .55126 L
s
1 .006 0 r
.70068 .55216 m
.70068 .5519 L
s
1 .051 0 r
.38332 .49843 m
.38279 .49807 L
s
.38279 .49807 m
.38308 .49752 L
s
1 0 0 r
.65548 .25457 m
.65548 .25457 L
s
.65548 .25457 m
.65548 .25457 L
s
.65548 .25457 m
.65548 .25457 L
s
.65548 .25457 m
.65548 .25457 L
s
.65548 .25457 m
.65548 .25457 L
s
.65548 .25457 m
.65548 .25457 L
s
.65548 .25457 m
.65548 .25457 L
s
.65548 .25457 m
.65548 .25457 L
s
.65548 .25457 m
.65548 .25457 L
s
0 .214 1 r
.23736 .22877 m
.27678 .26896 L
s
.19241 .25275 m
.23736 .22877 L
s
.23736 .22877 m
.24725 .22208 L
s
1 .006 0 r
.70068 .5519 m
.70074 .55195 L
s
.70061 .55195 m
.70068 .5519 L
s
.70068 .5519 m
.70068 .5519 L
s
1 .051 0 r
.38387 .49788 m
.38332 .49843 L
s
.38308 .49752 m
.38387 .49788 L
s
1 .019 0 r
.4827 .49788 m
.48238 .497 L
s
1 .006 0 r
.70068 .552 m
.70061 .55195 L
s
.70061 .55195 m
.70068 .5519 L
s
.70074 .55195 m
.70068 .552 L
s
.70068 .5519 m
.70074 .55195 L
s
.70068 .5519 m
.70068 .552 L
s
1 .648 0 r
.1933 .51579 m
.19933 .5201 L
s
.18626 .52324 m
.1933 .51579 L
s
.1933 .51579 m
.18815 .51606 L
s
1 .051 0 r
.38308 .49752 m
.38332 .49843 L
s
1 .455 0 r
.23731 .59945 m
.24203 .6045 L
s
.23196 .60285 m
.23731 .59945 L
s
.23731 .59945 m
.23847 .59978 L
s
1 .001 0 r
.75725 .41644 m
.75724 .4164 L
s
.75724 .4164 m
.75725 .4164 L
s
.75723 .41641 m
.75724 .4164 L
s
.75724 .4164 m
.75724 .4164 L
s
.75724 .41641 m
.75723 .41641 L
s
.75723 .41641 m
.75724 .4164 L
s
.75725 .4164 m
.75724 .41641 L
s
.75724 .4164 m
.75725 .4164 L
s
.75724 .4164 m
.75724 .41641 L
s
1 .002 0 r
.53922 .36214 m
.53917 .36206 L
s
.53918 .36206 m
.5392 .36207 L
s
.53916 .36208 m
.53918 .36206 L
s
.53918 .36206 m
.53917 .36206 L
s
.53918 .36209 m
.53916 .36208 L
s
.53916 .36208 m
.53917 .36206 L
s
.5392 .36207 m
.53918 .36209 L
s
.53917 .36206 m
.5392 .36207 L
s
.53917 .36206 m
.53918 .36209 L
s
1 .27 0 r
.26757 .5773 m
.26775 .58222 L
s
1 .099 0 r
.36639 .60551 m
.36588 .6011 L
s
1 .019 0 r
.48244 .497 m
.48265 .49715 L
s
.48223 .4972 m
.48244 .497 L
s
.48244 .497 m
.48238 .497 L
s
1 .155 0 r
.28136 .49508 m
.28279 .49603 L
s
.27975 .49694 m
.28136 .49508 L
s
.28136 .49508 m
.28004 .49517 L
s
1 .003 0 r
.85905 .57837 m
.85907 .57824 L
s
1 .019 0 r
.48244 .49735 m
.48223 .4972 L
s
.48223 .4972 m
.48238 .497 L
s
.48265 .49715 m
.48244 .49735 L
s
.48238 .497 m
.48265 .49715 L
s
1 .003 0 r
.85906 .57824 m
.8591 .57826 L
s
.85903 .57826 m
.85906 .57824 L
s
.85906 .57824 m
.85907 .57824 L
s
.85907 .57829 m
.85903 .57826 L
s
.85903 .57826 m
.85907 .57824 L
s
.8591 .57826 m
.85907 .57829 L
s
.85907 .57824 m
.8591 .57826 L
s
.85907 .57824 m
.85907 .57829 L
s
1 .019 0 r
.48238 .497 m
.48244 .49735 L
s
1 .007 0 r
.641 .52407 m
.64095 .52375 L
s
1 .155 0 r
.28118 .49789 m
.27975 .49694 L
s
.27975 .49694 m
.28004 .49517 L
s
1 0 0 r
.59577 .22633 m
.59577 .22633 L
s
.59577 .22633 m
.59577 .22633 L
s
.59577 .22633 m
.59577 .22633 L
s
.59577 .22633 m
.59577 .22633 L
s
.59577 .22633 m
.59577 .22633 L
s
.59577 .22633 m
.59577 .22633 L
s
.59577 .22633 m
.59577 .22633 L
s
.59577 .22633 m
.59577 .22633 L
s
.59577 .22633 m
.59577 .22633 L
s
1 .026 0 r
.4229 .46976 m
.4222 .46856 L
s
1 .007 0 r
.64096 .52376 m
.64104 .52381 L
s
.64089 .52382 m
.64096 .52376 L
s
.64096 .52376 m
.64095 .52375 L
s
.64096 .52388 m
.64089 .52382 L
s
.64089 .52382 m
.64095 .52375 L
s
.64104 .52381 m
.64096 .52388 L
s
.64095 .52375 m
.64104 .52381 L
s
.64095 .52375 m
.64096 .52388 L
s
1 .001 0 r
.69758 .38828 m
.69756 .38824 L
s
.69756 .38824 m
.69757 .38824 L
s
.69755 .38825 m
.69756 .38824 L
s
.69756 .38824 m
.69756 .38824 L
s
.69756 .38825 m
.69755 .38825 L
s
.69755 .38825 m
.69756 .38824 L
s
1 .078 0 r
.32211 .46834 m
.32284 .4688 L
s
.32131 .46928 m
.32211 .46834 L
s
.32211 .46834 m
.32146 .46837 L
s
1 .001 0 r
.69757 .38824 m
.69756 .38825 L
s
.69756 .38824 m
.69757 .38824 L
s
.69756 .38824 m
.69756 .38825 L
s
1 .078 0 r
.32204 .46974 m
.32131 .46928 L
s
.32131 .46928 m
.32146 .46837 L
s
1 .002 0 r
.47943 .33394 m
.47938 .33387 L
s
.47939 .33387 m
.4794 .33388 L
s
.47937 .33389 m
.47939 .33387 L
s
.47939 .33387 m
.47938 .33387 L
s
.47939 .3339 m
.47937 .33389 L
s
.47937 .33389 m
.47938 .33387 L
s
.4794 .33388 m
.47939 .3339 L
s
.47938 .33387 m
.4794 .33388 L
s
.47938 .33387 m
.47939 .3339 L
s
1 .168 0 r
.30652 .57744 m
.30372 .56991 L
s
1 .455 0 r
.24203 .6045 m
.23668 .6079 L
s
.23847 .59978 m
.24203 .6045 L
s
1 .648 0 r
.19228 .52758 m
.18626 .52324 L
s
.18626 .52324 m
.18815 .51606 L
s
1 .003 0 r
.79942 .55028 m
.79942 .55014 L
s
.79942 .55013 m
.79946 .55016 L
s
.79939 .55017 m
.79942 .55013 L
s
.79942 .55013 m
.79942 .55014 L
s
1 0 0 r
.75418 .25243 m
.75418 .25243 L
s
.75418 .25243 m
.75418 .25243 L
s
.75418 .25243 m
.75418 .25243 L
s
.75418 .25243 m
.75418 .25243 L
s
.75418 .25243 m
.75418 .25243 L
s
.75418 .25243 m
.75418 .25243 L
s
.75418 .25243 m
.75418 .25243 L
s
.75418 .25243 m
.75418 .25243 L
s
.75418 .25243 m
.75418 .25243 L
s
1 .155 0 r
.28279 .49603 m
.28118 .49789 L
s
.28004 .49517 m
.28279 .49603 L
s
1 .003 0 r
.79943 .55019 m
.79939 .55017 L
s
.79939 .55017 m
.79942 .55014 L
s
.79946 .55016 m
.79943 .55019 L
s
.79942 .55014 m
.79946 .55016 L
s
.79942 .55014 m
.79943 .55019 L
s
1 .026 0 r
.42235 .46857 m
.42262 .46875 L
s
.42206 .46886 m
.42235 .46857 L
s
.42235 .46857 m
.4222 .46856 L
s
1 .008 0 r
.58125 .49595 m
.58115 .49557 L
s
1 .301 0 r
.23878 .51881 m
.24153 .52072 L
s
.23562 .52238 m
.23878 .51881 L
s
.23878 .51881 m
.23624 .51901 L
s
1 .026 0 r
.42233 .46904 m
.42206 .46886 L
s
.42206 .46886 m
.4222 .46856 L
s
1 .078 0 r
.32284 .4688 m
.32204 .46974 L
s
.32146 .46837 m
.32284 .4688 L
s
1 .026 0 r
.42262 .46875 m
.42233 .46904 L
s
.4222 .46856 m
.42262 .46875 L
s
1 .037 0 r
.36304 .44161 m
.36158 .44001 L
s
1 .026 0 r
.4222 .46856 m
.42233 .46904 L
s
1 .078 0 r
.32146 .46837 m
.32204 .46974 L
s
1 .155 0 r
.28004 .49517 m
.28118 .49789 L
s
1 .008 0 r
.58117 .49557 m
.58126 .49563 L
s
.58108 .49565 m
.58117 .49557 L
s
.58117 .49557 m
.58115 .49557 L
s
.58117 .49572 m
.58108 .49565 L
s
.58108 .49565 m
.58115 .49557 L
s
.58126 .49563 m
.58117 .49572 L
s
.58115 .49557 m
.58126 .49563 L
s
.58115 .49557 m
.58117 .49572 L
s
1 .001 0 r
.63784 .36009 m
.63783 .36005 L
s
.63783 .36005 m
.63784 .36006 L
s
.63782 .36006 m
.63783 .36005 L
s
.63783 .36005 m
.63783 .36005 L
s
.63783 .36006 m
.63782 .36006 L
s
.63782 .36006 m
.63783 .36005 L
s
.63784 .36006 m
.63783 .36006 L
s
.63783 .36005 m
.63784 .36006 L
s
.63783 .36005 m
.63783 .36006 L
s
1 .042 0 r
.46486 .60368 m
.46472 .6018 L
s
1 .301 0 r
.23837 .52428 m
.23562 .52238 L
s
.23562 .52238 m
.23624 .51901 L
s
1 .31 0 r
.24658 .54934 m
.23453 .53636 L
s
1 .004 0 r
.73973 .52216 m
.73972 .522 L
s
1 0 0 r
.69446 .22416 m
.69446 .22416 L
s
.69446 .22416 m
.69446 .22416 L
s
.69446 .22416 m
.69446 .22416 L
s
.69446 .22416 m
.69446 .22416 L
s
.69446 .22416 m
.69446 .22416 L
s
.69446 .22416 m
.69446 .22416 L
s
.69446 .22416 m
.69446 .22416 L
s
.69446 .22416 m
.69446 .22416 L
s
.69446 .22416 m
.69446 .22416 L
s
1 .004 0 r
.73972 .522 m
.73976 .52203 L
s
.73968 .52204 m
.73972 .522 L
s
.73972 .522 m
.73972 .522 L
s
.73972 .52207 m
.73968 .52204 L
s
.73968 .52204 m
.73972 .522 L
s
.73976 .52203 m
.73972 .52207 L
s
.73972 .522 m
.73976 .52203 L
s
.73972 .522 m
.73972 .52207 L
s
1 .01 0 r
.52144 .46781 m
.52125 .46733 L
s
1 .037 0 r
.36189 .44 m
.36224 .44021 L
s
.36151 .44044 m
.36189 .44 L
s
.36189 .44 m
.36158 .44001 L
s
.36186 .44066 m
.36151 .44044 L
s
.36151 .44044 m
.36158 .44001 L
s
0 .558 1 r
.22925 .28752 m
.19357 .25084 L
s
.19357 .25084 m
.24285 .22326 L
s
1 0 0 r
.79638 .38625 m
.79638 .38623 L
s
.79638 .38623 m
.79638 .38623 L
s
.79637 .38623 m
.79638 .38623 L
s
.79638 .38623 m
.79638 .38623 L
s
.79638 .38624 m
.79637 .38623 L
s
.79637 .38623 m
.79638 .38623 L
s
.79638 .38623 m
.79638 .38624 L
s
.79638 .38623 m
.79638 .38623 L
s
.79638 .38623 m
.79638 .38624 L
s
1 .01 0 r
.52129 .46733 m
.5214 .46741 L
s
.52117 .46744 m
.52129 .46733 L
s
.52129 .46733 m
.52125 .46733 L
s
.52128 .46752 m
.52117 .46744 L
s
.52117 .46744 m
.52125 .46733 L
s
1 .455 0 r
.23668 .6079 m
.23196 .60285 L
s
.23196 .60285 m
.23847 .59978 L
s
1 .01 0 r
.5214 .46741 m
.52128 .46752 L
s
.52125 .46733 m
.5214 .46741 L
s
.52125 .46733 m
.52128 .46752 L
s
1 .001 0 r
.57805 .33187 m
.57803 .33184 L
s
1 .037 0 r
.36224 .44021 m
.36186 .44066 L
s
.36158 .44001 m
.36224 .44021 L
s
1 .001 0 r
.57803 .33184 m
.57804 .33184 L
s
.57803 .33185 m
.57803 .33184 L
s
.57803 .33184 m
.57803 .33184 L
s
.57803 .33185 m
.57803 .33185 L
s
.57803 .33185 m
.57803 .33184 L
s
.57804 .33184 m
.57803 .33185 L
s
.57803 .33184 m
.57804 .33184 L
s
.57803 .33184 m
.57803 .33185 L
s
1 .037 0 r
.36158 .44001 m
.36186 .44066 L
s
1 .063 0 r
.40498 .57559 m
.40429 .57273 L
s
1 .099 0 r
.36602 .60106 m
.36709 .60197 L
s
.36487 .60199 m
.36602 .60106 L
s
.36602 .60106 m
.36588 .6011 L
s
1 .004 0 r
.67998 .49402 m
.67994 .49383 L
s
1 .042 0 r
.46475 .60179 m
.46522 .60217 L
s
.46427 .60219 m
.46475 .60179 L
s
.46475 .60179 m
.46472 .6018 L
s
1 .004 0 r
.67995 .49383 m
.68 .49387 L
s
.6799 .49387 m
.67995 .49383 L
s
.67995 .49383 m
.67994 .49383 L
s
.67995 .49391 m
.6799 .49387 L
s
.6799 .49387 m
.67994 .49383 L
s
.68 .49387 m
.67995 .49391 L
s
.67994 .49383 m
.68 .49387 L
s
.67994 .49383 m
.67995 .49391 L
s
1 .013 0 r
.46157 .43963 m
.46121 .43903 L
s
1 .042 0 r
.46474 .60257 m
.46427 .60219 L
s
.46427 .60219 m
.46472 .6018 L
s
.46522 .60217 m
.46474 .60257 L
s
.46472 .6018 m
.46522 .60217 L
s
1 .301 0 r
.24153 .52072 m
.23837 .52428 L
s
.23624 .51901 m
.24153 .52072 L
s
1 .099 0 r
.36594 .6029 m
.36487 .60199 L
s
.36487 .60199 m
.36588 .6011 L
s
1 .042 0 r
.46472 .6018 m
.46474 .60257 L
s
1 .099 0 r
.36709 .60197 m
.36594 .6029 L
s
.36588 .6011 m
.36709 .60197 L
s
1 0 0 r
.73664 .35803 m
.73664 .35801 L
s
.73664 .35801 m
.73664 .35802 L
s
.73663 .35802 m
.73664 .35801 L
s
.73664 .35801 m
.73664 .35801 L
s
.73664 .35802 m
.73663 .35802 L
s
.73663 .35802 m
.73664 .35801 L
s
.73664 .35802 m
.73664 .35802 L
s
.73664 .35801 m
.73664 .35802 L
s
.73664 .35801 m
.73664 .35802 L
s
1 .02 0 r
.56351 .60185 m
.56348 .60096 L
s
1 .013 0 r
.46129 .43904 m
.46142 .43912 L
s
.46114 .43918 m
.46129 .43904 L
s
.46129 .43904 m
.46121 .43903 L
s
.46128 .43927 m
.46114 .43918 L
s
.46114 .43918 m
.46121 .43903 L
s
1 0 0 r
.5182 .30362 m
.51818 .3036 L
s
1 .013 0 r
.46142 .43912 m
.46128 .43927 L
s
.46121 .43903 m
.46142 .43912 L
s
1 0 0 r
.51818 .3036 m
.51819 .3036 L
s
.51818 .30361 m
.51818 .3036 L
s
.51818 .3036 m
.51818 .3036 L
s
.51818 .30361 m
.51818 .30361 L
s
.51818 .30361 m
.51818 .3036 L
s
.51819 .3036 m
.51818 .30361 L
s
.51818 .3036 m
.51819 .3036 L
s
.51818 .3036 m
.51818 .30361 L
s
1 .013 0 r
.46121 .43903 m
.46128 .43927 L
s
1 .101 0 r
.34504 .54746 m
.34283 .54295 L
s
1 .002 0 r
.83864 .52026 m
.83864 .52016 L
s
1 .455 0 r
.23847 .59978 m
.23668 .6079 L
s
1 .099 0 r
.36588 .6011 m
.36594 .6029 L
s
1 .002 0 r
.83864 .52016 m
.83866 .52018 L
s
.83862 .52018 m
.83864 .52016 L
s
.83864 .52016 m
.83864 .52016 L
s
.83864 .5202 m
.83862 .52018 L
s
.83862 .52018 m
.83864 .52016 L
s
.83866 .52018 m
.83864 .5202 L
s
.83864 .52016 m
.83866 .52018 L
s
.83864 .52016 m
.83864 .5202 L
s
1 .648 0 r
.19933 .5201 m
.19228 .52758 L
s
.18815 .51606 m
.19933 .5201 L
s
1 .301 0 r
.23624 .51901 m
.23837 .52428 L
s
1 .005 0 r
.62016 .46585 m
.6201 .46563 L
s
.62011 .46563 m
.62016 .46567 L
s
.62006 .46568 m
.62011 .46563 L
s
.62011 .46563 m
.6201 .46563 L
s
1 .02 0 r
.56348 .60096 m
.56371 .60114 L
s
.56326 .60114 m
.56348 .60096 L
s
.56348 .60096 m
.56348 .60096 L
s
1 .005 0 r
.62011 .46572 m
.62006 .46568 L
s
.62006 .46568 m
.6201 .46563 L
s
.62016 .46567 m
.62011 .46572 L
s
.6201 .46563 m
.62016 .46567 L
s
1 .017 0 r
.40165 .41143 m
.401 .4107 L
s
1 .005 0 r
.6201 .46563 m
.62011 .46572 L
s
1 .02 0 r
.56349 .60133 m
.56326 .60114 L
s
.56326 .60114 m
.56348 .60096 L
s
.56371 .60114 m
.56349 .60133 L
s
.56348 .60096 m
.56371 .60114 L
s
.56348 .60096 m
.56349 .60133 L
s
1 0 0 r
.67685 .32979 m
.67684 .32977 L
s
.67684 .32977 m
.67684 .32978 L
s
.67684 .32978 m
.67684 .32977 L
s
.67684 .32977 m
.67684 .32977 L
s
.67684 .32978 m
.67684 .32978 L
s
.67684 .32978 m
.67684 .32977 L
s
.67684 .32978 m
.67684 .32978 L
s
.67684 .32977 m
.67684 .32978 L
s
.67684 .32977 m
.67684 .32978 L
s
1 .027 0 r
.50362 .57373 m
.50343 .5725 L
s
1 .017 0 r
.40114 .4107 m
.4013 .4108 L
s
.40097 .4109 m
.40114 .4107 L
s
.40114 .4107 m
.401 .4107 L
s
1 .063 0 r
.40445 .57272 m
.40514 .57326 L
s
.40372 .57335 m
.40445 .57272 L
s
.40445 .57272 m
.40429 .57273 L
s
1 .017 0 r
.40113 .411 m
.40097 .4109 L
s
.40097 .4109 m
.401 .4107 L
s
1 .167 0 r
.28503 .5193 m
.27844 .5123 L
s
1 .017 0 r
.4013 .4108 m
.40113 .411 L
s
.401 .4107 m
.4013 .4108 L
s
.401 .4107 m
.40113 .411 L
s
1 .002 0 r
.77888 .49209 m
.77887 .49199 L
s
.77887 .49199 m
.7789 .49201 L
s
.77885 .49201 m
.77887 .49199 L
s
.77887 .49199 m
.77887 .49199 L
s
.77888 .49203 m
.77885 .49201 L
s
.77885 .49201 m
.77887 .49199 L
s
.7789 .49201 m
.77888 .49203 L
s
.77887 .49199 m
.7789 .49201 L
s
.77887 .49199 m
.77888 .49203 L
s
1 .063 0 r
.40441 .57389 m
.40372 .57335 L
s
.40372 .57335 m
.40429 .57273 L
s
.40514 .57326 m
.40441 .57389 L
s
.40429 .57273 m
.40514 .57326 L
s
1 .005 0 r
.56029 .43765 m
.56018 .4374 L
s
.5602 .4374 m
.56026 .43744 L
s
.56014 .43746 m
.5602 .4374 L
s
.5602 .4374 m
.56018 .4374 L
s
.5602 .4375 m
.56014 .43746 L
s
.56014 .43746 m
.56018 .4374 L
s
.56026 .43744 m
.5602 .4375 L
s
.56018 .4374 m
.56026 .43744 L
s
.56018 .4374 m
.5602 .4375 L
s
1 .063 0 r
.40429 .57273 m
.40441 .57389 L
s
1 .01 0 r
.66233 .60002 m
.66234 .59956 L
s
1 .027 0 r
.50347 .57249 m
.50377 .57273 L
s
.50316 .57276 m
.50347 .57249 L
s
.50347 .57249 m
.50343 .5725 L
s
1 0 0 r
.61699 .30151 m
.61698 .3015 L
s
.61698 .3015 m
.61699 .30151 L
s
.61698 .30151 m
.61698 .3015 L
s
.61698 .3015 m
.61698 .3015 L
s
.61698 .30151 m
.61698 .30151 L
s
.61698 .30151 m
.61698 .3015 L
s
.61699 .30151 m
.61698 .30151 L
s
.61698 .3015 m
.61699 .30151 L
s
.61698 .3015 m
.61698 .30151 L
s
1 .648 0 r
.18815 .51606 m
.19228 .52758 L
s
1 .027 0 r
.50346 .57299 m
.50316 .57276 L
s
.50316 .57276 m
.50343 .5725 L
s
.50377 .57273 m
.50346 .57299 L
s
.50343 .5725 m
.50377 .57273 L
s
1 .039 0 r
.44367 .54557 m
.44311 .54381 L
s
1 .027 0 r
.50343 .5725 m
.50346 .57299 L
s
1 .01 0 r
.66234 .59955 m
.66246 .59965 L
s
.66222 .59965 m
.66234 .59955 L
s
.66234 .59955 m
.66234 .59956 L
s
.66234 .59974 m
.66222 .59965 L
s
.66222 .59965 m
.66234 .59956 L
s
.66246 .59965 m
.66234 .59974 L
s
.66234 .59956 m
.66246 .59965 L
s
.66234 .59956 m
.66234 .59974 L
s
1 .002 0 r
.71906 .46389 m
.71904 .46378 L
s
.71905 .46378 m
.71907 .4638 L
s
.71902 .46381 m
.71905 .46378 L
s
.71905 .46378 m
.71904 .46378 L
s
.71905 .46382 m
.71902 .46381 L
s
.71902 .46381 m
.71904 .46378 L
s
.71907 .4638 m
.71905 .46382 L
s
.71904 .46378 m
.71907 .4638 L
s
.71904 .46378 m
.71905 .46382 L
s
1 .006 0 r
.50036 .40942 m
.50018 .40914 L
s
1 .168 0 r
.30437 .56987 m
.30614 .57126 L
s
.30242 .57158 m
.30437 .56987 L
s
.30437 .56987 m
.30372 .56991 L
s
1 .006 0 r
.50022 .40914 m
.50028 .40918 L
s
.50015 .40921 m
.50022 .40914 L
s
.50022 .40914 m
.50018 .40914 L
s
.50022 .40925 m
.50015 .40921 L
s
.50015 .40921 m
.50018 .40914 L
s
.50028 .40918 m
.50022 .40925 L
s
.50018 .40914 m
.50028 .40918 L
s
.50018 .40914 m
.50022 .40925 L
s
1 0 0 r
.77582 .3277 m
.77582 .3277 L
s
.77582 .3277 m
.77582 .3277 L
s
.77582 .3277 m
.77582 .3277 L
s
.77582 .3277 m
.77582 .3277 L
s
.77582 .3277 m
.77582 .3277 L
s
.77582 .3277 m
.77582 .3277 L
s
.77582 .3277 m
.77582 .3277 L
s
.77582 .3277 m
.77582 .3277 L
s
.77582 .3277 m
.77582 .3277 L
s
1 .013 0 r
.60244 .57187 m
.60239 .57128 L
s
1 0 0 r
.55707 .27321 m
.55707 .27321 L
s
.55707 .27321 m
.55707 .27321 L
s
.55707 .27321 m
.55707 .27321 L
s
.55707 .27321 m
.55707 .27321 L
s
.55707 .27321 m
.55707 .27321 L
s
.55707 .27321 m
.55707 .27321 L
s
.55707 .27321 m
.55707 .27321 L
s
.55707 .27321 m
.55707 .27321 L
s
.55707 .27321 m
.55707 .27321 L
s
1 .058 0 r
.38367 .51739 m
.38222 .51479 L
s
1 .276 0 r
.26686 .59489 m
.26981 .59745 L
s
.26356 .59747 m
.26686 .59489 L
s
.26686 .59489 m
.26633 .59498 L
s
1 .168 0 r
.30419 .57297 m
.30242 .57158 L
s
.30242 .57158 m
.30372 .56991 L
s
1 .039 0 r
.44323 .54381 m
.44365 .54412 L
s
.44279 .5442 m
.44323 .54381 L
s
.44323 .54381 m
.44311 .54381 L
s
1 .101 0 r
.34332 .54293 m
.34437 .54371 L
s
.34218 .54401 m
.34332 .54293 L
s
.34332 .54293 m
.34283 .54295 L
s
1 .013 0 r
.6024 .57127 m
.60255 .57139 L
s
.60225 .5714 m
.6024 .57127 L
s
.6024 .57127 m
.60239 .57128 L
s
.6024 .57151 m
.60225 .5714 L
s
.60225 .5714 m
.60239 .57128 L
s
1 .003 0 r
.65919 .43567 m
.65915 .43555 L
s
1 .013 0 r
.60255 .57139 m
.6024 .57151 L
s
.60239 .57128 m
.60255 .57139 L
s
1 .039 0 r
.44321 .54452 m
.44279 .5442 L
s
.44279 .5442 m
.44311 .54381 L
s
1 .013 0 r
.60239 .57128 m
.6024 .57151 L
s
1 .003 0 r
.65916 .43555 m
.65919 .43557 L
s
.65913 .43557 m
.65916 .43555 L
s
.65916 .43555 m
.65915 .43555 L
s
.65916 .43559 m
.65913 .43557 L
s
.65913 .43557 m
.65915 .43555 L
s
.65919 .43557 m
.65916 .43559 L
s
.65915 .43555 m
.65919 .43557 L
s
.65915 .43555 m
.65916 .43559 L
s
1 .039 0 r
.44365 .54412 m
.44321 .54452 L
s
.44311 .54381 m
.44365 .54412 L
s
1 .168 0 r
.30614 .57126 m
.30419 .57297 L
s
.30372 .56991 m
.30614 .57126 L
s
1 .007 0 r
.44037 .38117 m
.4401 .38086 L
s
1 .101 0 r
.34323 .54478 m
.34218 .54401 L
s
.34218 .54401 m
.34283 .54295 L
s
1 .039 0 r
.44311 .54381 m
.44321 .54452 L
s
1 .006 0 r
.76134 .59818 m
.76136 .59792 L
s
1 .007 0 r
.44015 .38086 m
.44022 .3809 L
s
.44008 .38094 m
.44015 .38086 L
s
.44015 .38086 m
.4401 .38086 L
s
.44015 .38098 m
.44008 .38094 L
s
.44008 .38094 m
.4401 .38086 L
s
.44022 .3809 m
.44015 .38098 L
s
.4401 .38086 m
.44022 .3809 L
s
.4401 .38086 m
.44015 .38098 L
s
1 0 0 r
.71596 .2994 m
.71596 .2994 L
s
.71596 .2994 m
.71596 .2994 L
s
.71596 .2994 m
.71596 .2994 L
s
.71596 .2994 m
.71596 .2994 L
s
.71596 .2994 m
.71596 .2994 L
s
.71596 .2994 m
.71596 .2994 L
s
.71596 .2994 m
.71596 .2994 L
s
.71596 .2994 m
.71596 .2994 L
s
.71596 .2994 m
.71596 .2994 L
s
1 .101 0 r
.34437 .54371 m
.34323 .54478 L
s
.34283 .54295 m
.34437 .54371 L
s
1 .006 0 r
.76135 .59792 m
.76142 .59797 L
s
.76129 .59797 m
.76135 .59792 L
s
.76135 .59792 m
.76136 .59792 L
s
1 .017 0 r
.54249 .54369 m
.54232 .54291 L
s
1 .006 0 r
.76136 .59803 m
.76129 .59797 L
s
.76129 .59797 m
.76136 .59792 L
s
.76142 .59797 m
.76136 .59803 L
s
.76136 .59792 m
.76142 .59797 L
s
.76136 .59792 m
.76136 .59803 L
s
1 .089 0 r
.3236 .48918 m
.32007 .4854 L
s
1 .168 0 r
.30372 .56991 m
.30419 .57297 L
s
1 .001 0 r
.81815 .46193 m
.81814 .46187 L
s
1 .101 0 r
.34283 .54295 m
.34323 .54478 L
s
1 .001 0 r
.81814 .46187 m
.81816 .46188 L
s
.81813 .46188 m
.81814 .46187 L
s
.81814 .46187 m
.81814 .46187 L
s
.81814 .46189 m
.81813 .46188 L
s
.81813 .46188 m
.81814 .46187 L
s
.81816 .46188 m
.81814 .46189 L
s
.81814 .46187 m
.81816 .46188 L
s
.81814 .46187 m
.81814 .46189 L
s
1 .003 0 r
.59925 .40741 m
.59919 .40728 L
s
1 .276 0 r
.26651 .60003 m
.26356 .59747 L
s
.26356 .59747 m
.26633 .59498 L
s
1 .017 0 r
.54235 .54291 m
.54255 .54305 L
s
.54217 .54308 m
.54235 .54291 L
s
.54235 .54291 m
.54232 .54291 L
s
1 .276 0 r
.26981 .59745 m
.26651 .60003 L
s
.26633 .59498 m
.26981 .59745 L
s
1 .003 0 r
.5992 .40729 m
.59923 .4073 L
s
.59917 .40731 m
.5992 .40729 L
s
.5992 .40729 m
.59919 .40728 L
s
.5992 .40733 m
.59917 .40731 L
s
.59917 .40731 m
.59919 .40728 L
s
.59923 .4073 m
.5992 .40733 L
s
.59919 .40728 m
.59923 .4073 L
s
.59919 .40728 m
.5992 .40733 L
s
1 .017 0 r
.54236 .54322 m
.54217 .54308 L
s
.54217 .54308 m
.54232 .54291 L
s
.54255 .54305 m
.54236 .54322 L
s
.54232 .54291 m
.54255 .54305 L
s
.54232 .54291 m
.54236 .54322 L
s
1 .663 0 r
.20677 .59726 m
.18286 .56917 L
s
1 .007 0 r
.70144 .57 m
.70144 .56969 L
s
1 .058 0 r
.38253 .51478 m
.38313 .51521 L
s
.38189 .51542 m
.38253 .51478 L
s
.38253 .51478 m
.38222 .51479 L
s
1 0 0 r
.65604 .27107 m
.65603 .27107 L
s
.65603 .27107 m
.65604 .27107 L
s
.65603 .27107 m
.65603 .27107 L
s
.65603 .27107 m
.65603 .27107 L
s
.65603 .27107 m
.65603 .27107 L
s
.65603 .27107 m
.65603 .27107 L
s
.65604 .27107 m
.65603 .27107 L
s
.65603 .27107 m
.65604 .27107 L
s
.65603 .27107 m
.65603 .27107 L
s
1 .023 0 r
.48248 .51548 m
.48208 .51443 L
s
1 .007 0 r
.70143 .56969 m
.70151 .56975 L
s
.70136 .56976 m
.70143 .56969 L
s
.70143 .56969 m
.70144 .56969 L
s
.70144 .56982 m
.70136 .56976 L
s
.70136 .56976 m
.70144 .56969 L
s
1 .058 0 r
.38249 .51584 m
.38189 .51542 L
s
.38189 .51542 m
.38222 .51479 L
s
1 .007 0 r
.70151 .56975 m
.70144 .56982 L
s
.70144 .56969 m
.70151 .56975 L
s
.70144 .56969 m
.70144 .56982 L
s
1 .058 0 r
.38313 .51521 m
.38249 .51584 L
s
.38222 .51479 m
.38313 .51521 L
s
1 .001 0 r
.75826 .43368 m
.75825 .43361 L
s
1 .654 0 r
.1916 .5332 m
.19771 .53762 L
s
.18445 .54077 m
.1916 .5332 L
s
.1916 .5332 m
.18636 .53355 L
s
1 .001 0 r
.75825 .43361 m
.75827 .43362 L
s
.75824 .43363 m
.75825 .43361 L
s
.75825 .43361 m
.75825 .43361 L
s
.75825 .43364 m
.75824 .43363 L
s
.75824 .43363 m
.75825 .43361 L
s
.75827 .43362 m
.75825 .43364 L
s
.75825 .43361 m
.75827 .43362 L
s
.75825 .43361 m
.75825 .43364 L
s
1 .058 0 r
.38222 .51479 m
.38249 .51584 L
s
1 .003 0 r
.53925 .37913 m
.53917 .379 L
s
.53919 .379 m
.53922 .37902 L
s
.53916 .37903 m
.53919 .379 L
s
.53919 .379 m
.53917 .379 L
s
.53919 .37905 m
.53916 .37903 L
s
.53916 .37903 m
.53917 .379 L
s
.53922 .37902 m
.53919 .37905 L
s
.53917 .379 m
.53922 .37902 L
s
.53917 .379 m
.53919 .37905 L
s
.86053 .59634 m
.86055 .59618 L
s
1 .023 0 r
.48216 .51443 m
.48241 .51461 L
s
.48191 .51467 m
.48216 .51443 L
s
.48216 .51443 m
.48208 .51443 L
s
1 .003 0 r
.86054 .59618 m
.86058 .59621 L
s
.8605 .59622 m
.86054 .59618 L
s
.86054 .59618 m
.86055 .59618 L
s
.86055 .59625 m
.8605 .59622 L
s
.8605 .59622 m
.86055 .59618 L
s
.86058 .59621 m
.86055 .59625 L
s
.86055 .59618 m
.86058 .59621 L
s
1 .023 0 r
.48216 .51485 m
.48191 .51467 L
s
.48191 .51467 m
.48208 .51443 L
s
1 .003 0 r
.86055 .59618 m
.86055 .59625 L
s
1 .276 0 r
.26633 .59498 m
.26651 .60003 L
s
1 .008 0 r
.64149 .54179 m
.64144 .54142 L
s
1 .023 0 r
.48241 .51461 m
.48216 .51485 L
s
.48208 .51443 m
.48241 .51461 L
s
.48208 .51443 m
.48216 .51485 L
s
1 .167 0 r
.27986 .51218 m
.2814 .51321 L
s
.27813 .51419 m
.27986 .51218 L
s
.27986 .51218 m
.27844 .5123 L
s
1 0 0 r
.59605 .24272 m
.59605 .24272 L
s
.59605 .24272 m
.59605 .24272 L
s
.59605 .24272 m
.59605 .24272 L
s
.59605 .24272 m
.59605 .24272 L
s
.59605 .24272 m
.59605 .24272 L
s
.59605 .24272 m
.59605 .24272 L
s
.59605 .24272 m
.59605 .24272 L
s
.59605 .24272 m
.59605 .24272 L
s
.59605 .24272 m
.59605 .24272 L
s
1 .032 0 r
.4224 .48724 m
.42155 .4858 L
s
1 .008 0 r
.64144 .54142 m
.64154 .54149 L
s
.64135 .5415 m
.64144 .54142 L
s
.64144 .54142 m
.64144 .54142 L
s
.64145 .54157 m
.64135 .5415 L
s
.64135 .5415 m
.64144 .54142 L
s
.64154 .54149 m
.64145 .54157 L
s
.64144 .54142 m
.64154 .54149 L
s
.64144 .54142 m
.64145 .54157 L
s
1 .167 0 r
.27967 .51522 m
.27813 .51419 L
s
.27813 .51419 m
.27844 .5123 L
s
1 .001 0 r
.69832 .4054 m
.6983 .40533 L
s
.6983 .40533 m
.69832 .40534 L
s
.69829 .40535 m
.6983 .40533 L
s
.6983 .40533 m
.6983 .40533 L
s
.69831 .40536 m
.69829 .40535 L
s
.69829 .40535 m
.6983 .40533 L
s
.69832 .40534 m
.69831 .40536 L
s
.6983 .40533 m
.69832 .40534 L
s
.6983 .40533 m
.69831 .40536 L
s
1 .003 0 r
.47919 .35082 m
.47909 .35069 L
s
.47911 .35069 m
.47914 .35071 L
s
.47908 .35073 m
.47911 .35069 L
s
.47911 .35069 m
.47909 .35069 L
s
.47911 .35074 m
.47908 .35073 L
s
.47908 .35073 m
.47909 .35069 L
s
1 .175 0 r
.30549 .59541 m
.30256 .58759 L
s
1 .003 0 r
.47914 .35071 m
.47911 .35074 L
s
.47909 .35069 m
.47914 .35071 L
s
.47909 .35069 m
.47911 .35074 L
s
1 .089 0 r
.32082 .48535 m
.32166 .48589 L
s
.3199 .48643 m
.32082 .48535 L
s
.32082 .48535 m
.32007 .4854 L
s
1 .004 0 r
.80063 .56813 m
.80063 .56796 L
s
0 .214 1 r
.27678 .26896 m
.23208 .29356 L
s
.24725 .22208 m
.27678 .26896 L
s
1 0 0 r
.75518 .26893 m
.75518 .26893 L
s
.75518 .26893 m
.75518 .26893 L
s
.75518 .26893 m
.75518 .26893 L
s
.75518 .26893 m
.75518 .26893 L
s
.75518 .26893 m
.75518 .26893 L
s
.75518 .26893 m
.75518 .26893 L
s
.75518 .26893 m
.75518 .26893 L
s
.75518 .26893 m
.75518 .26893 L
s
.75518 .26893 m
.75518 .26893 L
s
1 .004 0 r
.80063 .56796 m
.80068 .56799 L
s
.80059 .56799 m
.80063 .56796 L
s
.80063 .56796 m
.80063 .56796 L
s
1 .089 0 r
.32074 .48697 m
.3199 .48643 L
s
.3199 .48643 m
.32007 .4854 L
s
1 .004 0 r
.80063 .56803 m
.80059 .56799 L
s
.80059 .56799 m
.80063 .56796 L
s
.80068 .56799 m
.80063 .56803 L
s
.80063 .56796 m
.80068 .56799 L
s
.80063 .56796 m
.80063 .56803 L
s
1 .654 0 r
.19055 .54521 m
.18445 .54077 L
s
.18445 .54077 m
.18636 .53355 L
s
1 .01 0 r
.58147 .51356 m
.58135 .51309 L
s
1 .032 0 r
.42173 .4858 m
.42206 .48602 L
s
.42138 .48615 m
.42173 .4858 L
s
.42173 .4858 m
.42155 .4858 L
s
1 .046 0 r
.36227 .45898 m
.36048 .45702 L
s
1 .032 0 r
.42171 .48638 m
.42138 .48615 L
s
.42138 .48615 m
.42155 .4858 L
s
1 .31 0 r
.23717 .53613 m
.24002 .53812 L
s
.23389 .53983 m
.23717 .53613 L
s
.23717 .53613 m
.23453 .53636 L
s
1 .01 0 r
.58137 .51309 m
.58149 .51317 L
s
.58126 .51319 m
.58137 .51309 L
s
.58137 .51309 m
.58135 .51309 L
s
1 .032 0 r
.42206 .48602 m
.42171 .48638 L
s
.42155 .4858 m
.42206 .48602 L
s
1 .167 0 r
.2814 .51321 m
.27967 .51522 L
s
.27844 .5123 m
.2814 .51321 L
s
1 .01 0 r
.58137 .51327 m
.58126 .51319 L
s
.58126 .51319 m
.58135 .51309 L
s
.58149 .51317 m
.58137 .51327 L
s
.58135 .51309 m
.58149 .51317 L
s
.58135 .51309 m
.58137 .51327 L
s
1 .032 0 r
.42155 .4858 m
.42171 .48638 L
s
1 .089 0 r
.32166 .48589 m
.32074 .48697 L
s
.32007 .4854 m
.32166 .48589 L
s
1 .001 0 r
.63832 .37709 m
.63829 .37702 L
s
.6383 .37702 m
.63831 .37703 L
s
.63828 .37704 m
.6383 .37702 L
s
.6383 .37702 m
.63829 .37702 L
s
.6383 .37705 m
.63828 .37704 L
s
.63828 .37704 m
.63829 .37702 L
s
.63831 .37703 m
.6383 .37705 L
s
.63829 .37702 m
.63831 .37703 L
s
.63829 .37702 m
.6383 .37705 L
s
1 .089 0 r
.32007 .4854 m
.32074 .48697 L
s
1 .167 0 r
.27844 .5123 m
.27967 .51522 L
s
1 .317 0 r
.24528 .5672 m
.23287 .55396 L
s
1 .004 0 r
.74067 .5399 m
.74065 .5397 L
s
0 .124 1 r
.23726 .24072 m
.27788 .28218 L
s
.19095 .26558 m
.23726 .24072 L
s
.23726 .24072 m
.24745 .23414 L
s
1 .31 0 r
.23674 .54182 m
.23389 .53983 L
s
.23389 .53983 m
.23453 .53636 L
s
1 0 0 r
.69519 .24055 m
.69519 .24055 L
s
.69519 .24055 m
.69519 .24055 L
s
.69519 .24055 m
.69519 .24055 L
s
.69519 .24055 m
.69519 .24055 L
s
.69519 .24055 m
.69519 .24055 L
s
.69519 .24055 m
.69519 .24055 L
s
.69519 .24055 m
.69519 .24055 L
s
.69519 .24055 m
.69519 .24055 L
s
.69519 .24055 m
.69519 .24055 L
s
1 .004 0 r
.74065 .5397 m
.74071 .53973 L
s
.74061 .53974 m
.74065 .5397 L
s
.74065 .5397 m
.74065 .5397 L
s
.74066 .53978 m
.74061 .53974 L
s
.74061 .53974 m
.74065 .5397 L
s
.74071 .53973 m
.74066 .53978 L
s
.74065 .5397 m
.74071 .53973 L
s
.74065 .5397 m
.74066 .53978 L
s
1 .013 0 r
.52139 .4853 m
.52114 .4847 L
s
1 .001 0 r
.79758 .40337 m
.79757 .40334 L
s
.79757 .40334 m
.79758 .40335 L
s
.79756 .40335 m
.79757 .40334 L
s
.79757 .40334 m
.79757 .40334 L
s
.79757 .40335 m
.79756 .40335 L
s
.79756 .40335 m
.79757 .40334 L
s
.79758 .40335 m
.79757 .40335 L
s
.79757 .40334 m
.79758 .40335 L
s
.79757 .40334 m
.79757 .40335 L
s
1 .013 0 r
.52119 .4847 m
.52134 .4848 L
s
.52105 .48484 m
.52119 .4847 L
s
.52119 .4847 m
.52114 .4847 L
s
1 .046 0 r
.36086 .457 m
.36129 .45727 L
s
.36039 .45756 m
.36086 .457 L
s
.36086 .457 m
.36048 .45702 L
s
1 .013 0 r
.52119 .48493 m
.52105 .48484 L
s
.52105 .48484 m
.52114 .4847 L
s
1 .001 0 r
.57826 .34875 m
.57822 .34869 L
s
1 .013 0 r
.52134 .4848 m
.52119 .48493 L
s
.52114 .4847 m
.52134 .4848 L
s
1 .001 0 r
.57823 .34869 m
.57824 .3487 L
s
.57822 .34871 m
.57823 .34869 L
s
.57823 .34869 m
.57822 .34869 L
s
1 .046 0 r
.36082 .45782 m
.36039 .45756 L
s
.36039 .45756 m
.36048 .45702 L
s
1 .001 0 r
.57823 .34871 m
.57822 .34871 L
s
.57822 .34871 m
.57822 .34869 L
s
.57824 .3487 m
.57823 .34871 L
s
.57822 .34869 m
.57824 .3487 L
s
.57822 .34869 m
.57823 .34871 L
s
1 .013 0 r
.52114 .4847 m
.52119 .48493 L
s
1 .069 0 r
.4044 .59357 m
.40365 .59047 L
s
1 .046 0 r
.36129 .45727 m
.36082 .45782 L
s
.36048 .45702 m
.36129 .45727 L
s
1 .005 0 r
.68064 .51164 m
.6806 .5114 L
s
1 .046 0 r
.36048 .45702 m
.36082 .45782 L
s
1 0 0 r
.63515 .21213 m
.63515 .21213 L
s
.63515 .21213 m
.63515 .21213 L
s
.63515 .21213 m
.63515 .21213 L
s
.63515 .21213 m
.63515 .21213 L
s
.63515 .21213 m
.63515 .21213 L
s
.63515 .21213 m
.63515 .21213 L
s
.63515 .21213 m
.63515 .21213 L
s
.63515 .21213 m
.63515 .21213 L
s
.63515 .21213 m
.63515 .21213 L
s
1 .005 0 r
.68061 .5114 m
.68067 .51144 L
s
.68055 .51145 m
.68061 .5114 L
s
.68061 .5114 m
.6806 .5114 L
s
.68061 .51149 m
.68055 .51145 L
s
.68055 .51145 m
.6806 .5114 L
s
1 .017 0 r
.46125 .45701 m
.46078 .45624 L
s
1 .005 0 r
.68067 .51144 m
.68061 .51149 L
s
.6806 .5114 m
.68067 .51144 L
s
0 .558 1 r
.24285 .22326 m
.22925 .28752 L
s
1 .005 0 r
.6806 .5114 m
.68061 .51149 L
s
1 .001 0 r
.73757 .37504 m
.73756 .37501 L
s
.73756 .37501 m
.73757 .37501 L
s
.73755 .37501 m
.73756 .37501 L
s
.73756 .37501 m
.73756 .37501 L
s
.73756 .37502 m
.73755 .37501 L
s
.73755 .37501 m
.73756 .37501 L
s
.73757 .37501 m
.73756 .37502 L
s
.73756 .37501 m
.73757 .37501 L
s
.73756 .37501 m
.73756 .37502 L
s
.51813 .32038 m
.5181 .32034 L
s
.5181 .32034 m
.51811 .32034 L
s
.51809 .32035 m
.5181 .32034 L
s
.5181 .32034 m
.5181 .32034 L
s
1 .017 0 r
.46088 .45624 m
.46106 .45635 L
s
.4607 .45643 m
.46088 .45624 L
s
.46088 .45624 m
.46078 .45624 L
s
1 .001 0 r
.5181 .32035 m
.51809 .32035 L
s
.51809 .32035 m
.5181 .32034 L
s
.51811 .32034 m
.5181 .32035 L
s
.5181 .32034 m
.51811 .32034 L
s
.5181 .32034 m
.5181 .32035 L
s
1 .31 0 r
.24002 .53812 m
.23674 .54182 L
s
.23453 .53636 m
.24002 .53812 L
s
1 .017 0 r
.46087 .45654 m
.4607 .45643 L
s
.4607 .45643 m
.46078 .45624 L
s
1 .108 0 r
.34419 .56532 m
.3418 .56049 L
s
1 .017 0 r
.46106 .45635 m
.46087 .45654 L
s
.46078 .45624 m
.46106 .45635 L
s
1 .003 0 r
.84003 .538 m
.84003 .53788 L
s
1 .017 0 r
.46078 .45624 m
.46087 .45654 L
s
1 .003 0 r
.84002 .53788 m
.84005 .53791 L
s
.84 .53791 m
.84002 .53788 L
s
.84002 .53788 m
.84003 .53788 L
s
.84003 .53793 m
.84 .53791 L
s
.84 .53791 m
.84003 .53788 L
s
.84005 .53791 m
.84003 .53793 L
s
.84003 .53788 m
.84005 .53791 L
s
.84003 .53788 m
.84003 .53793 L
s
1 .006 0 r
.62056 .48335 m
.62048 .48307 L
s
.62049 .48307 m
.62056 .48312 L
s
.62043 .48313 m
.62049 .48307 L
s
.62049 .48307 m
.62048 .48307 L
s
1 .654 0 r
.19771 .53762 m
.19055 .54521 L
s
.18636 .53355 m
.19771 .53762 L
s
1 .022 0 r
.40105 .42869 m
.4002 .42773 L
s
1 .006 0 r
.6205 .48318 m
.62043 .48313 L
s
.62043 .48313 m
.62048 .48307 L
s
.62056 .48312 m
.6205 .48318 L
s
.62048 .48307 m
.62056 .48312 L
s
.62048 .48307 m
.6205 .48318 L
s
1 .31 0 r
.23453 .53636 m
.23674 .54182 L
s
1 .001 0 r
.6775 .34667 m
.67749 .34665 L
s
.67749 .34665 m
.6775 .34665 L
s
.67748 .34665 m
.67749 .34665 L
s
.67749 .34665 m
.67749 .34665 L
s
.67749 .34666 m
.67748 .34665 L
s
.67748 .34665 m
.67749 .34665 L
s
.6775 .34665 m
.67749 .34666 L
s
.67749 .34665 m
.6775 .34665 L
s
.67749 .34665 m
.67749 .34666 L
s
1 .031 0 r
.50349 .59172 m
.50327 .59033 L
s
1 .177 0 r
.28391 .53705 m
.27689 .52966 L
s
1 .022 0 r
.40038 .42772 m
.40059 .42785 L
s
.40015 .42799 m
.40038 .42772 L
s
.40038 .42772 m
.4002 .42773 L
s
.40036 .42812 m
.40015 .42799 L
s
.40015 .42799 m
.4002 .42773 L
s
1 .003 0 r
.78 .50971 m
.77999 .50958 L
s
1 .069 0 r
.40382 .59045 m
.40457 .59105 L
s
.40302 .59114 m
.40382 .59045 L
s
.40382 .59045 m
.40365 .59047 L
s
1 .003 0 r
.77999 .50958 m
.78002 .50961 L
s
.77996 .50961 m
.77999 .50958 L
s
.77999 .50958 m
.77999 .50958 L
s
.77999 .50963 m
.77996 .50961 L
s
.77996 .50961 m
.77999 .50958 L
s
.78002 .50961 m
.77999 .50963 L
s
.77999 .50958 m
.78002 .50961 L
s
1 0 0 r
.73447 .20993 m
.73447 .20993 L
s
.73447 .20993 m
.73447 .20993 L
s
.73447 .20993 m
.73447 .20993 L
s
.73447 .20993 m
.73447 .20993 L
s
.73447 .20993 m
.73447 .20993 L
s
.73447 .20993 m
.73447 .20993 L
s
.73447 .20993 m
.73447 .20993 L
s
.73447 .20993 m
.73447 .20993 L
s
.73447 .20993 m
.73447 .20993 L
s
1 .003 0 r
.77999 .50958 m
.77999 .50963 L
s
1 .022 0 r
.40059 .42785 m
.40036 .42812 L
s
.4002 .42773 m
.40059 .42785 L
s
.4002 .42773 m
.40036 .42812 L
s
1 .007 0 r
.56042 .45503 m
.56027 .4547 L
s
1 .069 0 r
.40378 .59173 m
.40302 .59114 L
s
.40302 .59114 m
.40365 .59047 L
s
.40457 .59105 m
.40378 .59173 L
s
.40365 .59047 m
.40457 .59105 L
s
1 .007 0 r
.5603 .4547 m
.56038 .45475 L
s
.56022 .45478 m
.5603 .4547 L
s
.5603 .4547 m
.56027 .4547 L
s
.5603 .45483 m
.56022 .45478 L
s
.56022 .45478 m
.56027 .4547 L
s
.56038 .45475 m
.5603 .45483 L
s
.56027 .4547 m
.56038 .45475 L
s
.56027 .4547 m
.5603 .45483 L
s
1 0 0 r
.61737 .31828 m
.61736 .31826 L
s
.61736 .31826 m
.61737 .31826 L
s
.61736 .31826 m
.61736 .31826 L
s
.61736 .31826 m
.61736 .31826 L
s
.61736 .31827 m
.61736 .31826 L
s
.61736 .31826 m
.61736 .31826 L
s
.61737 .31826 m
.61736 .31827 L
s
.61736 .31826 m
.61737 .31826 L
s
.61736 .31826 m
.61736 .31827 L
s
1 .069 0 r
.40365 .59047 m
.40378 .59173 L
s
1 .031 0 r
.50332 .59032 m
.50366 .59059 L
s
.50297 .59063 m
.50332 .59032 L
s
.50332 .59032 m
.50327 .59033 L
s
1 .044 0 r
.44327 .56345 m
.44263 .56147 L
s
1 .031 0 r
.50331 .5909 m
.50297 .59063 L
s
.50297 .59063 m
.50327 .59033 L
s
.50366 .59059 m
.50331 .5909 L
s
.50327 .59033 m
.50366 .59059 L
s
1 .654 0 r
.18636 .53355 m
.19055 .54521 L
s
1 .031 0 r
.50327 .59033 m
.50331 .5909 L
s
1 .003 0 r
.71991 .4814 m
.71988 .48125 L
s
.71989 .48125 m
.71992 .48128 L
s
.71985 .48128 m
.71989 .48125 L
s
.71989 .48125 m
.71988 .48125 L
s
.71989 .48131 m
.71985 .48128 L
s
.71985 .48128 m
.71988 .48125 L
s
.71992 .48128 m
.71989 .48131 L
s
.71988 .48125 m
.71992 .48128 L
s
.71988 .48125 m
.71989 .48131 L
s
1 .009 0 r
.50021 .42668 m
.49997 .42629 L
s
1 .175 0 r
.30324 .58753 m
.3051 .58899 L
s
.3012 .58933 m
.30324 .58753 L
s
.30324 .58753 m
.30256 .58759 L
s
1 .009 0 r
.50002 .42629 m
.50011 .42635 L
s
.49993 .42639 m
.50002 .42629 L
s
.50002 .42629 m
.49997 .42629 L
s
.50002 .42645 m
.49993 .42639 L
s
.49993 .42639 m
.49997 .42629 L
s
1 0 0 r
.77692 .3446 m
.77692 .34458 L
s
.77692 .34458 m
.77692 .34458 L
s
.77692 .34458 m
.77692 .34458 L
s
.77692 .34458 m
.77692 .34458 L
s
.77692 .34459 m
.77692 .34458 L
s
.77692 .34458 m
.77692 .34458 L
s
.77692 .34458 m
.77692 .34459 L
s
.77692 .34458 m
.77692 .34458 L
s
.77692 .34458 m
.77692 .34459 L
s
1 .009 0 r
.50011 .42635 m
.50002 .42645 L
s
.49997 .42629 m
.50011 .42635 L
s
.49997 .42629 m
.50002 .42645 L
s
1 .015 0 r
.60276 .58986 m
.6027 .58918 L
s
1 0 0 r
.55718 .28986 m
.55717 .28984 L
s
.55717 .28984 m
.55718 .28984 L
s
.55717 .28985 m
.55717 .28984 L
s
.55717 .28984 m
.55717 .28984 L
s
.55717 .28985 m
.55717 .28985 L
s
.55717 .28985 m
.55717 .28984 L
s
.55718 .28984 m
.55717 .28985 L
s
.55717 .28984 m
.55718 .28984 L
s
.55717 .28984 m
.55717 .28985 L
s
1 .065 0 r
.38299 .53515 m
.38136 .53224 L
s
1 .003 0 r
.65976 .45305 m
.65971 .45289 L
s
1 .015 0 r
.60271 .58918 m
.60288 .58931 L
s
.60254 .58933 m
.60271 .58918 L
s
.60271 .58918 m
.6027 .58918 L
s
1 .044 0 r
.44276 .56146 m
.44324 .56182 L
s
.44227 .56191 m
.44276 .56146 L
s
.44276 .56146 m
.44263 .56147 L
s
1 .015 0 r
.60271 .58946 m
.60254 .58933 L
s
.60254 .58933 m
.6027 .58918 L
s
1 .175 0 r
.30306 .59079 m
.3012 .58933 L
s
.3012 .58933 m
.30256 .58759 L
s
1 .015 0 r
.60288 .58931 m
.60271 .58946 L
s
.6027 .58918 m
.60288 .58931 L
s
1 .003 0 r
.65972 .45289 m
.65976 .45292 L
s
.65968 .45293 m
.65972 .45289 L
s
.65972 .45289 m
.65971 .45289 L
s
.65972 .45295 m
.65968 .45293 L
s
.65968 .45293 m
.65971 .45289 L
s
.65976 .45292 m
.65972 .45295 L
s
.65971 .45289 m
.65976 .45292 L
s
.65971 .45289 m
.65972 .45295 L
s
1 .108 0 r
.34233 .56046 m
.34346 .5613 L
s
.3411 .56162 m
.34233 .56046 L
s
.34233 .56046 m
.3418 .56049 L
s
1 .015 0 r
.6027 .58918 m
.60271 .58946 L
s
1 .01 0 r
.43995 .39831 m
.43956 .39786 L
s
1 .044 0 r
.44275 .56227 m
.44227 .56191 L
s
.44227 .56191 m
.44263 .56147 L
s
.44324 .56182 m
.44275 .56227 L
s
.44263 .56147 m
.44324 .56182 L
s
1 .175 0 r
.3051 .58899 m
.30306 .59079 L
s
.30256 .58759 m
.3051 .58899 L
s
1 .01 0 r
.43964 .39786 m
.43974 .39792 L
s
.43954 .39798 m
.43964 .39786 L
s
.43964 .39786 m
.43956 .39786 L
s
1 0 0 r
.71679 .31617 m
.71679 .31616 L
s
1 .044 0 r
.44263 .56147 m
.44275 .56227 L
s
1 0 0 r
.71679 .31616 m
.71679 .31617 L
s
.71678 .31617 m
.71679 .31616 L
s
.71679 .31616 m
.71679 .31616 L
s
.71679 .31617 m
.71678 .31617 L
s
.71678 .31617 m
.71679 .31616 L
s
.71679 .31617 m
.71679 .31617 L
s
.71679 .31616 m
.71679 .31617 L
s
.71679 .31616 m
.71679 .31617 L
s
1 .01 0 r
.43963 .39804 m
.43954 .39798 L
s
.43954 .39798 m
.43956 .39786 L
s
1 .108 0 r
.34223 .56246 m
.3411 .56162 L
s
.3411 .56162 m
.3418 .56049 L
s
1 .01 0 r
.43974 .39792 m
.43963 .39804 L
s
.43956 .39786 m
.43974 .39792 L
s
1 .02 0 r
.54253 .56157 m
.54234 .56067 L
s
1 .01 0 r
.43956 .39786 m
.43963 .39804 L
s
1 .099 0 r
.32265 .50682 m
.31872 .50263 L
s
1 .108 0 r
.34346 .5613 m
.34223 .56246 L
s
.3418 .56049 m
.34346 .5613 L
s
1 .002 0 r
.81944 .47944 m
.81943 .47936 L
s
.81943 .47936 m
.81946 .47937 L
s
.81942 .47938 m
.81943 .47936 L
s
.81943 .47936 m
.81943 .47936 L
s
.81944 .47939 m
.81942 .47938 L
s
.81942 .47938 m
.81943 .47936 L
s
.81946 .47937 m
.81944 .47939 L
s
.81943 .47936 m
.81946 .47937 L
s
.81943 .47936 m
.81944 .47939 L
s
1 .004 0 r
.59955 .42468 m
.59947 .4245 L
s
1 .175 0 r
.30256 .58759 m
.30306 .59079 L
s
1 .004 0 r
.59949 .4245 m
.59953 .42453 L
s
.59945 .42454 m
.59949 .4245 L
s
.59949 .4245 m
.59947 .4245 L
s
.59949 .42457 m
.59945 .42454 L
s
.59945 .42454 m
.59947 .4245 L
s
.59953 .42453 m
.59949 .42457 L
s
.59947 .4245 m
.59953 .42453 L
s
1 .02 0 r
.54238 .56066 m
.5426 .56083 L
s
.54215 .56086 m
.54238 .56066 L
s
.54238 .56066 m
.54234 .56067 L
s
1 .108 0 r
.3418 .56049 m
.34223 .56246 L
s
1 .004 0 r
.59947 .4245 m
.59949 .42457 L
s
1 .02 0 r
.54238 .56103 m
.54215 .56086 L
s
.54215 .56086 m
.54234 .56067 L
s
.5426 .56083 m
.54238 .56103 L
s
.54234 .56067 m
.5426 .56083 L
s
.54234 .56067 m
.54238 .56103 L
s
1 .008 0 r
.70221 .58801 m
.7022 .58764 L
s
1 0 0 r
.6566 .28773 m
.65659 .28772 L
s
.65659 .28772 m
.65659 .28772 L
s
.65659 .28772 m
.65659 .28772 L
s
.65659 .28772 m
.65659 .28772 L
s
.65659 .28772 m
.65659 .28772 L
s
.65659 .28772 m
.65659 .28772 L
s
.65659 .28772 m
.65659 .28772 L
s
.65659 .28772 m
.65659 .28772 L
s
.65659 .28772 m
.65659 .28772 L
s
1 .027 0 r
.48225 .53324 m
.48179 .53202 L
s
1 .008 0 r
.7022 .58764 m
.70229 .58771 L
s
.70211 .58772 m
.7022 .58764 L
s
.7022 .58764 m
.7022 .58764 L
s
1 .065 0 r
.38171 .53222 m
.38239 .5327 L
s
.38099 .53294 m
.38171 .53222 L
s
.38171 .53222 m
.38136 .53224 L
s
1 .008 0 r
.70221 .58779 m
.70211 .58772 L
s
.70211 .58772 m
.7022 .58764 L
s
.70229 .58771 m
.70221 .58779 L
s
.7022 .58764 m
.70229 .58771 L
s
.7022 .58764 m
.70221 .58779 L
s
1 .002 0 r
.75929 .45107 m
.75927 .45098 L
s
1 .065 0 r
.38167 .53342 m
.38099 .53294 L
s
.38099 .53294 m
.38136 .53224 L
s
1 .002 0 r
.75927 .45098 m
.7593 .451 L
s
.75925 .451 m
.75927 .45098 L
s
.75927 .45098 m
.75927 .45098 L
s
.75928 .45102 m
.75925 .451 L
s
.75925 .451 m
.75927 .45098 L
s
.7593 .451 m
.75928 .45102 L
s
.75927 .45098 m
.7593 .451 L
s
.75927 .45098 m
.75928 .45102 L
s
1 .659 0 r
.18991 .55083 m
.19609 .55534 L
s
.18268 .5585 m
.18991 .55083 L
s
.18991 .55083 m
.1846 .55126 L
s
1 .004 0 r
.53928 .39628 m
.53916 .39608 L
s
1 .065 0 r
.38239 .5327 m
.38167 .53342 L
s
.38136 .53224 m
.38239 .5327 L
s
1 .004 0 r
.53919 .39608 m
.53923 .39611 L
s
.53914 .39613 m
.53919 .39608 L
s
.53919 .39608 m
.53916 .39608 L
s
.53919 .39616 m
.53914 .39613 L
s
.53914 .39613 m
.53916 .39608 L
s
.53923 .39611 m
.53919 .39616 L
s
.53916 .39608 m
.53923 .39611 L
s
.53916 .39608 m
.53919 .39616 L
s
1 .065 0 r
.38136 .53224 m
.38167 .53342 L
s
1 .027 0 r
.48188 .53201 m
.48218 .53222 L
s
.48158 .5323 m
.48188 .53201 L
s
.48188 .53201 m
.48179 .53202 L
s
1 .01 0 r
.64198 .55968 m
.64192 .55923 L
s
1 .027 0 r
.48188 .53251 m
.48158 .5323 L
s
.48158 .5323 m
.48179 .53202 L
s
1 0 0 r
.59634 .25925 m
.59634 .25924 L
s
.59634 .25924 m
.59634 .25924 L
s
.59634 .25924 m
.59634 .25924 L
s
.59634 .25924 m
.59634 .25924 L
s
.59634 .25924 m
.59634 .25924 L
s
.59634 .25924 m
.59634 .25924 L
s
.59634 .25924 m
.59634 .25924 L
s
.59634 .25924 m
.59634 .25924 L
s
.59634 .25924 m
.59634 .25924 L
s
1 .027 0 r
.48218 .53222 m
.48188 .53251 L
s
.48179 .53202 m
.48218 .53222 L
s
1 .038 0 r
.4219 .50488 m
.4209 .5032 L
s
1 .027 0 r
.48179 .53202 m
.48188 .53251 L
s
1 .01 0 r
.64193 .55923 m
.64204 .55932 L
s
.64182 .55933 m
.64193 .55923 L
s
.64193 .55923 m
.64192 .55923 L
s
.64194 .55941 m
.64182 .55933 L
s
.64182 .55933 m
.64192 .55923 L
s
.64204 .55932 m
.64194 .55941 L
s
.64192 .55923 m
.64204 .55932 L
s
1 .177 0 r
.27841 .52951 m
.28005 .53063 L
s
.27656 .53165 m
.27841 .52951 L
s
.27841 .52951 m
.27689 .52966 L
s
1 .01 0 r
.64192 .55923 m
.64194 .55941 L
s
1 .002 0 r
.69908 .42267 m
.69905 .42258 L
s
.69905 .42258 m
.69907 .42259 L
s
.69903 .4226 m
.69905 .42258 L
s
.69905 .42258 m
.69905 .42258 L
s
.69905 .42261 m
.69903 .4226 L
s
.69903 .4226 m
.69905 .42258 L
s
.69907 .42259 m
.69905 .42261 L
s
.69905 .42258 m
.69907 .42259 L
s
.69905 .42258 m
.69905 .42261 L
s
1 .004 0 r
.47895 .36784 m
.47878 .36765 L
s
1 .177 0 r
.2782 .53276 m
.27656 .53165 L
s
.27656 .53165 m
.27689 .52966 L
s
1 .004 0 r
.47882 .36765 m
.47886 .36767 L
s
.47877 .3677 m
.47882 .36765 L
s
.47882 .36765 m
.47878 .36765 L
s
.47882 .36773 m
.47877 .3677 L
s
.47877 .3677 m
.47878 .36765 L
s
.47886 .36767 m
.47882 .36773 L
s
.47878 .36765 m
.47886 .36767 L
s
.47878 .36765 m
.47882 .36773 L
s
1 .005 0 r
.80185 .58615 m
.80185 .58594 L
s
1 0 0 r
.75619 .28559 m
.75619 .28559 L
s
.75619 .28559 m
.75619 .28559 L
s
.75619 .28559 m
.75619 .28559 L
s
.75619 .28559 m
.75619 .28559 L
s
.75619 .28559 m
.75619 .28559 L
s
.75619 .28559 m
.75619 .28559 L
s
.75619 .28559 m
.75619 .28559 L
s
.75619 .28559 m
.75619 .28559 L
s
.75619 .28559 m
.75619 .28559 L
s
1 .005 0 r
.80185 .58594 m
.8019 .58598 L
s
.8018 .58598 m
.80185 .58594 L
s
.80185 .58594 m
.80185 .58594 L
s
.80185 .58602 m
.8018 .58598 L
s
.8018 .58598 m
.80185 .58594 L
s
.8019 .58598 m
.80185 .58602 L
s
.80185 .58594 m
.8019 .58598 L
s
1 .012 0 r
.58169 .53133 m
.58154 .53076 L
s
1 .005 0 r
.80185 .58594 m
.80185 .58602 L
s
1 .099 0 r
.31955 .50257 m
.32048 .50317 L
s
.31853 .50377 m
.31955 .50257 L
s
.31955 .50257 m
.31872 .50263 L
s
1 .659 0 r
.18885 .56304 m
.18268 .5585 L
s
.18268 .5585 m
.1846 .55126 L
s
1 .054 0 r
.3615 .4765 m
.35938 .47421 L
s
1 .099 0 r
.31945 .50438 m
.31853 .50377 L
s
.31853 .50377 m
.31872 .50263 L
s
1 .038 0 r
.42111 .50319 m
.4215 .50346 L
s
.4207 .50361 m
.42111 .50319 L
s
.42111 .50319 m
.4209 .5032 L
s
1 .012 0 r
.58157 .53076 m
.58171 .53086 L
s
.58143 .53089 m
.58157 .53076 L
s
.58157 .53076 m
.58154 .53076 L
s
1 .038 0 r
.42109 .50388 m
.4207 .50361 L
s
.4207 .50361 m
.4209 .5032 L
s
1 .012 0 r
.58157 .53099 m
.58143 .53089 L
s
.58143 .53089 m
.58154 .53076 L
s
.58171 .53086 m
.58157 .53099 L
s
.58154 .53076 m
.58171 .53086 L
s
1 .002 0 r
.6388 .39424 m
.63876 .39415 L
s
1 .317 0 r
.23559 .55368 m
.23852 .55575 L
s
.23222 .55749 m
.23559 .55368 L
s
.23559 .55368 m
.23287 .55396 L
s
1 .012 0 r
.58154 .53076 m
.58157 .53099 L
s
1 .002 0 r
.63877 .39415 m
.63879 .39416 L
s
.63875 .39417 m
.63877 .39415 L
s
.63877 .39415 m
.63876 .39415 L
s
.63877 .39418 m
.63875 .39417 L
s
.63875 .39417 m
.63876 .39415 L
s
1 .038 0 r
.4215 .50346 m
.42109 .50388 L
s
.4209 .5032 m
.4215 .50346 L
s
1 .002 0 r
.63879 .39416 m
.63877 .39418 L
s
.63876 .39415 m
.63879 .39416 L
s
.63876 .39415 m
.63877 .39418 L
s
1 .038 0 r
.4209 .5032 m
.42109 .50388 L
s
1 .177 0 r
.28005 .53063 m
.2782 .53276 L
s
.27689 .52966 m
.28005 .53063 L
s
1 .324 0 r
.24398 .58522 m
.23125 .57177 L
s
1 .099 0 r
.32048 .50317 m
.31945 .50438 L
s
.31872 .50263 m
.32048 .50317 L
s
1 .005 0 r
.74161 .5578 m
.7416 .55755 L
s
1 0 0 r
.69593 .25708 m
.69593 .25708 L
s
.69593 .25708 m
.69593 .25708 L
s
.69593 .25708 m
.69593 .25708 L
s
.69593 .25708 m
.69593 .25708 L
s
.69593 .25708 m
.69593 .25708 L
s
.69593 .25708 m
.69593 .25708 L
s
.69593 .25708 m
.69593 .25708 L
s
.69593 .25708 m
.69593 .25708 L
s
.69593 .25708 m
.69593 .25708 L
s
1 .099 0 r
.31872 .50263 m
.31945 .50438 L
s
1 .005 0 r
.7416 .55755 m
.74166 .5576 L
s
.74154 .5576 m
.7416 .55755 L
s
.7416 .55755 m
.7416 .55755 L
s
1 .016 0 r
.52134 .50295 m
.52104 .50222 L
s
1 .177 0 r
.27689 .52966 m
.2782 .53276 L
s
1 .005 0 r
.7416 .55765 m
.74154 .5576 L
s
.74154 .5576 m
.7416 .55755 L
s
.74166 .5576 m
.7416 .55765 L
s
.7416 .55755 m
.74166 .5576 L
s
.7416 .55755 m
.7416 .55765 L
s
1 .317 0 r
.23515 .55956 m
.23222 .55749 L
s
.23222 .55749 m
.23287 .55396 L
s
1 .001 0 r
.79878 .42065 m
.79877 .4206 L
s
.79877 .42061 m
.79878 .42061 L
s
.79876 .42062 m
.79877 .42061 L
s
.79877 .42061 m
.79877 .4206 L
s
.79877 .42062 m
.79876 .42062 L
s
.79876 .42062 m
.79877 .4206 L
s
.79878 .42061 m
.79877 .42062 L
s
.79877 .4206 m
.79878 .42061 L
s
.79877 .4206 m
.79877 .42062 L
s
1 .002 0 r
.57846 .36578 m
.57841 .36569 L
s
1 .016 0 r
.5211 .50222 m
.52127 .50234 L
s
.52092 .50239 m
.5211 .50222 L
s
.5211 .50222 m
.52104 .50222 L
s
1 .002 0 r
.57842 .36569 m
.57844 .3657 L
s
.5784 .36571 m
.57842 .36569 L
s
.57842 .36569 m
.57841 .36569 L
s
.57842 .36573 m
.5784 .36571 L
s
.5784 .36571 m
.57841 .36569 L
s
1 .016 0 r
.5211 .50251 m
.52092 .50239 L
s
.52092 .50239 m
.52104 .50222 L
s
1 .002 0 r
.57844 .3657 m
.57842 .36573 L
s
.57841 .36569 m
.57844 .3657 L
s
.57841 .36569 m
.57842 .36573 L
s
1 .016 0 r
.52127 .50234 m
.5211 .50251 L
s
.52104 .50222 m
.52127 .50234 L
s
.52104 .50222 m
.5211 .50251 L
s
1 .054 0 r
.35983 .47418 m
.36034 .4745 L
s
.35928 .47483 m
.35983 .47418 L
s
.35983 .47418 m
.35938 .47421 L
s
.35979 .47515 m
.35928 .47483 L
s
.35928 .47483 m
.35938 .47421 L
s
1 .006 0 r
.68132 .52942 m
.68127 .52912 L
s
0 .088 1 r
.23642 .2555 m
.27761 .29764 L
s
.18942 .2809 m
.23642 .2555 L
s
.23642 .2555 m
.24673 .24921 L
s
1 0 0 r
.63561 .22855 m
.63561 .22855 L
s
.63561 .22855 m
.63561 .22855 L
s
.63561 .22855 m
.63561 .22855 L
s
.63561 .22855 m
.63561 .22855 L
s
.63561 .22855 m
.63561 .22855 L
s
.63561 .22855 m
.63561 .22855 L
s
.63561 .22855 m
.63561 .22855 L
s
.63561 .22855 m
.63561 .22855 L
s
.63561 .22855 m
.63561 .22855 L
s
1 .021 0 r
.46093 .47454 m
.46035 .47359 L
s
1 .006 0 r
.68128 .52912 m
.68135 .52918 L
s
.68121 .52919 m
.68128 .52912 L
s
.68128 .52912 m
.68127 .52912 L
s
.68128 .52924 m
.68121 .52919 L
s
.68121 .52919 m
.68127 .52912 L
s
1 .054 0 r
.36034 .4745 m
.35979 .47515 L
s
.35938 .47421 m
.36034 .4745 L
s
1 .006 0 r
.68135 .52918 m
.68128 .52924 L
s
.68127 .52912 m
.68135 .52918 L
s
.68127 .52912 m
.68128 .52924 L
s
1 .054 0 r
.35938 .47421 m
.35979 .47515 L
s
1 .001 0 r
.7385 .3922 m
.73848 .39215 L
s
.73849 .39215 m
.7385 .39216 L
s
.73848 .39216 m
.73849 .39215 L
s
.73849 .39215 m
.73848 .39215 L
s
.73849 .39217 m
.73848 .39216 L
s
.73848 .39216 m
.73848 .39215 L
s
.7385 .39216 m
.73849 .39217 L
s
.73848 .39215 m
.7385 .39216 L
s
.73848 .39215 m
.73849 .39217 L
s
1 .002 0 r
.51807 .33729 m
.518 .33721 L
s
.51801 .33721 m
.51803 .33722 L
s
.518 .33723 m
.51801 .33721 L
s
.51801 .33721 m
.518 .33721 L
s
.51801 .33724 m
.518 .33723 L
s
.518 .33723 m
.518 .33721 L
s
.51803 .33722 m
.51801 .33724 L
s
.518 .33721 m
.51803 .33722 L
s
.518 .33721 m
.51801 .33724 L
s
1 .115 0 r
.34333 .58335 m
.34078 .57823 L
s
1 .021 0 r
.46047 .47359 m
.46069 .47373 L
s
.46024 .47383 m
.46047 .47359 L
s
.46047 .47359 m
.46035 .47359 L
s
1 .003 0 r
.84142 .55591 m
.84142 .55576 L
s
1 .021 0 r
.46046 .47397 m
.46024 .47383 L
s
.46024 .47383 m
.46035 .47359 L
s
1 .003 0 r
.84142 .55576 m
.84146 .55579 L
s
.84139 .55579 m
.84142 .55576 L
s
.84142 .55576 m
.84142 .55576 L
s
.84143 .55582 m
.84139 .55579 L
s
.84139 .55579 m
.84142 .55576 L
s
1 .021 0 r
.46069 .47373 m
.46046 .47397 L
s
.46035 .47359 m
.46069 .47373 L
s
1 .003 0 r
.84146 .55579 m
.84143 .55582 L
s
.84142 .55576 m
.84146 .55579 L
s
.84142 .55576 m
.84143 .55582 L
s
1 .317 0 r
.23852 .55575 m
.23515 .55956 L
s
.23287 .55396 m
.23852 .55575 L
s
1 .021 0 r
.46035 .47359 m
.46046 .47397 L
s
0 .124 1 r
.27788 .28218 m
.23183 .30771 L
s
.24745 .23414 m
.27788 .28218 L
s
1 .008 0 r
.62096 .50101 m
.62086 .50066 L
s
1 .028 0 r
.40046 .4461 m
.39938 .4449 L
s
1 .008 0 r
.62088 .50066 m
.62096 .50072 L
s
.62079 .50074 m
.62088 .50066 L
s
.62088 .50066 m
.62086 .50066 L
s
.62088 .50079 m
.62079 .50074 L
s
.62079 .50074 m
.62086 .50066 L
s
.62096 .50072 m
.62088 .50079 L
s
.62086 .50066 m
.62096 .50072 L
s
.62086 .50066 m
.62088 .50079 L
s
1 .659 0 r
.19609 .55534 m
.18885 .56304 L
s
.1846 .55126 m
.19609 .55534 L
s
1 .001 0 r
.67816 .36371 m
.67814 .36367 L
s
.67814 .36367 m
.67815 .36367 L
s
.67813 .36368 m
.67814 .36367 L
s
.67814 .36367 m
.67814 .36367 L
s
.67814 .36368 m
.67813 .36368 L
s
.67813 .36368 m
.67814 .36367 L
s
.67815 .36367 m
.67814 .36368 L
s
.67814 .36367 m
.67815 .36367 L
s
.67814 .36367 m
.67814 .36368 L
s
1 .317 0 r
.23287 .55396 m
.23515 .55956 L
s
1 .185 0 r
.28278 .55496 m
.27539 .54724 L
s
1 .003 0 r
.78112 .5275 m
.78111 .52734 L
s
1 0 0 r
.73538 .22635 m
.73538 .22635 L
s
.73538 .22635 m
.73538 .22635 L
s
.73538 .22635 m
.73538 .22635 L
s
.73538 .22635 m
.73538 .22635 L
s
.73538 .22635 m
.73538 .22635 L
s
.73538 .22635 m
.73538 .22635 L
s
.73538 .22635 m
.73538 .22635 L
s
.73538 .22635 m
.73538 .22635 L
s
.73538 .22635 m
.73538 .22635 L
s
1 .003 0 r
.78111 .52734 m
.78115 .52737 L
s
.78107 .52737 m
.78111 .52734 L
s
.78111 .52734 m
.78111 .52734 L
s
1 .028 0 r
.3996 .44489 m
.39987 .44505 L
s
.39932 .44522 m
.3996 .44489 L
s
.3996 .44489 m
.39938 .4449 L
s
1 .003 0 r
.78112 .5274 m
.78107 .52737 L
s
.78107 .52737 m
.78111 .52734 L
s
.78115 .52737 m
.78112 .5274 L
s
.78111 .52734 m
.78115 .52737 L
s
.78111 .52734 m
.78112 .5274 L
s
1 .028 0 r
.39958 .44539 m
.39932 .44522 L
s
.39932 .44522 m
.39938 .4449 L
s
1 .009 0 r
.56054 .47257 m
.56036 .47214 L
s
1 .028 0 r
.39987 .44505 m
.39958 .44539 L
s
.39938 .4449 m
.39987 .44505 L
s
.39938 .4449 m
.39958 .44539 L
s
1 .009 0 r
.56039 .47215 m
.5605 .47221 L
s
.56029 .47225 m
.56039 .47215 L
s
.56039 .47215 m
.56036 .47214 L
s
.5604 .47231 m
.56029 .47225 L
s
.56029 .47225 m
.56036 .47214 L
s
.5605 .47221 m
.5604 .47231 L
s
.56036 .47214 m
.5605 .47221 L
s
.56036 .47214 m
.5604 .47231 L
s
1 .001 0 r
.61776 .3352 m
.61773 .33516 L
s
.61774 .33516 m
.61775 .33516 L
s
.61773 .33517 m
.61774 .33516 L
s
.61774 .33516 m
.61773 .33516 L
s
.61774 .33517 m
.61773 .33517 L
s
.61773 .33517 m
.61773 .33516 L
s
.61775 .33516 m
.61774 .33517 L
s
.61773 .33516 m
.61775 .33516 L
s
.61773 .33516 m
.61774 .33517 L
s
1 .049 0 r
.44286 .58148 m
.44215 .57929 L
s
0 .214 1 r
.23208 .29356 m
.19241 .25275 L
s
.19241 .25275 m
.24725 .22208 L
s
1 .004 0 r
.72076 .49906 m
.72073 .49888 L
s
1 .659 0 r
.1846 .55126 m
.18885 .56304 L
s
1 0 0 r
.675 .19776 m
.675 .19776 L
s
.675 .19776 m
.675 .19776 L
s
.675 .19776 m
.675 .19776 L
s
.675 .19776 m
.675 .19776 L
s
.675 .19776 m
.675 .19776 L
s
.675 .19776 m
.675 .19776 L
s
.675 .19776 m
.675 .19776 L
s
.675 .19776 m
.675 .19776 L
s
.675 .19776 m
.675 .19776 L
s
1 .004 0 r
.72073 .49888 m
.72078 .49891 L
s
.72069 .49892 m
.72073 .49888 L
s
.72073 .49888 m
.72073 .49888 L
s
.72074 .49895 m
.72069 .49892 L
s
.72069 .49892 m
.72073 .49888 L
s
.72078 .49891 m
.72074 .49895 L
s
.72073 .49888 m
.72078 .49891 L
s
.72073 .49888 m
.72074 .49895 L
s
1 .011 0 r
.50007 .4441 m
.49975 .44359 L
s
1 .001 0 r
.77804 .36164 m
.77803 .36162 L
s
.77803 .36162 m
.77804 .36162 L
s
.77803 .36162 m
.77803 .36162 L
s
.77803 .36162 m
.77803 .36162 L
s
.77803 .36163 m
.77803 .36162 L
s
.77803 .36162 m
.77803 .36162 L
s
.77804 .36162 m
.77803 .36163 L
s
.77803 .36162 m
.77804 .36162 L
s
.77803 .36162 m
.77803 .36163 L
s
1 .011 0 r
.49981 .44359 m
.49993 .44366 L
s
.49969 .44372 m
.49981 .44359 L
s
.49981 .44359 m
.49975 .44359 L
s
.49981 .44379 m
.49969 .44372 L
s
.49969 .44372 m
.49975 .44359 L
s
.49993 .44366 m
.49981 .44379 L
s
.49975 .44359 m
.49993 .44366 L
s
.49975 .44359 m
.49981 .44379 L
s
1 .001 0 r
.55729 .30665 m
.55727 .30662 L
s
.55727 .30662 m
.55728 .30663 L
s
.55727 .30663 m
.55727 .30662 L
s
.55727 .30662 m
.55727 .30662 L
s
.55727 .30664 m
.55727 .30663 L
s
.55727 .30663 m
.55727 .30662 L
s
.55728 .30663 m
.55727 .30664 L
s
.55727 .30662 m
.55728 .30663 L
s
.55727 .30662 m
.55727 .30664 L
s
1 .072 0 r
.38231 .55306 m
.38051 .54987 L
s
1 .004 0 r
.66034 .4706 m
.66028 .47039 L
s
.66029 .47039 m
.66034 .47042 L
s
.66024 .47043 m
.66029 .47039 L
s
.66029 .47039 m
.66028 .47039 L
s
.66029 .47047 m
.66024 .47043 L
s
.66024 .47043 m
.66028 .47039 L
s
.66034 .47042 m
.66029 .47047 L
s
.66028 .47039 m
.66034 .47042 L
s
.66028 .47039 m
.66029 .47047 L
s
1 .014 0 r
.43953 .4156 m
.439 .415 L
s
1 .049 0 r
.4423 .57928 m
.44283 .57968 L
s
.44175 .57978 m
.4423 .57928 L
s
.4423 .57928 m
.44215 .57929 L
s
1 .115 0 r
.34134 .57818 m
.34255 .57909 L
s
.34003 .57943 m
.34134 .57818 L
s
.34134 .57818 m
.34078 .57823 L
s
1 .049 0 r
.44228 .58019 m
.44175 .57978 L
s
.44175 .57978 m
.44215 .57929 L
s
1 0 0 r
.71763 .3331 m
.71762 .33308 L
s
.71762 .33308 m
.71763 .33308 L
s
.71762 .33308 m
.71762 .33308 L
s
.71762 .33308 m
.71762 .33308 L
s
.71762 .33309 m
.71762 .33308 L
s
.71762 .33308 m
.71762 .33308 L
s
1 .049 0 r
.44283 .57968 m
.44228 .58019 L
s
.44215 .57929 m
.44283 .57968 L
s
1 0 0 r
.71763 .33308 m
.71762 .33309 L
s
.71762 .33308 m
.71763 .33308 L
s
.71762 .33308 m
.71762 .33309 L
s
1 .023 0 r
.54258 .57961 m
.54235 .57858 L
s
1 .014 0 r
.43911 .415 m
.43924 .41508 L
s
.43897 .41517 m
.43911 .415 L
s
.43911 .415 m
.439 .415 L
s
.4391 .41525 m
.43897 .41517 L
s
.43897 .41517 m
.439 .415 L
s
1 .049 0 r
.44215 .57929 m
.44228 .58019 L
s
1 .014 0 r
.43924 .41508 m
.4391 .41525 L
s
.439 .415 m
.43924 .41508 L
s
.439 .415 m
.4391 .41525 L
s
1 .115 0 r
.34124 .58033 m
.34003 .57943 L
s
.34003 .57943 m
.34078 .57823 L
s
1 .108 0 r
.32169 .52461 m
.31739 .52007 L
s
1 .002 0 r
.82075 .49711 m
.82074 .49701 L
s
.82074 .49701 m
.82077 .49703 L
s
.82072 .49703 m
.82074 .49701 L
s
.82074 .49701 m
.82074 .49701 L
s
.82074 .49705 m
.82072 .49703 L
s
.82072 .49703 m
.82074 .49701 L
s
.82077 .49703 m
.82074 .49705 L
s
.82074 .49701 m
.82077 .49703 L
s
.82074 .49701 m
.82074 .49705 L
s
1 .005 0 r
.59986 .4421 m
.59975 .44186 L
s
1 .115 0 r
.34255 .57909 m
.34124 .58033 L
s
.34078 .57823 m
.34255 .57909 L
s
1 .005 0 r
.59977 .44186 m
.59983 .4419 L
s
.59972 .44192 m
.59977 .44186 L
s
.59977 .44186 m
.59975 .44186 L
s
.59977 .44196 m
.59972 .44192 L
s
.59972 .44192 m
.59975 .44186 L
s
.59983 .4419 m
.59977 .44196 L
s
.59975 .44186 m
.59983 .4419 L
s
.59975 .44186 m
.59977 .44196 L
s
1 .023 0 r
.5424 .57858 m
.54266 .57877 L
s
.54214 .57881 m
.5424 .57858 L
s
.5424 .57858 m
.54235 .57858 L
s
.5424 .579 m
.54214 .57881 L
s
.54214 .57881 m
.54235 .57858 L
s
.54266 .57877 m
.5424 .579 L
s
.54235 .57858 m
.54266 .57877 L
s
1 .115 0 r
.34078 .57823 m
.34124 .58033 L
s
1 .023 0 r
.54235 .57858 m
.5424 .579 L
s
1 0 0 r
.65716 .30453 m
.65715 .30451 L
s
.65716 .30451 m
.65716 .30451 L
s
.65715 .30452 m
.65716 .30451 L
s
.65716 .30451 m
.65715 .30451 L
s
.65716 .30452 m
.65715 .30452 L
s
.65715 .30452 m
.65715 .30451 L
s
.65716 .30451 m
.65716 .30452 L
s
.65715 .30451 m
.65716 .30451 L
s
.65715 .30451 m
.65716 .30452 L
s
1 .031 0 r
.48202 .55116 m
.48149 .54977 L
s
1 .002 0 r
.76032 .46862 m
.7603 .46851 L
s
1 .072 0 r
.38089 .54985 m
.38164 .55038 L
s
.38009 .55064 m
.38089 .54985 L
s
.38089 .54985 m
.38051 .54987 L
s
1 .002 0 r
.7603 .46851 m
.76033 .46853 L
s
.76028 .46853 m
.7603 .46851 L
s
.7603 .46851 m
.7603 .46851 L
s
.76031 .46855 m
.76028 .46853 L
s
.76028 .46853 m
.7603 .46851 L
s
.76033 .46853 m
.76031 .46855 L
s
.7603 .46851 m
.76033 .46853 L
s
.7603 .46851 m
.76031 .46855 L
s
1 .006 0 r
.53931 .41358 m
.53915 .41331 L
s
1 .072 0 r
.38084 .55118 m
.38009 .55064 L
s
.38009 .55064 m
.38051 .54987 L
s
1 .663 0 r
.18823 .56866 m
.19448 .57327 L
s
.18092 .57643 m
.18823 .56866 L
s
.18823 .56866 m
.18286 .56917 L
s
1 .006 0 r
.53918 .41331 m
.53924 .41335 L
s
.53912 .41338 m
.53918 .41331 L
s
.53918 .41331 m
.53915 .41331 L
s
.53918 .41342 m
.53912 .41338 L
s
.53912 .41338 m
.53915 .41331 L
s
.53924 .41335 m
.53918 .41342 L
s
.53915 .41331 m
.53924 .41335 L
s
.53915 .41331 m
.53918 .41342 L
s
1 .072 0 r
.38164 .55038 m
.38084 .55118 L
s
.38051 .54987 m
.38164 .55038 L
s
1 .012 0 r
.64248 .57773 m
.64241 .57721 L
s
1 0 0 r
.59663 .27593 m
.59663 .27592 L
s
.59663 .27592 m
.59663 .27592 L
s
.59662 .27592 m
.59663 .27592 L
s
.59663 .27592 m
.59663 .27592 L
s
.59663 .27592 m
.59662 .27592 L
s
.59662 .27592 m
.59663 .27592 L
s
1 .031 0 r
.4816 .54976 m
.48194 .55 L
s
.48125 .55009 m
.4816 .54976 L
s
.4816 .54976 m
.48149 .54977 L
s
1 0 0 r
.59663 .27592 m
.59663 .27592 L
s
.59663 .27592 m
.59663 .27592 L
s
.59663 .27592 m
.59663 .27592 L
s
1 .072 0 r
.38051 .54987 m
.38084 .55118 L
s
1 .043 0 r
.4214 .52269 m
.42024 .52076 L
s
1 .031 0 r
.48159 .55033 m
.48125 .55009 L
s
.48125 .55009 m
.48149 .54977 L
s
.48194 .55 m
.48159 .55033 L
s
.48149 .54977 m
.48194 .55 L
s
1 .012 0 r
.64242 .57721 m
.64256 .57731 L
s
.64229 .57732 m
.64242 .57721 L
s
.64242 .57721 m
.64241 .57721 L
s
1 .031 0 r
.48149 .54977 m
.48159 .55033 L
s
1 .012 0 r
.64243 .57742 m
.64229 .57732 L
s
.64229 .57732 m
.64241 .57721 L
s
.64256 .57731 m
.64243 .57742 L
s
.64241 .57721 m
.64256 .57731 L
s
1 .003 0 r
.69984 .4401 m
.6998 .43998 L
s
1 .012 0 r
.64241 .57721 m
.64243 .57742 L
s
1 .003 0 r
.6998 .43998 m
.69983 .44 L
s
.69977 .44001 m
.6998 .43998 L
s
.6998 .43998 m
.6998 .43998 L
s
.6998 .44002 m
.69977 .44001 L
s
.69977 .44001 m
.6998 .43998 L
s
.69983 .44 m
.6998 .44002 L
s
.6998 .43998 m
.69983 .44 L
s
.6998 .43998 m
.6998 .44002 L
s
1 .185 0 r
.27698 .54707 m
.27871 .54825 L
s
.27504 .54932 m
.27698 .54707 L
s
.27698 .54707 m
.27539 .54724 L
s
1 .006 0 r
.47871 .38503 m
.47846 .38474 L
s
.47851 .38474 m
.47858 .38477 L
s
.47845 .38482 m
.47851 .38474 L
s
.47851 .38474 m
.47846 .38474 L
s
.47851 .38485 m
.47845 .38482 L
s
.47845 .38482 m
.47846 .38474 L
s
.47858 .38477 m
.47851 .38485 L
s
.47846 .38474 m
.47858 .38477 L
s
.47846 .38474 m
.47851 .38485 L
s
1 0 0 r
.75722 .3024 m
.75721 .30239 L
s
.75721 .30239 m
.75721 .30239 L
s
.75721 .30239 m
.75721 .30239 L
s
.75721 .30239 m
.75721 .30239 L
s
.75721 .30239 m
.75721 .30239 L
s
.75721 .30239 m
.75721 .30239 L
s
.75721 .30239 m
.75721 .30239 L
s
.75721 .30239 m
.75721 .30239 L
s
.75721 .30239 m
.75721 .30239 L
s
1 .185 0 r
.27676 .55051 m
.27504 .54932 L
s
.27504 .54932 m
.27539 .54724 L
s
1 .015 0 r
.58192 .54926 m
.58174 .54859 L
s
1 .061 0 r
.36072 .49418 m
.35829 .49157 L
s
1 .663 0 r
.18716 .58106 m
.18092 .57643 L
s
.18092 .57643 m
.18286 .56917 L
s
1 .108 0 r
.3183 .51999 m
.31932 .52066 L
s
.31718 .52131 m
.3183 .51999 L
s
.3183 .51999 m
.31739 .52007 L
s
1 .043 0 r
.42048 .52075 m
.42093 .52106 L
s
.42001 .52123 m
.42048 .52075 L
s
.42048 .52075 m
.42024 .52076 L
s
1 .015 0 r
.58177 .54859 m
.58194 .54871 L
s
.58161 .54874 m
.58177 .54859 L
s
.58177 .54859 m
.58174 .54859 L
s
1 .003 0 r
.63929 .41155 m
.63923 .41142 L
s
1 .108 0 r
.31819 .52198 m
.31718 .52131 L
s
.31718 .52131 m
.31739 .52007 L
s
1 .015 0 r
.58178 .54886 m
.58161 .54874 L
s
.58161 .54874 m
.58174 .54859 L
s
.58194 .54871 m
.58178 .54886 L
s
.58174 .54859 m
.58194 .54871 L
s
1 .003 0 r
.63924 .41142 m
.63927 .41144 L
s
.63921 .41145 m
.63924 .41142 L
s
.63924 .41142 m
.63923 .41142 L
s
.63924 .41147 m
.63921 .41145 L
s
.63921 .41145 m
.63923 .41142 L
s
1 .043 0 r
.42046 .52154 m
.42001 .52123 L
s
.42001 .52123 m
.42024 .52076 L
s
1 .003 0 r
.63927 .41144 m
.63924 .41147 L
s
.63923 .41142 m
.63927 .41144 L
s
.63923 .41142 m
.63924 .41147 L
s
1 .015 0 r
.58174 .54859 m
.58178 .54886 L
s
1 .324 0 r
.23404 .57145 m
.23704 .57359 L
s
.23058 .57536 m
.23404 .57145 L
s
.23404 .57145 m
.23125 .57177 L
s
1 .043 0 r
.42093 .52106 m
.42046 .52154 L
s
.42024 .52076 m
.42093 .52106 L
s
1 .006 0 r
.74257 .57586 m
.74255 .57557 L
s
1 .043 0 r
.42024 .52076 m
.42046 .52154 L
s
1 0 0 r
.69668 .27377 m
.69668 .27377 L
s
.69668 .27377 m
.69668 .27377 L
s
.69668 .27377 m
.69668 .27377 L
s
.69668 .27377 m
.69668 .27377 L
s
.69668 .27377 m
.69668 .27377 L
s
.69668 .27377 m
.69668 .27377 L
s
.69668 .27377 m
.69668 .27377 L
s
.69668 .27377 m
.69668 .27377 L
s
.69668 .27377 m
.69668 .27377 L
s
1 .185 0 r
.27871 .54825 m
.27676 .55051 L
s
.27539 .54724 m
.27871 .54825 L
s
1 .019 0 r
.52129 .52076 m
.52093 .51989 L
s
1 .006 0 r
.74255 .57556 m
.74262 .57562 L
s
.74248 .57563 m
.74255 .57556 L
s
.74255 .57556 m
.74255 .57557 L
s
.74256 .57568 m
.74248 .57563 L
s
.74248 .57563 m
.74255 .57557 L
s
.74262 .57562 m
.74256 .57568 L
s
.74255 .57557 m
.74262 .57562 L
s
.74255 .57557 m
.74256 .57568 L
s
1 .108 0 r
.31932 .52066 m
.31819 .52198 L
s
.31739 .52007 m
.31932 .52066 L
s
1 .001 0 r
.8 .43809 m
.79998 .43802 L
s
1 .108 0 r
.31739 .52007 m
.31819 .52198 L
s
1 .324 0 r
.23358 .5775 m
.23058 .57536 L
s
.23058 .57536 m
.23125 .57177 L
s
1 .185 0 r
.27539 .54724 m
.27676 .55051 L
s
1 .001 0 r
.79998 .43802 m
.8 .43804 L
s
.79997 .43804 m
.79998 .43802 L
s
.79998 .43802 m
.79998 .43802 L
s
.79999 .43805 m
.79997 .43804 L
s
.79997 .43804 m
.79998 .43802 L
s
.8 .43804 m
.79999 .43805 L
s
.79998 .43802 m
.8 .43804 L
s
.79998 .43802 m
.79999 .43805 L
s
1 .003 0 r
.57867 .38297 m
.57859 .38283 L
s
.57861 .38284 m
.57864 .38285 L
s
.57858 .38287 m
.57861 .38284 L
s
.57861 .38284 m
.57859 .38283 L
s
.57861 .38289 m
.57858 .38287 L
s
.57858 .38287 m
.57859 .38283 L
s
.57864 .38285 m
.57861 .38289 L
s
.57859 .38283 m
.57864 .38285 L
s
1 .019 0 r
.521 .51989 m
.52121 .52004 L
s
.52079 .5201 m
.521 .51989 L
s
.521 .51989 m
.52093 .51989 L
s
1 .003 0 r
.57859 .38283 m
.57861 .38289 L
s
1 .019 0 r
.521 .52024 m
.52079 .5201 L
s
.52079 .5201 m
.52093 .51989 L
s
.52121 .52004 m
.521 .52024 L
s
.52093 .51989 m
.52121 .52004 L
s
.52093 .51989 m
.521 .52024 L
s
1 .008 0 r
.682 .54735 m
.68194 .54701 L
s
1 .061 0 r
.3588 .49153 m
.35938 .4919 L
s
.35816 .49228 m
.3588 .49153 L
s
.3588 .49153 m
.35829 .49157 L
s
1 0 0 r
.63608 .24511 m
.63608 .24511 L
s
.63608 .24511 m
.63608 .24511 L
s
.63608 .24511 m
.63608 .24511 L
s
.63608 .24511 m
.63608 .24511 L
s
.63608 .24511 m
.63608 .24511 L
s
.63608 .24511 m
.63608 .24511 L
s
.63608 .24511 m
.63608 .24511 L
s
.63608 .24511 m
.63608 .24511 L
s
.63608 .24511 m
.63608 .24511 L
s
1 .061 0 r
.35875 .49266 m
.35816 .49228 L
s
.35816 .49228 m
.35829 .49157 L
s
1 .025 0 r
.4606 .49223 m
.4599 .4911 L
s
1 .008 0 r
.68195 .54701 m
.68204 .54707 L
s
.68186 .54708 m
.68195 .54701 L
s
.68195 .54701 m
.68194 .54701 L
s
.68195 .54715 m
.68186 .54708 L
s
.68186 .54708 m
.68194 .54701 L
s
.68204 .54707 m
.68195 .54715 L
s
.68194 .54701 m
.68204 .54707 L
s
.68194 .54701 m
.68195 .54715 L
s
1 .001 0 r
.73944 .40951 m
.73942 .40945 L
s
1 .061 0 r
.35938 .4919 m
.35875 .49266 L
s
.35829 .49157 m
.35938 .4919 L
s
1 .001 0 r
.73942 .40945 m
.73944 .40946 L
s
.73941 .40946 m
.73942 .40945 L
s
.73942 .40945 m
.73942 .40945 L
s
.73942 .40947 m
.73941 .40946 L
s
.73941 .40946 m
.73942 .40945 L
s
.73944 .40946 m
.73942 .40947 L
s
.73942 .40945 m
.73944 .40946 L
s
.73942 .40945 m
.73942 .40947 L
s
0 .07 1 r
.23531 .27131 m
.27689 .31394 L
s
.18785 .29716 m
.23531 .27131 L
s
.23531 .27131 m
.2457 .26539 L
s
1 .061 0 r
.35829 .49157 m
.35875 .49266 L
s
1 .003 0 r
.518 .35436 m
.51789 .35423 L
s
.51791 .35423 m
.51794 .35425 L
s
.51789 .35426 m
.51791 .35423 L
s
.51791 .35423 m
.51789 .35423 L
s
.51791 .35428 m
.51789 .35426 L
s
.51789 .35426 m
.51789 .35423 L
s
.51794 .35425 m
.51791 .35428 L
s
.51789 .35423 m
.51794 .35425 L
s
.51789 .35423 m
.51791 .35428 L
s
1 .004 0 r
.84284 .57397 m
.84284 .5738 L
s
1 .025 0 r
.46004 .49109 m
.46031 .49127 L
s
.45977 .49138 m
.46004 .49109 L
s
.46004 .49109 m
.4599 .4911 L
s
1 .004 0 r
.84283 .5738 m
.84288 .57383 L
s
.84279 .57384 m
.84283 .5738 L
s
.84283 .5738 m
.84284 .5738 L
s
.84284 .57387 m
.84279 .57384 L
s
.84279 .57384 m
.84284 .5738 L
s
.84288 .57383 m
.84284 .57387 L
s
.84284 .5738 m
.84288 .57383 L
s
.84284 .5738 m
.84284 .57387 L
s
1 .025 0 r
.46004 .49155 m
.45977 .49138 L
s
.45977 .49138 m
.4599 .4911 L
s
1 .009 0 r
.62137 .51882 m
.62124 .5184 L
s
1 .025 0 r
.46031 .49127 m
.46004 .49155 L
s
.4599 .4911 m
.46031 .49127 L
s
.4599 .4911 m
.46004 .49155 L
s
1 .034 0 r
.39985 .46366 m
.39854 .46222 L
s
1 .324 0 r
.23704 .57359 m
.23358 .5775 L
s
.23125 .57177 m
.23704 .57359 L
s
1 .009 0 r
.62126 .5184 m
.62137 .51847 L
s
.62116 .5185 m
.62126 .5184 L
s
.62126 .5184 m
.62124 .5184 L
s
.62127 .51857 m
.62116 .5185 L
s
.62116 .5185 m
.62124 .5184 L
s
.62137 .51847 m
.62127 .51857 L
s
.62124 .5184 m
.62137 .51847 L
s
.62124 .5184 m
.62127 .51857 L
s
1 .001 0 r
.67883 .38091 m
.67879 .38084 L
s
1 .663 0 r
.19448 .57327 m
.18716 .58106 L
s
.18286 .56917 m
.19448 .57327 L
s
1 .001 0 r
.6788 .38084 m
.67882 .38085 L
s
.67878 .38086 m
.6788 .38084 L
s
.6788 .38084 m
.67879 .38084 L
s
.6788 .38087 m
.67878 .38086 L
s
.67878 .38086 m
.67879 .38084 L
s
.67882 .38085 m
.6788 .38087 L
s
.67879 .38084 m
.67882 .38085 L
s
.67879 .38084 m
.6788 .38087 L
s
1 .192 0 r
.28164 .57303 m
.27392 .56504 L
s
1 .004 0 r
.78226 .54544 m
.78224 .54525 L
s
1 .324 0 r
.23125 .57177 m
.23358 .5775 L
s
1 0 0 r
.73631 .24293 m
.73631 .24292 L
s
.73631 .24292 m
.73631 .24292 L
s
.73631 .24292 m
.73631 .24292 L
s
.73631 .24292 m
.73631 .24292 L
s
.73631 .24292 m
.73631 .24292 L
s
.73631 .24292 m
.73631 .24292 L
s
.73631 .24292 m
.73631 .24292 L
s
.73631 .24292 m
.73631 .24292 L
s
.73631 .24292 m
.73631 .24292 L
s
1 .004 0 r
.78225 .54525 m
.7823 .54528 L
s
.7822 .54529 m
.78225 .54525 L
s
.78225 .54525 m
.78224 .54525 L
s
.78225 .54533 m
.7822 .54529 L
s
.7822 .54529 m
.78224 .54525 L
s
.7823 .54528 m
.78225 .54533 L
s
.78224 .54525 m
.7823 .54528 L
s
.78224 .54525 m
.78225 .54533 L
s
1 .011 0 r
.56067 .49026 m
.56044 .48974 L
s
1 .034 0 r
.39881 .4622 m
.39914 .4624 L
s
.39847 .46261 m
.39881 .4622 L
s
.39881 .4622 m
.39854 .46222 L
s
.39879 .46281 m
.39847 .46261 L
s
.39847 .46261 m
.39854 .46222 L
s
0 .088 1 r
.27761 .29764 m
.23088 .32374 L
s
.24673 .24921 m
.27761 .29764 L
s
1 .011 0 r
.56049 .48974 m
.56061 .48983 L
s
.56036 .48987 m
.56049 .48974 L
s
.56049 .48974 m
.56044 .48974 L
s
1 .034 0 r
.39914 .4624 m
.39879 .46281 L
s
.39854 .46222 m
.39914 .4624 L
s
1 .011 0 r
.56049 .48995 m
.56036 .48987 L
s
.56036 .48987 m
.56044 .48974 L
s
1 .034 0 r
.39854 .46222 m
.39879 .46281 L
s
1 .011 0 r
.56061 .48983 m
.56049 .48995 L
s
.56044 .48974 m
.56061 .48983 L
s
.56044 .48974 m
.56049 .48995 L
s
1 .001 0 r
.61815 .35227 m
.61811 .35221 L
s
.61812 .35221 m
.61813 .35222 L
s
.6181 .35222 m
.61812 .35221 L
s
.61812 .35221 m
.61811 .35221 L
s
.61812 .35223 m
.6181 .35222 L
s
.6181 .35222 m
.61811 .35221 L
s
.61813 .35222 m
.61812 .35223 L
s
.61811 .35221 m
.61813 .35222 L
s
.61811 .35221 m
.61812 .35223 L
s
1 .005 0 r
.72163 .51689 m
.72158 .51666 L
s
1 0 0 r
.67565 .21421 m
.67565 .21421 L
s
.67565 .21421 m
.67565 .21421 L
s
.67565 .21421 m
.67565 .21421 L
s
.67565 .21421 m
.67565 .21421 L
s
.67565 .21421 m
.67565 .21421 L
s
.67565 .21421 m
.67565 .21421 L
s
.67565 .21421 m
.67565 .21421 L
s
.67565 .21421 m
.67565 .21421 L
s
.67565 .21421 m
.67565 .21421 L
s
1 .005 0 r
.72159 .51666 m
.72165 .5167 L
s
.72153 .51671 m
.72159 .51666 L
s
.72159 .51666 m
.72158 .51666 L
s
.72159 .51675 m
.72153 .51671 L
s
.72153 .51671 m
.72158 .51666 L
s
.72165 .5167 m
.72159 .51675 L
s
.72158 .51666 m
.72165 .5167 L
s
1 .014 0 r
.49992 .46168 m
.49951 .46104 L
s
1 .005 0 r
.72158 .51666 m
.72159 .51675 L
s
1 .663 0 r
.18286 .56917 m
.18716 .58106 L
s
1 .001 0 r
.77916 .37884 m
.77915 .3788 L
s
.77915 .3788 m
.77916 .37881 L
s
.77914 .37881 m
.77915 .3788 L
s
.77915 .3788 m
.77915 .3788 L
s
.77915 .37882 m
.77914 .37881 L
s
.77914 .37881 m
.77915 .3788 L
s
.77916 .37881 m
.77915 .37882 L
s
.77915 .3788 m
.77916 .37881 L
s
.77915 .3788 m
.77915 .37882 L
s
1 .014 0 r
.49959 .46104 m
.49974 .46113 L
s
.49944 .4612 m
.49959 .46104 L
s
.49959 .46104 m
.49951 .46104 L
s
.49959 .46129 m
.49944 .4612 L
s
.49944 .4612 m
.49951 .46104 L
s
1 .001 0 r
.55741 .32361 m
.55736 .32355 L
s
.55737 .32355 m
.55738 .32356 L
s
.55736 .32357 m
.55737 .32355 L
s
.55737 .32355 m
.55736 .32355 L
s
.55737 .32357 m
.55736 .32357 L
s
.55736 .32357 m
.55736 .32355 L
s
1 .014 0 r
.49974 .46113 m
.49959 .46129 L
s
.49951 .46104 m
.49974 .46113 L
s
1 .001 0 r
.55738 .32356 m
.55737 .32357 L
s
.55736 .32355 m
.55738 .32356 L
s
.55736 .32355 m
.55737 .32357 L
s
1 .014 0 r
.49951 .46104 m
.49959 .46129 L
s
1 .078 0 r
.38162 .57114 m
.37966 .5677 L
s
1 .006 0 r
.66093 .4883 m
.66084 .48804 L
s
.66086 .48804 m
.66092 .48808 L
s
.6608 .4881 m
.66086 .48804 L
s
.66086 .48804 m
.66084 .48804 L
s
1 .018 0 r
.4391 .43306 m
.43842 .43229 L
s
1 .006 0 r
.66086 .48814 m
.6608 .4881 L
s
.6608 .4881 m
.66084 .48804 L
s
.66092 .48808 m
.66086 .48814 L
s
.66084 .48804 m
.66092 .48808 L
s
.66084 .48804 m
.66086 .48814 L
s
1 .001 0 r
.71848 .35018 m
.71846 .35014 L
s
.71847 .35014 m
.71847 .35015 L
s
.71846 .35015 m
.71847 .35014 L
s
.71847 .35014 m
.71846 .35014 L
s
.71847 .35016 m
.71846 .35015 L
s
.71846 .35015 m
.71846 .35014 L
s
.71847 .35015 m
.71847 .35016 L
s
.71846 .35014 m
.71847 .35015 L
s
.71846 .35014 m
.71847 .35016 L
s
0 .214 1 r
.24725 .22208 m
.23208 .29356 L
s
1 .018 0 r
.43856 .43229 m
.43873 .43239 L
s
.43838 .4325 m
.43856 .43229 L
s
.43856 .43229 m
.43842 .43229 L
s
.43855 .4326 m
.43838 .4325 L
s
.43838 .4325 m
.43842 .43229 L
s
1 .116 0 r
.32073 .54257 m
.31608 .53772 L
s
1 .018 0 r
.43873 .43239 m
.43855 .4326 L
s
.43842 .43229 m
.43873 .43239 L
s
1 .003 0 r
.82207 .51495 m
.82206 .51482 L
s
1 .018 0 r
.43842 .43229 m
.43855 .4326 L
s
1 .003 0 r
.82206 .51482 m
.82209 .51484 L
s
.82203 .51485 m
.82206 .51482 L
s
.82206 .51482 m
.82206 .51482 L
s
.82206 .51487 m
.82203 .51485 L
s
.82203 .51485 m
.82206 .51482 L
s
.82209 .51484 m
.82206 .51487 L
s
.82206 .51482 m
.82209 .51484 L
s
.82206 .51482 m
.82206 .51487 L
s
1 .007 0 r
.60017 .45968 m
.60003 .45938 L
s
.60005 .45938 m
.60013 .45943 L
s
.59998 .45945 m
.60005 .45938 L
s
.60005 .45938 m
.60003 .45938 L
s
.60006 .4595 m
.59998 .45945 L
s
.59998 .45945 m
.60003 .45938 L
s
.60013 .45943 m
.60006 .4595 L
s
.60003 .45938 m
.60013 .45943 L
s
.60003 .45938 m
.60006 .4595 L
s
1 .001 0 r
.65773 .32149 m
.65772 .32146 L
s
.65772 .32146 m
.65773 .32146 L
s
.65771 .32146 m
.65772 .32146 L
s
.65772 .32146 m
.65772 .32146 L
s
.65772 .32147 m
.65771 .32146 L
s
.65771 .32146 m
.65772 .32146 L
s
.65773 .32146 m
.65772 .32147 L
s
.65772 .32146 m
.65773 .32146 L
s
.65772 .32146 m
.65772 .32147 L
s
1 .035 0 r
.48179 .56925 m
.48118 .56769 L
s
1 .003 0 r
.76137 .48633 m
.76134 .48619 L
s
.76134 .48619 m
.76138 .48621 L
s
.76131 .48622 m
.76134 .48619 L
s
.76134 .48619 m
.76134 .48619 L
s
1 0 0 r
.71533 .18322 m
.71533 .18322 L
s
.71533 .18322 m
.71533 .18322 L
s
.71533 .18322 m
.71533 .18322 L
s
.71533 .18322 m
.71533 .18322 L
s
.71533 .18322 m
.71533 .18322 L
s
.71533 .18322 m
.71533 .18322 L
s
.71533 .18322 m
.71533 .18322 L
s
.71533 .18322 m
.71533 .18322 L
s
.71533 .18322 m
.71533 .18322 L
s
1 .003 0 r
.76134 .48624 m
.76131 .48622 L
s
.76131 .48622 m
.76134 .48619 L
s
.76138 .48621 m
.76134 .48624 L
s
.76134 .48619 m
.76138 .48621 L
s
.76134 .48619 m
.76134 .48624 L
s
1 .008 0 r
.53934 .43104 m
.53912 .43069 L
s
1 .078 0 r
.38008 .56766 m
.3809 .56825 L
s
.37921 .56853 m
.38008 .56766 L
s
.38008 .56766 m
.37966 .5677 L
s
0 .124 1 r
.23183 .30771 m
.19095 .26558 L
s
.19095 .26558 m
.24745 .23414 L
s
1 .008 0 r
.53917 .43069 m
.53925 .43074 L
s
.53909 .43078 m
.53917 .43069 L
s
.53917 .43069 m
.53912 .43069 L
s
1 .078 0 r
.38002 .56912 m
.37921 .56853 L
s
.37921 .56853 m
.37966 .5677 L
s
1 .008 0 r
.53917 .43083 m
.53909 .43078 L
s
.53909 .43078 m
.53912 .43069 L
s
.53925 .43074 m
.53917 .43083 L
s
.53912 .43069 m
.53925 .43074 L
s
.53912 .43069 m
.53917 .43083 L
s
1 0 0 r
.59693 .29276 m
.59691 .29274 L
s
.59691 .29274 m
.59692 .29274 L
s
.59691 .29275 m
.59691 .29274 L
s
.59691 .29274 m
.59691 .29274 L
s
.59691 .29275 m
.59691 .29275 L
s
.59691 .29275 m
.59691 .29274 L
s
.59692 .29274 m
.59691 .29275 L
s
.59691 .29274 m
.59692 .29274 L
s
.59691 .29274 m
.59691 .29275 L
s
1 .078 0 r
.3809 .56825 m
.38002 .56912 L
s
.37966 .5677 m
.3809 .56825 L
s
1 .048 0 r
.42089 .54065 m
.41958 .5385 L
s
1 .035 0 r
.48131 .56767 m
.48169 .56795 L
s
.48092 .56805 m
.48131 .56767 L
s
.48131 .56767 m
.48118 .56769 L
s
.4813 .56832 m
.48092 .56805 L
s
.48092 .56805 m
.48118 .56769 L
s
1 .078 0 r
.37966 .5677 m
.38002 .56912 L
s
1 .035 0 r
.48169 .56795 m
.4813 .56832 L
s
.48118 .56769 m
.48169 .56795 L
s
1 .003 0 r
.7006 .45769 m
.70055 .45753 L
s
1 .035 0 r
.48118 .56769 m
.4813 .56832 L
s
1 .003 0 r
.70056 .45753 m
.7006 .45756 L
s
.70052 .45757 m
.70056 .45753 L
s
.70056 .45753 m
.70055 .45753 L
s
.70056 .45759 m
.70052 .45757 L
s
.70052 .45757 m
.70055 .45753 L
s
.7006 .45756 m
.70056 .45759 L
s
.70055 .45753 m
.7006 .45756 L
s
.70055 .45753 m
.70056 .45759 L
s
1 .009 0 r
.47846 .40237 m
.47812 .40197 L
s
1 .192 0 r
.27558 .56485 m
.27738 .56609 L
s
.27355 .5672 m
.27558 .56485 L
s
.27558 .56485 m
.27392 .56504 L
s
1 .009 0 r
.47819 .40197 m
.47828 .40202 L
s
.4781 .40208 m
.47819 .40197 L
s
.47819 .40197 m
.47812 .40197 L
s
.47819 .40213 m
.4781 .40208 L
s
.4781 .40208 m
.47812 .40197 L
s
1 0 0 r
.75825 .31936 m
.75824 .31935 L
s
.75824 .31935 m
.75824 .31935 L
s
.75824 .31935 m
.75824 .31935 L
s
.75824 .31935 m
.75824 .31935 L
s
.75824 .31935 m
.75824 .31935 L
s
.75824 .31935 m
.75824 .31935 L
s
.75824 .31935 m
.75824 .31935 L
s
.75824 .31935 m
.75824 .31935 L
s
.75824 .31935 m
.75824 .31935 L
s
1 .009 0 r
.47828 .40202 m
.47819 .40213 L
s
.47812 .40197 m
.47828 .40202 L
s
.47812 .40197 m
.47819 .40213 L
s
1 .017 0 r
.58214 .56736 m
.58194 .56659 L
s
1 .192 0 r
.27535 .56845 m
.27355 .5672 L
s
.27355 .5672 m
.27392 .56504 L
s
1 .069 0 r
.35993 .51203 m
.3572 .50912 L
s
1 .004 0 r
.63978 .42902 m
.63969 .42884 L
s
1 .116 0 r
.31707 .53761 m
.31817 .53834 L
s
.31586 .53904 m
.31707 .53761 L
s
.31707 .53761 m
.31608 .53772 L
s
1 .017 0 r
.58198 .56658 m
.58217 .56672 L
s
.58179 .56676 m
.58198 .56658 L
s
.58198 .56658 m
.58194 .56659 L
s
1 .004 0 r
.63971 .42884 m
.63975 .42887 L
s
.63967 .42888 m
.63971 .42884 L
s
.63971 .42884 m
.63969 .42884 L
s
1 .017 0 r
.58198 .5669 m
.58179 .56676 L
s
.58179 .56676 m
.58194 .56659 L
s
1 .004 0 r
.63971 .42891 m
.63967 .42888 L
s
.63967 .42888 m
.63969 .42884 L
s
1 .048 0 r
.41985 .53848 m
.42036 .53883 L
s
.41932 .53903 m
.41985 .53848 L
s
.41985 .53848 m
.41958 .5385 L
s
1 .004 0 r
.63975 .42887 m
.63971 .42891 L
s
.63969 .42884 m
.63975 .42887 L
s
.63969 .42884 m
.63971 .42891 L
s
1 .017 0 r
.58217 .56672 m
.58198 .5669 L
s
.58194 .56659 m
.58217 .56672 L
s
.58194 .56659 m
.58198 .5669 L
s
1 .116 0 r
.31695 .53977 m
.31586 .53904 L
s
.31586 .53904 m
.31608 .53772 L
s
1 .048 0 r
.41983 .53938 m
.41932 .53903 L
s
.41932 .53903 m
.41958 .5385 L
s
.42036 .53883 m
.41983 .53938 L
s
.41958 .5385 m
.42036 .53883 L
s
1 0 0 r
.69743 .29061 m
.69743 .2906 L
s
.69743 .2906 m
.69743 .2906 L
s
.69743 .2906 m
.69743 .2906 L
s
.69743 .2906 m
.69743 .2906 L
s
.69743 .2906 m
.69743 .2906 L
s
.69743 .2906 m
.69743 .2906 L
s
.69743 .2906 m
.69743 .2906 L
s
.69743 .2906 m
.69743 .2906 L
s
.69743 .2906 m
.69743 .2906 L
s
1 .022 0 r
.52124 .53873 m
.52082 .53773 L
s
1 .048 0 r
.41958 .5385 m
.41983 .53938 L
s
1 .192 0 r
.27738 .56609 m
.27535 .56845 L
s
.27392 .56504 m
.27738 .56609 L
s
1 .002 0 r
.80122 .45569 m
.8012 .4556 L
s
.80121 .4556 m
.80123 .45562 L
s
.80119 .45562 m
.80121 .4556 L
s
.80121 .4556 m
.8012 .4556 L
s
.80121 .45563 m
.80119 .45562 L
s
.80119 .45562 m
.8012 .4556 L
s
.80123 .45562 m
.80121 .45563 L
s
.8012 .4556 m
.80123 .45562 L
s
.8012 .4556 m
.80121 .45563 L
s
1 .116 0 r
.31817 .53834 m
.31695 .53977 L
s
.31608 .53772 m
.31817 .53834 L
s
1 .004 0 r
.57889 .40031 m
.57877 .40013 L
s
1 .192 0 r
.27392 .56504 m
.27535 .56845 L
s
1 .004 0 r
.57879 .40013 m
.57883 .40015 L
s
.57875 .40018 m
.57879 .40013 L
s
.57879 .40013 m
.57877 .40013 L
s
1 .116 0 r
.31608 .53772 m
.31695 .53977 L
s
1 .004 0 r
.57879 .4002 m
.57875 .40018 L
s
.57875 .40018 m
.57877 .40013 L
s
.57883 .40015 m
.57879 .4002 L
s
.57877 .40013 m
.57883 .40015 L
s
.57877 .40013 m
.57879 .4002 L
s
1 .022 0 r
.5209 .53773 m
.52114 .5379 L
s
.52066 .53797 m
.5209 .53773 L
s
.5209 .53773 m
.52082 .53773 L
s
.5209 .53814 m
.52066 .53797 L
s
.52066 .53797 m
.52082 .53773 L
s
.52114 .5379 m
.5209 .53814 L
s
.52082 .53773 m
.52114 .5379 L
s
1 .009 0 r
.68268 .56546 m
.68261 .56505 L
s
1 .022 0 r
.52082 .53773 m
.5209 .53814 L
s
1 0 0 r
.63656 .26183 m
.63655 .26182 L
s
.63656 .26182 m
.63656 .26183 L
s
.63655 .26183 m
.63656 .26182 L
s
.63656 .26182 m
.63655 .26182 L
s
.63656 .26183 m
.63655 .26183 L
s
.63655 .26183 m
.63655 .26182 L
s
.63656 .26183 m
.63656 .26183 L
s
.63655 .26182 m
.63656 .26183 L
s
.63655 .26182 m
.63656 .26183 L
s
1 .029 0 r
.46027 .51008 m
.45945 .50877 L
s
1 .069 0 r
.35777 .50907 m
.35843 .50949 L
s
.35706 .50991 m
.35777 .50907 L
s
.35777 .50907 m
.3572 .50912 L
s
1 .009 0 r
.68262 .56505 m
.68273 .56512 L
s
.68252 .56514 m
.68262 .56505 L
s
.68262 .56505 m
.68261 .56505 L
s
.68263 .56521 m
.68252 .56514 L
s
.68252 .56514 m
.68261 .56505 L
s
.68273 .56512 m
.68263 .56521 L
s
.68261 .56505 m
.68273 .56512 L
s
1 .069 0 r
.35772 .51034 m
.35706 .50991 L
s
.35706 .50991 m
.3572 .50912 L
s
1 .009 0 r
.68261 .56505 m
.68263 .56521 L
s
1 .002 0 r
.74039 .42699 m
.74036 .4269 L
s
.74037 .4269 m
.74039 .42691 L
s
.74034 .42692 m
.74037 .4269 L
s
.74037 .4269 m
.74036 .4269 L
s
.74037 .42693 m
.74034 .42692 L
s
.74034 .42692 m
.74036 .4269 L
s
.74039 .42691 m
.74037 .42693 L
s
.74036 .4269 m
.74039 .42691 L
s
.74036 .4269 m
.74037 .42693 L
s
1 .004 0 r
.51793 .37158 m
.51777 .37139 L
s
1 .069 0 r
.35843 .50949 m
.35772 .51034 L
s
.3572 .50912 m
.35843 .50949 L
s
1 .004 0 r
.51781 .37139 m
.51785 .37141 L
s
.51776 .37144 m
.51781 .37139 L
s
.51781 .37139 m
.51777 .37139 L
s
.51781 .37147 m
.51776 .37144 L
s
.51776 .37144 m
.51777 .37139 L
s
.51785 .37141 m
.51781 .37147 L
s
.51777 .37139 m
.51785 .37141 L
s
.51777 .37139 m
.51781 .37147 L
s
1 .069 0 r
.3572 .50912 m
.35772 .51034 L
s
0 .06 1 r
.23408 .28766 m
.27596 .3307 L
s
.18626 .31392 m
.23408 .28766 L
s
.23408 .28766 m
.24452 .28214 L
s
1 .011 0 r
.62177 .53681 m
.62162 .5363 L
s
1 .029 0 r
.45962 .50876 m
.45993 .50896 L
s
.4593 .50909 m
.45962 .50876 L
s
.45962 .50876 m
.45945 .50877 L
s
.45961 .5093 m
.4593 .50909 L
s
.4593 .50909 m
.45945 .50877 L
s
1 .039 0 r
.39924 .4814 m
.3977 .47971 L
s
1 .029 0 r
.45993 .50896 m
.45961 .5093 L
s
.45945 .50877 m
.45993 .50896 L
s
.45945 .50877 m
.45961 .5093 L
s
1 .011 0 r
.62165 .5363 m
.62178 .53639 L
s
.62153 .53642 m
.62165 .5363 L
s
.62165 .5363 m
.62162 .5363 L
s
.62166 .53651 m
.62153 .53642 L
s
.62153 .53642 m
.62162 .5363 L
s
.62178 .53639 m
.62166 .53651 L
s
.62162 .5363 m
.62178 .53639 L
s
.62162 .5363 m
.62166 .53651 L
s
1 .002 0 r
.6795 .39826 m
.67945 .39816 L
s
.67946 .39816 m
.67948 .39818 L
s
.67944 .39819 m
.67946 .39816 L
s
.67946 .39816 m
.67945 .39816 L
s
.67946 .3982 m
.67944 .39819 L
s
.67944 .39819 m
.67945 .39816 L
s
.67948 .39818 m
.67946 .3982 L
s
.67945 .39816 m
.67948 .39818 L
s
.67945 .39816 m
.67946 .3982 L
s
1 .005 0 r
.78341 .56356 m
.78339 .56332 L
s
1 0 0 r
.73725 .25965 m
.73725 .25964 L
s
.73725 .25964 m
.73725 .25964 L
s
.73725 .25965 m
.73725 .25964 L
s
.73725 .25964 m
.73725 .25964 L
s
.73725 .25965 m
.73725 .25965 L
s
.73725 .25965 m
.73725 .25964 L
s
.73725 .25964 m
.73725 .25965 L
s
.73725 .25964 m
.73725 .25964 L
s
.73725 .25964 m
.73725 .25965 L
s
1 .005 0 r
.78339 .56332 m
.78345 .56337 L
s
.78333 .56337 m
.78339 .56332 L
s
.78339 .56332 m
.78339 .56332 L
s
.7834 .56342 m
.78333 .56337 L
s
.78333 .56337 m
.78339 .56332 L
s
.78345 .56337 m
.7834 .56342 L
s
.78339 .56332 m
.78345 .56337 L
s
1 .014 0 r
.5608 .50812 m
.56052 .5075 L
s
1 .005 0 r
.78339 .56332 m
.7834 .56342 L
s
1 .039 0 r
.39802 .47968 m
.3984 .47992 L
s
.39761 .48017 m
.39802 .47968 L
s
.39802 .47968 m
.3977 .47971 L
s
.39799 .48041 m
.39761 .48017 L
s
.39761 .48017 m
.3977 .47971 L
s
1 .014 0 r
.56058 .5075 m
.56073 .5076 L
s
.56043 .50765 m
.56058 .5075 L
s
.56058 .5075 m
.56052 .5075 L
s
.56058 .50775 m
.56043 .50765 L
s
.56043 .50765 m
.56052 .5075 L
s
1 .002 0 r
.61854 .3695 m
.61848 .36941 L
s
1 .014 0 r
.56073 .5076 m
.56058 .50775 L
s
.56052 .5075 m
.56073 .5076 L
s
1 .002 0 r
.61849 .36941 m
.61852 .36942 L
s
.61847 .36943 m
.61849 .36941 L
s
.61849 .36941 m
.61848 .36941 L
s
.61849 .36944 m
.61847 .36943 L
s
.61847 .36943 m
.61848 .36941 L
s
1 .014 0 r
.56052 .5075 m
.56058 .50775 L
s
1 .002 0 r
.61852 .36942 m
.61849 .36944 L
s
.61848 .36941 m
.61852 .36942 L
s
.61848 .36941 m
.61849 .36944 L
s
1 .039 0 r
.3984 .47992 m
.39799 .48041 L
s
.3977 .47971 m
.3984 .47992 L
s
.3977 .47971 m
.39799 .48041 L
s
0 .07 1 r
.27689 .31394 m
.2297 .34051 L
s
.2457 .26539 m
.27689 .31394 L
s
1 .006 0 r
.72249 .53488 m
.72244 .5346 L
s
1 0 0 r
.67631 .23081 m
.67631 .23081 L
s
.67631 .23081 m
.67631 .23081 L
s
.67631 .23081 m
.67631 .23081 L
s
.67631 .23081 m
.67631 .23081 L
s
.67631 .23081 m
.67631 .23081 L
s
.67631 .23081 m
.67631 .23081 L
s
.67631 .23081 m
.67631 .23081 L
s
.67631 .23081 m
.67631 .23081 L
s
.67631 .23081 m
.67631 .23081 L
s
1 .006 0 r
.72245 .5346 m
.72252 .53465 L
s
.72238 .53467 m
.72245 .5346 L
s
.72245 .5346 m
.72244 .5346 L
s
1 .017 0 r
.49977 .47941 m
.49927 .47864 L
s
1 .006 0 r
.72245 .53471 m
.72238 .53467 L
s
.72238 .53467 m
.72244 .5346 L
s
.72252 .53465 m
.72245 .53471 L
s
.72244 .5346 m
.72252 .53465 L
s
.72244 .5346 m
.72245 .53471 L
s
1 .001 0 r
.7803 .3962 m
.78028 .39615 L
s
.78028 .39615 m
.78029 .39616 L
s
.78027 .39616 m
.78028 .39615 L
s
.78028 .39615 m
.78028 .39615 L
s
.78028 .39617 m
.78027 .39616 L
s
.78027 .39616 m
.78028 .39615 L
s
.78029 .39616 m
.78028 .39617 L
s
.78028 .39615 m
.78029 .39616 L
s
.78028 .39615 m
.78028 .39617 L
s
1 .002 0 r
.55752 .34071 m
.55745 .34062 L
s
1 .017 0 r
.49937 .47864 m
.49956 .47875 L
s
.49919 .47884 m
.49937 .47864 L
s
.49937 .47864 m
.49927 .47864 L
s
1 .002 0 r
.55746 .34062 m
.55748 .34063 L
s
.55744 .34065 m
.55746 .34062 L
s
.55746 .34062 m
.55745 .34062 L
s
.55746 .34066 m
.55744 .34065 L
s
.55744 .34065 m
.55745 .34062 L
s
.55748 .34063 m
.55746 .34066 L
s
.55745 .34062 m
.55748 .34063 L
s
.55745 .34062 m
.55746 .34066 L
s
1 .017 0 r
.49937 .47895 m
.49919 .47884 L
s
.49919 .47884 m
.49927 .47864 L
s
.49956 .47875 m
.49937 .47895 L
s
.49927 .47864 m
.49956 .47875 L
s
.49927 .47864 m
.49937 .47895 L
s
1 .007 0 r
.66152 .50617 m
.66142 .50585 L
s
1 .022 0 r
.43867 .45067 m
.43783 .44973 L
s
1 .007 0 r
.66143 .50585 m
.66151 .5059 L
s
.66136 .50592 m
.66143 .50585 L
s
.66143 .50585 m
.66142 .50585 L
s
.66144 .50597 m
.66136 .50592 L
s
.66136 .50592 m
.66142 .50585 L
s
.66151 .5059 m
.66144 .50597 L
s
.66142 .50585 m
.66151 .5059 L
s
.66142 .50585 m
.66144 .50597 L
s
1 .001 0 r
.71933 .36741 m
.71931 .36736 L
s
.71931 .36736 m
.71933 .36737 L
s
.7193 .36738 m
.71931 .36736 L
s
.71931 .36736 m
.71931 .36736 L
s
.71932 .36738 m
.7193 .36738 L
s
.7193 .36738 m
.71931 .36736 L
s
.71933 .36737 m
.71932 .36738 L
s
.71931 .36736 m
.71933 .36737 L
s
.71931 .36736 m
.71932 .36738 L
s
1 .123 0 r
.31975 .5607 m
.3148 .55557 L
s
1 .022 0 r
.438 .44972 m
.43821 .44985 L
s
.43778 .44999 m
.438 .44972 L
s
.438 .44972 m
.43783 .44973 L
s
.43799 .45012 m
.43778 .44999 L
s
.43778 .44999 m
.43783 .44973 L
s
1 .003 0 r
.8234 .53294 m
.82339 .53279 L
s
.82339 .53279 m
.82343 .53281 L
s
.82335 .53282 m
.82339 .53279 L
s
.82339 .53279 m
.82339 .53279 L
s
1 .022 0 r
.43821 .44985 m
.43799 .45012 L
s
.43783 .44973 m
.43821 .44985 L
s
1 .003 0 r
.82339 .53285 m
.82335 .53282 L
s
.82335 .53282 m
.82339 .53279 L
s
.82343 .53281 m
.82339 .53285 L
s
.82339 .53279 m
.82343 .53281 L
s
.82339 .53279 m
.82339 .53285 L
s
1 .022 0 r
.43783 .44973 m
.43799 .45012 L
s
1 .008 0 r
.60048 .47743 m
.6003 .47705 L
s
.60034 .47705 m
.60043 .47711 L
s
.60025 .47714 m
.60034 .47705 L
s
.60034 .47705 m
.6003 .47705 L
s
.60034 .4772 m
.60025 .47714 L
s
.60025 .47714 m
.6003 .47705 L
s
.60043 .47711 m
.60034 .4772 L
s
.6003 .47705 m
.60043 .47711 L
s
.6003 .47705 m
.60034 .4772 L
s
1 .001 0 r
.65831 .3386 m
.65828 .33855 L
s
.65829 .33855 m
.6583 .33856 L
s
.65828 .33856 m
.65829 .33855 L
s
.65829 .33855 m
.65828 .33855 L
s
.65829 .33857 m
.65828 .33856 L
s
.65828 .33856 m
.65828 .33855 L
s
.6583 .33856 m
.65829 .33857 L
s
.65828 .33855 m
.6583 .33856 L
s
.65828 .33855 m
.65829 .33857 L
s
1 .004 0 r
.76242 .50421 m
.76238 .50403 L
s
1 0 0 r
.71617 .1997 m
.71617 .1997 L
s
.71617 .1997 m
.71617 .1997 L
s
.71617 .1997 m
.71617 .1997 L
s
.71617 .1997 m
.71617 .1997 L
s
.71617 .1997 m
.71617 .1997 L
s
.71617 .1997 m
.71617 .1997 L
s
.71617 .1997 m
.71617 .1997 L
s
.71617 .1997 m
.71617 .1997 L
s
.71617 .1997 m
.71617 .1997 L
s
1 .004 0 r
.76239 .50403 m
.76243 .50406 L
s
.76235 .50407 m
.76239 .50403 L
s
.76239 .50403 m
.76238 .50403 L
s
.76239 .5041 m
.76235 .50407 L
s
.76235 .50407 m
.76238 .50403 L
s
.76243 .50406 m
.76239 .5041 L
s
.76238 .50403 m
.76243 .50406 L
s
.76238 .50403 m
.76239 .5041 L
s
1 .01 0 r
.53938 .44866 m
.53909 .44822 L
s
.53915 .44822 m
.53925 .44828 L
s
.53904 .44833 m
.53915 .44822 L
s
.53915 .44822 m
.53909 .44822 L
s
.53915 .44839 m
.53904 .44833 L
s
.53904 .44833 m
.53909 .44822 L
s
.53925 .44828 m
.53915 .44839 L
s
.53909 .44822 m
.53925 .44828 L
s
.53909 .44822 m
.53915 .44839 L
s
1 .001 0 r
.59722 .30975 m
.59719 .30971 L
s
.5972 .30971 m
.59721 .30972 L
s
.59719 .30972 m
.5972 .30971 L
s
.5972 .30971 m
.59719 .30971 L
s
.5972 .30973 m
.59719 .30972 L
s
.59719 .30972 m
.59719 .30971 L
s
.59721 .30972 m
.5972 .30973 L
s
.59719 .30971 m
.59721 .30972 L
s
.59719 .30971 m
.5972 .30973 L
s
1 .053 0 r
.42038 .55879 m
.41892 .55641 L
s
1 .004 0 r
.70138 .47544 m
.70131 .47524 L
s
.70132 .47524 m
.70137 .47527 L
s
.70128 .47529 m
.70132 .47524 L
s
.70132 .47524 m
.70131 .47524 L
s
.70132 .47532 m
.70128 .47529 L
s
.70128 .47529 m
.70131 .47524 L
s
.70137 .47527 m
.70132 .47532 L
s
.70131 .47524 m
.70137 .47527 L
s
.70131 .47524 m
.70132 .47532 L
s
1 .012 0 r
.47821 .41986 m
.47777 .41935 L
s
1 .001 0 r
.75929 .33648 m
.75927 .33645 L
s
.75928 .33645 m
.75928 .33646 L
s
.75927 .33646 m
.75928 .33645 L
s
.75928 .33645 m
.75927 .33645 L
s
.75928 .33646 m
.75927 .33646 L
s
.75927 .33646 m
.75927 .33645 L
s
.75928 .33646 m
.75928 .33646 L
s
.75927 .33645 m
.75928 .33646 L
s
.75927 .33645 m
.75928 .33646 L
s
1 .012 0 r
.47786 .41935 m
.47797 .41942 L
s
.47774 .41949 m
.47786 .41935 L
s
.47786 .41935 m
.47777 .41935 L
s
.47786 .41956 m
.47774 .41949 L
s
.47774 .41949 m
.47777 .41935 L
s
.47797 .41942 m
.47786 .41956 L
s
.47777 .41935 m
.47797 .41942 L
s
.47777 .41935 m
.47786 .41956 L
s
0 .088 1 r
.23088 .32374 m
.18942 .2809 L
s
.18942 .2809 m
.24673 .24921 L
s
1 .075 0 r
.35913 .53004 m
.35612 .52686 L
s
1 .005 0 r
.64027 .44665 m
.64016 .44642 L
s
.64018 .44642 m
.64024 .44646 L
s
.64013 .44648 m
.64018 .44642 L
s
.64018 .44642 m
.64016 .44642 L
s
.64019 .44651 m
.64013 .44648 L
s
.64013 .44648 m
.64016 .44642 L
s
.64024 .44646 m
.64019 .44651 L
s
.64016 .44642 m
.64024 .44646 L
s
.64016 .44642 m
.64019 .44651 L
s
1 .123 0 r
.31586 .55544 m
.31702 .55623 L
s
.31456 .55696 m
.31586 .55544 L
s
.31586 .55544 m
.3148 .55557 L
s
1 .053 0 r
.41923 .55639 m
.41979 .55678 L
s
.41863 .557 m
.41923 .55639 L
s
.41923 .55639 m
.41892 .55641 L
s
0 .124 1 r
.24745 .23414 m
.23183 .30771 L
s
1 .053 0 r
.4192 .55739 m
.41863 .557 L
s
.41863 .557 m
.41892 .55641 L
s
1 .123 0 r
.31573 .55775 m
.31456 .55696 L
s
.31456 .55696 m
.3148 .55557 L
s
1 0 0 r
.69819 .30761 m
.69818 .30759 L
s
.69818 .30759 m
.69819 .30759 L
s
.69818 .30759 m
.69818 .30759 L
s
.69818 .30759 m
.69818 .30759 L
s
.69818 .30759 m
.69818 .30759 L
s
.69818 .30759 m
.69818 .30759 L
s
.69819 .30759 m
.69818 .30759 L
s
.69818 .30759 m
.69819 .30759 L
s
.69818 .30759 m
.69818 .30759 L
s
1 .025 0 r
.52119 .55687 m
.5207 .55573 L
s
1 .053 0 r
.41979 .55678 m
.4192 .55739 L
s
.41892 .55641 m
.41979 .55678 L
s
.41892 .55641 m
.4192 .55739 L
s
1 .002 0 r
.80246 .47345 m
.80244 .47334 L
s
.80244 .47334 m
.80247 .47335 L
s
.80241 .47336 m
.80244 .47334 L
s
.80244 .47334 m
.80244 .47334 L
s
.80244 .47338 m
.80241 .47336 L
s
.80241 .47336 m
.80244 .47334 L
s
.80247 .47335 m
.80244 .47338 L
s
.80244 .47334 m
.80247 .47335 L
s
.80244 .47334 m
.80244 .47338 L
s
1 .005 0 r
.5791 .41782 m
.57894 .41757 L
s
1 .123 0 r
.31702 .55623 m
.31573 .55775 L
s
.3148 .55557 m
.31702 .55623 L
s
1 .005 0 r
.57897 .41757 m
.57903 .41761 L
s
.57892 .41764 m
.57897 .41757 L
s
.57897 .41757 m
.57894 .41757 L
s
.57897 .41767 m
.57892 .41764 L
s
.57892 .41764 m
.57894 .41757 L
s
.57903 .41761 m
.57897 .41767 L
s
.57894 .41757 m
.57903 .41761 L
s
.57894 .41757 m
.57897 .41767 L
s
1 .025 0 r
.5208 .55573 m
.52108 .55592 L
s
.52052 .556 m
.5208 .55573 L
s
.5208 .55573 m
.5207 .55573 L
s
.5208 .5562 m
.52052 .556 L
s
.52052 .556 m
.5207 .55573 L
s
1 .123 0 r
.3148 .55557 m
.31573 .55775 L
s
1 .025 0 r
.52108 .55592 m
.5208 .5562 L
s
.5207 .55573 m
.52108 .55592 L
s
1 0 0 r
.63704 .2787 m
.63703 .27869 L
s
.63703 .27869 m
.63703 .27869 L
s
.63703 .27869 m
.63703 .27869 L
s
.63703 .27869 m
.63703 .27869 L
s
.63703 .27869 m
.63703 .27869 L
s
.63703 .27869 m
.63703 .27869 L
s
.63703 .27869 m
.63703 .27869 L
s
.63703 .27869 m
.63703 .27869 L
s
.63703 .27869 m
.63703 .27869 L
s
1 .025 0 r
.5207 .55573 m
.5208 .5562 L
s
1 .033 0 r
.45994 .5281 m
.45899 .5266 L
s
1 .075 0 r
.35676 .52679 m
.35748 .52726 L
s
.35597 .52772 m
.35676 .52679 L
s
.35676 .52679 m
.35612 .52686 L
s
1 .003 0 r
.74135 .44463 m
.74131 .4445 L
s
1 .075 0 r
.35669 .5282 m
.35597 .52772 L
s
.35597 .52772 m
.35612 .52686 L
s
1 .003 0 r
.74132 .4445 m
.74135 .44452 L
s
.74129 .44453 m
.74132 .4445 L
s
.74132 .4445 m
.74131 .4445 L
s
.74132 .44455 m
.74129 .44453 L
s
.74129 .44453 m
.74131 .4445 L
s
.74135 .44452 m
.74132 .44455 L
s
.74131 .4445 m
.74135 .44452 L
s
.74131 .4445 m
.74132 .44455 L
s
1 .006 0 r
.51787 .38897 m
.51764 .3887 L
s
.51769 .3887 m
.51775 .38873 L
s
.51763 .38877 m
.51769 .3887 L
s
.51769 .3887 m
.51764 .3887 L
s
.51769 .38881 m
.51763 .38877 L
s
.51763 .38877 m
.51764 .3887 L
s
.51775 .38873 m
.51769 .38881 L
s
.51764 .3887 m
.51775 .38873 L
s
.51764 .3887 m
.51769 .38881 L
s
1 .075 0 r
.35748 .52726 m
.35669 .5282 L
s
.35612 .52686 m
.35748 .52726 L
s
1 .013 0 r
.62219 .55495 m
.62201 .55437 L
s
0 .053 1 r
.23279 .30435 m
.27493 .34776 L
s
.18464 .331 m
.23279 .30435 L
s
.23279 .30435 m
.24326 .29925 L
s
1 .075 0 r
.35612 .52686 m
.35669 .5282 L
s
1 .033 0 r
.45919 .52659 m
.45954 .52683 L
s
.45882 .52698 m
.45919 .52659 L
s
.45919 .52659 m
.45899 .5266 L
s
1 .045 0 r
.39863 .49929 m
.39685 .49737 L
s
1 .033 0 r
.45918 .52721 m
.45882 .52698 L
s
.45882 .52698 m
.45899 .5266 L
s
.45954 .52683 m
.45918 .52721 L
s
.45899 .5266 m
.45954 .52683 L
s
1 .013 0 r
.62204 .55437 m
.62219 .55447 L
s
.6219 .5545 m
.62204 .55437 L
s
.62204 .55437 m
.62201 .55437 L
s
.62205 .55461 m
.6219 .5545 L
s
.6219 .5545 m
.62201 .55437 L
s
1 .033 0 r
.45899 .5266 m
.45918 .52721 L
s
1 .013 0 r
.62219 .55447 m
.62205 .55461 L
s
.62201 .55437 m
.62219 .55447 L
s
1 .003 0 r
.68018 .41577 m
.68011 .41564 L
s
1 .013 0 r
.62201 .55437 m
.62205 .55461 L
s
1 .003 0 r
.68013 .41564 m
.68016 .41566 L
s
.6801 .41567 m
.68013 .41564 L
s
.68013 .41564 m
.68011 .41564 L
s
.68013 .41569 m
.6801 .41567 L
s
.6801 .41567 m
.68011 .41564 L
s
.68016 .41566 m
.68013 .41569 L
s
.68011 .41564 m
.68016 .41566 L
s
.68011 .41564 m
.68013 .41569 L
s
1 0 0 r
.73819 .27653 m
.73819 .27652 L
s
.73819 .27652 m
.73819 .27652 L
s
.73819 .27652 m
.73819 .27652 L
s
.73819 .27652 m
.73819 .27652 L
s
.73819 .27652 m
.73819 .27652 L
s
.73819 .27652 m
.73819 .27652 L
s
.73819 .27652 m
.73819 .27652 L
s
.73819 .27652 m
.73819 .27652 L
s
.73819 .27652 m
.73819 .27652 L
s
1 .016 0 r
.56093 .52615 m
.5606 .52542 L
s
1 .045 0 r
.39722 .49733 m
.39766 .49761 L
s
.39675 .49789 m
.39722 .49733 L
s
.39722 .49733 m
.39685 .49737 L
s
1 .003 0 r
.61894 .38689 m
.61885 .38676 L
s
1 .045 0 r
.39719 .49817 m
.39675 .49789 L
s
.39675 .49789 m
.39685 .49737 L
s
1 .016 0 r
.56067 .52542 m
.56085 .52554 L
s
.56049 .52559 m
.56067 .52542 L
s
.56067 .52542 m
.5606 .52542 L
s
.56067 .52571 m
.56049 .52559 L
s
.56049 .52559 m
.5606 .52542 L
s
1 .003 0 r
.61887 .38676 m
.6189 .38677 L
s
.61884 .38679 m
.61887 .38676 L
s
.61887 .38676 m
.61885 .38676 L
s
.61887 .38681 m
.61884 .38679 L
s
.61884 .38679 m
.61885 .38676 L
s
.6189 .38677 m
.61887 .38681 L
s
.61885 .38676 m
.6189 .38677 L
s
.61885 .38676 m
.61887 .38681 L
s
1 .016 0 r
.56085 .52554 m
.56067 .52571 L
s
.5606 .52542 m
.56085 .52554 L
s
.5606 .52542 m
.56067 .52571 L
s
1 .045 0 r
.39766 .49761 m
.39719 .49817 L
s
.39685 .49737 m
.39766 .49761 L
s
.39685 .49737 m
.39719 .49817 L
s
1 .007 0 r
.72337 .55303 m
.72331 .55271 L
s
1 0 0 r
.67697 .24756 m
.67697 .24756 L
s
.67697 .24756 m
.67697 .24756 L
s
.67697 .24756 m
.67697 .24756 L
s
.67697 .24756 m
.67697 .24756 L
s
.67697 .24756 m
.67697 .24756 L
s
.67697 .24756 m
.67697 .24756 L
s
.67697 .24756 m
.67697 .24756 L
s
.67697 .24756 m
.67697 .24756 L
s
.67697 .24756 m
.67697 .24756 L
s
1 .02 0 r
.49962 .49732 m
.49903 .4964 L
s
1 .007 0 r
.72332 .55271 m
.7234 .55277 L
s
.72324 .55278 m
.72332 .55271 L
s
.72332 .55271 m
.72331 .55271 L
s
0 .06 1 r
.27596 .3307 m
.22841 .35768 L
s
.24452 .28214 m
.27596 .3307 L
s
1 .007 0 r
.72332 .55284 m
.72324 .55278 L
s
.72324 .55278 m
.72331 .55271 L
s
.7234 .55277 m
.72332 .55284 L
s
.72331 .55271 m
.7234 .55277 L
s
.72331 .55271 m
.72332 .55284 L
s
1 .002 0 r
.78144 .41372 m
.78142 .41365 L
s
.78142 .41365 m
.78144 .41366 L
s
.7814 .41367 m
.78142 .41365 L
s
.78142 .41365 m
.78142 .41365 L
s
.78142 .41368 m
.7814 .41367 L
s
.7814 .41367 m
.78142 .41365 L
s
.78144 .41366 m
.78142 .41368 L
s
.78142 .41365 m
.78144 .41366 L
s
.78142 .41365 m
.78142 .41368 L
s
1 .003 0 r
.55764 .35798 m
.55753 .35784 L
s
.55755 .35784 m
.55758 .35786 L
s
.55752 .35788 m
.55755 .35784 L
s
.55755 .35784 m
.55753 .35784 L
s
.55755 .3579 m
.55752 .35788 L
s
.55752 .35788 m
.55753 .35784 L
s
.55758 .35786 m
.55755 .3579 L
s
.55753 .35784 m
.55758 .35786 L
s
.55753 .35784 m
.55755 .3579 L
s
1 .02 0 r
.49915 .4964 m
.49936 .49654 L
s
.49893 .49663 m
.49915 .4964 L
s
.49915 .4964 m
.49903 .4964 L
s
.49914 .49677 m
.49893 .49663 L
s
.49893 .49663 m
.49903 .4964 L
s
.49936 .49654 m
.49914 .49677 L
s
.49903 .4964 m
.49936 .49654 L
s
.49903 .4964 m
.49914 .49677 L
s
1 .008 0 r
.66211 .5242 m
.66199 .52382 L
s
1 .026 0 r
.43824 .46845 m
.43722 .46733 L
s
1 .008 0 r
.66201 .52382 m
.66211 .52388 L
s
.66192 .52391 m
.66201 .52382 L
s
.66201 .52382 m
.66199 .52382 L
s
.66202 .52397 m
.66192 .52391 L
s
.66192 .52391 m
.66199 .52382 L
s
.66211 .52388 m
.66202 .52397 L
s
.66199 .52382 m
.66211 .52388 L
s
.66199 .52382 m
.66202 .52397 L
s
1 .002 0 r
.7202 .38481 m
.72016 .38474 L
s
.72017 .38474 m
.72019 .38475 L
s
.72015 .38476 m
.72017 .38474 L
s
.72017 .38474 m
.72016 .38474 L
s
.72017 .38477 m
.72015 .38476 L
s
.72015 .38476 m
.72016 .38474 L
s
.72019 .38475 m
.72017 .38477 L
s
.72016 .38474 m
.72019 .38475 L
s
.72016 .38474 m
.72017 .38477 L
s
1 .004 0 r
.82475 .55111 m
.82473 .55092 L
s
1 .026 0 r
.43743 .46731 m
.43769 .46747 L
s
.43716 .46763 m
.43743 .46731 L
s
.43743 .46731 m
.43722 .46733 L
s
.43742 .46779 m
.43716 .46763 L
s
.43716 .46763 m
.43722 .46733 L
s
1 .004 0 r
.82473 .55092 m
.82478 .55095 L
s
.82468 .55096 m
.82473 .55092 L
s
.82473 .55092 m
.82473 .55092 L
s
.82473 .551 m
.82468 .55096 L
s
.82468 .55096 m
.82473 .55092 L
s
.82478 .55095 m
.82473 .551 L
s
.82473 .55092 m
.82478 .55095 L
s
.82473 .55092 m
.82473 .551 L
s
1 .01 0 r
.60079 .49534 m
.60058 .49488 L
s
1 .026 0 r
.43769 .46747 m
.43742 .46779 L
s
.43722 .46733 m
.43769 .46747 L
s
.43722 .46733 m
.43742 .46779 L
s
1 .01 0 r
.60062 .49488 m
.60073 .49495 L
s
.60051 .49499 m
.60062 .49488 L
s
.60062 .49488 m
.60058 .49488 L
s
.60062 .49506 m
.60051 .49499 L
s
.60051 .49499 m
.60058 .49488 L
s
.60073 .49495 m
.60062 .49506 L
s
.60058 .49488 m
.60073 .49495 L
s
.60058 .49488 m
.60062 .49506 L
s
1 .001 0 r
.65889 .35587 m
.65885 .3558 L
s
.65886 .3558 m
.65887 .35581 L
s
.65884 .35582 m
.65886 .3558 L
s
.65886 .3558 m
.65885 .3558 L
s
.65886 .35583 m
.65884 .35582 L
s
.65884 .35582 m
.65885 .3558 L
s
.65887 .35581 m
.65886 .35583 L
s
.65885 .3558 m
.65887 .35581 L
s
.65885 .3558 m
.65886 .35583 L
s
1 .005 0 r
.76348 .52225 m
.76344 .52203 L
s
1 0 0 r
.71702 .21633 m
.71702 .21633 L
s
.71702 .21633 m
.71702 .21633 L
s
.71702 .21633 m
.71702 .21633 L
s
.71702 .21633 m
.71702 .21633 L
s
.71702 .21633 m
.71702 .21633 L
s
.71702 .21633 m
.71702 .21633 L
s
.71702 .21633 m
.71702 .21633 L
s
.71702 .21633 m
.71702 .21633 L
s
.71702 .21633 m
.71702 .21633 L
s
1 .005 0 r
.76344 .52203 m
.7635 .52207 L
s
.76339 .52208 m
.76344 .52203 L
s
.76344 .52203 m
.76344 .52203 L
s
.76345 .52212 m
.76339 .52208 L
s
.76339 .52208 m
.76344 .52203 L
s
.7635 .52207 m
.76345 .52212 L
s
.76344 .52203 m
.7635 .52207 L
s
.76344 .52203 m
.76345 .52212 L
s
1 .012 0 r
.53941 .46645 m
.53906 .4659 L
s
.53913 .4659 m
.53926 .46598 L
s
.539 .46604 m
.53913 .4659 L
s
.53913 .4659 m
.53906 .4659 L
s
.53913 .46612 m
.539 .46604 L
s
.539 .46604 m
.53906 .4659 L
s
.53926 .46598 m
.53913 .46612 L
s
.53906 .4659 m
.53926 .46598 L
s
.53906 .4659 m
.53913 .46612 L
s
1 .001 0 r
.59752 .3269 m
.59747 .32684 L
s
.59748 .32684 m
.5975 .32684 L
s
.59747 .32685 m
.59748 .32684 L
s
.59748 .32684 m
.59747 .32684 L
s
.59748 .32686 m
.59747 .32685 L
s
.59747 .32685 m
.59747 .32684 L
s
.5975 .32684 m
.59748 .32686 L
s
.59747 .32684 m
.5975 .32684 L
s
.59747 .32684 m
.59748 .32686 L
s
1 .005 0 r
.70216 .49336 m
.70208 .49311 L
s
.70209 .49311 m
.70215 .49315 L
s
.70203 .49317 m
.70209 .49311 L
s
.70209 .49311 m
.70208 .49311 L
s
.70209 .49321 m
.70203 .49317 L
s
.70203 .49317 m
.70208 .49311 L
s
1 .015 0 r
.47796 .43753 m
.4774 .43689 L
s
1 .005 0 r
.70215 .49315 m
.70209 .49321 L
s
.70208 .49311 m
.70215 .49315 L
s
.70208 .49311 m
.70209 .49321 L
s
1 .001 0 r
.76034 .35376 m
.76032 .35372 L
s
.76032 .35372 m
.76033 .35372 L
s
.76031 .35373 m
.76032 .35372 L
s
.76032 .35372 m
.76032 .35372 L
s
.76032 .35373 m
.76031 .35373 L
s
.76031 .35373 m
.76032 .35372 L
s
.76033 .35372 m
.76032 .35373 L
s
.76032 .35372 m
.76033 .35372 L
s
.76032 .35372 m
.76032 .35373 L
s
1 .015 0 r
.47752 .43688 m
.47766 .43697 L
s
.47737 .43706 m
.47752 .43688 L
s
.47752 .43688 m
.4774 .43689 L
s
.47751 .43715 m
.47737 .43706 L
s
.47737 .43706 m
.4774 .43689 L
s
.47766 .43697 m
.47751 .43715 L
s
.4774 .43689 m
.47766 .43697 L
s
.4774 .43689 m
.47751 .43715 L
s
1 .082 0 r
.35833 .54821 m
.35505 .54478 L
s
1 .006 0 r
.64077 .46444 m
.64064 .46416 L
s
.64066 .46416 m
.64073 .4642 L
s
.64059 .46423 m
.64066 .46416 L
s
.64066 .46416 m
.64064 .46416 L
s
.64066 .46427 m
.64059 .46423 L
s
.64059 .46423 m
.64064 .46416 L
s
.64073 .4642 m
.64066 .46427 L
s
.64064 .46416 m
.64073 .4642 L
s
.64064 .46416 m
.64066 .46427 L
s
0 .07 1 r
.2297 .34051 m
.18785 .29716 L
s
.18785 .29716 m
.2457 .26539 L
s
1 .001 0 r
.69896 .32476 m
.69894 .32472 L
s
.69894 .32473 m
.69895 .32473 L
s
.69894 .32473 m
.69894 .32473 L
s
.69894 .32473 m
.69894 .32472 L
s
.69895 .32474 m
.69894 .32473 L
s
.69894 .32473 m
.69894 .32472 L
s
.69895 .32473 m
.69895 .32474 L
s
.69894 .32472 m
.69895 .32473 L
s
.69894 .32472 m
.69895 .32474 L
s
1 .003 0 r
.80371 .49137 m
.80368 .49123 L
s
.80369 .49123 m
.80372 .49126 L
s
.80365 .49126 m
.80369 .49123 L
s
.80369 .49123 m
.80368 .49123 L
s
.80369 .49129 m
.80365 .49126 L
s
.80365 .49126 m
.80368 .49123 L
s
.80372 .49126 m
.80369 .49129 L
s
.80368 .49123 m
.80372 .49126 L
s
.80368 .49123 m
.80369 .49129 L
s
1 .007 0 r
.57932 .43549 m
.57911 .43517 L
s
.57915 .43517 m
.57923 .43522 L
s
.57908 .43525 m
.57915 .43517 L
s
.57915 .43517 m
.57911 .43517 L
s
.57915 .4353 m
.57908 .43525 L
s
.57908 .43525 m
.57911 .43517 L
s
.57923 .43522 m
.57915 .4353 L
s
.57911 .43517 m
.57923 .43522 L
s
.57911 .43517 m
.57915 .4353 L
s
1 .001 0 r
.63752 .29573 m
.6375 .2957 L
s
.63751 .2957 m
.63751 .29571 L
s
.6375 .29571 m
.63751 .2957 L
s
.63751 .2957 m
.6375 .2957 L
s
.63751 .29571 m
.6375 .29571 L
s
.6375 .29571 m
.6375 .2957 L
s
.63751 .29571 m
.63751 .29571 L
s
.6375 .2957 m
.63751 .29571 L
s
.6375 .2957 m
.63751 .29571 L
s
1 .037 0 r
.4596 .54628 m
.45854 .54461 L
s
0 .088 1 r
.24673 .24921 m
.23088 .32374 L
s
1 .003 0 r
.74232 .46243 m
.74227 .46227 L
s
.74227 .46227 m
.74231 .4623 L
s
.74224 .46231 m
.74227 .46227 L
s
.74227 .46227 m
.74227 .46227 L
s
1 .082 0 r
.35574 .5447 m
.35653 .54522 L
s
.35489 .54572 m
.35574 .5447 L
s
.35574 .5447 m
.35505 .54478 L
s
1 .003 0 r
.74228 .46233 m
.74224 .46231 L
s
.74224 .46231 m
.74227 .46227 L
s
.74231 .4623 m
.74228 .46233 L
s
.74227 .46227 m
.74231 .4623 L
s
.74227 .46227 m
.74228 .46233 L
s
1 .008 0 r
.5178 .40651 m
.5175 .40616 L
s
1 .082 0 r
.35568 .54624 m
.35489 .54572 L
s
.35489 .54572 m
.35505 .54478 L
s
1 .008 0 r
.51756 .40616 m
.51764 .4062 L
s
.51748 .40625 m
.51756 .40616 L
s
.51756 .40616 m
.5175 .40616 L
s
.51756 .4063 m
.51748 .40625 L
s
.51748 .40625 m
.5175 .40616 L
s
.51764 .4062 m
.51756 .4063 L
s
.5175 .40616 m
.51764 .4062 L
s
.5175 .40616 m
.51756 .4063 L
s
1 .082 0 r
.35653 .54522 m
.35568 .54624 L
s
.35505 .54478 m
.35653 .54522 L
s
0 .049 1 r
.23146 .3213 m
.27383 .36506 L
s
.18301 .34833 m
.23146 .3213 L
s
.23146 .3213 m
.24195 .31664 L
s
1 .05 0 r
.39801 .51735 m
.39601 .5152 L
s
1 .037 0 r
.45876 .54459 m
.45916 .54486 L
s
.45834 .54503 m
.45876 .54459 L
s
.45876 .54459 m
.45854 .54461 L
s
1 .082 0 r
.35505 .54478 m
.35568 .54624 L
s
1 .037 0 r
.45874 .5453 m
.45834 .54503 L
s
.45834 .54503 m
.45854 .54461 L
s
1 .004 0 r
.68086 .43345 m
.68078 .43328 L
s
1 .037 0 r
.45916 .54486 m
.45874 .5453 L
s
.45854 .54461 m
.45916 .54486 L
s
1 .004 0 r
.6808 .43328 m
.68084 .4333 L
s
.68076 .43332 m
.6808 .43328 L
s
.6808 .43328 m
.68078 .43328 L
s
.6808 .43335 m
.68076 .43332 L
s
.68076 .43332 m
.68078 .43328 L
s
.68084 .4333 m
.6808 .43335 L
s
.68078 .43328 m
.68084 .4333 L
s
.68078 .43328 m
.6808 .43335 L
s
1 .037 0 r
.45854 .54461 m
.45874 .5453 L
s
1 0 0 r
.73915 .29356 m
.73914 .29354 L
s
.73914 .29354 m
.73914 .29355 L
s
.73914 .29355 m
.73914 .29354 L
s
.73914 .29354 m
.73914 .29354 L
s
.73914 .29355 m
.73914 .29355 L
s
.73914 .29355 m
.73914 .29354 L
s
.73914 .29355 m
.73914 .29355 L
s
.73914 .29354 m
.73914 .29355 L
s
.73914 .29354 m
.73914 .29355 L
s
1 .018 0 r
.56106 .54434 m
.56068 .5435 L
s
1 .004 0 r
.61934 .40444 m
.61923 .40426 L
s
1 .05 0 r
.39642 .51516 m
.39692 .51547 L
s
.3959 .51579 m
.39642 .51516 L
s
.39642 .51516 m
.39601 .5152 L
s
1 .018 0 r
.56076 .5435 m
.56096 .54364 L
s
.56055 .5437 m
.56076 .5435 L
s
.56076 .5435 m
.56068 .5435 L
s
1 .004 0 r
.61925 .40426 m
.61929 .40429 L
s
.61921 .40431 m
.61925 .40426 L
s
.61925 .40426 m
.61923 .40426 L
s
.61925 .40433 m
.61921 .40431 L
s
.61921 .40431 m
.61923 .40426 L
s
.61929 .40429 m
.61925 .40433 L
s
.61923 .40426 m
.61929 .40429 L
s
1 .018 0 r
.56076 .54384 m
.56055 .5437 L
s
.56055 .5437 m
.56068 .5435 L
s
1 .004 0 r
.61923 .40426 m
.61925 .40433 L
s
1 .05 0 r
.39639 .5161 m
.3959 .51579 L
s
.3959 .51579 m
.39601 .5152 L
s
1 .018 0 r
.56096 .54364 m
.56076 .54384 L
s
.56068 .5435 m
.56096 .54364 L
s
.56068 .5435 m
.56076 .54384 L
s
1 .05 0 r
.39692 .51547 m
.39639 .5161 L
s
.39601 .5152 m
.39692 .51547 L
s
1 0 0 r
.67764 .26447 m
.67763 .26446 L
s
.67763 .26446 m
.67764 .26446 L
s
.67763 .26446 m
.67763 .26446 L
s
.67763 .26446 m
.67763 .26446 L
s
.67764 .26447 m
.67763 .26446 L
s
.67763 .26446 m
.67763 .26446 L
s
.67764 .26446 m
.67764 .26447 L
s
.67763 .26446 m
.67764 .26446 L
s
.67763 .26446 m
.67764 .26447 L
s
1 .024 0 r
.49946 .51538 m
.49878 .51433 L
s
1 .05 0 r
.39601 .5152 m
.39639 .5161 L
s
0 .053 1 r
.27493 .34776 m
.22706 .37514 L
s
.24326 .29925 m
.27493 .34776 L
s
1 .002 0 r
.7826 .4314 m
.78256 .43131 L
s
.78257 .43131 m
.78259 .43132 L
s
.78255 .43133 m
.78257 .43131 L
s
.78257 .43131 m
.78256 .43131 L
s
.78257 .43134 m
.78255 .43133 L
s
.78255 .43133 m
.78256 .43131 L
s
.78259 .43132 m
.78257 .43134 L
s
.78256 .43131 m
.78259 .43132 L
s
.78256 .43131 m
.78257 .43134 L
s
1 .004 0 r
.55775 .3754 m
.5576 .37522 L
s
.55763 .37522 m
.55767 .37524 L
s
.55759 .37527 m
.55763 .37522 L
s
.55763 .37522 m
.5576 .37522 L
s
.55763 .37529 m
.55759 .37527 L
s
.55759 .37527 m
.5576 .37522 L
s
.55767 .37524 m
.55763 .37529 L
s
.5576 .37522 m
.55767 .37524 L
s
.5576 .37522 m
.55763 .37529 L
s
1 .024 0 r
.49892 .51432 m
.49917 .51448 L
s
.49866 .51459 m
.49892 .51432 L
s
.49892 .51432 m
.49878 .51433 L
s
.49891 .51476 m
.49866 .51459 L
s
.49866 .51459 m
.49878 .51433 L
s
1 .01 0 r
.66272 .5424 m
.66257 .54195 L
s
1 .024 0 r
.49917 .51448 m
.49891 .51476 L
s
.49878 .51433 m
.49917 .51448 L
s
.49878 .51433 m
.49891 .51476 L
s
1 .03 0 r
.4378 .4864 m
.43661 .48509 L
s
1 .01 0 r
.6626 .54195 m
.66271 .54203 L
s
.66249 .54206 m
.6626 .54195 L
s
.6626 .54195 m
.66257 .54195 L
s
.6626 .54213 m
.66249 .54206 L
s
.66249 .54206 m
.66257 .54195 L
s
.66271 .54203 m
.6626 .54213 L
s
.66257 .54195 m
.66271 .54203 L
s
.66257 .54195 m
.6626 .54213 L
s
1 .002 0 r
.72107 .40237 m
.72102 .40227 L
s
.72103 .40227 m
.72105 .40228 L
s
.72101 .40229 m
.72103 .40227 L
s
.72103 .40227 m
.72102 .40227 L
s
.72103 .40231 m
.72101 .40229 L
s
.72101 .40229 m
.72102 .40227 L
s
.72105 .40228 m
.72103 .40231 L
s
.72102 .40227 m
.72105 .40228 L
s
.72102 .40227 m
.72103 .40231 L
s
1 .03 0 r
.43686 .48507 m
.43716 .48525 L
s
.43654 .48545 m
.43686 .48507 L
s
.43686 .48507 m
.43661 .48509 L
s
1 .012 0 r
.60111 .51341 m
.60086 .51287 L
s
1 .03 0 r
.43684 .48563 m
.43654 .48545 L
s
.43654 .48545 m
.43661 .48509 L
s
.43716 .48525 m
.43684 .48563 L
s
.43661 .48509 m
.43716 .48525 L
s
.43661 .48509 m
.43684 .48563 L
s
1 .012 0 r
.6009 .51287 m
.60104 .51296 L
s
.60077 .513 m
.6009 .51287 L
s
.6009 .51287 m
.60086 .51287 L
s
.60091 .51309 m
.60077 .513 L
s
.60077 .513 m
.60086 .51287 L
s
.60104 .51296 m
.60091 .51309 L
s
.60086 .51287 m
.60104 .51296 L
s
.60086 .51287 m
.60091 .51309 L
s
1 .002 0 r
.65948 .3733 m
.65942 .3732 L
s
.65943 .3732 m
.65945 .37322 L
s
.65941 .37323 m
.65943 .3732 L
s
.65943 .3732 m
.65942 .3732 L
s
.65943 .37324 m
.65941 .37323 L
s
.65941 .37323 m
.65942 .3732 L
s
.65945 .37322 m
.65943 .37324 L
s
.65942 .3732 m
.65945 .37322 L
s
.65942 .3732 m
.65943 .37324 L
s
1 .005 0 r
.76456 .54046 m
.7645 .5402 L
s
1 0 0 r
.71788 .23312 m
.71787 .23312 L
s
.71787 .23312 m
.71787 .23312 L
s
.71787 .23312 m
.71787 .23312 L
s
.71787 .23312 m
.71787 .23312 L
s
.71787 .23312 m
.71787 .23312 L
s
.71787 .23312 m
.71787 .23312 L
s
.71787 .23312 m
.71787 .23312 L
s
.71787 .23312 m
.71787 .23312 L
s
.71787 .23312 m
.71787 .23312 L
s
1 .005 0 r
.76451 .5402 m
.76458 .54024 L
s
.76445 .54026 m
.76451 .5402 L
s
.76451 .5402 m
.7645 .5402 L
s
1 .014 0 r
.53944 .4844 m
.53902 .48374 L
s
1 .005 0 r
.76452 .5403 m
.76445 .54026 L
s
.76445 .54026 m
.7645 .5402 L
s
.76458 .54024 m
.76452 .5403 L
s
.7645 .5402 m
.76458 .54024 L
s
.7645 .5402 m
.76452 .5403 L
s
1 .014 0 r
.5391 .48374 m
.53926 .48384 L
s
.53895 .48391 m
.5391 .48374 L
s
.5391 .48374 m
.53902 .48374 L
s
.5391 .48401 m
.53895 .48391 L
s
.53895 .48391 m
.53902 .48374 L
s
1 .002 0 r
.59782 .34421 m
.59775 .34411 L
s
1 .014 0 r
.53926 .48384 m
.5391 .48401 L
s
.53902 .48374 m
.53926 .48384 L
s
1 .002 0 r
.59776 .34411 m
.59779 .34412 L
s
.59774 .34414 m
.59776 .34411 L
s
.59776 .34411 m
.59775 .34411 L
s
.59776 .34415 m
.59774 .34414 L
s
.59774 .34414 m
.59775 .34411 L
s
.59779 .34412 m
.59776 .34415 L
s
.59775 .34411 m
.59779 .34412 L
s
.59775 .34411 m
.59776 .34415 L
s
1 .014 0 r
.53902 .48374 m
.5391 .48401 L
s
1 .006 0 r
.70295 .51144 m
.70285 .51115 L
s
1 .018 0 r
.47771 .45535 m
.47703 .45458 L
s
1 .006 0 r
.70286 .51115 m
.70294 .51119 L
s
.70279 .51121 m
.70286 .51115 L
s
.70286 .51115 m
.70285 .51115 L
s
.70287 .51126 m
.70279 .51121 L
s
.70279 .51121 m
.70285 .51115 L
s
.70294 .51119 m
.70287 .51126 L
s
.70285 .51115 m
.70294 .51119 L
s
.70285 .51115 m
.70287 .51126 L
s
1 .001 0 r
.7614 .3712 m
.76137 .37114 L
s
.76137 .37114 m
.76139 .37115 L
s
.76136 .37115 m
.76137 .37114 L
s
.76137 .37114 m
.76137 .37114 L
s
.76137 .37116 m
.76136 .37115 L
s
.76136 .37115 m
.76137 .37114 L
s
.76139 .37115 m
.76137 .37116 L
s
.76137 .37114 m
.76139 .37115 L
s
.76137 .37114 m
.76137 .37116 L
s
1 .018 0 r
.47716 .45457 m
.47734 .45468 L
s
.47698 .45479 m
.47716 .45457 L
s
.47716 .45457 m
.47703 .45458 L
s
.47716 .4549 m
.47698 .45479 L
s
.47698 .45479 m
.47703 .45458 L
s
.47734 .45468 m
.47716 .4549 L
s
.47703 .45458 m
.47734 .45468 L
s
.47703 .45458 m
.47716 .4549 L
s
1 .007 0 r
.64127 .4824 m
.64111 .48205 L
s
.64114 .48205 m
.64122 .48211 L
s
.64106 .48214 m
.64114 .48205 L
s
.64114 .48205 m
.64111 .48205 L
s
.64114 .48219 m
.64106 .48214 L
s
.64106 .48214 m
.64111 .48205 L
s
.64122 .48211 m
.64114 .48219 L
s
.64111 .48205 m
.64122 .48211 L
s
.64111 .48205 m
.64114 .48219 L
s
1 .001 0 r
.69974 .34207 m
.6997 .34202 L
s
.69971 .34202 m
.69972 .34203 L
s
.6997 .34203 m
.69971 .34202 L
s
.69971 .34202 m
.6997 .34202 L
s
.69971 .34204 m
.6997 .34203 L
s
.6997 .34203 m
.6997 .34202 L
s
.69972 .34203 m
.69971 .34204 L
s
.6997 .34202 m
.69972 .34203 L
s
.6997 .34202 m
.69971 .34204 L
s
0 .06 1 r
.22841 .35768 m
.18626 .31392 L
s
.18626 .31392 m
.24452 .28214 L
s
1 .004 0 r
.80498 .50946 m
.80494 .50929 L
s
.80494 .50929 m
.80499 .50932 L
s
.8049 .50933 m
.80494 .50929 L
s
.80494 .50929 m
.80494 .50929 L
s
.80495 .50936 m
.8049 .50933 L
s
.8049 .50933 m
.80494 .50929 L
s
.80499 .50932 m
.80495 .50936 L
s
.80494 .50929 m
.80499 .50932 L
s
.80494 .50929 m
.80495 .50936 L
s
1 .009 0 r
.57953 .45332 m
.57928 .45293 L
s
.57933 .45293 m
.57942 .45298 L
s
.57924 .45303 m
.57933 .45293 L
s
.57933 .45293 m
.57928 .45293 L
s
.57933 .45309 m
.57924 .45303 L
s
.57924 .45303 m
.57928 .45293 L
s
.57942 .45298 m
.57933 .45309 L
s
.57928 .45293 m
.57942 .45298 L
s
.57928 .45293 m
.57933 .45309 L
s
1 .001 0 r
.63801 .31292 m
.63798 .31287 L
s
.63798 .31287 m
.63799 .31288 L
s
.63797 .31288 m
.63798 .31287 L
s
.63798 .31287 m
.63798 .31287 L
s
.63798 .31289 m
.63797 .31288 L
s
.63797 .31288 m
.63798 .31287 L
s
.63799 .31288 m
.63798 .31289 L
s
.63798 .31287 m
.63799 .31288 L
s
.63798 .31287 m
.63798 .31289 L
s
1 .004 0 r
.7433 .48039 m
.74323 .4802 L
s
.74324 .4802 m
.74329 .48023 L
s
.7432 .48025 m
.74324 .4802 L
s
.74324 .4802 m
.74323 .4802 L
s
.74324 .48028 m
.7432 .48025 L
s
.7432 .48025 m
.74323 .4802 L
s
.74329 .48023 m
.74324 .48028 L
s
.74323 .4802 m
.74329 .48023 L
s
.74323 .4802 m
.74324 .48028 L
s
1 .01 0 r
.51773 .42422 m
.51735 .42377 L
s
.51743 .42377 m
.51753 .42383 L
s
.51732 .42389 m
.51743 .42377 L
s
.51743 .42377 m
.51735 .42377 L
s
.51743 .42395 m
.51732 .42389 L
s
.51732 .42389 m
.51735 .42377 L
s
.51753 .42383 m
.51743 .42395 L
s
.51735 .42377 m
.51753 .42383 L
s
.51735 .42377 m
.51743 .42395 L
s
0 .07 1 r
.2457 .26539 m
.2297 .34051 L
s
1 .056 0 r
.39738 .53558 m
.39516 .53322 L
s
0 .046 1 r
.2301 .33848 m
.27269 .38258 L
s
.18137 .36589 m
.2301 .33848 L
s
.2301 .33848 m
.24061 .33426 L
s
1 .005 0 r
.68155 .45129 m
.68145 .45108 L
s
.68147 .45108 m
.68152 .45111 L
s
.68142 .45113 m
.68147 .45108 L
s
.68147 .45108 m
.68145 .45108 L
s
.68147 .45116 m
.68142 .45113 L
s
.68142 .45113 m
.68145 .45108 L
s
.68152 .45111 m
.68147 .45116 L
s
.68145 .45108 m
.68152 .45111 L
s
.68145 .45108 m
.68147 .45116 L
s
1 .001 0 r
.74011 .31075 m
.74009 .31072 L
s
.7401 .31073 m
.7401 .31073 L
s
.74009 .31073 m
.7401 .31073 L
s
.7401 .31073 m
.74009 .31072 L
s
.7401 .31074 m
.74009 .31073 L
s
.74009 .31073 m
.74009 .31072 L
s
.7401 .31073 m
.7401 .31074 L
s
.74009 .31072 m
.7401 .31073 L
s
.74009 .31072 m
.7401 .31074 L
s
1 .005 0 r
.61974 .42215 m
.6196 .42192 L
s
.61962 .42192 m
.61968 .42195 L
s
.61957 .42198 m
.61962 .42192 L
s
.61962 .42192 m
.6196 .42192 L
s
.61963 .42201 m
.61957 .42198 L
s
.61957 .42198 m
.6196 .42192 L
s
.61968 .42195 m
.61963 .42201 L
s
.6196 .42192 m
.61968 .42195 L
s
.6196 .42192 m
.61963 .42201 L
s
1 .056 0 r
.39563 .53317 m
.39617 .53352 L
s
.39504 .53386 m
.39563 .53317 L
s
.39563 .53317 m
.39516 .53322 L
s
.39559 .53422 m
.39504 .53386 L
s
.39504 .53386 m
.39516 .53322 L
s
1 0 0 r
.67832 .28154 m
.6783 .28152 L
s
.67831 .28152 m
.67831 .28152 L
s
.6783 .28152 m
.67831 .28152 L
s
.67831 .28152 m
.6783 .28152 L
s
.67831 .28153 m
.6783 .28152 L
s
.6783 .28152 m
.6783 .28152 L
s
.67831 .28152 m
.67831 .28153 L
s
.6783 .28152 m
.67831 .28152 L
s
.6783 .28152 m
.67831 .28153 L
s
1 .027 0 r
.49931 .53362 m
.49853 .53242 L
s
1 .056 0 r
.39617 .53352 m
.39559 .53422 L
s
.39516 .53322 m
.39617 .53352 L
s
.39516 .53322 m
.39559 .53422 L
s
1 .003 0 r
.78376 .44925 m
.78372 .44913 L
s
.78373 .44913 m
.78376 .44915 L
s
.7837 .44916 m
.78373 .44913 L
s
.78373 .44913 m
.78372 .44913 L
s
.78373 .44918 m
.7837 .44916 L
s
.7837 .44916 m
.78372 .44913 L
s
.78376 .44915 m
.78373 .44918 L
s
.78372 .44913 m
.78376 .44915 L
s
0 .049 1 r
.27383 .36506 m
.22567 .39284 L
s
.24195 .31664 m
.27383 .36506 L
s
1 .003 0 r
.78372 .44913 m
.78373 .44918 L
s
1 .005 0 r
.55787 .39299 m
.55767 .39274 L
s
.55771 .39274 m
.55776 .39277 L
s
.55765 .39281 m
.55771 .39274 L
s
.55771 .39274 m
.55767 .39274 L
s
.55771 .39284 m
.55765 .39281 L
s
.55765 .39281 m
.55767 .39274 L
s
.55776 .39277 m
.55771 .39284 L
s
.55767 .39274 m
.55776 .39277 L
s
.55767 .39274 m
.55771 .39284 L
s
1 .027 0 r
.49869 .53241 m
.49897 .5326 L
s
.49839 .53273 m
.49869 .53241 L
s
.49869 .53241 m
.49853 .53242 L
s
.49868 .53291 m
.49839 .53273 L
s
.49839 .53273 m
.49853 .53242 L
s
.49897 .5326 m
.49868 .53291 L
s
.49853 .53242 m
.49897 .5326 L
s
1 .034 0 r
.43736 .50451 m
.436 .50302 L
s
1 .027 0 r
.49853 .53242 m
.49868 .53291 L
s
1 .003 0 r
.72195 .42009 m
.72189 .41996 L
s
.7219 .41996 m
.72193 .41998 L
s
.72187 .41999 m
.7219 .41996 L
s
.7219 .41996 m
.72189 .41996 L
s
.7219 .42001 m
.72187 .41999 L
s
.72187 .41999 m
.72189 .41996 L
s
.72193 .41998 m
.7219 .42001 L
s
.72189 .41996 m
.72193 .41998 L
s
.72189 .41996 m
.7219 .42001 L
s
1 .014 0 r
.60143 .53166 m
.60113 .53103 L
s
1 .034 0 r
.43628 .50299 m
.43662 .50321 L
s
.43592 .50343 m
.43628 .50299 L
s
.43628 .50299 m
.436 .50302 L
s
.43626 .50364 m
.43592 .50343 L
s
.43592 .50343 m
.436 .50302 L
s
.43662 .50321 m
.43626 .50364 L
s
.436 .50302 m
.43662 .50321 L
s
1 .014 0 r
.60119 .53103 m
.60135 .53113 L
s
.60104 .53118 m
.60119 .53103 L
s
.60119 .53103 m
.60113 .53103 L
s
1 .034 0 r
.436 .50302 m
.43626 .50364 L
s
1 .014 0 r
.60119 .53129 m
.60104 .53118 L
s
.60104 .53118 m
.60113 .53103 L
s
1 .003 0 r
.66007 .3909 m
.65999 .39076 L
s
1 .014 0 r
.60135 .53113 m
.60119 .53129 L
s
.60113 .53103 m
.60135 .53113 L
s
.60113 .53103 m
.60119 .53129 L
s
1 .003 0 r
.66 .39076 m
.66004 .39078 L
s
.65997 .3908 m
.66 .39076 L
s
.66 .39076 m
.65999 .39076 L
s
.66001 .39081 m
.65997 .3908 L
s
.65997 .3908 m
.65999 .39076 L
s
.66004 .39078 m
.66001 .39081 L
s
.65999 .39076 m
.66004 .39078 L
s
.65999 .39076 m
.66001 .39081 L
s
1 0 0 r
.71874 .25007 m
.71874 .25006 L
s
.71874 .25006 m
.71874 .25006 L
s
.71873 .25006 m
.71874 .25006 L
s
.71874 .25006 m
.71874 .25006 L
s
.71874 .25006 m
.71873 .25006 L
s
.71873 .25006 m
.71874 .25006 L
s
.71874 .25006 m
.71874 .25006 L
s
.71874 .25006 m
.71874 .25006 L
s
.71874 .25006 m
.71874 .25006 L
s
1 .017 0 r
.53947 .50252 m
.53897 .50175 L
s
1 .003 0 r
.59813 .36167 m
.59802 .36154 L
s
1 .017 0 r
.53907 .50175 m
.53926 .50186 L
s
.53889 .50195 m
.53907 .50175 L
s
.53907 .50175 m
.53897 .50175 L
s
.53907 .50206 m
.53889 .50195 L
s
.53889 .50195 m
.53897 .50175 L
s
1 .003 0 r
.59804 .36154 m
.59807 .36156 L
s
.59801 .36158 m
.59804 .36154 L
s
.59804 .36154 m
.59802 .36154 L
s
.59804 .36159 m
.59801 .36158 L
s
.59801 .36158 m
.59802 .36154 L
s
.59807 .36156 m
.59804 .36159 L
s
.59802 .36154 m
.59807 .36156 L
s
.59802 .36154 m
.59804 .36159 L
s
1 .017 0 r
.53926 .50186 m
.53907 .50206 L
s
.53897 .50175 m
.53926 .50186 L
s
.53897 .50175 m
.53907 .50206 L
s
1 .007 0 r
.70374 .52969 m
.70362 .52934 L
s
1 .021 0 r
.47745 .47334 m
.47664 .47243 L
s
1 .007 0 r
.70364 .52934 m
.70373 .5294 L
s
.70356 .52943 m
.70364 .52934 L
s
.70364 .52934 m
.70362 .52934 L
s
.70365 .52949 m
.70356 .52943 L
s
.70356 .52943 m
.70362 .52934 L
s
.70373 .5294 m
.70365 .52949 L
s
.70362 .52934 m
.70373 .5294 L
s
.70362 .52934 m
.70365 .52949 L
s
1 .002 0 r
.76246 .3888 m
.76243 .38872 L
s
.76243 .38872 m
.76245 .38873 L
s
.76242 .38874 m
.76243 .38872 L
s
.76243 .38872 m
.76243 .38872 L
s
.76244 .38875 m
.76242 .38874 L
s
.76242 .38874 m
.76243 .38872 L
s
.76245 .38873 m
.76244 .38875 L
s
.76243 .38872 m
.76245 .38873 L
s
.76243 .38872 m
.76244 .38875 L
s
1 .021 0 r
.47681 .47242 m
.47702 .47255 L
s
.47659 .47268 m
.47681 .47242 L
s
.47681 .47242 m
.47664 .47243 L
s
.4768 .47281 m
.47659 .47268 L
s
.47659 .47268 m
.47664 .47243 L
s
.47702 .47255 m
.4768 .47281 L
s
.47664 .47243 m
.47702 .47255 L
s
.47664 .47243 m
.4768 .47281 L
s
1 .009 0 r
.64178 .50052 m
.64158 .50011 L
s
.64162 .50011 m
.64172 .50018 L
s
.64152 .50021 m
.64162 .50011 L
s
.64162 .50011 m
.64158 .50011 L
s
.64163 .50028 m
.64152 .50021 L
s
.64152 .50021 m
.64158 .50011 L
s
.64172 .50018 m
.64163 .50028 L
s
.64158 .50011 m
.64172 .50018 L
s
.64158 .50011 m
.64163 .50028 L
s
1 .002 0 r
.70052 .35955 m
.70047 .35947 L
s
.70048 .35947 m
.7005 .35948 L
s
.70046 .35949 m
.70048 .35947 L
s
.70048 .35947 m
.70047 .35947 L
s
.70048 .3595 m
.70046 .35949 L
s
.70046 .35949 m
.70047 .35947 L
s
.7005 .35948 m
.70048 .3595 L
s
.70047 .35947 m
.7005 .35948 L
s
.70047 .35947 m
.70048 .3595 L
s
1 .004 0 r
.80625 .52772 m
.8062 .52752 L
s
0 .053 1 r
.22706 .37514 m
.18464 .331 L
s
.18464 .331 m
.24326 .29925 L
s
1 .004 0 r
.80621 .52752 m
.80626 .52755 L
s
.80616 .52757 m
.80621 .52752 L
s
.80621 .52752 m
.8062 .52752 L
s
.80621 .5276 m
.80616 .52757 L
s
.80616 .52757 m
.8062 .52752 L
s
.80626 .52755 m
.80621 .5276 L
s
.8062 .52752 m
.80626 .52755 L
s
.8062 .52752 m
.80621 .5276 L
s
1 .01 0 r
.57975 .47132 m
.57944 .47084 L
s
.5795 .47084 m
.57962 .47091 L
s
.57939 .47097 m
.5795 .47084 L
s
.5795 .47084 m
.57944 .47084 L
s
.57951 .47104 m
.57939 .47097 L
s
.57939 .47097 m
.57944 .47084 L
s
.57962 .47091 m
.57951 .47104 L
s
.57944 .47084 m
.57962 .47091 L
s
.57944 .47084 m
.57951 .47104 L
s
1 .002 0 r
.63851 .33026 m
.63845 .33019 L
s
.63846 .3302 m
.63848 .3302 L
s
.63845 .33021 m
.63846 .3302 L
s
.63846 .3302 m
.63845 .33019 L
s
.63846 .33022 m
.63845 .33021 L
s
.63845 .33021 m
.63845 .33019 L
s
.63848 .3302 m
.63846 .33022 L
s
.63845 .33019 m
.63848 .3302 L
s
.63845 .33019 m
.63846 .33022 L
s
1 .005 0 r
.74428 .49852 m
.7442 .49829 L
s
.74421 .49829 m
.74427 .49833 L
s
.74416 .49835 m
.74421 .49829 L
s
.74421 .49829 m
.7442 .49829 L
s
.74422 .49839 m
.74416 .49835 L
s
.74416 .49835 m
.7442 .49829 L
s
.74427 .49833 m
.74422 .49839 L
s
.7442 .49829 m
.74427 .49833 L
s
1 .012 0 r
.51766 .44209 m
.51719 .44154 L
s
1 .005 0 r
.7442 .49829 m
.74422 .49839 L
s
1 .012 0 r
.51729 .44154 m
.51741 .44161 L
s
.51716 .44169 m
.51729 .44154 L
s
.51729 .44154 m
.51719 .44154 L
s
.51729 .44177 m
.51716 .44169 L
s
.51716 .44169 m
.51719 .44154 L
s
.51741 .44161 m
.51729 .44177 L
s
.51719 .44154 m
.51741 .44161 L
s
.51719 .44154 m
.51729 .44177 L
s
0 .044 1 r
.22871 .35586 m
.27152 .40029 L
s
.1797 .38364 m
.22871 .35586 L
s
.22871 .35586 m
.23924 .35209 L
s
0 .06 1 r
.24452 .28214 m
.22841 .35768 L
s
1 .006 0 r
.68225 .46929 m
.68212 .46903 L
s
.68215 .46903 m
.68221 .46907 L
s
.68209 .4691 m
.68215 .46903 L
s
.68215 .46903 m
.68212 .46903 L
s
.68215 .46914 m
.68209 .4691 L
s
.68209 .4691 m
.68212 .46903 L
s
.68221 .46907 m
.68215 .46914 L
s
.68212 .46903 m
.68221 .46907 L
s
.68212 .46903 m
.68215 .46914 L
s
1 .001 0 r
.74108 .3281 m
.74106 .32806 L
s
.74106 .32807 m
.74107 .32807 L
s
.74105 .32808 m
.74106 .32807 L
s
.74106 .32807 m
.74106 .32806 L
s
.74106 .32808 m
.74105 .32808 L
s
.74105 .32808 m
.74106 .32806 L
s
.74107 .32807 m
.74106 .32808 L
s
.74106 .32806 m
.74107 .32807 L
s
.74106 .32806 m
.74106 .32808 L
s
1 .006 0 r
.62015 .44003 m
.61997 .43974 L
s
.62 .43974 m
.62007 .43978 L
s
.61993 .43982 m
.62 .43974 L
s
.62 .43974 m
.61997 .43974 L
s
.62 .43986 m
.61993 .43982 L
s
.61993 .43982 m
.61997 .43974 L
s
.62007 .43978 m
.62 .43986 L
s
.61997 .43974 m
.62007 .43978 L
s
.61997 .43974 m
.62 .43986 L
s
1 .001 0 r
.679 .29876 m
.67898 .29873 L
s
.67898 .29873 m
.67899 .29873 L
s
.67897 .29874 m
.67898 .29873 L
s
.67898 .29873 m
.67898 .29873 L
s
.67898 .29874 m
.67897 .29874 L
s
.67897 .29874 m
.67898 .29873 L
s
.67899 .29873 m
.67898 .29874 L
s
.67898 .29873 m
.67899 .29873 L
s
.67898 .29873 m
.67898 .29874 L
s
1 .003 0 r
.78494 .46726 m
.78489 .46711 L
s
.78489 .46711 m
.78493 .46714 L
s
.78486 .46715 m
.78489 .46711 L
s
.78489 .46711 m
.78489 .46711 L
s
.7849 .46717 m
.78486 .46715 L
s
.78486 .46715 m
.78489 .46711 L
s
.78493 .46714 m
.7849 .46717 L
s
.78489 .46711 m
.78493 .46714 L
s
.78489 .46711 m
.7849 .46717 L
s
1 .007 0 r
.55799 .41074 m
.55773 .41043 L
s
0 .046 1 r
.27269 .38258 m
.22425 .41074 L
s
.24061 .33426 m
.27269 .38258 L
s
1 .007 0 r
.55778 .41042 m
.55785 .41047 L
s
.55771 .41051 m
.55778 .41042 L
s
.55778 .41042 m
.55773 .41043 L
s
.55778 .41055 m
.55771 .41051 L
s
.55771 .41051 m
.55773 .41043 L
s
.55785 .41047 m
.55778 .41055 L
s
.55773 .41043 m
.55785 .41047 L
s
.55773 .41043 m
.55778 .41055 L
s
1 .039 0 r
.43691 .52279 m
.43538 .52113 L
s
1 .003 0 r
.72284 .43798 m
.72276 .43781 L
s
.72277 .43781 m
.72281 .43784 L
s
.72273 .43785 m
.72277 .43781 L
s
.72277 .43781 m
.72276 .43781 L
s
.72278 .43788 m
.72273 .43785 L
s
.72273 .43785 m
.72276 .43781 L
s
.72281 .43784 m
.72278 .43788 L
s
.72276 .43781 m
.72281 .43784 L
s
.72276 .43781 m
.72278 .43788 L
s
1 .039 0 r
.4357 .52109 m
.43608 .52134 L
s
.43529 .52158 m
.4357 .52109 L
s
.4357 .52109 m
.43538 .52113 L
s
.43568 .52183 m
.43529 .52158 L
s
.43529 .52158 m
.43538 .52113 L
s
1 .004 0 r
.66067 .40866 m
.66056 .40848 L
s
1 .039 0 r
.43608 .52134 m
.43568 .52183 L
s
.43538 .52113 m
.43608 .52134 L
s
1 .004 0 r
.66058 .40848 m
.66062 .40851 L
s
.66054 .40853 m
.66058 .40848 L
s
.66058 .40848 m
.66056 .40848 L
s
.66058 .40855 m
.66054 .40853 L
s
.66054 .40853 m
.66056 .40848 L
s
1 .039 0 r
.43538 .52113 m
.43568 .52183 L
s
1 .004 0 r
.66062 .40851 m
.66058 .40855 L
s
.66056 .40848 m
.66062 .40851 L
s
.66056 .40848 m
.66058 .40855 L
s
1 0 0 r
.71961 .26717 m
.7196 .26715 L
s
.71961 .26715 m
.71961 .26716 L
s
.7196 .26716 m
.71961 .26715 L
s
.71961 .26715 m
.7196 .26715 L
s
.71961 .26716 m
.7196 .26716 L
s
.7196 .26716 m
.7196 .26715 L
s
.71961 .26716 m
.71961 .26716 L
s
.7196 .26715 m
.71961 .26716 L
s
.7196 .26715 m
.71961 .26716 L
s
1 .019 0 r
.5395 .5208 m
.53893 .51993 L
s
1 .004 0 r
.59844 .37931 m
.59829 .37913 L
s
1 .019 0 r
.53904 .51992 m
.53926 .52006 L
s
.53883 .52015 m
.53904 .51992 L
s
.53904 .51992 m
.53893 .51993 L
s
1 .004 0 r
.59832 .37913 m
.59836 .37915 L
s
.59828 .37917 m
.59832 .37913 L
s
.59832 .37913 m
.59829 .37913 L
s
.59832 .3792 m
.59828 .37917 L
s
.59828 .37917 m
.59829 .37913 L
s
.59836 .37915 m
.59832 .3792 L
s
.59829 .37913 m
.59836 .37915 L
s
1 .019 0 r
.53904 .52029 m
.53883 .52015 L
s
.53883 .52015 m
.53893 .51993 L
s
1 .004 0 r
.59829 .37913 m
.59832 .3792 L
s
1 .019 0 r
.53926 .52006 m
.53904 .52029 L
s
.53893 .51993 m
.53926 .52006 L
s
.53893 .51993 m
.53904 .52029 L
s
1 .024 0 r
.47719 .4915 m
.47625 .49045 L
s
1 .002 0 r
.76354 .40656 m
.7635 .40646 L
s
.7635 .40646 m
.76353 .40648 L
s
.76348 .40649 m
.7635 .40646 L
s
.7635 .40646 m
.7635 .40646 L
s
.76351 .4065 m
.76348 .40649 L
s
.76348 .40649 m
.7635 .40646 L
s
.76353 .40648 m
.76351 .4065 L
s
.7635 .40646 m
.76353 .40648 L
s
.7635 .40646 m
.76351 .4065 L
s
1 .024 0 r
.47644 .49044 m
.47669 .49058 L
s
.47619 .49074 m
.47644 .49044 L
s
.47644 .49044 m
.47625 .49045 L
s
.47644 .49089 m
.47619 .49074 L
s
.47619 .49074 m
.47625 .49045 L
s
1 .01 0 r
.64229 .51882 m
.64206 .51834 L
s
1 .024 0 r
.47669 .49058 m
.47644 .49089 L
s
.47625 .49045 m
.47669 .49058 L
s
.47625 .49045 m
.47644 .49089 L
s
1 .01 0 r
.64211 .51834 m
.64222 .51841 L
s
.64199 .51846 m
.64211 .51834 L
s
.64211 .51834 m
.64206 .51834 L
s
.64211 .51853 m
.64199 .51846 L
s
.64199 .51846 m
.64206 .51834 L
s
.64222 .51841 m
.64211 .51853 L
s
.64206 .51834 m
.64222 .51841 L
s
.64206 .51834 m
.64211 .51853 L
s
1 .002 0 r
.70131 .37718 m
.70124 .37708 L
s
.70126 .37708 m
.70128 .3771 L
s
.70123 .37711 m
.70126 .37708 L
s
.70126 .37708 m
.70124 .37708 L
s
.70126 .37712 m
.70123 .37711 L
s
.70123 .37711 m
.70124 .37708 L
s
.70128 .3771 m
.70126 .37712 L
s
.70124 .37708 m
.70128 .3771 L
s
.70124 .37708 m
.70126 .37712 L
s
0 .049 1 r
.22567 .39284 m
.18301 .34833 L
s
.18301 .34833 m
.24195 .31664 L
s
1 .012 0 r
.57997 .48949 m
.57961 .48893 L
s
.57968 .48892 m
.57982 .48901 L
s
.57955 .48907 m
.57968 .48892 L
s
.57968 .48892 m
.57961 .48893 L
s
.57968 .48916 m
.57955 .48907 L
s
.57955 .48907 m
.57961 .48893 L
s
.57982 .48901 m
.57968 .48916 L
s
.57961 .48893 m
.57982 .48901 L
s
1 .002 0 r
.639 .34777 m
.63893 .34768 L
s
1 .012 0 r
.57961 .48893 m
.57968 .48916 L
s
1 .002 0 r
.63894 .34768 m
.63897 .34769 L
s
.63892 .3477 m
.63894 .34768 L
s
.63894 .34768 m
.63893 .34768 L
s
.63894 .34771 m
.63892 .3477 L
s
.63892 .3477 m
.63893 .34768 L
s
.63897 .34769 m
.63894 .34771 L
s
.63893 .34768 m
.63897 .34769 L
s
.63893 .34768 m
.63894 .34771 L
s
1 .006 0 r
.74528 .51683 m
.74518 .51655 L
s
.7452 .51655 m
.74527 .5166 L
s
.74513 .51662 m
.7452 .51655 L
s
.7452 .51655 m
.74518 .51655 L
s
1 .015 0 r
.51759 .46013 m
.51703 .45948 L
s
1 .006 0 r
.7452 .51666 m
.74513 .51662 L
s
.74513 .51662 m
.74518 .51655 L
s
.74527 .5166 m
.7452 .51666 L
s
.74518 .51655 m
.74527 .5166 L
s
.74518 .51655 m
.7452 .51666 L
s
1 .015 0 r
.51714 .45947 m
.51729 .45956 L
s
.51699 .45966 m
.51714 .45947 L
s
.51714 .45947 m
.51703 .45948 L
s
.51714 .45975 m
.51699 .45966 L
s
.51699 .45966 m
.51703 .45948 L
s
.51729 .45956 m
.51714 .45975 L
s
.51703 .45948 m
.51729 .45956 L
s
.51703 .45948 m
.51714 .45975 L
s
0 .043 1 r
.2273 .37342 m
.27033 .41819 L
s
.17802 .40159 m
.2273 .37342 L
s
.2273 .37342 m
.23785 .37013 L
s
1 .007 0 r
.68295 .48747 m
.6828 .48716 L
s
.68283 .48716 m
.68291 .48721 L
s
.68276 .48724 m
.68283 .48716 L
s
.68283 .48716 m
.6828 .48716 L
s
0 .053 1 r
.24326 .29925 m
.22706 .37514 L
s
1 .007 0 r
.68283 .48728 m
.68276 .48724 L
s
.68276 .48724 m
.6828 .48716 L
s
.68291 .48721 m
.68283 .48728 L
s
.6828 .48716 m
.68291 .48721 L
s
.6828 .48716 m
.68283 .48728 L
s
1 .001 0 r
.74206 .34562 m
.74203 .34556 L
s
.74204 .34556 m
.74205 .34557 L
s
.74202 .34558 m
.74204 .34556 L
s
.74204 .34556 m
.74203 .34556 L
s
.74204 .34559 m
.74202 .34558 L
s
.74202 .34558 m
.74203 .34556 L
s
.74205 .34557 m
.74204 .34559 L
s
.74203 .34556 m
.74205 .34557 L
s
.74203 .34556 m
.74204 .34559 L
s
1 .008 0 r
.62056 .45808 m
.62034 .45773 L
s
.62038 .45773 m
.62047 .45778 L
s
.6203 .45782 m
.62038 .45773 L
s
.62038 .45773 m
.62034 .45773 L
s
.62038 .45787 m
.6203 .45782 L
s
.6203 .45782 m
.62034 .45773 L
s
.62047 .45778 m
.62038 .45787 L
s
.62034 .45773 m
.62047 .45778 L
s
.62034 .45773 m
.62038 .45787 L
s
1 .001 0 r
.67969 .31615 m
.67965 .3161 L
s
.67966 .3161 m
.67967 .31611 L
s
.67965 .31611 m
.67966 .3161 L
s
.67966 .3161 m
.67965 .3161 L
s
.67966 .31612 m
.67965 .31611 L
s
.67965 .31611 m
.67965 .3161 L
s
.67967 .31611 m
.67966 .31612 L
s
.67965 .3161 m
.67967 .31611 L
s
.67965 .3161 m
.67966 .31612 L
s
1 .004 0 r
.78613 .48545 m
.78606 .48527 L
s
.78607 .48527 m
.78612 .48529 L
s
.78603 .48531 m
.78607 .48527 L
s
.78607 .48527 m
.78606 .48527 L
s
.78608 .48534 m
.78603 .48531 L
s
.78603 .48531 m
.78606 .48527 L
s
.78612 .48529 m
.78608 .48534 L
s
.78606 .48527 m
.78612 .48529 L
s
.78606 .48527 m
.78608 .48534 L
s
1 .009 0 r
.55811 .42866 m
.55778 .42827 L
s
0 .044 1 r
.27152 .40029 m
.2228 .42884 L
s
.23924 .35209 m
.27152 .40029 L
s
1 .009 0 r
.55785 .42827 m
.55794 .42832 L
s
.55775 .42838 m
.55785 .42827 L
s
.55785 .42827 m
.55778 .42827 L
s
.55785 .42843 m
.55775 .42838 L
s
.55775 .42838 m
.55778 .42827 L
s
.55794 .42832 m
.55785 .42843 L
s
.55778 .42827 m
.55794 .42832 L
s
.55778 .42827 m
.55785 .42843 L
s
1 .004 0 r
.72373 .45603 m
.72364 .45583 L
s
.72365 .45583 m
.7237 .45586 L
s
.72361 .45588 m
.72365 .45583 L
s
.72365 .45583 m
.72364 .45583 L
s
.72366 .45591 m
.72361 .45588 L
s
.72361 .45588 m
.72364 .45583 L
s
.7237 .45586 m
.72366 .45591 L
s
.72364 .45583 m
.7237 .45586 L
s
.72364 .45583 m
.72366 .45591 L
s
1 .005 0 r
.66127 .42658 m
.66113 .42636 L
s
.66116 .42636 m
.66121 .42639 L
s
.66111 .42642 m
.66116 .42636 L
s
.66116 .42636 m
.66113 .42636 L
s
.66116 .42645 m
.66111 .42642 L
s
.66111 .42642 m
.66113 .42636 L
s
.66121 .42639 m
.66116 .42645 L
s
.66113 .42636 m
.66121 .42639 L
s
.66113 .42636 m
.66116 .42645 L
s
1 .001 0 r
.7205 .28443 m
.72048 .28441 L
s
.72048 .28441 m
.72049 .28441 L
s
.72048 .28442 m
.72048 .28441 L
s
.72048 .28441 m
.72048 .28441 L
s
.72048 .28442 m
.72048 .28442 L
s
.72048 .28442 m
.72048 .28441 L
s
.72049 .28441 m
.72048 .28442 L
s
.72048 .28441 m
.72049 .28441 L
s
.72048 .28441 m
.72048 .28442 L
s
1 .005 0 r
.59875 .3971 m
.59856 .39687 L
s
.5986 .39687 m
.59865 .3969 L
s
.59854 .39693 m
.5986 .39687 L
s
.5986 .39687 m
.59856 .39687 L
s
.5986 .39696 m
.59854 .39693 L
s
.59854 .39693 m
.59856 .39687 L
s
.59865 .3969 m
.5986 .39696 L
s
.59856 .39687 m
.59865 .3969 L
s
.59856 .39687 m
.5986 .39696 L
s
1 .027 0 r
.47693 .50984 m
.47586 .50865 L
s
1 .003 0 r
.76463 .4245 m
.76457 .42437 L
s
.76458 .42437 m
.76461 .42439 L
s
.76455 .4244 m
.76458 .42437 L
s
.76458 .42437 m
.76457 .42437 L
s
.76459 .42442 m
.76455 .4244 L
s
.76455 .4244 m
.76457 .42437 L
s
.76461 .42439 m
.76459 .42442 L
s
.76457 .42437 m
.76461 .42439 L
s
.76457 .42437 m
.76459 .42442 L
s
1 .027 0 r
.47607 .50862 m
.47636 .5088 L
s
.47579 .50897 m
.47607 .50862 L
s
.47607 .50862 m
.47586 .50865 L
s
.47607 .50914 m
.47579 .50897 L
s
.47579 .50897 m
.47586 .50865 L
s
.47636 .5088 m
.47607 .50914 L
s
.47586 .50865 m
.47636 .5088 L
s
.47586 .50865 m
.47607 .50914 L
s
1 .003 0 r
.7021 .39499 m
.70202 .39486 L
s
.70204 .39486 m
.70207 .39488 L
s
.70201 .39489 m
.70204 .39486 L
s
.70204 .39486 m
.70202 .39486 L
s
.70204 .39491 m
.70201 .39489 L
s
.70201 .39489 m
.70202 .39486 L
s
.70207 .39488 m
.70204 .39491 L
s
.70202 .39486 m
.70207 .39488 L
s
.70202 .39486 m
.70204 .39491 L
s
1 .014 0 r
.5802 .50783 m
.57977 .50718 L
s
0 .046 1 r
.22425 .41074 m
.18137 .36589 L
s
.18137 .36589 m
.24061 .33426 L
s
1 .014 0 r
.57985 .50717 m
.58001 .50727 L
s
.5797 .50735 m
.57985 .50717 L
s
.57985 .50717 m
.57977 .50718 L
s
.57986 .50744 m
.5797 .50735 L
s
.5797 .50735 m
.57977 .50718 L
s
1 .003 0 r
.63951 .36545 m
.6394 .36532 L
s
1 .014 0 r
.58001 .50727 m
.57986 .50744 L
s
.57977 .50718 m
.58001 .50727 L
s
1 .003 0 r
.63942 .36532 m
.63945 .36533 L
s
.63939 .36535 m
.63942 .36532 L
s
.63942 .36532 m
.6394 .36532 L
s
1 .014 0 r
.57977 .50718 m
.57986 .50744 L
s
1 .003 0 r
.63942 .36537 m
.63939 .36535 L
s
.63939 .36535 m
.6394 .36532 L
s
.63945 .36533 m
.63942 .36537 L
s
.6394 .36532 m
.63945 .36533 L
s
.6394 .36532 m
.63942 .36537 L
s
1 .017 0 r
.51752 .47834 m
.51686 .47758 L
s
.51699 .47757 m
.51717 .47768 L
s
.51681 .47779 m
.51699 .47757 L
s
.51699 .47757 m
.51686 .47758 L
s
.51699 .4779 m
.51681 .47779 L
s
.51681 .47779 m
.51686 .47758 L
s
.51717 .47768 m
.51699 .4779 L
s
.51686 .47758 m
.51717 .47768 L
s
.51686 .47758 m
.51699 .4779 L
s
0 .042 1 r
.22588 .39117 m
.26911 .43627 L
s
.17633 .41972 m
.22588 .39117 L
s
.22588 .39117 m
.23644 .38836 L
s
1 .008 0 r
.68366 .50582 m
.68348 .50545 L
s
.68352 .50545 m
.68361 .50551 L
s
.68343 .50554 m
.68352 .50545 L
s
.68352 .50545 m
.68348 .50545 L
s
.68352 .5056 m
.68343 .50554 L
s
.68343 .50554 m
.68348 .50545 L
s
.68361 .50551 m
.68352 .5056 L
s
.68348 .50545 m
.68361 .50551 L
s
.68348 .50545 m
.68352 .5056 L
s
0 .049 1 r
.24195 .31664 m
.22567 .39284 L
s
1 .002 0 r
.74305 .3633 m
.74301 .36323 L
s
.74301 .36323 m
.74303 .36324 L
s
.743 .36325 m
.74301 .36323 L
s
.74301 .36323 m
.74301 .36323 L
s
.74302 .36326 m
.743 .36325 L
s
.743 .36325 m
.74301 .36323 L
s
.74303 .36324 m
.74302 .36326 L
s
.74301 .36323 m
.74303 .36324 L
s
.74301 .36323 m
.74302 .36326 L
s
1 .009 0 r
.62098 .4763 m
.62071 .47588 L
s
.62076 .47588 m
.62086 .47594 L
s
.62066 .47599 m
.62076 .47588 L
s
.62076 .47588 m
.62071 .47588 L
s
.62076 .47605 m
.62066 .47599 L
s
.62066 .47599 m
.62071 .47588 L
s
.62086 .47594 m
.62076 .47605 L
s
.62071 .47588 m
.62086 .47594 L
s
.62071 .47588 m
.62076 .47605 L
s
1 .002 0 r
.68039 .3337 m
.68033 .33363 L
s
.68034 .33363 m
.68036 .33364 L
s
.68032 .33365 m
.68034 .33363 L
s
.68034 .33363 m
.68033 .33363 L
s
.68034 .33366 m
.68032 .33365 L
s
.68032 .33365 m
.68033 .33363 L
s
.68036 .33364 m
.68034 .33366 L
s
.68033 .33363 m
.68036 .33364 L
s
.68033 .33363 m
.68034 .33366 L
s
1 .005 0 r
.78733 .5038 m
.78725 .50359 L
s
.78726 .50359 m
.78732 .50362 L
s
.78721 .50364 m
.78726 .50359 L
s
.78726 .50359 m
.78725 .50359 L
s
.78727 .50367 m
.78721 .50364 L
s
.78721 .50364 m
.78725 .50359 L
s
.78732 .50362 m
.78727 .50367 L
s
.78725 .50359 m
.78732 .50362 L
s
.78725 .50359 m
.78727 .50367 L
s
1 .011 0 r
.55823 .44675 m
.55783 .44628 L
s
0 .043 1 r
.27033 .41819 m
.22134 .44713 L
s
.23785 .37013 m
.27033 .41819 L
s
1 .011 0 r
.55791 .44627 m
.55802 .44634 L
s
.5578 .44641 m
.55791 .44627 L
s
.55791 .44627 m
.55783 .44628 L
s
.55791 .44647 m
.5578 .44641 L
s
.5578 .44641 m
.55783 .44628 L
s
.55802 .44634 m
.55791 .44647 L
s
.55783 .44628 m
.55802 .44634 L
s
.55783 .44628 m
.55791 .44647 L
s
1 .005 0 r
.72464 .47426 m
.72452 .47401 L
s
.72454 .47401 m
.7246 .47405 L
s
.72448 .47407 m
.72454 .47401 L
s
.72454 .47401 m
.72452 .47401 L
s
.72454 .47411 m
.72448 .47407 L
s
.72448 .47407 m
.72452 .47401 L
s
.7246 .47405 m
.72454 .47411 L
s
.72452 .47401 m
.7246 .47405 L
s
.72452 .47401 m
.72454 .47411 L
s
1 .006 0 r
.66188 .44468 m
.66171 .44441 L
s
.66174 .44441 m
.66181 .44445 L
s
.66168 .44448 m
.66174 .44441 L
s
.66174 .44441 m
.66171 .44441 L
s
.66175 .44452 m
.66168 .44448 L
s
.66168 .44448 m
.66171 .44441 L
s
.66181 .44445 m
.66175 .44452 L
s
.66171 .44441 m
.66181 .44445 L
s
.66171 .44441 m
.66175 .44452 L
s
1 .001 0 r
.72139 .30186 m
.72136 .30182 L
s
.72136 .30182 m
.72137 .30183 L
s
.72135 .30183 m
.72136 .30182 L
s
.72136 .30182 m
.72136 .30182 L
s
.72136 .30184 m
.72135 .30183 L
s
.72135 .30183 m
.72136 .30182 L
s
.72137 .30183 m
.72136 .30184 L
s
.72136 .30182 m
.72137 .30183 L
s
.72136 .30182 m
.72136 .30184 L
s
1 .006 0 r
.59906 .41507 m
.59882 .41478 L
s
.59887 .41478 m
.59894 .41482 L
s
.5988 .41486 m
.59887 .41478 L
s
.59887 .41478 m
.59882 .41478 L
s
.59887 .4149 m
.5988 .41486 L
s
.5988 .41486 m
.59882 .41478 L
s
.59894 .41482 m
.59887 .4149 L
s
.59882 .41478 m
.59894 .41482 L
s
.59882 .41478 m
.59887 .4149 L
s
1 .003 0 r
.76573 .4426 m
.76566 .44244 L
s
.76567 .44244 m
.76571 .44247 L
s
.76563 .44248 m
.76567 .44244 L
s
.76567 .44244 m
.76566 .44244 L
s
.76567 .44251 m
.76563 .44248 L
s
.76563 .44248 m
.76566 .44244 L
s
.76571 .44247 m
.76567 .44251 L
s
.76566 .44244 m
.76571 .44247 L
s
.76566 .44244 m
.76567 .44251 L
s
1 .004 0 r
.70291 .41296 m
.7028 .4128 L
s
.70282 .4128 m
.70286 .41282 L
s
.70278 .41284 m
.70282 .4128 L
s
.70282 .4128 m
.7028 .4128 L
s
.70282 .41286 m
.70278 .41284 L
s
.70278 .41284 m
.7028 .4128 L
s
.70286 .41282 m
.70282 .41286 L
s
.7028 .4128 m
.70286 .41282 L
s
.7028 .4128 m
.70282 .41286 L
s
0 .044 1 r
.2228 .42884 m
.1797 .38364 L
s
.1797 .38364 m
.23924 .35209 L
s
1 .004 0 r
.64001 .38329 m
.63988 .38312 L
s
.6399 .38312 m
.63994 .38314 L
s
.63986 .38317 m
.6399 .38312 L
s
.6399 .38312 m
.63988 .38312 L
s
.63991 .38319 m
.63986 .38317 L
s
.63986 .38317 m
.63988 .38312 L
s
.63994 .38314 m
.63991 .38319 L
s
.63988 .38312 m
.63994 .38314 L
s
.63988 .38312 m
.63991 .38319 L
s
1 .02 0 r
.51745 .49672 m
.51668 .49585 L
s
.51684 .49584 m
.51704 .49596 L
s
.51663 .49609 m
.51684 .49584 L
s
.51684 .49584 m
.51668 .49585 L
s
.51683 .49622 m
.51663 .49609 L
s
.51663 .49609 m
.51668 .49585 L
s
.51704 .49596 m
.51683 .49622 L
s
.51668 .49585 m
.51704 .49596 L
s
.51668 .49585 m
.51683 .49622 L
s
0 .041 1 r
.22444 .4091 m
.26788 .45453 L
s
.17462 .43804 m
.22444 .4091 L
s
.22444 .4091 m
.23501 .40679 L
s
1 .002 0 r
.74405 .38115 m
.74399 .38105 L
s
0 .046 1 r
.24061 .33426 m
.22425 .41074 L
s
1 .002 0 r
.744 .38105 m
.74403 .38106 L
s
.74398 .38108 m
.744 .38105 L
s
.744 .38105 m
.74399 .38105 L
s
.744 .38109 m
.74398 .38108 L
s
.74398 .38108 m
.74399 .38105 L
s
.74403 .38106 m
.744 .38109 L
s
.74399 .38105 m
.74403 .38106 L
s
.74399 .38105 m
.744 .38109 L
s
1 .011 0 r
.6214 .49469 m
.62108 .4942 L
s
.62114 .4942 m
.62126 .49427 L
s
.62102 .49433 m
.62114 .4942 L
s
.62114 .4942 m
.62108 .4942 L
s
.62114 .4944 m
.62102 .49433 L
s
.62102 .49433 m
.62108 .4942 L
s
.62126 .49427 m
.62114 .4944 L
s
.62108 .4942 m
.62126 .49427 L
s
.62108 .4942 m
.62114 .4944 L
s
1 .002 0 r
.68109 .35142 m
.68101 .35132 L
s
.68103 .35132 m
.68105 .35133 L
s
.681 .35135 m
.68103 .35132 L
s
.68103 .35132 m
.68101 .35132 L
s
.68103 .35136 m
.681 .35135 L
s
.681 .35135 m
.68101 .35132 L
s
.68105 .35133 m
.68103 .35136 L
s
.68101 .35132 m
.68105 .35133 L
s
.68101 .35132 m
.68103 .35136 L
s
1 .013 0 r
.55835 .46501 m
.55787 .46445 L
s
0 .042 1 r
.26911 .43627 m
.21985 .46561 L
s
.23644 .38836 m
.26911 .43627 L
s
1 .013 0 r
.55797 .46445 m
.5581 .46452 L
s
.55784 .46461 m
.55797 .46445 L
s
.55797 .46445 m
.55787 .46445 L
s
.55797 .46468 m
.55784 .46461 L
s
.55784 .46461 m
.55787 .46445 L
s
.5581 .46452 m
.55797 .46468 L
s
.55787 .46445 m
.5581 .46452 L
s
.55787 .46445 m
.55797 .46468 L
s
1 .006 0 r
.72555 .49266 m
.72541 .49237 L
s
.72543 .49237 m
.72551 .49241 L
s
.72537 .49244 m
.72543 .49237 L
s
.72543 .49237 m
.72541 .49237 L
s
.72544 .49249 m
.72537 .49244 L
s
.72537 .49244 m
.72541 .49237 L
s
.72551 .49241 m
.72544 .49249 L
s
.72541 .49237 m
.72551 .49241 L
s
.72541 .49237 m
.72544 .49249 L
s
1 .007 0 r
.6625 .46295 m
.66229 .46263 L
s
.66233 .46262 m
.66241 .46267 L
s
.66226 .46271 m
.66233 .46262 L
s
.66233 .46262 m
.66229 .46263 L
s
.66233 .46276 m
.66226 .46271 L
s
.66226 .46271 m
.66229 .46263 L
s
.66241 .46267 m
.66233 .46276 L
s
.66229 .46263 m
.66241 .46267 L
s
.66229 .46263 m
.66233 .46276 L
s
1 .001 0 r
.72229 .31946 m
.72224 .3194 L
s
.72225 .3194 m
.72226 .31941 L
s
.72224 .31941 m
.72225 .3194 L
s
.72225 .3194 m
.72224 .3194 L
s
.72225 .31942 m
.72224 .31941 L
s
.72224 .31941 m
.72224 .3194 L
s
.72226 .31941 m
.72225 .31942 L
s
.72224 .3194 m
.72226 .31941 L
s
.72224 .3194 m
.72225 .31942 L
s
1 .008 0 r
.59938 .43321 m
.59909 .43285 L
s
.59914 .43285 m
.59923 .4329 L
s
.59906 .43295 m
.59914 .43285 L
s
.59914 .43285 m
.59909 .43285 L
s
.59915 .433 m
.59906 .43295 L
s
.59906 .43295 m
.59909 .43285 L
s
.59923 .4329 m
.59915 .433 L
s
.59909 .43285 m
.59923 .4329 L
s
.59909 .43285 m
.59915 .433 L
s
1 .004 0 r
.76684 .46088 m
.76675 .46069 L
s
.76677 .46069 m
.76681 .46072 L
s
.76672 .46074 m
.76677 .46069 L
s
.76677 .46069 m
.76675 .46069 L
s
.76677 .46076 m
.76672 .46074 L
s
.76672 .46074 m
.76675 .46069 L
s
.76681 .46072 m
.76677 .46076 L
s
.76675 .46069 m
.76681 .46072 L
s
.76675 .46069 m
.76677 .46076 L
s
.70372 .43111 m
.70359 .4309 L
s
.70361 .4309 m
.70366 .43093 L
s
.70357 .43096 m
.70361 .4309 L
s
.70361 .4309 m
.70359 .4309 L
s
.70362 .43098 m
.70357 .43096 L
s
.70357 .43096 m
.70359 .4309 L
s
.70366 .43093 m
.70362 .43098 L
s
.70359 .4309 m
.70366 .43093 L
s
.70359 .4309 m
.70362 .43098 L
s
0 .043 1 r
.22134 .44713 m
.17802 .40159 L
s
.17802 .40159 m
.23785 .37013 L
s
1 .005 0 r
.64053 .40131 m
.64035 .40109 L
s
.64039 .40109 m
.64044 .40111 L
s
.64034 .40115 m
.64039 .40109 L
s
.64039 .40109 m
.64035 .40109 L
s
.64039 .40118 m
.64034 .40115 L
s
.64034 .40115 m
.64035 .40109 L
s
.64044 .40111 m
.64039 .40118 L
s
.64035 .40109 m
.64044 .40111 L
s
.64035 .40109 m
.64039 .40118 L
s
0 .04 1 r
.22298 .42722 m
.26663 .47298 L
s
.17289 .45655 m
.22298 .42722 L
s
.22298 .42722 m
.23357 .4254 L
s
1 .003 0 r
.74506 .39917 m
.74498 .39904 L
s
.745 .39904 m
.74503 .39906 L
s
.74497 .39908 m
.745 .39904 L
s
.745 .39904 m
.74498 .39904 L
s
.745 .39909 m
.74497 .39908 L
s
.74497 .39908 m
.74498 .39904 L
s
.74503 .39906 m
.745 .39909 L
s
.74498 .39904 m
.74503 .39906 L
s
0 .044 1 r
.23924 .35209 m
.2228 .42884 L
s
1 .003 0 r
.74498 .39904 m
.745 .39909 L
s
.6818 .36931 m
.6817 .36918 L
s
.68172 .36918 m
.68175 .36919 L
s
.68169 .36921 m
.68172 .36918 L
s
.68172 .36918 m
.6817 .36918 L
s
.68172 .36923 m
.68169 .36921 L
s
.68169 .36921 m
.6817 .36918 L
s
.68175 .36919 m
.68172 .36923 L
s
.6817 .36918 m
.68175 .36919 L
s
.6817 .36918 m
.68172 .36923 L
s
1 .015 0 r
.55848 .48345 m
.55792 .4828 L
s
0 .041 1 r
.26788 .45453 m
.21835 .48427 L
s
.23501 .40679 m
.26788 .45453 L
s
1 .015 0 r
.55803 .48279 m
.55818 .48288 L
s
.55787 .48298 m
.55803 .48279 L
s
.55803 .48279 m
.55792 .4828 L
s
.55803 .48307 m
.55787 .48298 L
s
.55787 .48298 m
.55792 .4828 L
s
.55818 .48288 m
.55803 .48307 L
s
.55792 .4828 m
.55818 .48288 L
s
.55792 .4828 m
.55803 .48307 L
s
1 .008 0 r
.66312 .48139 m
.66287 .48101 L
s
.66292 .48101 m
.66301 .48107 L
s
.66283 .48111 m
.66292 .48101 L
s
.66292 .48101 m
.66287 .48101 L
s
.66293 .48117 m
.66283 .48111 L
s
.66283 .48111 m
.66287 .48101 L
s
.66301 .48107 m
.66293 .48117 L
s
.66287 .48101 m
.66301 .48107 L
s
.66287 .48101 m
.66293 .48117 L
s
1 .002 0 r
.72319 .33722 m
.72313 .33714 L
s
.72314 .33714 m
.72316 .33715 L
s
.72313 .33716 m
.72314 .33714 L
s
.72314 .33714 m
.72313 .33714 L
s
.72315 .33717 m
.72313 .33716 L
s
.72313 .33716 m
.72313 .33714 L
s
.72316 .33715 m
.72315 .33717 L
s
.72313 .33714 m
.72316 .33715 L
s
.72313 .33714 m
.72315 .33717 L
s
1 .009 0 r
.5997 .45152 m
.59935 .4511 L
s
.59942 .45109 m
.59952 .45115 L
s
.59932 .45121 m
.59942 .45109 L
s
.59942 .45109 m
.59935 .4511 L
s
.59942 .45127 m
.59932 .45121 L
s
.59932 .45121 m
.59935 .4511 L
s
.59952 .45115 m
.59942 .45127 L
s
.59935 .4511 m
.59952 .45115 L
s
.59935 .4511 m
.59942 .45127 L
s
1 .005 0 r
.76796 .47933 m
.76785 .4791 L
s
.76787 .4791 m
.76793 .47914 L
s
.76782 .47916 m
.76787 .4791 L
s
.76787 .4791 m
.76785 .4791 L
s
.76788 .47919 m
.76782 .47916 L
s
.76782 .47916 m
.76785 .4791 L
s
.76793 .47914 m
.76788 .47919 L
s
.76785 .4791 m
.76793 .47914 L
s
.76785 .4791 m
.76788 .47919 L
s
.70454 .44943 m
.70438 .44918 L
s
.70441 .44918 m
.70447 .44921 L
s
.70435 .44924 m
.70441 .44918 L
s
.70441 .44918 m
.70438 .44918 L
s
.70441 .44928 m
.70435 .44924 L
s
.70435 .44924 m
.70438 .44918 L
s
.70447 .44921 m
.70441 .44928 L
s
.70438 .44918 m
.70447 .44921 L
s
.70438 .44918 m
.70441 .44928 L
s
0 .042 1 r
.21985 .46561 m
.17633 .41972 L
s
.17633 .41972 m
.23644 .38836 L
s
1 .006 0 r
.64104 .41949 m
.64083 .41922 L
s
.64087 .41922 m
.64093 .41926 L
s
.64081 .4193 m
.64087 .41922 L
s
.64087 .41922 m
.64083 .41922 L
s
.64087 .41933 m
.64081 .4193 L
s
.64081 .4193 m
.64083 .41922 L
s
.64093 .41926 m
.64087 .41933 L
s
.64083 .41922 m
.64093 .41926 L
s
.64083 .41922 m
.64087 .41933 L
s
1 .003 0 r
.74608 .41737 m
.74598 .4172 L
s
.746 .41721 m
.74604 .41723 L
s
.74596 .41725 m
.746 .41721 L
s
.746 .41721 m
.74598 .4172 L
s
.746 .41727 m
.74596 .41725 L
s
.74596 .41725 m
.74598 .4172 L
s
.74604 .41723 m
.746 .41727 L
s
.74598 .4172 m
.74604 .41723 L
s
.74598 .4172 m
.746 .41727 L
s
0 .043 1 r
.23785 .37013 m
.22134 .44713 L
s
1 .004 0 r
.68251 .38737 m
.68238 .3872 L
s
.68241 .3872 m
.68245 .38722 L
s
.68237 .38725 m
.68241 .3872 L
s
.68241 .3872 m
.68238 .3872 L
s
.68241 .38727 m
.68237 .38725 L
s
.68237 .38725 m
.68238 .3872 L
s
.68245 .38722 m
.68241 .38727 L
s
.68238 .3872 m
.68245 .38722 L
s
.68238 .3872 m
.68241 .38727 L
s
0 .04 1 r
.26663 .47298 m
.21683 .50312 L
s
.23357 .4254 m
.26663 .47298 L
s
1 .002 0 r
.72411 .35515 m
.72403 .35505 L
s
.72405 .35505 m
.72407 .35506 L
s
.72402 .35508 m
.72405 .35505 L
s
.72405 .35505 m
.72403 .35505 L
s
.72405 .35509 m
.72402 .35508 L
s
.72402 .35508 m
.72403 .35505 L
s
.72407 .35506 m
.72405 .35509 L
s
.72403 .35505 m
.72407 .35506 L
s
.72403 .35505 m
.72405 .35509 L
s
1 .011 0 r
.60002 .47001 m
.59961 .46951 L
s
.59969 .46951 m
.59981 .46958 L
s
.59957 .46965 m
.59969 .46951 L
s
.59969 .46951 m
.59961 .46951 L
s
.59969 .46972 m
.59957 .46965 L
s
.59957 .46965 m
.59961 .46951 L
s
.59981 .46958 m
.59969 .46972 L
s
.59961 .46951 m
.59981 .46958 L
s
.59961 .46951 m
.59969 .46972 L
s
1 .006 0 r
.70537 .46792 m
.70518 .46763 L
s
.70521 .46763 m
.70529 .46767 L
s
.70514 .4677 m
.70521 .46763 L
s
.70521 .46763 m
.70518 .46763 L
s
.70522 .46775 m
.70514 .4677 L
s
.70514 .4677 m
.70518 .46763 L
s
.70529 .46767 m
.70522 .46775 L
s
.70518 .46763 m
.70529 .46767 L
s
.70518 .46763 m
.70522 .46775 L
s
0 .041 1 r
.21835 .48427 m
.17462 .43804 L
s
.17462 .43804 m
.23501 .40679 L
s
1 .007 0 r
.64157 .43785 m
.64131 .43753 L
s
.64136 .43753 m
.64143 .43757 L
s
.64128 .43762 m
.64136 .43753 L
s
.64136 .43753 m
.64131 .43753 L
s
.64136 .43766 m
.64128 .43762 L
s
.64128 .43762 m
.64131 .43753 L
s
.64143 .43757 m
.64136 .43766 L
s
.64131 .43753 m
.64143 .43757 L
s
.64131 .43753 m
.64136 .43766 L
s
1 .004 0 r
.74711 .43574 m
.74699 .43554 L
s
.74701 .43554 m
.74706 .43557 L
s
.74696 .43559 m
.74701 .43554 L
s
.74701 .43554 m
.74699 .43554 L
s
.74701 .43562 m
.74696 .43559 L
s
.74696 .43559 m
.74699 .43554 L
s
.74706 .43557 m
.74701 .43562 L
s
.74699 .43554 m
.74706 .43557 L
s
.74699 .43554 m
.74701 .43562 L
s
0 .042 1 r
.23644 .38836 m
.21985 .46561 L
s
1 .004 0 r
.68324 .4056 m
.68307 .4054 L
s
.68311 .4054 m
.68316 .40542 L
s
.68306 .40545 m
.68311 .4054 L
s
.68311 .4054 m
.68307 .4054 L
s
.68311 .40548 m
.68306 .40545 L
s
.68306 .40545 m
.68307 .4054 L
s
.68316 .40542 m
.68311 .40548 L
s
.68307 .4054 m
.68316 .40542 L
s
.68307 .4054 m
.68311 .40548 L
s
1 .003 0 r
.72503 .37326 m
.72493 .37313 L
s
.72495 .37313 m
.72498 .37314 L
s
.72492 .37316 m
.72495 .37313 L
s
.72495 .37313 m
.72493 .37313 L
s
.72496 .37318 m
.72492 .37316 L
s
.72492 .37316 m
.72493 .37313 L
s
.72498 .37314 m
.72496 .37318 L
s
.72493 .37313 m
.72498 .37314 L
s
.72493 .37313 m
.72496 .37318 L
s
0 .04 1 r
.21683 .50312 m
.17289 .45655 L
s
.17289 .45655 m
.23357 .4254 L
s
1 .008 0 r
.64209 .45639 m
.64178 .45601 L
s
.64184 .45601 m
.64194 .45606 L
s
.64176 .45612 m
.64184 .45601 L
s
.64184 .45601 m
.64178 .45601 L
s
.64185 .45617 m
.64176 .45612 L
s
.64176 .45612 m
.64178 .45601 L
s
.64194 .45606 m
.64185 .45617 L
s
.64178 .45601 m
.64194 .45606 L
s
.64178 .45601 m
.64185 .45617 L
s
1 .005 0 r
.74815 .45428 m
.748 .45405 L
s
.74803 .45405 m
.74809 .45408 L
s
.74797 .45411 m
.74803 .45405 L
s
.74803 .45405 m
.748 .45405 L
s
.74803 .45414 m
.74797 .45411 L
s
.74797 .45411 m
.748 .45405 L
s
.74809 .45408 m
.74803 .45414 L
s
.748 .45405 m
.74809 .45408 L
s
.748 .45405 m
.74803 .45414 L
s
0 .041 1 r
.23501 .40679 m
.21835 .48427 L
s
1 .005 0 r
.68397 .42401 m
.68377 .42376 L
s
.68381 .42376 m
.68387 .4238 L
s
.68375 .42383 m
.68381 .42376 L
s
.68381 .42376 m
.68377 .42376 L
s
.68381 .42387 m
.68375 .42383 L
s
.68375 .42383 m
.68377 .42376 L
s
.68387 .4238 m
.68381 .42387 L
s
.68377 .42376 m
.68387 .4238 L
s
.68377 .42376 m
.68381 .42387 L
s
1 .003 0 r
.72597 .39154 m
.72584 .39138 L
s
.72587 .39138 m
.72591 .3914 L
s
.72583 .39142 m
.72587 .39138 L
s
.72587 .39138 m
.72584 .39138 L
s
.72587 .39144 m
.72583 .39142 L
s
.72583 .39142 m
.72584 .39138 L
s
.72591 .3914 m
.72587 .39144 L
s
.72584 .39138 m
.72591 .3914 L
s
.72584 .39138 m
.72587 .39144 L
s
0 .04 1 r
.23357 .4254 m
.21683 .50312 L
s
1 .006 0 r
.6847 .4426 m
.68447 .44231 L
s
.68451 .44231 m
.68459 .44234 L
s
.68445 .44239 m
.68451 .44231 L
s
.68451 .44231 m
.68447 .44231 L
s
.68452 .44243 m
.68445 .44239 L
s
.68445 .44239 m
.68447 .44231 L
s
.68459 .44234 m
.68452 .44243 L
s
.68447 .44231 m
.68459 .44234 L
s
.68447 .44231 m
.68452 .44243 L
s
1 .004 0 r
.72691 .41 m
.72676 .4098 L
s
.72679 .4098 m
.72684 .40983 L
s
.72674 .40986 m
.72679 .4098 L
s
.72679 .4098 m
.72676 .4098 L
s
.72679 .40988 m
.72674 .40986 L
s
.72674 .40986 m
.72676 .4098 L
s
.72684 .40983 m
.72679 .40988 L
s
.72676 .4098 m
.72684 .40983 L
s
.72676 .4098 m
.72679 .40988 L
s
1 .005 0 r
.72786 .42864 m
.72768 .4284 L
s
.72771 .4284 m
.72777 .42843 L
s
.72766 .42847 m
.72771 .4284 L
s
.72771 .4284 m
.72768 .4284 L
s
.72772 .4285 m
.72766 .42847 L
s
.72766 .42847 m
.72768 .4284 L
s
.72777 .42843 m
.72772 .4285 L
s
.72768 .4284 m
.72777 .42843 L
s
.72768 .4284 m
.72772 .4285 L
s
0 g
.25 Mabswid
.61722 0 m
.96751 .49777 L
s
.96751 .49777 m
1 .78865 L
s
1 .78865 m
.62517 .31897 L
s
.62517 .31897 m
.61722 0 L
s
.04176 .22644 m
0 .5347 L
s
0 .5347 m
.62517 .31897 L
s
.62517 .31897 m
.61722 0 L
s
.61722 0 m
.04176 .22644 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 534.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009000025R000`400?l00000o`00003ooooonfYR
oookJP;o0000gOoonfX00?oooo]ZGooonfX3o`000003oookJ_l0003ooo]Z0=cooo]Z003ooookJUgo
oo]Z0_l00004oookJP;o0000g?oonfX00?oooo]ZF_oonfX3o`0000Kooo]Z00?o0000oookJ_l00000
fooonfX00?oooo]ZF?oonfX2o`0000Wooo]Z00?o0000oookJ_l00000fooonfX00?oooo]ZEOoonfX3
o`0000_ooo]Z00Co0000oookJ_oonf[o0000f_oonfX00?oooo]ZD_oonfX3o`0000kooo]Z00Go0000
oookJ_oonf[ooo]Zo`00003IoookJP00oooonfY@oookJP;o00004OoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z0=Kooo]Z003ooookJTgooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX0e_oonfX00?oooo]ZBooonfX2o`0001Kooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP3EoookJP00oooonfY8oookJP?o00006?oonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z0=Cooo]Z003ooookJTKooo]Z0_l0000KoookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0e?oonfX00?oooo]Z@ooonfX3o`0001gooo]Z00?o0000
oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP3CoookJP00oooonfY1oookJP;o00008?oonfX00ol0
003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z0=;ooo]Z003ooookJSkooo]Z0ol0000RoookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0dOoonfX00?oooo]Z??oonfX2o`0002Gooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP3AoookJP00oooonfXioookJP?o00009ooo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0=3ooo]Z003ooookJSOooo]Z0_l0000Z
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0cooonfX00?oooo]Z=?oonfX3o`00
02cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP3?oookJP00oooonfXaoookJP?o
0000<?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z0<kooo]Z003ooookJRoooo]Z
0_l0000coookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0cOoonfX00?oooo]Z;?oo
nfX3o`0003Gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP3=oookJP00oooonfXZ
oookJP;o0000>?oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z0<cooo]Z003ooook
JROooo]Z0ol0000joookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0booonfX00?oo
oo]Z9OoonfX2o`0003gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP3:oookJP00
oooonfXRoookJP?o0000?ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0<[ooo]Z
003ooookJR3ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0bOoo
nfX00?oooo]Z7OoonfX3o`0004Cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP38
oookJP00oooonfXKoookJP;o0000AooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z
0<Sooo]Z003ooookJQSooo]Z0ol00019oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oo
nfX0aooonfX00?oooo]Z5_oonfX2o`0004cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP36oookJP00oooonfXCoookJP?o0000C_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oo
nf[ooo]Z0<Gooo]Z003ooookJQ3ooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000
oookJ_oonfX0aOoonfX00?oooo]Z3_oonfX2o`0005Cooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP34oookJP00oooonfX;oookJP?o0000E_oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z0<?ooo]Z003ooookJPWooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX0`ooonfX00?oooo]Z1_oonfX3o`0005_ooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP32oookJP00oooonfX4oookJP;o0000G_oonfX00ol0003ooo]ZoookJP0F
oookJP03o`000?oonf[ooo]Z0<7ooo]Z003ooookJP7ooo]Z0ol0001PoookJP03o`000?oonf[ooo]Z
01Kooo]Z00?o0000oookJ_oonfX0`OoonfX00?kooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX0`?oonfX00?_ooo]Z0ol0001UoookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX0_ooonfX00?Wooo]Z0_l0001XoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o
0000oookJ_oonfX0__oonfX00?Kooo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000
oookJ_oonfX0__oonfX00?Cooo]Z0_l0001]oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oook
J_oonfX0_OoonfX00?7ooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0_?oonfX00>kooo]Z0ol0001boookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0
_?oonfX00>cooo]Z0_l0001eoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0^ooo
nfX00>Wooo]Z0ol0001goookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0^_oonfX0
0>Oooo]Z0_l0001joookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0^OoonfX00>Co
oo]Z0ol0001loookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0^OoonfX00>;ooo]Z
0_l0001ooookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0^?oonfX00=oooo]Z0ol0
0021oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0]ooonfX00=gooo]Z0_l00024
oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0]ooonfX00=[ooo]Z0ol00026oook
JP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0]_oonfX00=Sooo]Z0_l00029oookJP03
o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0]OoonfX00=Gooo]Z0ol0002;oookJP03o`00
0?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0]OoonfX00=?ooo]Z0_l0002?oookJP03o`000?oo
nf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0]?oonfX00=3ooo]Z0ol0002AoookJP03o`000?oonf[o
oo]Z02?ooo]Z00?o0000oookJ_oonfX0/ooonfX00<gooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX0/_oonfX00<_ooo]Z0_l0002GoookJP03o`000?oonf[ooo]Z02Co
oo]Z00?o0000oookJ_oonfX0/_oonfX00<Sooo]Z0ol0002IoookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX0/OoonfX00<Kooo]Z0_l0002LoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX0/?oonfX00<?ooo]Z0ol0002NoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX0/?oonfX00<7ooo]Z0_l0002QoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX0[ooonfX00;kooo]Z0ol0002SoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oo
nfX0[_oonfX00;cooo]Z0_l0002VoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0
[OoonfX00;Wooo]Z0ol0002XoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0[Ooo
nfX00;Oooo]Z0_l0002[oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0[?oonfX0
0;Cooo]Z0ol0002]oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0ZooonfX00;;o
oo]Z0_l0002`oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0ZooonfX00:oooo]Z
0ol0002boookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0Z_oonfX00:cooo]Z0ol0
002eoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0ZOoonfX00:[ooo]Z0_l0002h
oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0Z?oonfX00:Oooo]Z0ol0002joook
JP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0Z?oonfX00:Gooo]Z0_l0002moookJP03
o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0YooonfX00:;ooo]Z0ol0002ooookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0Y_oonfX00:3ooo]Z0_l00032oookJP03o`000?oo
nf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0Y_oonfX009gooo]Z0ol00034oookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX0YOoonfX009_ooo]Z0_l00037oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0Y?oonfX009Sooo]Z0ol00039oookJP03o`000?oonf[ooo]Z03;o
oo]Z00?o0000oookJ_oonfX0Y?oonfX009Kooo]Z0_l0003<oookJP03o`000?oonf[ooo]Z03?ooo]Z
00?o0000oookJ_oonfX0XooonfX009?ooo]Z0ol0003>oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX0X_oonfX0097ooo]Z0_l0003AoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000
oookJ_oonfX0XOoonfX008kooo]Z0ol0003CoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oook
J_oonfX0XOoonfX008_ooo]Z0ol0003FoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oo
nfX0X?oonfX008Wooo]Z0_l0003IoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0
WooonfX008Kooo]Z0ol0003KoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0Wooo
nfX008Cooo]Z0_l0003NoookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0W_oonfX0
087ooo]Z0ol0003PoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0WOoonfX007oo
oo]Z0_l0003SoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0W?oonfX007cooo]Z
0ol0003UoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0W?oonfX007[ooo]Z0_l0
003XoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0VooonfX007Oooo]Z0ol0003[
oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0V_oonfX007Gooo]Z0_l0003^oook
JP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0V_oonfX007;ooo]Z0ol0003`oookJP03
o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0VOoonfX0073ooo]Z0_l0003coookJP03o`00
0?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0V?oonfX006gooo]Z0ol0003eoookJP03o`000?oo
nf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0V?oonfX006[ooo]Z0ol0003hoookJP03o`000?oonf[o
oo]Z03kooo]Z00?o0000oookJ_oonfX0UooonfX006Sooo]Z0_l0003koookJP03o`000?oonf[ooo]Z
03oooo]Z00?o0000oookJ_oonfX0U_oonfX006Gooo]Z0ol0003moookJP03o`000?oonf[ooo]Z043o
oo]Z00?o0000oookJ_oonfX0UOoonfX006?ooo]Z0_l0003ooookJP7ooo]Z00?o0000oookJ_oonfX0
@?oonfX00ol0003ooo]ZoookJP2EoookJP00H?oonfX3o`000?oooo]Z0ooonfX00ol0003ooo]Zoook
JP11oookJP03o`000?oonf[ooo]Z09Cooo]Z001NoookJP;o0000oooonfX6oookJP03o`000?oonf[o
oo]Z04;ooo]Z00?o0000oookJ_oonfX0TooonfX005_ooo]Z0ol0003ooookJPSooo]Z00?o0000oook
J_oonfX0@_oonfX00ol0003ooo]ZoookJP2CoookJP00FOoonfX2o`000?oooo]Z2ooonfX00ol0003o
oo]ZoookJP13oookJP03o`000?oonf[ooo]Z09;ooo]Z001FoookJP?o0000oooonfX=oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?oo`00oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP2AoookJP00E?oo
nfX2o`000?oooo]Z4?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z093ooo]Z001A
oookJP?o0000oooonfXBoookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0T?oonfX0
04oooo]Z0_l0003ooookJQGooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP2?oook
JP00C?oonfX3o`000?oooo]Z5ooonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z08ko
oo]Z0019oookJP?o0000oooonfXJoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
S_oonfX004Oooo]Z0_l0003ooookJQgooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Zoook
JP2=oookJP00A?oonfX3o`000?oooo]Z7ooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z08cooo]Z0012oookJP;o0000oooonfXRoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oook
J_oonfX0S?oonfX003oooo]Z0ol0003ooookJRCooo]Z00?o0000oookJ_oonfX07?oonfX00ooo003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z08_ooo]Z000moookJP;o0000oooonfXWoookJP03o`00
0?oonf[ooo]Z03Cooo]Z00?oo`00oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2:oookJP00>_oo
nfX3o`000?oooo]Z:OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z08Wooo]Z000h
oookJP;o0000oooonfX/oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0ROoonfX0
03Gooo]Z0ol0003ooookJRkooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP28oook
JP00<ooonfX2o`000?oooo]Z<OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z08Oo
oo]Z000`oookJP?o0000oooonfXcoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0
QooonfX002kooo]Z0_l0003ooookJSKooo]Z00?o0000oookJ_oonfX0?_oonfX00ooo003ooo]Zoook
JP0>oookJP03o`000?oonf[ooo]Z08Kooo]Z000[oookJP?o0000oooonfXhoookJP03o`000?oonf[o
oo]Z00Gooo]Z00?oo`00oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP25oookJP00:?oonfX3o`00
0?oooo]Z>ooonfX00ol0003ooo]ZoookJP0LoookJP03ool00?oonf[ooo]Z03;ooo]Z00?o0000oook
J_oonfX0Q?oonfX002Kooo]Z0_l0003ooookJSkooo]Z00?o0000oookJ_oonfX0=?oonfX00ooo003o
oo]ZoookJP0JoookJP03o`000?oonf[ooo]Z08Cooo]Z000SoookJP?o0000oooonfY0oookJP03o`00
0?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0PooonfX0027ooo]Z0_l0003ooookJT?ooo]Z00?o
0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP22oookJP007_oonfX3o`000?oooo]ZAOoonfX0
0ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z08;ooo]Z000LoookJP;o0000K?oonfX2o`2>
o`03oookJ_l0=_oo03Ko0=Kooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP21oook
JP006OoonfX3o`0006cooo]Z0_l0S_l01Ooonf[o03Koo`0foooonf[o03Ko0=Oooo]Z00?o0000oook
J_oonfX09_oonfX00ooo003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z083ooo]Z000HoookJP;o
0000KOoonfX2o`2>o`;o03Ko0_l0S_l00ooonf[o03Koo`0fo`36oookJP03ool00?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX0?_oonfX00ooo003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z083o
oo]Z000HoookJP03o`000?oonf[o000006[ooo]Z0_l0S_l3o`0fo`04o`2>oooonf[ooo]Zo`0fo`;o
oo]Z00?o03KooookJ_oonfX0dooonfX00ol0003ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z04ko
oo]Z00?o0000oookJ_oonfX0OooonfX001Sooo]Z00Co0000oookJ_oonf[o0000IooonfX3o`2>o`?o
03Ko00Gooo]Zo`2>oooonf[ooo]Zo`0fo`02oookJP03o`0foooonf[ooo]Z0=?ooo]Z00?o0000oook
J_oonfX0E_oonfX00ol0003ooo]ZoookJP1noookJP006?oonfX01Ol0003ooo]ZoookJ_oonf[o0000
06Cooo]Z0ol0S_l3o`0fo`04o`2>oooonf[o03Koo`2>o`;ooo]Z00Go03Koo`2>oooonf[ooo]Zo`0f
o`3DoookJP03o`000?oonf[ooo]Z01cooo]Z00?oo`00oookJ_oonfX0>?oonfX00ol0003ooo]Zoook
JP1moookJP006?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z063ooo]Z0_l0S_l3
o`0fo`?ooo]Z0ol0S_l01ooonf[o03Koo`0foooonf[o08kooookJ_l0=_l0e?oonfX00ol0003ooo]Z
oookJP0doookJP03ool00?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0OOoonfX001Oooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP1MoookJP;o08ko0ol0=_l6oookJP;o08ko0_l0
=_l2o`0Oo`04o`2>oooonf[ooo]Zo`0fom?ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]Z
oookJP1loookJP005ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z05[ooo]Z0_l0
S_l3o`0fo`Sooo]Z0_l0S_l2o`0Oo`04oookJ_l07ooooo]Zo`2>o`;ooo]Z00?o03KooookJ_oonfX0
d?oonfX00ol0003ooo]ZoookJP18oookJP03ool00?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0
NooonfX001Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP1GoookJP;o08ko0ol0
=_l9oookJP04o`2>ool07ooo01ooo`0Oo`;o03Ko0_l07ol01?l0S_oooo]ZoookJ_l0=_oBoookJP03
o`000?oonf[ooo]Z00oooo]Z00?oo`00oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP1koookJP00
5ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z05Gooo]Z00Co08koo`0fool0=_oo
03Ko2ooonfX00ol07ooo08kooookJP02o`0fo`05o`0Oool0=_oooo]Zo`0Oool0S_l00_oonfX00ol0
=_oooo]ZoookJP2YoookJP03ool00?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX09_oonfX00ooo
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z07[ooo]Z000GoookJP03o`000?oonf[ooo]Z00So
oo]Z00?o0000oookJ_oonfX0D_oonfX01?l0S_oo03Koo`0fool0=_l;oookJP?o01oo00[o08kooook
J_l0=_oo03Koo`0Ooooonf[o03Koo`0Ooooonf[o08ko0_oonfX00ol0=_oooo]ZoookJP2noookJP03
ool00?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP1ioookJP00
5ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z04oooo]Z00Co08koo`0fool0=_oo
03Ko2ooonfX3o`0Oo`03o`2>oooonf[o08ko00;o03Ko00Oooo]Zo`0Oool0S_oooo]Zo`0fool07ooo
08ko00;ooo]Z00?o03KooookJ_oonfX0c_oonfX00ol0003ooo]ZoookJP0noookJP03ool00?oonf[o
oo]Z01_ooo]Z00?o0000oookJ_oonfX0N?oonfX001Oooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003ooo]ZoookJP1<oookJP;o08ko0_l0=_l;oookJP?o01oo0_oonfX2o`2>o`03oookJ_l07ooo03Ko
00;o01oo00Kooo]Zo`2>oooonf[o01oooookJ_l0S_l2oookJP03o`0foooonf[ooo]Z0<gooo]Z00?o
0000oookJ_oonfX01?oonfX00ooo003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z07Sooo]Z000F
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0S_oo03Koo`0fo`0;
oookJP?o01oo1?oonfX2o`2>o`03oookJ_l0=_oo03Ko00;o01oo0_oonfX01Ol0S_oooo]Zo`0Ooooo
nf[o08ko00;ooo]Z00?o03KooookJ_oonfX0c?oonfX00ol0003ooo]ZoookJP0LoookJP03ool00?oo
nf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0MooonfX001Kooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP17oookJP03o`2>ool0=_oo03Ko00_ooo]Z0ol07ol5oookJP08o`2>oooonf[o
08koo`0foooonf[o03Koo`0Oool05_l3oookJP04o`2>oooonf[o01ooo`2>o`;ooo]Z00?o03Kooook
J_oonfX0c?oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z07Kooo]Z000FoookJP03
o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0fo`cooo]Z0_l07ol7oookJP04
o`2>oooonf[o08koo`0fo`;o01Ko00?o01ooo`0FoooonfX00ooonfX01?l0S_oo01ooo`0fool0S_l2
oookJP03o`0foooonf[ooo]Z0<_ooo]Z00?o0000oookJ_oonfX0<OoonfX01?oo003ooo]ZoookJ_oo
000YoookJP03o`000?oonf[ooo]Z07Kooo]Z000FoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX0@ooonfX00ol0=_oo08kooookJP0:oookJP;o01oo2OoonfX2o`2>o`03oookJ_l05_oo
03Ko00;o01oo0_l05_l4oookJP06o`2>ool07ooo03Koo`2>oooonf[o03KobOoonfX01Ooo003ooo]Z
oookJ_oonf[o000004[ooo]Z00?oo`00oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP1eoookJP00
5_oonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o03KooookJ_l0S_l0
2?oonfX2o`0Oo`[ooo]Z00So08kooookJ_l05_oo01KooookJ_l0=_oo01ooo`0Fo`;ooo]Z00?o01Ko
oookJ_oonfX00_oonfX00ol0S_oo01ooo`0fo`02oookJP03o`0foooonf[ooo]Z08kooo]Z00?oo`00
oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0@oookJP03ool00?oonf[ooo]Z04gooo]Z00?o0000
oookJ_oonfX0M?oonfX001Kooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP12oook
JP03o`0foooonf[o08ko00Gooo]Z0ol07ol;oookJP?o01Ko00Go03KooookJ_l0=_oooo]Zo`0Fo`02
oookJP03o`0Fool07ooooo]Z00?ooo]Z00?o01oooookJ_l0=_l00_oonfX00ol0=_oooo]ZoookJP2S
oookJP03ool00?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP1d
oookJP005_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o03Kooook
J_l0S_l00_oonfX3o`0Oo`_ooo]Z0ol05_l01ooonf[o08koo`0Foooonf[o03Koo`0Oool05_l00ooo
nfX00ol05_oo01oooookJP03oookJP05o`0Oool0S_oo03KooookJ_l0=_l0booonfX00ol0003ooo]Z
oookJP0WoookJP03ool00?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0LooonfX001Kooo]Z00?o
0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP12oookJP03o`0foooonf[o01oo00;o01oo3?oo
nfX2o`0Fo`06oookJ_l0S_oooo]Zo`2>oooonf[o03Ko0_l07ol00ol05_oooo]ZoookJP02oookJP03
o`0Fool07ooooo]Z00?ooo]Z00Go01ooo`2>ool0=_oooo]Zo`0fo`2koookJP03ool00?oonf[ooo]Z
00cooo]Z00?o0000oookJ_oonfX0?ooonfX00ooo003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z
07;ooo]Z000EoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0@_oonfX2o`0Oo`03
o`2>oooonf[ooo]Z00Wooo]Z0_l05_l2oookJP09o`2>oooonf[o08koo`0foooonf[o03Koo`0Fool0
7ooo01Ko00Cooo]Z00?o01KooookJ_l07ol00ooonfX01_l07ooo08koo`2>ool0=_oooo]Zo`0folWo
oo]Z00?o0000oookJ_oonfX01OoonfX00ooo003ooo]ZoookJP1:oookJP03ool00?oonf[ooo]Z00ko
oo]Z00?o0000oookJ_oonfX0LOoonfX001Gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP0ooookJP;o01oo00Cooo]Zo`0foooonf[o08ko2?oonfX3o`0Fo`?ooo]Z00So08kooookJ_l0
S_oo03KooookJ_l0=_oooo]Zo`0Fo`Kooo]Z00?o01KooookJ_l07ol00ooonfX00ol07ooo08kooook
JP02o`0folWooo]Z00?o0000oookJ_oonfX06_oonfX00ooo003ooo]ZoookJP16oookJP03o`000?oo
nf[ooo]Z077ooo]Z000EoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0??oonfX2
o`0Oo`Cooo]Z00?o03KooookJ_l0S_l01OoonfX3o`0Fo`Gooo]Z00?o08kooookJ_l0S_l00_oonfX0
1?l0=_oo01ooo`0Fool05_l5oookJP04o`0Foooonf[ooo]Zo`0Oo`;ooo]Z00Co01oooookJ_l0S_oo
oo]Z0_l0=_o8oookJP03o`000?oonf[ooo]Z01cooo]Z00?oo`00oookJ_oonfX0AOoonfX00ol0003o
oo]ZoookJP1`oookJP005OoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z03[ooo]Z
00?o01oooookJ_oonfX01OoonfX00ol0=_oooo]Zo`2>o`03oookJP;o01Ko1_oonfX02Ol0S_oooo]Z
oookJ_l0S_oooo]Zo`0Oool0=_oo01ooo`0Fo`02o`0Ao`Gooo]Z00Co01KooookJ_oonf[o01oo0_oo
nfX01Ol07ooo08koo`2>oooonf[o03Ko0:kooo]Z00?oo`00oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP0aoookJP03ool00?oonf[ooo]Z00;oo`00;ooonfX00ol0003ooo]ZoookJP1_oookJP005Ooo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o01oooookJ_oonfX01Ooo
nfX00ol0=_oooo]Zo`2>o`02o`0Fo`Sooo]Z00co08kooookJ_l0S_oo03KooookJ_l0=_oooo]Zo`0A
ool05_oooo]Zo`0Aool05_l5oookJP04o`0Foooonf[ooo]Zo`0Oo`;o08ko00Go01oooookJ_oonf[o
oo]Zo`0fo`1eoookJP03ool00?oonf[ooo]Z04_ooo]Z00Goo`00oookJ_oonf[ooo]Zo`00000foook
JP03ool00?oonf[ooo]Z01;ooo]Z00?oo`00oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP1_oook
JP005OoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o01oooookJ_oo
nfX01OoonfX2o`0Fo`03o`2>oooonf[ooo]Z00Oooo]Z00?o08kooookJ_l0S_l00_oonfX2o`0Ao`03
o`0Oool05_oo017o00;o017o00?o01KooookJ_oonfX00_oonfX01ol05_oooo]Zo`2>ool0S_oo01oo
oookJ_l07ol00ooonfX2o`0foh[ooo]Z00?oo`00oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP1V
oookJP03o`000?oonf[ooo]Z06kooo]Z000EoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oook
J_oonfX0>_oonfX00ol07ooooo]ZoookJP03oookJP;o01Ko00?o03KooookJ_l0S_l01ooonfX01?l0
S_oooo]ZoookJ_l0S_l2o`0Ao`05o`0fool05_oo01KooookJ_l04Ol00_oonfX00ol04Ooo01Kooook
JP02oookJP03o`2>ool05_oooo]Z00;ooo]Z00?o01oooookJ_l07ol00_l0=_o8oookJP03o`000?oo
nf[ooo]Z013ooo]Z00?oo`00oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP1]oookJP005?oonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o01oooookJ_oonfX00_l05_l3
oookJP03o`0foooonf[o08ko00Kooo]Z00?o08kooookJ_l04Ol00ol04Ol01Ol0=_oo01ooo`0Foooo
nf[o017o00;ooo]Z00?o017ooookJ_l05_l00_l0S_l2oookJP07o`0Foooonf[ooo]ZoookJ_l07ooo
03Koo`0Oo`2SoookJP03ool00?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX09ooonfX00ooo003o
oo]ZoookJP0noookJP03o`000?oonf[ooo]Z06cooo]Z000DoookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX0>_oonfX2o`0Fo`Kooo]Z00?o03KooookJ_l0S_l01OoonfX3o`0Ao`06o`2>
oooonf[o01ooo`0fool07ooo01Ko0_l04Ol3oookJP03o`0Aool0S_oo01Ko00?ooo]Z00Go01Kooook
J_l0=_oo03KooookJP02o`0Ook[ooo]Z00?oo`00oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0l
oookJP03ool00?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0K?oonfX001Cooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP0goookJP;o01Ko00?ooo]Zo`0OoooonfX01_oonfX00ol0
=_oooo]Zo`2>o`03oookJP;o017o00Sooo]Zo`2>oooonf[o01ooo`0fool05_oo01ooo`0Fo`;o017o
00Oooo]Zo`2>ool0S_oooo]Zo`0Aoooonf[o01Ko00?ooo]Z00?o01KooookJ_oonfX00_oonfX2o`0O
okWooo]Z00?oo`00oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z
03Sooo]Z00?oo`00oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP1[oookJP005?oonfX00ol0003o
oo]ZoookJP0PoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o01KooookJ_oonfX00_oonfX00ol07ooo
oo]ZoookJP05oookJP03o`0foooonf[o08ko00;o017o00[o08kooookJ_oonf[o08kooookJ_l07ooo
03Koo`0Fool07ooo01Ko0_l04Ol01Ol0S_oooo]ZoookJ_oonf[o017o00;ooo]Z00Go01Koo`0fool0
=_oooo]Zo`0Fo`04oookJP03o`0Ooooonf[ooo]Z0<Kooo]Z00?o0000oookJ_oonfX01OoonfX00ooo
003ooo]ZoookJP1;oookJP03ool00?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0J_oonfX001Co
oo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0boookJP;o01Ko1_oonfX00ol07ooo
oo]ZoookJP05oookJP;o017o00go08kooookJ_l0S_oooo]Zo`0fool0S_oooo]Zo`0Oool0=_oooo]Z
o`0Fool0S_oo017o00Kooo]Z00Co017oo`0fool0=_oo01Ko0_oonfX00ol05_oooo]ZoookJP03oook
JP03o`0Ooooonf[ooo]Z09Gooo]Z00?oo`00oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0Koook
JP03ool00?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0J_oonfX001Cooo]Z00?o0000oookJ_oo
nfX08_oonfX00ol0003ooo]ZoookJP0`oookJP03o`0Foooonf[ooo]Z00Oooo]Z00?o01oooookJ_oo
nfX00_oonfX2o`0Ao`04oookJ_l0=_oooo]Zo`2>o`;ooo]Z00Oo03Koo`2>ool07ooooo]Zo`0fool0
7ooo01Ko00;o017o00?o00oooookJ_oonfX00_oonfX00ol0=_oo017ooookJP02oookJP04o`0Foooo
nf[ooo]Zo`0Fo`Cooo]Z0_l07omNoookJP03ool00?oonf[ooo]Z04_ooo]Z00?oo`00oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP0MoookJP03ool00?oonf[ooo]Z01;ooo]Z00?oo`00oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP1YoookJP005?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oo
nf[ooo]Z033ooo]Z00?o01KooookJ_oonfX01ooonfX00ol07ooooo]Zo`0Ao`02o`0Ao`?ooo]Z00[o
03Koo`2>ool0S_oooo]Zo`0fool0S_oo01ooo`0fool0S_oo01oo0_l03ol01?l04Ooo00ooo`0Aoooo
nfX2o`0fo`;ooo]Z00Go017ooookJ_oonf[ooo]Zo`0Fo`02oookJP04o`0Foooonf[o01ooo`0OogKo
oo]Z00?oo`00oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0eoookJP03ool00?oonf[ooo]Z03Co
oo]Z00?o0000oookJ_oonfX0J?oonfX001?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0`oookJP03o`0Foooonf[ooo]Z00Oooo]Z0_l04Ol6oookJP03o`0foooonf[o08ko00?o08ko
00Ko03Koo`0?ool03ooo01KooookJ_l04Ol2o`0?o`03o`0Aoooonf[ooo]Z00?ooo]Z00So017ooook
J_oonf[ooo]Zo`0Foooonf[o01Koo`0OolKooo]Z00Goo`00oookJ_oonf[ooo]Zo`00001<oookJP03
ool00?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0J?oonfX001?ooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP0`oookJP03o`0Foooonf[ooo]Z00Cooo]Z0_l04Ol00ooonf[o01oo
oookJP04oookJP06o`2>oooonf[o03Koo`0fool0S_oo01oo0ol03ol02?l05_oo017ooookJ_l03ooo
03KooookJ_l03ooo017o1?oonfX00ol04Ooooo]ZoookJP02oookJP;o01oo00?o01KooookJ_oonfX0
S?oonfX00ooo003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z013ooo]Z00?oo`00oookJ_oonfX0
B_oonfX00ooo003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z06Oooo]Z000CoookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0<?oonfX01?l05_oooo]ZoookJ_oonfX2o`0Ao`Cooo]Z
00?o01oooookJ_oonfX00_oonfX01?l0S_oooo]ZoookJ_l0=_l4o`0?o`05o`0Oool05_oo017oo`0A
ool03ol00_oonfX00ol03ooooo]Zo`0Ao`04oookJP05o`0Aoooonf[o01ooo`0OoooonfX00_l05_nT
oookJP03ool00?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX09?oonfX00ooo003ooo]ZoookJP16
oookJP03o`000?oonf[ooo]Z06Kooo]Z000CoookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oook
J_oonfX0<?oonfX00ol05_oo017oo`0Ao`07oookJP05o`0Ooooonf[ooo]ZoookJ_l0S_l00_oonfX2
o`0?o`08o`0Oool05_oo03Koo`0Oool05_oo03Koo`0Aool03ol3oookJP03o`0?oooonf[o017o00?o
oo]Z00?o01ooo`0AoooonfX00ooonfX2o`0Foj?ooo]Z00?oo`00oookJ_oonfX05?oonfX00ooo003o
oo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02Oooo]Z00?oo`00oookJ_oonfX04OoonfX00ooo003o
oo]ZoookJP0`oookJP03o`000?oonf[ooo]Z06Gooo]Z000CoookJP03o`000?oonf[ooo]Z02Wooo]Z
00?o0000oookJ_oonfX0;_oonfX2o`0Ao`03o`0Foooonf[ooo]Z00Oooo]Z00Co01oooookJ_oonf[o
08ko0_l03ol00ooonf[o01ooo`0fo`02o`0fo`05o`0Oool05_oooo]Zo`0Aool03ol01?oonfX01ol0
3ooooo]Zo`0Aoooonf[o01oooookJ_l04Ol01OoonfX2o`0Foh;ooo]Z00?oo`00oookJ_oonfX0=?oo
nfX00ooo003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX0IOoo
nfX001?ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0/oookJP;o017o0_oonfX0
0ol05_oooo]ZoookJP07oookJP0?o`0Oool03ooo00ooo`0?ool0=_oooo]Zo`0Ooooonf[o03Kooook
J_l07ooo01Koo`0?ool04Ooo00oo00Cooo]Z00Co00oooookJ_l07ooo017o0ooonfX00ol04Ooooo]Z
oookJP03oookJP03o`0Foooonf[ooo]Z04Wooo]Z00?oo`00oookJ_oonfX0NooonfX00ol0003ooo]Z
oookJP03oookJP03ool00?oonf[ooo]Z03Wooo]Z00?oo`00oookJ_oonfX04OoonfX00ooo003ooo]Z
oookJP0IoookJP03o`000?oonf[ooo]Z06Cooo]Z000CoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX0:OoonfX2o`0Ao`Gooo]Z00?o01KooookJ_oonfX01_oonfX2o`0?o`;ooo]Z00Co
03KooookJ_l07ooo01Ko0_oonfX01?l05_oooo]ZoookJ_l03ol5oookJP05o`0Oool03ooooo]Zoook
J_l04Ol00ooonfX00ol04Ooooo]ZoookJP03oookJP03o`0Foooonf[ooo]Z09Gooo]Z00?oo`00oook
J_oonfX0;_oonfX00ol0003ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z01?ooo]Z00?oo`00oook
J_oonfX0DooonfX00ol0003ooo]ZoookJP1SoookJP004ooonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o017ooookJ_oonfX01_oonfX00ol05_oooo]ZoookJP03oookJP;o
00oo00gooo]Zo`2>ool07ooo03KooookJ_l07ooooo]Zo`0Foooonf[o01ooo`0Foooonf[o017o00;o
00oo0ooonfX00ol07ooooo]Zo`0?o`03oookJP04o`0Aoooonf[ooo]Zo`0Ao`Gooo]Z0_l05_mNoook
JP03ool00?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP1Soook
JP004_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o017ooookJ_oo
nfX01ooonfX00ol05_oooo]ZoookJP02o`0?o`;ooo]Z013o08kooookJ_oonf[o01oooookJ_l07ooo
oo]Zo`0Foooonf[o01ooo`0Foooonf[o017oo`0?ool03Ooo00oo0_l07ol3oookJP05o`0?oooonf[o
oo]ZoookJ_l04Ol00_oonfX00ol04Ooooo]ZoookJP02o`0Fojkooo]Z00?oo`00oookJ_oonfX06?oo
nfX00ol0003ooo]ZoookJP0LoookJP03ool00?oonf[ooo]Z01;ooo]Z00?oo`00oookJ_oonfX04Ooo
nfX00ooo003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z06;ooo]Z000BoookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX09_oonfX00ol04Ooooo]ZoookJP07oookJP03o`0Fool03ooo
00oo00?ooo]Z00Co08kooookJ_oonf[o03Ko0_l07ol01Ol05_oooo]ZoookJ_l07ooo01Ko00;o00go
00Co00ooo`0=ool07ooo00oo1OoonfX01Ol03ooooo]ZoookJ_oonf[o017o00;ooo]Z00?o017oo`0F
oooonfX0MooonfX00ooo003ooo]ZoookJP1<oookJP05ool00?oonf[ooo]ZoookJ_l00000=ooonfX0
0ooo003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z067ooo]Z000BoookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX09_oonfX00ol04Ooooo]ZoookJP05oookJP;o00oo00?o01Kooook
J_oonfX00_oonfX01?l0S_oooo]Zo`0foooonfX2o`0Oo`03o`0Foooonf[ooo]Z00;o00go00?o00oo
o`0Aool03ol00_l03Ol00ooonf[o00oooookJP03oookJP03o`0?oooonf[ooo]Z00;ooo]Z00?o017o
o`0Fool04Ol0SooonfX00ooo003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z00kooo]Z00?oo`00
oookJ_oonfX0>?oonfX00ooo003ooo]ZoookJP0@oookJP03ool00?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX0H?oonfX001;ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0Voook
JP03o`0Aoooonf[ooo]Z00;ooo]Z0_l03ol3oookJP04o`0Foooonf[ooo]Zo`2>o`;ooo]Z00Go03Ko
oookJ_l07ooooo]Zo`0Oo`02o`0=o`05o`0Foooonf[o017oo`0?ool03Ol00_oonfX00ol03Ooooo]Z
o`0?o`04oookJP03o`0?oooonf[ooo]Z00;o01Ko00?o017ooookJ_l04Ol0YOoonfX00ooo003ooo]Z
oookJP0SoookJP03o`000?oonf[ooo]Z00oooo]Z0_oo000DoookJP03ool00?oonf[ooo]Z04_ooo]Z
00?o0000oookJ_oonfX0H?oonfX001;ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP0VoookJP03o`0Aoooonf[ooo]Z00;o00oo1OoonfX00ol05_oooo]Zo`2>o`02oookJP03o`0foooo
nf[o01oo00?o00go00Ko01ooo`0Fool07ooo017oo`0?ool03Ol2oookJP04o`0=oooonf[ooo]Zo`0?
o`Cooo]Z00?o00ooo`0FoooonfX00_oonfX2o`0Aofoooo]Z00?oo`00oookJ_oonfX0<_oonfX00ooo
003ooo]ZoookJP0DoookJP03ool00?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0M?oonfX00ol0
003ooo]ZoookJP1OoookJP004_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z02Ko
oo]Z0_l03ol8oookJP05o`0Fool0S_oooo]Zo`0foooonfX00ol03Ol2oookJP06o`0Oool05_oo00go
o`0Aool03ooo00go0ooonfX01Ol03Ooooo]ZoookJ_l03ooooo]Z00;o01Ko00?o00oooookJ_oonfX0
0ooonfX2o`0AocOooo]Z00?oo`00oookJ_oonfX0T?oonfX00ol0003ooo]ZoookJP0WoookJP03ool0
0?oonf[ooo]Z01;ooo]Z00?oo`00oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1NoookJP004_oo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02?ooo]Z0_l03ol00ooonf[o017ooook
JP07oookJP04o`2>ool05_oooo]Zo`0fo`;o00go00[ooo]Zo`0Foooonf[ooo]Zo`0Aool05_oo00oo
o`0Aool03ooo00go1?oonfX01?l03Ooooo]Zo`0Fool03ol3oookJP03o`0?oooonf[ooo]Z00?ooo]Z
0_l04On2oookJP03ool00?oonf[ooo]Z03Cooo]Z00?oo`00oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP04oookJP03ool00?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX0G_oonfX0017ooo]Z00?o
0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0QoookJP03o`0?oooonf[ooo]Z00;ooo]Z00?o
017ooookJ_oonfX01OoonfX01ol0S_oooo]Zo`0=ool03Ooooo]Zo`0Oool05_l00_oonfX01ol04Ooo
oo]Zo`0Fool03ooo017oo`0?ool03Ol01?oonfX01Ol03Ooo01KooookJ_oonf[o00oo00?ooo]Z00?o
00oooookJ_oonfX00ooonfX00ol04Ooooo]ZoookJP19oookJP03ool00?oonf[ooo]Z04[ooo]Z00?o
o`00oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0ooookJP03ool00?oonf[ooo]Z017ooo]Z00?o
o`00oookJ_oonfX04?oonfX00ooo003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z05gooo]Z000A
oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX07_oonfX2o`0?o`Kooo]Z00?o017o
oookJ_oonfX01?oonfX2o`0=o`05o`0fool05_oo01oooookJ_l05_l00_oonfX01Ol04Ooo01Koo`0?
ool04Ooo00oo00;o00go0ooonfX2o`0Fo`05o`0=oooonf[ooo]ZoookJ_l03ol00_oonfX00ol03ooo
oo]ZoookJP04oookJP03o`0Aoooonf[ooo]Z05gooo]Z00?oo`00oookJ_oonfX0I_oonfX00ol0003o
oo]ZoookJP04oookJP;oo`005OoonfX00ooo003ooo]ZoookJP0AoookJP03ool00?oonf[ooo]Z04Go
oo]Z00?o0000oookJ_oonfX0G?oonfX0017ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]Z
oookJP0LoookJP03o`0?oooonf[ooo]Z00Oooo]Z00Co017ooookJ_oonf[ooo]Z0_l03Ol2oookJP05
o`0foooonf[o01KooookJ_l05_l00_oonfX02?l04Ooo01Koo`0?ool04Ooo00ooo`0=oooonf[o00go
0_l05_l3oookJP05o`0=oooonf[ooo]ZoookJ_l03ol00_oonfX00ol03ooooo]ZoookJP03oookJP;o
017o[?oonfX00ooo003ooo]ZoookJP0CoookJP03ool00?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oo
nfX0MooonfX00ol0003ooo]ZoookJP1LoookJP004OoonfX00ol0003ooo]ZoookJP0ioookJP03o`00
0?oonf[ooo]Z01_ooo]Z00?o00oooookJ_oonfX02?oonfX01Ol04Ooo00goo`0=ool03Ooo08ko00;o
oo]Z00?o03KooookJ_l07ol00_l05_l02?oonf[o017ooookJ_l05_oo00ooo`0Aool03ooo00go0_l0
3?l00ol03Ooooo]ZoookJP02oookJP03o`0=oooonf[ooo]Z00;ooo]Z00Co00oooookJ_oonf[o00oo
0_oonfX2o`0AogGooo]Z0_oo000GoookJP03ool00?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
7OoonfX00ooo003ooo]ZoookJP0BoookJP03ool00?oonf[ooo]Z017ooo]Z00?oo`00oookJ_oonfX0
;ooonfX00ol0003ooo]ZoookJP1KoookJP004OoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z01_ooo]Z00?o00oooookJ_oonfX01ooonfX2o`0=o`;ooo]Z00Ko08kooookJ_l0=_oooo]Z
o`0OoooonfX2o`0Fo`0<oookJ_l04Ooooo]Zo`0Foooonf[o017oo`0<ool03Ooooo]Zo`0<oooonf[o
00go1?oonfX00ol03Ooooo]ZoookJP02oookJP03o`0?oooonf[o00oo00;o017oFOoonfX00ooo003o
oo]ZoookJP1[oookJP03ool00?oonf[ooo]Z00;o00004OoonfX00ooo003ooo]ZoookJP0SoookJP03
ool00?oonf[ooo]Z01;ooo]Z00?oo`00oookJ_oonfX04?oonfX00ooo003ooo]ZoookJP0IoookJP03
o`000?oonf[ooo]Z05[ooo]Z000AoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0
6ooonfX00ol03ooooo]ZoookJP04oookJP;o00go0_oonfX03_l04Ooo08kooookJ_oonf[o03Kooook
J_l07ooooo]Zo`0Foooonf[o01Koo`0Aoooonf[o01Ko0_l03?l00ol03ooo00goo`0<o`02o`0<o`03
oookJ_l03Ooooo]Z00?ooo]Z00?o00gooookJ_oonfX00_oonfX00ol03ooo017oo`0?o`2?oookJP03
ool00?oonf[ooo]Z01Cooo]Z00?oo`00oookJ_oonfX07ooonfX3o`000003oookJ_l0003ooo]Z03Ko
oo]Z00?oo`00oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP1IoookJP004OoonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z01_ooo]Z00Co00oooookJ_oonf[ooo]Z0_l03Ol5oookJP0;
o`0Aoooonf[ooo]Zo`0foooonf[o01oooookJ_l05_oooo]Zo`0Aool05_l00_l03?l01Ol04Ooo00oo
o`0=oooonf[o00co00;ooo]Z00?o00cooookJ_l03Ol00ooonfX01?l03Ooooo]ZoookJ_oonfX2o`0A
o`;o00oo9?oonfX00ooo003ooo]ZoookJP18oookJP03ool00?oonf[ooo]Z05?ooo]Z0ol00005oook
JP03o`000?oonf[ooo]Z00oooo]Z00?oo`00oookJ_oonfX04_oonfX00ooo003ooo]ZoookJP1Boook
JP03o`000?oonf[ooo]Z05Wooo]Z000AoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol03ooo00goo`0=o`07oookJP07o`2>ool04Ooo03KooookJ_l07ooooo]Zo`0Fo`02
oookJP;o00co00Oo01Koo`0<ool04Ooo00ooo`0=oooonf[o00co00;ooo]Z00Co00cooookJ_oonf[o
00go0ooonfX00ol03Ooo017oo`0Ao`03oookJP;o00oo=ooonfX00ooo003ooo]ZoookJP1ZoookJP03
ool00?oonf[ooo]Z01Cooo]Z00?oo`00oookJ_oonfX00ooonfX3o`0000Wooo]Z00?o0000oookJ_oo
nfX0>_oonfX00ooo003ooo]ZoookJP0@oookJP03ool00?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oo
nfX0F?oonfX0013ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0IoookJP;o00go
00?o00oooookJ_oonfX01_oonfX01ol0S_oooo]Zo`0Aoooonf[o01oooookJ_l05_l00_l03?l01ol0
4Ooooo]Zo`0?oooonf[o017oo`0?ool03Ol00_l03?l3oookJP05o`0<oooonf[ooo]Zo`0=oooonfX0
0_l04Ol00ol03Ooooo]ZoookJP03oookJP;o00ooPooonfX00ooo003ooo]ZoookJP0goookJP?o0000
3OoonfX00ol0003ooo]ZoookJP0FoookJP03ool00?oonf[ooo]Z00_ooo]Z0_oo001CoookJP03o`00
0?oonf[ooo]Z05Oooo]Z000@oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX05ooo
nfX2o`0=o`;ooo]Z00?o00oooookJ_oonfX01?oonfX01_l0S_oooo]ZoookJ_l0=_oo017oo`0Oo`?o
00co00So017ooookJ_oonf[o00oooookJ_l04Ooo00ooo`0=o`;o00co1?oonfX01?l03?oooo]Zo`0A
ool03Ol3oookJP03o`0=oooonf[ooo]Z00?ooo]Z00?o00oooookJ_oonfX0BOoonfX00ooo003ooo]Z
oookJP1/oookJP?o00004OoonfX01?l0003ooo]ZoookJ_oo000koookJP03ool00?oonf[ooo]Z017o
oo]Z00?oo`00oookJ_oonfX03ooonfX00ooo003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z05Oo
oo]Z000@oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX05?oonfX2o`0=o`Gooo]Z
00?o00oooookJ_oonfX00ooonfX01Ol0S_oooo]Zo`0foooonf[o01oo00;o00co0_oonfX00ol04Ooo
oo]Zo`0?o`02oookJP03o`0Aool03ooo00go00;o00co1?oonfX01Ol03?oo017ooookJ_oonf[o00go
00;ooo]Z00?o00gooookJ_oonfX01?oonfX00ol03ooooo]ZoookJP2FoookJP03ool00?oonf[ooo]Z
01Cooo]Z00?oo`00oookJ_oonfX01?oonfX3o`0001Cooo]Z00?o0000oookJ_oonfX05ooonfX00ooo
003ooo]ZoookJP0AoookJP03ool00?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0E_oonfX0013o
oo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0BoookJP03o`0=oooonf[ooo]Z00Ko
oo]Z00?o00oooookJ_oonfX00_oonfX00ol0S_oooo]Zo`0fo`02o`0<o`0;oookJ_l04Ooooo]Zoook
J_l04Ooooo]Zo`0?oooonf[o017oo`0?ool03Ol00_l03?l4oookJP;o017o00Go00cooookJ_oonf[o
oo]Zo`0=o`02oookJP03o`0=oooonf[ooo]Z00?ooo]Z0_l03omNoookJP;oo`006?oonfX00ooo003o
oo]ZoookJP0goookJP?o00003ooonfX00ooo003ooo]ZoookJP06oookJP04o`000?oonf[ooo]Zool0
07Sooo]Z00?o0000oookJ_oonfX0EOoonfX0013ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003o
oo]ZoookJP0AoookJP03o`0=oooonf[ooo]Z00Oooo]Z00Go00oooookJ_oonf[o08kooookJP02o`0<
o`04oookJ_l07ooooo]Zo`0Fo`;o017o0_oonfX01Ol03ooooo]Zo`0Aool03ooo00go00?o00co00?o
oo]Zo`0Aool04Ol00_oonfX00ol03?oooo]ZoookJP02oookJP04o`0=oooonf[ooo]Zo`0=o`;ooo]Z
0_l03om3oookJP03ool00?oonf[ooo]Z06Wooo]Z00?oo`00oookJ_oonfX00_l0000LoookJP03o`00
0?oonf[ooo]Z02cooo]Z00?oo`00oookJ_oonfX04OoonfX00ooo003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z05Cooo]Z000@oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX04Ooo
nfX00ol03Ooooo]ZoookJP07oookJP05o`0?oooonf[o00coo`0<ool0=_l00_oonfX01ol07ooo01Ko
oookJ_oonf[o017ooookJ_l03ol00_oonfX00ol04Ooo00ooo`0=o`02o`0<o`03o`0;ool03?oooo]Z
00Cooo]Z00?o00cooookJ_oonfX00_oonfX01Ol03Ooooo]Zo`0=oooonf[o00oo00oooo]Z00?oo`00
oookJ_oonfX0I_oonfX00ooo003ooo]ZoookJP0FoookJP03ool00?oonf[ooo]Z01gooo]Z0ol0000O
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX02ooonfX00ooo003ooo]ZoookJP1O
oookJP03o`000?oonf[ooo]Z05Cooo]Z000@oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oook
J_oonfX04OoonfX00ol03Ooooo]ZoookJP06oookJP;o00co00Oo08kooookJ_l0=_oooo]Zo`0Ooooo
nf[o01Ko00;ooo]Z0_l04Ol01Ol03ooooo]Zo`0=ool04Ooo00oo00;o00_o00Co00coo`0;oooonf[o
00co1OoonfX00ol03?oooo]ZoookJP02oookJP03o`0=ool03ooo00go05_ooo]Z00?oo`00oookJ_oo
nfX0BOoonfX00ooo003ooo]ZoookJP05oookJP?o00005ooonfX00ooo003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z04;ooo]Z00?oo`00oookJ_oonfX04OoonfX00ooo003ooo]ZoookJP0?oookJP03
ool00?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0DooonfX000oooo]Z00?o0000oookJ_oonfX0
AooonfX00ol0003ooo]ZoookJP0AoookJP03o`0=oooonf[ooo]Z00?ooo]Z0_l03?l02ooonf[o08ko
o`0?oooonf[o03KooookJ_l07ooooo]Zo`0Foooonf[o017o00;ooo]Z00?o017ooookJ_l03Ol00_l0
2ol00ol03Ooo00coo`0;o`02o`0;o`03oookJ_l03?oooo]Z00?ooo]Z00Co00cooookJ_oonf[ooo]Z
0_l03ol00ol03Ooooo]Zo`0=o`0SoookJP;oo`00JOoonfX2ool001Kooo]Z00?oo`00oookJ_oonfX0
0_oonfX3o`0002Kooo]Z00?o0000oookJ_oonfX07_oonfX00ooo003ooo]ZoookJP0=oookJP04ool0
0?oonf[ooo]Zool0013ooo]Z00?oo`00oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1BoookJP00
3ooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z017ooo]Z00?o00gooookJ_oonfX0
0_l03?l2ooo30004oookJ_l0S_oooo]Zo`0?o`;ooo]Z00So01ooo`0Foooonf[ooo]Zo`0Aoooonf[o
00oooookJP;o00_o00Go00ooo`0=ool03?oo00coo`0;o`02oookJP03o`0;oooonf[o00co00Cooo]Z
00?o00cooookJ_l03ol00ooonfX2o`0=ofoooo]Z00?oo`00oookJ_oonfX0=_oonfX3o`0001;ooo]Z
00?oo`00oookJ_oonfX04_oonfX01?oo003ooo]ZoookJ_l00009oookJP03ool00?oonf[ooo]Z06ko
oo]Z00?o0000oookJ_oonfX0D_oonfX000oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Z
oookJP0AoookJP03o`0=ool03?oool<000;ooo]Z0_oo``001ol0S_oooo]Zo`0fool03ooo01oooook
J_l05_l00_oonfX02ol04Ooooo]Zo`0;ool02ooo00goo`0;ool03ooo00gooookJ_l03?oo00_o00;o
oo]Z00Co00_ooookJ_oonf[o00co0ooonfX00ol03ooo00cooookJP04oookJP;o00go=ooonfX00ooo
003ooo]ZoookJP1:oookJP03ool00?oonf[ooo]Z01Cooo]Z00?oo`00oookJ_oonfX01_oonfX3o`00
02kooo]Z00?o0000oookJ_oonfX07_oonfX00ooo003ooo]ZoookJP0BoookJP03ool00?oonf[ooo]Z
013ooo]Z00?oo`00oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP1AoookJP003ooonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z00oooo]Z0_l03?l01Ol03Ooooo]ZoookJ_oo``3ooo]Z
00;ool<000Sooo]Zo`0foooonf[o00oooookJ_l05_oooo]Zo`0Ao`;o00_o00Wo00oooookJ_l03Ooo
oo]Zo`0?ool03Ooooo]Zo`0<ool02ol00ooonfX01?l02ooooo]ZoookJ_l03?l2o`0?o`03oookJ_l0
3?oooo]Z00Gooo]Z0_l03OmToookJP03ool00?oonf[ooo]Z01cooo]Z00?oo`00oookJ_oonfX06_oo
nfX3o`0002kooo]Z00Goo`00oookJ_oonf[ooo]Zo`00000@oookJP03ool00?oonf[ooo]Z00cooo]Z
00?oo`00oookJ_oonfX0??oonfX00ooo003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z053ooo]Z
000?oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX03?oonfX2o`0<o`0:ooo30?oo
nf[ooo]Zo`0=oooonf[ool<0oookJ_l0S_oool<0o`0fo`;ooo]Z00?o01ooo`0?oooonfX00ol02ol0
2?l03ooooo]ZoookJ_l03Ooooo]Zo`0?ool03Ooo00co0_l02ol4oookJP04o`0;oooonf[o00ooo`0<
o`?ooo]Z00?o00cooookJ_oonfX01?oonfX00ol03Ooooo]ZoookJP0]oookJP03ool00?oonf[ooo]Z
01Wooo]Z00?oo`00oookJ_oonfX0BooonfX01?oo003ooo]ZoookJ_oonfX3o`00013ooo]Z00?oo`00
oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z04Sooo]Z00?oo`00
oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1@oookJP003ooonfX00ol0003ooo]ZoookJP1<oook
JP03o`000?oonf[ooo]Z00Wooo]Z0_l03?l3oookJP07ooo30?oonf[ooo]Zo`0=oooo``3ooo]Zo`2>
o`02ooo30004oookJ_l07ooooo]Zo`0Fo`;o00_o00Go017ooookJ_l03ooooo]Zo`0=o`02oookJP03
o`0?ool03Ooo00co00;o00_o1?oonfX01Ol02ooo00oooookJ_oonf[o00co00?ooo]Z00?o00cooook
J_oonfX01?oonfX00ol03Ooooo]ZoookJP1MoookJP03ool00?oonf[ooo]Z01Kooo]Z00?oo`00oook
J_oonfX07OoonfX01?oo003ooo]Zo`000?l0000ioookJP03o`000?oonf[ooo]Z00oooo]Z00?oo`00
oookJ_oonfX04_oonfX00ooo003ooo]ZoookJP0=oookJP03ool00?oonf[ooo]Z047ooo]Z00?o0000
oookJ_oonfX0CooonfX000oooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP07oook
JP03o`0<oooonf[ooo]Z00Cooo]Z00Cool<0oookJ_oo``3o00go0_oo``001?oonf[o03KooookJ_l0
7ol2o`0;o`0=oookJ_l03ooooo]ZoookJ_l03ooooo]Zo`0=oooonf[o00ooo`0=oooonf[o00coo`0;
o`03oookJP;o00oo00?ooo]Zo`0;oooonfX00_oonfX01?l03?oooo]ZoookJ_l03?l6oookJP;o00go
@OoonfX00ooo003ooo]ZoookJP0JoookJP03ool00?oonf[ooo]Z03Gooo]Z0ol0000DoookJP03ool0
0?oonf[ooo]Z01Cooo]Z00?oo`00oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z04gooo]Z00?oo`00oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP1>oookJP003_oo
nfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o00cooookJ_oonfX01Ooo
nfX3ooo30004o`0=oooonf[ooo]Zo`0fo`;o00_o00ko01KooookJ_oonf[o017oo`0?oooonf[o00oo
oookJ_l03Ooooo]Zo`0?ool03Ooooo]Zo`0<o`;o00_o00?ooo]Zo`0?oooonfX00_oonfX00ol02ooo
oo]ZoookJP02oookJP04o`0<oooonf[ooo]Zo`0<o`?ooo]Z0_l03Ol=oookJP03ool00?oonf[ooo]Z
06Kooo]Z00?oo`00oookJ_oonfX05_oonfX00ooo003ooo]ZoookJP03oookJP?o0000@?oonfX00ol0
003ooo]ZoookJP0FoookJP03ool00?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX04OoonfX00ooo
003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z04gooo]Z000>oookJP03o`000?oonf[ooo]Z053o
oo]Z00?o0000oookJ_oonfX01_oonfX00ol03?oooo]ZoookJP05oookJP04ooo30?oonf[o08koo`0=
o`;o00_o00?o01oooookJ_l05_l00_oonfX01Ol04Ooooo]Zo`0?oooonf[o00go00;ooo]Z00Oo00oo
o`0=oooonf[o00coo`0;ool03ooo00_o00Gooo]Z00?o00_ooookJ_oonfX00_oonfX01_l03?oooo]Z
oookJ_l03?oooo]Zo`0=oe[ooo]Z00?oo`00oookJ_oonfX06ooonfX00ooo003ooo]ZoookJP0Ioook
JP?o00009_oonfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z013ooo]Z00Co0000oook
J_oonf[oo`003OoonfX00ooo003ooo]ZoookJP0noookJP03ool00?oonf[ooo]Z00oooo]Z00?oo`00
oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP1=oookJP003_oonfX00ol0003ooo]ZoookJP1Aoook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o00cooookJ_oonfX00ooonfX00ooo``3ooo]Zo`2>o`02o`0;
o`07o`0=oooonf[o01oooookJ_l05_oooo]Zo`0Ao`02oookJP;o00oo00Oo00gooookJ_oonf[o00oo
o`0=ool03?oo00oo00;o00_o00?ooo]Zo`0;oooonfX01?oonfX00ol02ooooo]ZoookJP02oookJP04
o`0<oooonf[o00coo`0=obCooo]Z00?oo`00oookJ_oonfX0HOoonfX00ooo003ooo]ZoookJP07oook
JP?o00004ooonfX00ooo003ooo]ZoookJP0NoookJP03ool00?oonf[ooo]Z013ooo]Z00?o0000oook
J_oonfX0:ooonfX00ooo003ooo]ZoookJP0>oookJP03ool00?oonf[ooo]Z03Wooo]Z00?o0000oook
J_oonfX0C?oonfX000kooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP06oookJP03
o`0<oooonf[ooo]Z00;ooo]Z00?ool<0o`0;ool02ol00_oonfX01?l03Ooooo]Zo`0Oool05_l2oook
JP06o`0Aoooonf[ooo]Zo`0?oooonf[o00oo0_oonfX01_l03ooo00goo`0;ool02ooooo]Zo`0;o`;o
oo]Z00?o00_ooookJ_oonfX00_oonfX00ol02ooooo]ZoookJP02oookJP;o00go00?ooo]Zo`0<oooo
nfX0D_oonfX00ooo003ooo]ZoookJP0JoookJP03ool00?oonf[ooo]Z01cooo]Z0ol00012oookJP03
ool00?oonf[ooo]Z00Kooo]Z00Go0000oookJ_oonf[ooo]Zool0000DoookJP03ool00?oonf[ooo]Z
00gooo]Z00?oo`00oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1;oookJP003_oonfX00ol0003o
oo]ZoookJP1CoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o00cooookJ_oonfX00_l02ol02?oonf[o
08kooookJ_l0=_oooo]Zo`0=oooonf[o01Ko0_oonfX02?l04Ooooo]Zo`0?oooonf[o00gooookJ_l0
2ooo00oo0_l02ol00ol03?oo00_oo`0;o`02o`0;o`;ooo]Z00?o00_ooookJ_oonfX00_oonfX01?l0
2ooooo]Zo`0=ool03Ol2oookJP;o00co7OoonfX00ooo003ooo]ZoookJP0HoookJP;oo`40D_oonfX3
o`0000kooo]Z00?oo`00oookJ_oonfX07_oonfX00ooo003ooo]ZoookJP0MoookJP03o`000?oonf[o
o`00043ooo]Z00?oo`00oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1;oookJP003_oonfX00ol0
003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z00Kooo]Z00ko00coo`0;oooonf[ool<0oookJ_l0
S_oooo]Zo`0foooonf[o01ooo`0=ool05_oooo]Zo`0Ao`;ooo]Z00?o00oooookJ_l02ol00ol02ol0
0ol03Ooo00_oo`0<o`02o`0;o`;ooo]Z00Co00_ooookJ_oonf[o00_o1?oonfX00ol02ooooo]Zoook
JP03oookJP;o00coI_oonfX00ooo003ooo]ZoookJP0KoookJP;oo`000ooonfX2o`0001[ooo]Z00?o
o`00oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z023ooo]Z00?o
o`00oookJ_oonfX0>OoonfX00ooo003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z04[ooo]Z000>
oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX01?oonfX2o`0;o`04o`0<oooo``3o
oo]Zo`2>o`;ooo]Z00Oo03KooookJ_l07ooo01Koo`0=oooonf[o017o00;ooo]Z00Wo00ooo`0;ool0
2ooo00_oool00?l03?oo00goo`0<oooonfX00_l02ol2oookJP06o`0;oooonf[ooo]ZoookJ_l02ooo
oo]Z0_l03Ol00ol02ooooo]ZoookJP04oookJP;o00co;ooonfX00ooo003ooo]ZoookJP0IoookJP;o
o`40>?oonfX3o`0002Wooo]Z00?oo`00oookJ_oonfX07_oonfX00ooo003ooo]ZoookJP09oookJP03
o`000?oonf[ooo]Z01Gooo]Z0_oo000JoookJP03ool00?oonf[ooo]Z027ooo]Z00?oo`00oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP19oookJP003_oonfX00ol0003ooo]ZoookJP1FoookJP04o`00
0?oonf[ooo]ZoookJP;o00_o0ooonfX03Ol03?oooo]Zo`2>oooonf[o03KooookJ_l07ooooo]Zo`0F
oooonf[o00goo`0AoooonfX00ol02ol2oookJP04o`0<oooonf[o00goo`0<o`?o00_o0ooonfX01Ol0
2ooooo]ZoookJ_l03Ooo00_o00?ooo]Z00?o00_ooookJ_oonfX01?oonfX00ol03?oooo]ZoookJP0]
oookJP03ool00?oonf[ooo]Z04Sooo]Z00?oo`00oookJ_oonfX01OoonfX3o`0001Gooo]Z00?oo`00
oookJ_oonfX07_oonfX2ool001oooo]Z00?oo`00oookJ_l000007ooonfX00ooo003ooo]ZoookJP0R
oookJP03ool00?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0B?oonfX000gooo]Z00?o0000oook
J_oonfX0F?oonfX00ol0003o00_oo`0;o`05oookJP0;ooo30?l03?oo08kooookJ_l0=_oooo]Zo`0O
oooonf[o01KooookJ_l04Ol01?l02ol01ol03Ooooo]ZoookJ_l03?oooo]Zo`0=ool03?l00ol02ol4
oookJP05o`0;ool03Ooooo]ZoookJ_l02ol00ooonfX00ol02ooooo]ZoookJP04oookJP03o`0<oooo
nf[ooo]Z047ooo]Z00?oo`00oookJ_oonfX06_oonfX00ooo0@3ooo]ZoookJP0KoookJP?o00009Ooo
nfX00ooo003ooo]ZoookJP0MoookJP03ool00?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX02?oo
nfX00ooo003ooo]ZoookJP0RoookJP03ool00?oonf[ooo]Z01Kooo]Z00?oo`00oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP18oookJP003OoonfX00ol0003ooo]ZoookJP1HoookJP03o`0;ool0003o
oo]Z00Cooo]Z00[ool<0oookJ_l0S_oo00cooookJ_l0=_oooo]Zo`0Oool05_oooo]Z1?l02ol00ol0
3ooooo]Zo`0=o`02oookJP04o`0<ool03Ooo00_oo`0<o`?o00_o0ooonfX00ol03Ooooo]Zo`0;o`03
oookJP04o`0;oooonf[ooo]Zo`0;o`Kooo]Z0_l03?l;oookJP03ool20?oonf[ooo]Z03?ooo]Z00?o
o`00oookJ_oonfX0:ooonfX00ooo003ooo]ZoookJP08oookJP?o00004OoonfX00ooo003ooo]Zoook
JP0MoookJP03ool00?oonf[ooo]Z023ooo]Z00?oo`00oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP0?oookJP03ool00?oonf[ooo]Z023ooo]Z00?oo`00oookJ_oonfX0@_oonfX00ol0003ooo]Zoook
JP17oookJP003OoonfX00ol0003ooo]ZoookJP1HoookJP03o`0;oooonf[o000000Cooo]Z00Wool<0
oookJ_l0S_oooo]Zo`0<oooonf[o01oooookJ_l05_l00ol02ol02ooonf[o00ooo`0=oooonf[o00go
oookJ_l03?oooo]Zo`0=ool02ooo00co00;o00_o00Cooo]Zo`0;ool03Ooo00go0_oonfX00ol02ooo
oo]ZoookJP02oookJP04o`0;oooonf[ooo]Zo`0;o`?ooo]Z0_l03?l=oookJP03ool20?oonf[ooo]Z
04Wooo]Z00?oo`00oookJ_oonfX06ooonfX00ooo0@3ooo]Zo`000002o`00043ooo]Z00?oo`00oook
J_oonfX07_oonfX01Ooo003ooo]ZoookJ_oonf[o000001oooo]Z00?oo`00oookJ_oonfX0>ooonfX0
0ooo003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z04Kooo]Z000=oookJP03o`000?oonf[ooo]Z
05Wooo]Z00?o00_ooookJ_l000000ooonfX01ooo``3ooo]Zo`2>oooonf[o03Koo`0<ool07ol00ol0
2ol01_l04Ooooo]ZoookJ_l03ooooo]Zo`0=o`;ooo]Z00Go00cooookJ_l03Ooo00cooookJP02o`0;
o`;o00go00?o00_ooookJ_oonfX00_oonfX00ol02ooooo]ZoookJP02oookJP06o`0;oooonf[ooo]Z
o`0;oooonf[o00co8ooonfX00ooo0P3ooo]ZoookJP0HoookJP03ool00?oonf[ooo]Z01Wooo]Z00?o
o`00oookJ_oonfX06ooonfX3o`0000gooo]Z00?oo`00oookJ_oonfX07OoonfX00ooo003ooo]Zoook
JP0NoookJP03ool00?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01_oonfX2ool001_ooo]Z00?o
o`00oookJ_oonfX08_oonfX00ooo003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z04Kooo]Z000=
oookJP03o`000?oonf[ooo]Z05[ooo]Z00Oo00_ooookJ_l0003ooo]Zooo30?oonf[o08ko00;ooo]Z
00Co03Koo`0;ool02ooo00_o0_oonfX01Ol04Ooooo]ZoookJ_l03ooooo]Z00;o00go00Oooo]Zo`0<
oooonf[o00goo`0<ool02ooo00go00;o00_o0_oonfX00ol02ooooo]ZoookJP02oookJP03o`0;oooo
nf[ooo]Z00;ooo]Z00Co00_ooookJ_l02ooo00co2_oonfX00ooo003ooo]ZoookJP0GoookJP03ool2
0?oonf[ooo]Z04[ooo]Z00?oo`00oookJ_oonfX00_oonfX3o`0001Oooo]Z00?oo`40oookJ_oonfX0
5OoonfX00ooo003ooo]ZoookJP0OoookJP03ool00?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP0?oookJP03ool00?oonf[ooo]Z02;ooo]Z0_oo000FoookJP03ool0
0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0AOoonfX000gooo]Z00?o0000oookJ_oonfX0Fooo
nfX01ol02ooooo]Zo`000?oo``3ooo]Zo`2>oooonfX00ol02ol01ol03?oo01KooookJ_oonf[o017o
oookJ_l03ol00_oonfX00ol03Ooooa<0o`0=o`02oookJP03o`0=ool03?oo00_o00?o00_o0ooonfX0
1Ol02ooooo]ZoookJ_oonf[o00_o00Cooo]Z0_l03?l00ooonf[o00_ooookJP1BoookJP03ool00?oo
nf[ooo]Z01_ooo]Z00?oo`00oookJ_oonfX00_l0000JoookJP03ool10?oonf[ooo]Z02cooo]Z00?o
o`00oookJ_oonfX08?oonfX01Ooo003ooo]ZoookJ_oonf[o000001Sooo]Z00?oo`00oookJ_oonfX0
1_oonfX00ooo003ooo]ZoookJP0AoookJP03ool00?oonf[ooo]Z00?ooo]Z00?oo`00oookJ_oonfX0
>ooonfX00ol0003ooo]ZoookJP14oookJP003OoonfX00ol0003ooo]ZoookJP1LoookJP05o`0;oooo
nf[o0000oookJ_l0S_l00_l02ol01_oonf[o01oooookJ_l03?oooo]Zo`0Ao`;ooo]Z00So00oooook
J_l03Ooooo]ZoolC0?l03?oo00_oo`0=o`?o00_o00Cooo]Zo`0;ool02ooo00_o0ooonfX01_l02ooo
oo]ZoookJ_oonf[o00_ooookJP;o00co0_oonfX2o`0;oagooo]Z0_oo000JoookJP03ool20?oonf[o
oo]Z03Gooo]Z0ol0000ZoookJP03ool00?oonf[ooo]Z01kooo]Z00?oo`00oookJ_oonfX02?oonfX0
0ooo003ooo]ZoookJP0EoookJP03ool00?oonf[ooo]Z00;ooo]Z00Go0000oookJ_oonf[ooo]Zool0
000KoookJP03ool00?oonf[ooo]Z00Gooo]Z00?oo`00oookJ_oonfX0>OoonfX00ooo003ooo]Zoook
JP0CoookJP03o`000?oonf[ooo]Z04?ooo]Z000<oookJP03o`000?oonf[ooo]Z05kooo]Z00co00_o
oookJ_l02ooo00_ooookJ_l0=_oooo]Zo`0Ooooonf[o01Koo`0<ool04Ol2oookJP04o`0?oooonf[o
00gooookJPCo00_o00?o00cooookJ_l02ol00_l02ol2oookJP05o`0;oooonf[ooo]ZoookJ_l02ol0
0ooonfX00ol02ooooo]ZoookJP03oookJP;o00_oIooonfX00ooo003ooo]ZoookJP03oookJP?o0000
5OoonfX2ool001oooo]Z00?oo`40oookJ_oonfX0?_oonfX01?l0003ooo]ZoookJ_oo000YoookJP03
ool00?oonf[ooo]Z02;ooo]Z00?oo`00oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP13oookJP00
3?oonfX00ol0003ooo]ZoookJP1NoookJP;o00_o00Oo08koo`000?l0=_oooo]Zo`0Ooooonf[o01Ko
00;ooo]Z00?o00cooookJ_l03ol00_oonfX02Ol03Ooo00_oo`0;ool02ooooo]Zo`0;ool03?oo00_o
oookJP02o`0;o`;ooo]Z00?o00_ooookJ_oonfX00_oonfX01_l02ooo00coo`0<oooonf[o00_oool9
00Cooo]Z0_l02ol`oookJP03ool00?oonf[ooo]Z01Wooo]Z00?oo`80oookJ_oonfX06_oonfX3o`00
02Oooo]Z00?oo`00oookJ_oonfX07?oonfX00ooo003ooo]ZoookJP0NoookJP;oo`002?oonfX00ooo
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00kooo]Z00?oo`00oookJ_oonfX0IOoonfX00ol0
003ooo]ZoookJP12oookJP003?oonfX00ol0003ooo]ZoookJP1LoookJP?o00_o00kooo]Zo`0;oooo
nf[o03KooookJ_l07ooooo]Zo`0Foooonf[o017ooookJ_l03?oo00oooookJP?o00_o00Oo00cooook
J_l02ooooo]Zo`0<ool02ooooo]Z00;o00_o0ooonfX00ol02ooooo]ZoookJP02o`0<o`05o`0;oooo
nf[ooo]Zo`0;oooo2@001OoonfX00ol02ooooo]ZoookJP1LoookJP03ool00?oonf[ooo]Z00Gooo]Z
0ol0000BoookJP03ool00?oonf[ooo]Z01gooo]Z00?oo`00oookJ_oonfX07ooonfX00ooo0@3ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z01Kooo]Z00?oo`00oookJ_oonfX08_oonfX00ooo003ooo]Z
oookJP02oookJP03ool00?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0@OoonfX000cooo]Z00?o
0000oookJ_oonfX0FooonfX2o`0;o`;ooo]Z00[o08kooookJ_l02ooo03Koo`000?l07ooooo]Zo`0F
oooonf[o017o0_oonfX4o`0;o`06oookJ_l03?oooo]Zo`0;oooonf[o00co1?l02ol4oookJP03o`0;
ool03?oooo]Z00;ooo]Z00Co00_ooookJ_oonf[o00_o1_oonfX00ol02ooooo]ZoookJP0VoookJP03
ool00?oonf[ooo]Z01Sooo]Z00?oo`40oookJ_oonfX06ooonfX01?oo0@3o0000o`000?l00012oook
JP03ool00?oonf[ooo]Z01gooo]Z00?oo`00oookJ_oonfX07OoonfX01?l0003ooo]ZoookJ_oo000T
oookJP;oo`00@?oonfX00ooo003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z047ooo]Z000<oook
JP03o`000?oonf[ooo]Z05Wooo]Z0_l02ol4oookJP07o`2>oooonf[o03Koo`0;ool07ooo0000o`0F
o`02oookJP03o`0Aool02ooo00_o00;o00_o00?o00gooookJ_l03?l00_oonfX01Ol02ooo00coo`0;
ool02ooooo]Z00;o00_o0ooonfX01Ol03?oo00_ooookJ_oonf[oo`0000;ooo]Z00Co00_ooookJ_oo
nf[o00_o1OoonfX2o`0;o`_ooo]Z00?oo`H0oookJ_oonfX0D?oonfX3o`0000oooo]Z00?oo`00oook
J_oonfX07?oonfX00ooo003ooo]ZoookJP0MoookJP03ool00?oonf[ooo]Z023ooo]Z0_oo0@0Coook
JP03o`000?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX08OoonfX00ooo003ooo]ZoookJP03oook
JP03ool00?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0@?oonfX000cooo]Z00?o0000oookJ_oo
nfX0F?oonfX00ol02ooooo]ZoookJP04oookJP09o`2>oooonf[o03KooookJ_l02ooooo]Zo`0Foooo
nf[o017o00?o00_o00Wooo]Zo`0=ool03?oooc`0o`0<oooonf[o00_ooookJ_l03?l01Ol02ol00ooo
nf[o00coo`0<o`02oookJP03o`0;oooonf[ooo]Z00?ooo]Z00?o00_ooookJ_l02ol00ooonfX2o`0;
ocgooo]Z00?oo`00oookJ_oonfX06OoonfX01?oo0@3ooo]ZoookJ_oonfX3o`0001Sooo]Z00?oo`40
oookJ_oonfX0@_oonfX00ooo003ooo]ZoookJP0OoookJP03ool00?oonf[ooo]Z00Kooo]Z00?oo`00
oookJ_l000006?oonfX00ooo003ooo]ZoookJP0koookJP03ool00?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX0?ooonfX000cooo]Z00?o0000oookJ_oonfX0F?oonfX00ol02ooooo]ZoookJP03oook
JP08o`2>oooonf[ooo]Zo`0foooonf[o01ooo`0;ool05_l3o`0;o`05oookJ_l03ooooo]Zo`0=oooo
?0000_l03?l01_oonf[o00_ooookJ_l03?oo00_ooookJP;o00_o00?o00coo`0;oooonfX01?oonfX0
0ol02ooooo]ZoookJP03oookJP05o`0;oooonf[o00_ooookJ_l02ol02OoonfX00ooo0@3ooo]Zoook
JP0GoookJP;oo`@0>?oonfX2o`0002[ooo]Z00?oo`00oookJ_oonfX07?oonfX2ool0023ooo]Z0_oo
000QoookJP03o`000?oonf[oo`4001cooo]Z00?oo`00oookJ_oonfX08_oonfX01Ooo003ooo]Zoook
J_oonf[oo`0002oooo]Z00?o0000oookJ_oonfX0?ooonfX000cooo]Z00?o0000oookJ_oonfX0FOoo
nfX00ol02ooooo]ZoookJP02oookJP06o`2>oooonf[o03KooookJ_l07ooooo]Z0ol02ol00ol04Ooo
oo]Zo`0?o`02oookJP0:o`0=oooonf[o00coo`0<oooonf[o00_ooookJ_l03?oo00_ooookJP;o00_o
00?o00[ooookJ_l02ol01?oonfX00ol02ooooo]ZoookJP04oookJP?o00_oE?oonfX00ooo003ooo]Z
oookJP04oookJP?o00004ooonfX2ool101kooo]Z00?oo`40oookJ_oonfX08_oonfX00ooo003ooo]Z
oookJP0BoookJP03ool00?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX05OoonfX00ol0003ooo]Z
ool10008oookJP03ool00?oonf[ooo]Z02;ooo]Z00?oo`00oookJ_oonfX0A_oonfX00ol0003ooo]Z
oookJP0noookJP002ooonfX00ol0003ooo]ZoookJP1KoookJP03o`0;oooonf[ooo]Z00?ooo]Z00?o
03KooookJ_l02ol00ol02ol01_l04Ooooo]Zo`000?l03ooooo]Zo`0=o`;ooo]Z00?o00cooookJ_l0
3?l00_oonfX01_l03?oo00_oo`0:ool02_oo00_oo`0:o`;ooo]Z00?o00_ooookJ_oonfX00_oonfX0
0ol02ooooo]ZoookJP02oookJPCo00_o7_oonfX00ooo0P3ooo]ZoookJP0HoookJP03ool30?oonf[o
oo]Z01cooo]Z0ol0000VoookJP03ool00?oonf[ooo]Z00gooo]Z00?oo`40oookJ_oonfX02ooonfX0
0ooo003ooo]ZoookJP0NoookJP03ool00?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX03_oonfX0
0ooo003ooo]ZoookJP0KoookJP03ool00?oonf[ooo]Z00?ooo]Z00?oo`00oookJ_oonfX0@OoonfX0
0ol0003ooo]ZoookJP0moookJP002ooonfX00ol0003ooo]ZoookJP1LoookJP03o`0;oooonf[ooo]Z
00;ooo]Z00Oo03Koo`0;ool02ooooo]Zo`0Foooonf[o00_o00;ooo]Z00?o00oooomO0?l03Ol00_oo
nfX01Ol03?oooo]Zo`0;ool02_oo00co00;o00[o0ol02ol2o`0:o`;ooo]Z00?o00_ooookJ_oonfX0
0_oonfX01?l02ooooo]Zo`0;ool02ol3oookJP;o00_o>OoonfX00ooo0`3ooo]ZoookJP0?oookJP03
ool00?oonf[ooo]Z00Kooo]Z0ol0000AoookJP03ool00?oonf[ooo]Z01_ooo]Z00?oo`40oookJ_oo
nfX0=_oonfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z01Gooo]Z00?oo`00oookJ_oo
nfX01_oonfX01Ooo003ooo]ZoookJ_oonf[o000001Sooo]Z00?oo`00oookJ_oonfX01?oonfX00ooo
003ooo]ZoookJP0joookJP03ool00?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0??oonfX000_o
oo]Z00?o0000oookJ_oonfX0GOoonfX00ol02ooooo]ZoookJP02o`0;o`03o`0Ooooonf[o01Ko00;o
oo]Z00?o017oo`0;ool03ol00_ooG`001?l03Ooooel0o`0<oooonfX4o`0:o`05o`0;oooonf[o00_o
o`0;ool02_l00_oonfX01?l02_oooo]ZoookJ_l02ol3oookJP;o00_o0_oo5004oookJP;o00_o5Ooo
nfX2ool001Wooo]Z00?oo`80oookJ_oonfX07OoonfX3o`0003;ooo]Z00?oo`40oookJ_oonfX03?oo
nfX00ooo003ooo]ZoookJP0?oookJP03ool10?oonf[ooo]Z00[ooo]Z00?oo`00oookJ_oonfX07ooo
nfX00ooo003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z02?ooo]Z00?oo`00oookJ_oonfX08Ooo
nfX01Ooo003ooo]ZoookJ_oonf[oo`0002Wooo]Z00?o0000oookJ_oonfX0??oonfX000_ooo]Z00?o
0000oookJ_oonfX0G_oonfX2o`0;o`07o`0foooonf[o01oooookJ_l05_oooo]Zo`0Ao`02oookJP06
o`0;ooooG`3o00goo`000?ooG`3o00co0ol02_l00ooonf[o00_oo`0;o`03o`0;o`04o`0:oooonf[o
oo]Zo`0:o`?ooo]Z00?o00_ooookJ_l02ol00_l02ol00ooonf[ooa@0oookJP04oookJP;o00_oC?oo
nfX3o`0000kooo]Z00?oo`00oookJ_oonfX06ooonfX00ooo003ooo]ZoookJP1FoookJP03ool00?oo
nf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP06oookJP03ool00?oo
nf[ooo]Z00Gooo]Z00?oo`00oookJ_oonfX01?oonfX00ooo003ooo]ZoookJP1MoookJP03o`000?oo
nf[ooo]Z03_ooo]Z000;oookJP03o`000?oonf[ooo]Z05cooo]Z1?l02ol01ol0=_oooo]Zo`0Ooooo
nf[o01KooookJ_l04Ol00_oonfX01?l03ooo00_oo`0=ooooG`03o`0:o`03o`0;oooonf[ooo]Z00;o
00_o00Co00[oo`0;ool02ooo00[o0ooonfX00ol02_oooo]ZoookJP02o`0;o`?ooo]Z00?o00_ooook
J_oo50001OoonfX00ol02ooooo]ZoookJP0VoookJP03ool00?oonf[ooo]Z01Wooo]Z00?oo`80oook
J_oonfX00_oonfX3o`0004oooo]Z00?oo`40oookJ_oonfX02_oonfX00ooo003ooo]ZoookJP0Boook
JP03ool10?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP0Ioook
JP03o`000?oonf[ooo]Z03?ooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP0Voook
JP03ool00?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0>_oonfX000_ooo]Z00?o0000oookJ_oo
nfX0FooonfX2o`0;o`;ooo]Z00Go03Koo`0;ool07ooooo]Zo`0Fo`02oookJP03o`0Aoooonf[o00oo
00;ooo]Z1?l02_l01Ooonf[o00_ooookJ_l02ooooo]Z00Co00_o00?o00[ooookJ_oonfX00_oonfX0
1Ol02_oo00_ooookJ_oo1P3o00_o00?ooo]Z00?o00_ooookJ_oonfX01OoonfX00ol02ooooo]Zoook
JP09oookJP03ool;0?oonf[ooo]Z03Gooo]Z00?oo`80oookJ_l000000_l0000HoookJP;oo`803ooo
nfX00ooo003ooo]ZoookJP0LoookJP03ool00?oonf[ooo]Z03Cooo]Z00?oo`00oookJ_oonfX08?oo
nfX00ooo003ooo]ZoookJP02oookJP05o`000?oonf[ooo]ZoookJ_oo00007?oonfX00ooo003ooo]Z
oookJP04oookJP03ool00?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0>_oonfX000_ooo]Z00?o
0000oookJ_oonfX0FOoonfX2o`0;o`Cooo]Z00Oo03KooookJ_l02ooooo]Zo`0Foooonf[o017o00;o
oo]Z00?o00ooo`0:ool02_l00_l02_l00ol03?oooo]Zo`0;o`02oookJP?o00_o00Cooo]Zo`0;ool0
2ooo00[o0ooonfX00ol02ooo00[ooookJP03oookJP04o`0;oooonf[ooo]Zo`0;o`Oooo]Z0_l02ol;
oookJP03ool;0?oonf[ooo]Z02cooo]Z00?oo`00oookJ_oonfX01OoonfX2o`0004[ooo]Z00?oo`00
oookJ_oonfX02ooonfX00ooo003ooo]ZoookJP0@oookJP;oo`402_oonfX00ooo003ooo]ZoookJP0E
oookJP03ool10?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX07OoonfX00ooo003ooo]ZoookJP09
oookJP03ool00?oonf[ooo]Z02;ooo]Z00?oo`00oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0i
oookJP002_oonfX00ol0003ooo]ZoookJP1IoookJP03o`0;oooonf[ooo]Z00Cooo]Z00Oo03Kooook
J_l07ooo00_oo`0Foooonf[o017o00;ooo]Z0ol02_l2oookJP05o`0;ooooG`3o00_oo`000?oonfX0
1Ol02ol2o`0:o`03oookJ_l02ooo00_o00;ooo]Z00?o00[ooookJ_oonfX00_oonfX01?l02ooooo]Z
oookJ_l02ol5oookJP03o`0;oooonf[ooo]Z00Cooo]Z0_oo1P0IoookJP03ool70?oonf[ooo]Z01go
oo]Z0ol0000EoookJP03ool10?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX02ooonfX2ool200ko
oo]Z00?oo`00oookJ_oonfX0BooonfX00ooo0@3ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z00Ko
oo]Z00?oo`00oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0>oookJP03ool00?oonf[ooo]Z00Co
oo]Z00?oo`00oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0hoookJP002_oonfX00ol0003ooo]Z
oookJP1IoookJP03o`0;oooonf[ooo]Z00?ooo]Z00So03KooookJ_l07ooooo]Zo`0Fool02ooooo]Z
o`0Ao`?o00[o00GoogL0o`0=oooonf[o00cooookJP02o`0;o`03oookJ_l02ooooo]Z00Co00_o00?o
00[oo`0;ool02_l01OoonfX00ol02_oooo]ZoookJP02oookJP04o`0;oooonf[ooo]Zo`0;o`;ooo]Z
0_l02olRoookJP03ool70?oonf[ooo]Z017ooo]Z00?oo`00oookJ_oonfX01_oonfX3o`00013ooo]Z
00?oo`00oookJ_oonfX0D_oonfX2ool000_ooo]Z00?oo`00oookJ_oonfX04ooonfX00ooo0@3ooo]Z
oookJP07oookJP03ool00?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0>_oonfX00ooo003ooo]Z
oookJP02oookJP03ool00?oonf[ooo]Z02Cooo]Z00?oo`00oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0goookJP002_oonfX00ol0003ooo]ZoookJP1JoookJP03o`0;oooonf[ooo]Z00;ooo]Z00Oo
03KooookJ_l07ooooo]Zo`0Foooonf[o00_o00;o00[o00?oogL0oookJ_ooM`000_ooM`002Ol03?oo
oo]Zo`0;ool02ooooo]Zo`0;ool0003o00_ooookJP02o`0;o`04o`0:oooonf[ooo]Zo`0:o`Cooo]Z
00?o00[ooookJ_oonfX00ooonfX00ol02ooooo]Zo`0;o`02o`0;o`Cooo]Z00?oo`00oookJ_oonfX0
5_oonfX00ooo1@3ooo]ZoookJP0NoookJP?o00004ooonfX00ooo003ooo]ZoookJP0JoookJP03ool1
0?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX06ooonfX00ooo003ooo]ZoookJP0ZoookJP03ool1
0?oonf[ooo]Z027ooo]Z0_oo0@04oookJP04o`000?oonf[ooo]Zool000Oooo]Z00?oo`00oookJ_oo
nfX08?oonfX00ooo003ooo]ZoookJP03oookJP03ool00?oonf[ooo]Z047ooo]Z00?o0000oookJ_oo
nfX0=ooonfX000[ooo]Z00?o0000oookJ_oonfX0FooonfX00ol02ooooo]ZoookJP03oookJP03o`0O
oooonf[o00[o00;o00[o00Go00_ooookJ_ooM`3oogL0o`0=o`02oookJP04o`0<oooonf[o00_ooook
JP;o00_o00?ooo]Zo`0;oooonfX00_l02ol3o`0:o`03oookJ_l02_oooo]Z00?ooo]Z00?o00[ooook
J_oo80000_oo80001?oonf[o00_oo`0;ool02olNoookJP03ool50?oonf[ooo]Z01Wooo]Z00?oo`D0
oookJ_l000000_l0000>oookJP03ool00?oonf[ooo]Z01[ooo]Z00?oo`40oookJ_oonfX09OoonfX0
0ooo0P3ooo]ZoookJP0/oookJP03ool00?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX09ooonfX0
0ooo003ooo]Zo`00000VoookJP;oo`00;_oonfX00ooo003ooo]ZoookJP0NoookJP03o`000?oonf[o
oo]Z03Kooo]Z000:oookJP03o`000?oonf[ooo]Z05cooo]Z00Ko00_ooookJ_oonf[ooo]Zo`0Ooooo
nfX2o`0:o`04oookJ_l04Ooooo]Zo`0;o`;oogL000?o00gooookJ_l03?l00_oonfX00ol02ooooa<0
o`0;o`02o`0;o`;o00[o00Go00_oo`0:ool02_oooo]Zo`0:o`02oookJP03o`0:oooonf[ooo]Z00;o
oo]Z00Co00[ooolP0?oo803ooo]Z0ol02ol00ooonf[o00_ooookJP0FoookJP03ool00?oonf[ooo]Z
01Oooo]Z0_oo1005oookJP?o0000;OoonfX00ooo0@3ooo]ZoookJP0LoookJP03ool10?oonf[ooo]Z
00_ooo]Z0_oo000ZoookJP03ool00?oonf[ooo]Z01oooo]Z0_oo0@08oookJP03ool00?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX03ooonfX00ooo0@3ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z
00?ooo]Z00?oo`00oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0eoookJP002_oonfX00ol0003o
oo]ZoookJP1MoookJP03o`0;oooonf[ooo]Z00;o00[o00?o01KooookJ_l04Ol00_oonfX02_l03ooo
00_ooomg0?oonf[oogL0o`0<oooo4`3o00_ooolC0?oonfX2o`0:o`03o`0;ool02_oo00[o00;o00[o
00Cooo]Zo`0:ool02_oo00[o0_oonfX01_l02_oooo]ZoookJ_oo5`3o00[ooookJP;o00_o0ooonfX2
o`0;oc7ooo]Z0_oo1002oookJP?o00005_oonfX00ooo103ooo]ZoookJP0?oookJP03ool00?oonf[o
oo]Z04Gooo]Z00?oo`40oookJ_oonfX02_oonfX00ooo003ooo]ZoookJP0OoookJP03ool00?oonf[o
oo]Z00Oooo]Z00?oo`00oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0=oookJP03ool10?oonf[o
oo]Z033ooo]Z00Goo`00oookJ_oonf[ooo]Zool0000_oookJP03o`000?oonf[ooo]Z03Gooo]Z000:
oookJP03o`000?oonf[ooo]Z05kooo]Z00Oo00_oo`0:ool07ooooo]Zo`0Foooonf[o017o00;ooo]Z
00co00oooookJ_l02oooogL0oookJ_l03?oooo]Zo`0;oooonf[o00[oo`0;oooonfX2o`0:o`;o00_o
00?o00[ooookJ_l02_l00_oonfX01?l02_oooo]ZoookJ_l02_l2oolG0005oookJ_l02_oooo]Zoook
J_oo80000ooonfX2o`0;ob[ooo]Z00?oo`40oookJ_oonfX01?oonfX3o`0001Wooo]Z00?oo`@0oook
J_oonfX0;OoonfX00ooo0@3ooo]ZoookJP0;oookJP03ool00?oonf[ooo]Z00oooo]Z00?oo`40oook
J_oonfX02_oonfX00ooo003ooo]ZoookJP0YoookJP03ool00?oonf[ooo]Z01oooo]Z00Co0000oook
J_oonf[oo`401_oonfX2ool000Kooo]Z00?oo`00oookJ_oonfX08?oonfX00ooo003ooo]ZoookJP10
oookJP03o`000?oonf[ooo]Z03Cooo]Z000:oookJP03o`000?oonf[ooo]Z05cooo]Z0ol02_l00ol0
2ooooo]Zo`0Fo`02oookJP0:o`0Aoooonf[ooo]Zo`0?oooonf[o00goo`0;ool03?oooo]Zoomg00;o
00[o00Go00_oo`0:ool02_oo00_ooookJP02o`0;o`03o`0:ool0003o00[o00;ooo]Z00Go00[ooook
J_oonf[ooo]Zo`0:o`02o`0;o`03oookJ_l02_oooo]Z00Gooo]Z0_l02ol<oookJP03ool@0?oonf[o
oo]Z01oooo]Z0_l0000DoookJP03ool30?oonf[ooo]Z00oooo]Z00?oo`00oookJ_oonfX06_oonfX0
0ooo003ooo]ZoookJP0UoookJP;oo`403?oonfX00ooo003ooo]ZoookJP0BoookJP03ool10?oonf[o
oo]Z00Sooo]Z0_oo0009oookJP03ool00?oonf[ooo]Z01kooo]Z00Koo`00oookJ_oonf[o0000oook
J_oo0@0/oookJP03ool00?oonf[ooo]Z02[ooo]Z00?oo`00oookJ_oonfX06OoonfX00ol0003ooo]Z
oookJP0coookJP002OoonfX00ol0003ooo]ZoookJP1LoookJP;o00[o0_oonfX01Ol07ooo00_oo`0F
oooonf[o017o00;ooo]Z00?o00oooookJ_l03Ol00_oonfX01?l02ooo00[oo`0:oooonfX2o`0:o`04
oookJ_l02ooooo]ZoookJP;o00_o0ol02_l3oookJP05o`0:oooonf[o00_oo`0;ool02_l00ooonfX0
0ol02_oooo]ZoookJP04oookJP03o`0;oooonf[ooo]Z00Gooo]Z00?oo`h0oookJ_oonfX00ooonfX0
0ooo403ooo]ZoookJP0BoookJP03ool00?oonf[ooo]Z00Kooo]Z0ol0000?oookJP03ool10?oonf[o
oo]Z02;ooo]Z00?oo`<0oookJ_oonfX0;?oonfX2ool100cooo]Z00?oo`00oookJ_oonfX07?oonfX0
0ooo0@3ooo]ZoookJP0/oookJP03ool00?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX07OoonfX0
0ooo003ooo]ZoookJP03oookJP03ool00?oonf[ooo]Z02Cooo]Z00?oo`00oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP0coookJP002OoonfX00ol0003ooo]ZoookJP1JoookJP;o00[o1?oonfX01Ol0
7ooooo]Zo`0;oooonf[o017o00;ooo]Z0oooQ`02oookJP0:o`0:ool02ooo00[oo`0:oooonf[o00_o
oookJ_l02ooooo]Zo`0:o`;o00_o0ol02_l01Ol0003oo`00oookJ_oonf[o00[o00?ooo]Z00Co00[o
oookJ_oonf[o00[o1ooonfX00ol02ooooo]ZoookJP03oookJP;oo`h08?oonfX3o`0001;ooo]Z00?o
o`40oookJ_oonfX06OoonfX00ooo0P3ooo]ZoookJP0>oookJP03ool00?oonf[ooo]Z04Gooo]Z0_oo
0@0;oookJP03ool00?oonf[ooo]Z01kooo]Z00?oo`00oookJ_oonfX01_oonfX00ooo003ooo]Zoook
JP0>oookJP03o`000?oonf[ooo]Z01Gooo]Z0_oo000_oookJP03ool00?oonf[ooo]Z02_ooo]Z00?o
0000oookJ_oonfX0<_oonfX000Wooo]Z00?o0000oookJ_oonfX0FOoonfX00ol02_oooo]ZoookJP03
oookJP06o`0Ooooonf[o01KooookJ_l02ooo017o0_oonfX00oooQ`3ooo]Zoon70004o`0:o`03o`0;
oooonf[o00_o00;ooo]Z00Ko00_oooll0?l02ooo00_oo`0:oooonfX2o`0:o`06oookJ_l0003o00_o
o`0;oooonf[o00[o0ooonfX01?l02_oooo]ZoookJ_l02_l6oookJP;o00_o1OoonfX00ooo3P3ooo]Z
oookJP0GoookJP04ool:0?oonf[ooo]ZoookJP?o00003_oonfX00ooo003ooo]ZoookJP0QoookJP03
ool20?oonf[ooo]Z01_ooo]Z00?oo`<0oookJ_oonfX03OoonfX00ooo003ooo]ZoookJP0MoookJP03
ool10?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX07ooonfX00ooo0@3ooo]ZoookJP05oookJP03
ool00?oonf[oo`0001[ooo]Z00?o0000oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP04oookJP03
ool00?oonf[ooo]Z02Kooo]Z00?oo`00oookJ_oonfX09OoonfX00ooo003ooo]ZoookJP0BoookJP03
o`000?oonf[ooo]Z037ooo]Z0009oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o00[ooookJ_oonfX0
0ooonfX02Ol07ooooo]Zo`0Foooonf[o017oo`0;oooonf[o00oooon70004o`0:o`03oon70?l02ooo
oo]Z00;o00_o00CoogL0o`0;oooo?03ooc`00_l02ol3o`0:o`04oookJ_l02_oo00_oo`0000;ooo]Z
00Ko00[ooookJ_oonf[oob/0oookJ_l02_l2oookJP04o`0:oooonf[ooo]ZoookJP;o00_o00?ooo]Z
ool10?oonfX05ooonfX2ool900Kooo]Z0ol0000/oookJP03ool10?oonf[ooo]Z01_ooo]Z00?oo`80
oookJ_oonfX03OoonfX00ooo003ooo]ZoookJP0VoookJP03ool10?oonf[oo`0001oooo]Z00?oo`40
oookJ_oonfX01ooonfX2ool002Gooo]Z00Go0000oookJ_oonf[ooo]Zool00005oookJP03ool00?oo
nf[ooo]Z023ooo]Z00?oo`00oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z033ooo]Z0009oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o00[ooookJ_oonfX01?oonfX0
1Ol05_oooo]Zo`0Aoooonf[o00_o00;o00[o00KoohL0o`0:oooonf[o00cooon70?l02ol2oookJP05
o`0;oooonf[o00_oooll0?l02_l00_l02ol3o`0:o`05o`0;oooonf[o00[ooookJ_l000000_oonfX0
2?l02_ooob/0ool[0?oo:`3ooo]Zo`0:oooonf[o00[o0_oonfX00ol02ooooo]ZoookJP0KoookJP04
ool90?oonf[ooo]ZoookJP?o00005?oonfX00ooo1`3ooo]ZoookJP0@oookJP;oo`009?oonfX00ooo
0P3ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z02Cooo]Z00?oo`00oookJ_oonfX0:OoonfX00ooo
003oo`40oookJP0SoookJP03ool10?oonf[ooo]Z00Gooo]Z0_oo0003oookJP03o`000?oonf[ooo]Z
02Cooo]Z00?oo`00oookJ_oonfX09_oonfX00ooo003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
033ooo]Z0009oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o00[ooookJ_oonfX00_oonfX01ol05_oo
oo]ZoookJ_l04Ooooo]Zo`0:ool02ol00_l02_l02?oonf[o00cooon70?oonf[o00_ooookJ_l02ooo
oc`00_l02ol01oooM`3o00[oo`0;ool02ooo00[oo`0;ool02_l00ooonfX01_l02_oooo]Zo`000?oo
nf[oobd0o`0:o`;oob/00_oonfX01?l02_oooo]Zo`0:ool02olGoookJP03ool20?oonf[ooo]Z00Go
oo]Z0ol0000GoookJP;oo`L02_oonfX00ooo003ooo]ZoookJP0QoookJP03ool10?oonf[ooo]Z02Ko
oo]Z00?oo`80oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP0WoookJP03ool10?oonf[ooo]Z02[o
oo]Z00Goo`00oookJ_oonf[ooo]Zool10003oookJP03ool00?oonf[ooo]Z00Oooo]Z00?o0000oook
J_oonfX05_oonfX00ooo003ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z05Cooo]Z00?o0000oook
J_oonfX0;ooonfX000Wooo]Z00?o0000oookJ_oonfX0G?oonfX01ol02_oooo]ZoookJ_oonf[o01Ko
oookJ_l04Ol01?l02_l00ol02oooohL0oon70002oon70005o`0;oooonf[ooc`0o`0;oooonfX00_l0
2ol01?oonf[o00[oo`0;ool02ol4o`0:o`?ooo]Z00Go00[ooookJ_l0003ooo]Zo`0:o`02oookJP06
ool[0?oonf[o00_oo`0;oooonf[o00[o4OoonfX00ooo003ooo]ZoookJP08oookJP?o00004ooonfX0
0ooo1P3ooo]ZoookJP0/oookJP03ool00?oonf[ooo]Z02Cooo]Z00?oo`80oookJ_oonfX0:ooonfX0
0ooo003ooo]ZoookJP09oookJP03ool00?oonf[ooo]Z023ooo]Z00?oo`40oookJ_oonfX01_oonfX0
0ooo003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00kooo]Z00?oo`00oookJ_oonfX01?oonfX0
0ooo003ooo]ZoookJP0UoookJP03ool00?oonf[ooo]Z02Cooo]Z00?oo`00oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP0^oookJP002?oonfX00ol0003ooo]ZoookJP1NoookJP04o`0:oooonf[ooo]Z
o`0Fo`Co00[o00oo00oooookJ_l03Ooo00_ooon70?l03?ooohL0o`0;oooo?03ooo]Zo`0;oooonf[o
00_ooookJ_l02_l00_l02ol3o`0:o`03oookJ_l02_oooo]Z00?ooo]Z00Ko00[ooookJ_oo;@3ooo]Z
o`0:oooonfX2o`0;o`;ooo]Z0_l02_lJoookJP;o00003ooonfX00ooo0`3ooo]ZoookJP0QoookJP03
ool50?oonf[ooo]Z00oooo]Z00?oo`00oookJ_oonfX06ooonfX00ooo0@3ooo]ZoookJP0;oookJP03
ool00?oonf[ooo]Z01Wooo]Z0_oo0P0;oookJP03ool00?oonf[ooo]Z023ooo]Z00?oo`40oookJ_oo
nfX01_oonfX00ooo003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z00Kooo]Z00?oo`40ool00?oo
nfX01?oonfX00ooo003ooo]ZoookJP0OoookJP03ool00?oonf[ooo]Z00Kooo]Z0_oo000ioookJP03
o`000?oonf[ooo]Z02kooo]Z0008oookJP03o`000?oonf[ooo]Z05oooo]Z00?o00[oo`0Fool02_l0
0_l02_l2oookJP05o`0?oooonf[o00gooookJ_l02ol00_oonfX00ol02ooooo]Zo`0;o`02oookJP?o
00[o00?o00_oo`0:ool02_l01Ol02_l4oookJP07o`0:oooo;@3o0000oookJ_l02_oooo]Zool[0003
oookJP;o00[o3OoonfX00ooo5P3ooo]ZoookJP06oookJP?o00004OoonfX00ooo0`3ooo]ZoookJP0I
oookJP03ool50?oonf[ooo]Z00Gooo]Z00?oo`D0oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP0R
oookJP;oo`40:OoonfX01?oo0P3ooo]ZoookJ_oo000ZoookJP03ool00?oo0@3ooo]Z02Kooo]Z00?o
o`00oookJ_l000000_oonfX00ooo003ooo]ZoookJP03oookJP03ool10?oonf[ooo]Z02;ooo]Z00?o
o`00oookJ_oonfX09OoonfX00ooo003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02gooo]Z0008
oookJP03o`000?oonf[ooo]Z05oooo]Z0ol02_l01?l04Ooooo]ZoookJ_l03ol2oookJP03o`0=oooo
nf[o00co00;o00_o00Gooo]Zoon70?l02ooooo]Zo`0:o`02oookJP;o00[o00?o00_oo`0:ooooG`00
0_l02_l2oookJP03o`0:oooonf[ooo]Z00;ooo]Z00Go00[oo`0;ool02ooooo]Zo`0:o`05oookJP;o
00[o1_oonfX3oolG00?ooo]Z0_oo5P04oookJP?o00003OoonfX2ool0027ooo]Z00?oo`D0oookJ_oo
nfX0:ooonfX2ool002Oooo]Z0_oo0P02oookJP03ool00?oonf[ooo]Z02Oooo]Z0_oo000[oookJP05
ool00?oonf[ooo]ZoookJ_oo0@001OoonfX00ol0003ooo]ZoookJP0LoookJP03ool00?oonf[ooo]Z
00Gooo]Z0_oo000NoookJP03ool00?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0;?oonfX000So
oo]Z00?o0000oookJ_oonfX0GOoonfX3o`0:o`03o`0Fool02_oo017o00;ooo]Z00?o00oooookJ_oo
T@000oooT@001?oonf[o00_ooookJ_oonfX2o`0:o`03o`0;ool02_oo00[o00;ooo]Z00?o00_oo`0:
ooooG`000_l02_l00ooonf[oo`80o`0:o`03oookJP;o00_o00Co00[ooookJ_l0003o00[o1_oonfX0
0ol02_oooo]ZoookJP05oookJP03oolG0?oonf[ooo]Z00Cooo]Z00CooaH0o`000?l0003o0000:ooo
nfX2ool302Cooo]Z00?oo`@0oookJ_oonfX01OoonfX00ooo003ooo]ZoookJP0ToookJP;oo`400ooo
nfX00ooo003ooo]ZoookJP0UoookJP03ool20?oo003ooo]Z02Wooo]Z00Coo`00oookJ_oonf[oo`40
4ooonfX00ol0003ooo]ZoookJP0?oookJP03ool00?oonf[ooo]Z00?ooo]Z0_oo000YoookJP03ool0
0?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0:ooonfX000Sooo]Z00?o0000oookJ_oonfX0G?oo
nfX2o`0:o`05oookJ_l05_oooo]ZoookJ_l02_l00_oonfX01?l03ooooo]ZoonA0?oonfX3oonA0004
o`0;ool02_oo00[ooon700;o00[o00Gooo]Zo`0:oooonf[ooo]Zo`0;o`04o`0:o`?ooo]Z00?o00[o
o`0;ool02ol00ooonfX01?l02_oooo]Zo`000?l02_l6oookJP03o`0:oooonf[ooo]Z00Cooo]Z00?o
oaL0oookJ_oonfX00_oonfX3o`0001;ooo]Z0_oo3@0CoookJP03ool00?oonf[ooo]Z027ooo]Z00?o
o`@0oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP0SoookJP03ool00?oonf[ooo]Z02Oooo]Z0_oo
0@000ooo003ooo]ZoookJP0WoookJP04ool00?oonf[ooo]Zool0023ooo]Z00?o0000oookJ_oonfX0
1ooonfX00ooo003ooo]ZoookJP04oookJP03ool10?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0
:ooonfX000Sooo]Z00?o0000oookJ_oonfX0F_oonfX2o`0:o`?ooo]Z00Ko01KooookJ_l04Ooooo]Z
o`0:ool03ol2oookJP;ooi4000Go00cooookJ_l02ooo00[ooookJP02o`0:o`08o`0;oooonf[ooo]Z
o`0:oooonf[o00_oo`0:ooooG`03o`0:o`?ooo]Z00Co00_oo`0:oooonf[ooo]Z0_oo=0001Ooonf[o
00[ooookJ_l0003o00[o00Gooo]Z0_l02_l00ooo1P3ooo]ZoookJP04oookJP?o00003ooonfX00ooo
3P3ooo]ZoookJP03oookJP;oo`d03?oonfX00ooo003ooo]ZoookJP0PoookJP03ool20?oonf[ooo]Z
02Cooo]Z00?oo`<0oookJ_oonfX01?oonfX00ooo003ooo]ZoookJP0VoookJP03ool10?oonf[oo`00
02cooo]Z00?oo`40oookJ_oonfX01_oonfX2ool0027ooo]Z00?o0000oookJ_oonfX01_oonfX00ooo
003ooo]ZoookJP04oookJP03ool10?oonf[ooo]Z023ooo]Z00?oo`00oookJ_oonfX09OoonfX00ooo
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02[ooo]Z0008oookJP03o`000?oonf[ooo]Z05Wo
oo]Z00?o00[ooookJ_oonfX01OoonfX01Ol04Ooooo]ZoookJ_l02_oooo]Z00?ooi4000?o00coo`0:
ool02_l00_l02_l3o`0;o`07oon70?l02_oooel0oomO0?l02ooo00[ooomO0003o`0:o`03oookJ_l0
2ooo00_o00;ooo]Z00?o00[ooolo0?oo=0000_oo=0001_oonf[o00[ooookJ_l02_oo0000ool000;o
oo]Z00?o00[ooookJ_oonfX01?oonfX3o`0001;ooo]Z00?oo`h0oookJ_oonfX0;?oonfX00ooo0@3o
oo]ZoookJP05oookJP03ool20?oonf[ooo]Z01_ooo]Z00?oo`<0oookJ_oonfX01?oonfX00ooo003o
oo]Zool3000_oookJP03ool10?oonf[ooo]Z02[ooo]Z00?oo`00ool10?oonfX0:?oonfX01_oo003o
oo]ZoookJ_l0003ooo]Zool002?ooo]Z00?oo`00oookJ_oonfX01OoonfX2ool001gooo]Z00?oo`00
oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0YoookJP001ooonfX00ol0003ooo]ZoookJP1Joook
JP03o`0:oooonf[ooo]Z00Gooo]Z00Go017ooookJ_oonf[o00ooo`0:o`02oonA00Co00[o00Oooo]Z
o`0;oooonf[ooo]Zo`0;ooooG`3o00[o00;ooo]Z00?o00_oo`0:oooonfX00_l02_l00ol02ooo00[o
oookJP03oookJP03o`0:oooonf[ooc@000;ooc@00_oonfX01?l02_oooo]Zo`0:ool00002o`0:o`Go
oo]Z0_l0000?oookJP03ool70?oonf[ooo]Z00?ooo]Z00?oo`h0oookJ_oonfX06?oonfX2ool901;o
oo]Z00?oo`40oookJ_oonfX08ooonfX00ooo0`3ooo]ZoookJP0[oookJP;oo`00:_oonfX00ooo003o
o`40oookJP0XoookJP05ool00?oonf[ooo]ZoookJ_oo00002ooonfX00ol0003ooo]ZoookJP0Eoook
JP03ool00?oonf[ooo]Z00Cooo]Z0_oo000XoookJP03ool00?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX0:OoonfX000Oooo]Z00?o0000oookJ_oonfX0FooonfX00ol02_oooo]ZoookJP03oookJP04
o`0Aoooonf[ooo]Zo`0?o`;ooo]Z0_l02_l04?ooT@3o00[ooonA0?ooT@3ooo]Zo`0;oooonf[o00_o
oomO0?l02ooo00[ooon70?oonf[o00_oo`0:oooonfX2o`0:o`;ooo]Z00?o00[ooookJ_oonfX00_oo
nfX01Ol02_ooocl0oookJ_oonf[ooc@000;ooo]Z0ol02_l01?l0003ooo]ZoookJ_oonfX3o`00017o
oo]Z00?oo`L0oookJ_oonfX05ooonfX2ool900Kooo]Z00?oo`T0oookJ_oonfX02OoonfX00ooo003o
oo]ZoookJP0QoookJP03ool20?oonf[ooo]Z02Kooo]Z00Coo`<0oookJ_oonf[ooo]Z0_oo000Yoook
JP;oo`40:?oonfX00ooo003ooo]ZoookJP02ool000;ooo]Z00?oo`40oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP0>oookJP03ool00?oonf[ooo]Z00Gooo]Z00?oo`00oookJ_oonfX07_oonfX00ooo
003ooo]ZoookJP0ToookJP03ool00?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0:?oonfX000Oo
oo]Z00?o0000oookJ_oonfX0G?oonfX00ol02_oooo]ZoookJP02oookJP07o`0Aoooonf[ooo]Zo`0?
oooonf[o00[ooookJP02o`0:o`0:oonA0?l02ooooi40oookJ_l02ooooel0o`0;oooonf[o00[oo`0;
o`;ooo]Z00?o00_oo`0:ool02_l00_l02_l3oookJP03o`0:oooonf[ooo]Z00;ooo]Z00Ko00[ooook
J_oonf[ooo]Zoold0?oonfX3o`0:o`04oookJ_l0003o0000o`0000gooo]Z0_oo000OoookJP;oo`T0
;OoonfX2ool102Kooo]Z00?oo`80oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP0VoookJP;oo`40
00?oo`00oookJ_oonfX09ooonfX2ool00003oookJ_oo0@3ooo]Z00_ooo]Z00?oo`40oookJ_oonfX0
5?oonfX01Ol0003ooo]ZoookJ_oonf[oo`0000Gooo]Z00?oo`00oookJ_oonfX02ooonfX00ooo003o
oo]ZoookJP0AoookJP03ool00?oonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX0?_oonfX00ol0003o
oo]ZoookJP0WoookJP001ooonfX00ol0003ooo]ZoookJP1MoookJP05o`0:oooonf[ooo]ZoookJ_l0
4Ol00_oonfX5o`0:o`;ooo]Z00?o00_ooookJ_l02ol00_oonfX01?l02ooooo]Zo`0:oooonfX2o`0;
o`05o`0:ool02ooo00[ooomg0?l02_l00_ooM`02oookJP05o`0:oooonf[ooo]Zoolo0?l02_l00ooo
nfX2o`0:o`06oookJ_l0003o0000o`000?oonf[o00001_oonfX00ooo8@3ooo]ZoookJP02oookJP;o
oa/07?oonfX00ooo1P3ooo]ZoookJP0PoookJP03ool70?oonf[ooo]Z00Oooo]Z0_oo000ToookJP;o
o`801?oonfX00ooo003ooo]ZoookJP0UoookJP03ool00?oonf[ooo]Z02Sooo]Z00?oo`00oookJ_oo
nfX02ooonfX00ooo0@3ooo]ZoookJP0IoookJP03ool00?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX01_oonfX00ooo003ooo]ZoookJP0XoookJP03ool00?oonf[ooo]Z01Sooo]Z00?oo`00oookJ_oo
nfX08ooonfX00ol0003ooo]ZoookJP0WoookJP001ooonfX00ol0003ooo]ZoookJP1NoookJP04o`0:
oooonf[o017ooookJPCo00[o00Go00gooookJ_l03?oo00[oo`0;o`02oookJP03o`0;ooooT@3o00_o
00;ooo]Z00Ko00[ooookJ_oonf[o00_oo`0:oooonfX2o`0:o`CoogL00_oonfX01?l02_oooo]Zoolo
0?oonfX3o`0:o`?o00000_oonfX2o`0:o`03oookJ_l0003ooo]Z00?ooo]Z0ooo8@02oookJP;ooa/0
5_oonfX00ooo0@3ooo]ZoookJP0OoookJP03ool60?oonf[ooo]Z00Kooo]Z00?oo`L0oookJ_oo0000
8ooonfX2ool100Oooo]Z00?oo`80oookJ_oonfX08OoonfX00ooo003ooo]ZoookJP04oookJP03ool2
0?oonf[ooo]Z027ooo]Z00?oo`00oookJ_oonfX02OoonfX00ooo0@3ooo]ZoookJP0YoookJP;oo`00
0ooonfX00ol0003ooo]ZoookJP0SoookJP03ool00?oonf[ooo]Z01Sooo]Z00?oo`00oookJ_oonfX0
8ooonfX00ooo003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z02Kooo]Z0007oookJP03o`000?oo
nf[ooo]Z05oooo]Z00?o00[oo`0Aool02_l00_l02_l00ooonf[o00gooonH0003oonH0008o`0:oooo
nf[ooo]Zo`0;oooonf[o00_ooookJ_l02_l3oookJP;o00[o00?ooo]Zo`0:ool02_l00_ooM`000ooo
2@3oogL0ool90002oookJP03o`0:oooonf[ooo]Z00?o00001_oonfX2o`0:o`03oookJ_l0003ooo]Z
00?ooo]Z00?oob40oookJ_oonfX00ooonfX00ooo6`3ooo]ZoookJP0=oookJP03ool00?oonf[ooo]Z
01kooo]Z00?oo`D0oookJ_oonfX01OoonfX00ooo1P3ooo]ZoookJP0SoookJP03ool00?oonf[ooo]Z
00Gooo]Z00?oo`40oookJ_oonfX08OoonfX00ooo003ooo]ZoookJP02oookJP;oo`800_oonfX00ooo
003ooo]ZoookJP0XoookJP03ool00?oonf[ooo]Z02Wooo]Z00Coo`00oookJ_oonf[ooo]Z0_oo0@0<
oookJP03o`000?oonf[ooo]Z01Gooo]Z00?oo`00oookJ_oonfX01OoonfX00ooo003ooo]ZoookJP0@
oookJP03ool00?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX09OoonfX000Oooo]Z00?o0000oook
J_oonfX0GooonfX3o`0:o`06oookJ_l03ooooo]Zo`0=ooooV03o00co0oooV0001ol02_oo00_ooook
J_oonf[o00_ooookJ_l02_l00_oonfX00ol02_oooo]Zo`0:o`03o`0:o`03oookJ_ooM`3oogL000Co
oo]Z0ol000000oooC@3ooo]Zo`0:o`07oookJP04o`0:oooonf[ooo]Zool>00Cooo]Z00?oob40oook
J_oonfX00ooonfX00ooo6`3ooo]ZoookJP0VoookJP03ool10?oonf[ooo]Z00Cooo]Z00?oo`D0oook
J_oonfX08_oonfX2ool500Oooo]Z00?oo`00oookJ_oonfX09?oonfX2ool202_ooo]Z00?oo`80ool0
0?oonfX0:OoonfX00ooo003ooo]ZoookJP02ool101Sooo]Z00?oo`00oookJ_l000002OoonfX00ooo
003ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z02Sooo]Z00?oo`00oookJ_oonfX0=ooonfX00ol0
003ooo]ZoookJP0ToookJP001ooonfX00ol0003ooo]ZoookJP1MoookJP?o00[o00?ooo]Zo`0:ool0
3ol00_oonfX01Ol03OoooiP0oonH0?oonf[o00_o00;ooo]Z00Ko00[ooookJ_l02ooooo]ZoonA0?l0
2_l2oookJP07o`0:ooooM`3o00[oo`0:oooonf[o00[ooookJP02oomg000:oookJ_l0003o0000o`00
0?l02_oooc/0o`0:ooooC@3ooo]Zo`0:o`Sooo]Z00Co00[oool>0?oo3P3o00000ooonfX00ooo8@3o
oo]ZoookJP0@oookJP03oolC0?oonf[ooo]Z00?ooo]Z0_oo4@0=oookJP03ool00?oonf[ooo]Z00Co
oo]Z00?oo`40oookJ_oonfX06OoonfX00ooo103ooo]ZoookJP05oookJP03ool50?oonf[ooo]Z02co
oo]Z00?oo`40oookJ_oonfX0:?oonfX00ooo0P3oo`00oookJP08oookJP03ool20?oonf[ooo]Z01?o
oo]Z00?oo`00oookJ_oonfX02?oonfX00ooo003ooo]Zool0000;oookJP03ool10?oonf[ooo]Z01[o
oo]Z00Co0000oookJ_oonf[oo`00:OoonfX00ooo003ooo]ZoookJP0UoookJP03ool00?oonf[ooo]Z
01gooo]Z00?o0000oookJ_oonfX09?oonfX000Kooo]Z00?o0000oookJ_oonfX0GOoonfX2o`0:o`07
oookJ_l04Ooooo]ZoookJ_l02_oooo]Zo`0=o`04oonH000;o`0;oooonf[ooiP0o`0;ool02_oo00_o
oookJ_l02_oooi40oookJ_ooM`000_l02_l01_oonf[o00[oo`0:oooonf[oogL0oookJP;o000000Co
oo]Zo`0:oooonf[ooo]Z0_oo>`001?l02_ooodd0oookJ_l02_l2oookJP03ool00?oonf[ooo]Z00;o
oo]Z0_l02_l2oookJP03o`000?oonf[ooo]Z01?ooo]Z0_oo4`06oookJP03oolA0?oonf[ooo]Z02co
oo]Z0_oo100VoookJP03ool40?oonf[ooo]Z00?ooo]Z0_oo000XoookJP03ool10?oonf[oo`0000So
oo]Z00?oo`80oookJ_oonfX07ooonfX00ooo003ooo]ZoookJP09oookJP03ool00?oonf[ooo]Z01co
oo]Z00?oo`00oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP07oookJP03ool10?oonf[ooo]Z01;o
oo]Z00?oo`00oookJ_oonfX09?oonfX00ooo003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02?o
oo]Z0006oookJP03o`000?oonf[ooo]Z05_ooo]Z0_l02_l6oookJP03o`0?ool02_oo00go00?ooiP0
00Cooo]Zo`0;ooooV03o00_o0_oonfX01ol02_oooo]Zo`0:ooooM`3ooi40o`0:oooonfX01?l02_l3
o`000003oookJ_l02_oo00[o00?ooo]Z0ooo>`001_l02_oooo]ZoookJ_l02_oooo]Zool000?ooo]Z
00?o00[ooookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0<oookJP;oo``01OoonfX00ooo4`3ooo]Z
oookJP0/oookJP03ool20?oonf[ooo]Z02;ooo]Z0_oo1006oookJP03ool00?oonf[oo`@002Gooo]Z
00?oo`40oookJ_oo00001ooonfX00ooo0@3ooo]ZoookJP0OoookJP03ool00?oonf[ooo]Z00Sooo]Z
00?oo`00ool20?oo0P007?oonfX00ooo003ooo]ZoookJP0?oookJP03ool10?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX03ooonfX00ooo003ooo]ZoookJP0BoookJP03ool00?oonf[ooo]Z04cooo]Z
00?o0000oookJ_oonfX08_oonfX000Kooo]Z00?o0000oookJ_oonfX0F_oonfX00ol02_oooo]Zoook
JP05oookJP06o`0?oooonf[ooo]Zo`0:oooonf[o00co1?ooV0001?l02ooooo]Zo`0;oooonfX2o`0:
o`;ooo]Z00?o00[ooookJ_l02_l00ol00002oookJP;o00[o1_oonfX2oolk0004oookJ_l02_oooo]Z
o`0:o`?ooo]Z0_l02_l7oookJP03o`000?oonf[ooo]Z00_ooo]Z00?oo``0oookJ_oonfX07ooonfX0
0ooo2`3ooo]ZoookJP09oookJP03ool00?oonf[ooo]Z02;ooo]Z00?oo`<0oookJ_oonfX01?oonfX0
0ooo003oo`@0ool4000SoookJP;oo`002?oonfX00ooo0@3ooo]ZoookJP0OoookJP03ool00?oonf[o
oo]Z00Sooo]Z00?oo`80oookJ_oonfX07?oonfX00ooo003ooo]ZoookJP0<oookJP;oo`004_oonfX0
0ol0003ooo]ZoookJP0EoookJP03ool00?oonf[ooo]Z01Wooo]Z00?oo`00oookJ_oonfX02ooonfX0
0ooo003ooo]ZoookJP0FoookJP03ool00?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX08_oonfX0
00Kooo]Z00?o0000oookJ_oonfX0F_oonfX00ol02_oooo]ZoookJP05oookJP0>o`0?oooonf[o00go
oookJ_l02_oo00cooookJ_ooV03ooo]ZoonH0?l02ooooo]Zo`0;ooooM`02o`0:o`;ooo]Z0ol00000
1Ol02_oooo]Zo`0:oooonf[o00[o00Oooo]Z00Ooodd0oookJ_oonf[ooc/0oookJ_l02_oooo]Z00?o
00[o2_oonfX00ol0003ooo]ZoookJP04oookJP03ool20?oonf[ooo]Z01Oooo]Z00?oo`T0oookJ_oo
nfX01?oonfX00ooo303ooo]ZoookJP05oookJP05ool;0?oonf[ooo]ZoookJ_oo00008_oonfX00ooo
0P3ooo]ZoookJP06oookJP03ool30?oonf[ooo]Z027ooo]Z00?oo`00oookJ_oonfX00_oonfX01Ooo
0`3ooo]ZoookJ_oonf[oo`00027ooo]Z00?oo`00oookJ_oonfX01_oonfX2ool102cooo]Z00?oo`00
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z01Sooo]Z00?oo`00
oookJ_oonfX09?oonfX00ooo003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z027ooo]Z0006oook
JP03o`000?oonf[ooo]Z05_ooo]Z00?o00[ooookJ_oonfX01?oonfX03ol03ooooo]Zo`0=oooonf[o
00coo`0:oooonf[o00_ooookJ_l02ooooiP0oookJ_l02ooooo]Zo`0:o`03o`0000;ooo]Z0_l02_l0
0ooonf[o00[oo`0:o`04oon700Cooo]Z00Koodd0oookJ_oonf[ooo]Zoolk0?oonfX3o`0:o`Wooo]Z
0_oo:0000ooonf[oo`00oookJP0NoookJP03ool90?oonf[ooo]Z00Cooo]Z00?oo``0oookJ_oonfX0
9?oonfX00ooo003ooo]ZoookJP05oookJP03ool20?oonf[ooo]Z027ooo]Z00Goo`00oookJ_oonf[o
oo]Zool30009oookJP03ool30?oonf[ooo]Z027ooo]Z0_oo0@0[oookJP03ool00?oonf[ooo]Z01_o
oo]Z00?oo`00oookJ_oonfX02OoonfX01Ooo003ooo]ZoookJ_oonf[o000000oooo]Z0_oo0@06oook
JP03ool00?oonf[ooo]Z01?ooo]Z00?oo`00oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0Poook
JP001_oonfX00ol0003ooo]ZoookJP1LoookJP03o`0:oooonf[ooo]Z00;ooo]Z00So00oooookJ_oo
nf[o00gooookJ_l03?oooo]Zo`0:o`;ooo]Z00?o00_ooookJ_l02ol00ol00002oookJP03o`0:oooo
nf[o00[o00?o00[o00?ooo]Zoon70?ooQ`001?ooQ`03oookJP03oom=0?oonf[ooo]Z00;ooo]Z1?l0
2_l9oookJP?oobP000Cooo]ZoolP0?oo803oob005OoonfX2ool300Gooo]Z00?oo`T0oookJ_oonfX0
8OoonfX01?oo203ooo]ZoookJ_oo000/oookJP03ool30?oonf[ooo]Z00Oooo]Z00?oo`<0oookJ_oo
nfX08OoonfX00ooo003ooo]ZoookJP0NoookJP03ool00?oonf[ooo]Z00Oooo]Z0_oo000<oookJP;o
o`403_oonfX00ooo003ooo]ZoookJP09oookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oo
nfX02?oonfX01?l0003ooo]Zool00?oo000LoookJP03ool00?oonf[ooo]Z02Kooo]Z00?oo`00oook
J_oonfX05OoonfX00ooo003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z01oooo]Z0006oookJP03
o`000?oonf[ooo]Z05gooo]Z00Oo00[ooookJ_oonf[ooo]Zo`0?oooonf[o00go00;ooo]Z00?o00co
oookJ_l02_l00_oonfX3o`000003oonH0?l02_oooo]Z00;ooo]Z1_l02_l00ooonf[oohL0oookJP02
oon70005oolD0?ooQ`3ooo]ZoookJ_ooC@001?oonfX01?l02_oooo]ZoookJ_oonfX2o`0:o`Sooo]Z
00?oobP0oookJ_oonfX00_oonfX00ooo803ooo]ZoookJP0>oookJP03ool00?oonf[ooo]Z01kooo]Z
00?oo`L0oookJ_oonfX01OoonfX00ooo203ooo]ZoookJP05oookJP03ool80?oonf[ooo]Z02Cooo]Z
00?oo`80oookJ_oonfX08OoonfX00ooo003ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z00Cooo]Z
0_oo0`0GoookJP03ool00?oonf[ooo]Z01Cooo]Z00?oo`40oookJ_oonfX07OoonfX00ooo003ooo]Z
oookJP0:oookJP03ool00?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03ooonfX00ooo003ooo]Z
oookJP0:oookJP03ool00?oonf[ooo]Z00[ooo]Z00?oo`00oookJ_oonfX02ooonfX00ooo003ooo]Z
oookJP0hoookJP03o`000?oonf[ooo]Z01oooo]Z0005oookJP03o`000?oonf[ooo]Z05oooo]Z00So
00[ooookJ_oonf[o00oooookJ_l03Ooooo]Zo`0<o`;ooid00ol00002oookJP03o`0;oooonf[o00[o
00;ooo]Z00Go00[ooookJ_oonf[o00[ooookJP02o`0:o`04oookJ_ooQ`3oohL0oookJP;oohL01?oo
nfX2oomH00;o00[o1OoonfX2o`0:o`?ooo]Z0_oo5`03oookJP03oolX0?oonf[ooo]Z00;ooo]Z00?o
ob00oookJ_oonfX0:?oonfX00ooo0`3ooo]ZoookJP03oookJP;oo`L09?oonfX00ooo003ooo]Zoook
JP05oookJP;oo`008OoonfX00ooo003ooo]ZoookJP0<oookJP;oo`<08_oonfX00ooo003ooo]Zoook
JP08oookJP03ool10?oonf[ooo]Z01gooo]Z00?oo`00oookJ_oonfX02OoonfX00ooo003ooo]Zoook
JP0GoookJP05o`000?oonf[ooo]ZoookJ_oo00005?oonfX00ooo003ooo]ZoookJP1IoookJP03o`00
0?oonf[ooo]Z01kooo]Z0005oookJP03o`000?oonf[ooo]Z063ooo]Z00Oo00[oo`0?oooonf[ooo]Z
o`0=oooonf[o00co00;o000000Gooo]ZoonM0?l02_oooid0o`0;o`02oookJP04o`0:oooonf[ooo]Z
o`0:o`;ooo]Z0_l02_l01_oonf[o00[ooon70?oonf[oohL0oookJP;oohL00ooonfX01?oo@@3o00[o
o`0:ooooF007oookJP;o00[o0_oonfX2oolG00?ooo]Z00?oobP0oookJ_oonfX00ooonfX00ooo803o
oo]ZoookJP0@oookJP;ooa<03OoonfX00ooo003ooo]ZoookJP04oookJP03ool30?oonf[ooo]Z027o
oo]Z00?oo`H0ool00?oonfX01_oonfX00ooo1P3ooo]ZoookJP0ToookJP03ool20?oonf[ooo]Z00Ko
oo]Z00?oo`80oookJ_oonfX08?oonfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z01go
oo]Z00?oo`00oookJ_oonfX06OoonfX00ooo0@3ooo]ZoookJP0:oookJP03ool00?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP0;oookJP03ool00?oonf[ooo]Z01[o
oo]Z00?oo`00oookJ_oonfX05_oonfX00ooo003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01go
oo]Z0005oookJP03o`000?oonf[ooo]Z067ooo]Z00?o00[ooookJ_l03Ol00ol00002oonM00;ooo]Z
00co00_oo`0:ooooW@3ooo]Zo`0:oooonf[ooiP0oookJ_l02_oooo]Zo`0:ooooQ`02o`0:o`Cooo]Z
00?oohL0oookJ_oonfX00ooonfX00ol02_oooeP0oom10002oomH00Cooo]Z00Koo`80oookJ_oonf[o
00[ooookJ_oo5`0<oookJP03o`000?oonf[ooo]Z00Wooo]Z0_oo6004oookJP;ooa<01ooonfX00ooo
003ooo]ZoookJP03oookJP03ool00?oonf[ooo]Z023ooo]Z00?oo`D0oookJ_oonfX01OoonfX2ool6
02Cooo]Z00?oo`40oookJ_oonfX01_oonfX2ool2027ooo]Z00?oo`00oookJ_oonfX04OoonfX2ool2
01Cooo]Z00?oo`00oookJ_oonfX02_oonfX00ooo0@3ooo]ZoookJP0:oookJP03ool10?oonf[ooo]Z
01cooo]Z00?oo`00oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z
00cooo]Z00?oo`00oookJ_oonfX02_oonfX00ooo003ooo]ZoookJP0GoookJP03ool00?oonf[ooo]Z
02?ooo]Z00?oo`00oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0MoookJP001OoonfX00ol0003o
oo]ZoookJP1QoookJP?o000000Cooo]Zo`0<ooooW@3ooo]Z0_ooW@001_l02ooooo]ZoonM0?l02_oo
oo]Zo`0:o`;ooo]Z00Go00[ooookJ_ooQ`3o00[ooookJP02o`0:o`Sooo]Z0_l02_l3oom100Gooo]Z
00?oo`80oookJ_oonfX00_oonfX00ol02_oooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00?ooo]Z
0_oo4P03oookJP03oolH0?oonf[ooo]Z00Gooo]Z00?ooa<0oookJ_oonfX09OoonfX2ool300Kooo]Z
00?oo`D0oookJ_oonfX08ooonfX00ooo003ooo]ZoookJP05oookJP03ool10?oonf[ooo]Z023ooo]Z
00?oo`00oookJ_oonfX01?oonfX00ooo0P3ooo]ZoookJP08oookJP03ool20?oonf[ooo]Z01oooo]Z
00?oo`00oookJ_oonfX02OoonfX00ooo0@3ooo]ZoookJP0AoookJP03ool00?oonf[ooo]Z00Wooo]Z
00?oo`00oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z02Cooo]Z
00?oo`00oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0LoookJP001OoonfX00ol0003ooo]Zoook
JP1NoookJP?o00000_oonfX01?l02_oooo]Zo`0<oooonfX2oonM0005oookJ_l02ooooid0o`0;oooo
nfX00_l02_l2oookJP05o`0:ooooV03ooo]Zo`0:oooonfX00_l02_l6oookJP;o00[o0ooonfX2oom1
00[ooo]Z0_l02_l>oookJP03o`000?oonf[ooo]Z00;ooo]Z00?ooa80oookJ_oonfX00ooonfX00ooo
603ooo]ZoookJP0UoookJP03ool10?oonf[ooo]Z00Cooo]Z00?oo`<0oookJ_oonfX08_oonfX00ooo
003oo`D0oookJP08oookJP03ool50?oonf[ooo]Z02;ooo]Z0_oo0@09oookJP03ool20?oonf[ooo]Z
01Cooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP0LoookJP03ool00?oonf[ooo]Z
01[ooo]Z00?oo`40oookJ_oonfX02?oonfX00ooo003ooo]Zo`00000OoookJP03ool00?oonf[ooo]Z
01Wooo]Z00?oo`00oookJ_oonfX05_oonfX00ooo003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z
01_ooo]Z0005oookJP03o`000?oonf[ooo]Z05_ooo]Z0ol00004oookJP06o`0=oooonf[o00[oo`0<
oooonf[o00_o1?ooW@001?l02ooooo]Zo`0:ool02_l2oon70007o`0:oooonf[o00[ooookJ_l02_oo
oo]Zo`0:o`05oookJP03o`0:oooonf[ooo]Z00?ooo]Z00?ooeP0oookJ_oo@@001ooonfX2o`0:o`ko
oo]Z0_oo1@000ooonf[o0000oookJP02oookJP03oolB0?oonf[ooo]Z01Oooo]Z0_oo3`05oookJP;o
o`d01?oonfX00ooo003ooo]ZoookJP0XoookJP;oo`@01ooonfX2ool501[ooo]Z00?oo`00oookJ_oo
nfX01_oonfX2ool1023ooo]Z00?oo`00oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP09oookJP03
ool20?oonf[ooo]Z013ooo]Z00?oo`00oookJ_oonfX06?oonfX00ooo0@3ooo]ZoookJP0:oookJP03
ool10?oonf[ooo]Z00_ooo]Z00Co0000oookJ_oonf[oo`003OoonfX00ooo003ooo]ZoookJP0Ioook
JP03ool00?oonf[ooo]Z01Kooo]Z00?oo`00oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0Koook
JP001OoonfX00ol0003ooo]ZoookJP1HoookJP?o00001ooonfX03_l03Ooooo]Zo`0<ool02_oooo]Z
o`0;oooonf[ooid0oookJ_ooW@3o00_ooookJ_l02_ooohL00_l02_l2oookJP05o`0:oooonf[o00[o
oookJ_l02_l00ooonfX2o`0:o`;ooi400ooonfX01?ooF03ooo]ZoookJ_oo@@06oookJP03o`0:oooo
nf[ooo]Z00Kooo]Z00Coobl0oookJ_oo003oo`002?oonfX00ol0003ooo]ZoookJP0CoookJP;oo`d0
1OoonfX00ooo3`3ooo]ZoookJP05oookJP03ool=0?oonf[ooo]Z01gooo]Z00?oo`40oookJ_oonfX0
1OoonfX00ooo0`3ooo]ZoookJP06oookJP03ool40?oonf[ooo]Z01Sooo]Z00?oo`00oookJ_oonfX0
9ooonfX00ooo003ooo]ZoookJP0AoookJP03ool20?oonf[ooo]Z00Sooo]Z0_oo0P0DoookJP03ool0
0?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX07?oonfX00ooo003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z00kooo]Z00?oo`00oookJ_oonfX02_oonfX00ooo003ooo]ZoookJP1CoookJP03o`00
0?oonf[ooo]Z01[ooo]Z0005oookJP03o`000?oonf[ooo]Z05Gooo]Z0ol0000:oookJP05o`0=oooo
nf[o00cooookJ_l02_l00_oonfX01_l02ooooo]Zo`0;ooooW@3ooo]Zo`0:o`;ooo]Z00Go00[ooook
J_oonf[o00[ooookJP02o`0:o`?ooo]Z00?o00[ooonA0?ooT@001?ooT@000ooonf[ooeP0oookJP02
oookJP04oom10?oonf[ooo]ZoookJP;o00[o2?oonfX3ool_00;ooo]Z00?oob@0oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP0<oookJP03ool60?oonf[ooo]Z00Cooo]Z00?oo`d0oookJ_oonfX01?oo
nfX00ooo3`3ooo]ZoookJP0LoookJP03ool00?oonf[ooo]Z00Gooo]Z00?oo`40oookJ_oonfX08?oo
nfX00ooo003ooo]ZoookJP0:oookJP03ool40?oonf[ooo]Z00Oooo]Z00?oo`@0oookJ_oonfX05ooo
nfX00ooo0@3ooo]ZoookJP08oookJP03ool10?oonf[ooo]Z00Sooo]Z00?oo`80oookJ_oonfX04ooo
nfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z013ooo]Z00?oo`00oookJ_oonfX02?oo
nfX00ooo003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00Kooo]Z00?oo`40oookJ_oonfX06ooo
nfX00ooo003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z01Wooo]Z0004oookJP03o`000?oonf[o
oo]Z05?ooo]Z0ol0000<oookJP0=o`0=oooonf[ooo]Zo`0<oooonf[o00_oo`0:oooonf[o00_ooook
J_l02ooooo]Zo`0:o`03oookJP?o00[o0_oonfX2o`0:o`05oookJ_l02_oo00[ooonA0?oonfX01Ooo
T@000oooF03ooo]ZoookJP03oookJP03oom10?l02_oo00[o00_ooo]Z00?oobl0oookJ_oonfX00ooo
9008oookJP03o`000?oonf[ooo]Z00Cooo]Z0_oo0005oookJP03ool60?oonf[ooo]Z01oooo]Z0_oo
2`02oookJP04ool00?oonf[ooo]ZoookJP;oo`T09_oonfX00ooo0P3ooo]ZoookJP06oookJP03ool3
0?oonf[ooo]Z00Oooo]Z00?oo`@0oookJ_oonfX05ooonfX00ooo003ooo]ZoookJP07oookJP03ool1
0?oonf[ooo]Z01Cooo]Z00?oo`00oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP0FoookJP03ool2
0?oonf[ooo]Z02_ooo]Z00?oo`40oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP06oookJP03ool1
0?oonf[ooo]Z00cooo]Z0_oo000IoookJP03ool00?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX0
1ooonfX00ooo003ooo]ZoookJP0;oookJP03ool00?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0
6?oonfX000Cooo]Z00?o0000oookJ_oonfX0DOoonfX2o`0000oooo]Z00?o00gooookJ_l03?l00_oo
nfX2oonQ0009o`0:ooooX@3ooj40o`0;oooonf[o00[ooonM0?oonf[o00[o00;ooo]Z00?o00[ooook
J_oonfX00ol02_l2oookJP;ooi4000Coob00oonA0?ooT@3ooi400ooonfX2oomO00;ooo]Z00?o00[o
oookJ_oonfX01ooonfX2oolQ00;ooo]Z00Coobl0oookJ_oonf[ooo]Z0_oo9009oookJP03ool00?oo
nf[ooo]Z02Gooo]Z00?oo`T0oookJ_oonfX01?oonfX2ool;00Oooo]Z00?oo`T0oookJ_oonfX06ooo
nfX2ool100Oooo]Z00?oo`80oookJ_oonfX05ooonfX00ooo003ooo]ZoookJP06oookJP;oo`00?ooo
nfX00ooo0@3ooo]ZoookJP0:oookJP03ool20?oonf[ooo]Z017ooo]Z00?oo`00oookJ_oonfX02Ooo
nfX2ool000oooo]Z00Coo`00oookJ_oonf[o00002OoonfX00ooo003ooo]ZoookJP0;oookJP03ool0
0?oonf[ooo]Z00[ooo]Z00?oo`00oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0HoookJP001?oo
nfX00ol0003ooo]ZoookJP1>oookJP?o00004OoonfX02Ol03Ooooo]Zo`0<oooonf[o00_ooonQ0?oo
nf[ooj40o`0:o`02oonQ0005oookJ_l02_oooo]ZoonM0?l02_l00_oonfX5o`0:o`06oookJ_ooT@3o
oi40oookJ_ooT@3ooo]Z0_ooT@02oookJP;ooel000Cooo]ZoomO0?l02_oo00[o2_oonfX2oolQ00;o
oo]Z00?oobl0oookJ_oonfX00ooonfX00ooo903ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01go
oo]Z00?oo`D0oookJ_oonfX01?oonfX00ooo2@3ooo]ZoookJP0KoookJP03ool00?oonf[ooo]Z00Go
oo]Z00?oo`00oookJ_oonfX0=ooonfX2ool300Wooo]Z0_oo0`0GoookJP03ool10?oonf[ooo]Z00So
oo]Z0_oo0@0CoookJP03ool00?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX03_oonfX00ooo003o
oo]ZoookJP09oookJP03ool00?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003o
oo]ZoookJP0GoookJP001?oonfX00ol0003ooo]ZoookJP1;oookJP?o00004ooonfX01_l03Ooooo]Z
oookJ_l03?oooo]Zo`0;o`;ooj4000Go00_ooookJ_l02_oooo]ZoonQ0002oookJP04o`0:oooonf[o
oo]Zo`0:o`;ooo]Z0_l02_l2oonA00Cooo]Z00Cooi40oookJ_oonf[ooo]Z0oooAP02o`0:o`;ooel0
2OoonfX00ooo8@3ooo]ZoookJP02oookJP03ool_0?oonf[ooo]Z00Cooo]Z00?oob@0oookJ_oonfX0
1ooonfX01?l0003ooo]ZoookJ_oo7005oookJP03oolF0?oonf[ooo]Z00Gooo]Z00?oo`00oookJ_oo
nfX01?oonfX00ooo0@3ooo]ZoookJP0XoookJP03ool80?oonf[ooo]Z00Kooo]Z00?oo`L0oookJ_oo
nfX08ooonfX2ool200Sooo]Z00?oo`<0oookJ_oonfX02?oonfX00ooo0`3ooo]ZoookJP0;oookJP03
ool00?oonf[ooo]Z00Oooo]Z0_oo0009oookJP03ool10?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oo
nfX01ooonfX00ooo003ooo]ZoookJP12oookJP03o`000?oonf[oo`0000gooo]Z0_oo0@0=oookJP03
ool00?oonf[ooo]Z00_ooo]Z00?oo`00oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP0;oookJP03
ool00?oonf[ooo]Z01Gooo]Z00?oo`00oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0FoookJP00
1?oonfX00ol0003ooo]ZoookJP18oookJP?o00005_oonfX00ol03Ooooo]Zo`0<o`02oookJPCooj40
00Cooo]Zo`0;ool02_oooj400_oonfX01Ol02_oooid0oookJ_l02_oooo]Z00;ooi4000?o00[ooook
J_oonfX02?oonfX01OooAP3o00[oo`0:ooooAP3ooel000Gooo]Z00?oo`H0oookJ_oonfX00_oonfX0
0ooo8@3ooo]ZoookJP0AoookJP;ooaP00_oonfX00ol0003ooa`0oolL0004oookJP?ooaH0:?oonfX0
0ooo1@3ooo]ZoookJP05oookJP03ool70?oonf[ooo]Z00Gooo]Z00?oo`P0oookJ_oonfX01_oonfX0
0ooo1`3ooo]ZoookJP0AoookJP03ool00?oonf[ooo]Z00Kooo]Z00?oo`40oookJ_oonfX01_oonfX0
0ooo0P3ooo]ZoookJP0=oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX0?_oonfX0
0ooo0@3ooo]ZoookJP09oookJP03ool10?oonf[ooo]Z013ooo]Z00?oo`00oookJ_oonfX02_oonfX0
0ooo003ooo]ZoookJP09oookJP05o`000?oo003ooo]ZoookJ_oo00003?oonfX00ooo003ooo]Zoook
JP0:oookJP03ool00?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX0A_oonfX00ol0003ooo]Zoook
JP0FoookJP001?oonfX00ol0003ooo]ZoookJP15oookJP?o00006ooonfX02ol03?oooo]Zo`0;oooo
X@3ooo]ZoonQ0?oonf[o00_ooookJ_ooX@3o00[o00;ooo]Z00?o00[ooookJ_l02_l00_ooT@02oook
JP03o`0:oooonf[ooo]Z00Sooo]Z00Co00[ooom60?ooAP3oodH08?oonfX01ooo603ooo]ZoookJ_oo
nf[o0000oookJ_oo70001_oonfX00ooo5P3ooo]ZoookJP0MoookJP;oo`801_oonfX00ooo1@3ooo]Z
oookJP05oookJP03ool70?oonf[ooo]Z01;ooo]Z00?oo`00oookJ_oonfX01OoonfX00ooo003ooo]Z
oookJP05oookJP03ool00?oonf[ooo]Z03_ooo]Z00?oo`<0oookJ_oonfX05?oonfX00ooo003ooo]Z
oookJP08oookJP;oo`402_oonfX2ool100Kooo]Z00?oo`00oookJ_oonfX02OoonfX00ooo003ooo]Z
oookJP09oookJP03ool00?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX01_oonfX00ol0003ooo]Z
oookJP1aoookJP03o`000?oonf[ooo]Z01Gooo]Z0004oookJP03o`000?oonf[ooo]Z04;ooo]Z0ol0
000NoookJP04o`0<oooonf[o00_ooookJP;ooj4000Gooo]Zo`0;ooooX@3o00[ooookJP02o`0:o`;o
oi4000?o00[ooonM0?oonfX00_oonfX00ol02_oooo]ZoookJP06oookJP;o00[o0_oonfX2oom601Wo
oo]Z0_oo2@04oookJP03oolH0?oonf[ooo]Z00?ooo]Z00?o0000oolL0?oonfX05ooonfX00ooo003o
oo]ZoookJP04oookJP03ool00?oonf[ooo]Z00Cooo]Z00?oo`80oookJ_oonfX0:ooonfX00ooo1P3o
oo]ZoookJP06oookJP;oo`H06ooonfX00ooo0@3ooo]ZoookJP06oookJP;oo`802OoonfX00ooo0P3o
oo]ZoookJP08oookJP03ool30?oonf[oo`0000Wooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo003o
oo]ZoookJP0AoookJP03ool00?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX05_oonfX00ooo003o
oo]ZoookJP0:oookJP03ool00?oonf[ooo]Z00_ooo]Z0_oo0009oookJP03ool00?oonf[ooo]Z00co
oo]Z00?oo`00oookJ_oonfX04ooonfX00ooo003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z01Co
oo]Z0003oookJP03o`000?oonf[ooo]Z043ooo]Z0ol0000PoookJP06o`0<oooonf[ooo]Zo`0;oooo
nf[o00_o1?ooX@001?l02_oooo]ZoookJ_l02_l2oookJP05o`0:oooonf[ooid0oookJ_l02_l01_oo
nfX01?ooV03o00[oo`0:ooooV003oookJP03oomO0?oonf[oodH000oooo]Z00CoocD0oookJ_oonf[o
o`001OoonfX00ooo2@3ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z00[ooo]Z0_oo4@04oookJP;o
oa801OoonfX2ool?02Sooo]Z00?oo`@0oookJ_oonfX01OoonfX00ooo1@3ooo]ZoookJP06oookJP03
ool60?oonf[ooo]Z00Oooo]Z00?oo`H0oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP06oookJP03
ool00?oonf[ooo]Z00Kooo]Z00?oo`40oookJ_oonfX05OoonfX00ooo003ooo]ZoookJP1;oookJP03
ool10?oonf[ooo]Z00_ooo]Z00?oo`40oookJ_oonfX03_oonfX01Ooo003ooo]ZoookJ_oonf[o0000
00Sooo]Z0ooo000<oookJP03ool00?oonf[ooo]Z01Kooo]Z00?oo`00oookJ_oonfX0@?oonfX00ol0
003ooo]ZoookJP0CoookJP000ooonfX00ol0003ooo]ZoookJP0moookJP?o00008ooonfX00ol03?oo
oo]Zo`0;o`02oookJP03o`0;oooonf[ooj4000;ooo]Z00?o00[ooookJ_oonfX00ol02_l4oookJP03
o`0:oooonf[ooo]Z00?ooo]Z00?ooiP0o`0:ooooV0001?ooV0001Ooo:`3ooel0oookJ_oonf[oodH0
00gooo]Z0ooo=@0EoookJP03o`000?oonf[ooo]Z00?ooo]Z00?oo`T0oookJ_oonfX00ooonfX2oolA
00Cooo]Z00?ooa80oookJ_oonfX01_oonfX00ooo3`3ooo]ZoookJP0EoookJP03ool00?oonf[ooo]Z
00Gooo]Z00?oo`80oookJ_oonfX01OoonfX00ooo103ooo]ZoookJP0HoookJP03ool00?oonf[ooo]Z
04Cooo]Z00?oo`80oookJ_oonfX02OoonfX00ooo0P3ooo]ZoookJP0BoookJP;oo`002_oonfX2ool1
00Gooo]Z00?oo`00oookJ_oonfX00ooonfX00ooo0@3ooo]ZoookJP03oookJP03ool00?oonf[ooo]Z
00Wooo]Z00?oo`00oookJ_oonfX03?oonfX01?oo003ooo]ZoookJ_l0001boookJP03o`000?oonf[o
oo]Z01?ooo]Z0003oookJP03o`000?oonf[ooo]Z03_ooo]Z0_l0000VoookJP03o`0<oooonf[o00_o
00;ooo]Z00So00_ooookJ_l02ooooo]Zo`0:oooonf[ooj40o`0:o`;ooo]Z00?o00[ooookJ_oonfX0
0_oonfX00ol02_oooo]ZoookJP02oookJP;o00[o0_oonfX2oonH0003ool[0?ooV03ooel000Cooo]Z
00?oodH0oookJ_oonfX02ooonfX01?oo=@3ooo]ZoookJ_oonfX2oolW013ooo]Z00?oo`80oookJ_l0
00000ooonfX2ool900Gooo]Z00?ooa40oookJ_oonfX01?oonfX00ooo4P3ooo]ZoookJP0FoookJP03
ool00?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX0=?oonfX2ool500Wooo]Z00?oo`D0oookJ_oo
nfX05ooonfX00ooo0@3ooo]ZoookJP08oookJP03ool20?oonf[ooo]Z00Sooo]Z00?oo`80ool00?oo
nfX02?oonfX00ooo003oo`80oookJP08oookJP03ool00?oonf[ooo]Z013ooo]Z00?oo`00oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP0goookJP03ool00?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oo
nfX02ooonfX00ooo003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01;ooo]Z0003oookJP03o`00
0?oonf[ooo]Z03Sooo]Z0ol0000WoookJP06o`0<oooonf[ooo]Zo`0;oooonf[o00_o0_oonfX00ol0
2ooooo]Zo`0:o`02oookJP03o`0:oooonf[ooo]Z00;o00[o0ooonfX00ol02_oooo]ZoookJP02o`0:
o`05oookJ_ooV03ooiP0oonH0?oonfX00oooV0001?ooG`3oofD0oomU0?ooI@02oookJP03oom60?oo
nf[ooo]Z00Kooo]Z0ooo:0001?oonf[oocD0oookJ_oonfX2oolW00_ooo]Z00?oo`00oookJ_oonfX0
0ooonfX01?oo0P3ooo]ZoookJ_l0000NoookJP03ool<0?oonf[ooo]Z00Cooo]Z00?oo`d0oookJ_oo
nfX01OoonfX00ooo2`3ooo]ZoookJP0LoookJP03ool20?oonf[ooo]Z00Kooo]Z00?oo`<0oookJ_oo
nfX01_oonfX00ooo103ooo]ZoookJP06oookJP;oo`D01_oonfX01?oo003ooo]ZoookJ_oo1@05oook
JP;oo`002?oonfX00ooo003ooo]ZoookJP07oookJP03ool10?oonf[ooo]Z00[ooo]Z00?oo`00oook
J_oonfX0FOoonfX00ooo0@3ooo]ZoookJP09oookJP05o`000?oonf[ooo]ZoookJ_oo00003?oonfX2
ool000cooo]Z0_oo000;oookJP03ool00?oonf[ooo]Z04?ooo]Z0ol0000CoookJP000ooonfX00ol0
003ooo]ZoookJP0eoookJP?o0000:_oonfX00ol03?oooo]Zo`0;o`02oookJPGooj<000Ko00[ooook
J_oonf[o00[ooonQ0?l02_l2oookJP07o`0:oooonf[ooo]Zo`0:oooonf[o00[ooookJP02oonH0004
oookJ_ooV03ooo]ZoookJP;ooiP00_ooI@02oookJP03oomU0?oonf[ooo]Z00[ooo]Z0_oo:002oook
JP05oole0?oonf[ooo]ZoookJ_oo9`005?oonfX00ol0003ooo]ZoookJP0CoookJP;oo`P01OoonfX2
ool<00Kooo]Z0_oo3@06oookJP;oo`/01OoonfX00ooo003ooo]ZoookJP05oookJP03ool00?oonf[o
oo]Z00Gooo]Z00?oo`00oookJ_oonfX01OoonfX00ooo0P3ooo]ZoookJP06oookJP03ool30?oonf[o
oo]Z00kooo]Z00?oo`00oookJ_oonfX0DOoonfX00ooo0P3ooo]ZoookJP0AoookJP03ool00?oonf[o
oo]Z00Wooo]Z00?oo`00oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP04oookJP05ool10?oonf[o
oo]ZoookJ_oo00002?oonfX01Ooo0@3ooo]ZoookJ_oonf[oo`0000Wooo]Z00Co0000oookJ_oo003o
o`00J_oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX04OoonfX000?ooo]Z00?o0000oookJ_oonfX0
<_oonfX3o`0002gooo]Z00?o00cooookJ_l02ol00_oonfX00oooX`3ooo]ZoonS0003oonS0005oook
J_l02_oooo]ZoookJ_l02_l00ooonfX4o`0:o`;ooiP00ooonfX00oooV03ooo]ZoonH0002oonH0003
oookJ_ooI@3ooo]Z00?oofD02_oonfX00ooo:03ooo]ZoookJP02oookJP03oole0?oonf[ooo]Z00;o
oo]Z00?oobL0oookJ_oonfX02ooonfX00ooo7`3ooo]ZoookJP04oookJP03o`000?oo003ooo]Z00Co
oo]Z0_oo0005oookJP03ool30?oonf[ooo]Z00Cooo]Z00?oo`P0oookJ_oonfX01OoonfX00ooo303o
oo]ZoookJP1goookJP03ool10?oonf[ooo]Z00Oooo]Z00?oo`40oookJ_oonfX02?oonfX2ool200So
oo]Z00Coo`00oookJ_oo0P3oo`802?oonfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0?_oonfX00ooo003ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z
00cooo]Z00?oo`00oookJ_oonfX03_oonfX3o`0000Gooo]Z00?o0000oookJ_oonfX04OoonfX000?o
oo]Z00?o0000oookJ_oonfX0;ooonfX3o`0002oooo]Z00Ko00cooookJ_oonf[o00_ooookJ_l02ol2
oonS0006o`0;oooonf[o00[ooookJ_ooX`3o00[o0_oonfX00ol02_oooo]ZoookJP02oookJP03o`0:
ooooV03ooiP000Kooo]Z0_ooV0001?oonf[oodT0oom90?ooB@03oomU00Cooo]Z0_oo2`04oookJP03
oolX0?oonf[ooo]Z00?ooo]Z00?oocD0oookJ_oonfX00ooonfX00ooo9`3ooo]ZoookJP05oookJP;o
oah00_oonfX3oolO00Cooo]Z0_oo6@000ol0003ooo]ZoookJP0foookJP03ool90?oonf[ooo]Z00Go
oo]Z0_oo200LoookJP03ool20?oonf[ooo]Z00Kooo]Z0_oo0`08oookJP03ool40?oonf[ooo]Z00?o
oo]Z00Coo`00oookJ_oonf[ooo]Z0_oo1004oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oo`00oook
J_oonfX01ooonfX00ooo0@3ooo]ZoookJP1ZoookJP03o`000?oonf[ooo]Z00Kooo]Z00?oo`40ool0
0?oonfX02ooonfX2ool000_ooo]Z00?oo`00oookJ_oo00002ooonfX00ooo003ooo]ZoookJP0`oook
JPCo00002?oonfX00ol0003ooo]ZoookJP0AoookJP000_oonfX00ol0003ooo]ZoookJP0]oookJP?o
0000<_oonfX00ol03?oooo]Zo`0;o`02oookJPCooj<000Wooo]Zo`0:ooooX`3ooo]Zo`0:oooonf[o
00[ooookJ_ooX@000_oonfX2oonH00_ooo]Z0_ooB@000ooonf[oodT0oomU000OoookJP;ooah00ooo
nfX00ooo7`3ooo]ZoookJP03oookJP;ooaT000?ooo]Zo`000?oonfX09_oonfX00ooo1`3ooo]Zoook
JP04oookJP;oo`T01_oonfX2ool900Oooo]Z0_oo2003oookJP03ool00?oonf[ooo]Z00Gooo]Z00?o
o`00oookJ_oonfX01OoonfX00ooo0@3ooo]ZoookJP06oookJP03ool20?oonf[ooo]Z06kooo]Z00?o
o`80oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP09oookJP;oo`000ooonfX00ooo003ooo]Zoook
JP05oookJP;oo`000_oonfX00ooo003ooo]ZoookJP07oookJP03ool10?oonf[oo`0000;ooo]Z00?o
0000oookJ_oonfX01_oonfX00ooo0@3oo`00oookJP1FoookJP?o00003?oonfX00ol0003ooo]Zoook
JP0AoookJP000_oonfX00ol0003ooo]ZoookJP0ZoookJP?o0000=ooonfX00ol02ooooo]ZoookJP03
oonS0005oookJ_l02_oooj<0oookJ_l02_l00_oonfX01Ol02_oooo]ZoonH0?ooX@3ooiP000gooo]Z
1?ooB@0JoookJP;oo`h01?oonfX00ooo7P3ooo]ZoookJP03oookJP03oolO0?oonf[ooo]Z00Cooo]Z
00?ooaT0oookJ_l000004?oonfX00ooo003ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z00Cooo]Z
00?oo`<0oookJ_oonfX01OoonfX00ooo1`3ooo]ZoookJP05oookJP03ool90?oonf[ooo]Z06gooo]Z
00?oo`00oookJ_oonfX01ooonfX2ool100Sooo]Z00?oo`00oookJ_oo0@002?oonfX01?oo003ooo]Z
oookJ_oo0@06oookJP;oo`000ooonfX2ool200Gooo]Z00?oo`00oookJ_oonfX0:_oonfX00ol0003o
oo]ZoookJP0foookJP03ool00?oonf[ooo]Z00_ooo]Z00?oo`00oookJ_oonfX05?oonfX00ooo003o
0000o`00000?oookJP03o`000?oonf[ooo]Z017ooo]Z0002oookJP03o`000?oonf[ooo]Z02Sooo]Z
0_l0000joookJP03o`0;oooonf[o00_o00;ooo]Z1?ooX`001_oonf[o00[ooookJ_oonf[o00[ooonH
00;ooo]Z00?ooj40oookJ_oonfX01ooonfX4oonM00;ooo]Z0_ooB@0CoookJP;oo`801?oonfX00ooo
3P3ooo]ZoookJP03oookJP03oolN0?oonf[ooo]Z00Cooo]Z00?ooal0oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP07oookJP03oolD0?oonf[ooo]Z05_ooo]Z00?oo`40oookJ_oonfX01_oonfX2ool2
00Sooo]Z0_oo0`03oookJP03ool00?oonf[ooo]Z00?ooo]Z00Coo`<0oookJ_oonf[oo`001ooonfX0
0ooo0`3ooo]Zool00009oookJP03ool00?oonf[ooo]Z067ooo]Z00Go0000oookJ_oonf[ooo]Zool0
000<oookJP03ool00?oonf[ooo]Z00_ooo]Z00?oo`00oookJ_oonfX02OoonfX00ooo003ooo]Zool0
000/oookJP?o00004ooonfX00ol0003ooo]ZoookJP0@oookJP000_oonfX00ol0003ooo]ZoookJP0U
oookJP?o0000>ooonfX03_l02ooooo]ZoookJ_l02ooooo]Zo`0;oooonf[ooj<0o`0:ooooX`3ooo]Z
o`0:oooonf[o00[o1OoonfX00oooX@3ooo]ZoookJP04oookJPSooid000?oofD0oold0?ooB@003ooo
nfX2ooli01oooo]Z00Co0000oookJ_oo503ooa@01OoonfX2oolD00Gooo]Z0_oo4@0OoookJP03ool3
0?oonf[ooo]Z00Gooo]Z0_oo1@07oookJP03ool70?oonf[ooo]Z00Kooo]Z00?oo`L0oookJ_oo0000
1_oonfX2ool600Sooo]Z00?oo`00oookJ_oonfX01_oonfX00ooo0@3ooo]ZoookJP06oookJP03ool2
0?oonf[ooo]Z05kooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP0:oookJP03ool0
0?oonf[ooo]Z00Wooo]Z0_oo00000ooonf[oo`00oookJP07oookJP03o`000?oonf[oo`0000gooo]Z
0_oo0@13oookJPCo00002ooonfX00ooo003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z013ooo]Z
0002oookJP03o`000?oonf[ooo]Z02;ooo]Z0ol0000noookJP08o`0;oooonf[ooo]Zo`0;oooonf[o
00_ooookJ_l02_l2oookJP04o`0:oooonf[ooo]Zo`0:o`cooo]Z00Cooid0oookJ_oonf[ooo]Z0_oo
W@000ooo=03ooid0oomU0002oookJP03oom90?oonf[ooo]Z00_ooo]Z1?oo>@0JoookJP;oo`d00ooo
nfX00ol0003ooo]ZoolD0006oookJP03oolD0?oonf[ooo]Z00?ooo]Z0_oo4@09oookJP03ool00?oo
nf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX01?oonfX2ool100Kooo]Z00?oo`<0oookJ_oonfX01Ooo
nfX00ooo1@3ooo]ZoookJP1GoookJP03ool00?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX01ooo
nfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z00Wooo]Z00?oo`40oookJ_oonfX01?oo
nfX00ooo003ooo]ZoookJP02oookJP03ool10?oonf[ooo]Z00[ooo]Z00?oo`40oookJ_oonfX0:?oo
nfX00ol0003ooo]ZoookJP0^oookJP03ool00?oonf[ooo]Z00[ooo]Z00?oo`00oookJ_oonfX03?oo
nfX01?oo003ooo]ZoookJ_oonfX3o`0001[ooo]Z00?o0000oookJ_oonfX04?oonfX000;ooo]Z00?o
0000oookJ_oonfX07ooonfX3o`00047ooo]Z00?o00_ooookJ_l02ol00_oonfX00ol02ooooo]Zo`0:
o`02oookJP04o`0:ooooX`3ooo]Zo`0:o`gooo]Z1?ooW@001?oonf[ooid0oold0?ooI@02oomY0003
oookJ_ooB@3ooo]Z00Wooo]Z0ooo;`001?oo>@3ooo]ZoookJ_oonfX2oolZ00[ooo]Z00?oo`00oook
J_oonfX00ooonfX2ool400Gooo]Z00?oo`d0oookJ_oonfX00ooonfX00ol0003ooa@0oookJP05oook
JP03oolD0?oonf[ooo]Z05?ooo]Z00?oo`00oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP06oook
JP;oo`002?oonfX00ooo0@3ooo]ZoookJP07oookJP03ool20?oonf[ooo]Z00Sooo]Z00?oo`80oook
J_oonfX02?oonfX00ooo0`3ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z05Oooo]Z00?oo`00o`00
0?oonfX02OoonfX00ooo003ooo]ZoookJP0:oookJP03ool00?oonf[ooo]Z00_ooo]Z00?oo`00oook
J_oonfX02ooonfX00ooo003ooo]ZoookJP0GoookJP?o00007OoonfX00ol0003ooo]ZoookJP0@oook
JP000_oonfX00ol0003ooo]ZoookJP0LoookJP?o0000@ooonfX01_l02ooooo]ZoookJ_l02ooooo]Z
o`0;o`;ooo]Z00Ko00[ooookJ_oonf[o00[ooookJ_l02_l=oookJP?ooid000Sooo]ZoonM0?ooW@3o
oid0oomU0?ooJ@3ooo]ZoomY00;ooo]Z00?oodT0oookJ_oonfX02?oonfX2ool_0003ooli0?oonf[o
oo]Z00;oobX07ooonfX00ol0003ooo]ZoookJP0AoookJP;oo`l01OoonfX2ool>00Kooo]Z0_oo3006
oookJP03ool00?oonf[ooo]Z00Gooo]Z00?oo`00oookJ_oonfX01?oonfX2ool100Oooo]Z00?oo`<0
oookJ_oonfX01_oonfX00ooo1@3ooo]ZoookJP06oookJP03ool50?oonf[ooo]Z00Kooo]Z0_oo1P0?
oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oo`40oookJ_oonfX0D?oonfX00ooo003ooo]ZoookJP08
oookJP03ool00?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP0:
oookJP05ool00?oonf[ooo]ZoookJ_l000002OoonfX00ooo003ooo]ZoookJP0;oookJP03ool00?oo
nf[ooo]Z02kooo]Z1?l0000PoookJP03o`000?oonf[ooo]Z013ooo]Z0002oookJP03o`000?oonf[o
oo]Z01Wooo]Z0ol00016oookJP05o`0;oooonf[ooo]Zo`0;oooonfX01OooY@001Ol02_oooo]Zoook
J_l02_oooj<000[ooo]Z0_ooW@02oookJP07oonM0?oonf[ooid0oonM0?oonf[oofT0oookJP03oomY
00_ooo]Z00Goobl0oookJ_oonf[ooo]Zooli0003oookJP03oolZ0?oonf[ooo]Z01Gooo]Z00?oo`00
oookJ_oonfX00ooonfX00ooo0@3ooo]Zo`000004oookJP03ool50?oonf[ooo]Z00Cooo]Z00?oo`/0
oookJ_oonfX01?oonfX00ooo3`3ooo]ZoookJP04oookJP03ool>0?oonf[ooo]Z00Gooo]Z00?oo``0
oookJ_oonfX05?oonfX2ool100Oooo]Z00?oo`<0oookJ_oonfX01_oonfX00ooo1@3ooo]ZoookJP1;
oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP08
oookJP03ool00?oonf[ooo]Z00Sooo]Z0_oo000:oookJP;oo`402ooonfX2ool100cooo]Z00?oo`40
oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP11oookJP04ool00?l0003o0000o`0000_ooo]Z00?o
o`00oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0@oookJP0000?ooo]Zo`000?oonfX06?oonfX3
o`0004Wooo]Z00?o00_ooookJ_l02ol00_oonfX00oooY@3ooo]ZoonU0003oonU0005oookJ_l02_oo
oo]ZoookJ_ooX`001_oonfX3oonM00Gooo]Z00?ooid0oookJ_ooC@000_ooC@02oomY0003oookJ_oo
J@3oofT000?ooo]Z0_oo4004oookJP03ool_0?oonf[ooo]Z00;ooo]Z00?oocT0oookJ_oonfX00_oo
nfX00ooo:P3ooo]ZoookJP07oookJP04oolR0?oonf[ooo]ZoookJP;oob<03OoonfX01?oo0@3ooo]Z
oookJ_l00003oookJP03ool50?oonf[ooo]Z00Cooo]Z00?oo`/0oookJ_oonfX01?oonfX00ooo3`3o
oo]ZoookJP05oookJP03ool>0?oonf[ooo]Z00Gooo]Z00?oo``0oookJ_oonfX0@OoonfX00ooo003o
oo]ZoookJP06oookJP03ool00?oonf[ooo]Z00Kooo]Z0_oo0008oookJP03ool00?oonf[ooo]Z00Oo
oo]Z0_oo0@09oookJP;oo`402_oonfX00ooo0P3ooo]ZoookJP09oookJP03ool20?oonf[ooo]Z04ko
oo]Z00?o0000oookJ_oonfX03_oonfX00ooo003ooo]ZoookJP0:oookJP03ool00?oonf[ooo]Z00_o
oo]Z00?oo`00oookJ_oonfX02ooonfX00ooo003ooo]ZoookJP04oookJP?o00009ooonfX00ol0003o
oo]ZoookJP0@oookJP0000?ooo]Zo`000?oonfX05OoonfX3o`0004_ooo]Z00Ko00_ooookJ_oonf[o
00_ooookJ_l02ol2oonU0006o`0:oooonf[o00[ooookJ_ooY@3o00[o0_oonfX00oooX`3ooo]Zoook
JP02oookJP;ooid02_oonfX2oom=0004oookJ_ooC@3oofT0oomY00Cooo]Z00?ooa00oookJ_oonfX0
0ooonfX00ooo;`3ooo]ZoookJP03oookJP03ooli0?oonf[ooo]Z00?ooo]Z00?oobX0oookJ_oonfX0
1OoonfX3oolR00;ooo]Z0_oo8`04oookJP;ooa/02ooonfX00ol0003ooo]ZoookJP0LoookJP03ool9
0?oonf[ooo]Z00Cooo]Z00?oo`/0oookJ_oonfX01OoonfX00ooo2`3ooo]ZoookJP03oookJP03ool0
0?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX01OoonfX2ool000Oooo]Z00?oo`40oookJ_oonfX0
1_oonfX00ooo0`3ooo]ZoookJP06oookJP03ool40?oonf[ooo]Z00Oooo]Z00?oo`@0oookJ_oonfX0
1ooonfX2ool406Wooo]Z00?oo`00oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP0:oookJP03ool0
0?oonf[ooo]Z00Oooo]Z00Co0000oookJ_oonf[oo`003?oonfX2ool000gooo]Z00?oo`00oookJ_oo
nfX06_oonfX4o`0002[ooo]Z00?o0000oookJ_oonfX04?oonfX00003oookJ_l0003ooo]Z01?ooo]Z
0_l0001>oookJP05o`0;oooonf[ooo]Zo`0;oooonfX01?ooY@001Ooonf[o00[ooonU0?oonf[o00[o
00?ooo]Z00Cooj<0oookJ_ooW@3ooid03?oonfX2oom=0003oookJ_ooC@3ooo]Z01[ooo]Z00?ooa<0
oookJ_oonfX00ooonfX00ooo8P3ooo]ZoookJP02oookJP03oolS0?oonf[ooo]Z00;ooo]Z00?ooa/0
oookJ_oonfX02ooonfX00ol0003oo`00oookJP04oookJP;oo`001OoonfX2ool100Kooo]Z00?oo`D0
oookJ_oonfX01?oonfX2ool900Kooo]Z00?oo`/0oookJ_oonfX01OoonfX2ool;00Oooo]Z00?oo`T0
oookJ_oonfX0;_oonfX00ooo103ooo]ZoookJP08oookJP03ool40?oonf[ooo]Z03Gooo]Z00?oo`00
oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z00Wooo]Z00?oo`00
oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP0:oookJP03ool10?oonf[ooo]Z00[ooo]Z0_oo0@0;
oookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0000>oookJP03ool00?oonf[ooo]Z00_ooo]Z00?oo`00
oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0@oookJP0000?ooo]Zo`000?oonfX04?oonfX3o`00
05;ooo]Z00?o00_ooookJ_oonfX00oooY@001Ooonf[oojD0oonU0?oonf[o00[o00Cooo]Z00?ooid0
oonS0?oonfX03_oonfX2oom=0003oomY0?oonf[ooo]Z01;ooo]Z00?oo`@0oookJ_oonfX00ooonfX2
oolC00Cooo]Z00?oob80oookJ_oonfX00ooonfX00ooo8`3ooo]ZoookJP03oookJP03oolK0?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX06OoonfX00ooo2@3ooo]ZoookJP05oookJP03ool;0?oonf[o
oo]Z00Kooo]Z00?oo`/0oookJ_oonfX01_oonfX00ooo2@3ooo]ZoookJP0noookJP03ool00?oonf[o
oo]Z00Kooo]Z00?oo`00oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[o
oo]Z00Sooo]Z00?oo`40oookJ_oonfX02?oonfX00ooo0@3ooo]ZoookJP09oookJP03ool20?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX05?oonfX00ooo003ooo]ZoookJP0:oookJP03ool00?oonf[o
oo]Z00_ooo]Z00?oo`00oookJ_oonfX00ol00008oookJP03ool00?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX03ooonfX00003oookJ_l0003ooo]Z00gooo]Z0ol0001EoookJP03o`0;oooonf[o00_o
00;ooo]Z1?ooY@001?oonf[o00[ooookJ_oonfX2oonM00;ooo]Z00?ooj<0oookJ_oonfX02?oonfX4
oonQ0004oolk0?ooC@3oodd0oolk013ooo]Z00?oocd0oookJ_oonfX03?oonfX00ooo8P3ooo]Zoook
JP04oookJP03oolS0?oonf[ooo]Z00?ooo]Z00?ooa/0oookJ_oonfX01?oonfX00ooo603ooo]Zoook
JP03oookJP;ooaL0;ooonfX00ooo1`3ooo]ZoookJP0AoookJP03ool00?oonf[ooo]Z00Gooo]Z00?o
o`00oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP06oookJP03ool10?oonf[ooo]Z00Kooo]Z0_oo
0P08oookJP;oo`<02OoonfX00ooo103ooo]ZoookJP0coookJP03ool00?oonf[ooo]Z02oooo]Z00?o
o`00oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP0:oookJP04ool00?oonf[ooo]Zo`0000Wooo]Z
00?oo`00oookJ_oonfX02_oonfX2ool000gooo]Z00?oo`00oookJ_oonfX02?oonfX3o`0002[ooo]Z
00?oo`00oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0?oookJP0000?ooo]Zo`000?oonfX02_oo
nfX3o`0005Sooo]Z00go00_ooookJ_l02ooooo]Zo`0:oooonf[oojD0o`0:ooooY@3ooo]Zo`0:oooo
nf[ooid000Gooo]Z00?ooj<0oookJ_oonfX01OoonfX8oonQ0003oolk0?ooC@3ooo]Z00kooo]Z0_oo
?@0LoookJP;ooa401?oonfX2oolH00Cooo]Z0_oo5`000ol0003ooo]ZoookJP02oookJP;ooa<02_oo
nfX00ooo003ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z00Cooo]Z00?oo`80oookJ_oonfX01Ooo
nfX00ooo1@3ooo]ZoookJP05oookJP03ool70?oonf[ooo]Z00Gooo]Z0_oo2007oookJP;oo`P0>Ooo
nfX01Ooo103ooo]ZoookJ_oonf[oo`0003cooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo003ooo]Z
oookJP09oookJP03ool00?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX02_oonfX00ooo003ooo]Z
oookJP0;oookJP03ool00?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX01_oonfX00ooo0@3ooo]Z
oookJP0OoookJP03ool00?l0003o000000;o00002?oonfX00ooo003ooo]ZoookJP0<oookJP03ool0
0?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX03ooonfX00003oookJ_l0003ooo]Z00Oooo]Z0ol0
001JoookJP06o`0;oooonf[ooo]Zo`0;oooonf[o00[o0_oonfX00ol02_oooo]Zo`0:o`0@oookJP03
oonQ0?oonf[ooc/000Cooj4000CoofT0oolk0?oonf[oodd03?oonfX00ooo=@3oocd0oolm0002oolm
00gooo]Z0_oo0@05oookJP03ool60?oonf[ooo]Z00?ooo]Z00?ooa40oookJ_oonfX01?oonfX00ooo
603ooo]ZoookJP04oookJP03oolG0?oonf[o000000?ooo]Z0_oo4`0aoookJP03ool80?oonf[ooo]Z
00Kooo]Z00?oo`P0oookJ_oonfX02_oonfX00ooo003ooo]ZoookJP0hoookJP03ool00?oonf[ooo]Z
00Oooo]Z00?oo`00oookJ_oonfX01ooonfX2ool000Wooo]Z0_oo000:oookJP03ool10?oonf[ooo]Z
00Wooo]Z00?oo`40oookJ_oonfX02_oonfX00ooo0@3ooo]ZoookJP0WoookJP03ool00?oonf[ooo]Z
00Kooo]Z00Go0000oookJ_oonf[ooo]Zool00003oookJP03ool10?oonf[ooo]Z00Kooo]Z00?oo`00
oookJ_oonfX05?oonfX3o`0003cooo]Z00?o0000oookJ_oonfX03ooonfX00003o`000?oonf[ooo]Z
00Cooo]Z0ol0001MoookJP03o`0;oooonf[o00_o00;ooo]Z00?o00[ooookJ_l02_l00_oonfX00ol0
2_ooojD0oookJP0?oookJP;ooj4000Gooo]ZoonQ0?ooX@3ooj40oomY0002oom/0003oookJ_ooC@3o
oo]Z00[ooo]Z00CoocD0oookJ_oo=@3oocd00_oonfX3ool]01gooo]Z00?ooaP0oookJ_oonfX01?oo
nfX01?oo5`3ooo]ZoookJ_l00004oookJP03oolC0?oonf[ooo]Z01;ooo]Z00?oo`00oookJ_oonfX0
1OoonfX00ooo003ooo]ZoookJP0_oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX0
1_oonfX2ool100Sooo]Z00?oo`40oookJ_oonfX01ooonfX00ooo0P3ooo]ZoookJP08oookJP03ool3
0?oonf[ooo]Z00Sooo]Z00?oo`<0oookJ_oonfX0<?oonfX00ooo003ooo]ZoookJP05oookJP05ool1
0?oonf[ooo]ZoookJ_oo00002_oonfX00ooo003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00ko
oo]Z00?oo`00oookJ_oonfX02_oonfX2ool000Gooo]Z0ol00005oookJP03ool00?oonf[ooo]Z03Oo
oo]Z00?o0000oookJ_oonfX03ooonfX00004o`000?oonf[ooo]ZoookJP?o0000H?oonfX01Ol02ooo
oo]Zo`0;oooonf[o00[o00;ooo]Z00Ko00[ooookJ_oonf[o00[ooookJ_ooY@0=oookJP?ooj400_oo
nfX01_ooX@3ooo]ZoomY0?ooK03ooo]Zoom/00;ooo]Z00?oodd0oookJ_oonfX01ooonfX01Ooo=@3o
oo]Zoole0?oonf[oocd000;ooo]Z0_oo;@0GoookJP03ool00?oonf[ooo]Z00_ooo]Z00Goo`L0oook
J_oonf[ooo]Zo`000002oookJP03ool>0?oonf[ooo]Z00?ooo]Z0_oo4@06oookJP03ool@0?oonf[o
oo]Z01Cooo]Z0_oo0006oookJP;oo`801ooonfX00ooo103ooo]ZoookJP05oookJP;oo`H01ooonfX2
ool600Sooo]Z00?oo`H0oookJ_oonfX0;OoonfX00ooo0`3ooo]ZoookJP08oookJP03ool30?oo003o
oo]Z00Sooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP0noookJP03ool00?oonf[o
oo]Z00[ooo]Z00?oo`00oookJ_oonfX02?oonfX01?l0003ooo]Zool00?oo000=oookJP03ool00?oo
nf[ooo]Z00cooo]Z1?l0000<oookJP03ool00?oonf[ooo]Z00_ooo]Z00?oo`00oookJ_oonfX02ooo
nfX00ooo003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00oooo]Z0004o`0006;ooo]Z00Go00_o
oookJ_oonf[o00_ooookJP05oonW0005o`0:oooonf[ooo]ZoookJ_ooY@002OoonfX3oonQ00;ooo]Z
00?ooj40oookJ_ooX@000_ooX@000oooK03ooo]Zoom/0002oom/00Gooo]Z0ooo5P02oookJP03oole
0?oonf[ooo]Z00;ooo]Z00?oocd0oookJ_oonfX00_oonfX00ooo;@3ooo]ZoookJP0KoookJP03ool2
0?oonf[ooo]Z00?ooo]Z0_oo1`04oookJP03o`000?oo3P3oo`h000Kooo]Z00?ooa40oookJ_oonfX0
1?oonfX00ooo403ooo]ZoookJP05oookJP03ool>0?oonf[ooo]Z02oooo]Z00?oo`H0oookJ_oonfX0
1ooonfX00ooo1P3ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX0
1ooonfX00ooo003ooo]ZoookJP0aoookJP03ool00?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX0
2OoonfX00ooo003ooo]ZoookJP09oookJP03ool10?oonf[ooo]Z00[ooo]Z00?oo`40oookJ_oonfX0
9OoonfX00ooo003ooo]Zo`000009oookJP03ool00?oonf[ooo]Z00?ooo]Z00?oo`00oookJ_oonfX0
1OoonfX01?oo003ooo]ZoookJ_oonfX3o`0000Kooo]Z00?oo`00oookJ_oonfX0?OoonfX00ol0003o
oo]ZoookJP0?oookJP000_l0001ToookJP03o`0;oooonf[o00_o00;ooo]Z00?oojL0oookJ_ooY`00
0oooY`04oookJP03oonU0?oonf[ooo]Z00Cooo]Z0_ooX@06oookJP;ooj401?ooC`001?ooK03ooo]Z
oom/0?ooK002oookJP;ooaH000Gooo]ZoolF0?oonf[ooo]Zoole0005oookJP03oolm0?oonf[ooo]Z
00?ooo]Z00?oobd0oookJ_oonfX01_oonfX2oolV00?ooo]Z0_oo9P0JoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?ooa40oookJ_oonfX01OoonfX00ooo403ooo]ZoookJP05oookJP03ool>0?oonf[ooo]Z
00oooo]Z00?oo`00oookJ_oonfX01OoonfX00ooo003ooo]ZoookJP05oookJP03ool10?oonf[ooo]Z
037ooo]Z00?oo`00oookJ_oonfX01ooonfX2ool100Wooo]Z00?oo`40oookJ_oonfX01ooonfX2ool2
00[ooo]Z00?oo`80oookJ_oonfX0;_oonfX00ooo003ooo]ZoookJP06oookJP03ool10?oonf[oo`00
00_ooo]Z00?oo`00oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z
01Gooo]Z0ol0000HoookJP03ool00?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX03ooonfX000;o
oo]Z00?o0000oookJ_oonfX0HOoonfX01Ol02ooooo]Zo`0;oooonf[o00[o00;oojL000Go00[ooook
J_oonf[o00[ooonW0003oookJP03oonU0?oonf[ooo]Z00;ooo]Z0_ooX@0:oookJP;oodl000Cooo]Z
oom?0?ooC`3oof`04?oonfX00ooo?@3ooo]ZoookJP04oookJP04ool]0?oonf[ooaP0oolH00Cooo]Z
0_oo9P02oookJP;oobH01?oonfX2oolM00kooo]Z00?oo`00oookJ_oonfX00ooonfX00ooo003ooo]Z
o`000004oookJP03ool20?oonf[ooo]Z00Cooo]Z0_oo1`06oookJP03ool;0?oonf[ooo]Z00Gooo]Z
00?oo`d0oookJ_oonfX04_oonfX00ooo003ooo]ZoookJP05oookJP03ool10?oonf[ooo]Z00Kooo]Z
00?oo`80oookJ_oonfX01_oonfX00ooo103ooo]ZoookJP06oookJP03ool50?oonf[ooo]Z00Oooo]Z
00?oo`D0oookJ_oonfX0=_oonfX00ooo003oo`80oookJP07oookJP03ool00?oonf[ooo]Z00Sooo]Z
00?oo`00oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP0ooookJP03ool00?oonf[ooo]Z00;ooo]Z
00?o0000oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP05oookJP03ool00?oonf[o000000?o0000
0_oo000ZoookJP03ool00?oonf[ooo]Z00_ooo]Z00?oo`00oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP0?oookJP000ooonfX00ol0003ooo]ZoookJP1OoookJP05o`0;oooonf[ooo]Zo`0;oooonfX0
1?ooY`001?oonf[o00[ooookJ_ooY`04oookJP04oonU0?ooX@3ooj40oonQ00cooo]Z0_ooC`000ooo
nf[oof`0oom?000DoookJP03ool70?oonf[ooo]Z00?ooo]Z0_oo6004oookJP03oolV0?oonf[ooo]Z
00;ooo]Z00?oobH0oookJ_oonfX00_oonfX2oolM01Oooo]Z00Go0000oookJ_oonf[ooo]Zool20006
oookJP;oo`L01_oonfX00ooo2`3ooo]ZoookJP04oookJP;oo`d01ooonfX00ooo303ooo]ZoookJP0]
oookJP03ool50?oonf[ooo]Z00Oooo]Z00?oo`D0oookJ_oonfX01OoonfX00ooo003ooo]ZoookJP06
oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP0a
oookJP03ool00?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX02OoonfX2ool000_ooo]Z0_oo0@0<
oookJP03ool10?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX03OoonfX3o`0000_ooo]Z00?oo`00
oookJ_oonfX02ooonfX00ooo003ooo]ZoookJP0;oookJP03ool00?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX03_oonfX000Cooo]Z00?o0000oookJ_oonfX0H?oonfX02_l02ooooo]ZoookJ_ooY`3o
oo]ZoonW0?oonf[oojL0o`0:ooooY`04oookJP;ooj4000?oojD0oookJ_oonfX02OoonfX3oonS0005
oookJ_ooC`3oodl0oom?0?oo@@004ooonfX2ool700Cooo]Z00?ooaP0oookJ_oonfX00ooonfX00ooo
9P3ooo]ZoookJP04oookJP03oolV0?oonf[ooo]Z00?ooo]Z00?ooad0oookJ_oonfX05OoonfX00ol0
003ooo]Zool0000GoookJP03ool=0?oonf[ooo]Z00Kooo]Z00?oo``0oookJ_oonfX03OoonfX00ooo
003ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z00Gooo]Z00?oo`00oookJ_oonfX01_oonfX00ooo
0@3ooo]ZoookJP0aoookJP03ool00?oonf[ooo]Z00Sooo]Z00?oo`40oookJ_oonfX02?oonfX00ooo
0@3ooo]ZoookJP08oookJP;oo`801_oonfX00ooo003ooo]ZoookJP02oookJP03ool20?oonf[ooo]Z
02Wooo]Z00?oo`40oookJ_oonfX02_oonfX00ooo003oo`40oookJP09oookJP;oo`002?oonfX01Ol0
003ooo]ZoookJ_oonf[oo`0000Oooo]Z0ol00019oookJP03ool00?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX03_oonfX000Gooo]Z00?o0000oookJ_oonfX0GooonfX01?l02ooooo]Zo`0:oooonfX2
oonW00;ooo]Z00?oojL0oookJ_oonfX00_oonfX01OooX@3ooo]ZoookJ_oonf[oojD000Wooo]Z00Co
oj<0oookJ_ooX`3ooo]Z0_ooX`02oom?00;ood403_oonfX3oom001Cooo]Z00?oobH0oookJ_oonfX0
1?oonfX00ooo7@3ooa@0oookJP03oookJP?ooa/01?oonfX00ooo6@3ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX01?oonfX2ool100Kooo]Z00?oo`<0oookJ_oonfX0
1OoonfX00ooo1P3ooo]ZoookJP05oookJP03ool80?oonf[ooo]Z027ooo]Z0_oo0@08oookJP03ool2
0?oonf[ooo]Z00Kooo]Z0_oo0`08oookJP;oo`@02OoonfX01Ooo103ooo]ZoookJ_oonf[oo`0002Wo
oo]Z00?oo`80oookJ_oonfX02OoonfX2ool200Gooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo003o
oo]ZoookJP09oookJP03ool00?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX01OoonfX3o`0000Go
oo]Z00?oo`00oookJ_oonfX01?oonfX00ooo003ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z00;o
oo]Z00?oo`00oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0>oookJP001_oonfX2o`0005oooo]Z
00?o00_ooookJ_l02_l00_oonfX4oonW00Wooo]Z00?oojD0oookJ_oonfX01OoonfX8oonS0003oom1
0?ooC`3ooo]Z00gooo]Z00Good00ooli0?oo@03ooo]Zoom0000=oookJP03ool20?oonf[ooo]Z00Co
oo]Z00?oo`T0oookJ_oonfX01?oonfX00ooo503ooo]ZoookJP03oookJP03oolK0?oonf[ooo]Z00;o
oo]Z0ooo6@05oookJP03oolD0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX04_oonfX00ooo0`3o
oo]ZoookJP05oookJP03ool60?oonf[ooo]Z00Gooo]Z00?oo`P0oookJ_oonfX01OoonfX2ool900Oo
oo]Z0_oo2@0<oookJP03ool00?oonf[ooo]Z01oooo]Z00?oo`@0oookJ_oonfX02?oonfX00ooo103o
oo]ZoookJP0;oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo003o
oo]ZoookJP0boookJP03ool00?oonf[ooo]Z00[ooo]Z00?oo`00oookJ_oonfX02OoonfX2ool000[o
oo]Z00Coo`00oookJ_oonf[oo`402ooonfX00ol0003ooo]ZoookJP04o`0002[ooo]Z00?oo`00oook
J_oonfX02ooonfX00ooo003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00kooo]Z0008oookJP03
o`000?oonf[ooo]Z05_ooo]Z00_o00_ooookJ_oonf[o00[ooookJ_l02_oooo]ZoonW0?l02_oooo]Z
oonW000@oookJP03oonS0?oonf[ooo]Z00?ooj<000Gooo]ZoonS0?oo@@3ooo]Zoom?000<oookJP03
ooli0?oonf[ood0000;ood005?oonfX00ooo2@3ooo]ZoookJP04oookJP03oolD0?oonf[ooo]Z00Co
oo]Z00?ooa/0oookJ_oonfX01?oonfX00ooo6@3ooo]ZoookJP03oookJP;ooa@01?oonfX00ol0003o
oo]ZoookJP0>oookJP03ool00?oonf[ooo]Z01Wooo]Z00?oo`T0oookJ_oonfX01OoonfX2ool901Co
oo]Z00?oo`00oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP06oookJP;oo`40=?oonfX00ooo003o
oo]ZoookJP08oookJP03ool10?oonf[ooo]Z00Sooo]Z0_oo0@05oookJP03ool00?oonf[ooo]Z00?o
oo]Z00?oo`80oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP0aoookJP03ool10?oonf[ooo]Z00Oo
oo]Z00?oo`00oookJ_oonfX00ol00008oookJP03ool00?oonf[ooo]Z00[ooo]Z00?oo`00oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0>oookJP002OoonfX00ol0003ooo]ZoookJP1JoookJP03o`0;
oooonf[o00[o00;ooo]Z00Co00[ooookJ_oonf[o00[o0_oonfX00oooY`3ooo]ZoookJP0>oookJP;o
oj<00_oonfX3oonS00?oofl000?oodl0oookJ_oonfX02_oonfX2ooli0003oom00?oonf[ooo]Z00?o
obl09OoonfX00ooo6@3ooo]ZoookJP04oookJP03ool@0?oo503ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX05OoonfX00ooo003ooo]ZoookJP04oookJP03ool10?oonf[ooo]Z00Gooo]Z00?oo`<0oookJ_oo
nfX01_oonfX00ooo1@3ooo]ZoookJP0YoookJP03ool10?oonf[ooo]Z00Oooo]Z00?oo`80oookJ_oo
nfX01ooonfX2ool300cooo]Z00?oo`00oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP0[oookJP03
ool20?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP09oookJP03
ool00?oonf[ooo]Z01Sooo]Z0ol000000ooonf[o0000oookJP0EoookJP03ool00?oonf[ooo]Z00co
oo]Z00Goo`00oookJ_oonf[ooo]Zool0000=oookJP03ool00?oonf[ooo]Z00_ooo]Z00?oo`00oook
J_oonfX05ooonfX00ol0003ooo]ZoookJP0>oookJP002_oonfX00ol0003ooo]ZoookJP1IoookJP03
o`0;oooonf[o00[o00;ooo]Z00?o00[ooookJ_l02_l01?oonfX00oooY`3ooo]ZoookJP0;oookJP;o
oj<000Gooo]ZoonS0?oonf[ooo]ZoonS0002oom_00;ooo]Z0_ooK`000oooC`3ooo]ZoookJP02oook
JP?ooa/00ooonfX01_oo>@3ooo]ZoookJ_oonf[ood00oookJP?oobl05ooonfX00ooo003ooo]Zoook
JP03oookJP03ool30?oonf[ooo]Z00Cooo]Z0_oo2@05oookJP;ooa001OoonfX2oolC00Gooo]Z0_oo
4P0NoookJP03ool30?oonf[ooo]Z00Gooo]Z0_oo1@07oookJP;oo`L01ooonfX2ool700[ooo]Z00?o
o`00oookJ_oonfX01OoonfX00ooo003ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z01[ooo]Z00?o
o`<0oookJ_oonfX05?oonfX00ooo003ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z00Sooo]Z00?o
o`00oookJ_oonfX0<ooonfX00ooo003ooo]ZoookJP0:oookJP;oo`002?oonfX01Ol0003oo`00o`00
0?l0003oo`0000Cooo]Z00Go0000oookJ_oonf[ooo]Zool0000<oookJP03ool00?oonf[ooo]Z04_o
oo]Z00?o0000oookJ_oonfX03_oonfX000_ooo]Z00?o0000oookJ_oonfX0EooonfX01Ol02ooooo]Z
oookJ_l02_oooo]Z00GoojP01?oonfX00oooY`3ooo]ZoookJP07oookJP?ooj<00ooonfX00oooX`3o
oo]ZoonS0002oonS0003oom_0?oonf[oofl000?oofl00ooonfX3oolK00?ooo]Z00?oocT0oookJ_oo
nfX00_oonfX00ooo@03ooo]ZoookJP02ool_00[ooo]Z00?oobX0oookJ_oonfX05ooonfX00ooo2@3o
oo]ZoookJP04oookJP03ool@0?oonf[ooo]Z00Cooo]Z00?ooa<0oookJ_l000001?oonfX2oolB01?o
oo]Z00?oo`00oookJ_oonfX01?oonfX00ooo003ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z00[o
oo]Z00?oo`L0oookJ_oonfX01_oonfX2ool701_ooo]Z00?oo`00oookJ_oonfX01_oonfX2ool000Wo
oo]Z00?oo`40oookJ_oonfX0<_oonfX00ooo003ooo]ZoookJP09oookJP03ool10?oonf[ooo]Z00Wo
oo]Z0_oo0@02oookJP03ool00?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX02OoonfX00ooo003o
oo]ZoookJP0DoookJP?o00002_oonfX00ol0003ooo]ZoookJP06oookJP03ool10?oonf[ooo]Z01;o
oo]Z00?oo`00oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00ko
oo]Z000<oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o00_ooookJ_l02_l00_oonfX00oooZ03ooo]Z
oonX0003oonX00Cooo]Z00?oojL0oookJ_oonfX01?oonfX2oonS00Oooo]Z0_ooX`02oomA0004oook
J_ooK`3oofl0oom_00Cooo]Z00?ooa/0oookJ_oonfX00ooonfX00ooo>@3ooo]ZoookJP03oookJP03
oom00?oonf[ooo]Z00;ooo]Z00?oobl0oookJ_oonfX01_oonfX3oolZ00;ooo]Z0_oo:00CoookJP03
ool00?oonf[ooo]Z00Cooo]Z00?oo`40oookJ_oonfX01OoonfX01?oo4`3ooo]ZoookJ_l00004oook
JP03oolB0?oonf[ooo]Z023ooo]Z00?oo`00oookJ_oonfX01OoonfX00ooo0@3ooo]ZoookJP06oook
JP03ool30?oonf[ooo]Z00Kooo]Z00?oo`@0oookJ_oonfX06?oonfX00ooo003ooo]ZoookJP0>oook
JP03ool10?oonf[ooo]Z00Sooo]Z00?oo`80oookJ_oonfX02?oonfX00ooo0P3ooo]ZoookJP07oook
JP03ool00?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP0Foook
JP03ool10?oonf[ooo]Z00[ooo]Z0_oo0@0IoookJP03ool00?oonf[ooo]Z00Cooo]Z0ol00003oook
JP03ool00?oonf[ooo]Z00Kooo]Z00?oo`00oookJ_l000002_oonfX00ooo003ooo]ZoookJP0_oook
JP03ool00?oonf[ooo]Z00_ooo]Z00?oo`00oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0>oook
JP003OoonfX2o`0005Kooo]Z00?o00_ooookJ_l02_l00_oonfX2oonX0005o`0:oooonf[ooo]Zoook
J_ooZ0000ooonfX00oooY`3ooo]ZoookJP02oookJP;ooj<02_oonfX4oomA0003oookJ_ooK`3ooo]Z
013ooo]Z00?ood00oookJ_oonfX00ooonfX00ooo;`3ooo]ZoookJP02oolL00Cooo]Z00?oobX0oook
J_oonfX00_oo:005oookJP03oolO0?oonf[ooo]Z01?ooo]Z00?oo`40oookJ_oonfX01?oonfX00ooo
103ooo]ZoookJP02oookJP04o`000?oonf[oo`T0ool900Gooo]Z0_oo3@06oookJP03ool>0?oonf[o
oo]Z01Kooo]Z00?oo`00oookJ_oonfX02ooonfX00ooo0`3ooo]ZoookJP06oookJP03ool40?oonf[o
oo]Z00Kooo]Z00?oo`H0oookJ_oonfX06?oonfX00ooo003ooo]ZoookJP07oookJP03ool00?oonf[o
oo]Z017ooo]Z00?oo`80oookJ_oonfX02?oonfX00ooo0`3ooo]ZoookJP0MoookJP03ool00?oonf[o
oo]Z00Wooo]Z00?oo`00oookJ_oonfX02ooonfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[o
oo]Z013ooo]Z1?l00006oookJP03ool00?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oo00003_oonfX0
0ooo003ooo]ZoookJP03oookJP03ool00?oonf[ooo]Z00_ooo]Z00?oo`00oookJ_oonfX0=?oonfX0
0ol0003ooo]ZoookJP0>oookJP003ooonfX00ol0003ooo]ZoookJP1BoookJP05o`0;oooonf[ooo]Z
o`0:oooonfX01?ooZ003oookJP03oonX0?oonf[ooo]Z00;ooo]Z00CoojL0oonS0?ooX`3ooj<03?oo
nfX5oomA01?ooo]Z0ooo2P04oookJP03oolL0?oonf[ooa`000?ooo]Z00?oobX0oookJ_oonfX00_oo
nfX00ooo:03ooo]ZoookJP02oookJP?ooal06OoonfX00ooo003ooo]ZoookJP05oookJP03o`000?oo
2@3ooo]Z00Kooo]Z00?oo`d0oookJ_oonfX01?oonfX2ool>00Kooo]Z0_oo3@0GoookJP03ool00?oo
nf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX03?oonfX00ooo1P3ooo]ZoookJP07oookJP03ool60?oo
nf[ooo]Z027ooo]Z0_oo0009oookJP03ool10?oonf[ooo]Z017ooo]Z00?oo`00oookJ_oonfX01ooo
nfX00ooo003ooo]ZoookJP0EoookJP03ool00?oonf[ooo]Z00[ooo]Z00?oo`40oookJ_oonfX02_oo
nfX00ooo0@3ooo]ZoookJP0:oookJP03ool00?oonf[ooo]Z00?o00001_oonfX00ooo003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX08?oonfX00ooo003ooo]Zoook
JP0LoookJP03ool00?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX03OoonfX0013ooo]Z00?o0000
oookJ_oonfX0DooonfX02_l02_oooo]ZoookJ_ooZ03ooo]ZoonX0?oonf[oojP0oookJ_ooZ004oook
JP;ooj<000?oojL0oookJ_oonfX02_oonfX2oonU00;ooe4000?ooo]ZoomA0?ooK`000_ooAP0Goook
JP03oolL0?oonf[ooo]Z00Cooo]Z00?oobX0oookJ_oonfX00ooonfX00ooo:03ooo]ZoookJP02oook
JP;ooal01ooonfX00ooo7P3ooo]ZoookJP0FoookJP03ool00?oonf[o000000Cooo]Z00?oo`40oook
J_oonfX02?oonfX00ooo3P3ooo]ZoookJP05oookJP03ool=0?oonf[ooo]Z01kooo]Z00?oo`00oook
J_oonfX01OoonfX2ool100Sooo]Z00?oo`<0oookJ_oonfX05_oonfX00ooo003ooo]ZoookJP07oook
JP03ool00?oonf[ooo]Z013ooo]Z00?oo`40oookJ_oonfX02?oonfX00ooo0P3ooo]ZoookJP09oook
JP03ool20?oonf[ooo]Z00oooo]Z00?oo`00oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP0Hoook
JP03ool10?oonf[ooo]Z00[ooo]Z0ol00009oookJP03ool00?oonf[ooo]Z00[ooo]Z00Goo`00oook
J_oonf[ooo]Zo`000009oookJP03ool00?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX02_oonfX0
0ooo003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z00gooo]Z000AoookJP03o`000?oonf[ooo]Z
05;ooo]Z00Co00[ooookJ_l02_oooo]Z0_ooZ002oookJP03oonX0?oonf[ooo]Z00;ooo]Z00Gooj<0
oookJ_oonf[ooo]ZoonW000:oookJP08oonU0?oonf[oojD0oookJ_ooY@3ooe40oom_0?ooD@02oom6
00kooo]Z0_oo@`0?oookJP03ool30?oonf[ooo]Z00;ooo]Z00?oobP0oookJ_oo30001?oonfX00ooo
7`3ooaP0oolH0004oookJP;ooah01?oonfX00ooo6`3ooo]ZoookJP0CoookJP05o`000?oonf[ooo]Z
oookJ_oo0@001_oonfX2ool400Kooo]Z0_oo2007oookJP03ool:0?oonf[ooo]Z01Cooo]Z00?oo`00
oookJ_oonfX01?oonfX2ool000kooo]Z00?oo`<0oookJ_oonfX01_oonfX2ool400Sooo]Z0_oo1@0G
oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX05?oonfX00ooo0P3ooo]ZoookJP0J
oookJP03ool00?oonf[ooo]Z00Wooo]Z0_oo000;oookJP03ool00?oonf[ooo]Z00Wooo]Z00Coo`00
o`000?l0003o00002?oonfX00ooo003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
o`00oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP0@oookJP03ool00?oonf[ooo]Z00_ooo]Z00?o
o`00oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0=oookJP004_oonfX00ol0003ooo]ZoookJP1A
oookJP03o`0:oooonf[o00[o00;ooo]Z1?ooZ009oookJP03oonW0?oonf[ooo]Z00Kooo]Z2?ooY@00
0oooAP3ooe40oookJP0<oookJP05oolm0?oo@`3ood<0oookJ_oo@`003OoonfX2ool300Gooo]Z0_oo
3005oookJP;ooaP01?oonfX00ooo7P3ooo]ZoookJP03oookJP;ooa/05OoonfX00ol0003oo`00oook
JP05oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oo`P0oookJ_oonfX01OoonfX2ool:00Oooo]Z00?o
o`/0oookJ_oonfX04ooonfX00ooo003ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z00Kooo]Z00?o
o`00oookJ_oonfX03_oonfX00ooo1@3ooo]ZoookJP0PoookJP03ool00?oonf[ooo]Z00Sooo]Z00?o
o`00oookJ_oonfX06_oonfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z01Oooo]Z00?o
o`00oookJ_oonfX01_oonfX4o`000003ool10?oonf[ooo]Z01Gooo]Z00?oo`00oookJ_oonfX01ooo
nfX01?l0003ooo]ZoookJ_oo000doookJP03ool00?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
3OoonfX001?ooo]Z0_l0001@oookJP08o`0:oooonf[ooo]Zo`0:oooonf[o00[ooookJ_ooZ002oook
JP03oonX0?oonf[ooo]Z00oooo]Z00?oojD0oom60?ooAP001?ooY@001?ooK`3ooo]ZoookJ_ooD@0<
oookJP04oolm0?oo@`3ood<0oom301_ooo]Z00?ooaP0oookJ_oonfX01?oonfX00ooo7P3ooo]Zoook
JP04oookJP03oolK0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX02ooonfX00ooo003ooo]Zoook
JP05oookJP03ool20?oonf[ooo]Z00Wooo]Z00?oo`/0oookJ_oonfX09OoonfX00ooo003ooo]Zoook
JP06oookJP;oo`402?oonfX00ooo0P3ooo]ZoookJP0EoookJP03ool00?oonf[ooo]Z00Oooo]Z00?o
o`00oookJ_oonfX04_oonfX00ooo0@3ooo]ZoookJP09oookJP03ool10?oonf[ooo]Z01Wooo]Z00?o
o`00oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP06oookJP?o00003?oonfX00ooo003ooo]Zoook
JP03oookJP03ool10?oonf[ooo]Z017ooo]Z00Co0000oookJ_oonf[oo`003OoonfX00ooo003ooo]Z
oookJP0@oookJP03ool00?oonf[ooo]Z00_ooo]Z00?oo`00oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0=oookJP005OoonfX00ol0003ooo]ZoookJP1=oookJP03o`0:oooonf[o00[o00;ooo]Z00?o
00[ooookJ_oonfX00ooonfX00oooZ03ooo]ZoookJP0>oookJP04oom60?ooY@3oojD0oookJP;oojD0
00Koofl0ooma0?ooL@3oog40oookJ_ooD@06oookJP03oolP0?oonf[ooo]Z00;ooo]Z0_oo?@000ooo
@`3ooo]ZoookJP02oola01Sooo]Z00?oo`40oookJ_oonfX01?oonfX00ooo1@3ooo]ZoookJP04oook
JP03oolK0?oonf[ooo]Z00Cooo]Z00?ooa<0oookJ_oonfX01?oonfX00ooo5@3ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z00kooo]Z00Goo`00oookJ_oonf[ooo]Zool20007oookJP03ool40?oonf[o
oo]Z00Gooo]Z0_oo1P0LoookJP03ool00?oonf[ooo]Z00Gooo]Z00?oo`00oookJ_oonfX03_oonfX0
0ooo0P3ooo]ZoookJP07oookJP;oo`<08?oonfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[o
oo]Z00Wooo]Z00?oo`40oookJ_oonfX02OoonfX01?oo0P3ooo]ZoookJ_oo000HoookJP03ool00?oo
nf[ooo]Z00?ooo]Z0ol00004oookJP03ool00?oonf[ooo]Z01Cooo]Z00?oo`00oookJ_oonfX02_oo
nfX00ooo003ooo]Zo`00000NoookJP03ool00?oonf[ooo]Z01gooo]Z00?oo`00oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP0=oookJP005_oonfX00ol0003ooo]ZoookJP1<oookJP03o`0:oooonf[o
00[o00;ooo]Z00?o00[ooookJ_oonfX01?oonfX00oooZ03ooo]ZoookJP0;oookJPCoojD00_oonfX0
0oooY@3oog40ooma0002oookJP;oog4000?ooo]ZoomA0?oonfX00ooonfX3oolP00;ooo]Z00Woocd0
oookJ_oonf[ooo]Zoom30?oonf[ooc40oookJ_oo<@007_oonfX00ooo1@3ooo]ZoookJP03oookJP?o
o``01OoonfX2oolC00Cooo]Z0_oo5@06oookJP05oolC0?oonf[ooo]ZoookJ_l000005ooonfX00ooo
003ooo]ZoookJP09oookJP03ool60?oonf[ooo]Z00Kooo]Z00?oo`P0oookJ_oonfX01_oonfX00ooo
203ooo]ZoookJP0JoookJP03ool00?oonf[ooo]Z00Oooo]Z00?oo`40oookJ_oonfX01OoonfX00ooo
0`3ooo]ZoookJP08oookJP03ool40?oonf[ooo]Z00[ooo]Z00?oo`00oookJ_oonfX01ooonfX00ooo
003ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX06?oonfX00ooo
003ooo]ZoookJP09oookJP04ool00?oonf[ooo]ZoookJPCo00005?oonfX00ooo003ooo]ZoookJP0;
oookJP03ool10?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP1;
oookJP03o`000?oonf[ooo]Z00gooo]Z000GoookJP03o`000?oonf[ooo]Z04[ooo]Z00Go00[ooook
J_oonf[o00[ooookJP04oonY00Gooo]Z00?oojP0oookJ_oonfX02?oonfX2oonU00?ooo]Z00?oojD0
oookJ_ooY@000_ooY@000oooL@3ooo]Zooma0003ooma00;ooo]Z0ooo80001Ooonf[oob00oookJ_oo
nf[oocd000Cooo]Z00Cood<0oookJ_oonf[ooc402ooonfX2ool]01Oooo]Z0_oo0007oookJP03oolC
0?oonf[ooo]Z00Cooo]Z00?ooaD0oookJ_oonfX01?oonfX2oolC00?ooo]Z00?o0000oookJ_oonfX0
7?oonfX00ooo003ooo]ZoookJP05oookJP03ool20?oonf[ooo]Z00;ooo]Z00?oo`P0oookJ_oonfX0
1_oonfX2ool801Cooo]Z00?oo`00oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP04oookJP;oo`40
2?oonfX2ool102Wooo]Z00?oo`00oookJ_oonfX05?oonfX2ool100_ooo]Z00?oo`40oookJ_oonfX0
3OoonfX3o`0000Sooo]Z00?oo`00oookJ_oonfX06ooonfX00ooo0@3ooo]ZoookJP02oookJP03ool0
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX05?oonfX00ooo003ooo]ZoookJP0<oookJP03ool0
0?oonf[ooo]Z00kooo]Z00?oo`00oookJ_oonfX02ooonfX00ooo003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z00gooo]Z000HoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o00[ooookJ_l02_l00_oo
nfX00oooZ@3ooo]ZoonY0002oonY00Gooo]Z00?oojP0oookJ_oonfX01OoonfX2oonU00Kooo]Z0_oo
Y@03oookJP?oog402_oonfX00ooo?@3ooo]ZoookJP03oookJP05oom30?oonf[ooo]ZoookJ_oo<@00
1OoonfX2oolO00;ooo]Z00Goobd0oookJ_oo;@3oobd0oookJP02ool[01[ooo]Z0_oo0@06oookJP03
ool50?oo5@3ooo]Z00Cooo]Z00?oo`/0oookJ_oo4`001?oonfX00ol0003oo`l0oookJP0GoookJP03
ool00?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo0P3ooo]ZoookJP05oookJP;o
o`@0;?oonfX00ooo003ooo]ZoookJP0@oookJP03ool20?oonf[ooo]Z00Sooo]Z00?oo`<0oookJ_oo
nfX07?oonfX2ool000[ooo]Z00?oo`00oookJ_oonfX02ooonfX00ooo0@3ooo]ZoookJP09oookJP04
ool00?l0003o0000o`0000Sooo]Z00?oo`00oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP0:oook
JP;oo`004OoonfX01?l0003ooo]ZoookJ_oo000=oookJP03ool00?oonf[ooo]Z04;ooo]Z00?o0000
oookJ_oonfX03OoonfX001Wooo]Z0_l00019oookJP03o`0:oooonf[o00[o00;ooo]Z0oooZ@000ooo
nf[oojT0oonY0004oookJP03oonX0?oonf[ooo]Z00;ooo]Z0oooY@0:oookJP?ooe8000?ooo]Zooma
0?oonfX04?oonfX00ooo@`3ooo]ZoookJP02ool=0004oola0?oonf[ooo]ZoookJP?ooal00ooonfX0
0ooo;@3ooo]ZoookJP04ool[01oooo]Z00?oo`00ool50?oonfX01_oonfX00ooo2`3ooo]ZoookJP04
oookJP;oo`l01_oonfX00ooo403ooo]ZoookJP0NoookJP03ool00?oonf[ooo]Z00_ooo]Z0_oo1@08
oookJP03ool60?oonf[ooo]Z027ooo]Z0_oo0009oookJP03ool10?oonf[ooo]Z00Oooo]Z00?oo`<0
oookJ_oonfX04OoonfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z00Wooo]Z00?oo`00
oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP08oookJPCo00005ooonfX00ooo003ooo]ZoookJP0=
oookJP03ool00?oonf[ooo]Z00_ooo]Z0_oo0003oookJP03o`000?oonf[ooo]Z01_ooo]Z00?oo`00
oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0<oookJP006ooonfX00ol0003ooo]ZoookJP15oook
JP07o`0:oooonf[ooo]Zo`0:oooonf[oojT0oookJP02oonY00?ooo]Z00?oojT0oookJ_oonfX00_oo
nfX01?ooZ03ooo]ZoonU0?ooY@0=oookJP04oomB0?oonf[ooo]ZoomB00;oodT04_oonfX01ooo3@3o
oo]ZoookJ_oonf[ooc40oookJ_oo7`001_oonfX01?oo;@3ooo]ZoookJ_oonfX2ool[02Kooo]Z0_oo
0008oookJP03ool?0?oonf[o000000Gooo]Z00?ooa00oookJ_oonfX09_oonfX2ool100Sooo]Z00?o
o`80oookJ_oonfX00ooonfX00ooo1P3ooo]ZoookJP0IoookJP03ool00?oonf[ooo]Z00Oooo]Z00?o
o`00oookJ_oonfX01_oonfX00ooo0@3ooo]ZoookJP07oookJP03ool10?oonf[ooo]Z02Oooo]Z00?o
o`00oookJ_oonfX02_oonfX00ooo003ooo]ZoookJP05oookJP?o000000?ooo]Zool10?oo0@002Ooo
nfX00ooo003ooo]ZoookJP0IoookJP03ool00?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX01_oo
nfX00ooo0@3ooo]Zool0000<oookJP03ool00?oonf[ooo]Z017ooo]Z00?oo`00oookJ_oonfX07?oo
nfX00ooo003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00cooo]Z000LoookJP03o`000?oonf[o
oo]Z04Kooo]Z00?o00[ooookJ_oonfX00oooZ@001?oonf[oojT0oookJ_ooZ@04oookJP;oojD000?o
ojP0oookJ_oonfX02_oonfX2oonW00Cooe8000Coog40oom90?ooB@3oodT07OoonfX00ooo;@3ooo]Z
oookJP03oookJP03ool[0?oonf[ooo]Z00Kooo]Z0_oo6`04oookJP03oolP0?oonf[ooo]Z01_ooo]Z
00?oo`00oookJ_oo0P001?oonfX01_l0003ooo]Zool50?oo1@3ooo]Zool@02?ooo]Z00?oo`00oook
J_oonfX01_oonfX00ooo003ooo]ZoookJP02oookJP03ool20?oonf[ooo]Z00Oooo]Z00?oo`<0oook
J_oonfX0:OoonfX00ooo003ooo]ZoookJP07oookJP03ool10?oonf[ooo]Z00Sooo]Z00?oo`80oook
J_oonfX04?oonfX00ooo003ooo]ZoookJP0DoookJP03ool00?oonf[ooo]Z00Cooo]Z0ol0000Aoook
JP;oo`402?oonfX00ooo003ooo]ZoookJP09oookJP03ool00?oonf[ooo]Z00kooo]Z00?oo`00oook
J_oonfX02?oonfX01?l0003ooo]ZoookJ_oo000QoookJP03ool00?oonf[ooo]Z02gooo]Z00?o0000
oookJ_oonfX03?oonfX001gooo]Z00?o0000oookJ_oonfX0AOoonfX00ol02_oooo]ZoookJP03oonY
00;ooo]Z00?oojT0oookJ_oonfX00_oonfX01OooY@3ooo]ZoookJ_oonf[oojP000[ooo]Z00GoojL0
oookJ_ooY`3ooo]ZoonW0002oomB0003ooma0?ooB@3oodT000gooo]Z00?ood00oom50?ooA@003ooo
nfX2ool500Cooo]Z00?oob/0ool?0?oo3`001OoonfX2oolK00?ooo]Z0ooo800RoookJP;oo`0000?o
0000ool50?oo1@001_oonfX2ool900Kooo]Z0_oo300VoookJP03ool00?oonf[ooo]Z00Cooo]Z00?o
o`<0oookJ_oonfX01_oonfX2ool501Sooo]Z00?oo`00oookJ_oonfX04?oonfX2ool001Gooo]Z00?o
o`<0oookJ_oonfX03_oonfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z00?ooo]Z0ol0
0005oookJP03ool00?oonf[ooo]Z00[ooo]Z00?oo`40oookJ_oonfX08_oonfX00ooo003ooo]Zoook
JP0=oookJP03o`000?oonf[oo`0000kooo]Z00?oo`00oookJ_oonfX07_oonfX00ooo003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z00cooo]Z000NoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o00[o
oookJ_l02_l00_oonfX4oonY00Wooo]Z00?oojP0oookJ_oonfX01_oonfX8oonW0003oomB0?oonf[o
oo]Z00cooo]Z00Good00oom50?ooA@3ood00oom5000DoookJP03ool?0?oonf[ooo]Z00Gooo]Z00?o
oa/0oookJ_oonfX00ooonfX00ooo803ooo]ZoookJP02oookJP;ooad08?oonfX00ol0003ooo]Zoook
JP02oookJP04ool10?oonf[ooo]Zool900Oooo]Z0_oo3007oookJP03ool<0?oonf[ooo]Z01Kooo]Z
00?oo`00oookJ_oonfX01OoonfX00ooo003ooo]ZoookJP04oookJP03ool10?oonf[ooo]Z00kooo]Z
0_oo1@0HoookJP03ool00?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX01ooonfX00ooo0@3ooo]Z
oookJP08oookJP03ool10?oonf[ooo]Z01cooo]Z1?l00006oookJP03ool00?oonf[ooo]Z00_ooo]Z
00?oo`40oookJ_oonfX02ooonfX00ooo0@3ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z01[ooo]Z
00Goo`00oookJ_oonf[ooo]Zo`00000>oookJP03ool00?oonf[ooo]Z00_ooo]Z00?oo`00oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP0<oookJP007ooonfX00ol0003ooo]ZoookJP12oookJP04o`0:
oooonf[ooo]Zo`0:o`?ooo]Z00CoojT0oookJ_oonf[oojT04OoonfX00oooY`3oodT0oom90003oonW
0004oookJ_ooY`3ooo]ZoomB00gooo]Z00Cood00oom50?ooA@3oodD07?oonfX00ooo6`3ooo]Zoook
JP04oookJP03oolP0?oonf[ooo]Z00?ooo]Z00?ooad0oookJ_oonfX07ooonfX00ol0003oo`00oook
JP05oookJP03ool00?oonf[ooo]Z00;oo`801ooonfX01Ooo1@3ooo]ZoookJ_oonf[oo``002Wooo]Z
00?oo`00oookJ_oonfX01?oonfX2ool203Cooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo0@3ooo]Z
oookJP09oookJP03ool20?oonf[ooo]Z00gooo]Z00?oo`00o`000?l000005_oonfX00ooo003ooo]Z
oookJP0=oookJP03ool10?oonf[ooo]Z017ooo]Z00?oo`00oookJ_oonfX02OoonfX00ooo003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX07_oonfX00ooo003ooo]Z
oookJP0;oookJP03ool00?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX03?oonfX0023ooo]Z0_l0
0012oookJP03o`0:oooonf[o00[o00Sooo]Z00?oojT0oookJ_oonfX03_oonfX00oooB@3oojL0oonW
0002oookJP;oojL000Coog40oomc0?ooL`3ooe801ooonfX2oolT00?ooo]Z0_oo@0000oooA@3ooo]Z
oookJP0QoookJP03ool60?oo803ooo]Z00Gooo]Z00?ooad0oookJ_oonfX00ooonfX2oolF01[ooo]Z
00?o0000oookJ_oonfX02ooonfX2ool000?ooo]Z00?oo`D0oookJ_oonfX01OoonfX00ooo203ooo]Z
oookJP0/oookJP03ool00?oonf[ooo]Z00Gooo]Z00?oo`<0oookJ_oonfX01ooonfX2ool401Kooo]Z
00?oo`00oookJ_oonfX04_oonfX00ooo003ooo]ZoookJP09oookJP03ool20?oonf[ooo]Z00[ooo]Z
0ol0000;oookJP03ool00?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX03?oonfX2ool002cooo]Z
00Go0000oookJ_oonf[ooo]Zool0000BoookJP;oo`00>OoonfX00ol0003ooo]ZoookJP0<oookJP00
8_oonfX00ol0003ooo]ZoookJP0ooookJP03o`0:oooonf[o00[o00Wooo]Z00?oojT0oookJ_oonfX0
2ooonfX3oonW0005oookJ_ooY`3ooo]ZoookJ_ooY`000_ooL`001?oonf[oog<0oomc0?ooDP03oook
JPGoob@00_oonfX01Ooo@03ooo]ZoookJ_oonf[oodD002Sooo]Z00?oo`00ool?0?oonfX01_oonfX0
0ooo5P3ooo]ZoookJP03oookJP;ooaL05?oonfX00ol0003ooo]ZoookJP0BoookJP;oo`400ooonfX0
0ooo203ooo]ZoookJP06oookJP03ool90?oonf[ooo]Z01cooo]Z00?oo`00oookJ_oonfX01_oonfX0
0ooo003ooo]ZoookJP05oookJP03ool10?oonf[ooo]Z00Gooo]Z00?oo`@0oookJ_oonfX07ooonfX0
0ooo003ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z00Wooo]Z00?oo`40oookJ_oonfX01ooonfX4
o`0000cooo]Z00?oo`00oookJ_oonfX05_oonfX00ooo003ooo]ZoookJP0>oookJP03ool10?oonf[o
oo]Z00oooo]Z00?oo`00oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0>oookJP03ool00?oonf[o
oo]Z01gooo]Z00?oo`00oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0<oookJP008ooonfX00ol0
003ooo]ZoookJP0moookJP04o`0:oooonf[ooo]Zo`0:o`[ooo]Z00?oojT0oookJ_oonfX02?oonfX2
oonW00Cooo]Z00KoojL0oookJ_ooY`3oojL0oomc0?oonfX4oomc0003oomB0?oonf[oob@000Kooo]Z
00?ood00oookJ_oonfX00_oonfX00oooA@3ooo]ZoookJP0<oookJP;ooc007ooonfX00ooo0P3ooaH0
oookJP05oookJP03oolG0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX03OoonfX00ooo003ooo]Z
oookJP05oookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`<0oookJ_oonfX00_oonfX00ooo2@3ooo]Z
oookJP0^oookJP03ool00?oonf[ooo]Z00Kooo]Z00?oo`80oookJ_oonfX07OoonfX00ooo003ooo]Z
oookJP07oookJP03ool00?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX01OoonfX3o`0000;ooo]Z
00?oo`40oookJ_oonfX05_oonfX00ooo003ooo]ZoookJP0;oookJP03ool00?oonf[ooo]Z00[ooo]Z
00?oo`00oookJ_oonfX03ooonfX00ooo0@3ooo]ZoookJP0>oookJP04ool00?oonf[ooo]Zo`0001go
oo]Z00?oo`00oookJ_oonfX07OoonfX00ooo003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00co
oo]Z000ToookJP03o`000?oonf[ooo]Z03cooo]Z00?o00[ooookJ_l02_l03?oonfX00oooZ@3ooo]Z
oookJP05oookJP;oojL01ooonfX2oonW00;ooo]Z0oooL`0:oookJP03oom00?oonf[ooo]Z00?ooo]Z
00?oodD0oookJ_oonfX00_oo4@05oookJP?oob<00_oonfX3ool`0003oookJ_oo;03oob`0023ooo]Z
00Goo`00oookJ_oo1`3oo`L0oolG0005oookJP03ool=0?oonf[ooo]Z00kooo]Z00?o0000oookJ_oo
nfX07?oonfX00ooo003ooo]ZoookJP02oookJP;oo`D09?oonfX00ooo003ooo]ZoookJP0?oookJP03
ool00?oonf[ooo]Z00Kooo]Z00?oo`<0oookJ_oonfX07OoonfX00ooo003ooo]ZoookJP0=oookJP?o
00000ooonfX00ooo003ooo]ZoookJP0;oookJP03ool20?oonf[ooo]Z01Gooo]Z00?oo`00oookJ_oo
nfX06_oonfX00ooo003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00Kooo]Z00?oo`00oookJ_oo
nfX02ooonfX00ooo003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z00_ooo]Z000UoookJP03o`00
0?oonf[ooo]Z03_ooo]Z00?o00[ooookJ_l02_l03?oonfX00oooZ@3ooo]ZoookJP02oookJP?oojL0
3_oonfX00oooL`3ooo]ZoookJP0?oookJP05oom50?oonf[ooa40oookJ_oo4@001?oonfX4oolS00;o
oo]Z0_oo<002oookJP03ool/0?oonf[oob`001oooo]Z00?oo`00oookJ_oonfX01?oonfX01?oo0@3o
oo]Zool=0?oo3@06oookJP;ooa402OoonfX00ol0003ooo]ZoookJP0FoookJP03ool00?oonf[ooo]Z
00;ooo]Z00Coo`00oookJ_oonf[oo`001?oonfX2ool100Cooo]Z0_oo1P08oookJP03ool70?oonf[o
oo]Z01Wooo]Z00?oo`00oookJ_oonfX01_oonfX2ool000Sooo]Z00?oo`40oookJ_oonfX01ooonfX0
0ooo0`3ooo]ZoookJP0LoookJP03ool00?oonf[ooo]Z00?o00001OoonfX00ooo003ooo]ZoookJP0:
oookJP03ool10?oonf[ooo]Z01Gooo]Z00?oo`00oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP09
oookJP03ool00?oonf[ooo]Z00oooo]Z00?oo`00oookJ_oonfX02OoonfX01Ol0003ooo]ZoookJ_oo
nf[oo`0001;ooo]Z00?oo`00oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP0LoookJP03ool00?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX02ooonfX002Kooo]Z0_l0000joookJP04o`0:oooonf[o
oo]Zo`0:o`gooo]Z00CoojT0oookJ_ooY`3oojL04?oonfX00oooL`3oodd0oom=000HoookJP03oolS
0?oonf[ooo]Z00Cooo]Z00?ooc00oookJ_oonfX00_oonfX00ooo;03ooo]ZoookJP0ZoookJP06ool0
0?oonf[oo`<0ool30?oonf[ooa401_oonfX2oolA00?ooo]Z00?o0000oookJ_oonfX09OoonfX00ooo
003ooo]ZoookJP03oookJP;oo`<01OoonfX00ooo1`3ooo]ZoookJP0RoookJP03ool00?oonf[ooo]Z
00Oooo]Z00?oo`00oookJ_oonfX01ooonfX2ool201cooo]Z00Coo`00o`000?l0003o00004ooonfX0
0ooo003ooo]ZoookJP0<oookJP03ool10?oonf[ooo]Z01?ooo]Z00?oo`00oookJ_oonfX06ooonfX0
0ooo003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00kooo]Z00?oo`00oookJ_oonfX0>ooonfX0
0ol0003ooo]ZoookJP0;oookJP00:?oonfX00ol0003ooo]ZoookJP0ioookJP03o`0:oooonf[ooo]Z
00_ooo]Z0_ooY`000oooZ@3ooo]ZoookJP0:oookJP?oojP00ooonfX01?ooL`3oodd0oom=0?ooC@0M
oookJP03ool`0?oo1`3oo`L000?ooo]Z00?oob`0oookJ_oonfX00_oo4P04oookJP;ooah01?oonfX2
oolR02?ooo]Z00Coo`00oookJ_oonf[oo`L00_oonfX00ooo4@3ooo]ZoookJP02oookJP03ool;0?oo
nf[ooo]Z02Cooo]Z00?oo`00oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP03oookJP;oo`@08ooo
nfX00ooo003ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oo`80ool00?oonfX02?oo
nfX2ool200kooo]Z0ol0000;oookJP03ool00?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oonfX02_oo
nfX00ooo003ooo]Zool1000RoookJP03ool00?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX04?oo
nfX00ol0003ooo]ZoookJP0KoookJP03ool00?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX02ooo
nfX002Wooo]Z00?o0000oookJ_oonfX0>?oonfX00ol02_oooo]ZoookJP0:oookJP05oonW0?oonf[o
oo]ZoookJ_ooZ@002_oonfX01?ooZ03ooo]ZoonX0?oonfX3oonX0003oomc0?ooC@3oodd000kooo]Z
00?ood<0oom60?oonfX05?oonfX01?oo;03ooa80oolB0?oo4P05oookJP;ooah00_oonfX3oolR02?o
oo]Z00?oo`00oookJ_oonfX00_oonfX01?oo003ooo]ZoookJ_oo0@02oookJP03ool;0?l0003ooo]Z
00Gooo]Z00?oo`d0oookJ_oonfX07ooonfX00ooo003ooo]ZoookJP03oookJP03ool00?oonf[oo`00
00?ooo]Z00Coo`@0oookJ_oonf[oo`401_oonfX2ool502;ooo]Z00?oo`00oookJ_oonfX01_oonfX0
0ooo003ooo]ZoookJP08oookJP03ool20?oonf[ooo]Z00[ooo]Z0ol0000<oookJP03ool00?oonf[o
oo]Z00[ooo]Z00?oo`00oookJ_oonfX02_oonfX00ooo003ooo]ZoookJP0:oookJP03ool10?oonf[o
oo]Z01;ooo]Z00?oo`00oookJ_oonfX03OoonfX00ooo003ooo]ZoookJP0?oookJP;oo`001?oonfX0
0ol0003ooo]ZoookJP0DoookJP03ool00?oonf[ooo]Z017ooo]Z00?oo`00oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0;oookJP00:_oonfX00ol0003ooo]ZoookJP0goookJP03o`0:oooonf[ooo]Z
00oooo]Z00?oojT0oookJ_oonfX01_oonfX9oonX0003oom=0?oonf[ooo]Z00cooo]Z00Cood<0oom6
0?ooAP3oodH06ooonfX00ooo0`3ooah0oookJP04oookJP03oolR0?oonf[ooo]Z02Wooo]Z0_oo0@02
oookJP05ool;0?oo003o0000oookJ_oo0`000ooonfX2ool=02_ooo]Z00Ooo`00oookJ_oonf[ooo]Z
ool10?oonf[oo`0000Cooo]Z00?oo`D0oookJ_oo0`008OoonfX00ooo003ooo]ZoookJP07oookJP03
ool00?oonf[ooo]Z00Oooo]Z00?oo`40oookJ_oonfX01_oonfX4o`0001[ooo]Z00?oo`00oookJ_oo
nfX02_oonfX00ooo003ooo]ZoookJP0<oookJP03ool10?oonf[ooo]Z01kooo]Z00?oo`00oookJ_oo
nfX03_oonfX2ool000[ooo]Z00?o0000oookJ_oonfX01OoonfX2ool001[ooo]Z00?oo`00oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0;oookJP00:ooonfX00ol0003ooo]ZoookJP0eoookJP03o`0:
oooonf[ooo]Z01Wooo]Z00CoojP0oookJ_ooC@3oodd01OooZ00:oookJP03oolW0?oonf[ooo]Z00;o
oo]Z1OooAP0JoookJP03oolN0?oonf[ooo]Z00Cooo]Z00?oob80ool80?oonfX01OoonfX00ooo4@3o
oo]ZoookJP0VoookJP05ool00?oonf[o0000ool30?oo00000_oonfX01?oo3@3ooo]ZoookJ_oonfX2
ool602gooo]Z00?oo`00oookJ_oo00001?oonfX00ooo0`3ooo]ZoookJP07oookJP03ool40?oonf[o
oo]Z01oooo]Z00?oo`00oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP03oookJP?o00000_oonfX2
ool202Gooo]Z00?oo`00oookJ_oonfX02ooonfX00ooo003ooo]ZoookJP0=oookJP;oo`407ooonfX0
0ooo003ooo]ZoookJP0=oookJP04o`000?oonf[ooo]Zool002kooo]Z00?oo`00oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP0;oookJP00;?oonfX2o`0003Gooo]Z00?o00[ooookJ_oonfX06_oonfX3
oonX0004oookJ_ooZ03oojP0oomc00?oog@02?oonfX2oolW00?ooo]Z0_oo@`000oooAP3ooo]Zoook
JP0QoookJP03oolR0?oonf[ooo]Z00?ooo]Z00?oo`40oolA0?oo4@001OoonfX2oolH02Cooo]Z00Go
0000oookJ_oonf[ooo]Zool00003oookJP03ool60?oonf[ooo]Z00;ooo]Z00Goo`80oookJ_oonf[o
oo]Zool9000^oookJP03ool10?oonf[ooo]Z00Gooo]Z00?oo`@0oookJ_oonfX02?oonfX00ooo1@3o
oo]ZoookJP0NoookJP03ool00?oonf[ooo]Z00?o00001OoonfX00ooo0@3ooo]ZoookJP09oookJP;o
o`805ooonfX00ooo003ooo]ZoookJP0:oookJP;oo`003_oonfX00ooo003ooo]ZoookJP0MoookJP03
ool00?oonf[ooo]Z00kooo]Z0_oo0002oookJP03o`000?oonf[ooo]Z00gooo]Z0_oo000HoookJP03
ool00?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX02ooonfX002kooo]Z00?o0000oookJ_oonfX0
<_oonfX00ol02_oooo]ZoookJP0HoookJPCoojP00_oonfX01_ooZ03oog<0oomd0?ooM03ooo]Zoomd
00Gooo]Z1Ooo9`02oookJP05oom30?oonf[ooo]ZoookJ_ooAP00:?oonfX00ooo4@3ooo]ZoookJP04
oookJP03ool40?oo603ooaP000Cooo]Z0ooo6@0NoookJP03o`000?oonf[ooo]Z00Cooo]Z00Goo`00
oookJ_oonf[ooo]Zool20003oookJP03ool00?oo2@3ooo]Z00Kooo]Z0_oo2P0WoookJP;oo`001_oo
nfX00ooo0@3ooo]ZoookJP05oookJP;oo`D07ooonfX01?l0003oo`00o`000?l00007oookJP03ool0
0?oonf[ooo]Z00Wooo]Z00?oo`40oookJ_oonfX08_oonfX00ooo003ooo]ZoookJP0<oookJP03ool0
0?oonf[ooo]Z00gooo]Z00?oo`40oookJ_oonfX07OoonfX00ooo003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX0:ooonfX00ooo003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z00_ooo]Z000_oookJP03o`000?oonf[ooo]Z033ooo]Z00?o00[ooookJ_oonfX05_oo
nfX3oonX00?ooo]Z00GoojP0oookJ_ooZ03oojP0oomd0002oookJP?oog@00ooonfX00ooo9`3ooo]Z
oookJP04oookJP03oom30?oonf[ooo]Z00;ooo]Z00?oodH0oookJ_oonfX01ooonfX2oolV00;ooo]Z
0ooo<P0NoookJP;oo`@000SooaP0oookJ_oonf[ooo]Zool00?oonf[oo`T0oolI023ooo]Z00?o0000
oookJ_oonfX03_oonfX00ooo003oo`@0ool40004oookJP03ool:0?oonf[ooo]Z02kooo]Z00?oo`00
oookJ_oonfX01_oonfX00ooo0P3ooo]ZoookJP0IoookJP?o00002_oonfX2ool000[ooo]Z00?oo`00
oookJ_oonfX02_oonfX00ooo0P3ooo]ZoookJP0RoookJP03ool00?oonf[ooo]Z00cooo]Z0_oo000/
oookJP04o`000?oonf[ooo]Zool001?ooo]Z00?oo`00oookJ_oonfX0;ooonfX00ol0003ooo]Zoook
JP0;oookJP00<?oonfX00ol0003ooo]ZoookJP0_oookJP03o`0:oooonf[ooo]Z01Cooo]Z0_ooZ007
oookJP;oojP00_oonfX01?ooM03ooo]Zoomd0?oonfX2oomd00Sooo]Z00?ood<0oookJ_oonfX00ooo
nfX00oooAP3ooo]ZoookJP02oolC00Cooo]Z0ooo9P02oookJP04oolb0?oonf[ooc80oolb02?ooo]Z
00Coo`00ool90?oo2@3ooaT00ooonfX01?oo0@3ooo]Zool?0?oo3`0JoookJP03o`000?oonf[ooo]Z
01;ooo]Z00Goo`00oookJ_oonf[oo`00oookJP02ool600Sooo]Z00?oo`L0oookJ_oonfX08_oonfX0
0ooo003ooo]Zool00006oookJP03ool10?oonf[ooo]Z00Kooo]Z00?oo`<0oookJ_oonfX03?oonfX3
o`0001Sooo]Z00?oo`00oookJ_oonfX02_oonfX00ooo0@3ooo]ZoookJP0PoookJP03ool00?oonf[o
oo]Z00cooo]Z00?oo`00oookJ_oonfX03_oonfX00ooo003ooo]ZoookJP0KoookJP04ool00?oonf[o
oo]Zo`0000oooo]Z00?oo`00oookJ_oonfX0:ooonfX00ooo003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z00[ooo]Z000aoookJP03o`000?oonf[ooo]Z02kooo]Z00?o00[ooookJ_oonfX04OoonfX3
oonX00kooo]Z0oooM00@oookJP05oom60?oo4`3ooa<0oookJ_oo4`000ooonfX01?oo9P3ooo]Zoook
J_oo9P03oookJP03oolb0?oonf[ooo]Z02[ooo]Z00?oo`40oookJ_oo3`000_oonfX01?oo003ooo]Z
oookJ_oonfX2oolB01Cooo]Z00?o0000oookJ_oonfX05ooonfX00ooo003ooo]Zool20005oookJP;o
o`L0;_oonfX2ool000Oooo]Z00?oo`40oookJ_oonfX02?oonfX3o`0001[ooo]Z00?oo`00oookJ_oo
nfX02OoonfX00ooo003ooo]ZoookJP0;oookJP03ool10?oonf[ooo]Z023ooo]Z00?oo`00oookJ_oo
nfX03OoonfX01Ooo003ooo]ZoookJ_oonf[oo`0000gooo]Z00?oo`40oookJ_oonfX04?oonfX00ol0
003ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z01;ooo]Z00?oo`00oookJ_oonfX09ooonfX00ol0
003ooo]ZoookJP0:oookJP00<_oonfX00ol0003ooo]ZoookJP0/oookJP03o`0:oooonf[ooo]Z013o
oo]Z0_ooZ00@oookJP04oom?0?ooM03oog@0oom?01Oooo]Z00?oobH0oookJ_oonfX01OoonfX00ooo
<P3oo`T0oookJP0aoookJP04ool40?oonf[ooo]ZoolB00Cooo]Z00?oo`P0oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP0KoookJP04ool00?oonf[ooo]Zool000;ooo]Z00?oo`<0oookJ_oonfX0=?oo
nfX00ooo003ooo]ZoookJP03oookJP?o00000_oo0P0VoookJP;oo`003?oonfX00ooo003ooo]Zool1
000;oookJP03ool10?oonf[ooo]Z023ooo]Z00?oo`00oookJ_oonfX03_oonfX00ooo003ooo]Zoook
JP02oookJP03ool10?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX05?oonfX00ooo003ooo]Zoook
JP04oookJP03ool00?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX02_oonfX003?ooo]Z0_l0000l
oookJP?oojP03OoonfX3oonY00;ooo]Z00?oog@0oookJ_ooC`000_ooC`0MoookJP03oolb0?oo2@3o
o`T000Gooo]Z0_oo5005oookJP;oob001?oonfX00ooo903ooo]ZoookJP0RoookJP05ool00?oonf[o
o`P0ool80?oo00001_oonfX00ooo3@3ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o
o`40oookJ_oonfX00ooonfX2ool502cooo]Z0_oo00001?oonf[o0000o`000?l00003oookJP03ool2
0?oo0@3ooo]Z00Wooo]Z00?oo`<0oookJ_oonfX09OoonfX00ooo003ooo]ZoookJP0;oookJP03ool1
0?oonf[oo`4001oooo]Z00?oo`00oookJ_oonfX03OoonfX01Ooo003ooo]ZoookJ_oonf[oo`0001Wo
oo]Z00?o0000oookJ_oonfX03OoonfX00ooo003ooo]ZoookJP0BoookJP03ool00?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX02_oonfX003Gooo]Z00?o0000oookJ_oonfX0>?oonfX00oooZ03ooo]Z
oookJP0=oookJP04oonY0?oonf[oojT0oookJP;oojT000Coog@0oom?0?ooC`3oodl03OoonfX2oom5
01Kooo]Z00?ooa@0oookJ_oo50001OoonfX2oolP00?ooo]Z0ooo900ZoookJP;oo`800_oonfX00ooo
3@3oo`00oookJP05oookJP04ool>0?oonf[ooo]Zo`0002Kooo]Z00Goo`00oookJ_oonf[oo`00ool5
0002oookJP03ool20?oonf[ooo]Z00Cooo]Z00?oo`H0oookJ_oonfX08OoonfX3o`0000Oooo]Z00?o
o`00oookJ_oonfX01ooonfX00ooo0@3oo`<0oookJP0ToookJP03ool00?oonf[ooo]Z00_ooo]Z00?o
o`00oookJ_oo0@00;OoonfX00ooo003ooo]ZoookJP0>oookJP03ool00?oonf[ooo]Z00;ooo]Z0_oo
000;oookJP03o`000?oonf[ooo]Z01_ooo]Z00?oo`00oookJ_oonfX00ooonfX00ooo003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z00[ooo]Z000foookJP03o`000?oonf[ooo]Z04Kooo]Z2?ooZ@00
0oooC`3ooo]ZoookJP0<oookJPCoodD07?oonfX00ooo103oob00oookJP04oookJP03oolT0?oonf[o
oo]Z02cooo]Z00?oo`d0ool00?oonfX00_oonfX01Ooo1@3oo`00oookJ_oonf[oo`h000?ooo]Z00?o
0000oookJ_oonfX0;?oonfX00ooo003ooo]Zool00002oookJP03ool60?oonf[oo`<001gooo]Z1?l0
000:oookJP03ool00?oonf[ooo]Z00Oooo]Z00?oo`40oookJ_oonfX0<?oonfX00ooo003ooo]Zoook
JP0;oookJP04ool00?oonf[oo`40ool102gooo]Z00?oo`00oookJ_oonfX04ooonfX00ol0003ooo]Z
oookJP13oookJP03o`000?oonf[ooo]Z00[ooo]Z000goookJP03o`000?oonf[ooo]Z04Gooo]Z00Co
ojT0oom?0?ooC`3oodl00_ooZ@000oooM03oojT0oookJP09oookJP;oobX00ooonfX4oom501cooo]Z
00?oob00oookJ_oonfX00ooonfX00ooo2`3oob@0oookJP05oookJP;ooa<0;ooonfX01?oo3P3ooo]Z
oookJ_oonfX2ool8037ooo]Z00Koo`00oookJ_oonf[oo`<0oookJ_oo0@07oookJP03ool40?oonf[o
oo]Z00kooo]Z0ol0000HoookJP03ool00?oonf[ooo]Z00Sooo]Z00?oo`40ool20?oonfX08ooonfX0
0ooo003ooo]ZoookJP0:oookJP04ool00?oonf[ooo]Zool002_ooo]Z00?oo`00oookJ_oonfX03ooo
nfX00ooo003ooo]ZoookJP02oookJP;oo`000ooonfX00ol0003ooo]ZoookJP0QoookJP03ool00?oo
nf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0:oookJP00>?oonfX0
0ol0003ooo]ZoookJP14oookJP03oom?0?ooZ@3oojT000;oojT000?ooo]ZoonY0?oonfX02_oonfX3
oolZ00;ooo]Z0_ooA@0UoookJP03oolT0?oonf[ooo]Z00;ooo]Z0_oo0@02oolC00Cooo]Z0ooo6P0/
oookJP05ool80?oonf[o0000ool00?oo0P001?oonfX00ooo2P3ooo]ZoookJP0^oookJP;oo`001?oo
nfX00ooo103ooo]Zool2000;oookJP?o00009_oonfX00ooo0@3ooo]ZoookJP0^oookJP03ool00?oo
nf[ooo]Z00_ooo]Z00?oo`00oookJ_oonfX00_oo0@0[oookJP03ool00?oonf[ooo]Z00;ooo]Z00?o
o`00oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z03Sooo]Z00?o
0000oookJ_oonfX02_oonfX003Wooo]Z0_l00013oookJP?oojT00ooonfX2oonY00Wooo]Z1?oo:P02
oookJP03oom50?oonf[ooo]Z02_ooo]Z00?ooa<0oookJ_oonfX00ooonfX2ool50003oolJ0?oonf[o
oo]Z02kooo]Z00Co0000oookJ_oonf[ooo]Z0_oo00000ooo2P3ooo]Zool00002ool403Cooo]Z00?o
o`80ool00?oonfX01OoonfX4o`0002Oooo]Z0_oo000;oookJP;oo`40;ooonfX00ooo003ooo]Zoook
JP0AoookJP03ool10?oonf[ooo]Z02[ooo]Z00Koo`00oookJ_oonf[o0000oookJ_oo0005oookJP03
ool00?oonf[ooo]Z02Kooo]Z00?oo`00oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0:oookJP00
>ooonfX00ol0003ooo]ZoookJP0noookJP;oojT00_oonfX00oooZ@3ooo]ZoookJP02oonY00Sooo]Z
0_oo:P05oookJP03oom50?oonf[ooo]Z00Kooo]Z00?ooaH0oookJ_oonfX00ooonfX3oolX00?ooo]Z
00?ooc<0oookJ_oonfX07_oonfX01?oo6P3ooo]ZoookJ_oonfX2ool00003oookJ_oo2`3ooo]Z02[o
oo]Z00?o0000oookJ_oonfX01OoonfX01Ooo103ooo]ZoookJ_oonf[oo`4000;ooo]Z00?oo`00oook
J_oo1`00;_oonfX00ooo003ooo]Zool00003o`0000;ooo]Z00?oo`<0ool10?oonfX0<OoonfX2ool0
00cooo]Z0_oo0P0QoookJP03ool00?oonf[ooo]Z00cooo]Z00Coo`00oookJ_oonf[oo`000ooonfX0
0ooo0@3ooo]ZoookJP0UoookJP03ool00?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03OoonfX0
0ooo003ooo]ZoookJP0UoookJP03ool00?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX02OoonfX0
03cooo]Z00?o0000oookJ_oonfX0>_oonfX3oonY00Gooo]Z0_ooZ@0@oookJP03oom50?oonf[ooo]Z
00Oooo]Z0_oo5P04oookJP03oolX0?oonf[oobP000;ooo]Z0ooo<`0UoookJP03ool;0?oonf[ooo]Z
00;ooo]Z0_oo0P001Ooonf[ooa40oolA0?oonf[oo`0002;ooo]Z00?o0000oookJ_oonfX02ooonfX0
1Ooo003ooo]Zool70?oo003ooo]Z00;oo`80:_oonfX3o`0000Kooo]Z00?oo`40ool00?oo00001_oo
nfX2ool402Sooo]Z00?oo`00oookJ_oonfX02OoonfX00ooo003oo`40ool2000]oookJP04ool00?oo
nf[ooo]Zool0017ooo]Z00?oo`40oookJ_oonfX09?oonfX01Ol0003ooo]ZoookJ_oonf[oo`0000Go
oo]Z00?oo`00oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00Wo
oo]Z000moookJP03o`000?oonf[ooo]Z03Oooo]Z0_ooZ@08oookJP03oonY0?oonf[ooo]Z01Oooo]Z
0_oo5P05oookJP03oolX0?oonf[oobP000?ooo]Z0_oo<`0]oookJP04oolA0?oonf[ooo]Zool000;o
oo]Z00Coo`D0oookJ_oo503ooa@07_oonfX00ol0003ooo]ZoookJP0?oookJP04ool20?oonf[ooo]Z
ool000;ooo]Z0_oo200QoookJP?o00003?oonfX00ooo003ooo]ZoookJP03oookJP03ool40?oo0P3o
o`00033ooo]Z0ooo000=oookJP03ool10?oonf[ooo]Z02gooo]Z00?oo`00oookJ_oonfX00_oo0002
oookJP;oo`409ooonfX00ol0003ooo]ZoookJP0EoookJP03ool00?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX02OoonfX003kooo]Z00?o0000oookJ_oonfX0=?oonfX2oonY00oooo]Z0oooD@0Hoook
JP03oolX0?oonf[ooo]Z00Cooo]Z00?ooc<0ool;0?oo2`001_oonfX00ooo5`3ooo]ZoookJP0Yoook
JP04ool50?oonf[ooa@0oolD00;oo`400_oonfX00ooo2P3oo`00oookJP0HoookJP03o`000?oonf[o
oo]Z01Cooo]Z00Coo`P0oookJ_oo003oo`@00_oonfX00ooo0@3ooo]ZoookJP0FoookJPCo00005_oo
nfX3ool000Sooo]Z00?oo`<0oookJ_oonfX0<?oonfX01Ooo003ooo]Zool00?oonf[oo`4002_ooo]Z
00?oo`00oookJ_oonfX00_oo000@oookJP03ool00?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0
1ooonfX00ooo003ooo]ZoookJP03oookJP03ool00?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX0
9ooonfX00ol0003ooo]ZoookJP09oookJP00?ooonfX00ol0003ooo]ZoookJP0`oookJP?oojT04Ooo
nfX4oomA01kooo]Z00?ooc<0oookJ_oonfX01OoonfX2oolG00Cooo]Z0ooo8P0VoookJP03oolD0?oo
nf[ooo]Z00;ooo]Z0_oo2P03oookJP05ool30?oonf[ooo]ZoookJ_oo3P004ooonfX00ol0003ooo]Z
oookJP0IoookJP06ool10?oonf[oo`00oookJ_oo003ooo]Z0_oo1P0>oookJP?o00009OoonfX00ooo
0`3ooo]ZoookJP0_oookJP;oo`003OoonfX00ooo0@3ooo]ZoookJP0/oookJP05ool00?oonf[ooo]Z
oookJ_oo00000ooonfX00ooo003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01_ooo]Z00?oo`00
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP09oookJP00@?oonfX2o`0002kooo]Z0_ooZ@0Coook
JPCooe403OoonfX2oom600oooo]Z00?ooc<0oookJ_oonfX01?oonfX2oolG00Gooo]Z0_oo1@02oolR
033ooo]Z00?oo`<0oookJ_oonfX00_oo3P03oookJP03ool00?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX07_oonfX02?oo1P3ooo]ZoookJ_oo0P3ooo]Zool00?oonf[oo`001OoonfX3o`0002Sooo]Z
00?oo`00oookJ_oonfX02?oonfX00ooo0P3ooo]ZoookJP0]oookJP07ool00?oonf[oo`00oookJ_oo
003ooo]Zool1000ooookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`40oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP0CoookJP03ool00?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX02OoonfX004;o
oo]Z00?o0000oookJ_oonfX0:_oonfX00oooZ@3ooo]ZoookJP0@oookJP?ooe400_oonfX00oooD@3o
oo]ZoookJP0;oookJPCoodH07OoonfX00ooo8P3ooo]ZoookJP04oookJP03ool=0?oonf[ooo]Z02co
oo]Z00?oo`h0oookJ_oonfX00_oonfX01Ooo1P3ooo]ZoookJ_oonf[oo`4000?ooo]Z00?oo`00oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP0VoookJP03ool00?l0003o000000;oo`@0=?oonfX00ooo
003oo`80oookJP0noookJP04ool00?oonf[ooo]Zool102Wooo]Z00Goo`00oookJ_oonf[ooo]Zool0
0004oookJP03ool00?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX08_oonfX00ooo003ooo]Zoook
JP0GoookJP03o`000?oonf[ooo]Z00Wooo]Z0013oookJP03o`000?oonf[ooo]Z03Wooo]Z0oooD@0?
oookJP?oobd00_oonfX01?ooAP3ooo]Zoom60?ooAP0KoookJP03oolR0?oonf[ooo]Z00Cooo]Z0_oo
3@04oookJP03ool20?oonf[ooaD003?ooo]Z00Goo`00ool90?oonf[ooo]Zool00007oookJP03o`00
0?oonf[ooo]Z02;ooo]Z0ol00003oookJP04ool40?oonf[oo`40oookJP;oo`0000?ooo]Zool00?oo
nfX00_oonfX00ooo1@3ooo]ZoookJP0coookJP03ool10?oo0P3ooo]Z02kooo]Z00Koo`00oookJ_oo
003oo`00oookJ_oo000ioookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX00_oonfX0
0ooo003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01[ooo]Z00?oo`00oookJ_oonfX01?oonfX0
0ooo003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00Wooo]Z0014oookJP03o`000?oonf[ooo]Z
03Oooo]Z00?ooe40oookJ_oonfX03_oonfX4ool]00;ooo]Z00?oodH0oookJ_ooAP00;?oonfX00ooo
5@3ooo]ZoookJP02oookJP03ool60?oo6`3ooa/002gooo]Z00Goo`T0oookJ_oonf[ooo]Zool30002
oookJP08ool00?oo303oo``0oookJ_oo003o0000oookJ_oo000NoookJP?o00004?oonfX01?oo1@3o
oo]Zool20?oo0@0boookJP03ool00?oo0@3ooo]Z03_ooo]Z00Coo`00oookJ_oonf[oo`000_oonfX0
0ooo0@3ooo]ZoookJP0ZoookJP03ool00?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ooo003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Wooo]Z0015oookJP03o`000?oonf[ooo]Z
04Gooo]Z0_oo;@02oookJP04ool]0?oonf[ooo]Zoom602kooo]Z00?ooaD0oookJ_oonfX00_oonfX2
ool60005oookJ_oo6`3ooo]ZoookJ_oo0@000_oonfX00ooo3@3ooo]ZoookJP0]oookJP;oo``00_oo
nfX2ool500;ooo]Z00?oo`40oookJ_oonfX05_oonfX4o`0001Gooo]Z00?oo`80ool10?oo00000_oo
000joookJP03ool00?oo0@3oo`8002gooo]Z00?oo`00oookJ_oonfX0>ooonfX00ooo003ooo]Zoook
JP02oookJP;oo`001?oonfX00ooo003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o
0000oookJ_oonfX02?oonfX004Kooo]Z0_l00014oookJP03ool]0?oonf[ooo]Z00Cooo]Z00?oodH0
oookJ_oonfX01_oonfX3oolI00Cooo]Z0ooo:`0ToookJP03oolK0?oonf[ooo]Z00?ooo]Z0_oo3@03
oookJP03ool30?oonf[ooo]Z02gooo]Z00?oo`D0oookJ_l000000_oo0@02oookJP04ool00?oonf[o
o`P0ool000oooo]Z0ol0000SoookJP04ool40?oo0@3oo`00ool0033ooo]Z00?oo`00oookJ_oonfX0
>_oonfX01?oo003ooo]ZoookJ_oo0003oookJP03ool00?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ooo003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00Sooo]Z0018oookJP03o`00
0?oonf[ooo]Z04Oooo]Z00?oodH0oookJ_oonfX01OoonfX2oolI0003oookJ_oo6@3ooo]Z00?ooo]Z
0_oo:`000ooonf[oob/0oookJP0^oookJP06ool30?oonf[ooo]ZoolB0?oonf[oo`00;OoonfX00ol0
003ooo]ZoookJP03oookJP04ool80?oonf[ooo]Zool300;ooo]Z00Koo`40oookJ_oonf[oo`00oook
J_oo0002oookJP?o0000:?oonfX00ooo003ooo]Zool0000hoookJP04ool00?oonf[oo`00ool000;o
o`40@_oonfX00ooo0@3ooo]ZoookJP0YoookJP04ool00?oonf[ooo]Zo`0000;ooo]Z00?oo`00oook
J_oonfX00ooonfX00ooo003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00Sooo]Z0019oookJP03
o`000?oonf[ooo]Z05Gooo]Z00Coob/0oookJ_oonf[oob/01?oonfX00ooo3@3ooo]ZoookJP0[oook
JP03oolB0?oonf[ooo]Z00;ooo]Z0_oo1`03oookJP03ool10?oonf[ooo]Z00;ooo]Z00?oo`00oook
J_oonfX08?oonfX00ol0003ooo]ZoookJP0=oookJP?o0000=?oonfX00ooo0P3oo`40ool00010oook
JP03ool20?oonf[ooo]Z02Sooo]Z0_oo0002oookJP05ool00?oonf[ooo]ZoookJ_oo00000ooonfX0
0ooo0@3ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00kooo]Z00?oo`00oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP08oookJP00B_oonfX00ol0003ooo]ZoookJP0ioookJP?ooe805ooonfX00ooo
:`3ooo]ZoookJP05oookJP;oo`d01_oonfX2oolI03;ooo]Z0_oo300ToookJP03o`000?oonf[ooo]Z
00Sooo]Z1?l000000ooonf[oo`D0oookJP02ool20004oookJ_oo003ooo]Zool000;ooo]Z00?oo`00
oookJ_oonfX0=?oonfX00ooo0`3ooo]ZoookJP0_oookJP03ool00?oonf[oo`0000;oo`400_oo0P0k
oookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX09?oonfX01?l0003ooo]ZoookJ_oo
0005oookJP03ool00?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX09ooonfX00ol0003ooo]Zoook
JP08oookJP00BooonfX00ol0003ooo]ZoookJP0goookJPGooe809OoonfX3oolI00Cooo]Z0_oo900/
oookJP;oo``00_oonfX2ool300;ooo]Z0_oo3`03oookJP03ool00?oonf[ooo]Z01Oooo]Z00?o0000
oookJ_oonfX01?oonfX3o`0000kooo]Z0_oo1`0foookJP03ool30?oo003ooo]Z03Sooo]Z00?oo`00
oookJ_oo00000_oonfX00ooo003ooo]Zool1000]oookJP05ool00?oonf[ooo]ZoookJ_oo00001?oo
nfX00ooo003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z00gooo]Z00?oo`00oookJ_oonfX01?oo
nfX00ooo003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Sooo]Z001<oookJP;o0000=ooonfX4
oomB02Gooo]Z00?ooaT0oookJ_oonfX01?oonfX2ool70003oolT0?oonf[ooo]Z03;ooo]Z0_oo3`03
oookJP05ool70?oonf[ooo]ZoookJ_oo0P000ooonfX01?oo003ooo]ZoookJ_oo000?oookJP03o`00
0?oonf[ooo]Z00?o00004OoonfX02_oo1`3ooo]ZoookJ_oo0`3ooo]Zool10?oonf[oo`00oookJ_oo
000hoookJP03ool00?oo0P3ooo]Z033ooo]Z00?oo`00oookJ_oo00000_oonfX00ooo0@3ooo]Zoook
JP0doookJP05ool00?oonf[ooo]ZoookJ_oo00001?oonfX00ooo003ooo]ZoookJP0MoookJP03o`00
0?oonf[ooo]Z01?ooo]Z00?oo`00oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP08oookJP00C_oo
nfX00ol0003ooo]ZoookJP0aoookJP?ooe8000?ooo]ZoomB0?oonfX0;_oonfX00ooo903ooo]Zoook
JP03oookJP;oo`h01?oonfX00ooo0`3ooo]ZoookJP0WoookJP04ool?0?oonf[ooo]ZoookJP;oo`L0
0_oonfX2ool201Oooo]Z0_l0000PoookJP04ool50?oonf[oo`80oookJP;oo`0000?ooo]Zool00?oo
nfX0;_oonfX00ooo0P3ooo]ZoookJP0ioookJP03ool00?oonf[oo`0000;ooo]Z00?oo`40oookJ_oo
nfX0<ooonfX00ooo003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01Cooo]Z00?oo`00oookJ_oo
nfX01?oonfX00ooo003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00Sooo]Z001?oookJP03o`00
0?oonf[ooo]Z02gooo]Z0oooDP0>oookJP?oobl08_oonfX00ooo903ooo]ZoookJP03oookJP03ool>
0?oonf[ooo]Z00?ooo]Z0_oo0`02oolG03Cooo]Z00Goo`X0oookJ_oonf[ooo]Zool40002oookJP03
ool10?oonf[ooo]Z00;oo`000_oonfX00ooo003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01oo
oo]Z00Goo`D0oookJ_oo0P3ooo]Zool0000koookJP;oo`0000?oo`40oookJ_oonfX0<ooonfX00ooo
0@3ooo]ZoookJP0goookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX00_oonfX00ooo
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX02?oonfX0053o
oo]Z00?o0000oookJ_oonfX0:_oonfX2oomB013ooo]Z0_oo;`000ooonf[oobl0oookJP0_oookJP;o
oaL01?oonfX00ooo203ooo]ZoookJP02oookJP03ool10?oonf[ooo]Z02Sooo]Z00Coo`X0oookJ_oo
nf[oo`@04?oonfX00ol0003ooo]ZoookJP0[oookJP03ool30?oo0@3ooo]Z00;oo`00JooonfX00ooo
003ooo]Zool00002oookJP03ool00?oonf[ooo]Z00;oo`40B_oonfX00ol0003ooo]ZoookJP0Qoook
JP03ool00?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX02?oonfX0057ooo]Z00?o0000oookJ_oo
nfX0>OoonfX2ool_00;ooo]Z00?oobl0oookJ_oonfX0;_oonfX00ooo5`3ooo]ZoookJP03oookJP03
ool80?oonf[ooo]Z00Gooo]Z0_oo3P0coookJP03ool60?oonf[ooo]Z00;oo`8000Sooo]Zool00?oo
003o0000oookJ_oo003ooo]Zool003Oooo]Z00?oo`00oookJ_oonfX0;OoonfX2ool00003ool10?oo
0P3ooo]Z03Sooo]Z00?oo`00oookJ_oonfX0<?oonfX00ooo003ooo]ZoookJP02oookJP03ool00?oo
nf[ooo]Z00?ooo]Z00?oo`00oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0XoookJP03ool00?oo
nf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01ooonfX005;ooo]Z00?o0000oookJ_oonfX0=ooonfX0
0ooo;`3ooo]ZoookJP0<oookJP?ooa/01?oonfX3ool/02[ooo]Z0ooo3P03oookJP03ool40?oonf[o
oo]Z00;ooo]Z00?oo`00oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP07oookJP03ool00?oonf[o
o`0002_ooo]Z00Coo`@0ool20?oo003oo`00>OoonfX3ool003Gooo]Z00Coo`00oookJ_oonf[oo`40
>OoonfX00ooo003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z02Kooo]Z00?oo`00oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP07oookJP00DooonfX2o`0004Cooo]Z0_oo6`02oookJP03oolK0?oo
nf[ooo]Z00;ooo]Z00?oob`0oookJ_oo;000<_oonfX2oolD00Cooo]Z00Goo`P0oookJ_oonf[ooo]Z
ool20003oookJP03ool00?oonf[ooo]Z02Gooo]Z00Go0000ool90?oonf[ooo]Zool40002oookJP03
ool10?oonf[ooo]Z03[ooo]Z00?oo`40ool00?oonfX0<?oonfX2ool00003oookJ_oo0@3ooo]Z03Ko
oo]Z00Goo`00oookJ_oonf[ooo]Zool0000hoookJP;oo`000ooonfX00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z00Oooo]Z001EoookJP03o`000?oonf[ooo]Z04Wooo]Z00?oob`0oookJ_oo
;0001?oonfX2ool?02gooo]Z00?ooa@0oookJ_oonfX00_oonfX2ool800?ooo]Z00?oo`80oookJ_oo
nfX0:OoonfX00ol0003ooo]ZoookJP0?oookJP05ool00?oonf[oo`00oookJ_oo0000;?oonfX00ooo
0`3oo`40oookJP0joookJP05ool00?oonf[oo`00oookJ_oo0@00<OoonfX01Ooo003ooo]ZoookJ_oo
nf[oo`0003Oooo]Z00Coo`00oookJ_oonf[o00000_oonfX00ooo003ooo]ZoookJP0^oookJP03o`00
0?oonf[ooo]Z00Oooo]Z001FoookJP03o`000?oonf[ooo]Z04Oooo]Z00?oob`0oookJ_oonfX01?oo
nfX00ooo3`3ooo]Zool?0005oookJP;ooa/0<ooonfX2ool=00?ooo]Z00Goo`@0oookJ_oonf[ooo]Z
ool10003oookJP03ool00?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX02_oonfX01?oo1P3ooo]Z
ool20?oo0P0>oookJP03ool00?oonf[ooo]Z02cooo]Z0_oo000boookJP03ool00?oonf[oo`4003[o
oo]Z00Goo`00oookJ_oonf[ooo]Zool0000boookJP03o`000?oonf[ooo]Z00Gooo]Z0_oo000Yoook
JP03o`000?oonf[ooo]Z00Oooo]Z001GoookJP03o`000?oonf[ooo]Z05Cooo]Z00?ooa/0oookJ_oo
6`001?oonfX00ooo203ooo]ZoookJP0[oookJP03ool=0?oonf[ooo]Z00;ooo]Z0_oo100BoookJP03
ool00?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX05_oonfX01Ooo103ooo]Zool10?oonf[oo`00
033ooo]Z00?oo`80oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP0^oookJP?oo`0000Cooo]Zool0
0?oonf[oo`40<_oonfX01?oo003ooo]ZoookJ_oonfX2ool102kooo]Z00?o0000oookJ_oonfX01_oo
nfX00ooo003ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX01ooo
nfX005Sooo]Z00?o0000oookJ_oonfX0D_oonfX00ooo6`3ooo]ZoookJP04oookJP;oo`P0>_oonfX2
ool800;ooo]Z00Goo`80oookJ_oonf[ooo]Zool0000DoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o
o`@0oookJ_oonfX02ooonfX00ooo003ooo]Zool0000_oookJP03ool10?oonf[ooo]Z03Cooo]Z00?o
o`40oookJ_oonfX00_oonfX00ooo003ooo]ZoookJP0doookJP04ool00?oonf[ooo]ZoookJP;oo`00
9OoonfX00ol0003ooo]ZoookJP0=oookJP03ool00?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
1ooonfX005Wooo]Z0_l0001QoookJP;ooa000ooonfX00ooo103ooo]ZoookJP0/oookJP03ool80?oo
nf[ooo]Z013ooo]Z0_oo0002oookJP03ool00?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX07ooo
nfX2ool50003ool20?oonf[oo`0003;ooo]Z00?oo`<0oookJ_oonfX01_oonfX2ool003Cooo]Z00?o
o`00oookJ_oo0@00=OoonfX01Ooo003ooo]ZoookJ_oonf[oo`0002?ooo]Z00?o0000oookJ_oonfX0
3OoonfX00ooo003ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
1ooonfX005_ooo]Z00?o0000oookJ_oonfX0<_oonfX3oola02Sooo]Z00?ooa00oookJ_oonfX01Ooo
nfX2oolI00Wooo]Z00?oo`80oookJ_oonfX0:?oonfX00ooo303ooo]ZoookJP02ool500;ooo]Z00?o
o`40oookJ_oonfX02_oonfX01Ol0003ooo]ZoookJ_oonf[oo`0001gooo]Z00?oo`D0oookJ_oonfX0
2ooonfX3ool0033ooo]Z00?oo`00ool20?oonfX0=?oonfX01Ooo0@3ooo]ZoookJ_oonf[oo`0000;o
oo]Z00?oo`00oookJ_oonfX0=OoonfX2ool001kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP07oookJP00G?oonfX00ol0003ooo]ZoookJP0_oookJPCooc40<OoonfX00ooo6@3ooo]Z
oookJP02oookJP;oo`T00ooonfX00ooo0P3ooo]ZoookJP0XoookJP03ool<0?oonf[ooo]Z013ooo]Z
0_oo00000ol0003oo`00oookJP0[oookJP03ool40?oo0@3ooo]Z00_ooo]Z00?oo`00oookJ_oonfX0
;OoonfX3ool003;ooo]Z00Coo`00oookJ_oonf[oo`00>?oonfX00ooo003ooo]ZoookJP02oookJP03
ool00?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX06_oonfX00ooo003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z00Kooo]Z001MoookJP03o`000?oonf[ooo]Z02cooo]Z0_oo<@02oookJP03oola
0?oonf[ooo]Z02oooo]Z00?ooaT0oookJ_oonfX02ooonfX00ooo403ooo]ZoookJP02oookJP04ool5
0?oonf[ooo]ZoookJP;oo`40:_oonfX01?oo1`3ooo]ZoookJ_oo0`04oookJP03o`000?oonf[ooo]Z
00Wooo]Z00?oo`00oookJ_oonfX0:ooonfX00ooo0@3oo`00oookJP0`oookJP03ool00?oo0@3oo`40
00Kooo]Z00?oo`00oookJ_oonfX0<OoonfX01?oo003ooo]ZoookJ_oo000doookJP03ool00?oonf[o
oo]Z00?ooo]Z00?oo`00oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0QoookJP03ool00?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX01_oonfX005kooo]Z00?o0000oookJ_oonfX0:_oonfX00ooo
<@3ooo]ZoookJP0=oookJP?ooad0<OoonfX2ool@00?ooo]Z0_oo1@0?oookJP03ool00?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX01?oonfX01?oo0@3ooo]ZoookJ_oo000;oookJP03ool00?oonf[o
oo]Z023ooo]Z00?oo`80oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP0_oookJP03ool00?oonf[o
o`4003Oooo]Z00?oo`40oookJ_oo0000=_oonfX2ool000oooo]Z00?o0000oookJ_oonfX0;?oonfX0
0ol0003ooo]ZoookJP06oookJP00GooonfX2o`0003Sooo]Z0_oo7@000ooonf[ooad0oolM000noook
JP;oo`T00_oonfX2ool200?ooo]Z00?oo`00oookJ_oonfX09OoonfX01Ol0003ooo]ZoookJ_oonf[o
o`D000oooo]Z00?oo`00oookJ_oonfX0;OoonfX00ooo0@3oo`00oookJP08oookJP03ool00?oonf[o
oo]Z02Kooo]Z0_oo0@000ooo0P3ooo]ZoookJP04oookJP03ool00?oonf[ooo]Z02oooo]Z00?oo`00
oookJ_oonfX00_oo000hoookJP;oo`0000?ooo]Zool00?oonfX01ooonfX00ol0003ooo]ZoookJP0[
oookJP03o`000?oonf[ooo]Z00Kooo]Z001QoookJP03o`000?oonf[ooo]Z04Cooo]Z0_oo4@0aoook
JP;oo`T04?oonfX00ooo0@3ooo]ZoookJP02ool001_ooo]Z00?o0000oookJ_oonfX03?oonfX2ool3
0003oookJ_oo003ooo]Z00_ooo]Z00?oo`00oookJ_oonfX08OoonfX2ool300[ooo]Z00?oo`00oook
J_oonfX0<?oonfX2ool00003oookJ_oo0@3ooo]Z03?ooo]Z0_oo0003oookJP03ool00?oonf[ooo]Z
033ooo]Z00?oo`00oookJ_oonfX01?oonfX01Ooo003ooo]ZoookJ_oonf[o000002cooo]Z00?o0000
oookJ_oonfX01_oonfX006;ooo]Z00?o0000oookJ_oonfX0@OoonfX3oolA00Kooo]Z0_oo7@0coook
JP04ool>0?oonf[ooo]ZoookJP;oo`D00_oonfX00ooo0@3ooo]ZoookJP0=oookJP03ool00?oonf[o
oo]Z00kooo]Z00?o0000oookJ_oonfX02_oonfX00ooo1`3ooo]ZoookJP0=oookJP?oo`00;_oonfX2
ool103Cooo]Z00?oo`40oookJ_oonfX00ooonfX00ooo003ooo]Zool0000goookJP03ool00?oonf[o
oo]Z03Oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP06oookJP00HooonfX00ol0
003ooo]ZoookJP18oookJP?ooad00ooonfX2ool902gooo]Z0_oo3P0CoookJP03ool00?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX05_oonfX00ooo103ooo]Zool1000<oookJP;oo`009?oonfX00ooo
0P3ooo]ZoookJP07oookJP;oo`00<_oonfX00ooo003ooo]Zool1000ioookJP03ool00?oonf[ooo]Z
03Cooo]Z00?o0000oookJ_oo00001_oonfX00ooo003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
00Kooo]Z001ToookJP03o`000?oonf[ooo]Z04Kooo]Z00?ooad0oookJ_oonfX03?oonfX00ooo4P3o
oo]ZoookJP0aoookJP;oo`T00_oonfX00ooo0`3ooo]ZoookJP0<oookJP04ool00?oonf[ooo]Zool0
00Kooo]Z00?o0000oookJ_oonfX05OoonfX2ool400cooo]Z00?oo`40ool00?oonfX0<?oonfX00ooo
0@3ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z033ooo]Z0_oo00000ooonf[oo`00oookJP0boook
JP;oo`000ooonfX00ooo003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Kooo]Z0_oo000Poook
JP03o`000?oonf[ooo]Z00Kooo]Z001UoookJP03o`000?oonf[ooo]Z05?ooo]Z0_oo4P03oookJP;o
o`D0;_oonfX00ooo2@3ooo]ZoookJP0=oookJP03ool10?oonf[ooo]Z00[ooo]Z00Go0000oookJ_oo
nf[ooo]Zool0000OoookJP03ool30?oonf[ooo]Z00_ooo]Z00?oo`00oookJ_oonfX0;_oonfX00ooo
003oo`40oookJP0boookJP04ool00?oonf[ooo]Zool100;ooo]Z0_oo000aoookJP05ool00?oonf[o
oo]ZoookJ_oo0000:_oonfX00ol0003ooo]ZoookJP0=oookJP03ool00?oonf[ooo]Z01Oooo]Z00?o
0000oookJ_oonfX01_oonfX006Kooo]Z0_l0001BoookJP03oolB0?oonf[ooo]Z00_ooo]Z00?oo`/0
oookJ_oonfX00_oonfX00ooo0`3ooo]ZoookJP0/oookJP;oo`H03OoonfX01?oo0@3ooo]Zo`000?oo
000]oookJP03ool20?oo003oo`0000[ooo]Z00?oo`00oookJ_oonfX09?oonfX00ooo0@3oo`80oook
JP07oookJP03ool00?oonf[ooo]Z02_ooo]Z00?oo`40oookJ_oonfX00ooonfX00ooo003ooo]Zoook
JP0foookJP05ool00?oonf[ooo]ZoookJ_oo00008_oonfX00ol0003ooo]ZoookJP0DoookJP03ool0
0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX01OoonfX006Sooo]Z00?o0000oookJ_oonfX0G?oo
nfX2ool;013ooo]Z00?oo`40oookJ_oonfX0;?oonfX01_oo0`3ooo]ZoookJ_oo0@3ooo]Zo`0000_o
oo]Z00?oo`00oookJ_oonfX07ooonfX00ooo103oo`80oookJP0:oookJP03ool00?oonf[ooo]Z02Ko
oo]Z00?oo`80oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z02_o
oo]Z0_oo0@05oookJP03ool00?oonf[ooo]Z03Gooo]Z00?oo`00oookJ_oonfX07?oonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00Gooo]Z001YoookJP03o`000?oonf[ooo]Z06?ooo]Z
0_oo4@03oookJP;oo`H00ooonfX00ooo0@3ooo]ZoookJP0YoookJP04ool80?oonf[ooo]Zool300Co
oo]Z00?o0000oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP0:oookJP03ool00?oonf[ooo]Z01Go
oo]Z00?oo`@0oookJ_oonfX02?oonfX00ooo0`3oo`40oookJP09oookJP03ool00?oonf[ooo]Z02Oo
oo]Z00?oo`40oookJ_oonfX01OoonfX2ool0037ooo]Z00Goo`00oookJ_oonf[ooo]Zool0000doook
JP03ool00?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX06_oonfX00ooo003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z00Gooo]Z001ZoookJP03o`000?oonf[ooo]Z02kooo]Z0ooo7`0`oookJP03
oolA0?oonf[ooa4001Cooo]Z00?oo`00oookJ_oonfX07?oonfX00ooo203ooo]ZoookJP06oookJP06
o`000?oonf[ooo]ZoookJ_oo1@3ooo]Z0_oo0P0<oookJP03ool00?oonf[ooo]Z02;ooo]Z00?oo`<0
oookJ_oonfX02?oonfX2ool000Wooo]Z00?oo`00oookJ_oonfX09ooonfX00ooo0@3ooo]ZoookJP0b
oookJP03ool00?oonf[ooo]Z00;ooo]Z00?oo`00oookJ_oonfX0=OoonfX00ooo003ooo]ZoookJP0E
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX01OoonfX006_ooo]Z00?o0000oook
J_oonfX0:_oonfX3oolO0003oookJ_oo7`3ooo]Z03kooo]Z00Goo`/0oookJ_oonf[ooo]Zool3000?
oookJP03ool00?oonf[ooo]Z01[ooo]Z00Go0000oookJ_oonf[ooo]Zool5000=oookJP03ool10?oo
nf[ooo]Z00[ooo]Z00?oo`00oookJ_oonfX08_oonfX00ooo0P3ooo]ZoookJP08oookJP03ool00?oo
nf[ooo]Z02oooo]Z00?oo`00oookJ_oonfX0<ooonfX00ooo003ooo]ZoookJP0goookJP04ool00?oo
nf[oo`00ool000oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP05oookJP00K?oo
nfX2o`0003Wooo]Z0_oo4`0boookJP;oo`/03ooonfX00ooo0P3ooo]ZoookJP0<oookJP03ool00?oo
nf[ooo]Z00oooo]Z00?o0000oookJ_oonfX03?oonfX2ool300cooo]Z00?oo`00oookJ_oonfX0;ooo
nfX00ooo0@3ooo]ZoookJP0aoookJP03ool00?oonf[oo`4000Cooo]Z00?oo`00oookJ_oonfX0;_oo
nfX00ooo0@3ooo]ZoookJP02oookJP03ool00?oonf[ooo]Z03Oooo]Z00?oo`00oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00Gooo]Z001^oookJP03o`000?oonf[o
oo]Z03Gooo]Z00?ooa<0oookJ_oo4`00?ooonfX00ooo1P3ooo]ZoookJP0=oookJP03ool10?oonf[o
oo]Z00_ooo]Z00?oo`00oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0HoookJP03ool20?oonf[o
o`0000_ooo]Z00?oo`00oookJ_oonfX08ooonfX00ooo0`3ooo]ZoookJP07oookJP03ool00?oonf[o
oo]Z02Wooo]Z00?oo`40oookJ_oonfX01?oonfX2ool003Kooo]Z00?oo`00oookJ_oonfX00_oonfX0
0ooo003ooo]ZoookJP0foookJP05ool00?oonf[ooo]ZoookJ_l000009?oonfX00ol0003ooo]Zoook
JP05oookJP00KooonfX00ol0003ooo]ZoookJP11oookJP?oo`/0?_oonfX00ooo103ooo]ZoookJP0<
oookJP03ool00?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX05_oonfX00ooo1@3ooo]Zool2000;
oookJP;oo`009OoonfX2ool300Wooo]Z00?oo`00oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP0Y
oookJP03ool10?oonf[ooo]Z00Cooo]Z00?oo`00oookJ_oonfX0=?oonfX00ooo003ooo]ZoookJP0b
oookJP03ool00?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP05
oookJP00L?oonfX00ol0003ooo]ZoookJP19oookJP04oolC0?oonf[ooo]ZoookJP;oo`H0;_oonfX0
1Ooo2P3ooo]ZoookJ_oonf[oo`@000_ooo]Z00Coo`80oookJ_oonf[oo`002OoonfX01Ol0003ooo]Z
oookJ_oonf[oo`0001?ooo]Z0_oo1@0<oookJP03ool10?oonf[ooo]Z00Wooo]Z00?oo`00oookJ_oo
nfX09?oonfX2ool200Sooo]Z00?oo`00oookJ_oonfX0<ooonfX00ooo003ooo]ZoookJP03oookJP03
ool00?oonf[ooo]Z02_ooo]Z00?oo`00oookJ_oonfX0=ooonfX01?l0003ooo]ZoookJ_oo000Poook
JP03o`000?oonf[ooo]Z00Gooo]Z001aoookJP03o`000?oonf[ooo]Z04Oooo]Z0_oo4`0boookJP03
ool:0?oonf[ooo]Z00gooo]Z0_oo0P0<oookJP03o`000?oo003ooo]Z027ooo]Z00?oo`<0oookJ_oo
nfX02OoonfX2ool000[ooo]Z00?oo`00oookJ_oonfX09OoonfX00ooo0@3ooo]ZoookJP06oookJP03
ool00?oonf[ooo]Z02Sooo]Z00?oo`00oookJ_oonfX0>ooonfX00ooo003ooo]ZoookJP0_oookJP03
o`000?oonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP05oookJP00
L_oonfX2o`0004Kooo]Z00?ooa<0oookJ_oonfX02ooonfX01?oo303ooo]ZoookJ_oonfX2ool302ko
oo]Z00?oo`H0oookJ_oonfX03?oonfX00ooo0@3ooo]Zo`00000;oookJP03ool00?oonf[ooo]Z023o
oo]Z0_oo0P0:oookJP03ool00?oonf[ooo]Z02oooo]Z00?oo`00ool10?oonfX0<_oonfX00ooo003o
oo]ZoookJP0foookJP04ool00?oonf[ooo]Zool002[ooo]Z00?o0000oookJ_oonfX03OoonfX00ooo
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Cooo]Z001doookJP03o`000?oonf[ooo]Z053o
oo]Z0_oo300?oookJP;oo`80;_oonfX00ooo103ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?oo`00oookJ_oonfX02_oonfX00ooo003ooo]ZoookJP0QoookJP03ool10?oonf[ooo]Z00So
oo]Z00?oo`00oookJ_oonfX09_oonfX00ooo0@3ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z02_o
oo]Z00?oo`40oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP0foookJP03ool00?oonf[ooo]Z02?o
oo]Z00?o0000oookJ_oonfX03?oonfX00ooo003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00Co
oo]Z001eoookJP03o`000?oonf[ooo]Z05_ooo]Z0_oo1`0?oookJP;oo`409ooonfX00ol0003ooo]Z
oookJP03oookJP;oo`803?oonfX00ooo003ooo]ZoookJP0SoookJP03ool10?oonf[ooo]Z03;ooo]Z
00?oo`80oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP0coookJP;oo`001?oonfX00ooo003ooo]Z
oookJP0eoookJP03ool00?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX04ooonfX00ooo003ooo]Z
oookJP08oookJP03o`000?oonf[ooo]Z00Cooo]Z001foookJP03o`000?oonf[ooo]Z06Oooo]Z00?o
o`@0oookJ_oonfX03OoonfX00ooo003ooo]ZoookJP0JoookJP06o`000?oonf[ooo]ZoookJ_oo1P3o
oo]Z0_oo0P0:oookJP03ool10?oonf[oo`0000[ooo]Z00?oo`00oookJ_oonfX05ooonfX00ooo0`3o
oo]ZoookJP09oookJP03ool10?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX09ooonfX00ooo0@3o
oo]ZoookJP06oookJP03ool00?oonf[ooo]Z03?ooo]Z00?oo`00oookJ_oonfX0<OoonfX00ooo003o
oo]ZoookJP0LoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX01?oonfX007Oooo]Z
00?o0000oookJ_oonfX0H_oonfX01Ooo303ooo]ZoookJ_oonf[oo`@001[ooo]Z00?oo`00oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP02ool600gooo]Z00?oo`40oookJ_oonfX0;ooonfX2ool200Wo
oo]Z00?oo`00oookJ_oonfX0<OoonfX00ooo0@3ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z02Wo
oo]Z0_oo000koookJP03ool00?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP04oookJP00N?oonfX00ol0003ooo]ZoookJP0/oookJP;ooa@0<_oonfX00ooo303ooo]Z
oookJP0>oookJP03ool20?oonf[ooo]Z00cooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z00cooo]Z0_oo100<oookJP03ool00?oonf[ooo]Z00Wooo]Z
00?oo`00oookJ_oonfX08ooonfX00ooo0@3ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z02Oooo]Z
00?oo`40oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP0`oookJP;oo`00>OoonfX00ooo003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX01?oonfX007Wooo]Z0_l0
000ZoookJP?ooa@02ooonfX2ool<03;ooo]Z0_oo1`0>oookJP;oo`403OoonfX00ooo003ooo]Zoook
JP04oookJP05o`000?oonf[ooo]ZoookJ_oo00005_oonfX00ooo0P3ooo]ZoookJP09oookJP;oo`00
<?oonfX2ool100Sooo]Z00?oo`00oookJ_oonfX09ooonfX00ooo003ooo]ZoookJP0eoookJP05ool0
0?oonf[ooo]ZoookJ_oo0000>OoonfX00ooo003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01_o
oo]Z00?o0000oookJ_oonfX01?oonfX007_ooo]Z00?o0000oookJ_oonfX0=?oonfX00ooo303ooo]Z
ool<000noookJP;oo`@03_oonfX00ooo003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z02?ooo]Z
00?oo`40oookJ_oonfX02OoonfX00ooo003ooo]ZoookJP0ToookJP03ool10?oonf[ooo]Z03?ooo]Z
00?oo`40oookJ_oonfX01?oonfX00ooo003ooo]ZoookJP0eoookJP03ool00?oonf[ooo]Z03gooo]Z
00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP04oookJP00O?oonfX00ol0003ooo]Zoook
JP10oookJP;oo`L0?_oonfX2ool200cooo]Z00?o0000ool00?oonfX08ooonfX00ooo0@3ooo]Zoook
JP08oookJP03ool10?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX06_oonfX2ool200Sooo]Z0_oo
000doookJP03ool10?oonf[ooo]Z00?ooo]Z0_oo000]oookJP03ool00?oonf[ooo]Z00Kooo]Z00?o
o`00oookJ_oonfX0<OoonfX01Ooo003ooo]ZoookJ_oonf[o000001cooo]Z00?o0000oookJ_oonfX0
1?oonfX007gooo]Z00?o0000oookJ_oonfX0C?oonfX2ool402kooo]Z00?oo`L0oookJ_oonfX03?oo
nfX00ooo0@3ooo]Zo`00000;oookJP03ool00?oonf[ooo]Z01Gooo]Z00?oo`@0oookJ_oonfX02Ooo
nfX2ool103;ooo]Z00?oo`40oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP0coookJP03ool00?oo
nf[ooo]Z033ooo]Z00?oo`00oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oo
nf[ooo]Z00?ooo]Z001noookJP03o`000?oonf[ooo]Z04Kooo]Z0_oo3@0?oookJP03ool20?oonf[o
oo]Z027ooo]Z00?oo`L0oookJ_oonfX03?oonfX00ooo0@3o0000oookJP08oookJP03ool10?oonf[o
oo]Z00[ooo]Z00?oo`00oookJ_oonfX05_oonfX00ooo0P3ooo]ZoookJP09oookJP03ool00?oonf[o
oo]Z033ooo]Z00?oo`40oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP0XoookJP03ool00?oonf[o
oo]Z00Oooo]Z00?oo`00oookJ_oonfX0<?oonfX00ooo003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z00Kooo]Z00?oo`00oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP03oookJP00OooonfX2o`00
04Gooo]Z00?oo`d0oookJ_oo3@006ooonfX00ooo0@3ooo]ZoookJP0QoookJP05ool50?oonf[ooo]Z
oookJ_l000002OoonfX00ooo0@3ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z02?ooo]Z0_oo0@09
oookJP03ool00?oonf[ooo]Z02Kooo]Z00?oo`40oookJ_oonfX01ooonfX00ooo003ooo]ZoookJP0`
oookJP03ool00?oonf[ooo]Z03Kooo]Z0_oo000/oookJP03o`000?oonf[ooo]Z00Gooo]Z00?oo`00
oookJ_oonfX01OoonfX00ooo003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00?ooo]Z0021oook
JP03o`000?oonf[ooo]Z04oooo]Z0_oo200?oookJP03ool10?oonf[ooo]Z00Wooo]Z00?oo`00oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP04oookJP;oo`<03?oonfX00ooo003ooo]ZoookJP0^oook
JP03ool10?oonf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX09_oonfX00ooo003ooo]ZoookJP07oook
JP03ool00?oonf[ooo]Z02[ooo]Z00?oo`40oookJ_oonfX00ooonfX00ooo003ooo]ZoookJP0eoook
JP03ool00?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP03oook
JP00P_oonfX00ol0003ooo]ZoookJP1JoookJP;oo`D03ooonfX00ooo003ooo]ZoookJP08oookJP03
ool00?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX04?oonfX00ooo0P3ooo]ZoookJP09oookJP;o
o`009OoonfX00ooo0@3ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z02Sooo]Z00?oo`40oookJ_oo
nfX01OoonfX00ooo003ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z02[ooo]Z00?oo`00oookJ_oo
nfX0<_oonfX00ooo003ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP03oookJP00PooonfX00ol0003ooo]ZoookJP1UoookJP;oo`<0
3_oonfX00ooo003ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
6ooonfX00ooo0@3ooo]ZoookJP09oookJP03ool00?oonf[ooo]Z01Sooo]Z00?oo`80oookJ_oonfX0
2?oonfX00ooo003ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z02Oooo]Z0_oo0@0coookJP03ool0
0?oonf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z00?ooo]Z0024oookJP03o`000?oonf[ooo]Z067ooo]Z00?oo`P0oookJ_oonfX03?oo
nfX2ool100gooo]Z00?oo`00oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP02oookJP03ool00?oo
nf[ooo]Z00Sooo]Z0_oo1@0FoookJP;oo`009_oonfX00ooo0P3ooo]ZoookJP07oookJP03ool00?oo
nf[ooo]Z00Oooo]Z00?oo`00oookJ_oonfX09ooonfX00ooo003ooo]ZoookJP0aoookJP03ool00?oo
nf[ooo]Z00Kooo]Z00?oo`00oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oo
nf[ooo]Z00?ooo]Z0025oookJP;o0000;?oonfX2ool>03;ooo]Z0_oo200JoookJP03ool10?oonf[o
oo]Z00Kooo]Z00?o0000oookJ_oonfX06OoonfX00ooo0`3ooo]ZoookJP0DoookJP03ool00?oonf[o
oo]Z02Cooo]Z0_oo0@0loookJP03ool00?oonf[ooo]Z033ooo]Z00?oo`00oookJ_oonfX0=ooonfX0
0ooo003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX00ooonfX0
08Oooo]Z00?o0000oookJ_oonfX0:?oonfX3ool>03kooo]Z0_oo1@0GoookJP03o`000?oonf[oo`00
02Cooo]Z00?oo`80oookJ_oonfX04ooonfX00ooo003ooo]ZoookJP0UoookJP03ool00?oonf[ooo]Z
033ooo]Z00?oo`00oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP0[oookJP;oo`00=?oonfX00ooo
003ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP03oookJP00R?oonfX00ol0003ooo]ZoookJP0doookJP;oo`P0?_oonfX2ool300_o
oo]Z00?o0000oookJ_oonfX02_oonfX00ooo003ooo]ZoookJP0RoookJP03ool10?oonf[ooo]Z03Wo
oo]Z0_oo000ZoookJP;oo`401OoonfX00ooo003ooo]ZoookJP0doookJP03ool00?oonf[ooo]Z03go
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP02oookJP00ROoonfX00ol0003ooo]Z
oookJP10oookJP03ool50?oonf[ooo]Z03cooo]Z00?oo`80o`000?oonfX05OoonfX00ooo003ooo]Z
oookJP0RoookJP03ool00?oonf[ooo]Z02Kooo]Z0_oo0P0AoookJP03ool00?oonf[ooo]Z02Wooo]Z
00?oo`00oookJ_oonfX0<OoonfX00ooo003ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z03Gooo]Z
00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP02oookJP00R_oonfX00ol0003ooo]Zoook
JP1;oookJP03ool30?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX01ooonfX00ooo0@3ooo]Zoook
JP0SoookJP;oo`<05?oonfX2ool002Oooo]Z0_oo0@0loookJP03ool00?oonf[ooo]Z037ooo]Z00?o
o`00oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z00;ooo]Z002;
oookJP03o`000?oonf[ooo]Z04Kooo]Z00?oo`T0oookJ_oonfX03OoonfX00ooo0@3ooo]ZoookJP0P
oookJP;oo`D00ooonfX00ol0003ooo]ZoookJP0BoookJP03ool00?oonf[ooo]Z02?ooo]Z0_oo0P0D
oookJP03ool00?oonf[ooo]Z02Gooo]Z0_oo0@0koookJP03ool00?oonf[ooo]Z06;ooo]Z00?o0000
oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00;ooo]Z002<oook
JP;o0000AOoonfX2ool901[ooo]Z0_oo0@0KoookJP03o`000?oonf[ooo]Z00Cooo]Z00?oo`<0oook
J_oonfX05OoonfX2ool002Gooo]Z00?oo`40oookJ_oonfX0>_oonfX00ooo003ooo]ZoookJP1Yoook
JP03ool00?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z00;ooo]Z002>oookJP03o`000?oonf[ooo]Z04kooo]Z0_oo1P0JoookJP03
ool00?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0?oookJP;o
o`805_oonfX00ooo003ooo]ZoookJP0SoookJP;oo`40>_oonfX2ool002cooo]Z00?oo`00oookJ_oo
nfX0<_oonfX00ooo003ooo]ZoookJP05oookJP03ool00?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oo
nfX04?oonfX00ol0003ooo]ZoookJP02oookJP00SooonfX00ol0003ooo]ZoookJP1IoookJP;oo`<0
7ooonfX00ol0003ooo]ZoookJP02oookJP03ool00?oonf[ooo]Z01Kooo]Z00?oo`40oookJ_oonfX0
>OoonfX2ool002Wooo]Z00?oo`40oookJ_oonfX0>ooonfX00ooo003ooo]ZoookJP1GoookJP03o`00
0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX00_oonfX0093ooo]Z00?o0000oookJ_oonfX0I?oo
nfX00ooo0P3ooo]ZoookJP09oookJP03ool10?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX09Ooo
nfX2ool000Wooo]Z00?oo`00oookJ_oonfX06_oonfX00ooo0P3ooo]ZoookJP0AoookJP03ool00?oo
nf[ooo]Z02Sooo]Z00?oo`40oookJ_oonfX0>_oonfX00ooo003ooo]ZoookJP1?oookJP03o`000?oo
nf[ooo]Z00kooo]Z00?o0000oookJ_oonfX00_oonfX0097ooo]Z00?o0000oookJ_oonfX0K_oonfX0
0ooo0@3ooo]ZoookJP07oookJP03o`000?oonf[oo`0001Sooo]Z0_oo0`0FoookJP03ool00?oonf[o
oo]Z00Oooo]Z00?oo`00oookJ_oonfX06ooonfX00ooo0@3ooo]ZoookJP0joookJP03ool00?oonf[o
oo]Z08Cooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP02oookJP00T_oonfX2o`00
02cooo]Z00?oo`T0oookJ_oonfX0<?oonfX2ool601Oooo]Z00?o0000ool00?oo00002OoonfX2ool0
01Wooo]Z00?oo`80oookJ_oonfX0>ooonfX00ooo0@3ooo]ZoookJP0joookJP03ool00?oonf[ooo]Z
06Wooo]Z00?oo`00oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
00;ooo]Z002DoookJP03o`000?oonf[ooo]Z02Oooo]Z0ooo2@0noookJP03ool40?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX05?oonfX00ooo003ooo]ZoookJP0HoookJP03ool10?oonf[ooo]Z00Oo
oo]Z00?oo`40oookJ_oonfX0<?oonfX00ooo003ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z05go
oo]Z00?oo`00oookJ_oonfX0<_oonfX00ooo003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000oookJ_oonfX00OoonfX009Gooo]Z00?o0000oookJ_oonfX0<ooonfX2ool600_ooo]Z
00?oo`<0oookJ_oonfX0;ooonfX2ool20003o`000?oonf[ooo]Z00Oooo]Z00?oo`40oookJ_oonfX0
;ooonfX00ooo0@3ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z02kooo]Z00?oo`00oookJ_oonfX0
:OoonfX2ool103cooo]Z00?oo`00oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z007ooo]Z002FoookJP03o`000?oonf[ooo]Z03kooo]Z0_oo0`0;oookJP03ool20?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX01ooonfX00ooo0@3ooo]ZoookJP08oookJP03ool10?oo
nf[ooo]Z02kooo]Z0_oo0008oookJP;oo`007_oonfX00ooo0@3ooo]ZoookJP0koookJP03ool00?oo
nf[ooo]Z077ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP01oookJP00UooonfX0
0ol0003ooo]ZoookJP19oookJP03ool20?oonf[ooo]Z00Wooo]Z00?oo`40oookJ_oonfX06_oonfX0
0ol0003ooo]ZoookJP0LoookJP;oo`006_oonfX2ool203gooo]Z00?oo`40oookJ_oonfX0>OoonfX2
ool006_ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP01oookJP00V?oonfX00ol0
003ooo]ZoookJP1OoookJP;oo`004?oonfX00ol0003ooo]ZoookJP04oookJP03ool40?oonf[ooo]Z
00Wooo]Z00?oo`80oookJ_oonfX05?oonfX00ooo003ooo]ZoookJP0IoookJP03ool10?oonf[ooo]Z
00Sooo]Z00?oo`40oookJ_oonfX0;ooonfX2ool000Sooo]Z00?oo`00oookJ_oonfX0TooonfX00ol0
003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z007ooo]Z002IoookJP;o0000A?oonfX2ool600[o
oo]Z00?oo`@0oookJ_oonfX05ooonfX2ool000Gooo]Z00Go0000oookJ_oonf[ooo]Zool0000=oook
JP;oo`802_oonfX00ooo0@3ooo]ZoookJP0_oookJP;oo`402OoonfX00ooo003ooo]ZoookJP0_oook
JP03ool00?oonf[ooo]Z06Sooo]Z00?oo`00oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP09oook
JP03o`000?oonf[ooo]Z007ooo]Z002KoookJP03o`000?oonf[ooo]Z04gooo]Z00?oo`@0oookJ_oo
nfX02OoonfX00ooo0P3ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z01[ooo]Z0_oo0@09oookJP;o
o`40<OoonfX00ooo003ooo]ZoookJP06oookJP;oo`00GOoonfX2ool0063ooo]Z00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP01oookJP00W?oonfX00ol0003ooo]ZoookJP1SoookJP;oo`40
2?oonfX00ol0003ooo]ZoookJP0`oookJP03ool00?oonf[ooo]Z05Wooo]Z00?oo`40oookJ_oonfX0
>_oonfX00ooo003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0
0OoonfX009gooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003oo`40ool1000:oookJP03ool00?oo
nf[ooo]Z02gooo]Z00?oo`00oookJ_oonfX06ooonfX00ooo0@3ooo]ZoookJP07oookJP03ool10?oo
nf[ooo]Z037ooo]Z00?oo`00oookJ_oonfX01_oonfX00ooo003ooo]ZoookJP21oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX00OoonfX009kooo]Z00?o0000oookJ_oonfX0JooonfX0
0ol0003ooo]ZoookJP09oookJP03ool00?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX03OoonfX0
0ooo0`3ooo]ZoookJP08oookJP03ool20?oonf[ooo]Z033ooo]Z00?oo`40oookJ_oonfX01ooonfX0
0ooo003ooo]ZoookJP0`oookJP03ool00?oonf[ooo]Z08;ooo]Z00?o0000oookJ_oonfX01ooonfX1
o`00007ooo]Z0OoonfX009oooo]Z0_l0000ZoookJP;oo`H0<_oonfX00ooo103ooo]ZoookJP09oook
JP03ool30?l0003ooo]Z033ooo]Z00?oo`80oookJ_oonfX01ooonfX2ool1037ooo]Z00?oo`00oook
J_oonfX01ooonfX00ooo003ooo]ZoookJP2/oookJP03o`000?oonf[ooo]Z00Kooo]Z0Ol00001oook
JP7ooo]Z002QoookJP03o`000?oonf[ooo]Z02Oooo]Z0_oo1P0:oookJP;oo`@0<OoonfX00ooo0`3o
oo]Zo`000009oookJP03ool10?oonf[ooo]Z03[ooo]Z00?oo`00oookJ_oonfX0V?oonfX00ooo003o
oo]ZoookJP14oookJP03o`000?oonf[ooo]Z00Gooo]Z0Ol00001oookJP7ooo]Z002RoookJP03o`00
0?oonf[ooo]Z03kooo]Z0_oo0P0:oookJP03ool10?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0
4_oonfX00ooo0@3ooo]ZoookJP08oookJP03ool00?oonf[ooo]Z02kooo]Z00?oo`00oookJ_oonfX0
F_oonfX00ooo003ooo]ZoookJP06oookJP03ool00?oonf[ooo]Z073ooo]Z00?o0000oookJ_oonfX0
1?oonfX1o`00007ooo]Z0OoonfX00:?ooo]Z00?o0000oookJ_oonfX0BOoonfX00ooo0@3ooo]Zoook
JP08oookJP;oo`404?oonfX00ol0003ooo]ZoookJP0LoookJP03ool00?oonf[ooo]Z00Sooo]Z00?o
o`00oookJ_oonfX06_oonfX00ooo0P3ooo]ZoookJP0`oookJP03ool10?oonf[ooo]Z00Oooo]Z00?o
o`00oookJ_oonfX0<?oonfX00ooo003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z00Cooo]Z0Ol0
0001oookJP7ooo]Z002ToookJP03o`000?oonf[ooo]Z05kooo]Z0_oo0005oookJP05o`000?oonf[o
oo]ZoookJ_oo00003_oonfX00ooo0`3ooo]ZoookJP0`oookJP03ool20?oonf[ooo]Z00Sooo]Z00?o
o`40oookJ_oonfX0<?oonfX00ooo003ooo]ZoookJP06oookJP;oo`00W?oonfX00ol0003ooo]Zoook
JP03oookJP7o00000OoonfX1oookJP00YOoonfX2o`0004Cooo]Z00?oo`@0oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0?oookJP;oo`<02OoonfX2ool203cooo]Z00?oo`00oookJ_oonfX01ooonfX0
0ooo003ooo]ZoookJP34oookJP03o`000?oonf[ooo]Z00;ooo]Z0Ol00001oookJP7ooo]Z002Woook
JP03o`000?oonf[ooo]Z047ooo]Z00?oo`@0oookJ_oonfX02?oonfX2ool301Cooo]Z00?o0000oook
J_oonfX09OoonfX2ool100Wooo]Z00?oo`00oookJ_oonfX0;ooonfX00ooo003ooo]ZoookJP35oook
JP05o`000?oonf[ooo]ZoookJ_l000000_oonfX00:Sooo]Z00?o0000oookJ_oonfX0EooonfX00ooo
0P3ooo]ZoookJP07oookJP03o`000?oo0@3oo`40033ooo]Z00?oo`00oookJ_oonfX01ooonfX00ooo
003ooo]ZoookJP1IoookJP03ool10?oonf[ooo]Z037ooo]Z00?oo`00oookJ_oonfX0G_oonfX01?l0
003ooo]ZoookJ_l00002oookJP00ZOoonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z
00Wooo]Z00?oo`00oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP1<oookJP03ool10?oonf[ooo]Z
033ooo]Z00?oo`40oookJ_oonfX01_oonfX2ool008[ooo]Z00Go0000oookJ_oonf[ooo]Zo`000001
oookJP00Z_oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z02oooo]Z00?oo`80oook
J_oonfX0<?oonfX00ooo0@3ooo]ZoookJP07oookJP;oo`40__oonfX01?l0003ooo]ZoookJ_l00001
oookJP00ZooonfX00ol0003ooo]ZoookJP1LoookJP;oo`<000?o0000oookJ_oonfX0>OoonfX2ool1
00Wooo]Z00?oo`40oookJ_oonfX0;ooonfX00ooo003ooo]ZoookJP2doookJP03o`000?oonf[o0000
007ooo]Z002/oookJP;o0000:OoonfX00ooo1@3ooo]ZoookJP09oookJP03ool30?oonf[ooo]Z02Ko
oo]Z00?o0000oookJ_oonfX01_oonfX2ool200[ooo]Z00?oo`40oookJ_oonfX0;ooonfX00ooo0@3o
oo]ZoookJP07oookJP03ool00?oonf[ooo]Z0=gooo]Z0_l00001oookJP00[_oonfX00ol0003ooo]Z
oookJP0boookJP03ool30?oonf[ooo]Z00Sooo]Z0_oo0P0LoookJP03o`000?oonf[ooo]Z01cooo]Z
0_oo0009oookJP03ool00?oonf[ooo]Z08_ooo]Z00?oo`00oookJ_oonfX0MOoonfX3o`00007ooo]Z
002_oookJP03o`000?oonf[ooo]Z04Sooo]Z00?oo`40oookJ_oonfX02?oonfX00ooo003ooo]Zoook
JP04oookJP03o`000?oonf[ooo]Z02Oooo]Z00?oo`00oookJ_oonfX0EooonfX2ool103;ooo]Z00?o
o`00oookJ_oonfX0LOoonfX4o`0000Cooo]Z002`oookJP03o`000?oonf[ooo]Z05Wooo]Z00Go0000
oookJ_oonf[ooo]Zool0001<oookJP03ool10?oonf[ooo]Z00Oooo]Z00?oo`40oookJ_oonfX0<?oo
nfX00ooo003ooo]ZoookJP2GoookJPCo00002?oonfX00;7ooo]Z00?o0000oookJ_oonfX0F?oonfX0
0ol0003ooo]ZoookJP0JoookJP;oo`802_oonfX00ooo0@3ooo]ZoookJP0_oookJP03ool10?oonf[o
oo]Z00Oooo]Z00?oo`00oookJ_oonfX0_?oonfX4o`0000cooo]Z002boookJP;o0000@_oonfX2ool3
00[ooo]Z00?oo`80oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0UoookJP03ool10?oonf[ooo]Z
00Sooo]Z00?oo`40oookJ_oonfX02?oonfX00ooo003ooo]ZoookJP3PoookJP?o00004?oonfX00;Co
oo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003oo`40oookJP09oookJP03ool10?oonf[ooo]Z02ko
oo]Z00?oo`00oookJ_oonfX0gOoonfX4o`0001?ooo]Z002eoookJP03o`000?oonf[ooo]Z05Cooo]Z
00?o0000oookJ_oonfX05?oonfX00ooo003ooo]ZoookJP29oookJP03ool00?oonf[ooo]Z07?ooo]Z
1?l0000GoookJP00]_oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o
o`40oookJ_oonfX0<?oonfX00ooo0@3ooo]ZoookJP06oookJP;oo`00V_oonfX4o`0001_ooo]Z002g
oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX01ooonfX00ooo0P3ooo]ZoookJP0_
oookJP;oo`402OoonfX00ooo0@3ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z0;gooo]Z1?l0000O
oookJP00^?oonfX2o`0002Wooo]Z00?oo`<0oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP06oook
JP;oo`802OoonfX2ool100Wooo]Z0_oo0@0`oookJP03ool00?oonf[ooo]Z0;Wooo]Z1?l0000Soook
JP00^_oonfX00ol0003ooo]ZoookJP0UoookJP03ool30?oonf[ooo]Z00Wooo]Z0_oo0P0:oookJP03
ool10?oonf[ooo]Z00Sooo]Z00?oo`40oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0LoookJP03
ool10?oonf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX0g?oonfX4o`0002Oooo]Z002koookJP03o`00
0?oonf[ooo]Z04Oooo]Z00?oo`40oookJ_oonfX01?oonfX01Ol0003ooo]ZoookJ_oonf[oo`0008Wo
oo]Z00?oo`00oookJ_oonfX0M?oonfX4o`0002_ooo]Z002loookJP03o`000?oonf[ooo]Z04gooo]Z
00?o0000oookJ_oonfX0F?oonfX2ool1037ooo]Z00?oo`00oookJ_oonfX0L?oonfX4o`0002oooo]Z
002moookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX09OoonfX2ool100Wooo]Z00?o
o`40oookJ_oonfX09OoonfX00ooo0@3ooo]ZoookJP07oookJP03ool00?oonf[ooo]Z09Kooo]Z0ol0
000coookJP00__oonfX00ol0003ooo]ZoookJP11oookJP03ool20?oonf[ooo]Z00Oooo]Z00?o0000
ool10?oonfX0<?oonfX00ooo0@3ooo]ZoookJP07oookJP;oo`00^ooonfX4o`0003Kooo]Z002ooook
JP;o0000BooonfX00ol0003oo`40oookJP09oookJP03ool10?oonf[ooo]Z00Sooo]Z00?oo`00oook
J_oonfX0g?oonfX4o`0003[ooo]Z0031oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oo
nfX0kooonfX4o`0003kooo]Z0032oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
MooonfX00ooo0@3ooo]ZoookJP1aoookJPCo0000@_oonfX00<?ooo]Z00?o0000oookJ_oonfX0A_oo
nfX00ol0003ooo]ZoookJP0BoookJP03ool20?oonf[ooo]Z02oooo]Z00?oo`40oookJ_oonfX01ooo
nfX2ool109Oooo]Z1?l00016oookJP00a?oonfX00ol0003ooo]ZoookJP0XoookJP03ool20?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX04OoonfX2ool200Wooo]Z0_oo0@09oookJP03ool00?oonf[o
oo]Z0;Wooo]Z1?l0001:oookJP00aOoonfX2o`0002Oooo]Z00?oo`80oookJ_oonfX02?oonfX2ool1
00[ooo]Z00?oo`40oookJ_oonfX01?oonfX01Ol0003ooo]ZoookJ_oonf[oo`000=gooo]Z1?l0001>
oookJP00aooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z0=_ooo]Z1?l0001Boook
JP00b?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z06;ooo]Z0_oo0@1doookJP?o
0000E_oonfX00<Wooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP0`oookJP03ool1
0?oonf[ooo]Z00Sooo]Z00?oo`40oookJ_oonfX09?oonfX00ooo0@3ooo]ZoookJP1_oookJPCo0000
FOoonfX00<[ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003oo`80oookJP09oookJP03ool10?oo
nf[ooo]Z00Sooo]Z00?oo`00oookJ_oonfX08ooonfX2ool109Cooo]Z1?l0001MoookJP00booonfX2
o`0003oooo]Z00?o0000oookJ_oonfX05?oonfX00ooo003ooo]ZoookJP2eoookJPCo0000HOoonfX0
0<gooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP38oookJPCo0000IOoonfX00<ko
oo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP34oookJPCo0000JOoonfX00<oooo]Z
00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0MoookJP03ool10?oonf[ooo]Z02kooo]Z
0_oo0@1`oookJPCo0000KOoonfX00=3ooo]Z00?o0000oookJ_oonfX09_oonfX2ool200[ooo]Z00?o
o`40oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0LoookJP03ool10?oonf[ooo]Z00Sooo]Z00?o
o`40oookJ_oonfX0T_oonfX4o`00077ooo]Z003AoookJP03o`000?oonf[ooo]Z02Gooo]Z0_oo0P0:
oookJP03ool10?oonf[ooo]Z00Cooo]Z00Go0000oookJ_oonf[ooo]Zool0002foookJPCo0000MOoo
nfX00=;ooo]Z0_l0000hoookJP03o`000?oonf[ooo]Z0;Gooo]Z0ol0001ioookJP00e?oonfX00ol0
003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0001loookJP00eOoonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z03_ooo]Z00?oo`40oookJ_oonfX0KooonfX4o`00083o
oo]Z003FoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX02OoonfX00ooo0@3ooo]Z
oookJP08oookJP03ool10?oonf[ooo]Z09;ooo]Z1?l00024oookJP00eooonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z0:Gooo]Z1?l00028oookJP00f?oonfX2o`0003;ooo]Z00?o0000
oookJ_oonfX0XOoonfX4o`0008cooo]Z003JoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oook
J_oonfX0WOoonfX4o`00093ooo]Z003KoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX09ooonfX00ooo0@3ooo]ZoookJP1_oookJPCo0000U?oonfX00=cooo]Z00?o0000oookJ_oonfX0
9OoonfX2ool100Kooo]Z00?o0000oookJ_oonfX00_oo0@2CoookJPCo0000V?oonfX00=gooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP2CoookJP?o0000W?oonfX00=kooo]Z0_l0000[
oookJP03o`000?oonf[ooo]Z08oooo]Z1?l0002OoookJP00h?oonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z08_ooo]Z1?l0002SoookJP00hOoonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01Gooo]Z00?oo`40oookJ_oonfX0KooonfX4o`000:Oooo]Z003RoookJP03o`00
0?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX05?oonfX2ool106gooo]Z1?l0002[oookJP00hooo
nfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z07oooo]Z1?l0002_oookJP00i?oonfX0
0ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z07_ooo]Z1?l0002coookJP00iOoonfX2o`00
02Cooo]Z00?o0000oookJ_oonfX0MooonfX4o`000;Oooo]Z003WoookJP03o`000?oonf[ooo]Z027o
oo]Z00?o0000oookJ_oonfX0M?oonfX3o`000;_ooo]Z003XoookJP03o`000?oonf[ooo]Z023ooo]Z
00Co0000oookJ_oonf[ooo]Z0_oo0@1]oookJPCo0000__oonfX00>Wooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP1/oookJPCo0000`_oonfX00>[ooo]Z00?o0000oookJ_oonfX07_oo
nfX00ol0003ooo]ZoookJP1XoookJPCo0000a_oonfX00>_ooo]Z0_l0000NoookJP03o`000?oonf[o
oo]Z06Cooo]Z1?l0003:oookJP00kOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z
063ooo]Z1?l0003>oookJP00k_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z05co
oo]Z1?l0003BoookJP00kooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z05Sooo]Z
1?l0003FoookJP00l?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z05Cooo]Z1?l0
003JoookJP00lOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z057ooo]Z0ol0003N
oookJP00l_oonfX2o`0001Oooo]Z00?o0000oookJ_oonfX0COoonfX4o`000>7ooo]Z003doookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0BOoonfX4o`000>Gooo]Z003eoookJP03o`00
0?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0AOoonfX4o`000>Wooo]Z003foookJP03o`000?oo
nf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0@OoonfX4o`000>gooo]Z003goookJP03o`000?oonf[o
oo]Z017ooo]Z00?o0000oookJ_oonfX0?OoonfX4o`000?7ooo]Z003hoookJP;o00004OoonfX00ol0
003ooo]ZoookJP0ioookJPCo0000mOoonfX00?[ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003o
oo]ZoookJP0eoookJPCo0000nOoonfX00?_ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0aoookJPCo0000oOoonfX00?cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP0^oookJP?o0000oooonfX2oookJP00oOoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z02[ooo]Z1?l0003ooookJPGooo]Z003noookJP;o00002ooonfX00ol0003ooo]ZoookJP0Voook
JPCo0000oooonfX9oookJP00oooonfX1oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX08_oonfX4o`000?oooo]Z3OoonfX00?oooo]Z0_oonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z01kooo]Z1?l0003ooookJQ7ooo]Z003ooookJP?ooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP0JoookJPCo0000oooonfXEoookJP00oooonfX4oookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX05_oonfX4o`000?oooo]Z6OoonfX00?oooo]Z1OoonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01;ooo]Z1?l0003ooookJQgooo]Z003ooookJPKo
oo]Z0_l00004oookJP03o`000?oonf[ooo]Z00kooo]Z1?l0003ooookJR7ooo]Z003ooookJPSooo]Z
00Go0000oookJ_oonf[ooo]Zo`00000=oookJP?o0000oooonfXUoookJP00oooonfX9oookJP04o`00
0?oonf[ooo]Zo`0000Wooo]Z1?l0003ooookJRSooo]Z003ooookJP[ooo]Z00?o0000oookJ_l00000
1OoonfX4o`000?oooo]Z;?oonfX00?oooo]Z2ooonfX2o`000003oookJ_l0003o000000;o0000oooo
nfX`oookJP00oooonfX<oookJP;o0000oooonfXdoookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {533.375, 0}} -> {-9.64553*^-5, 0.0170307, \
0.00163328, 0.00163328}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Calculate the curl of the function using the VectorAnalysis \
package--note that the coordinate system is specified as cartesian. 
For the particular case of n=3:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curl[\ LeavingKansas[x, y, z, 3], Cartesian[x, y, z]] // 
      Simplify\)], "Input",
  CellTags->"mmtag:13:Curl[]"],

Cell[BoxData[
    \({\(3\ x\ z\^2\)\/\((x\^2 + y\^2 + z\^2)\)\^\(5/2\), \(3\ y\ \
z\^2\)\/\((x\^2 + y\^2 + z\^2)\)\^\(5/2\), \(3\ z\^3\)\/\((x\^2 + y\^2 + \
z\^2)\)\^\(5/2\)}\)], "Output"]
}, Open  ]],

Cell["Define a new vector function for the curl for general n", "Text"],

Cell[BoxData[
    \(Glenda[x_, \ y_\ , \ z_, \ n_]\  := \ 
      Simplify[Curl[LeavingKansas[x, y, z, n], 
          Cartesian[x, y, z]]]\)], "Input"],

Cell["\<\
Demonstrate the assertion that the curl has a fairly simple form \
and is sphericaly symmetric for n=1\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Glenda[x, y, z, n]\)], "Input"],

Cell[BoxData[
    \({n\ x\ z\^\(\(-1\) + n\)\ \((x\^2 + y\^2 + z\^2)\)\^\(\(-1\) - n\/2\), 
      n\ y\ z\^\(\(-1\) + n\)\ \((x\^2 + y\^2 + z\^2)\)\^\(\(-1\) - n\/2\), 
      n\ z\^n\ \((x\^2 + y\^2 + z\^2)\)\^\(\(-1\) - n\/2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Glenda[x, y, z, 1]\)], "Input"],

Cell[BoxData[
    \({x\/\((x\^2 + y\^2 + z\^2)\)\^\(3/2\), 
      y\/\((x\^2 + y\^2 + z\^2)\)\^\(3/2\), 
      z\/\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(The\ above\ is\ a\ vector\ field\ that\ points\ radially\ from\ the\ \
origin, \ with\ a\ magnitude\ that\ falls\ off\ like\ 1/
        r\^2\)], "Subsubsection"],

Cell["Visualize the curl for n=3", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlotVectorField3D[
      Evaluate[Glenda[x, y, z, 3]], {x, 0,  .5}, {y, 0,  .5}, {z, 0.1,  .5}, 
      VectorHeads \[Rule] True, \ 
      ColorFunction \[Rule] \((\((Hue[#* .66])\) &)\), 
      PlotPoints \[Rule] 7]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9936 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0170162 1.08562 0 1.08562 [
[ 0 0 0 0 ]
[ 1 .9936 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07103 .24925 m
0 .69744 L
s
0 .69744 m
.39947 .9936 L
s
.39947 .9936 m
.41362 .58856 L
s
.41362 .58856 m
.07103 .24925 L
s
.67792 0 m
.94145 .42058 L
s
.94145 .42058 m
1 .84892 L
s
1 .84892 m
.70518 .46965 L
s
.70518 .46965 m
.67792 0 L
s
.07103 .24925 m
0 .69744 L
s
0 .69744 m
.70518 .46965 L
s
.70518 .46965 m
.67792 0 L
s
.67792 0 m
.07103 .24925 L
s
.41362 .58856 m
.94145 .42058 L
s
.94145 .42058 m
1 .84892 L
s
1 .84892 m
.39947 .9936 L
s
.39947 .9936 m
.41362 .58856 L
s
0 0 m
1 0 L
1 .9936 L
0 .9936 L
closepath
clip
newpath
1 .004 0 r
.5 Mabswid
.42641 .58384 m
.4264 .58383 L
s
.4264 .58381 m
.42641 .58384 L
s
.42641 .58384 m
.42639 .58383 L
s
.42641 .58382 m
.42641 .58384 L
s
.42636 .58377 m
.42641 .58384 L
s
.4264 .58381 m
.42639 .58383 L
s
.42641 .58382 m
.4264 .58381 L
s
.42639 .58383 m
.4264 .58383 L
s
.4264 .58383 m
.42641 .58382 L
s
.50308 .55942 m
.50307 .55942 L
s
.50307 .5594 m
.50308 .55942 L
s
.50308 .55942 m
.50306 .55941 L
s
.50308 .5594 m
.50308 .55942 L
s
.50302 .55936 m
.50308 .55942 L
s
.50307 .5594 m
.50306 .55941 L
s
.50308 .5594 m
.50307 .5594 L
s
.50306 .55941 m
.50307 .55942 L
s
.50307 .55942 m
.50308 .5594 L
s
1 .013 0 r
.42466 .64217 m
.42462 .64221 L
s
.42468 .64219 m
.42466 .64217 L
s
.42466 .64217 m
.42467 .64223 L
s
.42467 .64223 m
.42464 .64222 L
s
.42467 .64223 m
.42462 .64221 L
s
.42468 .64219 m
.42467 .64223 L
s
.42455 .64205 m
.42467 .64223 L
s
.42462 .64221 m
.42464 .64222 L
s
.42464 .64222 m
.42468 .64219 L
s
1 .01 0 r
.38088 .53829 m
.38085 .53828 L
s
.38086 .53824 m
.38088 .53829 L
s
.38088 .53829 m
.38083 .53826 L
s
.38088 .53825 m
.38088 .53829 L
s
.38077 .53814 m
.38088 .53829 L
s
.38086 .53824 m
.38083 .53826 L
s
.38088 .53825 m
.38086 .53824 L
s
.38083 .53826 m
.38085 .53828 L
s
.38085 .53828 m
.38088 .53825 L
s
1 .003 0 r
.58203 .53425 m
.58202 .53426 L
s
.58204 .53425 m
.58203 .53425 L
s
.58203 .53425 m
.58204 .53427 L
s
.58204 .53427 m
.58203 .53427 L
s
.58204 .53427 m
.58202 .53426 L
s
.58204 .53425 m
.58204 .53427 L
s
.58198 .53422 m
.58204 .53427 L
s
.58202 .53426 m
.58203 .53427 L
s
.58203 .53427 m
.58204 .53425 L
s
1 .012 0 r
.50273 .61817 m
.50269 .61821 L
s
.50275 .61818 m
.50273 .61817 L
s
.50273 .61817 m
.50275 .61823 L
s
.50275 .61823 m
.50271 .61822 L
s
.50275 .61823 m
.50269 .61821 L
s
.50275 .61818 m
.50275 .61823 L
s
.5026 .61806 m
.50275 .61823 L
s
.50269 .61821 m
.50271 .61822 L
s
.50271 .61822 m
.50275 .61818 L
s
1 .022 0 r
.42284 .70272 m
.42278 .70277 L
s
.42288 .70274 m
.42284 .70272 L
s
.42284 .70272 m
.42287 .70282 L
s
.42287 .70282 m
.42282 .70279 L
s
.42287 .70282 m
.42278 .70277 L
s
.42288 .70274 m
.42287 .70282 L
s
.42268 .70248 m
.42287 .70282 L
s
.42278 .70277 m
.42282 .70279 L
s
.42282 .70279 m
.42288 .70274 L
s
1 .009 0 r
.45899 .51244 m
.45897 .51247 L
s
.45901 .51244 m
.45899 .51244 L
s
.45899 .51244 m
.45901 .51248 L
s
.45901 .51248 m
.45898 .51248 L
s
.45901 .51248 m
.45897 .51247 L
s
.45901 .51244 m
.45901 .51248 L
s
.45889 .51235 m
.45901 .51248 L
s
.45897 .51247 m
.45898 .51248 L
s
.45898 .51248 m
.45901 .51244 L
s
1 .002 0 r
.66338 .50834 m
.66337 .50835 L
s
.66338 .50834 m
.66338 .50834 L
s
.66338 .50834 m
.66339 .50835 L
s
.66337 .50835 m
.66337 .50835 L
s
.66339 .50835 m
.66337 .50835 L
s
.66339 .50835 m
.66337 .50835 L
s
.66338 .50834 m
.66339 .50835 L
s
.66333 .50832 m
.66339 .50835 L
s
.66337 .50835 m
.66338 .50834 L
s
1 .026 0 r
.37826 .59746 m
.37819 .59753 L
s
.37831 .59749 m
.37826 .59746 L
s
.37826 .59746 m
.37829 .59758 L
s
.37829 .59758 m
.37823 .59755 L
s
.37829 .59758 m
.37819 .59753 L
s
.37831 .59749 m
.37829 .59758 L
s
.37806 .5972 m
.37829 .59758 L
s
.37819 .59753 m
.37823 .59755 L
s
.37823 .59755 m
.37831 .59749 L
s
1 .01 0 r
.58316 .59343 m
.58313 .59347 L
s
.58317 .59344 m
.58316 .59343 L
s
.58316 .59343 m
.58318 .59348 L
s
.58313 .59347 m
.58315 .59347 L
s
.58318 .59348 m
.58313 .59347 L
s
.58318 .59348 m
.58315 .59347 L
s
.58317 .59344 m
.58318 .59348 L
s
.58303 .59334 m
.58318 .59348 L
s
.58315 .59347 m
.58317 .59344 L
s
1 .021 0 r
.50237 .67918 m
.50231 .67924 L
s
.5024 .6792 m
.50237 .67918 L
s
.50237 .67918 m
.5024 .67928 L
s
.50231 .67924 m
.50234 .67925 L
s
.5024 .67928 m
.50231 .67924 L
s
.5024 .67928 m
.50234 .67925 L
s
.5024 .6792 m
.5024 .67928 L
s
.50217 .67897 m
.5024 .67928 L
s
.50234 .67925 m
.5024 .6792 L
s
1 .025 0 r
.33281 .49018 m
.33274 .49024 L
s
.33286 .4902 m
.33281 .49018 L
s
.33281 .49018 m
.33285 .49029 L
s
.33285 .49029 m
.33278 .49026 L
s
.33285 .49029 m
.33274 .49024 L
s
.33286 .4902 m
.33285 .49029 L
s
.3326 .48992 m
.33285 .49029 L
s
.33274 .49024 m
.33278 .49026 L
s
1 .029 0 r
.42095 .76554 m
.42085 .76561 L
s
.421 .76557 m
.42095 .76554 L
s
.42095 .76554 m
.42097 .76568 L
s
1 .025 0 r
.33278 .49026 m
.33286 .4902 L
s
1 .029 0 r
.42097 .76568 m
.4209 .76563 L
s
.42097 .76568 m
.42085 .76561 L
s
.421 .76557 m
.42097 .76568 L
s
.42073 .7652 m
.42097 .76568 L
s
.42085 .76561 m
.4209 .76563 L
s
.4209 .76563 m
.421 .76557 L
s
1 .007 0 r
.53951 .48584 m
.53949 .48586 L
s
.53952 .48584 m
.53951 .48584 L
s
.53951 .48584 m
.53953 .48587 L
s
.53949 .48586 m
.5395 .48587 L
s
.53953 .48587 m
.53949 .48586 L
s
.53953 .48587 m
.5395 .48587 L
s
.53952 .48584 m
.53953 .48587 L
s
.5394 .48578 m
.53953 .48587 L
s
.5395 .48587 m
.53952 .48584 L
s
1 .001 0 r
.74722 .48164 m
.74723 .48164 L
s
.74723 .48163 m
.74722 .48164 L
s
.74724 .48164 m
.74722 .48164 L
s
.74723 .48163 m
.74723 .48163 L
s
.74723 .48163 m
.74724 .48164 L
s
.74724 .48164 m
.74723 .48164 L
s
.74723 .48163 m
.74724 .48164 L
s
.74719 .48162 m
.74724 .48164 L
s
.74723 .48164 m
.74723 .48163 L
s
1 .024 0 r
.45786 .57207 m
.45779 .57213 L
s
.4579 .57208 m
.45786 .57207 L
s
.45786 .57207 m
.4579 .57217 L
s
.45779 .57213 m
.45783 .57215 L
s
.4579 .57217 m
.45779 .57213 L
s
.4579 .57217 m
.45783 .57215 L
s
.4579 .57208 m
.4579 .57217 L
s
.45762 .57183 m
.4579 .57217 L
s
.45783 .57215 m
.4579 .57208 L
s
1 .008 0 r
.66606 .56792 m
.66604 .56795 L
s
.66607 .56793 m
.66606 .56792 L
s
.66606 .56792 m
.66609 .56796 L
s
.66604 .56795 m
.66605 .56796 L
s
.66609 .56796 m
.66604 .56795 L
s
.66609 .56796 m
.66605 .56796 L
s
.66607 .56793 m
.66609 .56796 L
s
.66595 .56786 m
.66609 .56796 L
s
.66605 .56796 m
.66607 .56793 L
s
1 .04 0 r
.37555 .65897 m
.37542 .65906 L
s
.37561 .659 m
.37555 .65897 L
s
.37555 .65897 m
.37558 .65916 L
s
.37558 .65916 m
.37548 .65908 L
s
.37558 .65916 m
.37542 .65906 L
s
.37561 .659 m
.37558 .65916 L
s
.37524 .65851 m
.37558 .65916 L
s
.37542 .65906 m
.37548 .65908 L
s
.37548 .65908 m
.37561 .659 L
s
1 .018 0 r
.58434 .6549 m
.58428 .65495 L
s
.58436 .65491 m
.58434 .6549 L
s
.58434 .6549 m
.58437 .65498 L
s
.58428 .65495 m
.58431 .65496 L
s
.58437 .65498 m
.58428 .65495 L
s
.58437 .65498 m
.58431 .65496 L
s
.58436 .65491 m
.58437 .65498 L
s
.58413 .65473 m
.58437 .65498 L
s
.58431 .65496 m
.58436 .65491 L
s
1 .023 0 r
.41247 .46284 m
.41241 .46291 L
s
.4125 .46286 m
.41247 .46284 L
s
.41247 .46284 m
.41252 .46295 L
s
.41252 .46295 m
.41244 .46293 L
s
.41252 .46295 m
.41241 .46291 L
s
.4125 .46286 m
.41252 .46295 L
s
.41221 .46264 m
.41252 .46295 L
s
.41241 .46291 m
.41244 .46293 L
s
1 .028 0 r
.50198 .74253 m
.50189 .7426 L
s
.50202 .74255 m
.50198 .74253 L
s
.50198 .74253 m
.50201 .74266 L
s
.50189 .7426 m
.50193 .74261 L
s
.50201 .74266 m
.50189 .7426 L
s
.50201 .74266 m
.50193 .74261 L
s
.50202 .74255 m
.50201 .74266 L
s
.50171 .74222 m
.50201 .74266 L
s
1 .023 0 r
.41244 .46293 m
.4125 .46286 L
s
1 .028 0 r
.50193 .74261 m
.50202 .74255 L
s
1 .005 0 r
.62251 .45843 m
.62251 .45843 L
s
.62252 .45841 m
.62251 .45843 L
s
.62254 .45843 m
.62251 .45843 L
s
.62253 .45841 m
.62252 .45841 L
s
.62252 .45841 m
.62254 .45843 L
s
.62254 .45843 m
.62251 .45843 L
s
.62253 .45841 m
.62254 .45843 L
s
.62243 .45837 m
.62254 .45843 L
s
.62251 .45843 m
.62253 .45841 L
s
1 .056 0 r
.32932 .5504 m
.32915 .55052 L
s
.32941 .55043 m
.32932 .5504 L
s
.32932 .5504 m
.32938 .55065 L
s
.32938 .55065 m
.32923 .55055 L
s
.32938 .55065 m
.32915 .55052 L
s
.32941 .55043 m
.32938 .55065 L
s
.32888 .54976 m
.32938 .55065 L
s
.32915 .55052 m
.32923 .55055 L
s
.32923 .55055 m
.32941 .55043 L
s
1 .035 0 r
.41896 .83077 m
.41884 .83083 L
s
.41901 .83079 m
.41896 .83077 L
s
.41896 .83077 m
.41898 .83093 L
s
.41884 .83083 m
.41889 .83086 L
s
.41898 .83093 m
.41884 .83083 L
s
.41898 .83093 m
.41889 .83086 L
s
.41901 .83079 m
.41898 .83093 L
s
.41871 .83033 m
.41898 .83093 L
s
.41889 .83086 m
.41901 .83079 L
s
1 .001 0 r
.8337 .4541 m
.8337 .4541 L
s
.8337 .45409 m
.8337 .4541 L
s
.83371 .45409 m
.8337 .4541 L
s
.8337 .45409 m
.8337 .45409 L
s
.8337 .45409 m
.83371 .45409 L
s
.83371 .45409 m
.8337 .4541 L
s
.8337 .45409 m
.83371 .45409 L
s
.83367 .45408 m
.83371 .45409 L
s
.8337 .4541 m
.8337 .45409 L
s
1 .019 0 r
.53991 .54585 m
.53986 .54591 L
s
.53993 .54586 m
.53991 .54585 L
s
.53991 .54585 m
.53995 .54593 L
s
.53986 .54591 m
.53988 .54592 L
s
.53995 .54593 m
.53986 .54591 L
s
.53995 .54593 m
.53988 .54592 L
s
.53993 .54586 m
.53995 .54593 L
s
.53967 .54568 m
.53995 .54593 L
s
.53988 .54592 m
.53993 .54586 L
s
1 .006 0 r
.75155 .54165 m
.75156 .54165 L
s
.75157 .54162 m
.75155 .54165 L
s
.75159 .54165 m
.75155 .54165 L
s
.75157 .54162 m
.75157 .54162 L
s
.75157 .54162 m
.75159 .54165 L
s
.75159 .54165 m
.75156 .54165 L
s
.75157 .54162 m
.75159 .54165 L
s
.75147 .54158 m
.75159 .54165 L
s
.75156 .54165 m
.75157 .54162 L
s
1 .038 0 r
.45667 .63403 m
.45656 .63412 L
s
.45672 .63404 m
.45667 .63403 L
s
.45667 .63403 m
.45672 .6342 L
s
.45656 .63412 m
.4566 .63414 L
s
.45672 .6342 m
.45656 .63412 L
s
.45672 .6342 m
.4566 .63414 L
s
.45672 .63404 m
.45672 .6342 L
s
.4563 .63362 m
.45672 .6342 L
s
.4566 .63414 m
.45672 .63404 L
s
1 .014 0 r
.66886 .62984 m
.66882 .62989 L
s
.66888 .62985 m
.66886 .62984 L
s
.66886 .62984 m
.6689 .62991 L
s
.66882 .62989 m
.66884 .6299 L
s
.6689 .62991 m
.66882 .62989 L
s
.6689 .62991 m
.66884 .6299 L
s
.66888 .62985 m
.6689 .62991 L
s
.66867 .62972 m
.6689 .62991 L
s
.66884 .6299 m
.66888 .62985 L
s
1 .074 0 r
.28224 .43972 m
.28201 .43988 L
s
.28236 .43976 m
.28224 .43972 L
s
.28224 .43972 m
.28233 .44005 L
s
.28233 .44005 m
.28213 .43993 L
s
.28233 .44005 m
.28201 .43988 L
s
.28236 .43976 m
.28233 .44005 L
s
.28162 .43889 m
.28233 .44005 L
s
.28201 .43988 m
.28213 .43993 L
s
.28213 .43993 m
.28236 .43976 L
s
1 .05 0 r
.37268 .72283 m
.37252 .72292 L
s
.37276 .72285 m
.37268 .72283 L
s
.37268 .72283 m
.37271 .72306 L
s
.37252 .72292 m
.37259 .72295 L
s
.37271 .72306 m
.37252 .72292 L
s
.37271 .72306 m
.37259 .72295 L
s
.37276 .72285 m
.37271 .72306 L
s
.37232 .7222 m
.37271 .72306 L
s
.37259 .72295 m
.37276 .72285 L
s
1 .025 0 r
.58554 .71876 m
.58547 .71883 L
s
.58557 .71877 m
.58554 .71876 L
s
.58554 .71876 m
.58558 .71887 L
s
.58547 .71883 m
.58549 .71884 L
s
.58558 .71887 m
.58547 .71883 L
s
1 .016 0 r
.49457 .43463 m
.49453 .43468 L
s
.49459 .43463 m
.49457 .43463 L
s
.49457 .43463 m
.49461 .4347 L
s
.49453 .43468 m
.49455 .43469 L
s
.49461 .4347 m
.49453 .43468 L
s
.49461 .4347 m
.49455 .43469 L
s
.49459 .43463 m
.49461 .4347 L
s
.49434 .43451 m
.49461 .4347 L
s
1 .025 0 r
.58558 .71887 m
.58549 .71884 L
s
.58557 .71877 m
.58558 .71887 L
s
.58526 .7185 m
.58558 .71887 L
s
1 .016 0 r
.49455 .43469 m
.49459 .43463 L
s
1 .025 0 r
.58549 .71884 m
.58557 .71877 L
s
1 .003 0 r
.70816 .43013 m
.70816 .43013 L
s
.70816 .43012 m
.70816 .43013 L
s
.70818 .43013 m
.70816 .43013 L
s
.70817 .43012 m
.70816 .43012 L
s
.70816 .43012 m
.70818 .43013 L
s
.70818 .43013 m
.70816 .43013 L
s
.70817 .43012 m
.70818 .43013 L
s
.7081 .4301 m
.70818 .43013 L
s
.70816 .43013 m
.70817 .43012 L
s
1 .05 0 r
.41053 .52342 m
.41039 .52355 L
s
.41059 .52344 m
.41053 .52342 L
s
.41053 .52342 m
.41061 .52364 L
s
.41039 .52355 m
.41044 .52357 L
s
.41061 .52364 m
.41039 .52355 L
s
.41061 .52364 m
.41044 .52357 L
s
.41059 .52344 m
.41061 .52364 L
s
.40999 .5229 m
.41061 .52364 L
s
1 .033 0 r
.50155 .80833 m
.50144 .80841 L
s
.50159 .80835 m
.50155 .80833 L
s
.50155 .80833 m
.50158 .80849 L
s
1 .05 0 r
.41044 .52357 m
.41059 .52344 L
s
1 .033 0 r
.50144 .80841 m
.50148 .80843 L
s
.50158 .80849 m
.50144 .80841 L
s
.50158 .80849 m
.50148 .80843 L
s
.50159 .80835 m
.50158 .80849 L
s
.50124 .80793 m
.50158 .80849 L
s
.50148 .80843 m
.50159 .80835 L
s
1 0 0 r
.92293 .42568 m
.92293 .42568 L
s
.92293 .42567 m
.92293 .42568 L
s
.92293 .42568 m
.92293 .42568 L
s
.92293 .42567 m
.92293 .42567 L
s
.92293 .42567 m
.92293 .42568 L
s
.92293 .42568 m
.92293 .42568 L
s
.92293 .42567 m
.92293 .42568 L
s
.92291 .42567 m
.92293 .42568 L
s
.92293 .42568 m
.92293 .42567 L
s
1 .014 0 r
.6245 .51885 m
.62451 .51885 L
s
.62454 .5188 m
.6245 .51885 L
s
.62457 .51886 m
.6245 .51885 L
s
.62455 .5188 m
.62454 .5188 L
s
.62454 .5188 m
.62457 .51886 L
s
.62457 .51886 m
.62451 .51885 L
s
.62455 .5188 m
.62457 .51886 L
s
.62433 .51869 m
.62457 .51886 L
s
.62451 .51885 m
.62455 .5188 L
s
1 .077 0 r
.3256 .61293 m
.32534 .61307 L
s
.32571 .61296 m
.3256 .61293 L
s
.3256 .61293 m
.32565 .61329 L
s
.32534 .61307 m
.32544 .6131 L
s
.32565 .61329 m
.32534 .61307 L
s
.32565 .61329 m
.32544 .6131 L
s
.32571 .61296 m
.32565 .61329 L
s
.32502 .61194 m
.32565 .61329 L
s
.32544 .6131 m
.32571 .61296 L
s
1 .037 0 r
.41687 .89852 m
.41674 .89859 L
s
.41692 .89854 m
.41687 .89852 L
s
.41687 .89852 m
.41689 .8987 L
s
.41674 .89859 m
.41679 .89861 L
s
.41689 .8987 m
.41674 .89859 L
s
.41689 .8987 m
.41679 .89861 L
s
.41692 .89854 m
.41689 .8987 L
s
.41661 .89802 m
.41689 .8987 L
s
.41679 .89861 m
.41692 .89854 L
s
1 .004 0 r
.83979 .5145 m
.83979 .51451 L
s
.8398 .51449 m
.83979 .5145 L
s
.83981 .5145 m
.83979 .5145 L
s
.8398 .51449 m
.8398 .51449 L
s
.8398 .51449 m
.83981 .5145 L
s
.83981 .5145 m
.83979 .51451 L
s
.8398 .51449 m
.83981 .5145 L
s
.83972 .51446 m
.83981 .5145 L
s
.83979 .51451 m
.8398 .51449 L
s
1 .031 0 r
.54032 .60824 m
.54023 .60833 L
s
.54035 .60825 m
.54032 .60824 L
s
.54032 .60824 m
.54038 .60838 L
s
.54023 .60833 m
.54026 .60835 L
s
.54038 .60838 m
.54023 .60833 L
s
.54038 .60838 m
.54026 .60835 L
s
.54035 .60825 m
.54038 .60838 L
s
.53994 .60793 m
.54038 .60838 L
s
.54026 .60835 m
.54035 .60825 L
s
1 .011 0 r
.75606 .60403 m
.75607 .60404 L
s
.75608 .60399 m
.75606 .60403 L
s
.75612 .60404 m
.75606 .60403 L
s
.75609 .604 m
.75608 .60399 L
s
.75608 .60399 m
.75612 .60404 L
s
.75612 .60404 m
.75607 .60404 L
s
.75609 .604 m
.75612 .60404 L
s
.75592 .60391 m
.75612 .60404 L
s
.75607 .60404 m
.75609 .604 L
s
1 .061 0 r
.36351 .41056 m
.36335 .41074 L
s
.36357 .41058 m
.36351 .41056 L
s
.36351 .41056 m
.36363 .41083 L
s
.36335 .41074 m
.3634 .41076 L
s
.36363 .41083 m
.36335 .41074 L
s
.36363 .41083 m
.3634 .41076 L
s
.36357 .41058 m
.36363 .41083 L
s
.36277 .40999 m
.36363 .41083 L
s
1 .047 0 r
.45538 .69841 m
.45522 .69851 L
s
.45543 .69842 m
.45538 .69841 L
s
.45538 .69841 m
.45543 .69862 L
s
1 .061 0 r
.3634 .41076 m
.36357 .41058 L
s
1 .047 0 r
.45522 .69851 m
.45527 .69853 L
s
.45543 .69862 m
.45522 .69851 L
s
.45543 .69862 m
.45527 .69853 L
s
.45543 .69842 m
.45543 .69862 L
s
.45492 .69784 m
.45543 .69862 L
s
.45527 .69853 m
.45543 .69842 L
s
1 .02 0 r
.67176 .69422 m
.6717 .69428 L
s
.67178 .69423 m
.67176 .69422 L
s
.67176 .69422 m
.6718 .69431 L
s
.6717 .69428 m
.67172 .69429 L
s
.6718 .69431 m
.6717 .69428 L
s
1 .01 0 r
.57926 .40556 m
.57927 .40557 L
s
.57928 .40552 m
.57926 .40556 L
s
.57931 .40556 m
.57926 .40556 L
s
.57929 .40553 m
.57928 .40552 L
s
.57928 .40552 m
.57931 .40556 L
s
1 .02 0 r
.6718 .69431 m
.67172 .69429 L
s
.67178 .69423 m
.6718 .69431 L
s
.67149 .69402 m
.6718 .69431 L
s
1 .01 0 r
.57931 .40556 m
.57927 .40557 L
s
.57929 .40553 m
.57931 .40556 L
s
.57911 .40546 m
.57931 .40556 L
s
.57927 .40557 m
.57929 .40553 L
s
1 .02 0 r
.67172 .69429 m
.67178 .69423 L
s
1 .133 0 r
.27782 .50123 m
.27736 .50148 L
s
.278 .50126 m
.27782 .50123 L
s
.27782 .50123 m
.2779 .50184 L
s
.27736 .50148 m
.27754 .50151 L
s
.2779 .50184 m
.27736 .50148 L
s
.2779 .50184 m
.27754 .50151 L
s
.278 .50126 m
.2779 .50184 L
s
.27678 .4995 m
.2779 .50184 L
s
.27754 .50151 m
.278 .50126 L
s
1 .055 0 r
.36966 .78916 m
.36947 .78925 L
s
.36974 .78917 m
.36966 .78916 L
s
.36966 .78916 m
.36968 .78941 L
s
.36947 .78925 m
.36954 .78927 L
s
.36968 .78941 m
.36947 .78925 L
s
.36968 .78941 m
.36954 .78927 L
s
.36974 .78917 m
.36968 .78941 L
s
.36928 .78841 m
.36968 .78941 L
s
.36954 .78927 m
.36974 .78917 L
s
1 .002 0 r
.79657 .40093 m
.79657 .40093 L
s
.79657 .40092 m
.79657 .40093 L
s
.79658 .40093 m
.79657 .40093 L
s
.79657 .40092 m
.79657 .40092 L
s
.79657 .40092 m
.79658 .40093 L
s
.79658 .40093 m
.79657 .40093 L
s
.79657 .40092 m
.79658 .40093 L
s
.79653 .40091 m
.79658 .40093 L
s
.79657 .40093 m
.79657 .40092 L
s
1 .038 0 r
.49422 .49551 m
.49412 .49563 L
s
.49425 .49552 m
.49422 .49551 L
s
.49422 .49551 m
.4943 .49567 L
s
.49412 .49563 m
.49414 .49564 L
s
.4943 .49567 m
.49412 .49563 L
s
.4943 .49567 m
.49414 .49564 L
s
.49425 .49552 m
.4943 .49567 L
s
.49372 .49517 m
.4943 .49567 L
s
1 .03 0 r
.58677 .78515 m
.58667 .78522 L
s
.5868 .78516 m
.58677 .78515 L
s
.58677 .78515 m
.58681 .78529 L
s
.58667 .78522 m
.5867 .78524 L
s
.58681 .78529 m
.58667 .78522 L
s
.58681 .78529 m
.5867 .78524 L
s
.5868 .78516 m
.58681 .78529 L
s
.58644 .78481 m
.58681 .78529 L
s
1 .038 0 r
.49414 .49564 m
.49425 .49552 L
s
1 .03 0 r
.5867 .78524 m
.5868 .78516 L
s
1 .01 0 r
.71187 .49093 m
.71188 .49093 L
s
.71189 .49089 m
.71187 .49093 L
s
.71192 .49093 m
.71187 .49093 L
s
.7119 .49089 m
.71189 .49089 L
s
.71189 .49089 m
.71192 .49093 L
s
.71192 .49093 m
.71188 .49093 L
s
.7119 .49089 m
.71192 .49093 L
s
.71173 .49083 m
.71192 .49093 L
s
.71188 .49093 m
.7119 .49089 L
s
1 .071 0 r
.40842 .58639 m
.40818 .58656 L
s
.40847 .5864 m
.40842 .58639 L
s
.40842 .58639 m
.40849 .58671 L
s
.40818 .58656 m
.40824 .58657 L
s
.40849 .58671 m
.40818 .58656 L
s
.40849 .58671 m
.40824 .58657 L
s
.40847 .5864 m
.40849 .58671 L
s
.40768 .58555 m
.40849 .58671 L
s
1 .036 0 r
.50108 .87674 m
.50095 .87681 L
s
.50112 .87675 m
.50108 .87674 L
s
.50108 .87674 m
.5011 .87691 L
s
.50095 .87681 m
.50099 .87683 L
s
.5011 .87691 m
.50095 .87681 L
s
.5011 .87691 m
.50099 .87683 L
s
.50112 .87675 m
.5011 .87691 L
s
.50075 .87627 m
.5011 .87691 L
s
1 .071 0 r
.40824 .58657 m
.40847 .5864 L
s
1 .036 0 r
.50099 .87683 m
.50112 .87675 L
s
1 .002 0 r
.93088 .48649 m
.93089 .48649 L
s
.93089 .48648 m
.93088 .48649 L
s
.9309 .48649 m
.93088 .48649 L
s
.93089 .48648 m
.93089 .48648 L
s
.93089 .48648 m
.9309 .48649 L
s
.9309 .48649 m
.93089 .48649 L
s
.93089 .48648 m
.9309 .48649 L
s
.93083 .48646 m
.9309 .48649 L
s
.93089 .48649 m
.93089 .48648 L
s
1 .024 0 r
.62663 .58162 m
.62657 .5817 L
s
.62665 .58163 m
.62663 .58162 L
s
.62663 .58162 m
.62669 .58173 L
s
.62657 .5817 m
.62658 .58171 L
s
.62669 .58173 m
.62657 .5817 L
s
.62669 .58173 m
.62658 .58171 L
s
.62665 .58163 m
.62669 .58173 L
s
.6263 .58142 m
.62669 .58173 L
s
.62658 .58171 m
.62665 .58163 L
s
1 .276 0 r
.22982 .38839 m
.22889 .38892 L
s
.2302 .38844 m
.22982 .38839 L
s
.22982 .38839 m
.23004 .38965 L
s
.23004 .38965 m
.22927 .38897 L
s
.23004 .38965 m
.22889 .38892 L
s
.2302 .38844 m
.23004 .38965 L
s
.22758 .3848 m
.23004 .38965 L
s
.22889 .38892 m
.22927 .38897 L
s
.22927 .38897 m
.2302 .38844 L
s
1 .087 0 r
.32161 .67782 m
.3213 .67796 L
s
.32172 .67783 m
.32161 .67782 L
s
.32161 .67782 m
.32164 .67821 L
s
.3213 .67796 m
.32141 .67797 L
s
.32164 .67821 m
.3213 .67796 L
s
.32164 .67821 m
.32141 .67797 L
s
.32172 .67783 m
.32164 .67821 L
s
.321 .67661 m
.32164 .67821 L
s
1 .038 0 r
.41468 .96895 m
.41454 .96902 L
s
.41473 .96897 m
.41468 .96895 L
s
.41468 .96895 m
.41469 .96914 L
s
.41454 .96902 m
.4146 .96904 L
s
.41469 .96914 m
.41454 .96902 L
s
1 .087 0 r
.32141 .67797 m
.32172 .67783 L
s
1 .038 0 r
.41469 .96914 m
.4146 .96904 L
s
.41473 .96897 m
.41469 .96914 L
s
.41442 .96842 m
.41469 .96914 L
s
.4146 .96904 m
.41473 .96897 L
s
1 .008 0 r
.84612 .57735 m
.84613 .57735 L
s
.84614 .57731 m
.84612 .57735 L
s
.84617 .57735 m
.84612 .57735 L
s
.84615 .57732 m
.84614 .57731 L
s
.84614 .57731 m
.84617 .57735 L
s
.84617 .57735 m
.84613 .57735 L
s
.84615 .57732 m
.84617 .57735 L
s
.84601 .57726 m
.84617 .57735 L
s
.84613 .57735 m
.84615 .57732 L
s
1 .038 0 r
.44704 .38054 m
.44706 .38055 L
s
.44713 .38041 m
.44704 .38054 L
s
.44723 .38056 m
.44704 .38054 L
s
.44714 .38042 m
.44713 .38041 L
s
.44713 .38041 m
.44723 .38056 L
s
1 .04 0 r
.5407 .67313 m
.54057 .67324 L
s
.54072 .67314 m
.5407 .67313 L
s
.5407 .67313 m
.54075 .67332 L
s
.54057 .67324 m
.5406 .67325 L
s
.54075 .67332 m
.54057 .67324 L
s
1 .038 0 r
.44723 .38056 m
.44706 .38055 L
s
.44714 .38042 m
.44723 .38056 L
s
.44656 .38015 m
.44723 .38056 L
s
1 .04 0 r
.54075 .67332 m
.5406 .67325 L
s
.54072 .67314 m
.54075 .67332 L
s
.54022 .67269 m
.54075 .67332 L
s
1 .038 0 r
.44706 .38055 m
.44714 .38042 L
s
1 .04 0 r
.5406 .67325 m
.54072 .67314 L
s
1 .016 0 r
.76074 .66894 m
.76075 .66895 L
s
.76078 .66888 m
.76074 .66894 L
s
.76082 .66896 m
.76074 .66894 L
s
.76079 .66889 m
.76078 .66888 L
s
.76078 .66888 m
.76082 .66896 L
s
1 .006 0 r
.66675 .37552 m
.66676 .37553 L
s
.66676 .3755 m
.66675 .37552 L
s
.66679 .37552 m
.66675 .37552 L
s
1 .016 0 r
.76082 .66896 m
.76075 .66895 L
s
.76079 .66889 m
.76082 .66896 L
s
.76054 .66875 m
.76082 .66896 L
s
1 .006 0 r
.66677 .3755 m
.66676 .3755 L
s
.66676 .3755 m
.66679 .37552 L
s
.66679 .37552 m
.66676 .37553 L
s
.66677 .3755 m
.66679 .37552 L
s
.66665 .37547 m
.66679 .37552 L
s
.66676 .37553 m
.66677 .3755 L
s
1 .016 0 r
.76075 .66895 m
.76079 .66889 L
s
1 .115 0 r
.3608 .4723 m
.36044 .4726 L
s
.36086 .4723 m
.3608 .4723 L
s
.3608 .4723 m
.36094 .47281 L
s
.36044 .4726 m
.3605 .47259 L
s
.36094 .47281 m
.36044 .4726 L
s
.36094 .47281 m
.3605 .47259 L
s
.36086 .4723 m
.36094 .47281 L
s
.35949 .47101 m
.36094 .47281 L
s
1 .052 0 r
.45398 .76533 m
.4538 .76544 L
s
.45403 .76534 m
.45398 .76533 L
s
.45398 .76533 m
.45402 .76557 L
s
.4538 .76544 m
.45385 .76545 L
s
.45402 .76557 m
.4538 .76544 L
s
.45402 .76557 m
.45385 .76545 L
s
.45403 .76534 m
.45402 .76557 L
s
.4535 .76465 m
.45402 .76557 L
s
1 .115 0 r
.3605 .47259 m
.36086 .4723 L
s
1 .052 0 r
.45385 .76545 m
.45403 .76534 L
s
1 .001 0 r
.88788 .37078 m
.88788 .37078 L
s
.88788 .37077 m
.88788 .37078 L
s
.88789 .37078 m
.88788 .37078 L
s
.88788 .37078 m
.88788 .37077 L
s
.88788 .37077 m
.88789 .37078 L
s
.88789 .37078 m
.88788 .37078 L
s
.88788 .37078 m
.88789 .37078 L
s
.88785 .37077 m
.88789 .37078 L
s
.88788 .37078 m
.88788 .37078 L
s
1 .026 0 r
.58052 .46681 m
.58053 .46682 L
s
.58058 .46672 m
.58052 .46681 L
s
.58064 .46683 m
.58052 .46681 L
s
.58059 .46673 m
.58058 .46672 L
s
.58058 .46672 m
.58064 .46683 L
s
1 .025 0 r
.67476 .76119 m
.67468 .76126 L
s
.67477 .7612 m
.67476 .76119 L
s
.67476 .76119 m
.6748 .76131 L
s
.67468 .76126 m
.67469 .76127 L
s
.6748 .76131 m
.67468 .76126 L
s
1 .026 0 r
.58064 .46683 m
.58053 .46682 L
s
.58059 .46673 m
.58064 .46683 L
s
.58019 .46654 m
.58064 .46683 L
s
1 .025 0 r
.6748 .76131 m
.67469 .76127 L
s
.67477 .7612 m
.6748 .76131 L
s
.67444 .76092 m
.6748 .76131 L
s
1 .026 0 r
.58053 .46682 m
.58059 .46673 L
s
1 .025 0 r
.67469 .76127 m
.67477 .7612 L
s
1 .156 0 r
.27285 .56478 m
.27228 .56502 L
s
.27304 .56477 m
.27285 .56478 L
s
.27285 .56478 m
.27289 .56548 L
s
.27228 .56502 m
.27247 .565 L
s
.27289 .56548 m
.27228 .56502 L
s
.27289 .56548 m
.27247 .565 L
s
.27304 .56477 m
.27289 .56548 L
s
.27175 .56255 m
.27289 .56548 L
s
1 .055 0 r
.36649 .8581 m
.36628 .85819 L
s
.36656 .85812 m
.36649 .8581 L
s
.36649 .8581 m
.3665 .85837 L
s
.36628 .85819 m
.36635 .8582 L
s
.3665 .85837 m
.36628 .85819 L
s
1 .156 0 r
.27247 .565 m
.27304 .56477 L
s
1 .055 0 r
.3665 .85837 m
.36635 .8582 L
s
.36656 .85812 m
.3665 .85837 L
s
.36612 .8573 m
.3665 .85837 L
s
.36635 .8582 m
.36656 .85812 L
s
1 .006 0 r
.80211 .46211 m
.80211 .46211 L
s
.80212 .46208 m
.80211 .46211 L
s
.80215 .46211 m
.80211 .46211 L
s
.80213 .46208 m
.80212 .46208 L
s
.80212 .46208 m
.80215 .46211 L
s
.80215 .46211 m
.80211 .46211 L
s
.80213 .46208 m
.80215 .46211 L
s
.802 .46205 m
.80215 .46211 L
s
.80211 .46211 m
.80213 .46208 L
s
1 .056 0 r
.49378 .55888 m
.49362 .55904 L
s
.4938 .55888 m
.49378 .55888 L
s
.49378 .55888 m
.49387 .55912 L
s
.49362 .55904 m
.49364 .55904 L
s
.49387 .55912 m
.49362 .55904 L
s
1 .033 0 r
.58802 .8542 m
.58791 .85428 L
s
.58805 .85421 m
.58802 .8542 L
s
.58802 .8542 m
.58806 .85436 L
s
1 .056 0 r
.49387 .55912 m
.49364 .55904 L
s
.4938 .55888 m
.49387 .55912 L
s
.49307 .5583 m
.49387 .55912 L
s
1 .033 0 r
.58791 .85428 m
.58794 .8543 L
s
.58806 .85436 m
.58791 .85428 L
s
.58806 .85436 m
.58794 .8543 L
s
.58805 .85421 m
.58806 .85436 L
s
.58767 .8538 m
.58806 .85436 L
s
.58794 .8543 m
.58805 .85421 L
s
1 .056 0 r
.49364 .55904 m
.4938 .55888 L
s
1 .017 0 r
.71573 .55421 m
.71574 .55422 L
s
.71578 .55415 m
.71573 .55421 L
s
.71582 .55423 m
.71573 .55421 L
s
.71578 .55416 m
.71578 .55415 L
s
.71578 .55415 m
.71582 .55423 L
s
.71582 .55423 m
.71574 .55422 L
s
.71578 .55416 m
.71582 .55423 L
s
.71551 .55402 m
.71582 .55423 L
s
.71574 .55422 m
.71578 .55416 L
s
1 .197 0 r
.31291 .35605 m
.31236 .35664 L
s
.31294 .35602 m
.31291 .35605 L
s
.31291 .35605 m
.31324 .35688 L
s
.31236 .35664 m
.31239 .35661 L
s
.31324 .35688 m
.31236 .35664 L
s
.31324 .35688 m
.31239 .35661 L
s
.31294 .35602 m
.31324 .35688 L
s
.31031 .35413 m
.31324 .35688 L
s
1 .081 0 r
.40607 .65181 m
.40579 .65198 L
s
.40613 .6518 m
.40607 .65181 L
s
.40607 .65181 m
.40613 .65218 L
s
.40579 .65198 m
.40584 .65198 L
s
.40613 .65218 m
.40579 .65198 L
s
1 .037 0 r
.50057 .94789 m
.50043 .94797 L
s
.5006 .94791 m
.50057 .94789 L
s
.50057 .94789 m
.50059 .94808 L
s
1 .081 0 r
.40613 .65218 m
.40584 .65198 L
s
.40613 .6518 m
.40613 .65218 L
s
.40528 .65076 m
.40613 .65218 L
s
1 .037 0 r
.50043 .94797 m
.50047 .94798 L
s
.50059 .94808 m
.50043 .94797 L
s
1 .197 0 r
.31239 .35661 m
.31294 .35602 L
s
1 .037 0 r
.50059 .94808 m
.50047 .94798 L
s
.5006 .94791 m
.50059 .94808 L
s
.50025 .94738 m
.50059 .94808 L
s
.50047 .94798 m
.5006 .94791 L
s
1 .081 0 r
.40584 .65198 m
.40613 .6518 L
s
1 .005 0 r
.93917 .54979 m
.93918 .54979 L
s
.93919 .54976 m
.93917 .54979 L
s
.93921 .54979 m
.93917 .54979 L
s
.93919 .54977 m
.93919 .54976 L
s
.93919 .54976 m
.93921 .54979 L
s
.93921 .54979 m
.93918 .54979 L
s
.93919 .54977 m
.93921 .54979 L
s
.93908 .54973 m
.93921 .54979 L
s
.93918 .54979 m
.93919 .54977 L
s
1 .032 0 r
.62878 .64702 m
.62869 .64712 L
s
.62879 .64702 m
.62878 .64702 L
s
.62878 .64702 m
.62884 .64716 L
s
.62869 .64712 m
.6287 .64712 L
s
.62884 .64716 m
.62869 .64712 L
s
1 .02 0 r
.53344 .34949 m
.53344 .3495 L
s
.53348 .34941 m
.53344 .34949 L
s
.53354 .34949 m
.53344 .34949 L
s
.53348 .34941 m
.53348 .34941 L
s
.53348 .34941 m
.53354 .34949 L
s
.53354 .34949 m
.53344 .3495 L
s
.53348 .34941 m
.53354 .34949 L
s
.53314 .34932 m
.53354 .34949 L
s
1 .032 0 r
.62884 .64716 m
.6287 .64712 L
s
.62879 .64702 m
.62884 .64716 L
s
.62835 .6467 m
.62884 .64716 L
s
1 .02 0 r
.53344 .3495 m
.53348 .34941 L
s
1 .032 0 r
.6287 .64712 m
.62879 .64702 L
s
1 .355 0 r
.22396 .45141 m
.22264 .45189 L
s
.22435 .45128 m
.22396 .45141 L
s
.22396 .45141 m
.22399 .45294 L
s
.22264 .45189 m
.22302 .45176 L
s
.22399 .45294 m
.22264 .45189 L
s
.22399 .45294 m
.22302 .45176 L
s
.22435 .45128 m
.22399 .45294 L
s
.22149 .44616 m
.22399 .45294 L
s
1 .087 0 r
.31739 .74521 m
.31707 .74533 L
s
.3175 .74521 m
.31739 .74521 L
s
.31739 .74521 m
.3174 .74561 L
s
.31707 .74533 m
.31717 .74533 L
s
.3174 .74561 m
.31707 .74533 L
s
1 .355 0 r
.22302 .45176 m
.22435 .45128 L
s
1 .087 0 r
.3174 .74561 m
.31717 .74533 L
s
.3175 .74521 m
.3174 .74561 L
s
.31682 .74392 m
.3174 .74561 L
s
.31717 .74533 m
.3175 .74521 L
s
1 .012 0 r
.85272 .64277 m
.85273 .64277 L
s
.85275 .64272 m
.85272 .64277 L
s
.85278 .64277 m
.85272 .64277 L
s
.85276 .64273 m
.85275 .64272 L
s
.85275 .64272 m
.85278 .64277 L
s
1 .003 0 r
.75717 .34451 m
.75717 .34451 L
s
.75717 .34449 m
.75717 .34451 L
s
.75719 .34451 m
.75717 .34451 L
s
.75718 .34449 m
.75717 .34449 L
s
.75717 .34449 m
.75719 .34451 L
s
1 .012 0 r
.85278 .64277 m
.85273 .64277 L
s
.85276 .64273 m
.85278 .64277 L
s
.85255 .64263 m
.85278 .64277 L
s
1 .003 0 r
.75719 .34451 m
.75717 .34451 L
s
.75718 .34449 m
.75719 .34451 L
s
.7571 .34448 m
.75719 .34451 L
s
.75717 .34451 m
.75718 .34449 L
s
1 .012 0 r
.85273 .64277 m
.85276 .64273 L
s
1 .077 0 r
.44583 .4425 m
.44583 .4425 L
s
.44604 .44225 m
.44583 .4425 L
s
.44618 .44258 m
.44583 .4425 L
s
.44604 .44225 m
.44604 .44225 L
s
.44604 .44225 m
.44618 .44258 L
s
1 .046 0 r
.54104 .74064 m
.54088 .74076 L
s
.54106 .74065 m
.54104 .74064 L
s
.54104 .74064 m
.54109 .74086 L
s
.54088 .74076 m
.54091 .74077 L
s
.54109 .74086 m
.54088 .74076 L
s
1 .077 0 r
.44618 .44258 m
.44583 .4425 L
s
.44604 .44225 m
.44618 .44258 L
s
.44494 .44157 m
.44618 .44258 L
s
1 .046 0 r
.54109 .74086 m
.54091 .74077 L
s
.54106 .74065 m
.54109 .74086 L
s
.54052 .74009 m
.54109 .74086 L
s
.54091 .74077 m
.54106 .74065 L
s
1 .077 0 r
.44583 .4425 m
.44604 .44225 L
s
1 .02 0 r
.76559 .7365 m
.7656 .73651 L
s
.76565 .73643 m
.76559 .7365 L
s
.76569 .73653 m
.76559 .7365 L
s
.76566 .73644 m
.76565 .73643 L
s
.76565 .73643 m
.76569 .73653 L
s
1 .016 0 r
.66978 .4371 m
.66979 .43711 L
s
.66982 .43704 m
.66978 .4371 L
s
.66987 .4371 m
.66978 .4371 L
s
.66982 .43704 m
.66982 .43704 L
s
.66982 .43704 m
.66987 .4371 L
s
.66987 .4371 m
.66979 .43711 L
s
.66982 .43704 m
.66987 .4371 L
s
.66954 .43695 m
.66987 .4371 L
s
1 .02 0 r
.76569 .73653 m
.7656 .73651 L
s
.76566 .73644 m
.76569 .73653 L
s
.76536 .73624 m
.76569 .73653 L
s
1 .016 0 r
.66979 .43711 m
.66982 .43704 L
s
1 .02 0 r
.7656 .73651 m
.76566 .73644 L
s
1 .139 0 r
.35754 .5363 m
.35706 .53662 L
s
.35758 .53626 m
.35754 .5363 L
s
.35754 .5363 m
.35764 .53692 L
s
.35706 .53662 m
.3571 .53658 L
s
.35764 .53692 m
.35706 .53662 L
s
1 .053 0 r
.45249 .83494 m
.45229 .83505 L
s
.45253 .83495 m
.45249 .83494 L
s
.45249 .83494 m
.45251 .8352 L
s
.45229 .83505 m
.45233 .83505 L
s
.45251 .8352 m
.45229 .83505 L
s
1 .139 0 r
.35764 .53692 m
.3571 .53658 L
s
.35758 .53626 m
.35764 .53692 L
s
.35607 .53452 m
.35764 .53692 L
s
1 .053 0 r
.45251 .8352 m
.45233 .83505 L
s
.45253 .83495 m
.45251 .8352 L
s
.45201 .8342 m
.45251 .8352 L
s
.45233 .83505 m
.45253 .83495 L
s
1 .139 0 r
.3571 .53658 m
.35758 .53626 L
s
1 .004 0 r
.89538 .43235 m
.89538 .43235 L
s
.89538 .43233 m
.89538 .43235 L
s
.8954 .43234 m
.89538 .43235 L
s
.89539 .43233 m
.89538 .43233 L
s
.89538 .43233 m
.8954 .43234 L
s
.8954 .43234 m
.89538 .43235 L
s
.89539 .43233 m
.8954 .43234 L
s
.8953 .43231 m
.8954 .43234 L
s
.89538 .43235 m
.89539 .43233 L
s
.622 1 0 r
.1791 .34867 m
.17376 .35009 L
s
.18038 .34757 m
.1791 .34867 L
s
.1791 .34867 m
.17878 .3542 L
s
1 .04 0 r
.58179 .53061 m
.58179 .53061 L
s
.5819 .53047 m
.58179 .53061 L
s
.58198 .53065 m
.58179 .53061 L
s
.5819 .53048 m
.5819 .53047 L
s
.5819 .53047 m
.58198 .53065 L
s
1 .028 0 r
.67785 .8309 m
.67776 .83098 L
s
.67786 .83091 m
.67785 .8309 L
s
.67785 .8309 m
.67789 .83104 L
s
.67776 .83098 m
.67777 .83099 L
s
.67789 .83104 m
.67776 .83098 L
s
1 .04 0 r
.58198 .53065 m
.58179 .53061 L
s
.5819 .53048 m
.58198 .53065 L
s
.58131 .53013 m
.58198 .53065 L
s
1 .028 0 r
.67789 .83104 m
.67777 .83099 L
s
.67786 .83091 m
.67789 .83104 L
s
.6775 .83058 m
.67789 .83104 L
s
.67777 .83099 m
.67786 .83091 L
s
1 .04 0 r
.58179 .53061 m
.5819 .53048 L
s
.622 1 0 r
.17376 .35009 m
.17503 .34899 L
s
.17878 .3542 m
.17376 .35009 L
s
1 .152 0 r
.26748 .63052 m
.2669 .63071 L
s
.26765 .63047 m
.26748 .63052 L
s
.26748 .63052 m
.26746 .63118 L
s
.2669 .63071 m
.26706 .63066 L
s
.26746 .63118 m
.2669 .63071 L
s
1 .054 0 r
.36317 .92985 m
.36296 .92993 L
s
.36323 .92986 m
.36317 .92985 L
s
.36317 .92985 m
.36317 .93011 L
s
.36296 .92993 m
.36303 .92994 L
s
.36317 .93011 m
.36296 .92993 L
s
.36282 .92904 m
.36317 .93011 L
s
1 .152 0 r
.26746 .63118 m
.26706 .63066 L
s
.26765 .63047 m
.26746 .63118 L
s
.26651 .6282 m
.26746 .63118 L
s
1 .054 0 r
.36317 .93011 m
.36303 .92994 L
s
.36323 .92986 m
.36317 .93011 L
s
.622 1 0 r
.17878 .3542 m
.17503 .34899 L
s
.18038 .34757 m
.17878 .3542 L
s
.17019 .32737 m
.17878 .3542 L
s
1 .054 0 r
.36303 .92994 m
.36323 .92986 L
s
1 .152 0 r
.26706 .63066 m
.26765 .63047 L
s
.622 1 0 r
.17503 .34899 m
.18038 .34757 L
s
1 .012 0 r
.80789 .52583 m
.80789 .52584 L
s
.80791 .52579 m
.80789 .52583 L
s
.80795 .52584 m
.80789 .52583 L
s
.80792 .52579 m
.80791 .52579 L
s
.80791 .52579 m
.80795 .52584 L
s
.80771 .52571 m
.80795 .52584 L
s
.80795 .52584 m
.80789 .52584 L
s
.80792 .52579 m
.80795 .52584 L
s
.80789 .52584 m
.80792 .52579 L
s
1 .091 0 r
.39709 .3233 m
.39705 .32329 L
s
.39727 .32296 m
.39709 .3233 L
s
.39749 .3233 m
.39709 .3233 L
s
.39722 .32296 m
.39727 .32296 L
s
.39727 .32296 m
.39749 .3233 L
s
1 .067 0 r
.4932 .6248 m
.49299 .62498 L
s
.49321 .6248 m
.4932 .6248 L
s
.4932 .6248 m
.49328 .62511 L
s
.49299 .62498 m
.49299 .62498 L
s
.49328 .62511 m
.49299 .62498 L
s
1 .034 0 r
.58931 .92609 m
.58919 .92617 L
s
.58933 .9261 m
.58931 .92609 L
s
.58931 .92609 m
.58934 .92626 L
s
.58919 .92617 m
.58921 .92619 L
s
.58934 .92626 m
.58919 .92617 L
s
.58895 .92565 m
.58934 .92626 L
s
1 .067 0 r
.49239 .62403 m
.49328 .62511 L
s
1 .091 0 r
.39583 .32242 m
.39749 .3233 L
s
1 .034 0 r
.58934 .92626 m
.58921 .92619 L
s
.58933 .9261 m
.58934 .92626 L
s
1 .067 0 r
.49328 .62511 m
.49299 .62498 L
s
.49321 .6248 m
.49328 .62511 L
s
1 .091 0 r
.39749 .3233 m
.39705 .32329 L
s
.39722 .32296 m
.39749 .3233 L
s
1 .034 0 r
.58921 .92619 m
.58933 .9261 L
s
1 .067 0 r
.49299 .62498 m
.49321 .6248 L
s
1 .091 0 r
.39705 .32329 m
.39722 .32296 L
s
1 .024 0 r
.71974 .62013 m
.71975 .62014 L
s
.7198 .62004 m
.71974 .62013 L
s
.71986 .62015 m
.71974 .62013 L
s
.71981 .62005 m
.7198 .62004 L
s
.7198 .62004 m
.71986 .62015 L
s
1 .01 0 r
.62281 .31752 m
.62281 .31752 L
s
.62282 .31748 m
.62281 .31752 L
s
.62286 .31751 m
.62281 .31752 L
s
.62282 .31748 m
.62282 .31748 L
s
.62282 .31748 m
.62286 .31751 L
s
1 .024 0 r
.71944 .61984 m
.71986 .62015 L
s
1 .01 0 r
.62263 .31745 m
.62286 .31751 L
s
.62286 .31751 m
.62281 .31752 L
s
.62282 .31748 m
.62286 .31751 L
s
1 .024 0 r
.71986 .62015 m
.71975 .62014 L
s
.71981 .62005 m
.71986 .62015 L
s
1 .01 0 r
.62281 .31752 m
.62282 .31748 L
s
1 .024 0 r
.71975 .62014 m
.71981 .62005 L
s
1 .28 0 r
.30915 .41925 m
.30822 .41996 L
s
.30907 .4191 m
.30915 .41925 L
s
.30915 .41925 m
.30935 .42044 L
s
.30822 .41996 m
.30814 .41981 L
s
.30935 .42044 m
.30822 .41996 L
s
1 .082 0 r
.40354 .71981 m
.40324 .71997 L
s
.40358 .7198 m
.40354 .71981 L
s
.40354 .71981 m
.40357 .72019 L
s
.40324 .71997 m
.40328 .71996 L
s
.40357 .72019 m
.40324 .71997 L
s
1 .28 0 r
.30584 .41588 m
.30935 .42044 L
s
1 .082 0 r
.40278 .71867 m
.40357 .72019 L
s
.40357 .72019 m
.40328 .71996 L
s
.40358 .7198 m
.40357 .72019 L
s
.40328 .71996 m
.40358 .7198 L
s
1 .28 0 r
.30935 .42044 m
.30814 .41981 L
s
.30907 .4191 m
.30935 .42044 L
s
.30814 .41981 m
.30907 .4191 L
s
1 .009 0 r
.94781 .61572 m
.94781 .61573 L
s
.94783 .61569 m
.94781 .61572 L
s
.94786 .61573 m
.94781 .61572 L
s
.94783 .61569 m
.94783 .61569 L
s
.94783 .61569 m
.94786 .61573 L
s
1 .001 0 r
.85065 .31246 m
.85065 .31246 L
s
.85065 .31245 m
.85065 .31246 L
s
.85066 .31246 m
.85065 .31246 L
s
.85065 .31245 m
.85065 .31245 L
s
.85065 .31245 m
.85066 .31246 L
s
1 .009 0 r
.94767 .61563 m
.94786 .61573 L
s
1 .001 0 r
.85061 .31245 m
.85066 .31246 L
s
.85066 .31246 m
.85065 .31246 L
s
.85065 .31245 m
.85066 .31246 L
s
1 .009 0 r
.94786 .61573 m
.94781 .61573 L
s
.94783 .61569 m
.94786 .61573 L
s
1 .001 0 r
.85065 .31246 m
.85065 .31245 L
s
1 .009 0 r
.94781 .61573 m
.94783 .61569 L
s
1 .046 0 r
.53392 .4116 m
.53391 .4116 L
s
.53402 .41143 m
.53392 .4116 L
s
.53413 .41161 m
.53392 .4116 L
s
1 .037 0 r
.63098 .71511 m
.63086 .71522 L
s
.63098 .71512 m
.63098 .71511 L
s
.63098 .71511 m
.63103 .71529 L
s
.63086 .71522 m
.63087 .71523 L
s
.63103 .71529 m
.63086 .71522 L
s
1 .046 0 r
.534 .41143 m
.53402 .41143 L
s
.53402 .41143 m
.53413 .41161 L
s
.53329 .41113 m
.53413 .41161 L
s
1 .037 0 r
.63048 .71471 m
.63103 .71529 L
s
.63103 .71529 m
.63087 .71523 L
s
.63098 .71512 m
.63103 .71529 L
s
1 .046 0 r
.53413 .41161 m
.53391 .4116 L
s
.534 .41143 m
.53413 .41161 L
s
1 .037 0 r
.63087 .71523 m
.63098 .71512 L
s
1 .046 0 r
.53391 .4116 m
.534 .41143 L
s
1 .318 0 r
.21704 .51508 m
.21578 .51538 L
s
.21734 .51484 m
.21704 .51508 L
s
.21704 .51508 m
.21691 .51637 L
s
1 .082 0 r
.31297 .81531 m
.31265 .81542 L
s
.31307 .8153 m
.31297 .81531 L
s
.31297 .81531 m
.31296 .81569 L
s
.31265 .81542 m
.31275 .81541 L
s
.31296 .81569 m
.31265 .81542 L
s
.31246 .81404 m
.31296 .81569 L
s
1 .318 0 r
.21515 .51007 m
.21691 .51637 L
s
.21578 .51538 m
.21608 .51515 L
s
.21691 .51637 m
.21578 .51538 L
s
1 .082 0 r
.31296 .81569 m
.31275 .81541 L
s
.31307 .8153 m
.31296 .81569 L
s
.31275 .81541 m
.31307 .8153 L
s
1 .318 0 r
.21691 .51637 m
.21608 .51515 L
s
.21734 .51484 m
.21691 .51637 L
s
.21608 .51515 m
.21734 .51484 L
s
1 .016 0 r
.85958 .71091 m
.85958 .71092 L
s
.85962 .71086 m
.85958 .71091 L
s
.85966 .71093 m
.85958 .71091 L
s
.85963 .71086 m
.85962 .71086 L
s
.85962 .71086 m
.85966 .71093 L
s
1 .01 0 r
.7621 .40644 m
.7621 .40644 L
s
.76211 .4064 m
.7621 .40644 L
s
.76215 .40644 m
.7621 .40644 L
s
.76211 .4064 m
.76211 .4064 L
s
.76211 .4064 m
.76215 .40644 L
s
1 .016 0 r
.85937 .71072 m
.85966 .71093 L
s
1 .01 0 r
.76193 .40636 m
.76215 .40644 L
s
.76215 .40644 m
.7621 .40644 L
s
.76211 .4064 m
.76215 .40644 L
s
1 .016 0 r
.85966 .71093 m
.85958 .71092 L
s
.85963 .71086 m
.85966 .71093 L
s
1 .01 0 r
.7621 .40644 m
.76211 .4064 L
s
1 .016 0 r
.85958 .71092 m
.85963 .71086 L
s
1 .101 0 r
.4443 .50692 m
.44427 .5069 L
s
.44461 .50662 m
.4443 .50692 L
s
.44474 .50707 m
.4443 .50692 L
s
.44457 .5066 m
.44461 .50662 L
s
.44461 .50662 m
.44474 .50707 L
s
1 .048 0 r
.54135 .81093 m
.54118 .81105 L
s
.54137 .81094 m
.54135 .81093 L
s
.54135 .81093 m
.54139 .81116 L
s
.54118 .81105 m
.5412 .81105 L
s
.54139 .81116 m
.54118 .81105 L
s
.54082 .81031 m
.54139 .81116 L
s
1 .101 0 r
.44325 .50555 m
.44474 .50707 L
s
1 .048 0 r
.54139 .81116 m
.5412 .81105 L
s
.54137 .81094 m
.54139 .81116 L
s
.5412 .81105 m
.54137 .81094 L
s
1 .101 0 r
.44474 .50707 m
.44427 .5069 L
s
.44457 .5066 m
.44474 .50707 L
s
.44427 .5069 m
.44457 .5066 L
s
1 .027 0 r
.67293 .50129 m
.67293 .50129 L
s
.67299 .50119 m
.67293 .50129 L
s
.67306 .5013 m
.67293 .50129 L
s
1 .023 0 r
.77064 .80688 m
.77064 .80689 L
s
.77071 .80681 m
.77064 .80688 L
s
.77075 .80692 m
.77064 .80688 L
s
.77072 .80682 m
.77071 .80681 L
s
.77071 .80681 m
.77075 .80692 L
s
1 .027 0 r
.67299 .50119 m
.67299 .50119 L
s
.67299 .50119 m
.67306 .5013 L
s
1 .023 0 r
.77038 .80657 m
.77075 .80692 L
s
1 .027 0 r
.67255 .501 m
.67306 .5013 L
s
1 .023 0 r
.77075 .80692 m
.77064 .80689 L
s
.77072 .80682 m
.77075 .80692 L
s
1 .027 0 r
.67306 .5013 m
.67293 .50129 L
s
.67299 .50119 m
.67306 .5013 L
s
1 .023 0 r
.77064 .80689 m
.77072 .80682 L
s
1 .027 0 r
.67293 .50129 m
.67299 .50119 L
s
1 .139 0 r
.35387 .60264 m
.35335 .60292 L
s
.35388 .60257 m
.35387 .60264 L
s
.35387 .60264 m
.35389 .60326 L
s
1 .052 0 r
.45091 .90744 m
.45071 .90753 L
s
.45095 .90744 m
.45091 .90744 L
s
.45091 .90744 m
.45092 .90769 L
s
1 .139 0 r
.35335 .60292 m
.35336 .60285 L
s
.35389 .60326 m
.35335 .60292 L
s
1 .052 0 r
.45071 .90753 m
.45075 .90753 L
s
.45092 .90769 m
.45071 .90753 L
s
1 .139 0 r
.35251 .60071 m
.35389 .60326 L
s
1 .052 0 r
.45046 .90667 m
.45092 .90769 L
s
1 .693 0 r
.25455 .29475 m
.26475 .30381 L
s
1 .052 0 r
.45092 .90769 m
.45075 .90753 L
s
.45095 .90744 m
.45092 .90769 L
s
.45075 .90753 m
.45095 .90744 L
s
1 .139 0 r
.35389 .60326 m
.35336 .60285 L
s
.35388 .60257 m
.35389 .60326 L
s
.35336 .60285 m
.35388 .60257 L
s
1 .693 0 r
.26231 .30333 m
.26129 .30291 L
s
.26413 .30108 m
.26231 .30333 L
s
.26475 .30381 m
.26231 .30333 L
s
.26312 .30066 m
.26413 .30108 L
s
.26413 .30108 m
.26475 .30381 L
s
.26475 .30381 m
.26129 .30291 L
s
.26312 .30066 m
.26475 .30381 L
s
1 .008 0 r
.9032 .49651 m
.9032 .49651 L
s
.90321 .49647 m
.9032 .49651 L
s
.90324 .49651 m
.9032 .49651 L
s
.90321 .49648 m
.90321 .49647 L
s
.90321 .49647 m
.90324 .49651 L
s
.90306 .49643 m
.90324 .49651 L
s
.90324 .49651 m
.9032 .49651 L
s
.90321 .49648 m
.90324 .49651 L
s
.9032 .49651 m
.90321 .49648 L
s
1 .693 0 r
.26129 .30291 m
.26312 .30066 L
s
1 .05 0 r
.58304 .59705 m
.58303 .59705 L
s
.58319 .59689 m
.58304 .59705 L
s
.58326 .59712 m
.58304 .59705 L
s
1 .03 0 r
.68105 .90353 m
.68095 .90361 L
s
.68107 .90354 m
.68105 .90353 L
s
.68105 .90353 m
.68109 .90368 L
s
1 .05 0 r
.58317 .59689 m
.58319 .59689 L
s
.58319 .59689 m
.58326 .59712 L
s
1 .03 0 r
.68095 .90361 m
.68096 .90362 L
s
.68109 .90368 m
.68095 .90361 L
s
1 .038 0 r
.48487 .2899 m
.48484 .2899 L
s
.48492 .28974 m
.48487 .2899 L
s
.48504 .28987 m
.48487 .2899 L
s
1 .03 0 r
.68069 .90316 m
.68109 .90368 L
s
1 .05 0 r
.58248 .5964 m
.58326 .59712 L
s
1 .038 0 r
.48426 .28963 m
.48504 .28987 L
s
.48489 .28974 m
.48492 .28974 L
s
.48492 .28974 m
.48504 .28987 L
s
1 .03 0 r
.68109 .90368 m
.68096 .90362 L
s
.68107 .90354 m
.68109 .90368 L
s
1 .05 0 r
.58326 .59712 m
.58303 .59705 L
s
.58317 .59689 m
.58326 .59712 L
s
1 .03 0 r
.68096 .90362 m
.68107 .90354 L
s
1 .038 0 r
.48504 .28987 m
.48484 .2899 L
s
.48489 .28974 m
.48504 .28987 L
s
.48484 .2899 m
.48489 .28974 L
s
1 .05 0 r
.58303 .59705 m
.58317 .59689 L
s
1 .136 0 r
.26184 .6988 m
.2613 .69894 L
s
.26198 .69873 m
.26184 .6988 L
s
.26184 .6988 m
.26179 .69938 L
s
.26105 .69662 m
.26179 .69938 L
s
1 .911 0 r
.16271 .38945 m
.16613 .40737 L
s
1 .136 0 r
.2613 .69894 m
.26143 .69887 L
s
.26179 .69938 m
.2613 .69894 L
s
.26179 .69938 m
.26143 .69887 L
s
.26198 .69873 m
.26179 .69938 L
s
.26143 .69887 m
.26198 .69873 L
s
1 .911 0 r
.16699 .40421 m
.16322 .40461 L
s
.16768 .40295 m
.16699 .40421 L
s
.16699 .40421 m
.16613 .40737 L
s
.16322 .40461 m
.16391 .40335 L
s
.16613 .40737 m
.16322 .40461 L
s
1 .017 0 r
.8139 .59225 m
.8139 .59226 L
s
.81394 .59219 m
.8139 .59225 L
s
.81399 .59226 m
.8139 .59225 L
s
.81394 .59219 m
.81394 .59219 L
s
.81394 .59219 m
.81399 .59226 L
s
1 .005 0 r
.71529 .28452 m
.71529 .28452 L
s
.71529 .28449 m
.71529 .28452 L
s
.71532 .28451 m
.71529 .28452 L
s
.71529 .28449 m
.71529 .28449 L
s
.71529 .28449 m
.71532 .28451 L
s
1 .017 0 r
.81365 .59206 m
.81399 .59226 L
s
1 .005 0 r
.71518 .28449 m
.71532 .28451 L
s
.71532 .28451 m
.71529 .28452 L
s
.71529 .28449 m
.71532 .28451 L
s
.71529 .28452 m
.71529 .28449 L
s
1 .017 0 r
.81399 .59226 m
.8139 .59226 L
s
.81394 .59219 m
.81399 .59226 L
s
.8139 .59226 m
.81394 .59219 L
s
1 .911 0 r
.16613 .40737 m
.16391 .40335 L
s
.16768 .40295 m
.16613 .40737 L
s
.16391 .40335 m
.16768 .40295 L
s
1 .07 0 r
.4925 .69343 m
.49226 .69361 L
s
.4925 .69342 m
.4925 .69343 L
s
.4925 .69343 m
.49255 .69376 L
s
.49226 .69361 m
.49225 .6936 L
s
.49255 .69376 m
.49226 .69361 L
s
1 .157 0 r
.39308 .38456 m
.39565 .38653 L
s
1 .07 0 r
.49168 .69254 m
.49255 .69376 L
s
1 .157 0 r
.39502 .38643 m
.39485 .38638 L
s
.39541 .38589 m
.39502 .38643 L
s
.39565 .38653 m
.39502 .38643 L
s
.39525 .38584 m
.39541 .38589 L
s
.39541 .38589 m
.39565 .38653 L
s
1 .07 0 r
.49255 .69376 m
.49225 .6936 L
s
.4925 .69342 m
.49255 .69376 L
s
.49225 .6936 m
.4925 .69342 L
s
1 .157 0 r
.39565 .38653 m
.39485 .38638 L
s
.39525 .38584 m
.39565 .38653 L
s
.39485 .38638 m
.39525 .38584 L
s
1 .029 0 r
.72389 .68882 m
.72389 .68883 L
s
.72397 .68872 m
.72389 .68882 L
s
.72403 .68886 m
.72389 .68882 L
s
.72397 .68873 m
.72397 .68872 L
s
.72397 .68872 m
.72403 .68886 L
s
1 .026 0 r
.62508 .37987 m
.62507 .37987 L
s
.62512 .37976 m
.62508 .37987 L
s
.6252 .37986 m
.62508 .37987 L
s
.62468 .37965 m
.6252 .37986 L
s
1 .029 0 r
.72354 .68845 m
.72403 .68886 L
s
1 .026 0 r
.62511 .37977 m
.62512 .37976 L
s
.62512 .37976 m
.6252 .37986 L
s
1 .029 0 r
.72403 .68886 m
.72389 .68883 L
s
.72397 .68873 m
.72403 .68886 L
s
1 .026 0 r
.6252 .37986 m
.62507 .37987 L
s
.62511 .37977 m
.6252 .37986 L
s
.62507 .37987 m
.62511 .37977 L
s
1 .029 0 r
.72389 .68883 m
.72397 .68873 L
s
1 .078 0 r
.40086 .79062 m
.40055 .79076 L
s
.40089 .79059 m
.40086 .79062 L
s
.40086 .79062 m
.40086 .79098 L
s
.40055 .79076 m
.40059 .79074 L
s
.40086 .79098 m
.40055 .79076 L
s
1 .27 0 r
.30118 .48025 m
.30399 .48502 L
s
1 .078 0 r
.40017 .78946 m
.40086 .79098 L
s
.40086 .79098 m
.40059 .79074 L
s
.40089 .79059 m
.40086 .79098 L
s
1 .27 0 r
.30401 .48389 m
.30301 .48447 L
s
.30384 .48366 m
.30401 .48389 L
s
.30401 .48389 m
.30399 .48502 L
s
.30301 .48447 m
.30285 .48424 L
s
.30399 .48502 m
.30301 .48447 L
s
1 .078 0 r
.40059 .79074 m
.40089 .79059 L
s
1 .27 0 r
.30399 .48502 m
.30285 .48424 L
s
.30384 .48366 m
.30399 .48502 L
s
.30285 .48424 m
.30384 .48366 L
s
1 .012 0 r
.9568 .68446 m
.9568 .68447 L
s
.95683 .68442 m
.9568 .68446 L
s
.95687 .68447 m
.9568 .68446 L
s
.95683 .68442 m
.95683 .68442 L
s
.95683 .68442 m
.95687 .68447 L
s
1 .006 0 r
.85762 .37476 m
.85762 .37476 L
s
.85762 .37473 m
.85762 .37476 L
s
.85765 .37475 m
.85762 .37476 L
s
.85762 .37473 m
.85762 .37473 L
s
.85762 .37473 m
.85765 .37475 L
s
1 .012 0 r
.95663 .68433 m
.95687 .68447 L
s
1 .006 0 r
.8575 .37471 m
.85765 .37475 L
s
.85765 .37475 m
.85762 .37476 L
s
.85762 .37473 m
.85765 .37475 L
s
1 .012 0 r
.95687 .68447 m
.9568 .68447 L
s
.95683 .68442 m
.95687 .68447 L
s
1 .006 0 r
.85762 .37476 m
.85762 .37473 L
s
1 .012 0 r
.9568 .68447 m
.95683 .68442 L
s
1 .04 0 r
.63322 .78608 m
.63309 .78619 L
s
.63322 .78608 m
.63322 .78608 L
s
.63322 .78608 m
.63327 .78627 L
s
.63309 .78619 m
.63309 .7862 L
s
.63327 .78627 m
.63309 .78619 L
s
1 .065 0 r
.53429 .47635 m
.53425 .47634 L
s
.53446 .47611 m
.53429 .47635 L
s
.53458 .47639 m
.53429 .47635 L
s
.53345 .47557 m
.53458 .47639 L
s
1 .04 0 r
.63271 .7856 m
.63327 .78627 L
s
1 .065 0 r
.53441 .47611 m
.53446 .47611 L
s
.53446 .47611 m
.53458 .47639 L
s
1 .04 0 r
.63327 .78627 m
.63309 .7862 L
s
.63322 .78608 m
.63327 .78627 L
s
.63309 .7862 m
.63322 .78608 L
s
1 .065 0 r
.53458 .47639 m
.53425 .47634 L
s
.53441 .47611 m
.53458 .47639 L
s
.53425 .47634 m
.53441 .47611 L
s
1 .074 0 r
.30836 .88836 m
.30806 .88844 L
s
.30844 .88834 m
.30836 .88836 L
s
.30836 .88836 m
.30833 .8887 L
s
.30792 .88714 m
.30833 .8887 L
s
1 .256 0 r
.20854 .5767 m
.20966 .5819 L
s
0 .04 1 r
.10915 .26626 m
.10009 .32904 L
s
1 .074 0 r
.30806 .88844 m
.30814 .88842 L
s
.30833 .8887 m
.30806 .88844 L
s
1 .256 0 r
.20985 .5809 m
.2088 .58108 L
s
.21008 .58065 m
.20985 .5809 L
s
.20985 .5809 m
.20966 .5819 L
s
1 .074 0 r
.30833 .8887 m
.30814 .88842 L
s
.30844 .88834 m
.30833 .8887 L
s
.30814 .88842 m
.30844 .88834 L
s
1 .256 0 r
.2088 .58108 m
.20902 .58083 L
s
.20966 .5819 m
.2088 .58108 L
s
.20966 .5819 m
.20902 .58083 L
s
.21008 .58065 m
.20966 .5819 L
s
.20902 .58083 m
.21008 .58065 L
s
1 .018 0 r
.86672 .78196 m
.86672 .78197 L
s
.86677 .7819 m
.86672 .78196 L
s
.86681 .78199 m
.86672 .78196 L
s
.86677 .78191 m
.86677 .7819 L
s
.86677 .7819 m
.86681 .78199 L
s
1 .017 0 r
.76724 .47103 m
.76723 .47104 L
s
.76727 .47096 m
.76724 .47103 L
s
.76732 .47103 m
.76724 .47103 L
s
.76726 .47097 m
.76727 .47096 L
s
.76727 .47096 m
.76732 .47103 L
s
1 .018 0 r
.86648 .78172 m
.86681 .78199 L
s
1 .017 0 r
.76696 .47087 m
.76732 .47103 L
s
1 .018 0 r
.86681 .78199 m
.86672 .78197 L
s
.86677 .78191 m
.86681 .78199 L
s
1 .017 0 r
.76732 .47103 m
.76723 .47104 L
s
.76726 .47097 m
.76732 .47103 L
s
1 .018 0 r
.86672 .78197 m
.86677 .78191 L
s
1 .017 0 r
.76723 .47104 m
.76726 .47097 L
s
1 .047 0 r
.54165 .88419 m
.54147 .8843 L
s
.54166 .88419 m
.54165 .88419 L
s
.54165 .88419 m
.54167 .88442 L
s
.54147 .8843 m
.54148 .8843 L
s
.54167 .88442 m
.54147 .8843 L
s
1 .108 0 r
.44149 .57226 m
.44293 .57404 L
s
1 .047 0 r
.54115 .88353 m
.54167 .88442 L
s
1 .197 0 r
.34184 .261 m
.34542 .26237 L
s
1 .108 0 r
.4425 .57386 m
.44243 .57381 L
s
.44286 .57356 m
.4425 .57386 L
s
.44293 .57404 m
.4425 .57386 L
s
.44279 .57352 m
.44286 .57356 L
s
.44286 .57356 m
.44293 .57404 L
s
1 .047 0 r
.54167 .88442 m
.54148 .8843 L
s
.54166 .88419 m
.54167 .88442 L
s
.54148 .8843 m
.54166 .88419 L
s
1 .108 0 r
.44293 .57404 m
.44243 .57381 L
s
.44279 .57352 m
.44293 .57404 L
s
.44243 .57381 m
.44279 .57352 L
s
1 .197 0 r
.34476 .2625 m
.3444 .26249 L
s
.34501 .2617 m
.34476 .2625 L
s
.34542 .26237 m
.34476 .2625 L
s
.34465 .26168 m
.34501 .2617 L
s
.34501 .2617 m
.34542 .26237 L
s
.34542 .26237 m
.3444 .26249 L
s
.34465 .26168 m
.34542 .26237 L
s
.3444 .26249 m
.34465 .26168 L
s
1 .025 0 r
.77588 .88027 m
.77588 .88028 L
s
.77596 .88019 m
.77588 .88027 L
s
.776 .88032 m
.77588 .88027 L
s
.77597 .8802 m
.77596 .88019 L
s
.77596 .88019 m
.776 .88032 L
s
1 .035 0 r
.67616 .56822 m
.67615 .56822 L
s
.67625 .56809 m
.67616 .56822 L
s
.67633 .56825 m
.67616 .56822 L
s
1 .025 0 r
.77561 .8799 m
.776 .88032 L
s
1 .035 0 r
.67569 .5678 m
.67633 .56825 L
s
1 .016 0 r
.57577 .2557 m
.57614 .25576 L
s
1 .035 0 r
.67624 .56809 m
.67625 .56809 L
s
.67625 .56809 m
.67633 .56825 L
s
1 .016 0 r
.57607 .25579 m
.57605 .25579 L
s
.57608 .25571 m
.57607 .25579 L
s
.57614 .25576 m
.57607 .25579 L
s
.57607 .25571 m
.57608 .25571 L
s
.57608 .25571 m
.57614 .25576 L
s
1 .025 0 r
.776 .88032 m
.77588 .88028 L
s
.77597 .8802 m
.776 .88032 L
s
1 .016 0 r
.57614 .25576 m
.57605 .25579 L
s
.57607 .25571 m
.57614 .25576 L
s
.57605 .25579 m
.57607 .25571 L
s
1 .025 0 r
.77588 .88028 m
.77597 .8802 L
s
1 .035 0 r
.67633 .56825 m
.67615 .56822 L
s
.67624 .56809 m
.67633 .56825 L
s
.67615 .56822 m
.67624 .56809 L
s
1 .127 0 r
.3488 .66973 m
.34992 .67218 L
s
1 .632 0 r
.24874 .35721 m
.25563 .36702 L
s
1 .127 0 r
.34995 .67161 m
.34945 .67184 L
s
.34994 .67153 m
.34995 .67161 L
s
.34995 .67161 m
.34992 .67218 L
s
.34945 .67184 m
.34944 .67176 L
s
.34992 .67218 m
.34945 .67184 L
s
.34992 .67218 m
.34944 .67176 L
s
.34994 .67153 m
.34992 .67218 L
s
.34944 .67176 m
.34994 .67153 L
s
1 .632 0 r
.25388 .36626 m
.25263 .36561 L
s
.25588 .3645 m
.25388 .36626 L
s
.25563 .36702 m
.25388 .36626 L
s
.25463 .36385 m
.25588 .3645 L
s
.25588 .3645 m
.25563 .36702 L
s
1 .012 0 r
.91135 .56344 m
.91135 .56344 L
s
.91137 .56338 m
.91135 .56344 L
s
.91141 .56344 m
.91135 .56344 L
s
.91138 .56339 m
.91137 .56338 L
s
.91137 .56338 m
.91141 .56344 L
s
1 .002 0 r
.81103 .25039 m
.81103 .25039 L
s
.81103 .25037 m
.81103 .25039 L
s
.81105 .25038 m
.81103 .25039 L
s
1 .012 0 r
.91115 .56331 m
.91141 .56344 L
s
1 .002 0 r
.81097 .25037 m
.81105 .25038 L
s
.81103 .25037 m
.81103 .25037 L
s
.81103 .25037 m
.81105 .25038 L
s
.81105 .25038 m
.81103 .25039 L
s
.81103 .25037 m
.81105 .25038 L
s
.81103 .25039 m
.81103 .25037 L
s
1 .012 0 r
.91141 .56344 m
.91135 .56344 L
s
.91138 .56339 m
.91141 .56344 L
s
.91135 .56344 m
.91138 .56339 L
s
1 .632 0 r
.25563 .36702 m
.25263 .36561 L
s
.25463 .36385 m
.25563 .36702 L
s
.25263 .36561 m
.25463 .36385 L
s
1 .077 0 r
.48337 .35215 m
.48483 .35286 L
s
1 .055 0 r
.58369 .66551 m
.58451 .66638 L
s
.58427 .66629 m
.58425 .66628 L
s
.58445 .66612 m
.58427 .66629 L
s
.58451 .66638 m
.58427 .66629 L
s
.58442 .66612 m
.58445 .66612 L
s
.58445 .66612 m
.58451 .66638 L
s
1 .077 0 r
.48452 .35287 m
.48442 .35287 L
s
.48465 .35257 m
.48452 .35287 L
s
.48483 .35286 m
.48452 .35287 L
s
1 .055 0 r
.58451 .66638 m
.58425 .66628 L
s
.58442 .66612 m
.58451 .66638 L
s
1 .077 0 r
.48455 .35256 m
.48465 .35257 L
s
.48465 .35257 m
.48483 .35286 L
s
1 .055 0 r
.58425 .66628 m
.58442 .66612 L
s
1 .077 0 r
.48483 .35286 m
.48442 .35287 L
s
.48455 .35256 m
.48483 .35286 L
s
.48442 .35287 m
.48455 .35256 L
s
1 .117 0 r
.25598 .76994 m
.25549 .77004 L
s
.2561 .76987 m
.25598 .76994 L
s
.25598 .76994 m
.25591 .77045 L
s
.25535 .76798 m
.25591 .77045 L
s
1 .571 0 r
.15489 .45421 m
.15623 .46547 L
s
1 .117 0 r
.25549 .77004 m
.25561 .76997 L
s
.25591 .77045 m
.25549 .77004 L
s
.25591 .77045 m
.25561 .76997 L
s
.2561 .76987 m
.25591 .77045 L
s
.25561 .76997 m
.2561 .76987 L
s
1 .571 0 r
.15698 .46364 m
.15454 .46372 L
s
.15739 .4627 m
.15698 .46364 L
s
.15698 .46364 m
.15623 .46547 L
s
.15454 .46372 m
.15494 .46278 L
s
.15623 .46547 m
.15454 .46372 L
s
1 .021 0 r
.82015 .66153 m
.82015 .66154 L
s
.82021 .66145 m
.82015 .66153 L
s
.82026 .66155 m
.82015 .66153 L
s
1 .014 0 r
.71926 .34707 m
.71959 .34716 L
s
1 .021 0 r
.81985 .66127 m
.82026 .66155 L
s
.82021 .66146 m
.82021 .66145 L
s
.82021 .66145 m
.82026 .66155 L
s
1 .014 0 r
.71952 .34717 m
.71951 .34717 L
s
.71953 .34711 m
.71952 .34717 L
s
.71959 .34716 m
.71952 .34717 L
s
.71953 .34711 m
.71953 .34711 L
s
.71953 .34711 m
.71959 .34716 L
s
.71959 .34716 m
.71951 .34717 L
s
.71953 .34711 m
.71959 .34716 L
s
1 .021 0 r
.82026 .66155 m
.82015 .66154 L
s
.82021 .66146 m
.82026 .66155 L
s
1 .014 0 r
.71951 .34717 m
.71953 .34711 L
s
1 .021 0 r
.82015 .66154 m
.82021 .66146 L
s
1 .571 0 r
.15494 .46278 m
.15739 .4627 L
s
.15739 .4627 m
.15623 .46547 L
s
.15623 .46547 m
.15494 .46278 L
s
1 .068 0 r
.49095 .76401 m
.49174 .76527 L
s
1 .177 0 r
.39022 .44939 m
.39276 .45197 L
s
1 .068 0 r
.49171 .76495 m
.49146 .76511 L
s
.4917 .76493 m
.49171 .76495 L
s
.49171 .76495 m
.49174 .76527 L
s
.49146 .76511 m
.49145 .76509 L
s
.49174 .76527 m
.49146 .76511 L
s
0 .04 1 r
.10925 .32339 m
.09214 .32013 L
s
.11176 .31239 m
.10925 .32339 L
s
.10009 .32904 m
.10925 .32339 L
s
1 .068 0 r
.49174 .76527 m
.49145 .76509 L
s
.4917 .76493 m
.49174 .76527 L
s
.49145 .76509 m
.4917 .76493 L
s
1 .177 0 r
.39212 .45177 m
.39186 .45168 L
s
.39263 .45121 m
.39212 .45177 L
s
.39276 .45197 m
.39212 .45177 L
s
.39238 .45112 m
.39263 .45121 L
s
.39263 .45121 m
.39276 .45197 L
s
.39276 .45197 m
.39186 .45168 L
s
.39238 .45112 m
.39276 .45197 L
s
.39186 .45168 m
.39238 .45112 L
s
0 .04 1 r
.09214 .32013 m
.09455 .3091 L
s
.09214 .32013 m
.10009 .32904 L
s
1 .032 0 r
.72818 .76047 m
.72818 .76047 L
s
.72828 .76036 m
.72818 .76047 L
s
.72833 .76052 m
.72818 .76047 L
s
1 .04 0 r
.62682 .44454 m
.62759 .44495 L
s
1 .032 0 r
.72782 .76002 m
.72833 .76052 L
s
.72828 .76037 m
.72828 .76036 L
s
.72828 .76036 m
.72833 .76052 L
s
1 .04 0 r
.62741 .44495 m
.62738 .44495 L
s
.62749 .44479 m
.62741 .44495 L
s
.62759 .44495 m
.62741 .44495 L
s
.62746 .44479 m
.62749 .44479 L
s
.62749 .44479 m
.62759 .44495 L
s
1 .032 0 r
.72833 .76052 m
.72818 .76047 L
s
.72828 .76037 m
.72833 .76052 L
s
.72818 .76047 m
.72828 .76037 L
s
1 .04 0 r
.62759 .44495 m
.62738 .44495 L
s
.62746 .44479 m
.62759 .44495 L
s
.62738 .44495 m
.62746 .44479 L
s
1 .228 0 r
.29631 .54741 m
.29831 .55166 L
s
1 .072 0 r
.39745 .86331 m
.39803 .86478 L
s
.622 1 0 r
.19517 .23151 m
.209 .24182 L
s
1 .072 0 r
.39805 .86444 m
.39776 .86456 L
s
.39808 .86441 m
.39805 .86444 L
s
.39805 .86444 m
.39803 .86478 L
s
.39776 .86456 m
.39778 .86453 L
s
.39803 .86478 m
.39776 .86456 L
s
.39803 .86478 m
.39778 .86453 L
s
.39808 .86441 m
.39803 .86478 L
s
.39778 .86453 m
.39808 .86441 L
s
1 .228 0 r
.29845 .55071 m
.29755 .55115 L
s
.29827 .55047 m
.29845 .55071 L
s
.29845 .55071 m
.29831 .55166 L
s
.29755 .55115 m
.29737 .55091 L
s
.29831 .55166 m
.29755 .55115 L
s
.29831 .55166 m
.29737 .55091 L
s
.29827 .55047 m
.29831 .55166 L
s
.29737 .55091 m
.29827 .55047 L
s
1 .014 0 r
.96618 .75618 m
.96618 .75619 L
s
.96621 .75613 m
.96618 .75618 L
s
.96625 .7562 m
.96618 .75618 L
s
.96597 .756 m
.96625 .7562 L
s
1 .011 0 r
.86469 .43967 m
.86495 .43976 L
s
.86489 .43977 m
.86489 .43977 L
s
.86491 .43972 m
.86489 .43977 L
s
.86495 .43976 m
.86489 .43977 L
s
1 .014 0 r
.96622 .75613 m
.96621 .75613 L
s
.96621 .75613 m
.96625 .7562 L
s
1 .011 0 r
.86491 .43972 m
.86491 .43972 L
s
.86491 .43972 m
.86495 .43976 L
s
1 .014 0 r
.96625 .7562 m
.96618 .75619 L
s
.96622 .75613 m
.96625 .7562 L
s
1 .011 0 r
.86495 .43976 m
.86489 .43977 L
s
.86491 .43972 m
.86495 .43976 L
s
.86489 .43977 m
.86491 .43972 L
s
1 .014 0 r
.96618 .75619 m
.96622 .75613 L
s
0 .04 1 r
.09455 .3091 m
.11176 .31239 L
s
.10009 .32904 m
.11176 .31239 L
s
1 .076 0 r
.53362 .54281 m
.53483 .54389 L
s
1 .04 0 r
.63503 .85957 m
.63557 .8603 L
s
1 .061 0 r
.4322 .22605 m
.43343 .22625 L
s
1 .04 0 r
.63554 .8601 m
.63539 .86021 L
s
.63553 .8601 m
.63554 .8601 L
s
.63554 .8601 m
.63557 .8603 L
s
.63539 .86021 m
.63539 .86021 L
s
.63557 .8603 m
.63539 .86021 L
s
1 .076 0 r
.53452 .54381 m
.53444 .5438 L
s
.53473 .54356 m
.53452 .54381 L
s
.53483 .54389 m
.53452 .54381 L
s
1 .04 0 r
.63557 .8603 m
.63539 .86021 L
s
.63553 .8601 m
.63557 .8603 L
s
1 .076 0 r
.53465 .54354 m
.53473 .54356 L
s
.53473 .54356 m
.53483 .54389 L
s
1 .04 0 r
.63539 .86021 m
.63553 .8601 L
s
1 .061 0 r
.43322 .22634 m
.43311 .22635 L
s
.43325 .22607 m
.43322 .22634 L
s
.43343 .22625 m
.43322 .22634 L
s
.43314 .22607 m
.43325 .22607 L
s
.43325 .22607 m
.43343 .22625 L
s
1 .076 0 r
.53483 .54389 m
.53444 .5438 L
s
.53465 .54354 m
.53483 .54389 L
s
.53444 .5438 m
.53465 .54354 L
s
1 .061 0 r
.43343 .22625 m
.43311 .22635 L
s
.43314 .22607 m
.43343 .22625 L
s
.43311 .22635 m
.43314 .22607 L
s
0 .04 1 r
.09455 .3091 m
.10009 .32904 L
s
1 .201 0 r
.20164 .64623 m
.20235 .65042 L
s
.575 1 0 r
.10009 .32904 m
.09673 .35232 L
s
1 .201 0 r
.20255 .64964 m
.20169 .64975 L
s
.20272 .64942 m
.20255 .64964 L
s
.20255 .64964 m
.20235 .65042 L
s
.20169 .64975 m
.20186 .64952 L
s
.20235 .65042 m
.20169 .64975 L
s
.20235 .65042 m
.20186 .64952 L
s
.20272 .64942 m
.20235 .65042 L
s
.20186 .64952 m
.20272 .64942 L
s
1 .02 0 r
.87415 .8561 m
.87415 .85611 L
s
.87422 .85603 m
.87415 .8561 L
s
.87426 .85613 m
.87415 .8561 L
s
.8739 .85581 m
.87426 .85613 L
s
1 .024 0 r
.77221 .53819 m
.77269 .53846 L
s
1 .007 0 r
.67052 .22057 m
.67071 .22058 L
s
1 .02 0 r
.87422 .85604 m
.87422 .85603 L
s
.87422 .85603 m
.87426 .85613 L
s
1 .024 0 r
.77258 .53845 m
.77256 .53845 L
s
.77263 .53835 m
.77258 .53845 L
s
.77269 .53846 m
.77258 .53845 L
s
1 .007 0 r
.67068 .2206 m
.67067 .2206 L
s
.67068 .22056 m
.67068 .2206 L
s
.67071 .22058 m
.67068 .2206 L
s
.67067 .22056 m
.67068 .22056 L
s
.67068 .22056 m
.67071 .22058 L
s
1 .024 0 r
.77262 .53836 m
.77263 .53835 L
s
.77263 .53835 m
.77269 .53846 L
s
1 .007 0 r
.67071 .22058 m
.67067 .2206 L
s
.67067 .22056 m
.67071 .22058 L
s
.67067 .2206 m
.67067 .22056 L
s
1 .02 0 r
.87426 .85613 m
.87415 .85611 L
s
.87422 .85604 m
.87426 .85613 L
s
.87415 .85611 m
.87422 .85604 L
s
1 .024 0 r
.77269 .53846 m
.77256 .53845 L
s
.77262 .53836 m
.77269 .53846 L
s
.77256 .53845 m
.77262 .53836 L
s
.622 1 0 r
.20865 .24235 m
.20329 .24282 L
s
.20913 .23667 m
.20865 .24235 L
s
.209 .24182 m
.20865 .24235 L
s
1 .104 0 r
.43965 .64189 m
.44091 .64373 L
s
1 .28 0 r
.33783 .32383 m
.34216 .32678 L
s
1 .104 0 r
.44052 .64352 m
.44043 .64347 L
s
.44089 .64325 m
.44052 .64352 L
s
.44091 .64373 m
.44052 .64352 L
s
.4408 .6432 m
.44089 .64325 L
s
.44089 .64325 m
.44091 .64373 L
s
.44091 .64373 m
.44043 .64347 L
s
.4408 .6432 m
.44091 .64373 L
s
.622 1 0 r
.20376 .23713 m
.20913 .23667 L
s
.20913 .23667 m
.209 .24182 L
s
1 .104 0 r
.44043 .64347 m
.4408 .6432 L
s
.622 1 0 r
.20329 .24282 m
.20376 .23713 L
s
.209 .24182 m
.20329 .24282 L
s
1 .28 0 r
.34138 .32677 m
.34068 .32669 L
s
.3419 .32569 m
.34138 .32677 L
s
.34216 .32678 m
.34138 .32677 L
s
.34121 .32561 m
.3419 .32569 L
s
.3419 .32569 m
.34216 .32678 L
s
.34068 .32669 m
.34121 .32561 L
s
.34216 .32678 m
.34068 .32669 L
s
.34121 .32561 m
.34216 .32678 L
s
.622 1 0 r
.20376 .23713 m
.209 .24182 L
s
.575 1 0 r
.10008 .35019 m
.09384 .34902 L
s
.10097 .34625 m
.10008 .35019 L
s
.09673 .35232 m
.10008 .35019 L
s
1 .04 0 r
.67897 .63752 m
.67967 .63809 L
s
1 .038 0 r
.57687 .31859 m
.57765 .31884 L
s
1 .04 0 r
.67949 .63805 m
.67946 .63805 L
s
.6796 .6379 m
.67949 .63805 L
s
.67967 .63809 m
.67949 .63805 L
s
.67957 .63791 m
.6796 .6379 L
s
.6796 .6379 m
.67967 .63809 L
s
1 .038 0 r
.5775 .31887 m
.57745 .31887 L
s
.57755 .3187 m
.5775 .31887 L
s
.57765 .31884 m
.5775 .31887 L
s
.5775 .31871 m
.57755 .3187 L
s
.57755 .3187 m
.57765 .31884 L
s
1 .04 0 r
.67967 .63809 m
.67946 .63805 L
s
.67957 .63791 m
.67967 .63809 L
s
.67946 .63805 m
.67957 .63791 L
s
1 .038 0 r
.57765 .31884 m
.57745 .31887 L
s
.5775 .31871 m
.57765 .31884 L
s
.575 1 0 r
.09384 .34902 m
.09472 .34507 L
s
.09384 .34902 m
.09673 .35232 L
s
1 .038 0 r
.57745 .31887 m
.5775 .31871 L
s
1 .111 0 r
.34492 .74177 m
.3458 .74401 L
s
1 .46 0 r
.24268 .42241 m
.24649 .43018 L
s
1 .111 0 r
.34586 .74351 m
.3454 .7437 L
s
.34585 .74343 m
.34586 .74351 L
s
.34586 .74351 m
.3458 .74401 L
s
.3454 .7437 m
.34539 .74361 L
s
.3458 .74401 m
.3454 .7437 L
s
.575 1 0 r
.09472 .34507 m
.10097 .34625 L
s
.09673 .35232 m
.10097 .34625 L
s
1 .111 0 r
.3458 .74401 m
.34539 .74361 L
s
.34585 .74343 m
.3458 .74401 L
s
.34539 .74361 m
.34585 .74343 L
s
.575 1 0 r
.09472 .34507 m
.09673 .35232 L
s
1 .46 0 r
.24545 .42949 m
.24442 .42889 L
s
.24703 .42835 m
.24545 .42949 L
s
.24649 .43018 m
.24545 .42949 L
s
.246 .42775 m
.24703 .42835 L
s
.24703 .42835 m
.24649 .43018 L
s
1 .008 0 r
.81722 .31332 m
.81742 .31336 L
s
1 .016 0 r
.9196 .63312 m
.91993 .63331 L
s
.91985 .6333 m
.91984 .6333 L
s
.91988 .63323 m
.91985 .6333 L
s
.91993 .63331 m
.91985 .6333 L
s
1 .008 0 r
.81738 .31337 m
.81737 .31337 L
s
.81739 .31333 m
.81738 .31337 L
s
.81742 .31336 m
.81738 .31337 L
s
1 .016 0 r
.91988 .63324 m
.91988 .63323 L
s
.91988 .63323 m
.91993 .63331 L
s
1 .008 0 r
.81738 .31333 m
.81739 .31333 L
s
.81739 .31333 m
.81742 .31336 L
s
.81742 .31336 m
.81737 .31337 L
s
.81738 .31333 m
.81742 .31336 L
s
.81737 .31337 m
.81738 .31333 L
s
1 .016 0 r
.91993 .63331 m
.91984 .6333 L
s
.91988 .63324 m
.91993 .63331 L
s
.91984 .6333 m
.91988 .63324 L
s
1 .46 0 r
.24442 .42889 m
.246 .42775 L
s
.24649 .43018 m
.24442 .42889 L
s
.246 .42775 m
.24649 .43018 L
s
1 .101 0 r
.48244 .41742 m
.48419 .41859 L
s
1 .055 0 r
.58496 .73766 m
.58575 .73861 L
s
.58552 .7385 m
.58548 .7385 L
s
.58571 .73834 m
.58552 .7385 L
s
.58575 .73861 m
.58552 .7385 L
s
.58567 .73834 m
.58571 .73834 L
s
.58571 .73834 m
.58575 .73861 L
s
.58575 .73861 m
.58548 .7385 L
s
.58567 .73834 m
.58575 .73861 L
s
1 .101 0 r
.48381 .41856 m
.48364 .41854 L
s
.48404 .41817 m
.48381 .41856 L
s
.48419 .41859 m
.48381 .41856 L
s
1 .055 0 r
.58548 .7385 m
.58567 .73834 L
s
1 .101 0 r
.48386 .41815 m
.48404 .41817 L
s
.48404 .41817 m
.48419 .41859 L
s
.48419 .41859 m
.48364 .41854 L
s
.48386 .41815 m
.48419 .41859 L
s
.48364 .41854 m
.48386 .41815 L
s
1 .1 0 r
.24941 .84249 m
.24982 .84465 L
s
1 .378 0 r
.14674 .52181 m
.14728 .52936 L
s
1 .1 0 r
.24991 .84421 m
.24947 .84429 L
s
.25 .84415 m
.24991 .84421 L
s
.24991 .84421 m
.24982 .84465 L
s
.24947 .84429 m
.24957 .84422 L
s
.24982 .84465 m
.24947 .84429 L
s
.24982 .84465 m
.24957 .84422 L
s
.25 .84415 m
.24982 .84465 L
s
.24957 .84422 m
.25 .84415 L
s
1 .378 0 r
.14788 .52819 m
.14621 .52818 L
s
.14814 .52751 m
.14788 .52819 L
s
.14788 .52819 m
.14728 .52936 L
s
.14621 .52818 m
.14647 .5275 L
s
.14728 .52936 m
.14621 .52818 L
s
.14647 .5275 m
.14814 .52751 L
s
.14814 .52751 m
.14728 .52936 L
s
.14728 .52936 m
.14647 .5275 L
s
1 .024 0 r
.72352 .4124 m
.72403 .4126 L
s
.82633 .73352 m
.82678 .73388 L
s
.82666 .73385 m
.82665 .73385 L
s
.82673 .73376 m
.82666 .73385 L
s
.82678 .73388 m
.82666 .73385 L
s
.82672 .73376 m
.82673 .73376 L
s
.82673 .73376 m
.82678 .73388 L
s
.72392 .41261 m
.7239 .41262 L
s
.72396 .41251 m
.72392 .41261 L
s
.72403 .4126 m
.72392 .41261 L
s
.72394 .41251 m
.72396 .41251 L
s
.72396 .41251 m
.72403 .4126 L
s
.82678 .73388 m
.82665 .73385 L
s
.82672 .73376 m
.82678 .73388 L
s
.82665 .73385 m
.82672 .73376 L
s
.72403 .4126 m
.7239 .41262 L
s
.72394 .41251 m
.72403 .4126 L
s
.7239 .41262 m
.72394 .41251 L
s
1 .064 0 r
.49018 .83863 m
.49087 .83988 L
s
1 .167 0 r
.38723 .51707 m
.38933 .51977 L
s
1 .276 0 r
.28428 .19551 m
.28845 .19599 L
s
1 .064 0 r
.49087 .83957 m
.49062 .83971 L
s
.49085 .83955 m
.49087 .83957 L
s
.49087 .83957 m
.49087 .83988 L
s
.49062 .83971 m
.4906 .83969 L
s
.49087 .83988 m
.49062 .83971 L
s
.49087 .83988 m
.4906 .83969 L
s
.49085 .83955 m
.49087 .83988 L
s
.4906 .83969 m
.49085 .83955 L
s
1 .167 0 r
.38879 .51953 m
.3885 .51942 L
s
.38933 .51904 m
.38879 .51953 L
s
.38933 .51977 m
.38879 .51953 L
s
.38904 .51893 m
.38933 .51904 L
s
.38933 .51904 m
.38933 .51977 L
s
.38933 .51977 m
.3885 .51942 L
s
.38904 .51893 m
.38933 .51977 L
s
.3885 .51942 m
.38904 .51893 L
s
1 .276 0 r
.28809 .19643 m
.2872 .19657 L
s
.28804 .19521 m
.28809 .19643 L
s
.28845 .19599 m
.28809 .19643 L
s
.28714 .19535 m
.28804 .19521 L
s
.28804 .19521 m
.28845 .19599 L
s
.2872 .19657 m
.28714 .19535 L
s
.28845 .19599 m
.2872 .19657 L
s
.28714 .19535 m
.28845 .19599 L
s
1 .05 0 r
.62905 .5123 m
.62996 .51291 L
s
1 .023 0 r
.52581 .18985 m
.52631 .18987 L
s
1 .033 0 r
.73228 .83475 m
.7328 .83532 L
s
.73265 .83525 m
.73264 .83526 L
s
.73276 .83515 m
.73265 .83525 L
s
.7328 .83532 m
.73265 .83525 L
s
.73275 .83516 m
.73276 .83515 L
s
.73276 .83515 m
.7328 .83532 L
s
1 .023 0 r
.52623 .18992 m
.52619 .18992 L
s
.52623 .18981 m
.52623 .18992 L
s
.52631 .18987 m
.52623 .18992 L
s
1 .05 0 r
.62975 .51288 m
.62969 .51288 L
s
.62987 .51269 m
.62975 .51288 L
s
.62996 .51291 m
.62975 .51288 L
s
1 .023 0 r
.52619 .18981 m
.52623 .18981 L
s
.52623 .18981 m
.52631 .18987 L
s
1 .033 0 r
.7328 .83532 m
.73264 .83526 L
s
.73275 .83516 m
.7328 .83532 L
s
1 .05 0 r
.62981 .51269 m
.62987 .51269 L
s
.62987 .51269 m
.62996 .51291 L
s
1 .033 0 r
.73264 .83526 m
.73275 .83516 L
s
1 .023 0 r
.52631 .18987 m
.52619 .18992 L
s
.52619 .18981 m
.52631 .18987 L
s
.52619 .18992 m
.52619 .18981 L
s
1 .05 0 r
.62996 .51291 m
.62969 .51288 L
s
.62981 .51269 m
.62996 .51291 L
s
.62969 .51288 m
.62981 .51269 L
s
1 .911 0 r
.18785 .29465 m
.19371 .30512 L
s
1 .185 0 r
.29123 .61754 m
.29261 .62115 L
s
.2928 .62038 m
.29204 .6207 L
s
.29263 .62016 m
.2928 .62038 L
s
.2928 .62038 m
.29261 .62115 L
s
.29204 .6207 m
.29187 .62048 L
s
.29261 .62115 m
.29204 .6207 L
s
.29261 .62115 m
.29187 .62048 L
s
.29263 .62016 m
.29261 .62115 L
s
.29187 .62048 m
.29263 .62016 L
s
1 .016 0 r
.97573 .83086 m
.97604 .8311 L
s
.87221 .50751 m
.87256 .50767 L
s
1 .003 0 r
.76869 .18417 m
.76879 .18417 L
s
1 .016 0 r
.97596 .83108 m
.97596 .83108 L
s
.976 .83101 m
.97596 .83108 L
s
.97604 .8311 m
.97596 .83108 L
s
1 .003 0 r
.76877 .18418 m
.76877 .18418 L
s
.76877 .18416 m
.76877 .18418 L
s
.76879 .18417 m
.76877 .18418 L
s
.76877 .18416 m
.76877 .18416 L
s
.76877 .18416 m
.76879 .18417 L
s
1 .016 0 r
.976 .83102 m
.976 .83101 L
s
.976 .83101 m
.97604 .8311 L
s
.87248 .50767 m
.87247 .50768 L
s
.87251 .5076 m
.87248 .50767 L
s
.87256 .50767 m
.87248 .50767 L
s
1 .003 0 r
.76879 .18417 m
.76877 .18418 L
s
.76877 .18416 m
.76879 .18417 L
s
.76877 .18418 m
.76877 .18416 L
s
1 .016 0 r
.8725 .50761 m
.87251 .5076 L
s
.87251 .5076 m
.87256 .50767 L
s
.97604 .8311 m
.97596 .83108 L
s
.976 .83102 m
.97604 .8311 L
s
.87256 .50767 m
.87247 .50768 L
s
.8725 .50761 m
.87256 .50767 L
s
.97596 .83108 m
.976 .83102 L
s
.87247 .50768 m
.8725 .50761 L
s
1 .078 0 r
.53379 .61304 m
.53495 .61427 L
s
1 .115 0 r
.43013 .28925 m
.43221 .29001 L
s
1 .078 0 r
.53464 .61416 m
.53455 .61413 L
s
.53489 .61391 m
.53464 .61416 L
s
.53495 .61427 m
.53464 .61416 L
s
.53479 .61389 m
.53489 .61391 L
s
.53489 .61391 m
.53495 .61427 L
s
.53495 .61427 m
.53455 .61413 L
s
.53479 .61389 m
.53495 .61427 L
s
.53455 .61413 m
.53479 .61389 L
s
1 .115 0 r
.43187 .2901 m
.43159 .29011 L
s
.43199 .2896 m
.43187 .2901 L
s
.43221 .29001 m
.43187 .2901 L
s
.43172 .28961 m
.43199 .2896 L
s
.43199 .2896 m
.43221 .29001 L
s
.43159 .29011 m
.43172 .28961 L
s
.43221 .29001 m
.43159 .29011 L
s
.43172 .28961 m
.43221 .29001 L
s
1 .911 0 r
.19419 .30472 m
.19031 .3048 L
s
.19476 .30124 m
.19419 .30472 L
s
.19371 .30512 m
.19419 .30472 L
s
1 .726 0 r
.09062 .39461 m
.08884 .40698 L
s
1 .159 0 r
.19443 .71886 m
.19488 .72225 L
s
.19508 .72163 m
.19438 .7217 L
s
.19521 .72144 m
.19508 .72163 L
s
.19508 .72163 m
.19488 .72225 L
s
.19438 .7217 m
.19451 .7215 L
s
.19488 .72225 m
.19438 .7217 L
s
.19451 .7215 m
.19521 .72144 L
s
.19521 .72144 m
.19488 .72225 L
s
.19488 .72225 m
.19451 .7215 L
s
1 .911 0 r
.19031 .3048 m
.19087 .30131 L
s
.19371 .30512 m
.19031 .3048 L
s
.19087 .30131 m
.19476 .30124 L
s
.19476 .30124 m
.19371 .30512 L
s
1 .029 0 r
.7777 .60851 m
.77826 .60887 L
s
1 .019 0 r
.67375 .28381 m
.67419 .2839 L
s
1 .029 0 r
.77812 .60885 m
.7781 .60886 L
s
.77819 .60874 m
.77812 .60885 L
s
.77826 .60887 m
.77812 .60885 L
s
1 .019 0 r
.6741 .28393 m
.67408 .28393 L
s
.67412 .28383 m
.6741 .28393 L
s
.67419 .2839 m
.6741 .28393 L
s
1 .029 0 r
.77817 .60875 m
.77819 .60874 L
s
.77819 .60874 m
.77826 .60887 L
s
1 .019 0 r
.67409 .28384 m
.67412 .28383 L
s
.67412 .28383 m
.67419 .2839 L
s
.67419 .2839 m
.67408 .28393 L
s
.67409 .28384 m
.67419 .2839 L
s
.67408 .28393 m
.67409 .28384 L
s
1 .029 0 r
.77826 .60887 m
.7781 .60886 L
s
.77817 .60875 m
.77826 .60887 L
s
.7781 .60886 m
.77817 .60875 L
s
1 .911 0 r
.19087 .30131 m
.19371 .30512 L
s
1 .726 0 r
.09059 .40579 m
.08734 .40519 L
s
.09105 .4038 m
.09059 .40579 L
s
.08884 .40698 m
.09059 .40579 L
s
1 .095 0 r
.43773 .71461 m
.43878 .7164 L
s
1 .27 0 r
.33364 .38947 m
.33714 .39299 L
s
1 .095 0 r
.43844 .71618 m
.43834 .71613 L
s
.4388 .71596 m
.43844 .71618 L
s
.43878 .7164 m
.43844 .71618 L
s
1 .726 0 r
.08734 .40519 m
.0878 .40321 L
s
.08734 .40519 m
.08884 .40698 L
s
1 .095 0 r
.43871 .7159 m
.4388 .71596 L
s
.4388 .71596 m
.43878 .7164 L
s
.43878 .7164 m
.43834 .71613 L
s
.43871 .7159 m
.43878 .7164 L
s
.43834 .71613 m
.43871 .7159 L
s
1 .27 0 r
.33652 .39283 m
.33574 .39271 L
s
.33713 .39186 m
.33652 .39283 L
s
.33714 .39299 m
.33652 .39283 L
s
.33635 .39173 m
.33713 .39186 L
s
.33713 .39186 m
.33714 .39299 L
s
1 .726 0 r
.0878 .40321 m
.09105 .4038 L
s
.08884 .40698 m
.09105 .4038 L
s
1 .27 0 r
.33574 .39271 m
.33635 .39173 L
s
.33714 .39299 m
.33574 .39271 L
s
1 .726 0 r
.0878 .40321 m
.08884 .40698 L
s
1 .27 0 r
.33635 .39173 m
.33714 .39299 L
s
1 .043 0 r
.6824 .71035 m
.6831 .71102 L
s
1 .056 0 r
.57801 .38429 m
.5791 .38479 L
s
1 .043 0 r
.68291 .71096 m
.68288 .71096 L
s
.68305 .71081 m
.68291 .71096 L
s
.6831 .71102 m
.68291 .71096 L
s
.68301 .71082 m
.68305 .71081 L
s
.68305 .71081 m
.6831 .71102 L
s
1 .056 0 r
.57888 .38481 m
.57879 .38481 L
s
.57898 .38457 m
.57888 .38481 L
s
.5791 .38479 m
.57888 .38481 L
s
1 .043 0 r
.6831 .71102 m
.68288 .71096 L
s
.68301 .71082 m
.6831 .71102 L
s
1 .056 0 r
.57888 .38457 m
.57898 .38457 L
s
.57898 .38457 m
.5791 .38479 L
s
1 .043 0 r
.68288 .71096 m
.68301 .71082 L
s
1 .056 0 r
.5791 .38479 m
.57879 .38481 L
s
.57888 .38457 m
.5791 .38479 L
s
.57879 .38481 m
.57888 .38457 L
s
1 .096 0 r
.34087 .81704 m
.34156 .81905 L
s
1 .329 0 r
.23634 .49053 m
.23848 .49641 L
s
1 .096 0 r
.34164 .81862 m
.34122 .81876 L
s
.34162 .81854 m
.34164 .81862 L
s
.34164 .81862 m
.34156 .81905 L
s
.34122 .81876 m
.3412 .81868 L
s
.34156 .81905 m
.34122 .81876 L
s
.34156 .81905 m
.3412 .81868 L
s
.34162 .81854 m
.34156 .81905 L
s
.3412 .81868 m
.34162 .81854 L
s
1 .329 0 r
.23785 .49584 m
.23706 .49537 L
s
.23904 .4951 m
.23785 .49584 L
s
.23848 .49641 m
.23785 .49584 L
s
.23825 .49462 m
.23904 .4951 L
s
.23904 .4951 m
.23848 .49641 L
s
.23706 .49537 m
.23825 .49462 L
s
.23848 .49641 m
.23706 .49537 L
s
1 .014 0 r
.82375 .37909 m
.82409 .37919 L
s
1 .018 0 r
.92843 .70606 m
.92881 .70631 L
s
.92871 .70629 m
.9287 .7063 L
s
.92876 .70621 m
.92871 .70629 L
s
.92881 .70631 m
.92871 .70629 L
s
1 .014 0 r
.82402 .3792 m
.82401 .37921 L
s
.82404 .37913 m
.82402 .3792 L
s
.82409 .37919 m
.82402 .3792 L
s
1 .018 0 r
.92875 .70622 m
.92876 .70621 L
s
.92876 .70621 m
.92881 .70631 L
s
1 .014 0 r
.82403 .37914 m
.82404 .37913 L
s
.82404 .37913 m
.82409 .37919 L
s
1 .018 0 r
.92881 .70631 m
.9287 .7063 L
s
.92875 .70622 m
.92881 .70631 L
s
1 .014 0 r
.82409 .37919 m
.82401 .37921 L
s
.82403 .37914 m
.82409 .37919 L
s
.82401 .37921 m
.82403 .37914 L
s
1 .018 0 r
.9287 .7063 m
.92875 .70622 L
s
1 .329 0 r
.23825 .49462 m
.23848 .49641 L
s
1 .108 0 r
.48147 .48562 m
.48317 .48708 L
s
1 .054 0 r
.58629 .81305 m
.58701 .81404 L
s
1 .074 0 r
.37664 .15819 m
.37794 .1581 L
s
1 .054 0 r
.58679 .81392 m
.58675 .81391 L
s
.58699 .81377 m
.58679 .81392 L
s
.58701 .81404 m
.58679 .81392 L
s
.58695 .81376 m
.58699 .81377 L
s
.58699 .81377 m
.58701 .81404 L
s
.58701 .81404 m
.58675 .81391 L
s
.58695 .81376 m
.58701 .81404 L
s
.58675 .81391 m
.58695 .81376 L
s
1 .108 0 r
.4828 .487 m
.48258 .48697 L
s
.48307 .48661 m
.4828 .487 L
s
.48317 .48708 m
.4828 .487 L
s
.48285 .48658 m
.48307 .48661 L
s
.48307 .48661 m
.48317 .48708 L
s
1 .074 0 r
.37781 .15827 m
.3776 .15831 L
s
.37777 .15793 m
.37781 .15827 L
s
.37794 .1581 m
.37781 .15827 L
s
.37756 .15796 m
.37777 .15793 L
s
.37777 .15793 m
.37794 .1581 L
s
.3776 .15831 m
.37756 .15796 L
s
.37794 .1581 m
.3776 .15831 L
s
1 .108 0 r
.48258 .48697 m
.48285 .48658 L
s
.48317 .48708 m
.48258 .48697 L
s
.48285 .48658 m
.48317 .48708 L
s
1 .074 0 r
.37756 .15796 m
.37794 .1581 L
s
1 .265 0 r
.13822 .59245 m
.13843 .59785 L
s
.1389 .59703 m
.1377 .597 L
s
.13908 .59654 m
.1389 .59703 L
s
.1389 .59703 m
.13843 .59785 L
s
.1377 .597 m
.13788 .59651 L
s
.13843 .59785 m
.1377 .597 L
s
.13788 .59651 m
.13908 .59654 L
s
.13908 .59654 m
.13843 .59785 L
s
.13843 .59785 m
.13788 .59651 L
s
1 .032 0 r
.72797 .48068 m
.72863 .48101 L
s
1 .026 0 r
.83309 .80903 m
.83356 .80945 L
s
1 .009 0 r
.62285 .15233 m
.62308 .15232 L
s
1 .026 0 r
.83344 .8094 m
.83342 .80941 L
s
.83352 .80931 m
.83344 .8094 L
s
.83356 .80945 m
.83344 .8094 L
s
1 .009 0 r
.62304 .15235 m
.62303 .15235 L
s
.62304 .1523 m
.62304 .15235 L
s
.62308 .15232 m
.62304 .15235 L
s
1 .026 0 r
.8335 .80932 m
.83352 .80931 L
s
.83352 .80931 m
.83356 .80945 L
s
1 .009 0 r
.62303 .1523 m
.62304 .1523 L
s
.62304 .1523 m
.62308 .15232 L
s
1 .032 0 r
.72848 .48101 m
.72844 .48101 L
s
.72855 .48087 m
.72848 .48101 L
s
.72863 .48101 m
.72848 .48101 L
s
1 .009 0 r
.62308 .15232 m
.62303 .15235 L
s
.62303 .1523 m
.62308 .15232 L
s
.62303 .15235 m
.62303 .1523 L
s
1 .032 0 r
.72851 .48088 m
.72855 .48087 L
s
.72855 .48087 m
.72863 .48101 L
s
1 .026 0 r
.83356 .80945 m
.83342 .80941 L
s
.8335 .80932 m
.83356 .80945 L
s
.83342 .80941 m
.8335 .80932 L
s
1 .032 0 r
.72863 .48101 m
.72844 .48101 L
s
.72851 .48088 m
.72863 .48101 L
s
.72844 .48101 m
.72851 .48088 L
s
1 .355 0 r
.27884 .25899 m
.28321 .26128 L
s
1 .146 0 r
.38411 .5878 m
.38574 .59036 L
s
.3853 .59011 m
.38502 .58999 L
s
.38581 .58971 m
.3853 .59011 L
s
.38574 .59036 m
.3853 .59011 L
s
.38552 .58959 m
.38581 .58971 L
s
.38581 .58971 m
.38574 .59036 L
s
.38502 .58999 m
.38552 .58959 L
s
.38574 .59036 m
.38502 .58999 L
s
.38552 .58959 m
.38574 .59036 L
s
1 .355 0 r
.28296 .26151 m
.28161 .26168 L
s
.28306 .25997 m
.28296 .26151 L
s
.28321 .26128 m
.28296 .26151 L
s
.2817 .26013 m
.28306 .25997 L
s
.28306 .25997 m
.28321 .26128 L
s
.28161 .26168 m
.2817 .26013 L
s
.28321 .26128 m
.28161 .26168 L
s
.2817 .26013 m
.28321 .26128 L
s
1 .055 0 r
.63138 .58313 m
.63233 .58389 L
s
1 .05 0 r
.52582 .25339 m
.52682 .25358 L
s
1 .055 0 r
.63211 .58384 m
.63203 .58384 L
s
.63226 .58364 m
.63211 .58384 L
s
.63233 .58389 m
.63211 .58384 L
s
.63218 .58363 m
.63226 .58364 L
s
.63226 .58364 m
.63233 .58389 L
s
1 .05 0 r
.52666 .25365 m
.52655 .25366 L
s
.52669 .25342 m
.52666 .25365 L
s
.52682 .25358 m
.52666 .25365 L
s
.52658 .25343 m
.52669 .25342 L
s
.52669 .25342 m
.52682 .25358 L
s
1 .055 0 r
.63233 .58389 m
.63203 .58384 L
s
.63218 .58363 m
.63233 .58389 L
s
.63203 .58384 m
.63218 .58363 L
s
1 .05 0 r
.52655 .25366 m
.52658 .25343 L
s
.52682 .25358 m
.52655 .25366 L
s
.52658 .25343 m
.52682 .25358 L
s
1 .571 0 r
.1802 .36065 m
.18269 .36851 L
s
1 .149 0 r
.28592 .69085 m
.28688 .69388 L
s
.28645 .69349 m
.2863 .6933 L
s
.28709 .69325 m
.28645 .69349 L
s
.28688 .69388 m
.28645 .69349 L
s
.28693 .69306 m
.28709 .69325 L
s
.28709 .69325 m
.28688 .69388 L
s
.28688 .69388 m
.2863 .6933 L
s
.28693 .69306 m
.28688 .69388 L
s
.2863 .6933 m
.28693 .69306 L
s
1 .02 0 r
.88006 .57843 m
.88049 .57866 L
s
1 .01 0 r
.7742 .24776 m
.77445 .24778 L
s
.7744 .24781 m
.77439 .24781 L
s
.77441 .24775 m
.7744 .24781 L
s
.77445 .24778 m
.7744 .24781 L
s
1 .02 0 r
.88039 .57865 m
.88038 .57866 L
s
.88044 .57857 m
.88039 .57865 L
s
.88049 .57866 m
.88039 .57865 L
s
1 .01 0 r
.7744 .24775 m
.77441 .24775 L
s
.77441 .24775 m
.77445 .24778 L
s
1 .02 0 r
.88042 .57857 m
.88044 .57857 L
s
.88044 .57857 m
.88049 .57866 L
s
1 .01 0 r
.77445 .24778 m
.77439 .24781 L
s
.7744 .24775 m
.77445 .24778 L
s
.77439 .24781 m
.7744 .24775 L
s
1 .02 0 r
.88049 .57866 m
.88038 .57866 L
s
.88042 .57857 m
.88049 .57866 L
s
.88038 .57866 m
.88042 .57857 L
s
1 .571 0 r
.18326 .36799 m
.18072 .36794 L
s
.18367 .36593 m
.18326 .36799 L
s
.18269 .36851 m
.18326 .36799 L
s
1 .075 0 r
.53397 .68645 m
.53501 .68774 L
s
1 .139 0 r
.42795 .35531 m
.43022 .35663 L
s
1 .571 0 r
.18072 .36794 m
.18112 .36588 L
s
.18269 .36851 m
.18072 .36794 L
s
1 .075 0 r
.53473 .68761 m
.53462 .68758 L
s
.53498 .68738 m
.53473 .68761 L
s
.53501 .68774 m
.53473 .68761 L
s
.53487 .68735 m
.53498 .68738 L
s
.53498 .68738 m
.53501 .68774 L
s
.53501 .68774 m
.53462 .68758 L
s
.53487 .68735 m
.53501 .68774 L
s
.53462 .68758 m
.53487 .68735 L
s
1 .571 0 r
.18112 .36588 m
.18367 .36593 L
s
.18367 .36593 m
.18269 .36851 L
s
1 .139 0 r
.42986 .35666 m
.42946 .35666 L
s
.43007 .35607 m
.42986 .35666 L
s
.43022 .35663 m
.42986 .35666 L
s
.42967 .35607 m
.43007 .35607 L
s
.43007 .35607 m
.43022 .35663 L
s
.42946 .35666 m
.42967 .35607 L
s
.43022 .35663 m
.42946 .35666 L
s
.42967 .35607 m
.43022 .35663 L
s
1 .571 0 r
.18112 .36588 m
.18269 .36851 L
s
1 .127 0 r
.1869 .79478 m
.18719 .79757 L
s
1 .439 0 r
.08073 .46317 m
.0796 .47098 L
s
1 .127 0 r
.18737 .79707 m
.18679 .79711 L
s
.18747 .79692 m
.18737 .79707 L
s
.18737 .79707 m
.18719 .79757 L
s
.18679 .79711 m
.18689 .79696 L
s
.18719 .79757 m
.18679 .79711 L
s
.18689 .79696 m
.18747 .79692 L
s
.18747 .79692 m
.18719 .79757 L
s
.18719 .79757 m
.18689 .79696 L
s
1 .032 0 r
.78343 .68203 m
.78403 .68248 L
s
1 .031 0 r
.67712 .34994 m
.67779 .35015 L
s
1 .032 0 r
.78388 .68245 m
.78385 .68246 L
s
.78397 .68233 m
.78388 .68245 L
s
.78403 .68248 m
.78388 .68245 L
s
.78394 .68233 m
.78397 .68233 L
s
.78397 .68233 m
.78403 .68248 L
s
1 .031 0 r
.67766 .35018 m
.67761 .35018 L
s
.6777 .35003 m
.67766 .35018 L
s
.67779 .35015 m
.67766 .35018 L
s
.67765 .35004 m
.6777 .35003 L
s
.6777 .35003 m
.67779 .35015 L
s
1 .032 0 r
.78403 .68248 m
.78385 .68246 L
s
.78394 .68233 m
.78403 .68248 L
s
.78385 .68246 m
.78394 .68233 L
s
1 .031 0 r
.67761 .35018 m
.67765 .35004 L
s
.67779 .35015 m
.67761 .35018 L
s
.67765 .35004 m
.67779 .35015 L
s
1 .439 0 r
.0807 .47018 m
.07868 .46983 L
s
.08097 .469 m
.0807 .47018 L
s
.0796 .47098 m
.0807 .47018 L
s
.07868 .46983 m
.07896 .46864 L
s
.07868 .46983 m
.0796 .47098 L
s
.07896 .46864 m
.08097 .469 L
s
.0796 .47098 m
.08097 .469 L
s
.07896 .46864 m
.0796 .47098 L
s
1 .084 0 r
.43573 .79066 m
.43658 .79233 L
s
1 .228 0 r
.32925 .4581 m
.33176 .4615 L
s
1 .084 0 r
.43629 .79212 m
.43619 .79207 L
s
.43663 .79193 m
.43629 .79212 L
s
.43658 .79233 m
.43629 .79212 L
s
.43653 .79188 m
.43663 .79193 L
s
.43663 .79193 m
.43658 .79233 L
s
.43658 .79233 m
.43619 .79207 L
s
.43653 .79188 m
.43658 .79233 L
s
.43619 .79207 m
.43653 .79188 L
s
1 .228 0 r
.33133 .46128 m
.33061 .46114 L
s
.3319 .4605 m
.33133 .46128 L
s
.33176 .4615 m
.33133 .46128 L
s
.33118 .46036 m
.3319 .4605 L
s
.3319 .4605 m
.33176 .4615 L
s
.33061 .46114 m
.33118 .46036 L
s
.33176 .4615 m
.33061 .46114 L
s
.33118 .46036 m
.33176 .4615 L
s
1 .067 0 r
.5792 .453 m
.58042 .45374 L
s
1 .043 0 r
.68598 .78651 m
.68666 .78725 L
s
1 .025 0 r
.47243 .11949 m
.47294 .11941 L
s
1 .043 0 r
.68647 .78717 m
.68643 .78717 L
s
.68662 .78703 m
.68647 .78717 L
s
.68666 .78725 m
.68647 .78717 L
s
.68657 .78703 m
.68662 .78703 L
s
.68662 .78703 m
.68666 .78725 L
s
1 .025 0 r
.47288 .11948 m
.47281 .11949 L
s
.47286 .11936 m
.47288 .11948 L
s
.47294 .11941 m
.47288 .11948 L
s
.47279 .11937 m
.47286 .11936 L
s
.47286 .11936 m
.47294 .11941 L
s
1 .043 0 r
.68666 .78725 m
.68643 .78717 L
s
.68657 .78703 m
.68666 .78725 L
s
.68643 .78717 m
.68657 .78703 L
s
1 .025 0 r
.47281 .11949 m
.47279 .11937 L
s
.47294 .11941 m
.47281 .11949 L
s
1 .067 0 r
.58018 .45373 m
.58004 .45373 L
s
.58031 .45345 m
.58018 .45373 L
s
.58042 .45374 m
.58018 .45373 L
s
1 .025 0 r
.47279 .11937 m
.47294 .11941 L
s
1 .067 0 r
.58017 .45345 m
.58031 .45345 L
s
.58031 .45345 m
.58042 .45374 L
s
.58004 .45373 m
.58017 .45345 L
s
.58042 .45374 m
.58004 .45373 L
s
.58017 .45345 m
.58042 .45374 L
s
1 .241 0 r
.22971 .56177 m
.23097 .5663 L
s
.23057 .56583 m
.22997 .56546 L
s
.23148 .56532 m
.23057 .56583 L
s
.23097 .5663 m
.23057 .56583 L
s
.23087 .56495 m
.23148 .56532 L
s
.23148 .56532 m
.23097 .5663 L
s
.22997 .56546 m
.23087 .56495 L
s
.23097 .5663 m
.22997 .56546 L
s
.23087 .56495 m
.23097 .5663 L
s
1 .02 0 r
.83058 .44788 m
.83104 .44805 L
s
.93766 .78234 m
.93807 .78264 L
s
1 .004 0 r
.7235 .11341 m
.72362 .1134 L
s
.7236 .11341 m
.7236 .11341 L
s
.7236 .11339 m
.7236 .11341 L
s
.72362 .1134 m
.7236 .11341 L
s
.7236 .11339 m
.7236 .11339 L
s
.7236 .11339 m
.72362 .1134 L
s
1 .02 0 r
.93797 .78262 m
.93795 .78263 L
s
.93802 .78254 m
.93797 .78262 L
s
.93807 .78264 m
.93797 .78262 L
s
1 .004 0 r
.72362 .1134 m
.7236 .11341 L
s
.7236 .11339 m
.72362 .1134 L
s
.7236 .11341 m
.7236 .11339 L
s
1 .02 0 r
.93801 .78255 m
.93802 .78254 L
s
.93802 .78254 m
.93807 .78264 L
s
.83095 .44806 m
.83092 .44807 L
s
.83098 .44797 m
.83095 .44806 L
s
.83104 .44805 m
.83095 .44806 L
s
.83096 .44797 m
.83098 .44797 L
s
.83098 .44797 m
.83104 .44805 L
s
.93807 .78264 m
.93795 .78263 L
s
.93801 .78255 m
.93807 .78264 L
s
.93795 .78263 m
.93801 .78255 L
s
.83104 .44805 m
.83092 .44807 L
s
.83096 .44797 m
.83104 .44805 L
s
.83092 .44807 m
.83096 .44797 L
s
1 .133 0 r
.37321 .22201 m
.37533 .22239 L
s
1 .104 0 r
.48045 .55695 m
.48194 .55854 L
s
.48162 .55842 m
.48138 .55838 L
s
.48191 .55806 m
.48162 .55842 L
s
.48194 .55854 m
.48162 .55842 L
s
.48167 .55802 m
.48191 .55806 L
s
.48191 .55806 m
.48194 .55854 L
s
.48138 .55838 m
.48167 .55802 L
s
.48194 .55854 m
.48138 .55838 L
s
.48167 .55802 m
.48194 .55854 L
s
1 .133 0 r
.37514 .22258 m
.37468 .22266 L
s
.37513 .22196 m
.37514 .22258 L
s
.37533 .22239 m
.37514 .22258 L
s
.37468 .22204 m
.37513 .22196 L
s
.37513 .22196 m
.37533 .22239 L
s
.37468 .22266 m
.37468 .22204 L
s
.37533 .22239 m
.37468 .22266 L
s
.37468 .22204 m
.37533 .22239 L
s
1 .195 0 r
.1293 .66634 m
.12936 .67043 L
s
.12974 .66981 m
.12883 .66977 L
s
.12987 .66944 m
.12974 .66981 L
s
.12974 .66981 m
.12936 .67043 L
s
.12883 .66977 m
.12897 .66941 L
s
.12936 .67043 m
.12883 .66977 L
s
.12897 .66941 m
.12987 .66944 L
s
.12987 .66944 m
.12936 .67043 L
s
.12936 .67043 m
.12897 .66941 L
s
1 .037 0 r
.73263 .5521 m
.73336 .55255 L
s
1 .024 0 r
.62509 .21619 m
.62561 .21623 L
s
1 .037 0 r
.7332 .55254 m
.73314 .55254 L
s
.73328 .55238 m
.7332 .55254 L
s
.73336 .55255 m
.7332 .55254 L
s
1 .024 0 r
.62553 .21628 m
.62548 .21629 L
s
.62553 .21616 m
.62553 .21628 L
s
.62561 .21623 m
.62553 .21628 L
s
.62548 .21617 m
.62553 .21616 L
s
.62553 .21616 m
.62561 .21623 L
s
1 .037 0 r
.73323 .55239 m
.73328 .55238 L
s
.73328 .55238 m
.73336 .55255 L
s
1 .024 0 r
.62548 .21629 m
.62548 .21617 L
s
.62561 .21623 m
.62548 .21629 L
s
.62548 .21617 m
.62561 .21623 L
s
1 .037 0 r
.73336 .55255 m
.73314 .55254 L
s
.73323 .55239 m
.73336 .55255 L
s
.73314 .55254 m
.73323 .55239 L
s
1 .318 0 r
.27314 .32541 m
.27631 .32852 L
s
1 .124 0 r
.38084 .6618 m
.38208 .66412 L
s
.38173 .66387 m
.38147 .66377 L
s
.38219 .66355 m
.38173 .66387 L
s
.38208 .66412 m
.38173 .66387 L
s
.38193 .66344 m
.38219 .66355 L
s
.38219 .66355 m
.38208 .66412 L
s
.38147 .66377 m
.38193 .66344 L
s
.38208 .66412 m
.38147 .66377 L
s
.38193 .66344 m
.38208 .66412 L
s
1 .318 0 r
.27625 .32851 m
.27493 .32862 L
s
.27642 .32717 m
.27625 .32851 L
s
.27631 .32852 m
.27625 .32851 L
s
.2751 .32729 m
.27642 .32717 L
s
.27642 .32717 m
.27631 .32852 L
s
.27493 .32862 m
.2751 .32729 L
s
.27631 .32852 m
.27493 .32862 L
s
.2751 .32729 m
.27631 .32852 L
s
1 .055 0 r
.63383 .65723 m
.63474 .65809 L
s
1 .071 0 r
.52582 .31987 m
.52715 .32034 L
s
1 .055 0 r
.63452 .65802 m
.63443 .65802 L
s
.63469 .65782 m
.63452 .65802 L
s
.63474 .65809 m
.63452 .65802 L
s
.63459 .65782 m
.63469 .65782 L
s
.63469 .65782 m
.63474 .65809 L
s
.63474 .65809 m
.63443 .65802 L
s
.63459 .65782 m
.63474 .65809 L
s
.63443 .65802 m
.63459 .65782 L
s
1 .071 0 r
.52694 .3204 m
.52675 .32041 L
s
.52701 .32007 m
.52694 .3204 L
s
.52715 .32034 m
.52694 .3204 L
s
.52682 .32009 m
.52701 .32007 L
s
.52701 .32007 m
.52715 .32034 L
s
.52675 .32041 m
.52682 .32009 L
s
.52715 .32034 m
.52675 .32041 L
s
.52682 .32009 m
.52715 .32034 L
s
1 .378 0 r
.1722 .4297 m
.17335 .43554 L
s
1 .121 0 r
.28036 .76756 m
.28105 .77011 L
s
.28071 .76977 m
.28058 .76961 L
s
.28125 .76959 m
.28071 .76977 L
s
.28105 .77011 m
.28071 .76977 L
s
.28111 .76944 m
.28125 .76959 L
s
.28125 .76959 m
.28105 .77011 L
s
.28105 .77011 m
.28058 .76961 L
s
.28111 .76944 m
.28105 .77011 L
s
.28058 .76961 m
.28111 .76944 L
s
1 .018 0 r
.77996 .31429 m
.78038 .31438 L
s
1 .023 0 r
.88828 .65264 m
.88876 .65294 L
s
.88865 .65292 m
.88863 .65293 L
s
.88871 .65283 m
.88865 .65292 L
s
.88876 .65294 m
.88865 .65292 L
s
1 .018 0 r
.7803 .31441 m
.78027 .31441 L
s
.78032 .31432 m
.7803 .31441 L
s
.78038 .31438 m
.7803 .31441 L
s
1 .023 0 r
.88868 .65284 m
.88871 .65283 L
s
.88871 .65283 m
.88876 .65294 L
s
1 .018 0 r
.78029 .31432 m
.78032 .31432 L
s
.78032 .31432 m
.78038 .31438 L
s
1 .023 0 r
.88876 .65294 m
.88863 .65293 L
s
.88868 .65284 m
.88876 .65294 L
s
1 .018 0 r
.78027 .31441 m
.78029 .31432 L
s
.78038 .31438 m
.78027 .31441 L
s
.78029 .31432 m
.78038 .31438 L
s
1 .023 0 r
.88863 .65293 m
.88868 .65284 L
s
1 .378 0 r
.17385 .43506 m
.17211 .43499 L
s
.17414 .43375 m
.17385 .43506 L
s
.17335 .43554 m
.17385 .43506 L
s
.17211 .43499 m
.17239 .43368 L
s
.17335 .43554 m
.17211 .43499 L
s
.17239 .43368 m
.17414 .43375 L
s
.17414 .43375 m
.17335 .43554 L
s
.17239 .43368 m
.17335 .43554 L
s
1 .069 0 r
.53416 .76328 m
.53506 .76456 L
s
1 .139 0 r
.42568 .42444 m
.4277 .42609 L
s
1 .069 0 r
.53481 .76442 m
.5347 .76439 L
s
.53506 .76421 m
.53481 .76442 L
s
.53506 .76456 m
.53481 .76442 L
s
.53495 .76419 m
.53506 .76421 L
s
.53506 .76421 m
.53506 .76456 L
s
.53506 .76456 m
.5347 .76439 L
s
.53495 .76419 m
.53506 .76456 L
s
.5347 .76439 m
.53495 .76419 L
s
1 .139 0 r
.42739 .42605 m
.42695 .42604 L
s
.42765 .42549 m
.42739 .42605 L
s
.4277 .42609 m
.42739 .42605 L
s
.4272 .42547 m
.42765 .42549 L
s
.42765 .42549 m
.4277 .42609 L
s
.42695 .42604 m
.4272 .42547 L
s
.4277 .42609 m
.42695 .42604 L
s
.4272 .42547 m
.4277 .42609 L
s
1 .293 0 r
.07037 .53491 m
.06958 .54038 L
s
.07034 .53979 m
.06896 .53956 L
s
.07052 .53901 m
.07034 .53979 L
s
.06958 .54038 m
.07034 .53979 L
s
.06896 .53956 m
.06914 .53878 L
s
.06896 .53956 m
.06958 .54038 L
s
1 .033 0 r
.78944 .75897 m
.79004 .7595 L
s
1 .04 0 r
.68064 .41915 m
.68147 .41951 L
s
1 .01 0 r
.57184 .07933 m
.57208 .07928 L
s
.57205 .07931 m
.57202 .07932 L
s
.57204 .07926 m
.57205 .07931 L
s
.57208 .07928 m
.57205 .07931 L
s
.57201 .07926 m
.57204 .07926 L
s
.57204 .07926 m
.57208 .07928 L
s
1 .033 0 r
.78989 .75945 m
.78985 .75946 L
s
.78999 .75933 m
.78989 .75945 L
s
.79004 .7595 m
.78989 .75945 L
s
1 .01 0 r
.57202 .07932 m
.57201 .07926 L
s
.57208 .07928 m
.57202 .07932 L
s
1 .033 0 r
.78995 .75934 m
.78999 .75933 L
s
.78999 .75933 m
.79004 .7595 L
s
1 .01 0 r
.57201 .07926 m
.57208 .07928 L
s
1 .04 0 r
.68131 .41952 m
.68123 .41953 L
s
.68137 .41934 m
.68131 .41952 L
s
.68147 .41951 m
.68131 .41952 L
s
1 .293 0 r
.06914 .53878 m
.07052 .53901 L
s
.06958 .54038 m
.07052 .53901 L
s
1 .033 0 r
.79004 .7595 m
.78985 .75946 L
s
.78995 .75934 m
.79004 .7595 L
s
.78985 .75946 m
.78995 .75934 L
s
1 .04 0 r
.68129 .41935 m
.68137 .41934 L
s
.68137 .41934 m
.68147 .41951 L
s
.68123 .41953 m
.68129 .41935 L
s
.68147 .41951 m
.68123 .41953 L
s
.68129 .41935 m
.68147 .41951 L
s
1 .293 0 r
.06914 .53878 m
.06958 .54038 L
s
1 .185 0 r
.32467 .52993 m
.32642 .53298 L
s
.32613 .53273 m
.32551 .5326 L
s
.32663 .53213 m
.32613 .53273 L
s
.32642 .53298 m
.32613 .53273 L
s
.326 .532 m
.32663 .53213 L
s
.32663 .53213 m
.32642 .53298 L
s
.32551 .5326 m
.326 .532 L
s
.32642 .53298 m
.32551 .5326 L
s
.326 .532 m
.32642 .53298 L
s
1 .056 0 r
.47118 .18361 m
.4722 .18363 L
s
1 .07 0 r
.58045 .52493 m
.58165 .52583 L
s
.58141 .52579 m
.58124 .52579 L
s
.58157 .52551 m
.58141 .52579 L
s
.58165 .52583 m
.58141 .52579 L
s
.5814 .52551 m
.58157 .52551 L
s
.58157 .52551 m
.58165 .52583 L
s
1 .056 0 r
.47209 .18375 m
.47192 .18378 L
s
.47207 .18348 m
.47209 .18375 L
s
.4722 .18363 m
.47209 .18375 L
s
.4719 .18351 m
.47207 .18348 L
s
.47207 .18348 m
.4722 .18363 L
s
1 .07 0 r
.58124 .52579 m
.5814 .52551 L
s
.58165 .52583 m
.58124 .52579 L
s
1 .056 0 r
.47192 .18378 m
.4719 .18351 L
s
.4722 .18363 m
.47192 .18378 L
s
1 .07 0 r
.5814 .52551 m
.58165 .52583 L
s
1 .056 0 r
.4719 .18351 m
.4722 .18363 L
s
1 .181 0 r
.22277 .63635 m
.22356 .63993 L
s
.22329 .63954 m
.22281 .63926 L
s
.22399 .63918 m
.22329 .63954 L
s
.22356 .63993 m
.22329 .63954 L
s
.22351 .63889 m
.22399 .63918 L
s
.22399 .63918 m
.22356 .63993 L
s
.22281 .63926 m
.22351 .63889 L
s
.22356 .63993 m
.22281 .63926 L
s
.22351 .63889 m
.22356 .63993 L
s
1 .025 0 r
.83774 .51989 m
.83828 .52015 L
s
1 .012 0 r
.72814 .17758 m
.72844 .17758 L
s
.72839 .17761 m
.72837 .17761 L
s
.72839 .17754 m
.72839 .17761 L
s
.72844 .17758 m
.72839 .17761 L
s
.72837 .17755 m
.72839 .17754 L
s
.72839 .17754 m
.72844 .17758 L
s
1 .025 0 r
.83817 .52015 m
.83813 .52016 L
s
.83822 .52004 m
.83817 .52015 L
s
.83828 .52015 m
.83817 .52015 L
s
.83818 .52005 m
.83822 .52004 L
s
.83822 .52004 m
.83828 .52015 L
s
1 .012 0 r
.72837 .17761 m
.72837 .17755 L
s
.72844 .17758 m
.72837 .17761 L
s
.72837 .17755 m
.72844 .17758 L
s
1 .025 0 r
.83813 .52016 m
.83818 .52005 L
s
.83828 .52015 m
.83813 .52016 L
s
.83818 .52005 m
.83828 .52015 L
s
1 .156 0 r
.36963 .28882 m
.37182 .28981 L
s
1 .095 0 r
.47938 .63164 m
.48063 .63323 L
s
.48036 .63309 m
.48012 .63305 L
s
.48065 .63277 m
.48036 .63309 L
s
.48063 .63323 m
.48036 .63309 L
s
.48041 .63273 m
.48065 .63277 L
s
.48065 .63277 m
.48063 .63323 L
s
.48012 .63305 m
.48041 .63273 L
s
.48063 .63323 m
.48012 .63305 L
s
.48041 .63273 m
.48063 .63323 L
s
1 .156 0 r
.37165 .28992 m
.37106 .29001 L
s
.3717 .28921 m
.37165 .28992 L
s
.37182 .28981 m
.37165 .28992 L
s
.37111 .2893 m
.3717 .28921 L
s
.3717 .28921 m
.37182 .28981 L
s
.37106 .29001 m
.37111 .2893 L
s
.37182 .28981 m
.37106 .29001 L
s
.37111 .2893 m
.37182 .28981 L
s
1 .148 0 r
.11997 .74371 m
.11996 .74693 L
s
.12027 .74644 m
.11956 .74641 L
s
.12037 .74616 m
.12027 .74644 L
s
.12027 .74644 m
.11996 .74693 L
s
.11956 .74641 m
.11966 .74613 L
s
.11996 .74693 m
.11956 .74641 L
s
.11966 .74613 m
.12037 .74616 L
s
.12037 .74616 m
.11996 .74693 L
s
.11996 .74693 m
.11966 .74613 L
s
1 .038 0 r
.62743 .28306 m
.62821 .28323 L
s
1 .04 0 r
.73751 .62689 m
.73826 .62744 L
s
.73809 .62741 m
.73802 .62742 L
s
.73819 .62725 m
.73809 .62741 L
s
.73826 .62744 m
.73809 .62741 L
s
.73812 .62726 m
.73819 .62725 L
s
.73819 .62725 m
.73826 .62744 L
s
1 .038 0 r
.62809 .28328 m
.628 .28329 L
s
.62811 .2831 m
.62809 .28328 L
s
.62821 .28323 m
.62809 .28328 L
s
.62802 .28311 m
.62811 .2831 L
s
.62811 .2831 m
.62821 .28323 L
s
1 .04 0 r
.73802 .62742 m
.73812 .62726 L
s
.73826 .62744 m
.73802 .62742 L
s
.73812 .62726 m
.73826 .62744 L
s
1 .038 0 r
.628 .28329 m
.62802 .28311 L
s
.62821 .28323 m
.628 .28329 L
s
.62802 .28311 m
.62821 .28323 L
s
1 .105 0 r
.37742 .73929 m
.37836 .74137 L
s
1 .256 0 r
.26717 .39495 m
.26927 .3981 L
s
1 .105 0 r
.37809 .74113 m
.37785 .74104 L
s
.37849 .74087 m
.37809 .74113 L
s
.37836 .74137 m
.37809 .74113 L
s
.37825 .74078 m
.37849 .74087 L
s
.37849 .74087 m
.37836 .74137 L
s
.37785 .74104 m
.37825 .74078 L
s
.37836 .74137 m
.37785 .74104 L
s
.37825 .74078 m
.37836 .74137 L
s
1 .256 0 r
.26933 .39796 m
.2682 .39802 L
s
.26951 .39692 m
.26933 .39796 L
s
.26927 .3981 m
.26933 .39796 L
s
.2682 .39802 m
.26837 .39699 L
s
.26927 .3981 m
.2682 .39802 L
s
.26837 .39699 m
.26951 .39692 L
s
.26951 .39692 m
.26927 .3981 L
s
.26837 .39699 m
.26927 .3981 L
s
1 .054 0 r
.63638 .73484 m
.63723 .73576 L
s
1 .081 0 r
.52582 .38949 m
.52723 .39023 L
s
1 .054 0 r
.63702 .73567 m
.63692 .73567 L
s
.63719 .73549 m
.63702 .73567 L
s
.63723 .73576 m
.63702 .73567 L
s
.63709 .73548 m
.63719 .73549 L
s
.63719 .73549 m
.63723 .73576 L
s
.63692 .73567 m
.63709 .73548 L
s
.63723 .73576 m
.63692 .73567 L
s
.63709 .73548 m
.63723 .73576 L
s
1 .081 0 r
.52701 .39025 m
.52677 .39027 L
s
.52712 .38989 m
.52701 .39025 L
s
.52723 .39023 m
.52701 .39025 L
s
.52687 .38991 m
.52712 .38989 L
s
.52712 .38989 m
.52723 .39023 L
s
.52677 .39027 m
.52687 .38991 L
s
.52723 .39023 m
.52677 .39027 L
s
.52687 .38991 m
.52723 .39023 L
s
1 .265 0 r
.16381 .50203 m
.16439 .5065 L
s
.1648 .50608 m
.16354 .50601 L
s
.165 .50519 m
.1648 .50608 L
s
.16439 .5065 m
.1648 .50608 L
s
.16354 .50601 m
.16375 .50513 L
s
.16439 .5065 m
.16354 .50601 L
s
1 .025 0 r
.89689 .73037 m
.8974 .73074 L
s
.78599 .38399 m
.78655 .38417 L
s
1 .004 0 r
.6751 .03761 m
.67522 .03758 L
s
.67521 .0376 m
.67519 .0376 L
s
.6752 .03757 m
.67521 .0376 L
s
.67522 .03758 m
.67521 .0376 L
s
.67519 .03757 m
.6752 .03757 L
s
.6752 .03757 m
.67522 .03758 L
s
.67519 .0376 m
.67519 .03757 L
s
.67522 .03758 m
.67519 .0376 L
s
.67519 .03757 m
.67522 .03758 L
s
1 .025 0 r
.89728 .73071 m
.89725 .73072 L
s
.89735 .73061 m
.89728 .73071 L
s
.8974 .73074 m
.89728 .73071 L
s
1 .265 0 r
.16375 .50513 m
.165 .50519 L
s
.165 .50519 m
.16439 .5065 L
s
1 .025 0 r
.89732 .73062 m
.89735 .73061 L
s
.89735 .73061 m
.8974 .73074 L
s
.78645 .38419 m
.7864 .3842 L
s
.78648 .38407 m
.78645 .38419 L
s
.78655 .38417 m
.78645 .38419 L
s
.78643 .38408 m
.78648 .38407 L
s
.78648 .38407 m
.78655 .38417 L
s
.8974 .73074 m
.89725 .73072 L
s
.89732 .73062 m
.8974 .73074 L
s
.89725 .73072 m
.89732 .73062 L
s
.7864 .3842 m
.78643 .38408 L
s
.78655 .38417 m
.7864 .3842 L
s
.78643 .38408 m
.78655 .38417 L
s
1 .265 0 r
.16375 .50513 m
.16439 .5065 L
s
1 .127 0 r
.4233 .49686 m
.42496 .49863 L
s
.42472 .49853 m
.42428 .49851 L
s
.42498 .49804 m
.42472 .49853 L
s
.42496 .49863 m
.42472 .49853 L
s
.42454 .49802 m
.42498 .49804 L
s
.42498 .49804 m
.42496 .49863 L
s
.42428 .49851 m
.42454 .49802 L
s
.42496 .49863 m
.42428 .49851 L
s
.42454 .49802 m
.42496 .49863 L
s
1 .209 0 r
.05953 .61007 m
.05893 .61417 L
s
.05949 .61371 m
.05848 .61354 L
s
.05962 .61316 m
.05949 .61371 L
s
.05893 .61417 m
.05949 .61371 L
s
.05848 .61354 m
.05861 .613 L
s
.05848 .61354 m
.05893 .61417 L
s
.05861 .613 m
.05962 .61316 L
s
.05893 .61417 m
.05962 .61316 L
s
.05861 .613 m
.05893 .61417 L
s
1 .046 0 r
.68433 .49166 m
.68523 .49216 L
s
1 .026 0 r
.57294 .14373 m
.57347 .14369 L
s
.57341 .14376 m
.57334 .14377 L
s
.5734 .14363 m
.57341 .14376 L
s
.57347 .14369 m
.57341 .14376 L
s
.57333 .14364 m
.5734 .14363 L
s
.5734 .14363 m
.57347 .14369 L
s
1 .046 0 r
.68506 .49216 m
.68495 .49217 L
s
.68514 .49196 m
.68506 .49216 L
s
.68523 .49216 m
.68506 .49216 L
s
1 .026 0 r
.57334 .14377 m
.57333 .14364 L
s
.57347 .14369 m
.57334 .14377 L
s
1 .046 0 r
.68504 .49196 m
.68514 .49196 L
s
.68514 .49196 m
.68523 .49216 L
s
1 .026 0 r
.57333 .14364 m
.57347 .14369 L
s
1 .046 0 r
.68495 .49217 m
.68504 .49196 L
s
.68523 .49216 m
.68495 .49217 L
s
.68504 .49196 m
.68523 .49216 L
s
1 .149 0 r
.31986 .6052 m
.32109 .60786 L
s
.3209 .60762 m
.32037 .6075 L
s
.32132 .60715 m
.3209 .60762 L
s
.32109 .60786 m
.3209 .60762 L
s
.32079 .60704 m
.32132 .60715 L
s
.32132 .60715 m
.32109 .60786 L
s
.32037 .6075 m
.32079 .60704 L
s
.32109 .60786 m
.32037 .6075 L
s
.32079 .60704 m
.32109 .60786 L
s
1 .068 0 r
.58176 .6003 m
.58286 .60131 L
s
1 .077 0 r
.46987 .25081 m
.47119 .25108 L
s
1 .068 0 r
.58264 .60124 m
.58246 .60124 L
s
.58282 .60098 m
.58264 .60124 L
s
.58286 .60131 m
.58264 .60124 L
s
.58264 .60097 m
.58282 .60098 L
s
.58282 .60098 m
.58286 .60131 L
s
.58246 .60124 m
.58264 .60097 L
s
.58286 .60131 m
.58246 .60124 L
s
.58264 .60097 m
.58286 .60131 L
s
1 .077 0 r
.47105 .25119 m
.47079 .25124 L
s
.47106 .25082 m
.47105 .25119 L
s
.47119 .25108 m
.47105 .25119 L
s
.47079 .25087 m
.47106 .25082 L
s
.47106 .25082 m
.47119 .25108 L
s
.47079 .25124 m
.47079 .25087 L
s
.47119 .25108 m
.47079 .25124 L
s
.47079 .25087 m
.47119 .25108 L
s
1 .141 0 r
.2155 .71451 m
.216 .71743 L
s
.21582 .71709 m
.21543 .71687 L
s
.21638 .71682 m
.21582 .71709 L
s
.216 .71743 m
.21582 .71709 L
s
.21599 .7166 m
.21638 .71682 L
s
.21638 .71682 m
.216 .71743 L
s
.21543 .71687 m
.21599 .7166 L
s
.216 .71743 m
.21543 .71687 L
s
.21599 .7166 m
.216 .71743 L
s
1 .028 0 r
.84523 .59537 m
.84583 .59571 L
s
1 .021 0 r
.73301 .24483 m
.73348 .24488 L
s
1 .028 0 r
.8457 .5957 m
.84566 .59571 L
s
.84577 .59558 m
.8457 .5957 L
s
.84583 .59571 m
.8457 .5957 L
s
1 .021 0 r
.73341 .24492 m
.73336 .24493 L
s
.73342 .24481 m
.73341 .24492 L
s
.73348 .24488 m
.73341 .24492 L
s
1 .028 0 r
.84572 .59559 m
.84577 .59558 L
s
.84577 .59558 m
.84583 .59571 L
s
1 .021 0 r
.73337 .24482 m
.73342 .24481 L
s
.73342 .24481 m
.73348 .24488 L
s
.73336 .24493 m
.73337 .24482 L
s
.73348 .24488 m
.73336 .24493 L
s
.73337 .24482 m
.73348 .24488 L
s
1 .028 0 r
.84566 .59571 m
.84572 .59559 L
s
.84583 .59571 m
.84566 .59571 L
s
.84572 .59559 m
.84583 .59571 L
s
1 .084 0 r
.47826 .70992 m
.47929 .71145 L
s
1 .152 0 r
.36587 .35885 m
.36775 .36025 L
s
1 .084 0 r
.47906 .7113 m
.47883 .71126 L
s
.47934 .71103 m
.47906 .7113 L
s
.47929 .71145 m
.47906 .7113 L
s
.47911 .71099 m
.47934 .71103 L
s
.47934 .71103 m
.47929 .71145 L
s
.47883 .71126 m
.47911 .71099 L
s
.47929 .71145 m
.47883 .71126 L
s
.47911 .71099 m
.47929 .71145 L
s
1 .152 0 r
.36765 .36027 m
.36702 .36035 L
s
.36773 .35959 m
.36765 .36027 L
s
.36775 .36025 m
.36765 .36027 L
s
.3671 .35967 m
.36773 .35959 L
s
.36773 .35959 m
.36775 .36025 L
s
.36702 .36035 m
.3671 .35967 L
s
.36775 .36025 m
.36702 .36035 L
s
.3671 .35967 m
.36775 .36025 L
s
1 .04 0 r
.74262 .70529 m
.74335 .70592 L
s
1 .047 0 r
.62988 .35317 m
.63082 .35349 L
s
1 .04 0 r
.74319 .70587 m
.74311 .70588 L
s
.7433 .70571 m
.74319 .70587 L
s
.74335 .70592 m
.74319 .70587 L
s
.74322 .70572 m
.7433 .70571 L
s
.7433 .70571 m
.74335 .70592 L
s
1 .047 0 r
.63067 .35353 m
.63054 .35355 L
s
.63072 .3533 m
.63067 .35353 L
s
.63082 .35349 m
.63067 .35353 L
s
1 .04 0 r
.74311 .70588 m
.74322 .70572 L
s
.74335 .70592 m
.74311 .70588 L
s
.74322 .70572 m
.74335 .70592 L
s
1 .047 0 r
.63059 .35332 m
.63072 .3533 L
s
.63072 .3533 m
.63082 .35349 L
s
.63054 .35355 m
.63059 .35332 L
s
.63082 .35349 m
.63054 .35355 L
s
.63059 .35332 m
.63082 .35349 L
s
1 .201 0 r
.26092 .46787 m
.2623 .47075 L
s
.26241 .47055 m
.26148 .47059 L
s
.26257 .46976 m
.26241 .47055 L
s
.2623 .47075 m
.26241 .47055 L
s
.26148 .47059 m
.26164 .4698 L
s
.2623 .47075 m
.26148 .47059 L
s
.26164 .4698 m
.26257 .46976 L
s
.26257 .46976 m
.2623 .47075 L
s
.26164 .4698 m
.2623 .47075 L
s
1 .082 0 r
.52582 .46249 m
.52715 .46343 L
s
.52695 .46341 m
.52668 .46343 L
s
.52708 .46306 m
.52695 .46341 L
s
.52715 .46343 m
.52695 .46341 L
s
.52681 .46307 m
.52708 .46306 L
s
.52708 .46306 m
.52715 .46343 L
s
.52668 .46343 m
.52681 .46307 L
s
.52715 .46343 m
.52668 .46343 L
s
.52681 .46307 m
.52715 .46343 L
s
1 .195 0 r
.15502 .57788 m
.15531 .58142 L
s
.15565 .58105 m
.1547 .58099 L
s
.15581 .58042 m
.15565 .58105 L
s
.15531 .58142 m
.15565 .58105 L
s
.1547 .58099 m
.15485 .58036 L
s
.15531 .58142 m
.1547 .58099 L
s
.15485 .58036 m
.15581 .58042 L
s
.15581 .58042 m
.15531 .58142 L
s
.15485 .58036 m
.15531 .58142 L
s
1 .03 0 r
.79232 .45708 m
.79297 .45735 L
s
1 .013 0 r
.67873 .10227 m
.67903 .10223 L
s
.67899 .10227 m
.67896 .10228 L
s
.67898 .1022 m
.67899 .10227 L
s
.67903 .10223 m
.67899 .10227 L
s
.67895 .10221 m
.67898 .1022 L
s
.67898 .1022 m
.67903 .10223 L
s
.67896 .10228 m
.67895 .10221 L
s
.67903 .10223 m
.67896 .10228 L
s
.67895 .10221 m
.67903 .10223 L
s
1 .03 0 r
.79285 .45736 m
.79279 .45737 L
s
.7929 .45722 m
.79285 .45736 L
s
.79297 .45735 m
.79285 .45736 L
s
.79283 .45723 m
.7929 .45722 L
s
.7929 .45722 m
.79297 .45735 L
s
.79279 .45737 m
.79283 .45723 L
s
.79297 .45735 m
.79279 .45737 L
s
.79283 .45723 m
.79297 .45735 L
s
1 .111 0 r
.4208 .57281 m
.42212 .57456 L
s
.42194 .57443 m
.42153 .57441 L
s
.42219 .57401 m
.42194 .57443 L
s
.42212 .57456 m
.42194 .57443 L
s
.42177 .57399 m
.42219 .57401 L
s
.42219 .57401 m
.42212 .57456 L
s
.42153 .57441 m
.42177 .57399 L
s
.42212 .57456 m
.42153 .57441 L
s
.42177 .57399 m
.42212 .57456 L
s
1 .157 0 r
.04815 .6889 m
.04768 .69213 L
s
.04812 .69174 m
.04734 .69162 L
s
.04821 .69134 m
.04812 .69174 L
s
.04768 .69213 m
.04812 .69174 L
s
.04734 .69162 m
.04743 .69122 L
s
.04734 .69162 m
.04768 .69213 L
s
.04743 .69122 m
.04821 .69134 L
s
.04768 .69213 m
.04821 .69134 L
s
.04743 .69122 m
.04768 .69213 L
s
1 .048 0 r
.68821 .56772 m
.6891 .56833 L
s
1 .04 0 r
.5741 .21128 m
.57488 .21134 L
s
1 .048 0 r
.68893 .56831 m
.68881 .56831 L
s
.68903 .5681 m
.68893 .56831 L
s
.6891 .56833 m
.68893 .56831 L
s
.68891 .56811 m
.68903 .5681 L
s
.68903 .5681 m
.6891 .56833 L
s
1 .04 0 r
.57479 .21142 m
.57466 .21145 L
s
.57478 .21122 m
.57479 .21142 L
s
.57488 .21134 m
.57479 .21142 L
s
.57466 .21124 m
.57478 .21122 L
s
.57478 .21122 m
.57488 .21134 L
s
1 .048 0 r
.68881 .56831 m
.68891 .56811 L
s
.6891 .56833 m
.68881 .56831 L
s
1 .04 0 r
.57466 .21145 m
.57466 .21124 L
s
.57488 .21134 m
.57466 .21145 L
s
1 .048 0 r
.68891 .56811 m
.6891 .56833 L
s
1 .04 0 r
.57466 .21124 m
.57488 .21134 L
s
1 .121 0 r
.31482 .68415 m
.31571 .68647 L
s
.31557 .68623 m
.31513 .68614 L
s
.31593 .68587 m
.31557 .68623 L
s
.31571 .68647 m
.31557 .68623 L
s
.31548 .68578 m
.31593 .68587 L
s
.31593 .68587 m
.31571 .68647 L
s
.31513 .68614 m
.31548 .68578 L
s
.31571 .68647 m
.31513 .68614 L
s
.31548 .68578 m
.31571 .68647 L
s
1 .064 0 r
.58314 .67937 m
.58411 .68043 L
s
1 .087 0 r
.4685 .3213 m
.46986 .32187 L
s
1 .064 0 r
.58392 .68034 m
.58373 .68033 L
s
.58409 .6801 m
.58392 .68034 L
s
.58411 .68043 m
.58392 .68034 L
s
.58391 .68009 m
.58409 .6801 L
s
.58409 .6801 m
.58411 .68043 L
s
.58373 .68033 m
.58391 .68009 L
s
.58411 .68043 m
.58373 .68033 L
s
.58391 .68009 m
.58411 .68043 L
s
1 .087 0 r
.46974 .32193 m
.46941 .32199 L
s
.46977 .32152 m
.46974 .32193 L
s
.46986 .32187 m
.46974 .32193 L
s
.46944 .32157 m
.46977 .32152 L
s
.46977 .32152 m
.46986 .32187 L
s
.46941 .32199 m
.46944 .32157 L
s
.46986 .32187 m
.46941 .32199 L
s
.46944 .32157 m
.46986 .32187 L
s
1 .03 0 r
.8531 .67456 m
.85371 .67498 L
s
1 .028 0 r
.73811 .31539 m
.73873 .31553 L
s
1 .03 0 r
.85358 .67496 m
.85353 .67497 L
s
.85366 .67483 m
.85358 .67496 L
s
.85371 .67498 m
.85358 .67496 L
s
.8536 .67484 m
.85366 .67483 L
s
.85366 .67483 m
.85371 .67498 L
s
1 .028 0 r
.73863 .31556 m
.73856 .31558 L
s
.73865 .31542 m
.73863 .31556 L
s
.73873 .31553 m
.73863 .31556 L
s
.73858 .31543 m
.73865 .31542 L
s
.73865 .31542 m
.73873 .31553 L
s
1 .03 0 r
.85353 .67497 m
.8536 .67484 L
s
.85371 .67498 m
.85353 .67497 L
s
.8536 .67484 m
.85371 .67498 L
s
1 .028 0 r
.73856 .31558 m
.73858 .31543 L
s
.73873 .31553 m
.73856 .31558 L
s
.73858 .31543 m
.73873 .31553 L
s
1 .136 0 r
.36192 .43233 m
.36342 .43392 L
s
.36337 .43387 m
.36277 .43393 L
s
.36347 .43327 m
.36337 .43387 L
s
.36342 .43392 m
.36337 .43387 L
s
.36287 .43334 m
.36347 .43327 L
s
.36347 .43327 m
.36342 .43392 L
s
.36277 .43393 m
.36287 .43334 L
s
.36342 .43392 m
.36277 .43393 L
s
.36287 .43334 m
.36342 .43392 L
s
1 .052 0 r
.63246 .42673 m
.63344 .42722 L
s
.63329 .42723 m
.63313 .42725 L
s
.63336 .42699 m
.63329 .42723 L
s
.63344 .42722 m
.63329 .42723 L
s
.6332 .42701 m
.63336 .42699 L
s
.63336 .42699 m
.63344 .42722 L
s
.63313 .42725 m
.6332 .42701 L
s
.63344 .42722 m
.63313 .42725 L
s
.6332 .42701 m
.63344 .42722 L
s
1 .159 0 r
.25436 .54439 m
.25528 .54696 L
s
.25541 .54673 m
.25465 .54675 L
s
.25555 .54613 m
.25541 .54673 L
s
.25528 .54696 m
.25541 .54673 L
s
.25465 .54675 m
.25478 .54615 L
s
.25528 .54696 m
.25465 .54675 L
s
.25478 .54615 m
.25555 .54613 L
s
.25555 .54613 m
.25528 .54696 L
s
.25478 .54615 m
.25528 .54696 L
s
1 .078 0 r
.52582 .53912 m
.527 .54018 L
s
.52683 .54012 m
.52655 .54014 L
s
.52697 .53979 m
.52683 .54012 L
s
.527 .54018 m
.52683 .54012 L
s
.52669 .5398 m
.52697 .53979 L
s
.52697 .53979 m
.527 .54018 L
s
.52655 .54014 m
.52669 .5398 L
s
.527 .54018 m
.52655 .54014 L
s
.52669 .5398 m
.527 .54018 L
s
1 .148 0 r
.14579 .6575 m
.14593 .66039 L
s
.14622 .66007 m
.14547 .66002 L
s
.14634 .6596 m
.14622 .66007 L
s
.14593 .66039 m
.14622 .66007 L
s
.14547 .66002 m
.14559 .65956 L
s
.14593 .66039 m
.14547 .66002 L
s
.14559 .65956 m
.14634 .6596 L
s
.14634 .6596 m
.14593 .66039 L
s
.14559 .65956 m
.14593 .66039 L
s
1 .033 0 r
.79897 .53381 m
.79966 .53418 L
s
1 .022 0 r
.68254 .17016 m
.68302 .17016 L
s
.68296 .17021 m
.6829 .17022 L
s
.68296 .17009 m
.68296 .17021 L
s
.68302 .17016 m
.68296 .17021 L
s
1 .033 0 r
.79953 .53418 m
.79945 .53419 L
s
.79959 .53402 m
.79953 .53418 L
s
.79966 .53418 m
.79953 .53418 L
s
1 .022 0 r
.68289 .1701 m
.68296 .17009 L
s
.68296 .17009 m
.68302 .17016 L
s
1 .033 0 r
.79951 .53404 m
.79959 .53402 L
s
.79959 .53402 m
.79966 .53418 L
s
1 .022 0 r
.6829 .17022 m
.68289 .1701 L
s
.68302 .17016 m
.6829 .17022 L
s
.68289 .1701 m
.68302 .17016 L
s
1 .033 0 r
.79945 .53419 m
.79951 .53404 L
s
.79966 .53418 m
.79945 .53419 L
s
.79951 .53404 m
.79966 .53418 L
s
1 .096 0 r
.41818 .65256 m
.41922 .65422 L
s
.41908 .65407 m
.41871 .65405 L
s
.41931 .65373 m
.41908 .65407 L
s
.41922 .65422 m
.41908 .65407 L
s
.41894 .6537 m
.41931 .65373 L
s
.41931 .65373 m
.41922 .65422 L
s
.41871 .65405 m
.41894 .6537 L
s
.41922 .65422 m
.41871 .65405 L
s
.41894 .6537 m
.41922 .65422 L
s
1 .047 0 r
.69228 .64758 m
.69312 .64828 L
s
1 .05 0 r
.57531 .28222 m
.57623 .28244 L
s
1 .047 0 r
.69296 .64823 m
.69283 .64824 L
s
.69308 .64803 m
.69296 .64823 L
s
.69312 .64828 m
.69296 .64823 L
s
.69294 .64804 m
.69308 .64803 L
s
.69308 .64803 m
.69312 .64828 L
s
1 .05 0 r
.57613 .2825 m
.57595 .28254 L
s
.57614 .28225 m
.57613 .2825 L
s
.57623 .28244 m
.57613 .2825 L
s
1 .047 0 r
.69283 .64824 m
.69294 .64804 L
s
.69312 .64828 m
.69283 .64824 L
s
.69294 .64804 m
.69312 .64828 L
s
1 .05 0 r
.57596 .28228 m
.57614 .28225 L
s
.57614 .28225 m
.57623 .28244 L
s
.57595 .28254 m
.57596 .28228 L
s
.57623 .28244 m
.57595 .28254 L
s
.57596 .28228 m
.57623 .28244 L
s
1 .087 0 r
.46706 .39534 m
.46832 .39614 L
s
.46822 .39615 m
.46786 .39621 L
s
.46827 .39574 m
.46822 .39615 L
s
.46832 .39614 m
.46822 .39615 L
s
.46791 .3958 m
.46827 .39574 L
s
.46827 .39574 m
.46832 .39614 L
s
.46786 .39621 m
.46791 .3958 L
s
.46832 .39614 m
.46786 .39621 L
s
.46791 .3958 m
.46832 .39614 L
s
1 .033 0 r
.74347 .38951 m
.74418 .38976 L
s
.74407 .38978 m
.74397 .3898 L
s
.7441 .38961 m
.74407 .38978 L
s
.74418 .38976 m
.74407 .38978 L
s
.74401 .38963 m
.7441 .38961 L
s
.7441 .38961 m
.74418 .38976 L
s
.74397 .3898 m
.74401 .38963 L
s
.74418 .38976 m
.74397 .3898 L
s
.74401 .38963 m
.74418 .38976 L
s
1 .117 0 r
.35778 .50953 m
.35893 .51116 L
s
.35893 .51106 m
.35838 .51111 L
s
.35903 .51056 m
.35893 .51106 L
s
.35893 .51116 m
.35893 .51106 L
s
.35838 .51111 m
.35848 .51061 L
s
.35893 .51116 m
.35838 .51111 L
s
.35848 .51061 m
.35903 .51056 L
s
.35903 .51056 m
.35893 .51116 L
s
.35848 .51061 m
.35893 .51116 L
s
1 .053 0 r
.63516 .50404 m
.63612 .50465 L
s
.63598 .50464 m
.6358 .50466 L
s
.63606 .50439 m
.63598 .50464 L
s
.63612 .50465 m
.63598 .50464 L
s
.63588 .50441 m
.63606 .50439 L
s
.63606 .50439 m
.63612 .50465 L
s
.6358 .50466 m
.63588 .50441 L
s
.63612 .50465 m
.6358 .50466 L
s
.63588 .50441 m
.63612 .50465 L
s
1 .127 0 r
.24746 .62481 m
.24809 .62707 L
s
.24823 .62684 m
.24759 .62685 L
s
.24834 .62638 m
.24823 .62684 L
s
.24809 .62707 m
.24823 .62684 L
s
.24759 .62685 m
.24771 .62639 L
s
.24809 .62707 m
.24759 .62685 L
s
.24771 .62639 m
.24834 .62638 L
s
.24834 .62638 m
.24809 .62707 L
s
.24771 .62639 m
.24809 .62707 L
s
1 .072 0 r
.52582 .61965 m
.52683 .62076 L
s
.52669 .62069 m
.52642 .6207 L
s
.52684 .62039 m
.52669 .62069 L
s
.52683 .62076 m
.52669 .62069 L
s
.52656 .6204 m
.52684 .62039 L
s
.52684 .62039 m
.52683 .62076 L
s
.52642 .6207 m
.52656 .6204 L
s
.52683 .62076 m
.52642 .6207 L
s
.52656 .6204 m
.52683 .62076 L
s
1 .034 0 r
.80595 .61447 m
.80665 .61492 L
s
1 .029 0 r
.68655 .24152 m
.68717 .24159 L
s
1 .034 0 r
.80652 .6149 m
.80643 .61491 L
s
.80659 .61474 m
.80652 .6149 L
s
.80665 .61492 m
.80652 .6149 L
s
1 .029 0 r
.6871 .24165 m
.687 .24167 L
s
.6871 .24149 m
.6871 .24165 L
s
.68717 .24159 m
.6871 .24165 L
s
1 .034 0 r
.8065 .61476 m
.80659 .61474 L
s
.80659 .61474 m
.80665 .61492 L
s
1 .029 0 r
.687 .24151 m
.6871 .24149 L
s
.6871 .24149 m
.68717 .24159 L
s
1 .034 0 r
.80643 .61491 m
.8065 .61476 L
s
.80665 .61492 m
.80643 .61491 L
s
1 .029 0 r
.687 .24167 m
.687 .24151 L
s
.68717 .24159 m
.687 .24167 L
s
1 .034 0 r
.8065 .61476 m
.80665 .61492 L
s
1 .029 0 r
.687 .24151 m
.68717 .24159 L
s
1 .055 0 r
.57658 .3568 m
.57754 .35718 L
s
.57744 .35722 m
.57723 .35727 L
s
.57747 .35695 m
.57744 .35722 L
s
.57754 .35718 m
.57744 .35722 L
s
.57725 .35699 m
.57747 .35695 L
s
.57747 .35695 m
.57754 .35718 L
s
.57723 .35727 m
.57725 .35699 L
s
.57754 .35718 m
.57723 .35727 L
s
.57725 .35699 m
.57754 .35718 L
s
1 .082 0 r
.46554 .4732 m
.46664 .47415 L
s
.46657 .47413 m
.46621 .47418 L
s
.46663 .47374 m
.46657 .47413 L
s
.46664 .47415 m
.46657 .47413 L
s
.46627 .4738 m
.46663 .47374 L
s
.46663 .47374 m
.46664 .47415 L
s
.46621 .47418 m
.46627 .4738 L
s
.46664 .47415 m
.46621 .47418 L
s
.46627 .4738 m
.46664 .47415 L
s
1 .036 0 r
.74911 .46748 m
.74986 .46782 L
s
.74974 .46783 m
.74962 .46785 L
s
.74979 .46765 m
.74974 .46783 L
s
.74986 .46782 m
.74974 .46783 L
s
.74967 .46767 m
.74979 .46765 L
s
.74979 .46765 m
.74986 .46782 L
s
.74962 .46785 m
.74967 .46767 L
s
.74986 .46782 m
.74962 .46785 L
s
.74967 .46767 m
.74986 .46782 L
s
1 .1 0 r
.35342 .59073 m
.35431 .59232 L
s
.35433 .59219 m
.35384 .59223 L
s
.35442 .59178 m
.35433 .59219 L
s
.35431 .59232 m
.35433 .59219 L
s
.35384 .59223 m
.35393 .59182 L
s
.35431 .59232 m
.35384 .59223 L
s
.35393 .59182 m
.35442 .59178 L
s
.35442 .59178 m
.35431 .59232 L
s
.35393 .59182 m
.35431 .59232 L
s
1 .052 0 r
.63801 .58536 m
.6389 .58607 L
s
.63877 .58604 m
.63858 .58606 L
s
.63886 .5858 m
.63877 .58604 L
s
.6389 .58607 m
.63877 .58604 L
s
.63867 .58582 m
.63886 .5858 L
s
.63886 .5858 m
.6389 .58607 L
s
.63858 .58606 m
.63867 .58582 L
s
.6389 .58607 m
.63858 .58606 L
s
.63867 .58582 m
.6389 .58607 L
s
1 .035 0 r
.69077 .31662 m
.69148 .3168 L
s
.69139 .31684 m
.69127 .31687 L
s
.6914 .31666 m
.69139 .31684 L
s
.69148 .3168 m
.69139 .31684 L
s
.69128 .31668 m
.6914 .31666 L
s
.6914 .31666 m
.69148 .3168 L
s
.69127 .31687 m
.69128 .31668 L
s
.69148 .3168 m
.69127 .31687 L
s
.69128 .31668 m
.69148 .3168 L
s
1 .055 0 r
.57792 .43532 m
.57885 .43584 L
s
.57876 .43586 m
.57853 .4359 L
s
.57879 .43558 m
.57876 .43586 L
s
.57885 .43584 m
.57876 .43586 L
s
.57856 .43562 m
.57879 .43558 L
s
.57879 .43558 m
.57885 .43584 L
s
.57853 .4359 m
.57856 .43562 L
s
.57885 .43584 m
.57853 .4359 L
s
.57856 .43562 m
.57885 .43584 L
s
1 .074 0 r
.46394 .55519 m
.46488 .55623 L
s
.46483 .55617 m
.46448 .55621 L
s
.4649 .55582 m
.46483 .55617 L
s
.46488 .55623 m
.46483 .55617 L
s
.46455 .55587 m
.4649 .55582 L
s
.4649 .55582 m
.46488 .55623 L
s
.46448 .55621 m
.46455 .55587 L
s
.46488 .55623 m
.46448 .55621 L
s
.46455 .55587 m
.46488 .55623 L
s
1 .037 0 r
.75505 .54959 m
.75579 .55002 L
s
.75568 .55002 m
.75555 .55004 L
s
.75573 .54983 m
.75568 .55002 L
s
.75579 .55002 m
.75568 .55002 L
s
.7556 .54986 m
.75573 .54983 L
s
.75573 .54983 m
.75579 .55002 L
s
.75555 .55004 m
.7556 .54986 L
s
.75579 .55002 m
.75555 .55004 L
s
.7556 .54986 m
.75579 .55002 L
s
.69522 .39578 m
.69596 .39606 L
s
.69587 .39608 m
.69572 .39612 L
s
.69589 .39589 m
.69587 .39608 L
s
.69596 .39606 m
.69587 .39608 L
s
.69574 .39592 m
.69589 .39589 L
s
.69589 .39589 m
.69596 .39606 L
s
.69572 .39612 m
.69574 .39592 L
s
.69596 .39606 m
.69572 .39612 L
s
.69574 .39592 m
.69596 .39606 L
s
1 .054 0 r
.57933 .51809 m
.58019 .51873 L
s
.58011 .51871 m
.57987 .51875 L
s
.58016 .51844 m
.58011 .51871 L
s
.58019 .51873 m
.58011 .51871 L
s
.57992 .51849 m
.58016 .51844 L
s
.58016 .51844 m
.58019 .51873 L
s
.57987 .51875 m
.57992 .51849 L
s
.58019 .51873 m
.57987 .51875 L
s
.57992 .51849 m
.58019 .51873 L
s
1 .038 0 r
.69991 .47931 m
.70064 .47969 L
s
.70056 .4797 m
.7004 .47974 L
s
.70059 .4795 m
.70056 .4797 L
s
.70064 .47969 m
.70056 .4797 L
s
.70043 .47953 m
.70059 .4795 L
s
.70059 .4795 m
.70064 .47969 L
s
.7004 .47974 m
.70043 .47953 L
s
.70064 .47969 m
.7004 .47974 L
s
.70043 .47953 m
.70064 .47969 L
s
0 g
.25 Mabswid
.67792 0 m
.94145 .42058 L
s
.94145 .42058 m
1 .84892 L
s
1 .84892 m
.70518 .46965 L
s
.70518 .46965 m
.67792 0 L
s
.07103 .24925 m
0 .69744 L
s
0 .69744 m
.70518 .46965 L
s
.70518 .46965 m
.67792 0 L
s
.67792 0 m
.07103 .24925 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 572.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900002?2000`400?l00000o`00003ooooonfZ5
oookJP;o0000^_oonfX00?oooo]ZP_oonfX3o`000003oookJ_l0003ooo]Z0;Wooo]Z003ooookJX3o
oo]Z0_l00004oookJP;o0000^OoonfX00?oooo]ZO_oonfX2o`0000Kooo]Z00?o0000oookJ_l00000
^?oonfX00?oooo]ZNooonfX3o`0000Sooo]Z00?o0000oookJ_l00000^?oonfX00?oooo]ZNOoonfX2
o`0000_ooo]Z00Co0000oookJ_oonf[o0000]ooonfX00?oooo]ZM_oonfX3o`0000gooo]Z00Co0000
oookJ_oonf[o0000]ooonfX00?oooo]ZM?oonfX2o`00013ooo]Z00Go0000oookJ_oonf[ooo]Zo`00
002foookJP00oooonfYaoookJP?o00004_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z0;?ooo]Z003ooookJVoooo]Z0_l0000FoookJP05o`000?oonf[ooo]ZoookJ_l00000]OoonfX0
0?oooo]ZKOoonfX2o`0001Sooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP2boook
JP00oooonfYZoookJP?o00006_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z0;7o
oo]Z003ooookJVSooo]Z0_l0000MoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
/OoonfX00?oooo]ZIOoonfX3o`0001oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP2`oookJP00oooonfYSoookJP;o00008_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z0;3ooo]Z003ooookJV3ooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oook
J_oonfX0[ooonfX00?oooo]ZG_oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP2^oookJP00oooonfYLoookJP;o0000:OoonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z0:kooo]Z003ooookJUWooo]Z0ol0000[oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX0[OoonfX00?oooo]ZEooonfX2o`0002kooo]Z00?o0000oookJ_oonfX02?oonfX0
0ol0003ooo]ZoookJP2/oookJP00oooonfYDoookJP?o0000<?oonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z0:cooo]Z003ooookJU;ooo]Z0_l0000coookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0ZooonfX00?oooo]ZCooonfX3o`0003?ooo]Z00?oo`40oookJ_l00000
3?oonfX00ol0003ooo]ZoookJP2ZoookJP00oooonfY=oookJP;o0000>?oonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z0:[ooo]Z003ooookJT_ooo]Z0_l0000joookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX0ZOoonfX00?oooo]ZB?oonfX3o`0003cooo]Z00?o0000oook
J_oonfX02ooonfX00ol0003ooo]ZoookJP2YoookJP00oooonfY6oookJP;o0000@?oonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z0:Sooo]Z003ooookJT?ooo]Z0ol00012oookJP03o`00
0?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0YooonfX00?oooo]Z@OoonfX2o`0004Gooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP2WoookJP00oooonfXooookJP;o0000AooonfX0
0ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0:Kooo]Z003ooookJScooo]Z0ol00019oook
JP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0YOoonfX00?oooo]Z>_oonfX2o`0004co
oo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP2UoookJP00oooonfXgoookJP?o0000
C_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z0:Cooo]Z003ooookJSGooo]Z0_l0
001AoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0Y?oonfX00?oooo]Z<_oonfX3
o`0005?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP2SoookJP00oooonfX`oook
JP;o0000E_oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z0:;ooo]Z003ooookJRko
oo]Z0_l0001HoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0X_oonfX00?oooo]Z
:ooonfX3o`0005[ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP2QoookJP00oooo
nfXYoookJP;o0000GOoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z0:3ooo]Z003o
oookJRKooo]Z0ol0001OoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0X?oonfX0
0?oooo]Z9?oonfX2o`0006;ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP2Ooook
JP00oooonfXQoookJP?o0000I?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z09oo
oo]Z003ooookJQoooo]Z0_l0001WoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0
W_oonfX00?oooo]Z7OoonfX2o`0006[ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zoook
JP2MoookJP00oooonfXJoookJP?o0000K?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[o
oo]Z09gooo]Z003ooookJQSooo]Z0_l0001_oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oook
J_oonfX0W?oonfX00?oooo]Z5OoonfX3o`00037ooo]Z0_oo0P0noookJP03o`000?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX0VooonfX00?oooo]Z4ooonfX2o`0007Cooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP2KoookJP00oooonfX@oookJP?o0000M_oonfX00ol0003ooo]Zoook
JP0HoookJP03o`000?oonf[ooo]Z09[ooo]Z003ooookJPkooo]Z0_l0001ioookJP03o`000?oonf[o
oo]Z01Sooo]Z00?o0000oookJ_oonfX0V_oonfX00?oooo]Z3?oonfX2o`0007_ooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP2IoookJP00oooonfX9oookJP?o0000OOoonfX00ol0003o
oo]ZoookJP0JoookJP03o`000?oonf[ooo]Z09Sooo]Z003ooookJPOooo]Z0_l00020oookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0V?oonfX00?oooo]Z1?oonfX3o`0008;ooo]Z00?o
0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP2GoookJP00oooonfX2oookJP;o0000QOoonfX0
0ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z09Kooo]Z003noookJP?o0000QooonfX00ol0
003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z09Kooo]Z003loookJP;o0000R_oonfX00ol0003o
oo]ZoookJP0MoookJP03o`000?oonf[ooo]Z09Gooo]Z003joookJP;o0000S?oonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z09Gooo]Z003goookJP?o0000S_oonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?oonf[ooo]Z09Cooo]Z003eoookJP;o0000SooonfX00ooo0`3ooo]Zo`00000Q
oookJP03o`000?oonf[ooo]Z09?ooo]Z003boookJP?o0000U?oonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z09?ooo]Z003`oookJP;o0000UooonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z09;ooo]Z003^oookJP;o0000VOoonfX00ol0003ooo]ZoookJP0PoookJP03o`00
0?oonf[ooo]Z097ooo]Z003[oookJP?o0000VooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oo
nf[ooo]Z097ooo]Z003YoookJP;o0000W_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z093ooo]Z003VoookJP?o0000X?oonfX00ol0003ooo]ZoookJP0DoookJP03ool10?oonf[ooo]Z
00_ooo]Z00?o0000oookJ_oonfX0SooonfX00>Cooo]Z0_l0002SoookJP03o`000?oonf[ooo]Z02;o
oo]Z00?o0000oookJ_oonfX0SooonfX00>7ooo]Z0ol0002UoookJP03o`000?oonf[ooo]Z02?ooo]Z
00?o0000oookJ_oonfX0S_oonfX00=oooo]Z0_l0002XoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o
0000oookJ_oonfX0S_oonfX00=gooo]Z0_l0000`oookJP03ool60?oonf[ooo]Z07Oooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP2=oookJP00f_oonfX3o`000:cooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP2<oookJP00f?oonfX2o`000:oooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP2<oookJP00eOoonfX3o`000;7ooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP2;oookJP00dooonfX2o`000;Cooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP2:oookJP00d?oonfX3o`000;Kooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP2:oookJP00c_oonfX2o`000;Wooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0
003ooo]ZoookJP29oookJP00c?oonfX2o`000;_ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP29oookJP00bOoonfX3o`000;kooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Z
oookJP28oookJP00aooonfX2o`000<7ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP27oookJP00a?oonfX3o`000<?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP27
oookJP00`_oonfX2o`000<Kooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP26oook
JP00_ooonfX3o`000<Sooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP25oookJP00
_OoonfX2o`000<_ooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP25oookJP00^ooo
nfX2o`0008cooo]Z00?oo`H0oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z08Cooo]Z002hoookJP?o0000cooonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z08Cooo]Z002foookJP;o0000d_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
08?ooo]Z002coookJP?o0000e?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z08;o
oo]Z002aoookJP;o0000eooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z08;ooo]Z
002_oookJP;o0000]OoonfX00ooo0P3ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02oooo]Z00?o
0000oookJ_oonfX0POoonfX00:cooo]Z0ol0003KoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX0P?oonfX00:[ooo]Z0_l0003NoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oook
J_oonfX0P?oonfX00:Oooo]Z0ol0000^oookJP;ooa80/?oonfX00ol0003ooo]ZoookJP0aoookJP03
o`000?oonf[ooo]Z07oooo]Z002UoookJP;o0000hooonfX00ol0003ooo]ZoookJP0aoookJP03o`00
0?oonf[ooo]Z07oooo]Z002RoookJP?o0000iOoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z07kooo]Z002PoookJP;o0000jOoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z07gooo]Z002NoookJP;o0000jooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z
07gooo]Z002KoookJP?o0000kOoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z07co
oo]Z002IoookJP;o0000l?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z07_ooo]Z
002FoookJP?o0000kooonfX01?oo1@3ooo]ZoookJ_l0000foookJP03o`000?oonf[ooo]Z07_ooo]Z
002DoookJP;o0000mOoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z07[ooo]Z002A
oookJP?o0000mooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z07[ooo]Z002?oook
JP;o0000n_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z07Wooo]Z002=oookJP;o
0000o?oonfX00ol0003ooo]ZoookJP0DoookJP;oo`<08OoonfX00ol0003ooo]ZoookJP1hoookJP00
R_oonfX3o`000?kooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1hoookJP00R?oo
nfX2o`000?oooo]Z0_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z07Oooo]Z0025
oookJP?o0000oooonfX4oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0M_oonfX0
08?ooo]Z0_l00029oookJP;oo`h0NooonfX00ol0003ooo]ZoookJP0[oookJP;oo`003?oonfX00ol0
003ooo]ZoookJP1foookJP00P?oonfX3o`000?oooo]Z2OoonfX00ol0003ooo]ZoookJP0joookJP03
o`000?oonf[ooo]Z07Gooo]Z001noookJP;o0000oooonfX<oookJP03o`000?oonf[ooo]Z03_ooo]Z
00?o0000oookJ_oonfX0M?oonfX007cooo]Z0_l0002`oookJP03ool50?oonf[ooo]Z05[ooo]Z00?o
0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP1doookJP00NOoonfX3o`000?oooo]Z4?oonfX0
0ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z07?ooo]Z001goookJP;o0000oooonfXDoook
JP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0LooonfX007Cooo]Z0ol0000^oookJP03
oom60?oonf[ooo]Z0>Cooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1boookJP00
L_oonfX2o`0002oooo]Z0oooAP3VoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0
LOoonfX006oooo]Z0ol0003ooookJQ_ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Zoook
JP1aoookJP00KOoonfX2o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[o
oo]Z073ooo]Z001[oookJP;o0000oooonfXPoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oook
J_oonfX0KooonfX006Sooo]Z0ol0003ooookJR;ooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003o
oo]ZoookJP1_oookJP00I_oonfX2o`000?oooo]Z9OoonfX00ol0003ooo]ZoookJP10oookJP03o`00
0?oonf[ooo]Z06kooo]Z001SoookJP?o0000oooonfXWoookJP03o`000?oonf[ooo]Z043ooo]Z00?o
0000oookJ_oonfX0K_oonfX0067ooo]Z0_l0003ooookJR[ooo]Z00?o0000oookJ_oonfX0@OoonfX0
0ol0003ooo]ZoookJP1]oookJP00GooonfX2o`000?oooo]Z;?oonfX00ol0003ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z06cooo]Z001LoookJP?o0000jooonfX00ooo2P3ooo]ZoookJP0ooookJP03
o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0K?oonfX005[ooo]Z0_l0003ooookJS7ooo]Z
00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP1[oookJP00EooonfX3o`000?oooo]Z3_oo
nfX00ooo1P3ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0J_oo
nfX005Gooo]Z0_l0003ooookJQ7ooo]Z00?oo`H0oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP14
oookJP03o`000?oonf[ooo]Z06[ooo]Z001BoookJP?o0000oooonfXhoookJP03o`000?oonf[ooo]Z
04Gooo]Z00?o0000oookJ_oonfX0JOoonfX0053ooo]Z0_l0003ooookJS3ooo]Z00?oo`40oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z06Wooo]Z001>oookJP;o0000
Q_oonfX2oolR0;Gooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1XoookJP00Booo
nfX3o`000?oooo]Z@?oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z06Oooo]Z0019
oookJP;o0000[OoonfX2ool?09?ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP1W
oookJP00A_oonfX3o`000?oooo]ZAOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z
06Kooo]Z0014oookJP;o0000oooonfY8oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oo
nfX0IOoonfX0047ooo]Z0ol0000/oookJP;oWol0oooonfXLoookJP03o`000?oonf[ooo]Z04Sooo]Z
00?o0000oookJ_oonfX0IOoonfX003oooo]Z0_l0000aoookJP03oioo0?oonf[ooo]Z0?oooo]Z6Ooo
nfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z06Cooo]Z000moookJP;o0000=?oonfX0
0onOo`3ooo]ZoookJP3ooookJQSooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP1T
oookJP00>_oonfX3o`0003Oooo]Z0_nOo`000ooonf[oWol0oioo003ooookJQGooo]Z00?o0000oook
J_oonfX0B_oonfX00ol0003ooo]ZoookJP1SoookJP00>?oonfX2o`0003_ooo]Z0_nOo`000ooonf[o
Wol0oookJP3ooookJQCooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP1RoookJP00
=OoonfX3o`0003gooo]Z00CoWol0oookJ_nOo`3oWol0oooonfXEoookJP03o`000?oonf[ooo]Z04_o
oo]Z00?o0000oookJ_oonfX0H_oonfX003?ooo]Z0_l0000ooookJP03oioo0?oonf[oWol000;oWol0
oooonfXBoookJP;oo`L000?ooo]Zo`000?oonfX0COoonfX00ol0003ooo]ZoookJP1QoookJP00<?oo
nfX3o`00047ooo]Z1?nOo`3ooookJQKooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]Zoook
JP1PoookJP00;_oonfX2o`000?oooo]ZG_oonfX00ol0003ooo]ZoookJP0EoookJP03ool50?oonf[o
oo]Z03Gooo]Z00?o0000oookJ_oonfX0H?oonfX002cooo]Z0_l0003ooookJV3ooo]Z00?o0000oook
J_oonfX0;OoonfX00ooo0P3ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z05oooo]Z000YoookJP?o
0000oooonfYRoookJP03o`000?oonf[ooo]Z02gooo]Z00?oo`80oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP1NoookJP00:?oonfX2o`000>Cooo]Z00?ooa<0oookJ_oonfX0OOoonfX00ol0003ooo]Z
oookJP11oookJP03ool00?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0G_oonfX002Sooo]Z00?o
0000oookJ_l00000hooonfX00ooo4`3ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX0GOoonfX002Sooo]Z00Co0000oookJ_oonf[o0000oooonfX3oookJP03ool<0?oo
nf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1MoookJP00:?oonfX0
1Ol0003ooo]ZoookJ_oonf[o00000?oooo]Z7ooonfX00ooo103ooo]ZoookJP10oookJP03o`000?oo
nf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0G?oonfX002Oooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP3ooookJUoooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1K
oookJP009ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z06oooo]Z0_ooFP3/oook
JP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0FooonfX002Oooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP1_oookJP;ooeX08OoonfX2oolb0<Sooo]Z00?o0000oookJ_oo
nfX0D_oonfX00ol0003ooo]ZoookJP1JoookJP009ooonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?oonf[ooo]Z06kooo]Z0_ooFP0SoookJP03oolb0?oonf[ooo]Z0<Gooo]Z00?o0000oookJ_oonfX0
DooonfX00ol0003ooo]ZoookJP1IoookJP009ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oo
nf[ooo]Z0?oooo]ZFooonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z05Wooo]Z000W
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX02OoonfX00ol02_oooo]ZoookJP3o
oookJTkooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP1HoookJP009ooonfX00ol0
003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o00[ooookJ_oonfX0oooonfY>oook
JP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0F?oonfX002Kooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP07oookJP03o`0:oooonf[ooo]Z0?oooo]ZC_oonfX00ol0003o
oo]ZoookJP1EoookJP03o`000?oonf[ooo]Z05Oooo]Z000VoookJP03o`000?oonf[ooo]Z00cooo]Z
00?o0000oookJ_oonfX01_oonfX00ol02_oooo]ZoookJP3ooookJTkooo]Z00?o0000oookJ_oonfX0
E_oonfX00ol0003ooo]ZoookJP1FoookJP009_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oo
nf[ooo]Z00Gooo]Z00?o00[ooookJ_oonfX0oooonfY>oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o
0000oookJ_oonfX0E_oonfX002Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP03
oookJP03o`0:oooonf[ooo]Z0?oooo]ZCooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[o
oo]Z05Gooo]Z000VoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
2_oooo]ZoookJP3ooookJToooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP1Doook
JP009_oonfX00ol0003ooo]ZoookJP0@oookJP05o`000?oonf[ooo]ZoookJ_l02_l0oooonfYAoook
JP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0E?oonfX002Gooo]Z00?o0000oookJ_oo
nfX04_oonfX01?l0003ooo]ZoookJ_l02_oooookJU;ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0
003ooo]ZoookJP1CoookJP009OoonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[o00[o0?oo
oo]Z3OoonfX2ool<04?ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP1CoookJP00
9OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?l02_oooo]Z0?oooo]Z3OoonfX00ooo303ooo]Z
oookJP0JoookJP;oo`T06OoonfX00ooo103ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z05Wooo]Z
00?o0000oookJ_oonfX0D_oonfX002Gooo]Z00?o0000oookJ_oonfX05OoonfX00ol02_oooo]Zoook
JP3ooookJU3ooo]Z00?o0000oookJ_oonfX02OoonfX00ooo0@3ooo]ZoookJP1>oookJP03o`000?oo
nf[ooo]Z057ooo]Z000UoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o00[ooookJ_l00000oooonfYA
oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0DOoonfX002Gooo]Z00?o0000oook
J_oonfX05?oonfX01?l02_oooo]ZoookJ_l0002DoookJP;oobL0^OoonfX00ol0003ooo]ZoookJP1K
oookJP03o`000?oonf[ooo]Z053ooo]Z000ToookJP03o`000?oonf[ooo]Z01Gooo]Z00Go00[ooook
J_oonf[ooo]Zo`00002DoookJP03oolW0?oonf[ooo]Z01oooo]Z0_oo7@0MoookJP;oo`T0MooonfX0
0ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z04oooo]Z000ToookJP03o`000?oonf[ooo]Z
01Gooo]Z00?o00[ooookJ_oonfX00_oonfX00ol0003ooo]ZoookJP3ooookJTcooo]Z00?o0000oook
J_oonfX0G?oonfX00ol0003ooo]ZoookJP1?oookJP009?oonfX00ol0003ooo]ZoookJP0EoookJP03
o`0:oooonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0oooonfY;oookJP03o`000?oonf[ooo]Z05go
oo]Z00?o0000oookJ_oonfX0C_oonfX002Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol02_oooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z02Kooo]Z00?oonT0oookJ_oonfX08ooonfX2oona0?_ooo]Z
00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP1>oookJP009?oonfX00ol0003ooo]Zoook
JP0EoookJP03o`0:oooonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX09OoonfX00oooj@3ooo]Zoook
JP0UoookJP03oona0?oonf[ooo]Z0?Sooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]Zoook
JP1=oookJP009?oonfX00ol0003ooo]ZoookJP0DoookJP03o`0:oooonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX09OoonfX00oooj@3ooo]ZoookJP0UoookJP03oona0?oonf[ooo]Z0?Oooo]Z00?o0000
oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP1<oookJP009?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`0:oooonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX09?oonfX3oooY02Kooo]Z0_oo/@3goook
JP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX0C?oonfX002?ooo]Z00?o0000oookJ_oo
nfX05OoonfX00ol02_oooo]ZoookJP09oookJP03o`000?oonf[ooo]Z02?ooo]Z0oooj@0VoookJP;o
ok40mooonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z04_ooo]Z000SoookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o00[ooookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0RoookJP?oonT0
9_oonfX3oona0?Kooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP1:oookJP008ooo
nfX00ol0003ooo]ZoookJP0EoookJP03o`0:oooonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX08ooo
nfX00oooj@3ooo]ZoookJP3ooookJQkooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]Zoook
JP1:oookJP008ooonfX00ol0003ooo]ZoookJP0EoookJP03o`0:oooonf[ooo]Z00cooo]Z00?o0000
oookJ_oonfX0oooonfY3oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0BOoonfX0
02?ooo]Z00?o0000oookJ_oonfX04?oonfX4o`0:o`03oookJ_l02_oooo]Z00kooo]Z00?o0000oook
J_oonfX0oooonfY3oookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0BOoonfX002?o
oo]Z00?o0000oookJ_oonfX04?oonfX01?l02_oooo]ZoookJ_oonfX5o`0:o`gooo]Z00?o0000oook
J_oonfX0oooonfY2oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0B?oonfX002;o
oo]Z00?o0000oookJ_oonfX04?oonfX2o`0:o`?ooo]Z00?o00[ooookJ_oonfX00_oonfX2o`0:o`co
oo]Z00?o0000oookJ_oonfX0oooonfY1oookJP03o`000?oonf[ooo]Z04;ooo]Z0_oo0P0BoookJP03
ool00?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0AooonfX002;ooo]Z00?o0000oookJ_oonfX0
4?oonfX00ol02_oooo]Zo`0:o`02oookJP03o`0:oooonf[ooo]Z00?ooo]Z00?o00[ooookJ_oonfX0
2ooonfX00ol0003ooo]ZoookJP3ooookJT3ooo]Z00?o0000oookJ_oonfX0;OoonfX00ooo103ooo]Z
oookJP0coookJP03o`000?oonf[ooo]Z04Oooo]Z000RoookJP03o`000?oonf[ooo]Z013ooo]Z00?o
00[ooookJ_l02_l00_oonfX00ol02_oooo]ZoookJP02oookJP03o`0:oooonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX0oooonfXEoookJP03ool20?oonf[ooo]Z02Cooo]Z00Coo`P0oookJ_oonf[o0000
5ooonfX00ooo1`3ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z04Kooo]Z000RoookJP03o`000?oo
nf[ooo]Z00oooo]Z00Co00[ooookJ_oonf[o00[o0_oonfX01?l02_oooo]ZoookJ_oonfX2o`0:oa3o
oo]Z00?o0000oookJ_oonfX0n?oonfX2ool901Wooo]Z00?oo`80oookJ_oonfX09ooonfX00ol0003o
oo]ZoookJP1UoookJP03o`000?oonf[ooo]Z04Gooo]Z000RoookJP03o`000?oonf[ooo]Z00oooo]Z
1Ol02_l01ooonf[o00[ooookJ_oonf[o00[ooookJ_l02_l04OoonfX00ol0003ooo]ZoookJP3Joook
JP;ooa807?oonfX00ooo2@3ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oook
J_oonfX0AOoonfX002;ooo]Z00?o0000oookJ_oonfX04?oonfX00ol02_oooo]ZoookJP05o`0:o`03
oookJ_l02_oooo]Z01;ooo]Z00?o0000oookJ_oonfX0^?oonfX2oolF087ooo]Z00?o0000oookJ_oo
nfX0I_oonfX00ol0003ooo]ZoookJP14oookJP008_oonfX00ol0003ooo]ZoookJP0AoookJP04o`0:
oooonf[o00[oo`0:o`;ooo]Z0ol02_lDoookJP03o`000?oonf[ooo]Z06cooo]Z00?oodL0oookJ_oo
nfX07_oonfX2oolG0:_ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP13oookJP00
8OoonfX00ol0003ooo]ZoookJP0CoookJP?o00[o00?ooo]Zo`0:ool02_l05ooonfX00ol0003ooo]Z
oookJP16oookJP03oomA0?oonf[ooo]Z02?ooo]Z0_ooA`3;oookJP03o`000?oonf[ooo]Z06Oooo]Z
00?o0000oookJ_oonfX0@ooonfX0027ooo]Z00?o0000oookJ_oonfX05?oonfX3o`0:oa[ooo]Z00?o
0000oookJ_oonfX02OoonfX00onOo`3ooo]ZoookJP0ioookJP;ooe409?oonfX2oom70<_ooo]Z00?o
0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP12oookJP008OoonfX00ol0003ooo]ZoookJP0E
oookJP03oi?o0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX02?oonfX00onOo`3ooo]ZoookJP0j
oookJP03oomA0?oonf[ooo]Z0>oooo]Z00?o0000oookJ_oonfX0J?oonfX00ol0003ooo]ZoookJP12
oookJP008OoonfX00ol0003ooo]ZoookJP0EoookJP03oi?o0?oonf[ooo]Z01_ooo]Z00?o0000oook
J_oonfX01ooonfX00onOo`3ooo]ZoookJP3ooookJRgooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0
003ooo]ZoookJP11oookJP008OoonfX00ol0003ooo]ZoookJP0EoookJP03oi?o0?oonf[ooo]Z01co
oo]Z00?o0000oookJ_oonfX01ooonfX00onOo`3ooo]ZoookJP3ooookJRcooo]Z00?o0000oookJ_oo
nfX0J_oonfX00ol0003ooo]ZoookJP10oookJP008OoonfX00ol0003ooo]ZoookJP0EoookJP03oi?o
0?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX01_oonfX00onOo`3ooo]ZoookJP3ooookJRcooo]Z
00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP10oookJP008?oonfX00ol0003ooo]Zoook
JP0EoookJP03oi?o0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX01OoonfX00onOo`3ooo]Zoook
JP3ooookJRcooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP0ooookJP008?oonfX0
0ol0003ooo]ZoookJP0EoookJP03oi?o0?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX01OoonfX0
0onOo`3ooo]ZoookJP3ooookJR_ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0n
oookJP008?oonfX00ol0003ooo]ZoookJP0EoookJP03oi?o0?oonf[ooo]Z027ooo]Z00?o0000oook
J_oonfX01?oonfX00onOo`3ooo]ZoookJP3ooookJRcooo]Z00?o0000oookJ_oonfX0JooonfX00ol0
003ooo]ZoookJP0noookJP008?oonfX00ol0003ooo]ZoookJP0EoookJP03oi?o0?oonf[ooo]Z02;o
oo]Z00?o0000oookJ_oonfX00ooonfX00onOo`3ooo]ZoookJP3ooookJRcooo]Z00?o0000oookJ_oo
nfX0K?oonfX00ol0003ooo]ZoookJP0moookJP008?oonfX00ol0003ooo]ZoookJP0EoookJP03oi?o
0?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX00ooonfX00onOo`3ooo]ZoookJP3ooookJR_ooo]Z
00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0moookJP008?oonfX00ol0003ooo]Zoook
JP0EoookJP03oi?o0?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX00_oonfX00onOo`3ooo]Zoook
JP3ooookJR_ooo]Z00?o0000oookJ_oonfX07ooonfX00ooo003ooo]ZoookJP1;oookJP03o`000?oo
nf[ooo]Z03cooo]Z000PoookJP03o`000?oonf[ooo]Z01?ooo]Z1OnCo`0UoookJP05o`000?oonf[o
oo]ZoookJ_nOo`00oooonfX]oookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000oookJ_oonfX0>ooo
nfX001oooo]Z00?o0000oookJ_oonfX05?oonfX2oi?o00;ooo]Z00?oTol0oookJ_oonfX09?oonfX0
1?l0003ooo]ZoookJ_oonfX3oioo0?oooo]Z:_oonfX00ol0003ooo]ZoookJP09oookJP03ool30?oo
nf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0>ooonfX001oooo]Z00?o0000oookJ_oonfX04ooonfX3
oi?o0003oookJ_nCo`3ooo]Z02Oooo]Z00?o0000oioo0?nOo`000onOo`3:oookJP;oo`D0DOoonfX0
0ooo1`3ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX0>_oonfX0
01oooo]Z00?o0000oookJ_oonfX05?oonfX4oi?o02Wooo]Z00?o0000oioo0?nOo`000_nOo`3ooook
JQkooo]Z00?oo`L0oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z
03Wooo]Z000OoookJP03o`000?oonf[ooo]Z01Gooo]Z00?oTol0oookJ_oonfX0:_oonfX00ol0003o
Wol0oioo002^oookJP;ooa<0DooonfX00ooo303ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z073o
oo]Z00?o0000oookJ_oonfX0>OoonfX001oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003oWol0
oookJP1:oookJP;ooc80@_oonfX00ooo8`3ooo]ZoookJP2HoookJP03o`000?oonf[ooo]Z077ooo]Z
00?o0000oookJ_oonfX0>?oonfX001oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]Zoook
JP1:oookJP;ooc80@OoonfX2oolS05?ooo]Z0_oo3P14oookJP03o`000?oonf[ooo]Z077ooo]Z00?o
0000oookJ_oonfX0>?oonfX001kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0U
oookJP03oonQ0?oonf[ooo]Z0;Wooo]Z0_oo3P14oookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000
oookJ_oonfX0=ooonfX001kooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0Toook
JP03oonQ0?oonf[ooo]Z043ooo]Z0_oo9P2moookJP03o`000?oonf[ooo]Z07?ooo]Z00?o0000oook
J_oonfX0=_oonfX001kooo]Z00?o0000oookJ_oonfX0A_oonfX00oooTP3ooo]Zo`00000VoookJP03
oonQ0?oonf[ooo]Z0?kooo]Z00?o0000oookJ_oonfX0LooonfX00ol0003ooo]ZoookJP0foookJP00
7_oonfX00ol0003ooo]ZoookJP16oookJP04oonB0?oonf[ooo]Zo`0002Kooo]Z0_ooX@3noookJP03
o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX0=OoonfX001kooo]Z00?o0000oookJ_oonfX0
AooonfX01?ooTP3ooo]ZoookJ_l0000UoookJP?ooj40oOoonfX00ol0003ooo]ZoookJP1eoookJP03
o`000?oonf[ooo]Z03Cooo]Z000NoookJP03o`000?oonf[ooo]Z04Oooo]Z0_ooTP02oookJP03o`00
0?oonf[ooo]Z02;ooo]Z0_ooX@3noookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX0
=?oonfX001gooo]Z00?o0000oookJ_oonfX0AooonfX3oonB00?ooo]Z00?o0000oookJ_oonfX0oooo
nfXSoookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX0<ooonfX001gooo]Z00?o0000
oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP3ooookJR;ooo]Z00?o0000oookJ_oonfX0JOoonfX0
0ooo003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z03?ooo]Z000MoookJP03o`000?oonf[ooo]Z
04oooo]Z00?o0000oookJ_oonfX0oooonfXQoookJP03o`000?oonf[ooo]Z07Kooo]Z00?o0000oook
J_oonfX0<_oonfX001gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP3ooookJR3o
oo]Z00?o0000oookJ_oonfX0F?oonfX00ooo0@3ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z037o
oo]Z000MoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0oooonfX<oookJP03ool1
0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0F?oonfX00ooo0@3ooo]ZoookJP0LoookJP03o`00
0?oonf[ooo]Z037ooo]Z000MoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0oooo
nfXNoookJP03o`000?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oonfX0<?oonfX001gooo]Z00?o0000
oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP3aoookJP03ool60?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX0A?oonfX2ool303?ooo]Z00?o0000oookJ_oonfX0;ooonfX001cooo]Z00?o0000oook
J_oonfX0EOoonfX00ol0003ooo]ZoookJP29oookJP;oo`T0IOoonfX00ooo1P3ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oonfX0;ooonfX001cooo]Z00?o0000oookJ_oo
nfX0E_oonfX00ol0003ooo]ZoookJP3ooookJQ_ooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003o
oo]ZoookJP0^oookJP007?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z00Wooo]Z
00?oodH0oookJ_oonfX0GOoonfX00ooo:03ooo]ZoookJP1WoookJP03ool>0?oonf[ooo]Z04?ooo]Z
00?o0000oookJ_oonfX0;_oonfX2ool604[ooo]Z00?o0000oookJ_oonfX0;_oonfX001cooo]Z00?o
0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP08oookJP03oom60?oonf[ooo]Z05kooo]Z00?o
obP0oookJ_oonfX0[?oonfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z02gooo]Z000L
oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX02?oonfX00oooAP3ooo]ZoookJP3o
oookJPgooo]Z00?o0000oookJ_oonfX0O?oonfX00ol0003ooo]ZoookJP0/oookJP007?oonfX00ol0
003ooo]ZoookJP0noookJP03oooY0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX01ooonfX2oom6
03[ooo]Z00?oodD0oookJ_oonfX0K?oonfX2oolD06;ooo]Z00?o0000oookJ_oonfX05_oonfX00ooo
203ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z02cooo]Z000KoookJP03o`000?oonf[ooo]Z03oo
oo]Z00?oonT0oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP13oookJP;oodD0K?oonfX2oolD06;o
oo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP0[oookJP006ooonfX00ol0003ooo]Z
oookJP0ooookJP03oooY0?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0@ooonfX00oooA@3ooo]Z
oookJP3>oookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX0:_oonfX001_ooo]Z00?o
0000oookJ_oonfX05_oonfX00ooo^@3ooo]ZoookJP0WoookJP03oooY0?oonf[ooo]Z01_ooo]Z00?o
0000oookJ_oonfX06_oonfX00ooo@@3ooo]ZoookJP3foookJP03o`000?oonf[ooo]Z07kooo]Z00?o
0000oookJ_oonfX0:_oonfX001_ooo]Z00?o0000oookJ_oonfX05_oonfX00ooo^@3ooo]ZoookJP0W
oookJP03oooY0?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX06OoonfX2oom1077ooo]Z0_oo5P21
oookJP;oo`T000?ooo]Zo`000?oonfX0P?oonfX00ol0003ooo]ZoookJP0YoookJP006ooonfX00ol0
003ooo]ZoookJP0FoookJP03ooni0?oonf[ooo]Z02Oooo]Z00?oonT0oookJ_oonfX07OoonfX00ol0
003ooo]ZoookJP0IoookJP03oom10?oonf[ooo]Z0?Kooo]Z00?o0000oookJ_oonfX0OooonfX00ol0
003ooo]ZoookJP0XoookJP006ooonfX00ol0003ooo]ZoookJP0FoookJP03ooni0?oonf[ooo]Z02Oo
oo]Z00?oonT0oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP3ooookJQ;ooo]Z00?o0000oookJ_oo
nfX0=?oonfX00ooo003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z02Sooo]Z000KoookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?ookT0oookJ_oonfX0:?oonfX00oooj@3ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z0?oooo]Z4OoonfX00ol0003ooo]ZoookJP20oookJP03o`000?oonf[ooo]Z02Oooo]Z
000JoookJP03o`000?oonf[ooo]Z01Gooo]Z0ooo^@0YoookJP?oonT08?oonfX00ol0003ooo]Zoook
JP3ooookJQ3ooo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]ZoookJP0WoookJP006_oonfX0
0ol0003ooo]ZoookJP0EoookJP?ookT0:?oonfX4oooY027ooo]Z00?o0000oookJ_oonfX0aooonfX2
ool204Gooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP0VoookJP006_oonfX00ol0
003ooo]ZoookJP0FoookJP;ookT0:_oonfX00oooj@3ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z
0?oooo]Z3_oonfX00ol0003ooo]ZoookJP0PoookJP03ool20?oonf[ooo]Z05oooo]Z00?o0000oook
J_oonfX09OoonfX001[ooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP3ooookJPgo
oo]Z00?o0000oookJ_oonfX0P_oonfX00ol0003ooo]ZoookJP0UoookJP006_oonfX00ol0003ooo]Z
oookJP1XoookJP03o`000?oonf[ooo]Z04Sooo]Z0_oo3`31oookJP03o`000?oonf[ooo]Z08?ooo]Z
00?o0000oookJ_oonfX09?oonfX001[ooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]Zoook
JP2YoookJP;oo`/0GooonfX00ol0003ooo]ZoookJP0:oookJP03ool60?oonf[ooo]Z07Oooo]Z00?o
0000oookJ_oonfX08ooonfX001Wooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP3o
oookJP[ooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP0SoookJP006OoonfX00ol0
003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z02Cooo]Z00?oodL0oookJ_oonfX0hOoonfX00ol0
003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z02;ooo]Z000IoookJP03o`000?oonf[ooo]Z06go
oo]Z00?o0000oookJ_oonfX08ooonfX00oooA`3ooo]ZoookJP1SoookJP03oolI0?oonf[ooo]Z07_o
oo]Z00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]ZoookJP0RoookJP006OoonfX00ol0003ooo]Z
oookJP1^oookJP;o00009?oonfX2oom706Cooo]Z00?ooaT0oookJ_oonfX0K_oonfX00ooo2P3ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX08OoonfX001Wooo]Z00?o
0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP0RoookJP03oom70?oonf[ooo]Z0=oooo]Z00?o
0000oookJ_oonfX0QOoonfX3o`0002;ooo]Z000IoookJP03o`000?oonf[ooo]Z06oooo]Z00?oogD0
oookJ_l00000oooonfX6oookJP03o`000?oonf[ooo]Z08;ooo]Z0ol00002oookJP03o`000?oonf[o
oo]Z023ooo]Z000IoookJP03o`000?oonf[ooo]Z06oooo]Z00CoogD0oookJ_oonf[o0000IOoonfX0
0ooo8`3ooo]ZoookJP2LoookJP03o`000?oonf[ooo]Z07oooo]Z0ol00005oookJP03o`000?oonf[o
oo]Z023ooo]Z000HoookJP03o`000?oonf[ooo]Z077ooo]Z00CoogD0oookJ_oonf[o0000IOoonfX0
0ooo8`3ooo]ZoookJP2KoookJP03o`000?oonf[ooo]Z07cooo]Z00?oo`00o`000?l000002?oonfX0
0ol0003ooo]ZoookJP0PoookJP006?oonfX00ol0003ooo]ZoookJP1aoookJP?oogD000?ooo]Zo`00
0?oonfX0fOoonfX2ool=02Oooo]Z00?o0000oookJ_oonfX0N?oonfX3o`0000_ooo]Z00?o0000oook
J_oonfX08?oonfX001Sooo]Z00?o0000oookJ_oonfX0B?oonfX00oooH03ooo]ZoookJP0VoookJP?o
ogD00_oonfX00ol0003ooo]ZoookJP3ooookJP7ooo]Z00Co0000oookJ_oonf[oo`00M?oonfX3o`00
00oooo]Z00?o0000oookJ_oonfX07ooonfX001Sooo]Z00?o0000oookJ_oonfX0B?oonfX00oooH03o
oo]ZoookJP0WoookJP03oome0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0oooonfX01?l0003o
oo]ZoookJ_oo001aoookJP?o00004_oonfX00ol0003ooo]ZoookJP0OoookJP006?oonfX00ol0003o
oo]ZoookJP18oookJP03oomP0?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0>_oonfX2oolR0<;o
oo]Z00?o0000oookJ_oonfX0JooonfX2ool10003oookJ_l0003o000000;o00005OoonfX00ol0003o
oo]ZoookJP0OoookJP006?oonfX00ol0003ooo]ZoookJP17oookJP?oof00;ooonfX00ol0003ooo]Z
oookJP0ioookJP03oolR0?oonf[ooo]Z04Wooo]Z00?oo`@0oookJ_oonfX0;OoonfX00ooo3P3ooo]Z
oookJP15oookJP03o`000?oonf[ooo]Z06_ooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z01oooo]Z
000GoookJP03o`000?oonf[ooo]Z04Wooo]Z00?oof00oookJ_oonfX0;ooonfX00ol0003ooo]Zoook
JP2doookJP03ool>0?oonf[ooo]Z037ooo]Z0_oo100BoookJP03o`000?oonf[ooo]Z06Sooo]Z0ol0
000LoookJP03o`000?oonf[ooo]Z01oooo]Z000GoookJP03o`000?oonf[ooo]Z07cooo]Z00?o0000
oookJ_oonfX0j?oonfX00ooo103ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z06Gooo]Z0ol0000O
oookJP03o`000?oonf[ooo]Z01oooo]Z000GoookJP03o`000?oonf[ooo]Z07gooo]Z00?o0000oook
J_oonfX01ooonfX2oolB0?7ooo]Z00?o0000oookJ_oonfX0F_oonfX00ooo0P3ooo]ZoookJP05oook
JP?o00008_oonfX00ol0003ooo]ZoookJP0OoookJP005ooonfX00ol0003ooo]ZoookJP1noookJP03
o`000?oonf[ooo]Z06Cooo]Z0_oo4`2CoookJP03o`000?oonf[ooo]Z05oooo]Z0ol0000VoookJP03
o`000?oonf[ooo]Z01kooo]Z000GoookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX0
I?oonfX00ooo4`3ooo]ZoookJP2AoookJP03o`000?oonf[ooo]Z05cooo]Z0ol0000YoookJP03o`00
0?oonf[ooo]Z01kooo]Z000GoookJP03o`000?oonf[ooo]Z083ooo]Z00?o0000oookJ_oonfX0booo
nfX2ool:02[ooo]Z00?o0000oookJ_oonfX0FOoonfX3o`0002cooo]Z00?o0000oookJ_oonfX07_oo
nfX001Kooo]Z00?o0000oookJ_oonfX0I_oonfX00oooFP3ooo]ZoookJP0IoookJP03o`000?oonf[o
oo]Z0?Kooo]Z00?o0000oookJ_oonfX0EOoonfX4o`0002oooo]Z00?o0000oookJ_oonfX07_oonfX0
01Kooo]Z00?o0000oookJ_oonfX0I_oonfX00oooFP3ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z
0?Gooo]Z00?o0000oookJ_oonfX0A_oonfX2ool500[ooo]Z0ol0000coookJP03o`000?oonf[ooo]Z
01kooo]Z000FoookJP03o`000?oonf[ooo]Z06Kooo]Z00?ooeX0oookJ_oonfX06ooonfX00ol0003o
oo]ZoookJP10oookJP03ool]0?oonf[ooo]Z0;7ooo]Z00?o0000oookJ_oonfX0CooonfX3o`0003Ko
oo]Z00?o0000oookJ_oonfX07_oonfX001Kooo]Z00?o0000oookJ_oonfX0IooonfX2oomJ01cooo]Z
00?o0000oookJ_oonfX0@?oonfX00ooo;@3ooo]ZoookJP2`oookJP03o`000?oonf[ooo]Z04cooo]Z
0ol0000ioookJP03o`000?oonf[ooo]Z01kooo]Z000FoookJP03o`000?oonf[ooo]Z043ooo]Z00?o
oi80oookJ_oonfX09?oonfX00oooFP3ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o
oa40oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP18oookJP04ool00?l0003o0000o`0003cooo]Z
00?o0000oookJ_oonfX07_oonfX001Kooo]Z00?o0000oookJ_oonfX0@?oonfX00oooTP3ooo]Zoook
JP14oookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX0A_oonfX3o`00043ooo]Z00?o
0000oookJ_oonfX07OoonfX001Kooo]Z00?o0000oookJ_oonfX0@?oonfX00oooTP3ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z0?7ooo]Z00?o0000oookJ_oonfX0;ooonfX2ool7017ooo]Z0ol00013
oookJP03o`000?oonf[ooo]Z01gooo]Z000EoookJP03o`000?oonf[ooo]Z047ooo]Z00?ooi80oook
J_oonfX0A_oonfX00ol0003ooo]ZoookJP0HoookJP03oolj0?oonf[ooo]Z0:Gooo]Z0_oo0@0^oook
JP03o`000?oonf[ooo]Z03kooo]Z1?l00016oookJP03o`000?oonf[ooo]Z01gooo]Z000EoookJP03
o`000?oonf[ooo]Z047ooo]Z00?ooi80oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0GoookJP;o
ocX0e_oonfX00ol0003ooo]ZoookJP0koookJP?o0000B_oonfX00ol0003ooo]ZoookJP0MoookJP00
5OoonfX00ol0003ooo]ZoookJP11oookJP;ooi80BOoonfX00ol0003ooo]ZoookJP0GoookJP03oolj
0?oonf[ooo]Z02cooo]Z00?oo`D0oookJ_oonfX0?_oonfX2oolD06Gooo]Z00?o0000oookJ_oonfX0
=OoonfX00ooo0@3ooo]ZoookJP03o`0004gooo]Z00?o0000oookJ_oonfX07OoonfX001Gooo]Z00?o
0000oookJ_oonfX05_oonfX00oooL03ooo]ZoookJP0WoookJP?ooi80B_oonfX00ol0003ooo]Zoook
JP26oookJP;ooa@0IOoonfX00ol0003ooo]ZoookJP0eoookJP?o0000D?oonfX00ol0003ooo]Zoook
JP0MoookJP005OoonfX00ol0003ooo]ZoookJP0FoookJP03oom`0?oonf[ooo]Z02Sooo]Z00?ooi80
oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP2ToookJP;oo`H0A_oonfX00ol0003ooo]ZoookJP0b
oookJP?o0000DooonfX00ol0003ooo]ZoookJP0MoookJP005OoonfX00ol0003ooo]ZoookJP0Foook
JP03oom`0?oonf[ooo]Z06Gooo]Z00?ooc<0oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP2Soook
JP03ool60?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX05_oonfX2ool901Oooo]Z0ol0001Goook
JP03o`000?oonf[ooo]Z01cooo]Z000DoookJP03o`000?oonf[ooo]Z01Kooo]Z0_ooL01WoookJP03
oolc0?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0j?oonfX3o`0002kooo]Z0ol0001JoookJP03
o`000?oonf[ooo]Z01cooo]Z000DoookJP03o`000?oonf[ooo]Z01Kooo]Z0_ooL01WoookJP03oolc
0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX08_oonfX00ooo7@3ooo]ZoookJP2ooookJP?o0000
0_oonfX00ol0003ooo]ZoookJP0QoookJP03ool40?oonf[ooo]Z00Gooo]Z0ol0001MoookJP03o`00
0?oonf[ooo]Z01cooo]Z000DoookJP03o`000?oonf[ooo]Z09?ooo]Z00?o0000oookJ_oonfX08_oo
nfX00ooo7@3ooo]ZoookJP0ioookJP03oolD0?oonf[ooo]Z07oooo]Z0ol00006oookJP03o`000?oo
nf[ooo]Z02Cooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z01cooo]Z000DoookJP03o`000?oonf[o
oo]Z09Cooo]Z00?o0000oookJ_oonfX0G_oonfX00ooo503ooo]ZoookJP1koookJP?o00002_oonfX0
0ol0003ooo]ZoookJP0PoookJP?o0000I?oonfX00ol0003ooo]ZoookJP0LoookJP005?oonfX00ol0
003ooo]ZoookJP2EoookJP03o`000?oonf[ooo]Z08?ooo]Z0_oo401CoookJP?o00003_oonfX00ol0
003ooo]ZoookJP0LoookJP?o0000IooonfX00ol0003ooo]ZoookJP0LoookJP005?oonfX00ol0003o
oo]ZoookJP2FoookJP03o`000?oonf[ooo]Z0=Cooo]Z0ol0000AoookJP03o`000?oonf[ooo]Z01Wo
oo]Z0ol0001ZoookJP03o`000?oonf[ooo]Z01cooo]Z000DoookJP03o`000?oonf[ooo]Z09Kooo]Z
00?oodD0o`000?oonfX0dOoonfX3o`0000kooo]Z0_oo2@05oookJP03o`000?oonf[ooo]Z01Gooo]Z
0ol0001]oookJP03o`000?oonf[ooo]Z01cooo]Z000CoookJP03o`000?oonf[ooo]Z09Oooo]Z00?o
odD0oookJ_l00000c_oonfX3o`0001Wooo]Z00?o0000oookJ_oonfX01OoonfX2ool800Wooo]Z00Co
o`00o`000?l0003o0000LOoonfX00ol0003ooo]ZoookJP0KoookJP004ooonfX00ol0003ooo]Zoook
JP2HoookJP03oom50?oonf[o00000<[ooo]Z0ol0000MoookJP03o`000?oonf[ooo]Z00gooo]Z0ol0
001doookJP03o`000?oonf[ooo]Z01_ooo]Z000CoookJP03o`000?oonf[ooo]Z09Sooo]Z00CoodD0
oookJ_oonf[o0000H_oonfX00ooo6`3ooo]ZoookJP0OoookJP03ool10?oonf[ooo]Z03oooo]Z0ol0
000QoookJP03o`000?oonf[ooo]Z00Sooo]Z1?l0001goookJP03o`000?oonf[ooo]Z01_ooo]Z000C
oookJP03o`000?oonf[ooo]Z09cooo]Z00?o0000oookJ_oonfX0H?oonfX00ooo6`3ooo]ZoookJP0N
oookJP03ool10?oonf[ooo]Z03cooo]Z0ol0000ToookJP03o`000?oonf[ooo]Z00Gooo]Z0ol0001`
oookJP03ool00?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX06ooonfX001?ooo]Z00?o0000oook
J_oonfX0WOoonfX00ol0003ooo]ZoookJP2koookJPCo0000:?oonfX01?l0003ooo]ZoookJ_oonfX3
o`0007kooo]Z00?o0000oookJ_oonfX06ooonfX001?ooo]Z00?o0000oookJ_oonfX0LOoonfX00ooo
E03ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00?oo`H0oookJ_oonfX0[?oonfX3o`00
02Sooo]Z00?oo`80oookJ_oonfX00_oonfX3o`00087ooo]Z00?o0000oookJ_oonfX06ooonfX001;o
oo]Z00?o0000oookJ_oonfX0L_oonfX00oooE03ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z0;?o
oo]Z0ol0000KoookJP;oo`/04?oonfX3o`000003oookJ_l0003ooo]Z087ooo]Z00?o0000oookJ_oo
nfX06ooonfX001;ooo]Z00?o0000oookJ_oonfX0LooonfX00oooE03ooo]ZoookJP0[oookJP03o`00
0?oonf[ooo]Z0:oooo]Z0ol0000]oookJP?o00001?oonfX00ol0003ooo]ZoookJP21oookJP03o`00
0?oonf[ooo]Z01[ooo]Z000BoookJP03o`000?oonf[ooo]Z07?ooo]Z0_ooE00]oookJP03o`000?oo
nf[ooo]Z067ooo]Z0_oo2@18oookJP?o0000;OoonfX3o`0000Sooo]Z00?o0000oookJ_oonfX0I?oo
nfX00ooo0P3ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z01[ooo]Z000BoookJP03o`000?oonf[o
oo]Z07Cooo]Z00?ooe@0oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0hoookJP03oolP0?oonf[o
oo]Z06cooo]Z0ol0000]oookJP?o00003?oonfX00ol0003ooo]ZoookJP1SoookJP03ool20?oonf[o
oo]Z01Wooo]Z00?o0000oookJ_oonfX06_oonfX001;ooo]Z00?o0000oookJ_oonfX0R_oonfX00ooo
8P3ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z03Oooo]Z0_oo801ZoookJP?o0000;?oonfX4o`00
013ooo]Z00?o0000oookJ_oonfX0O_oonfX00ol0003ooo]ZoookJP0JoookJP004_oonfX00ol0003o
oo]ZoookJP2:oookJP03oolR0?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0WooonfX3o`0002?o
oo]Z0_oo1P07oookJP?o00005OoonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z01[o
oo]Z000BoookJP03o`000?oonf[ooo]Z04Wooo]Z00?ood<0oookJ_oonfX0?_oonfX00ooo8P3ooo]Z
oookJP0IoookJP03o`000?oonf[ooo]Z09_ooo]Z0ol0000/oookJP?o00006?oonfX00ol0003ooo]Z
oookJP1moookJP03o`000?oonf[ooo]Z01[ooo]Z000AoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o
od<0oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP2GoookJP?o00005?oonfX00ooo3@3ooo]Zoook
JP0EoookJP?o00007?oonfX00ol0003ooo]ZoookJP1loookJP03o`000?oonf[ooo]Z01[ooo]Z000A
oookJP03o`000?oonf[ooo]Z04[ooo]Z00?ood<0oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0n
oookJP;ooaT0DooonfX3o`0002cooo]Z0ol0000PoookJP03o`000?oonf[ooo]Z07cooo]Z00?o0000
oookJ_oonfX06OoonfX0017ooo]Z00?o0000oookJ_oonfX0Z_oonfX00ol0003ooo]ZoookJP0noook
JP03oolI0?oonf[ooo]Z04gooo]Z1?l0000ZoookJP03ool00?oonf[o000000;o00009?oonfX00ol0
003ooo]ZoookJP1<oookJP03ool40?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX06OoonfX0017o
oo]Z00?o0000oookJ_oonfX0IooonfX00oooD@3ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z00_o
oo]Z00?ooad0oookJ_oonfX0O?oonfX3o`0002gooo]Z0ol0000WoookJP03o`000?oonf[ooo]Z07_o
oo]Z00?o0000oookJ_oonfX06OoonfX0017ooo]Z00?o0000oookJ_oonfX0IooonfX00oooD@3ooo]Z
oookJP12oookJP03o`000?oonf[ooo]Z00_ooo]Z00?ooad0oookJ_oonfX0N?oonfX3o`0002cooo]Z
1?l0000[oookJP03o`000?oonf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX06OoonfX0017ooo]Z00?o
0000oookJ_oonfX0IooonfX00oooD@3ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z04?ooo]Z0_oo
0P0moookJP?o00008?oonfX2ool<00[ooo]Z0ol0000`oookJP03o`000?oonf[ooo]Z07Wooo]Z00?o
0000oookJ_oonfX06OoonfX0013ooo]Z00?o0000oookJ_oonfX0JOoonfX00oooD@3ooo]ZoookJP13
oookJP03o`000?oonf[ooo]Z07kooo]Z0ol0000/oookJP?o0000=?oonfX00ol0003ooo]ZoookJP0f
oookJP;oo`40@?oonfX00ol0003ooo]ZoookJP0IoookJP004?oonfX00ol0003ooo]ZoookJP1Yoook
JP03oomA0?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX06?oonfX00ooo:P3ooo]ZoookJP1Ooook
JP?o0000;?oonfX3o`0003Sooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP0Ioook
JP004?oonfX00ol0003ooo]ZoookJP2aoookJP03o`000?oonf[ooo]Z01Oooo]Z00?oobX0oookJ_oo
nfX0G?oonfX3o`0000gooo]Z00?oo`d0oookJ_oonfX05_oonfX2ool300Cooo]Z0ol0000koookJP03
o`000?oonf[ooo]Z07Oooo]Z00?o0000oookJ_oonfX06OoonfX0013ooo]Z00?o0000oookJ_oonfX0
/_oonfX00ol0003ooo]ZoookJP0GoookJP03oolZ0?oonf[ooo]Z05Sooo]Z0ol0000ZoookJP03ool3
0?oonf[o000000;o0000?ooonfX00ol0003ooo]ZoookJP0coookJP;oo`H0@_oonfX00ol0003ooo]Z
oookJP0HoookJP004?oonfX00ol0003ooo]ZoookJP11oookJP03oomP0?oonf[ooo]Z06oooo]Z00?o
0000oookJ_oonfX0K_oonfX3o`0002cooo]Z0ol00013oookJP03o`000?oonf[ooo]Z07Kooo]Z00?o
0000oookJ_oonfX06?oonfX0013ooo]Z00?o0000oookJ_oonfX0@OoonfX00oooH03ooo]ZoookJP1`
oookJP03o`000?oonf[ooo]Z027ooo]Z0_oo3017oookJP?o0000;?oonfX3o`0004Oooo]Z00?o0000
oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP0HoookJP003ooonfX00ol0003ooo]ZoookJP12oook
JP03oomP0?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX0I_oonfX3o`0001Wooo]Z0_oo4@0@oook
JPCo0000B_oonfX00ol0003ooo]ZoookJP0PoookJP03ool30?oonf[ooo]Z05;ooo]Z00?o0000oook
J_oonfX06?oonfX000oooo]Z00?o0000oookJ_oonfX0@_oonfX2oomP07?ooo]Z00?o0000oookJ_oo
nfX0HOoonfX4o`0001gooo]Z00?ooa40oookJ_oonfX02ooonfX3o`0004oooo]Z00?o0000oookJ_oo
nfX07ooonfX00ooo0`3ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01Sooo]Z000?oookJP03o`00
0?oonf[ooo]Z04;ooo]Z0_ooH01doookJP03o`000?oonf[ooo]Z05gooo]Z0ol0000/oookJP?o0000
DooonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z01Sooo]Z000?oookJP03o`000?oo
nf[ooo]Z04;ooo]Z00?oof00oookJ_oonfX0HooonfX00ooo;`3ooo]ZoookJP0>oookJP03o`000?oo
nf[ooo]Z05Wooo]Z0ol0000ToookJP03ool:0?oonf[ooo]Z00Gooo]Z0ol0001GoookJP03o`000?oo
nf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX06?oonfX000oooo]Z00?o0000oookJ_oonfX0Z?oonfX2
ool_013ooo]Z00?o0000oookJ_oonfX0EOoonfX3o`0002cooo]Z0ol0001KoookJP03o`000?oonf[o
oo]Z07;ooo]Z00?o0000oookJ_oonfX05ooonfX000oooo]Z00?o0000oookJ_oonfX0ZOoonfX00ooo
;`3ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z057ooo]Z0ol0000ZoookJP03ool00?oonf[o0000
00;o0000G_oonfX00ol0003ooo]ZoookJP0GoookJP03ool80?oonf[ooo]Z05Sooo]Z00?o0000oook
J_oonfX05ooonfX000oooo]Z00?o0000oookJ_oonfX05_oonfX00oooB`3ooo]ZoookJP2QoookJP;o
ob<000?o0000oookJ_oonfX0COoonfX3o`0002cooo]Z0ol0001RoookJP03o`000?oonf[ooo]Z077o
oo]Z00?o0000oookJ_oonfX05ooonfX000kooo]Z00?o0000oookJ_oonfX05ooonfX00oooB`3ooo]Z
oookJP2RoookJP03oolS0?oonf[o000000_ooo]Z00?oo`80oookJ_oonfX0?OoonfX3o`0002_ooo]Z
1?l0001VoookJP03o`000?oonf[ooo]Z00Kooo]Z00?oo`H0oookJ_oonfX0IooonfX00ol0003ooo]Z
oookJP0GoookJP003_oonfX00ol0003ooo]ZoookJP0FoookJP;ood/0YooonfX00ol0003ooo]Zoook
JP07oookJP;oo`80??oonfX3o`0001?ooo]Z00?ooa<0oookJ_oonfX05OoonfX3o`0006_ooo]Z00?o
0000oookJ_oonfX01OoonfX00ooo1P3ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z01Oooo]Z000>
oookJP03o`000?oonf[ooo]Z01Oooo]Z00?ood/0oookJ_oonfX0Y_oonfX00ol0003ooo]ZoookJP11
oookJP?o00005_oonfX2oolC01?ooo]Z0ol0001ZoookJP05ool10?oonf[ooo]ZoookJ_l00000LOoo
nfX00ol0003ooo]ZoookJP0GoookJP003_oonfX00ol0003ooo]ZoookJP31oookJP03o`000?oonf[o
oo]Z03gooo]Z0ol0000MoookJP03oolC0?oonf[ooo]Z00_ooo]Z0ol0001]oookJP03ool10?oonf[o
oo]Z00;ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP0GoookJP003_oonfX00ol0
003ooo]ZoookJP21oookJP03oolX0?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0>OoonfX3o`00
027ooo]Z00?ooa<0oookJ_oonfX01ooonfX3o`0007Kooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0
003ooo]ZoookJP0GoookJP003_oonfX00ol0003ooo]ZoookJP21oookJP03oolX0?oonf[ooo]Z03oo
oo]Z00?o0000oookJ_oonfX0=?oonfX4o`0002Oooo]Z00Coo`@0oookJ_oonf[ooo]Z0ol0001joook
JP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX05_oonfX000gooo]Z00?o0000oookJ_oo
nfX0P_oonfX00ooo:03ooo]ZoookJP0EoookJP03oolj0?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oo
nfX0<?oonfX3o`0002cooo]Z0ol0001moookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oo
nfX05_oonfX000gooo]Z00?o0000oookJ_oonfX0V_oonfX00ooo>P3ooo]ZoookJP0@oookJP03ool>
0?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0;?oonfX3o`0002cooo]Z0ol0001koookJP03ool9
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0H?oonfX2ool100[ooo]Z00?o0000oookJ_oonfX0
5_oonfX000gooo]Z00?o0000oookJ_oonfX0V_oonfX2oolj017ooo]Z00?oo`h0oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP0XoookJP?o0000:ooonfX4o`0008Gooo]Z00?o0000oookJ_oonfX0Jooo
nfX00ol0003ooo]ZoookJP0FoookJP003OoonfX00ol0003ooo]ZoookJP38oookJP03o`000?oonf[o
oo]Z02Cooo]Z0ol0000[oookJP?o0000MOoonfX00ooo2@3ooo]ZoookJP0BoookJP03o`000?oonf[o
oo]Z06[ooo]Z00?o0000oookJ_oonfX05_oonfX000gooo]Z00?o0000oookJ_oonfX0bOoonfX00ol0
003ooo]ZoookJP0PoookJP?o00002ooonfX00ooo4P3ooo]ZoookJP0MoookJP?o0000K_oonfX00ooo
103ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX05_oonfX000go
oo]Z00?o0000oookJ_oonfX0b_oonfX00ol0003ooo]ZoookJP0LoookJP?o00003ooonfX00ooo4P3o
oo]ZoookJP06oookJP03oolJ0?oonf[ooo]Z013ooo]Z0ol0002AoookJP03o`000?oonf[ooo]Z06Wo
oo]Z00?o0000oookJ_oonfX05_oonfX000gooo]Z00?o0000oookJ_oonfX0booonfX00ol0003ooo]Z
oookJP0HoookJP?o00006ooonfX2oolJ00Gooo]Z0_oo3P07oookJP?o0000UOoonfX00ol0003ooo]Z
oookJP1YoookJP03o`000?oonf[ooo]Z01Gooo]Z000<oookJP03o`000?oonf[ooo]Z0<gooo]Z00?o
0000oookJ_oonfX05?oonfX3o`0002Gooo]Z00?oo`h0oookJ_oonfX00ooonfX00ooo0@3o0000o`00
002IoookJP03o`000?oonf[ooo]Z06Sooo]Z00?o0000oookJ_oonfX05OoonfX000cooo]Z00?o0000
oookJ_oonfX0MOoonfX00ooo?@3ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z013ooo]Z0ol0000[
oookJP?o0000WOoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z01Gooo]Z000<oook
JP03o`000?oonf[ooo]Z07Gooo]Z00?oocd0oookJ_oonfX05OoonfX00ooo9`3ooo]ZoookJP0ooook
JP03o`000?oonf[ooo]Z00cooo]Z0ol0000ZoookJPCo0000X?oonfX00ol0003ooo]ZoookJP1:oook
JP;oo`<06ooonfX00ol0003ooo]ZoookJP0EoookJP003?oonfX00ol0003ooo]ZoookJP1eoookJP;o
ocd05_oonfX2oolW047ooo]Z00?o0000oookJ_oonfX01ooonfX4o`0002[ooo]Z0ol0002UoookJP03
o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX05OoonfX000cooo]Z00?o0000oookJ_oonfX0
MOoonfX00ooo?@3ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000[oookJP?o0000
J?oonfX00ooo0P3ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0
5OoonfX000cooo]Z00?o0000oookJ_oonfX0d_oonfX00ol0003ooo]Zo`000002o`0002_ooo]Z0ol0
001ZoookJP;oo`801?oonfX2ool800Gooo]Z0_oo300doookJP03o`000?oonf[ooo]Z06Cooo]Z00?o
0000oookJ_oonfX05OoonfX000_ooo]Z00?o0000oookJ_oonfX0d_oonfX3o`0002_ooo]Z0ol0002a
oookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX05OoonfX000_ooo]Z00?o0000oook
J_oonfX0cooonfX3o`0000?ooo]Z00?o0000oookJ_oonfX05ooonfX00ooo6`3ooo]ZoookJP07oook
JP04ool60?oonf[ooo]ZoookJP?o0000]?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[o
oo]Z01Cooo]Z000;oookJP03o`000?oonf[ooo]Z0<cooo]Z0ol00007oookJP03o`000?oonf[ooo]Z
00[ooo]Z0_oo700;oookJP03oolK0?oonf[ooo]Z00Oooo]Z0ol0002hoookJP03o`000?oonf[ooo]Z
06?ooo]Z00?o0000oookJ_oonfX05?oonfX000_ooo]Z00?o0000oookJ_oonfX0bOoonfX3o`0000_o
oo]Z00?o0000oookJ_oonfX02_oonfX00ooo703ooo]ZoookJP0@oookJP?o0000_?oonfX00ol0003o
oo]ZoookJP1RoookJP03o`000?oonf[ooo]Z01Cooo]Z000;oookJP03o`000?oonf[ooo]Z04_ooo]Z
00?ooc40oookJ_oonfX06ooonfX00ooo@@3ooo]ZoookJP1JoookJP?o00003ooonfX00ol0003ooo]Z
oookJP0HoookJPCo0000`?oonfX00ol0003ooo]ZoookJP0NoookJP03ool20?oonf[ooo]Z043ooo]Z
00?o0000oookJ_oonfX05?oonfX000_ooo]Z00?o0000oookJ_oonfX0BooonfX00ooo<@3ooo]Zoook
JP0KoookJP03oom10?oonf[ooo]Z05Oooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0
0034oookJP03o`000?oonf[ooo]Z03;ooo]Z00?oo`D0oookJ_oonfX0;?oonfX00ol0003ooo]Zoook
JP0DoookJP002ooonfX00ol0003ooo]ZoookJP1:oookJP;ooc407_oonfX00ooo@@3ooo]ZoookJP1C
oookJP?o00005ooonfX00ol0003ooo]ZoookJP0@oookJP?o0000J_oonfX00ooo1P3ooo]ZoookJP1K
oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX05?oonfX000[ooo]Z00?o0000oook
J_oonfX0JooonfX00ooo@@3ooo]ZoookJP1?oookJPCo00006ooonfX00ol0003ooo]ZoookJP0<oook
JP?o0000KOoonfX01?oo1P3ooo]ZoookJ_oo3P1KoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000
oookJ_oonfX05?oonfX000[ooo]Z00?o0000oookJ_oonfX0^_oonfX3o`00023ooo]Z00?o0000oook
J_oonfX02?oonfX00ooo0@3o0000o`00001coookJP03ool>0?oonf[ooo]Z05[ooo]Z00?o0000oook
J_oonfX0GooonfX00ol0003ooo]ZoookJP0CoookJP002_oonfX00ol0003ooo]ZoookJP2goookJP?o
00008ooonfX2oolB00Kooo]Z0ol0001ioookJP;oo`d0FOoonfX00ol0003ooo]ZoookJP1NoookJP03
o`000?oonf[ooo]Z01?ooo]Z000:oookJP03o`000?oonf[ooo]Z0;Cooo]Z0ol0000HoookJP03oolU
0?oonf[ooo]Z00_ooo]Z00?ooa80oookJ_l000000_oonfX3o`000=Oooo]Z00?o0000oookJ_oonfX0
G_oonfX00ol0003ooo]ZoookJP0CoookJP002_oonfX00ol0003ooo]ZoookJP2aoookJP?o00006ooo
nfX2oolU00oooo]Z0_l0003KoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX04ooo
nfX000[ooo]Z00?o0000oookJ_oonfX0[_oonfX3o`0000gooo]Z00?ooaT0oookJ_oonfX03ooonfX0
0ooo9@3ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0=_ooo]Z00?o0000oookJ_oonfX01_oonfX0
0ooo103ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z01?ooo]Z0009oookJP03o`000?oonf[ooo]Z
04?ooo]Z00?ood<0oookJ_oonfX0I_oonfX3o`00013ooo]Z00?ooaT0oookJ_oonfX07ooonfX00ol0
003ooo]ZoookJP1OoookJP03ool20?oonf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX01?oonfX2ool4
05Gooo]Z00?o0000oookJ_oonfX04ooonfX000Wooo]Z00?o0000oookJ_oonfX0@ooonfX00ooo@`3o
oo]ZoookJP1SoookJP?o0000=OoonfX00ol0003ooo]ZoookJP3LoookJP03o`000?oonf[ooo]Z01Oo
oo]Z00?oo`L0oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0CoookJP002OoonfX00ol0003ooo]Z
oookJP13oookJP03oom30?oonf[ooo]Z063ooo]Z0ol0000ToookJP03ool60?oonf[ooo]Z017ooo]Z
00?o0000oookJ_oonfX0G_oonfX2ool<07gooo]Z00?o0000oookJ_oonfX05_oonfX00ooo1`3ooo]Z
oookJP11oookJP03o`000?oonf[ooo]Z01?ooo]Z0009oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o
od<0oookJ_oonfX0GOoonfX3o`0002Oooo]Z00?oo`H0oookJ_oonfX04OoonfX00ol0003ooo]Zoook
JP1OoookJP03ool<0?oonf[ooo]Z07cooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]Zoook
JP0BoookJP002OoonfX00ol0003ooo]ZoookJP2PoookJP?o0000?_oonfX00ol0003ooo]ZoookJP1N
oookJP03oolA0?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0B
oookJP002OoonfX00ol0003ooo]ZoookJP2LoookJPCo00007_oonfX00ooo8`3ooo]ZoookJP0Poook
JP03o`000?oonf[ooo]Z05kooo]Z0_oo4@20oookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oook
J_oonfX04_oonfX000Sooo]Z00?o0000oookJ_oonfX0V_oonfX3o`0002?ooo]Z00?oob<0oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP32oookJP03ool20?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oo
nfX0F?oonfX00ol0003ooo]ZoookJP0BoookJP002?oonfX00ol0003ooo]ZoookJP2GoookJP?o0000
4_oonfX00ooo9P3ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z0<;ooo]Z00?oo`80oookJ_oonfX0
7?oonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z01;ooo]Z0008oookJP03o`000?oo
nf[ooo]Z09Cooo]Z0ol0000EoookJP;oobH0=?oonfX00ol0003ooo]ZoookJP3RoookJP03o`000?oo
nf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX04_oonfX000Sooo]Z00?o0000oookJ_oonfX0TOoonfX3
o`0001Wooo]Z00?oobH0oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP16oookJP03ool70?oonf[o
oo]Z08Kooo]Z00?oo`L0oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[o
oo]Z01;ooo]Z0008oookJP03o`000?oonf[ooo]Z01Oooo]Z00?oocD0oookJ_oonfX0M?oonfX3o`00
057ooo]Z00?o0000oookJ_oonfX0hooonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z
017ooo]Z0008oookJP03o`000?oonf[ooo]Z01Oooo]Z00?oocD0oookJ_oonfX0LOoonfX3o`00027o
oo]Z00?ooa<0oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP3ToookJP03o`000?oonf[ooo]Z05Go
oo]Z00?o0000oookJ_oonfX04OoonfX000Sooo]Z00?o0000oookJ_oonfX05_oonfX2oole073ooo]Z
0ol0000UoookJP03oolC0?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0@_oonfX2oolC0:7ooo]Z
00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0AoookJP001ooonfX00ol0003ooo]Zoook
JP26oookJP?o0000FOoonfX00ol0003ooo]ZoookJP3PoookJP03ool80?oonf[ooo]Z00Cooo]Z00?o
0000oookJ_oonfX0AooonfX2ool200[ooo]Z00?o0000oookJ_oonfX04OoonfX000Oooo]Z00?o0000
oookJ_oonfX0PooonfX3o`0001Oooo]Z00?oobl0oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0b
oookJP03ool30?oonf[ooo]Z0;?ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0A
oookJP001ooonfX00ol0003ooo]ZoookJP20oookJP?o00006_oonfX00ooo;`3ooo]ZoookJP12oook
JP03o`000?oonf[ooo]Z037ooo]Z0_oo0`0<oookJP03oolB0?oonf[ooo]Z06gooo]Z00?oo`H0oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z017ooo]Z0007oookJP03
o`000?oonf[ooo]Z07cooo]Z1?l0000MoookJP;oobl0@ooonfX00ol0003ooo]ZoookJP0ooookJP03
oolB0?oonf[ooo]Z06cooo]Z0_oo1P0ioookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oo
nfX04OoonfX000Oooo]Z00?o0000oookJ_oonfX0NOoonfX3o`0006Kooo]Z00?o0000oookJ_oonfX0
j_oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z017ooo]Z0007oookJP03o`000?oo
nf[ooo]Z07Kooo]Z0ol0000;oookJP03oolP0?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ooo4@3ooo]ZoookJP2loookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX04?oo
nfX000Kooo]Z00?o0000oookJ_oonfX0M?oonfX3o`0000kooo]Z00?oob00oookJ_oonfX0FooonfX0
0ol0003ooo]ZoookJP0/oookJP03oolA0?oonf[ooo]Z0;cooo]Z00?o0000oookJ_oonfX0D?oonfX0
0ol0003ooo]ZoookJP0@oookJP001_oonfX00ol0003ooo]ZoookJP1aoookJP?o00004OoonfX00ooo
803ooo]ZoookJP08oookJP03oolV0?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0^OoonfX00ooo
2P3ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX04?oonfX000Ko
oo]Z00?o0000oookJ_oonfX0K_oonfX3o`0001oooo]Z00?oobH0oookJ_oonfX0D?oonfX00ol0003o
oo]ZoookJP2AoookJP03ool30?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003o
oo]ZoookJP0@oookJP001_oonfX00ol0003ooo]ZoookJP1[oookJP?o00008_oonfX00ooo9P3ooo]Z
oookJP1@oookJP03o`000?oonf[ooo]Z02Cooo]Z00?ooaP0oookJ_oonfX0aooonfX00ol0003ooo]Z
oookJP1=oookJP03o`000?oonf[ooo]Z013ooo]Z0006oookJP03o`000?oonf[ooo]Z06Sooo]Z0ol0
001hoookJP03o`000?oonf[ooo]Z02Gooo]Z00?ooaP0oookJ_oonfX0a_oonfX00ol0003ooo]Zoook
JP0`oookJP;oo`@06ooonfX00ol0003ooo]ZoookJP0@oookJP001_oonfX00ol0003ooo]ZoookJP1U
oookJP?o0000NooonfX00ol0003ooo]ZoookJP0GoookJP03ool90?oonf[ooo]Z0=Gooo]Z00?o0000
oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0@oookJP001_oonfX00ol0003ooo]ZoookJP1Roook
JP?o00004_oonfX00ooo;P3ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oook
J_oonfX0C?oonfX00ol0003ooo]ZoookJP0?oookJP001OoonfX00ol0003ooo]ZoookJP1PoookJP?o
00005OoonfX00ooo;P3ooo]ZoookJP1YoookJP03o`000?oonf[ooo]Z09Oooo]Z0_oo2P1HoookJP03
o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX03ooonfX000Gooo]Z00?o0000oookJ_oonfX0
G?oonfX4o`0001Sooo]Z00?oobh0oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP3boookJP03o`00
0?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX03ooonfX000Gooo]Z00?o0000oookJ_oonfX0FOoo
nfX3o`0008Sooo]Z00?o0000oookJ_oonfX01OoonfX00ooo0`3ooo]ZoookJP05oookJP03oolJ0?oo
nf[ooo]Z0>;ooo]Z00?o0000oookJ_oonfX01_oonfX00ooo0`3ooo]ZoookJP11oookJP03o`000?oo
nf[ooo]Z00oooo]Z0005oookJP03o`000?oonf[ooo]Z05Kooo]Z0ol0002;oookJP03o`000?oonf[o
oo]Z00kooo]Z00?ooaX0oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP05oookJP03ool30?oonf[o
oo]Z047ooo]Z00?o0000oookJ_oonfX03ooonfX000Gooo]Z00?o0000oookJ_oonfX0DooonfX3o`00
08kooo]Z00?o0000oookJ_oonfX0m?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
00oooo]Z0005oookJP03o`000?oonf[ooo]Z053ooo]Z0ol0000HoookJP03oolc0?oonf[ooo]Z07Ko
oo]Z00?o0000oookJ_oonfX0N_oonfX00ooo203ooo]ZoookJP1hoookJP03o`000?oonf[ooo]Z04Oo
oo]Z00?o0000oookJ_oonfX03ooonfX000Cooo]Z00?o0000oookJ_oonfX0C_oonfX3o`0001_ooo]Z
00?ooc<0oookJ_oonfX0M_oonfX00ol0003ooo]ZoookJP2OoookJP03ool<0?oonf[ooo]Z05?ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0>oookJP001?oonfX00ol0003ooo]Zoook
JP1;oookJP?o00007_oonfX2oolc07Cooo]Z00Cooa@0oookJ_oonf[o0000n?oonfX00ol0003ooo]Z
oookJP17oookJP03o`000?oonf[ooo]Z00kooo]Z0004oookJP03o`000?oonf[ooo]Z04Sooo]Z0ol0
002GoookJP04oolD0?oonf[ooo]Zo`0000?ooo]Z00?ooaP0oookJ_oonfX0looonfX00ol0003ooo]Z
oookJP0EoookJP;oo`D0;ooonfX00ol0003ooo]ZoookJP0>oookJP001?oonfX00ol0003ooo]Zoook
JP15oookJP?o0000WOoonfX01?l0003ooo]ZoookJ_oonfX2oolH0?Gooo]Z00?o0000oookJ_oonfX0
5?oonfX2ool502oooo]Z00?o0000oookJ_oonfX03_oonfX000Cooo]Z00?o0000oookJ_oonfX0@_oo
nfX3o`000:3ooo]Z00?o0000oookJ_oonfX0H?oonfX2ool409Oooo]Z00?o0000oookJ_oonfX0A?oo
nfX00ol0003ooo]ZoookJP0>oookJP001?oonfX00ol0003ooo]ZoookJP0ooookJP?o00002_oonfX0
0ooo9@3ooo]ZoookJP2FoookJP03o`000?oonf[ooo]Z07gooo]Z00?oo`h0oookJ_oonfX0NOoonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z00kooo]Z0004oookJP03o`000?oonf[ooo]Z
03_ooo]Z1?l0000=oookJP;oobD0P_oonfX2ool:01?ooo]Z00?o0000oookJ_oonfX0OOoonfX00ooo
3P3ooo]ZoookJP1joookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX03_oonfX000?o
oo]Z00?o0000oookJ_oonfX0>OoonfX3o`00017ooo]Z0_oo9@2GoookJP03o`000?oonf[ooo]Z0>So
oo]Z00?oo`D0oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z00ko
oo]Z0003oookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0002KoookJP03oolO0?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX0j?oonfX00ooo1@3ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z04;ooo]Z
00?o0000oookJ_oonfX03OoonfX000?ooo]Z00?o0000oookJ_oonfX0<ooonfX3o`0009oooo]Z00?o
oal0oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP3loookJP03o`000?oonf[ooo]Z04;ooo]Z00?o
0000oookJ_oonfX03OoonfX000?ooo]Z00?o0000oookJ_oonfX0<?oonfX3o`00017ooo]Z00?ooc40
oookJ_oonfX0W_oonfX00ol0003ooo]ZoookJP1QoookJP;oo`h0VooonfX00ol0003ooo]ZoookJP11
oookJP03o`000?oonf[ooo]Z00gooo]Z0003oookJP03o`000?oonf[ooo]Z02gooo]Z0ol0000Doook
JP03oola0?oonf[ooo]Z09kooo]Z00?o0000oookJ_oonfX0oooonfX00ol0003ooo]ZoookJP10oook
JP03o`000?oonf[ooo]Z00gooo]Z0003oookJP03o`000?oonf[ooo]Z02[ooo]Z0ol0000GoookJP03
oola0?oonf[ooo]Z07_ooo]Z00?oob00oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP37oookJP03
ool40?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0=oookJP00
0_oonfX00ol0003ooo]ZoookJP0XoookJP?o00006_oonfX00ooo<@3ooo]ZoookJP1koookJP;oob00
8OoonfX00ol0003ooo]ZoookJP3ooookJP;ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]Z
oookJP0=oookJP000_oonfX00ol0003ooo]ZoookJP0UoookJP?o0000W?oonfX00ooo803ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z04Sooo]Z0_oo2P2goookJP03o`000?oonf[ooo]Z03kooo]Z00?o
0000oookJ_oonfX03OoonfX000;ooo]Z00?o0000oookJ_oonfX08_oonfX3o`000<7ooo]Z00?o0000
oookJ_oonfX0o?oonfX2ool700Cooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0<
oookJP000_oonfX00ol0003ooo]ZoookJP0OoookJP?o0000TOoonfX00ooo5P3ooo]ZoookJP0`oook
JP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
00cooo]Z0002oookJP03o`000?oonf[ooo]Z01_ooo]Z1?l0002DoookJP03oolF0?oonf[ooo]Z033o
oo]Z00?o0000oookJ_oonfX0<ooonfX00ooo1@3ooo]ZoookJP3>oookJP03o`000?oonf[ooo]Z03co
oo]Z00?o0000oookJ_oonfX03?oonfX000;ooo]Z00?o0000oookJ_oonfX06?oonfX3o`000<_ooo]Z
00?o0000oookJ_oonfX0<_oonfX00ooo1@3ooo]ZoookJP0/oookJP03ool@0?oonf[ooo]Z0:3ooo]Z
00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0<oookJP0000?ooo]Zo`000?oonfX05ooo
nfX3o`000<kooo]Z00?o0000oookJ_oonfX0e?oonfX2ool802oooo]Z00?o0000oookJ_oonfX0>ooo
nfX00ol0003ooo]ZoookJP0<oookJP0000?ooo]Zo`000?oonfX05?oonfX3o`000=7ooo]Z00?o0000
oookJ_oonfX0e?oonfX00ooo203ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z02oooo]Z00?oo`<0
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0<oookJP0000?ooo]Zo`000?oonfX04OoonfX3o`00
09kooo]Z00?ooah0oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP3ooookJPSooo]Z00?o0000oook
J_oonfX0;_oonfX00ooo0`3ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z00cooo]Z00000ooonf[o
0000oookJP0>oookJP?o0000XOoonfX00ooo7P3ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Go
oo]Z00?ooa<0oookJ_oonfX0`?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z00co
oo]Z00000ooonf[o0000oookJP0;oookJP?o00002_oonfX00ooo:03ooo]ZoookJP3=oookJP03o`00
0?oonf[ooo]Z04Gooo]Z00?ooa<0oookJ_oonfX0J_oonfX00ooo1`3ooo]ZoookJP1CoookJP03o`00
0?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX02ooonfX00003oookJ_l0003ooo]Z00Sooo]Z0ol0
000=oookJP03oolX0?oonf[ooo]Z08Kooo]Z00?oobH0oookJ_oonfX0A?oonfX00ol0003ooo]Zoook
JP3ooookJP[ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0;oookJP0000?ooo]Z
o`000?oonfX01OoonfX3o`00013ooo]Z00?oobP0oookJ_oonfX0Q_oonfX00ooo9P3ooo]ZoookJP14
oookJP03o`000?oonf[ooo]Z02cooo]Z00?ooa40oookJ_oonfX0fooonfX00ol0003ooo]ZoookJP0g
oookJP03o`000?oonf[ooo]Z00_ooo]Z00000ol0003ooo]ZoookJP02oookJP?o0000W?oonfX2oolV
04Gooo]Z00?o0000oookJ_oonfX0;OoonfX00ooo4@3ooo]ZoookJP1ToookJP03ool50?oonf[ooo]Z
07Cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0;oookJP0000?o0000oookJ_l0
00000_l0003VoookJP03o`000?oonf[ooo]Z0?oooo]Z3?oonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z00_ooo]Z0002o`0009Cooo]Z00?oob80oookJ_oonfX0D_oonfX00ol0003ooo]Z
oookJP0GoookJP03ool<0?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Z
oookJP0;oookJP000_oonfX00ol0003ooo]ZoookJP2AoookJP03oolR0?oonf[ooo]Z05;ooo]Z00?o
0000oookJ_oonfX05ooonfX2ool<0?Cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0;oookJP000ooonfX00ol0003ooo]ZoookJP3UoookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX0
0ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z00[ooo]Z0004oookJP;o0000iOoonfX00ol0
003ooo]ZoookJP05oookJP03ool50?oonf[ooo]Z0?oooo]Z1ooonfX00ol0003ooo]ZoookJP0doook
JP03o`000?oonf[ooo]Z00[ooo]Z0006oookJP03o`000?oonf[ooo]Z0>;ooo]Z00?o0000oookJ_oo
nfX0oooonfX@oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX02_oonfX000Oooo]Z
00?o0000oookJ_oonfX0hOoonfX00ol0003ooo]ZoookJP2moookJP03ool:0?oonf[ooo]Z053ooo]Z
00?o0000oookJ_oonfX05?oonfX2ool401cooo]Z00?o0000oookJ_oonfX02_oonfX000Sooo]Z0_l0
003QoookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oo
nf[ooo]Z00[ooo]Z000:oookJP03o`000?oonf[ooo]Z0=kooo]Z00?o0000oookJ_oonfX09OoonfX0
0ooo5@3ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX02_oonfX0
00_ooo]Z00?o0000oookJ_oonfX0gOoonfX00ol0003ooo]ZoookJP0UoookJP03oolE0?oonf[ooo]Z
07;ooo]Z00?oo`/0oookJ_oonfX0HooonfX00ooo103ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z
033ooo]Z00?o0000oookJ_oonfX02_oonfX000cooo]Z0_l0003MoookJP03o`000?oonf[ooo]Z0?oo
oo]Z5?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z00[ooo]Z000>oookJP03o`00
0?oonf[ooo]Z06[ooo]Z00?oob@0oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0=oookJP03oolH
0?oonf[ooo]Z06cooo]Z0_oo2@2FoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0
2OoonfX000oooo]Z00?o0000oookJ_oonfX0JOoonfX2oolT06gooo]Z00?o0000oookJ_oonfX03ooo
nfX00ooo603ooo]ZoookJP3ooookJPGooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP09oookJP004?oonfX2o`0006[ooo]Z00?oob@0oookJ_oonfX0J?oonfX01?oo503ooo]ZoookJ_l0
001UoookJP03ool60?oonf[ooo]Z0;3ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]Zoook
JP09oookJP004_oonfX00ol0003ooo]ZoookJP1JoookJP03oolX0?oonf[ooo]Z07Gooo]Z0_oo5000
0ooonf[o0000oookJP1ToookJP03ool60?oonf[ooo]Z0;7ooo]Z00?o0000oookJ_oonfX0;OoonfX0
0ol0003ooo]ZoookJP09oookJP004ooonfX2o`0005[ooo]Z0_oo:01UoookJP03ool<0?oonf[ooo]Z
017ooo]Z00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oook
J_oonfX02OoonfX001Gooo]Z00?o0000oookJ_oonfX0__oonfX00ooo303ooo]ZoookJP0AoookJP03
o`000?oonf[ooo]Z0?oooo]Z6_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Wo
oo]Z000FoookJP03o`000?oonf[ooo]Z0=7ooo]Z00?o0000oookJ_oonfX0oooonfXKoookJP03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX02OoonfX001Oooo]Z0_l0003AoookJP03o`000?oo
nf[ooo]Z0?oooo]Z6ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Sooo]Z000I
oookJP03o`000?oonf[ooo]Z0<kooo]Z00?o0000oookJ_oonfX0oooonfXLoookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX02?oonfX001[ooo]Z00?o0000oookJ_oonfX0cOoonfX00ol0
003ooo]ZoookJP3ooookJQOooo]Z0_oo1P04oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oook
J_oonfX02?oonfX001_ooo]Z0_l0003=oookJP03o`000?oonf[ooo]Z0?oooo]Z7_oonfX00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z00Sooo]Z000MoookJP03o`000?oonf[ooo]Z0<[ooo]Z
00?o0000oookJ_oonfX0k_oonfX00ooo1P3ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX02?oonfX001kooo]Z00?o0000oookJ_oonfX0bOoonfX00ol0003ooo]Zoook
JP20oookJP;oo`d0BOoonfX00ooo1@3ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX02?oonfX001oooo]Z0_l00039oookJP03o`000?oonf[ooo]Z06?ooo]Z0_oo3P1V
oookJP03ool50?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP08
oookJP008OoonfX00ol0003ooo]ZoookJP2eoookJP03oolJ0?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX0HooonfX00ooo3P3ooo]ZoookJP2joookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oook
J_oonfX02?oonfX002;ooo]Z00?o0000oookJ_oonfX0]?oonfX00ooo6P3ooo]ZoookJP0>oookJP03
o`000?oonf[ooo]Z04Wooo]Z0_oo2`3FoookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oo
nfX01ooonfX002?ooo]Z0_l0002QoookJP03oolL0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
<ooonfX00ooo1`3ooo]ZoookJP3[oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
1ooonfX002Gooo]Z00?o0000oookJ_oonfX07?oonfX00ooo9@3ooo]ZoookJP1_oookJP03oolF0?oo
nf[ooo]Z00gooo]Z00?ooa`0oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP3ooookJR?ooo]Z00?o
0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP07oookJP009_oonfX00ol0003ooo]ZoookJP0K
oookJP;oobD0L?oonfX00ooo5P3ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z0?oooo]Z9?oonfX0
0ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00Oooo]Z000WoookJP;o00006ooonfX00ooo
9@3ooo]ZoookJP2SoookJP03o`000?oonf[ooo]Z0?oooo]Z9OoonfX00ol0003ooo]ZoookJP0Roook
JP03o`000?oonf[ooo]Z00Oooo]Z000YoookJP03o`000?oonf[ooo]Z0;kooo]Z00?o0000oookJ_oo
nfX0oooonfXUoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX01ooonfX002[ooo]Z
00?o0000oookJ_oonfX0_OoonfX00ol0003ooo]ZoookJP3ooookJRKooo]Z00?o0000oookJ_oonfX0
8OoonfX00ol0003ooo]ZoookJP07oookJP00:ooonfX2o`000;gooo]Z00?o0000oookJ_oonfX0oooo
nfXWoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX01_oonfX002gooo]Z00?o0000
oookJ_oonfX0^_oonfX00ol0003ooo]ZoookJP3ooookJRSooo]Z00?o0000oookJ_oonfX08?oonfX0
0ol0003ooo]ZoookJP06oookJP00;_oonfX00ol0003ooo]ZoookJP2ioookJP03o`000?oonf[ooo]Z
0?oooo]Z:OoonfX00ol0003ooo]ZoookJP0CoookJP03ool30?oonf[ooo]Z00Wooo]Z00?o0000oook
J_oonfX01_oonfX002oooo]Z0_l0002ioookJP03o`000?oonf[ooo]Z0?oooo]Z:OoonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z00Kooo]Z000aoookJP03o`000?oonf[ooo]Z0;Kooo]Z
00?o0000oookJ_oonfX0]OoonfX2ool8027ooo]Z0_oo201?oookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX01_oonfX003;ooo]Z0_l0002foookJP03o`000?oonf[ooo]Z09Kooo]Z0_oo
1P2BoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX01_oonfX003Cooo]Z00?o0000
oookJ_oonfX0/ooonfX00ol0003ooo]ZoookJP0]oookJP03oolA0?oonf[ooo]Z01Kooo]Z00?ooa40
oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00Kooo]Z000eoook
JP03o`000?oonf[ooo]Z0;;ooo]Z00?o0000oookJ_oonfX01?oonfX2ool7017ooo]Z0_oo3@0Doook
JP03oolA0?oonf[ooo]Z01Kooo]Z00?ooa40oookJ_oonfX0h_oonfX00ol0003ooo]ZoookJP0Loook
JP03o`000?oonf[ooo]Z00Kooo]Z000foookJP;o0000/OoonfX00ol0003ooo]ZoookJP3ooookJRko
oo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP05oookJP00>?oonfX00ol0003ooo]Z
oookJP1GoookJP03oolM0?oonf[ooo]Z00cooo]Z00?ooah0oookJ_oonfX0AOoonfX00ol0003ooo]Z
oookJP3ooookJRoooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP05oookJP00>Ooo
nfX00ol0003ooo]ZoookJP1FoookJP;ooad03OoonfX00ooo7P3ooo]ZoookJP15oookJP03o`000?oo
nf[ooo]Z0?oooo]Z<?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00Gooo]Z000j
oookJP;o0000[OoonfX00ol0003ooo]ZoookJP3ooookJS7ooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP05oookJP00??oonfX00ol0003ooo]ZoookJP2ZoookJP03o`000?oonf[ooo]Z
0?oooo]Z<OoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Gooo]Z000moookJP03
o`000?oonf[ooo]Z0:Wooo]Z00?o0000oookJ_oonfX0oooonfXboookJP03o`000?oonf[ooo]Z01So
oo]Z00?o0000oookJ_oonfX01OoonfX003kooo]Z0_l0002YoookJP03o`000?oonf[ooo]Z0?oooo]Z
<ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z00Gooo]Z0010oookJP03o`000?oo
nf[ooo]Z0:Kooo]Z00?o0000oookJ_oonfX0oooonfXdoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o
0000oookJ_oonfX01?oonfX0047ooo]Z00?o0000oookJ_oonfX0YOoonfX00ol0003ooo]ZoookJP3o
oookJSCooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP04oookJP00@_oonfX2o`00
0:Gooo]Z00?o0000oookJ_oonfX0oooonfX7oookJP03ool40?oonf[ooo]Z02Kooo]Z00?oo`D0oook
J_oonfX00_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00Cooo]Z0014oookJP03
o`000?oonf[ooo]Z0:;ooo]Z00?o0000oookJ_oonfX0IOoonfX00ooo1`3ooo]ZoookJP3=oookJP03
o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX01?oonfX004Gooo]Z00?o0000oookJ_oonfX0
XOoonfX00ol0003ooo]ZoookJP1UoookJP03ool70?oonf[ooo]Z01Oooo]Z0_oo2P0MoookJP;oo`/0
U_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Cooo]Z0016oookJP;o0000XOoo
nfX00ol0003ooo]ZoookJP2NoookJP03ool;0?oonf[ooo]Z09Gooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP04oookJP00B?oonfX00ol0003ooo]ZoookJP29oookJP03ool>0?oonf[o
oo]Z00oooo]Z00Cooa<0oookJ_oonf[o0000oooonfXjoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o
0000oookJ_oonfX01?oonfX004Wooo]Z00?o0000oookJ_oonfX0V_oonfX01?oo4`3ooo]ZoookJ_l0
000@oookJP03oolE0?oonf[ooo]Z0?oooo]Z:?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oo
nf[ooo]Z00?ooo]Z001:oookJP;o0000WOoonfX00ol0003ooo]ZoookJP0>oookJP;ooaD0oooonfXZ
oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX00ooonfX004cooo]Z00?o0000oook
J_oonfX07?oonfX00ooo803ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z0?oooo]Z>ooonfX00ol0
003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z00?ooo]Z001=oookJP03o`000?oonf[ooo]Z01_o
oo]Z00?oob00oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP3ooookJS_ooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP03oookJP00C_oonfX2o`0001_ooo]Z00?oob00oookJ_oonfX0
NooonfX00ol0003ooo]ZoookJP3ooookJScooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Z
oookJP03oookJP00D?oonfX00ol0003ooo]ZoookJP2FoookJP03o`000?oonf[ooo]Z0?oooo]Z?Ooo
nfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00?ooo]Z001AoookJP03o`000?oonf[o
oo]Z09Gooo]Z00?o0000oookJ_oonfX0oooonfXnoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000
oookJ_oonfX00ooonfX005;ooo]Z0_l0002EoookJP03o`000?oonf[ooo]Z0?oooo]Z?_oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00?ooo]Z001DoookJP03o`000?oonf[ooo]Z09;o
oo]Z00?o0000oookJ_oonfX0oooonfXooookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oo
nfX00_oonfX005Gooo]Z0_l0002BoookJP03o`000?oonf[ooo]Z0<kooo]Z0_oo1@1_oookJP03o`00
0?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX00_oonfX005Oooo]Z00?o0000oookJ_oonfX0Sooo
nfX00ol0003ooo]ZoookJP0doookJP03ool80?oonf[ooo]Z0;cooo]Z00?oo`H0oookJ_oonfX0B_oo
nfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00;ooo]Z001HoookJP03o`000?oonf[o
oo]Z08kooo]Z00?o0000oookJ_oonfX0B_oonfX2ool<0:Oooo]Z00?oo`H0oookJ_oonfX0BooonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00;ooo]Z001IoookJP;o0000S_oonfX00ol0
003ooo]ZoookJP1;oookJP03ool<0?oonf[ooo]Z0??ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0
003ooo]ZoookJP02oookJP00FooonfX00ol0003ooo]ZoookJP1EoookJP03oolD0?oonf[ooo]Z03?o
oo]Z00?o0000oookJ_oonfX0IOoonfX00ooo3@3ooo]ZoookJP3JoookJP03o`000?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX00_oonfX005cooo]Z00?o0000oookJ_oonfX0E?oonfX2oolD03Cooo]Z
00?o0000oookJ_oonfX0oooonfY4oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
0_oonfX005gooo]Z0_l0001UoookJP03oolH0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0oooo
nfY6oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX00OoonfX005oooo]Z00?o0000
oookJ_oonfX0H_oonfX00ooo603ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z0?oooo]ZA_oonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z007ooo]Z001PoookJP03o`000?oonf[ooo]Z
08Gooo]Z00?o0000oookJ_oonfX0oooonfY7oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX00OoonfX0067ooo]Z0_l00025oookJP03o`000?oonf[ooo]Z0?oooo]ZB?oonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z007ooo]Z001SoookJP03o`000?oonf[ooo]Z08;ooo]Z
00?o0000oookJ_oonfX0oooonfY9oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
0OoonfX006Cooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP3ooookJT[ooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP01oookJP00IOoonfX2o`00087ooo]Z00?o0000
oookJ_oonfX0oooonfY:oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00OoonfX0
06Oooo]Z00?o0000oookJ_oonfX0O_oonfX00ol0003ooo]ZoookJP3ooookJT_ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP01oookJP00J?oonfX00ol0003ooo]ZoookJP1moookJP03
o`000?oonf[ooo]Z00Gooo]Z0_oo202CoookJP;oo`L0Z_oonfX00ooo103ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z00Cooo]Z0Ol00001oookJP7ooo]Z001YoookJP;o0000OOoonfX00ol0003ooo]Z
oookJP3ooookJTgooo]Z00?o0000oookJ_oonfX00ooonfX1o`00007ooo]Z0OoonfX006_ooo]Z00?o
0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP0HoookJP;oo`d0X?oonfX00ooo203ooo]Zoook
JP2?oookJP03o`000?oonf[ooo]Z00?ooo]Z0Ol00001oookJP7ooo]Z001/oookJP03o`000?oonf[o
oo]Z07Wooo]Z00?o0000oookJ_oonfX0oooonfY>oookJP03o`000?oonf[ooo]Z00;ooo]Z0Ol00001
oookJP7ooo]Z001]oookJP;o0000NOoonfX00ol0003ooo]ZoookJP0^oookJP03ool@0?oonf[ooo]Z
0?oooo]Z7_oonfX01Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z001_oookJP03o`000?oonf[ooo]Z
07Kooo]Z00?o0000oookJ_oonfX0;ooonfX00ooo403ooo]ZoookJP3ooookJQkooo]Z00Co0000oook
J_oonf[o00000_oonfX0073ooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]ZoookJP3ooook
JU7ooo]Z00?o0000oookJ_l000000_oonfX0077ooo]Z0_l0000LoookJP03oolI0?oonf[ooo]Z05Ko
oo]Z00?o0000oookJ_oonfX0oooonfYAoookJP04o`000?oonf[ooo]Zo`00007ooo]Z001coookJP03
o`000?oonf[ooo]Z01Wooo]Z00?ooaT0oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP3ooookJU;o
oo]Z00?o0000oookJ_l000000OoonfX007Cooo]Z0_l0001boookJP03o`000?oonf[ooo]Z0?oooo]Z
DooonfX2o`00007ooo]Z001foookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX0oooo
nfYBoookJP?o00000OoonfX007Oooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP3o
oookJTkooo]Z1?l00004oookJP00N?oonfX2o`0006kooo]Z00?o0000oookJ_oonfX0oooonfY:oook
JPCo00002?oonfX007[ooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP1VoookJP;o
o`P0g?oonfX5o`0000cooo]Z001koookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03ool50?oonf[ooo]Z03;ooo]Z1?l0000AoookJP00O?oonfX2o`0005Cooo]Z00?o
o`h0oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP3ooookJSgooo]Z1?l0000EoookJP00O_oonfX0
0ol0003ooo]ZoookJP1AoookJP03ool>0?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0P_oonfX0
0ooo2P3ooo]ZoookJP2coookJPCo00006OoonfX007oooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0
003ooo]ZoookJP22oookJP03ool:0?oonf[ooo]Z0:oooo]Z1?l0000MoookJP00P?oonfX2o`0006Ko
oo]Z00?o0000oookJ_oonfX0oooonfXaoookJPCo00008OoonfX008;ooo]Z00?o0000oookJ_oonfX0
GooonfX2oolB00;ooo]Z00?o0000oookJ_oonfX0oooonfX]oookJPCo00009OoonfX008?ooo]Z00?o
0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP3ooookJRSooo]Z1Ol0000YoookJP00Q?oonfX2
o`00067ooo]Z00?o0000oookJ_oonfX0oooonfXUoookJPCo0000;_oonfX008Kooo]Z00?o0000oook
J_oonfX0G_oonfX00ol0003ooo]ZoookJP3ooookJR7ooo]Z1?l0000boookJP00QooonfX00ol0003o
oo]ZoookJP1MoookJP03o`000?oonf[ooo]Z0?oooo]Z7OoonfX4o`0003Kooo]Z0028oookJP;o0000
GOoonfX00ol0003ooo]ZoookJP3ooookJQWooo]Z1?l0000joookJP00R_oonfX00ol0003ooo]Zoook
JP1JoookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX4o`0003kooo]Z002;oookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX0=OoonfX2ool90=Sooo]Z1Ol00012oookJP00S?oonfX2o`00
05Wooo]Z00?o0000oookJ_oonfX0oooonfX<oookJPCo0000AooonfX008kooo]Z00?o0000oookJ_oo
nfX0E_oonfX00ol0003ooo]ZoookJP3CoookJP;oo`H0<_oonfX4o`0004_ooo]Z002?oookJP03o`00
0?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0oooonfX4oookJPCo0000CooonfX0093ooo]Z0_l0
001EoookJP03o`000?oonf[ooo]Z04gooo]Z00?oo``0oookJ_oonfX0[ooonfX4o`0005?ooo]Z002B
oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0COoonfX00ooo303ooo]ZoookJP2[
oookJPCo0000EooonfX009?ooo]Z0_l0000LoookJP03oolB0?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0m_oonfX5o`0005_ooo]Z002EoookJP03o`000?oonf[ooo]Z01Wooo]Z00?ooa80oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP3boookJPCo0000H?oonfX009Kooo]Z00?o0000oookJ_oonfX0
C_oonfX00ol0003ooo]ZoookJP3^oookJPCo0000I?oonfX009Oooo]Z0_l0001>oookJP03o`000?oo
nf[ooo]Z0>[ooo]Z1?l0001XoookJP00VOoonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[o
oo]Z0>Kooo]Z1?l0001/oookJP00V_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z
0>;ooo]Z1?l0001`oookJP00VooonfX2o`0004[ooo]Z00?o0000oookJ_oonfX0g_oonfX4o`0007Co
oo]Z002MoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX01OoonfX00ooo2@3ooo]Z
oookJP3AoookJPGo0000N?oonfX009kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Zoook
JP3EoookJPCo0000OOoonfX009oooo]Z0_l00016oookJP03o`000?oonf[ooo]Z09gooo]Z00?oo`L0
oookJ_oonfX0<OoonfX4o`00087ooo]Z002QoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oook
J_oonfX0WOoonfX00ooo1`3ooo]ZoookJP0]oookJPCo0000QOoonfX00:;ooo]Z00?o0000oookJ_oo
nfX0@_oonfX00ol0003ooo]ZoookJP39oookJPCo0000ROoonfX00:?ooo]Z0_l00012oookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?oo`d0oookJ_oonfX0ZOoonfX4o`0008gooo]Z002UoookJP03o`000?oo
nf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0`?oonfX5o`00097ooo]Z002VoookJP03o`000?oonf[o
oo]Z03kooo]Z00?o0000oookJ_oonfX0_?oonfX4o`0009Kooo]Z002WoookJP;o0000?_oonfX00ol0
003ooo]ZoookJP2hoookJPCo0000V_oonfX00:Wooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003o
oo]ZoookJP2doookJPCo0000W_oonfX00:[ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Z
oookJP2`oookJPCo0000X_oonfX00:_ooo]Z0_l0000ioookJP03o`000?oonf[ooo]Z0:gooo]Z1?l0
002VoookJP00[OoonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z0:Sooo]Z1Ol0002Z
oookJP00[_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z0:Cooo]Z1?l0002_oook
JP00[ooonfX2o`0003Gooo]Z00?o0000oookJ_oonfX0X?oonfX4o`000;?ooo]Z002aoookJP03o`00
0?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0JOoonfX2ool8037ooo]Z1?l0002goookJP00/_oo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z06Wooo]Z00?oo`P0oookJ_oonfX0;?oo
nfX4o`000;_ooo]Z002coookJP;o00006ooonfX00ooo3@3ooo]ZoookJP0CoookJP03o`000?oonf[o
oo]Z09Cooo]Z1?l0002ooookJP00]OoonfX00ol0003ooo]ZoookJP0HoookJP;oo`d05?oonfX00ol0
003ooo]ZoookJP2@oookJPCo0000`ooonfX00;Kooo]Z0_l0000^oookJP03o`000?oonf[ooo]Z08_o
oo]Z1Ol00037oookJP00^?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z08Oooo]Z
1?l0003<oookJP00^OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z08?ooo]Z1?l0
003@oookJP00^_oonfX2o`0002[ooo]Z00?o0000oookJ_oonfX0OooonfX4o`000=Cooo]Z002loook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0NooonfX4o`000=Sooo]Z002moookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0MooonfX4o`000=cooo]Z002noookJP;o0000
9_oonfX00ol0003ooo]ZoookJP1boookJPGo0000h?oonfX00<3ooo]Z00?o0000oookJ_oonfX08ooo
nfX00ol0003ooo]ZoookJP1^oookJPCo0000iOoonfX00<7ooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP1ZoookJPCo0000jOoonfX00<;ooo]Z0_l0000RoookJP03o`000?oonf[ooo]Z
03Kooo]Z0_oo2@0^oookJPCo0000kOoonfX00<Cooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP1RoookJPCo0000lOoonfX00<Gooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP1NoookJPCo0000mOoonfX00<Kooo]Z0_l0000NoookJP03o`000?oonf[ooo]Z05[ooo]Z1?l0
003ioookJP00b?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z05Gooo]Z1Ol0003m
oookJP00bOoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z057ooo]Z1?l0003ooook
JP?ooo]Z003:oookJP;o00006_oonfX00ol0003ooo]ZoookJP1=oookJPCo0000oooonfX7oookJP00
c?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Wooo]Z1?l0003ooookJP_ooo]Z
003=oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0AOoonfX4o`000?oooo]Z3ooo
nfX00<kooo]Z0_l0000FoookJP03o`000?oonf[ooo]Z047ooo]Z1?l0003ooookJQ?ooo]Z003@oook
JP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0??oonfX5o`000?oooo]Z5ooonfX00=7o
oo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP0hoookJPCo0000oooonfXLoookJP00
d_oonfX2o`00017ooo]Z00?o0000oookJ_oonfX01_oonfX00ooo2@3ooo]ZoookJP0/oookJPCo0000
oooonfXPoookJP00e?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z037ooo]Z1?l0
003ooookJRCooo]Z003EoookJP;o00003_oonfX00ol0003ooo]ZoookJP0]oookJPCo0000oooonfXX
oookJP00eooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02Wooo]Z1?l0003ooook
JRcooo]Z003HoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX09?oonfX5o`000?oo
oo]Z<?oonfX00=Wooo]Z0_l0000:oookJP03o`000?oonf[ooo]Z023ooo]Z1?l0003ooookJSGooo]Z
003KoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX07?oonfX4o`000?oooo]Z>Ooo
nfX00=cooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0HoookJPCo0000oooonfXm
oookJP00gOoonfX2o`0000Kooo]Z00?o0000oookJ_oonfX05?oonfX4o`000?oooo]Z@OoonfX00=oo
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0@oookJPCo0000oooonfY5oookJP00
h?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00cooo]Z1?l0003ooookJTWooo]Z
003QoookJP;o00000_oonfX00ol0003ooo]ZoookJP07oookJPGo0000oooonfY=oookJP00hooonfX0
0ol0003ooo]Zo`000005oookJPCo0000oooonfYBoookJP00i?oonfX2o`000003oookJ_l0003o0000
00;o0000oooonfYFoookJP00iOoonfX2o`000?oooo]ZF_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {571.312, 0}} -> {0.0156635, -4.57623*^-6, \
0.00160201, 0.00160201}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Demonstrate that the divergence of the curl vanishes for the above \
function independent of n\
\>", "Text",
  CellTags->"mmtag:13:divergence_of_curl__example"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DivCurl\  = \ Div[Glenda[x, y, z, n], Cartesian[x, y, z]]\)], "Input"],

Cell[BoxData[
    \(2\ \((\(-1\) - 
            n\/2)\)\ n\ x\^2\ z\^\(\(-1\) + n\)\ \((x\^2 + y\^2 + z\^2)\)\^\(\
\(-2\) - n\/2\) + 
      2\ \((\(-1\) - 
            n\/2)\)\ n\ y\^2\ z\^\(\(-1\) + n\)\ \((x\^2 + y\^2 + z\^2)\)\^\(\
\(-2\) - n\/2\) + 
      2\ \((\(-1\) - 
            n\/2)\)\ n\ z\^\(1 + n\)\ \((x\^2 + y\^2 + z\^2)\)\^\(\(-2\) - \
n\/2\) + 2\ n\ z\^\(\(-1\) + n\)\ \((x\^2 + y\^2 + z\^2)\)\^\(\(-1\) - n\/2\) \
+ n\^2\ z\^\(\(-1\) + n\)\ \((x\^2 + y\^2 + z\^2)\)\^\(\(-1\) - n\/2\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[DivCurl]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{4, 1920}, {0, 1178}},
ScreenStyleEnvironment->"Presentation",
WindowToolbars->"EditBar",
WindowSize->{1057, 724},
WindowMargins->{{Automatic, 192}, {Automatic, 98}},
WindowTitle->"Lecture 13 MIT 3.016 (Fall 2005)   \[Copyright] W. Craig Carter \
2003-2005",
CellLabelAutoDelete->True,
StyleDefinitions -> "3016_Carter.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "mmtag:13:1/r_potentials"->{
    Cell[2007, 60, 224, 4, 81, "Text",
      CellTags->"mmtag:13:1/r_potentials"]},
  "mmtag:13:gradient__example_function"->{
    Cell[3028, 91, 218, 4, 59, "Input",
      CellTags->"mmtag:13:gradient__example_function"]},
  "mmtag:13:Plot3D[]__example_1/r_potentials"->{
    Cell[3783, 115, 161, 3, 59, "Input",
      CellTags->"mmtag:13:Plot3D[]__example_1/r_potentials"]},
  "mmtag:13:ContourPlot[]__example_1/r_potentials"->{
    Cell[280161, 4986, 248, 4, 80, "Input",
      CellTags->"mmtag:13:ContourPlot[]__example_1/r_potentials"]},
  "mmtag:13:PlotVectorField[]__example_gradient_of_1/r_potentials"->{
    Cell[523234, 10244, 282, 4, 80, "Input",
      CellTags->
      "mmtag:13:PlotVectorField[]__example_gradient_of_1/r_potentials"]},
  "mmtag:13:divergence__example_function"->{
    Cell[667879, 14449, 172, 3, 59, "Input",
      CellTags->"mmtag:13:divergence__example_function"]},
  "mmtag:13:laplacian__example_divegence_of_gradient_of_1/r_potentials"->{
    Cell[668850, 14472, 343, 6, 60, "Text",
      CellTags->
      "mmtag:13:laplacian__example_divegence_of_gradient_of_1/r_potentials"]},\

  "mmtag:13:Plot3D[]__example_divegence_of_1/r_potentials"->{
    Cell[669218, 14482, 184, 3, 59, "Input",
      CellTags->"mmtag:13:Plot3D[]__example_divegence_of_1/r_potentials"]},
  "mmtag:13:VectorAnalysis_package"->{
    Cell[1340051, 27106, 107, 2, 59, "Input",
      CellTags->"mmtag:13:VectorAnalysis_package"]},
  "mmtag:13:coordinate_systems__converting_between"->{
    Cell[1340257, 27117, 122, 1, 78, "Subsection",
      CellTags->"mmtag:13:coordinate_systems__converting_between"]},
  "mmtag:13:CoordinatesFromCartesian[]"->{
    Cell[1340500, 27127, 152, 3, 59, "Input",
      CellTags->"mmtag:13:CoordinatesFromCartesian[]"]},
  "mmtag:13:CoordinatesToCartesian[]"->{
    Cell[1341280, 27151, 154, 3, 59, "Input",
      CellTags->"mmtag:13:CoordinatesToCartesian[]"],
    Cell[1341437, 27156, 155, 3, 74, "Output",
      CellTags->"mmtag:13:CoordinatesToCartesian[]"]},
  "mmtag:13:MiscellaneousCityData_package"->{
    Cell[1342165, 27187, 113, 2, 59, "Input",
      CellTags->"mmtag:13:MiscellaneousCityData_package"]},
  "mmtag:13:latitude_and_longitude"->{
    Cell[1342281, 27191, 165, 4, 59, "Text",
      CellTags->"mmtag:13:latitude_and_longitude"]},
  "mmtag:13:CityData[]"->{
    Cell[1342471, 27199, 117, 2, 59, "Input",
      CellTags->"mmtag:13:CityData[]"]},
  "mmtag:13:SphericalCoordinatesofCity[]__example_function"->{
    Cell[1342855, 27216, 504, 9, 243, "Input",
      CellTags->"mmtag:13:SphericalCoordinatesofCity[]__example_function"]},
  "mmtag:13:CartesianCoordinatesofCity[]__example_function"->{
    Cell[1343580, 27237, 310, 6, 80, "Input",
      CellTags->{
      "mmtag:13:CartesianCoordinatesofCity[]__example_function", 
        "mmtag:13:distances_from_Boston_to_Paris"}]},
  "mmtag:13:distances_from_Boston_to_Paris"->{
    Cell[1343580, 27237, 310, 6, 80, "Input",
      CellTags->{
      "mmtag:13:CartesianCoordinatesofCity[]__example_function", 
        "mmtag:13:distances_from_Boston_to_Paris"}]},
  "mmtag:13:Grad[]"->{
    Cell[1345178, 27307, 122, 2, 59, "Input",
      CellTags->"mmtag:13:Grad[]"],
    Cell[1345303, 27311, 210, 4, 103, "Output",
      CellTags->"mmtag:13:Grad[]"]},
  "mmtag:13:Div[]"->{
    Cell[1346720, 27369, 132, 3, 59, "Input",
      CellTags->"mmtag:13:Div[]"]},
  "mmtag:13:PlotVectorField3D[]"->{
    Cell[1349135, 27450, 328, 6, 80, "Input",
      CellTags->"mmtag:13:PlotVectorField3D[]"]},
  "mmtag:13:plots__dealing_with_singularities"->{
    Cell[2631234, 124629, 448, 8, 149, "Input",
      CellTags->"mmtag:13:plots__dealing_with_singularities"]},
  "mmtag:13:Curl[]"->{
    Cell[5196740, 322324, 136, 3, 77, "Input",
      CellTags->"mmtag:13:Curl[]"]},
  "mmtag:13:divergence_of_curl__example"->{
    Cell[5388996, 333515, 170, 4, 77, "Text",
      CellTags->"mmtag:13:divergence_of_curl__example"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"mmtag:13:1/r_potentials", 5390796, 333572},
  {"mmtag:13:gradient__example_function", 5390923, 333575},
  {"mmtag:13:Plot3D[]__example_1/r_potentials", 5391069, 333578},
  {"mmtag:13:ContourPlot[]__example_1/r_potentials", 5391227, 333581},
  {"mmtag:13:PlotVectorField[]__example_gradient_of_1/r_potentials", 5391409, \
333584},
  {"mmtag:13:divergence__example_function", 5391590, 333588},
  {"mmtag:13:laplacian__example_divegence_of_gradient_of_1/r_potentials", \
5391769, 333591},
  {"mmtag:13:Plot3D[]__example_divegence_of_1/r_potentials", 5391973, \
333596},
  {"mmtag:13:VectorAnalysis_package", 5392133, 333599},
  {"mmtag:13:coordinate_systems__converting_between", 5392287, 333602},
  {"mmtag:13:CoordinatesFromCartesian[]", 5392450, 333605},
  {"mmtag:13:CoordinatesToCartesian[]", 5392594, 333608},
  {"mmtag:13:MiscellaneousCityData_package", 5392842, 333613},
  {"mmtag:13:latitude_and_longitude", 5392987, 333616},
  {"mmtag:13:CityData[]", 5393112, 333619},
  {"mmtag:13:SphericalCoordinatesofCity[]__example_function", 5393262, \
333622},
  {"mmtag:13:CartesianCoordinatesofCity[]__example_function", 5393449, \
333625},
  {"mmtag:13:distances_from_Boston_to_Paris", 5393680, 333630},
  {"mmtag:13:Grad[]", 5393887, 333635},
  {"mmtag:13:Div[]", 5394076, 333640},
  {"mmtag:13:PlotVectorField3D[]", 5394194, 333643},
  {"mmtag:13:plots__dealing_with_singularities", 5394340, 333646},
  {"mmtag:13:Curl[]", 5394475, 333649},
  {"mmtag:13:divergence_of_curl__example", 5394603, 333652}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 72, 0, 104, "Title"],

Cell[CellGroupData[{
Cell[1851, 55, 153, 3, 115, "Section"],
Cell[2007, 60, 224, 4, 81, "Text",
  CellTags->"mmtag:13:1/r_potentials"],
Cell[2234, 66, 133, 2, 59, "Input"],
Cell[2370, 70, 71, 0, 59, "Text"],
Cell[2444, 72, 114, 2, 59, "Input"],
Cell[2561, 76, 75, 0, 59, "Text"],
Cell[2639, 78, 116, 2, 59, "Input"],
Cell[2758, 82, 122, 2, 59, "Input"],
Cell[2883, 86, 142, 3, 86, "Text"],
Cell[3028, 91, 218, 4, 59, "Input",
  CellTags->"mmtag:13:gradient__example_function"],
Cell[3249, 97, 59, 0, 59, "Text"],
Cell[3311, 99, 181, 3, 80, "Input"],
Cell[3495, 104, 44, 0, 59, "Text"],
Cell[3542, 106, 152, 3, 59, "Input"],
Cell[3697, 111, 61, 0, 59, "Text"],

Cell[CellGroupData[{
Cell[3783, 115, 161, 3, 59, "Input",
  CellTags->"mmtag:13:Plot3D[]__example_1/r_potentials"],
Cell[3947, 120, 275969, 4854, 476, 72134, 2333, "GraphicsData", "PostScript", \
"Graphics"],
Cell[279919, 4976, 137, 3, 74, "Output"]
}, Open  ]],
Cell[280071, 4982, 65, 0, 59, "Text"],

Cell[CellGroupData[{
Cell[280161, 4986, 248, 4, 80, "Input",
  CellTags->"mmtag:13:ContourPlot[]__example_1/r_potentials"],
Cell[280412, 4992, 241996, 5223, 584, 45657, 2794, "GraphicsData", \
"PostScript", "Graphics"],
Cell[522411, 10217, 137, 3, 74, "Output"]
}, Open  ]],
Cell[522563, 10223, 54, 0, 59, "Text"],

Cell[CellGroupData[{
Cell[522642, 10227, 82, 1, 59, "Input"],
Cell[522727, 10230, 412, 6, 205, "Output"]
}, Open  ]],
Cell[523154, 10239, 55, 1, 59, "Input"],

Cell[CellGroupData[{
Cell[523234, 10244, 282, 4, 80, "Input",
  CellTags->
  "mmtag:13:PlotVectorField[]__example_gradient_of_1/r_potentials"],
Cell[523519, 10250, 292, 5, 48, "Message"],
Cell[523814, 10257, 311, 5, 26, "Message"],
Cell[524128, 10264, 292, 5, 48, "Message"],
Cell[524423, 10271, 311, 5, 26, "Message"],
Cell[524737, 10278, 142861, 4158, 584, 62326, 3159, "GraphicsData", \
"PostScript", "Graphics"],
Cell[667601, 14438, 130, 3, 74, "Output"]
}, Open  ]],
Cell[667746, 14444, 130, 3, 59, "Text"],
Cell[667879, 14449, 172, 3, 59, "Input",
  CellTags->"mmtag:13:divergence__example_function"],

Cell[CellGroupData[{
Cell[668076, 14456, 116, 2, 59, "Input"],
Cell[668195, 14460, 640, 9, 261, "Output"]
}, Open  ]],
Cell[668850, 14472, 343, 6, 60, "Text",
  CellTags->
  "mmtag:13:laplacian__example_divegence_of_gradient_of_1/r_potentials"],

Cell[CellGroupData[{
Cell[669218, 14482, 184, 3, 59, "Input",
  CellTags->"mmtag:13:Plot3D[]__example_divegence_of_1/r_potentials"],
Cell[669405, 14487, 670252, 12601, 476, 301193, 8040, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1339660, 27090, 137, 3, 74, "Output"]
}, Open  ]],
Cell[1339812, 27096, 180, 6, 59, "Text"],
Cell[1339995, 27104, 53, 0, 52, "Subtitle"],
Cell[1340051, 27106, 107, 2, 59, "Input",
  CellTags->"mmtag:13:VectorAnalysis_package"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1340195, 27113, 37, 0, 84, "Section"],

Cell[CellGroupData[{
Cell[1340257, 27117, 122, 1, 78, "Subsection",
  CellTags->"mmtag:13:coordinate_systems__converting_between"],
Cell[1340382, 27120, 93, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[1340500, 27127, 152, 3, 59, "Input",
  CellTags->"mmtag:13:CoordinatesFromCartesian[]"],
Cell[1340655, 27132, 359, 5, 26, "Message"],
Cell[1341017, 27139, 118, 2, 116, "Output"]
}, Open  ]],
Cell[1341150, 27144, 105, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[1341280, 27151, 154, 3, 59, "Input",
  CellTags->"mmtag:13:CoordinatesToCartesian[]"],
Cell[1341437, 27156, 155, 3, 74, "Output",
  CellTags->"mmtag:13:CoordinatesToCartesian[]"]
}, Open  ]],
Cell[1341607, 27162, 92, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[1341724, 27169, 144, 3, 59, "Input"],
Cell[1341871, 27174, 121, 2, 116, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1342041, 27182, 121, 3, 78, "Subsection"],
Cell[1342165, 27187, 113, 2, 59, "Input",
  CellTags->"mmtag:13:MiscellaneousCityData_package"],
Cell[1342281, 27191, 165, 4, 59, "Text",
  CellTags->"mmtag:13:latitude_and_longitude"],

Cell[CellGroupData[{
Cell[1342471, 27199, 117, 2, 59, "Input",
  CellTags->"mmtag:13:CityData[]"],
Cell[1342591, 27203, 76, 1, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1342704, 27209, 80, 1, 59, "Input"],
Cell[1342787, 27212, 53, 1, 74, "Output"]
}, Open  ]],
Cell[1342855, 27216, 504, 9, 243, "Input",
  CellTags->"mmtag:13:SphericalCoordinatesofCity[]__example_function"],

Cell[CellGroupData[{
Cell[1343384, 27229, 73, 1, 59, "Input"],
Cell[1343460, 27232, 105, 2, 100, "Output"]
}, Open  ]],
Cell[1343580, 27237, 310, 6, 80, "Input",
  CellTags->{
  "mmtag:13:CartesianCoordinatesofCity[]__example_function", 
    "mmtag:13:distances_from_Boston_to_Paris"}],

Cell[CellGroupData[{
Cell[1343915, 27247, 72, 1, 59, "Input"],
Cell[1343990, 27250, 102, 2, 74, "Output"]
}, Open  ]],
Cell[1344107, 27255, 194, 3, 80, "Input"],

Cell[CellGroupData[{
Cell[1344326, 27262, 73, 1, 59, "Input"],
Cell[1344402, 27265, 52, 1, 74, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1344503, 27272, 98, 3, 78, "Subsection"],

Cell[CellGroupData[{
Cell[1344626, 27279, 70, 1, 77, "Input"],
Cell[1344699, 27282, 52, 1, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1344788, 27288, 71, 1, 77, "Input"],
Cell[1344862, 27291, 52, 1, 74, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1344975, 27299, 52, 0, 84, "Section"],
Cell[1345030, 27301, 123, 2, 96, "Input"],

Cell[CellGroupData[{
Cell[1345178, 27307, 122, 2, 59, "Input",
  CellTags->"mmtag:13:Grad[]"],
Cell[1345303, 27311, 210, 4, 103, "Output",
  CellTags->"mmtag:13:Grad[]"]
}, Open  ]],
Cell[1345528, 27318, 143, 3, 109, "Text"],
Cell[1345674, 27323, 151, 4, 55, "Text"],
Cell[1345828, 27329, 65, 1, 85, "Input"],

Cell[CellGroupData[{
Cell[1345918, 27334, 124, 3, 59, "Input"],
Cell[1346045, 27339, 58, 1, 100, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1346140, 27345, 87, 1, 59, "Input"],
Cell[1346230, 27348, 58, 1, 100, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1346325, 27354, 108, 2, 59, "Input"],
Cell[1346436, 27358, 106, 2, 116, "Output"]
}, Open  ]],
Cell[1346557, 27363, 138, 2, 59, "Input"],

Cell[CellGroupData[{
Cell[1346720, 27369, 132, 3, 59, "Input",
  CellTags->"mmtag:13:Div[]"],
Cell[1346855, 27374, 109, 2, 84, "Output"]
}, Open  ]],
Cell[1346979, 27379, 169, 3, 109, "Text"],

Cell[CellGroupData[{
Cell[1347173, 27386, 102, 2, 59, "Input"],
Cell[1347278, 27390, 35, 1, 74, "Output"]
}, Open  ]],
Cell[1347328, 27394, 252, 4, 83, "Text"],
Cell[1347583, 27400, 38, 0, 52, "Subtitle"],
Cell[1347624, 27402, 817, 19, 140, "Text"],
Cell[1348444, 27423, 172, 3, 99, "Input"],

Cell[CellGroupData[{
Cell[1348641, 27430, 58, 1, 59, "Input"],
Cell[1348702, 27433, 216, 4, 111, "Output"]
}, Open  ]],
Cell[1348933, 27440, 57, 1, 59, "Input"],
Cell[1348993, 27443, 117, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[1349135, 27450, 328, 6, 80, "Input",
  CellTags->"mmtag:13:PlotVectorField3D[]"],
Cell[1349466, 27458, 278, 4, 48, "Message"],
Cell[1349747, 27464, 311, 5, 26, "Message"],
Cell[1350061, 27471, 311, 5, 26, "Message"],
Cell[1350375, 27478, 311, 5, 26, "Message"],
Cell[1350689, 27485, 336, 5, 26, "Message"],
Cell[1351028, 27492, 278, 4, 48, "Message"],
Cell[1351309, 27498, 278, 4, 48, "Message"],
Cell[1351590, 27504, 329, 5, 26, "Message"],
Cell[1351922, 27511, 1279059, 97105, 523, 1050774, 94282, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2630984, 124618, 132, 3, 74, "Output"]
}, Open  ]],
Cell[2631131, 124624, 100, 3, 59, "Text"],
Cell[2631234, 124629, 448, 8, 149, "Input",
  CellTags->"mmtag:13:plots__dealing_with_singularities"],

Cell[CellGroupData[{
Cell[2631707, 124641, 290, 5, 80, "Input"],
Cell[2632000, 124648, 1280112, 97163, 523, 1051378, 94335, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3912115, 221813, 132, 3, 74, "Output"]
}, Open  ]],
Cell[3912262, 221819, 103, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[3912390, 221826, 274, 5, 80, "Input"],
Cell[3912667, 221833, 1283712, 100475, 543, 1092823, 98114, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5196382, 322310, 132, 3, 74, "Output"]
}, Open  ]],
Cell[5196529, 322316, 186, 4, 125, "Text"],

Cell[CellGroupData[{
Cell[5196740, 322324, 136, 3, 77, "Input",
  CellTags->"mmtag:13:Curl[]"],
Cell[5196879, 322329, 188, 3, 111, "Output"]
}, Open  ]],
Cell[5197082, 322335, 71, 0, 59, "Text"],
Cell[5197156, 322337, 150, 3, 59, "Input"],
Cell[5197309, 322342, 126, 3, 77, "Text"],

Cell[CellGroupData[{
Cell[5197460, 322349, 51, 1, 59, "Input"],
Cell[5197514, 322352, 242, 3, 84, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5197793, 322360, 51, 1, 59, "Input"],
Cell[5197847, 322363, 162, 3, 103, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5198046, 322371, 181, 3, 57, "Subsubsection"],
Cell[5198230, 322376, 42, 0, 59, "Text"],

Cell[CellGroupData[{
Cell[5198297, 322380, 248, 5, 80, "Input"],
Cell[5198548, 322387, 190298, 11120, 581, 113692, 10170, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5388849, 333509, 132, 3, 74, "Output"]
}, Open  ]],
Cell[5388996, 333515, 170, 4, 77, "Text",
  CellTags->"mmtag:13:divergence_of_curl__example"],

Cell[CellGroupData[{
Cell[5389191, 333523, 90, 1, 59, "Input"],
Cell[5389284, 333526, 519, 11, 141, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5389840, 333542, 50, 1, 59, "Input"],
Cell[5389893, 333545, 35, 1, 74, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

